package io.flutter.embedding.engine;

import android.content.Context;
import android.content.res.AssetManager;
import android.graphics.Bitmap;
import android.graphics.SurfaceTexture;
import android.opengl.Matrix;
import android.os.Build;
import android.os.Looper;
import android.util.Log;
import android.view.Choreographer;
import android.view.Surface;
import android.view.WindowInsets;
import android.view.accessibility.AccessibilityEvent;
import androidx.annotation.Keep;
import g.a.a.b.a;
import g.a.a.b.e.b;
import g.a.a.b.e.c;
import g.a.b.a.b;
import g.a.b.a.p;
import g.a.e.b;
import g.a.e.e;
import g.a.e.f;
import io.flutter.view.FlutterCallbackInformation;
import java.nio.ByteBuffer;
import java.nio.ByteOrder;
import java.util.ArrayList;
import java.util.HashSet;
import java.util.Iterator;
import java.util.List;
import java.util.Map;
import java.util.Set;
import java.util.concurrent.CopyOnWriteArraySet;

@Keep
public class FlutterJNI {
    public static final String TAG = "FlutterJNI";
    public static b asyncWaitForVsyncDelegate;
    public static String observatoryUri;
    public static float refreshRateFPS;
    public a accessibilityDelegate;
    public final Set<a.b> engineLifecycleListeners = new CopyOnWriteArraySet();
    public final Set<g.a.a.b.h.b> flutterUiDisplayListeners = new CopyOnWriteArraySet();
    public final Looper mainLooper = Looper.getMainLooper();
    public Long nativePlatformViewId;
    public c platformMessageHandler;

    public interface a {
    }

    public interface b {
    }

    public static void asyncWaitForVsync(long j) {
        b bVar = asyncWaitForVsyncDelegate;
        if (bVar != null) {
            f.a aVar = (f.a) bVar;
            if (aVar != null) {
                Choreographer.getInstance().postFrameCallback(new e(aVar, j));
                return;
            }
            throw null;
        }
        throw new IllegalStateException("An AsyncWaitForVsyncDelegate must be registered with FlutterJNI before asyncWaitForVsync() is invoked.");
    }

    private void ensureAttachedToNative() {
        if (this.nativePlatformViewId == null) {
            throw new RuntimeException("Cannot execute operation because FlutterJNI is not attached to native.");
        }
    }

    private void ensureNotAttachedToNative() {
        if (this.nativePlatformViewId != null) {
            throw new RuntimeException("Cannot execute operation because FlutterJNI is attached to native.");
        }
    }

    private void ensureRunningOnMainThread() {
        if (Looper.myLooper() != this.mainLooper) {
            StringBuilder b2 = b.b.a.a.a.b("Methods marked with @UiThread must be executed on the main thread. Current thread: ");
            b2.append(Thread.currentThread().getName());
            throw new RuntimeException(b2.toString());
        }
    }

    public static String getObservatoryUri() {
        return observatoryUri;
    }

    private void handlePlatformMessage(String str, byte[] bArr, int i2) {
        ByteBuffer byteBuffer;
        c cVar = this.platformMessageHandler;
        if (cVar != null) {
            g.a.a.b.e.b bVar = (g.a.a.b.e.b) cVar;
            b.a aVar = bVar.f677b.get(str);
            if (aVar != null) {
                if (bArr == null) {
                    byteBuffer = null;
                } else {
                    try {
                        byteBuffer = ByteBuffer.wrap(bArr);
                    } catch (Exception e2) {
                        Log.e("DartMessenger", "Uncaught exception in binary message listener", e2);
                        bVar.a.invokePlatformMessageEmptyResponseCallback(i2);
                        return;
                    }
                }
                aVar.a(byteBuffer, new b.a(bVar.a, i2));
                return;
            }
            bVar.a.invokePlatformMessageEmptyResponseCallback(i2);
        }
    }

    private void handlePlatformMessageResponse(int i2, byte[] bArr) {
        b.AbstractC0045b remove;
        ByteBuffer byteBuffer;
        c cVar = this.platformMessageHandler;
        if (cVar != null && (remove = ((g.a.a.b.e.b) cVar).c.remove(Integer.valueOf(i2))) != null) {
            if (bArr == null) {
                byteBuffer = null;
            } else {
                try {
                    byteBuffer = ByteBuffer.wrap(bArr);
                } catch (Exception e2) {
                    Log.e("DartMessenger", "Uncaught exception in binary message reply handler", e2);
                    return;
                }
            }
            remove.a(byteBuffer);
        }
    }

    private native long nativeAttach(FlutterJNI flutterJNI, boolean z);

    private native void nativeDestroy(long j);

    private native void nativeDispatchEmptyPlatformMessage(long j, String str, int i2);

    private native void nativeDispatchPlatformMessage(long j, String str, ByteBuffer byteBuffer, int i2, int i3);

    private native void nativeDispatchPointerDataPacket(long j, ByteBuffer byteBuffer, int i2);

    private native void nativeDispatchSemanticsAction(long j, int i2, int i3, ByteBuffer byteBuffer, int i4);

    private native Bitmap nativeGetBitmap(long j);

    public static native void nativeInit(Context context, String[] strArr, String str, String str2, String str3);

    private native void nativeInvokePlatformMessageEmptyResponseCallback(long j, int i2);

    private native void nativeInvokePlatformMessageResponseCallback(long j, int i2, ByteBuffer byteBuffer, int i3);

    public static native FlutterCallbackInformation nativeLookupCallbackInformation(long j);

    private native void nativeMarkTextureFrameAvailable(long j, long j2);

    public static native void nativeOnVsync(long j, long j2, long j3);

    public static native void nativeRecordStartTimestamp(long j);

    private native void nativeRegisterTexture(long j, long j2, SurfaceTexture surfaceTexture);

    private native void nativeRunBundleAndSnapshotFromLibrary(long j, String str, String str2, String str3, AssetManager assetManager);

    private native void nativeSetAccessibilityFeatures(long j, int i2);

    private native void nativeSetSemanticsEnabled(long j, boolean z);

    private native void nativeSetViewportMetrics(long j, float f2, int i2, int i3, int i4, int i5, int i6, int i7, int i8, int i9, int i10, int i11, int i12, int i13, int i14, int i15);

    private native void nativeSurfaceChanged(long j, int i2, int i3);

    private native void nativeSurfaceCreated(long j, Surface surface);

    private native void nativeSurfaceDestroyed(long j);

    private native void nativeUnregisterTexture(long j, long j2);

    private void onPreEngineRestart() {
        for (a.b bVar : this.engineLifecycleListeners) {
            bVar.a();
        }
    }

    public static void setAsyncWaitForVsyncDelegate(b bVar) {
        asyncWaitForVsyncDelegate = bVar;
    }

    public static void setRefreshRateFPS(float f2) {
        refreshRateFPS = f2;
    }

    private void updateCustomAccessibilityActions(ByteBuffer byteBuffer, String[] strArr) {
        String str;
        String str2;
        ensureRunningOnMainThread();
        a aVar = this.accessibilityDelegate;
        if (aVar != null) {
            b.a aVar2 = (b.a) aVar;
            if (aVar2 != null) {
                byteBuffer.order(ByteOrder.LITTLE_ENDIAN);
                g.a.e.b bVar = g.a.e.b.this;
                if (bVar != null) {
                    while (byteBuffer.hasRemaining()) {
                        b.g a2 = bVar.a(byteBuffer.getInt());
                        a2.c = byteBuffer.getInt();
                        int i2 = byteBuffer.getInt();
                        if (i2 == -1) {
                            str = null;
                        } else {
                            str = strArr[i2];
                        }
                        a2.f795d = str;
                        int i3 = byteBuffer.getInt();
                        if (i3 == -1) {
                            str2 = null;
                        } else {
                            str2 = strArr[i3];
                        }
                        a2.f796e = str2;
                    }
                    return;
                }
                throw null;
            }
            throw null;
        }
    }

    private void updateSemantics(ByteBuffer byteBuffer, String[] strArr) {
        int i2;
        b.j jVar;
        int i3;
        b.j jVar2;
        b.j jVar3;
        int i4;
        String str;
        String str2;
        String str3;
        float f2;
        float f3;
        int i5;
        WindowInsets rootWindowInsets;
        ensureRunningOnMainThread();
        a aVar = this.accessibilityDelegate;
        if (aVar != null) {
            b.a aVar2 = (b.a) aVar;
            if (aVar2 != null) {
                byteBuffer.order(ByteOrder.LITTLE_ENDIAN);
                g.a.e.b bVar = g.a.e.b.this;
                if (bVar != null) {
                    ArrayList arrayList = new ArrayList();
                    while (true) {
                        i2 = 16;
                        if (!byteBuffer.hasRemaining()) {
                            break;
                        }
                        b.j b2 = bVar.b(byteBuffer.getInt());
                        b2.t = true;
                        b2.z = b2.p;
                        b2.A = b2.o;
                        b2.u = b2.c;
                        b2.v = b2.f798d;
                        b2.w = b2.f801g;
                        b2.x = b2.f802h;
                        b2.y = b2.l;
                        b2.c = byteBuffer.getInt();
                        b2.f798d = byteBuffer.getInt();
                        b2.f799e = byteBuffer.getInt();
                        b2.f800f = byteBuffer.getInt();
                        b2.f801g = byteBuffer.getInt();
                        b2.f802h = byteBuffer.getInt();
                        b2.f803i = byteBuffer.getInt();
                        b2.j = byteBuffer.getInt();
                        b2.k = byteBuffer.getInt();
                        b2.l = byteBuffer.getFloat();
                        b2.m = byteBuffer.getFloat();
                        b2.n = byteBuffer.getFloat();
                        int i6 = byteBuffer.getInt();
                        b2.o = i6 == -1 ? null : strArr[i6];
                        int i7 = byteBuffer.getInt();
                        b2.p = i7 == -1 ? null : strArr[i7];
                        int i8 = byteBuffer.getInt();
                        b2.q = i8 == -1 ? null : strArr[i8];
                        int i9 = byteBuffer.getInt();
                        b2.r = i9 == -1 ? null : strArr[i9];
                        int i10 = byteBuffer.getInt();
                        b2.s = i10 == -1 ? null : strArr[i10];
                        int i11 = byteBuffer.getInt();
                        if (i11 == 1) {
                            b.k kVar = b.k.RTL;
                        } else if (i11 != 2) {
                            b.k kVar2 = b.k.UNKNOWN;
                        } else {
                            b.k kVar3 = b.k.LTR;
                        }
                        b2.B = byteBuffer.getFloat();
                        b2.C = byteBuffer.getFloat();
                        b2.D = byteBuffer.getFloat();
                        b2.E = byteBuffer.getFloat();
                        if (b2.F == null) {
                            b2.F = new float[16];
                        }
                        for (int i12 = 0; i12 < 16; i12++) {
                            b2.F[i12] = byteBuffer.getFloat();
                        }
                        b2.M = true;
                        b2.O = true;
                        int i13 = byteBuffer.getInt();
                        b2.H.clear();
                        b2.I.clear();
                        for (int i14 = 0; i14 < i13; i14++) {
                            b.j a2 = g.a.e.b.a(b2.a, byteBuffer.getInt());
                            a2.G = b2;
                            b2.H.add(a2);
                        }
                        for (int i15 = 0; i15 < i13; i15++) {
                            b.j a3 = g.a.e.b.a(b2.a, byteBuffer.getInt());
                            a3.G = b2;
                            b2.I.add(a3);
                        }
                        int i16 = byteBuffer.getInt();
                        if (i16 == 0) {
                            b2.J = null;
                        } else {
                            List<b.g> list = b2.J;
                            if (list == null) {
                                b2.J = new ArrayList(i16);
                            } else {
                                list.clear();
                            }
                            for (int i17 = 0; i17 < i16; i17++) {
                                b.g b3 = g.a.e.b.b(b2.a, byteBuffer.getInt());
                                int i18 = b3.c;
                                if (i18 == b.f.TAP.x) {
                                    b2.K = b3;
                                } else if (i18 == b.f.LONG_PRESS.x) {
                                    b2.L = b3;
                                } else {
                                    b2.J.add(b3);
                                }
                                b2.J.add(b3);
                            }
                        }
                        if (!b2.a(b.h.IS_HIDDEN)) {
                            if (b2.a(b.h.IS_FOCUSED)) {
                                bVar.m = b2;
                            }
                            if (b2.t) {
                                arrayList.add(b2);
                            }
                        }
                    }
                    HashSet hashSet = new HashSet();
                    b.j a4 = bVar.a();
                    ArrayList arrayList2 = new ArrayList();
                    if (a4 != null) {
                        float[] fArr = new float[16];
                        Matrix.setIdentityM(fArr, 0);
                        if (Build.VERSION.SDK_INT >= 23 && (rootWindowInsets = bVar.a.getRootWindowInsets()) != null) {
                            if (!bVar.r.equals(Integer.valueOf(rootWindowInsets.getSystemWindowInsetLeft()))) {
                                a4.O = true;
                                a4.M = true;
                            }
                            Integer valueOf = Integer.valueOf(rootWindowInsets.getSystemWindowInsetLeft());
                            bVar.r = valueOf;
                            Matrix.translateM(fArr, 0, (float) valueOf.intValue(), 0.0f, 0.0f);
                        }
                        a4.a(fArr, (Set<b.j>) hashSet, false);
                        a4.a(arrayList2);
                    }
                    Iterator it = arrayList2.iterator();
                    b.j jVar4 = null;
                    while (it.hasNext()) {
                        b.j jVar5 = (b.j) it.next();
                        if (!bVar.p.contains(Integer.valueOf(jVar5.f797b))) {
                            jVar4 = jVar5;
                        }
                    }
                    if (jVar4 == null && arrayList2.size() > 0) {
                        jVar4 = (b.j) arrayList2.get(arrayList2.size() - 1);
                    }
                    if (!(jVar4 == null || (i5 = jVar4.f797b) == bVar.q)) {
                        bVar.q = i5;
                        AccessibilityEvent a5 = bVar.a(i5, 32);
                        a5.getText().add(jVar4.a());
                        bVar.a(a5);
                    }
                    bVar.p.clear();
                    Iterator it2 = arrayList2.iterator();
                    while (it2.hasNext()) {
                        bVar.p.add(Integer.valueOf(((b.j) it2.next()).f797b));
                    }
                    Iterator<Map.Entry<Integer, b.j>> it3 = bVar.f790g.entrySet().iterator();
                    while (it3.hasNext()) {
                        b.j value = it3.next().getValue();
                        if (!hashSet.contains(value)) {
                            value.G = null;
                            b.j jVar6 = bVar.f792i;
                            if (jVar6 == value) {
                                bVar.b(jVar6.f797b, 65536);
                                bVar.f792i = null;
                            }
                            if (bVar.m == value) {
                                bVar.m = null;
                            }
                            if (bVar.o == value) {
                                bVar.o = null;
                            }
                            it3.remove();
                        }
                    }
                    bVar.c(0);
                    Iterator it4 = arrayList.iterator();
                    while (it4.hasNext()) {
                        b.j jVar7 = (b.j) it4.next();
                        if (!Float.isNaN(jVar7.l) && !Float.isNaN(jVar7.y) && jVar7.y != jVar7.l) {
                            AccessibilityEvent a6 = bVar.a(jVar7.f797b, 4096);
                            float f4 = jVar7.l;
                            float f5 = jVar7.m;
                            if (Float.isInfinite(f5)) {
                                if (f4 > 70000.0f) {
                                    f4 = 70000.0f;
                                }
                                f5 = 100000.0f;
                            }
                            if (Float.isInfinite(jVar7.n)) {
                                f2 = f5 + 100000.0f;
                                if (f4 < -70000.0f) {
                                    f4 = -70000.0f;
                                }
                                f3 = f4 + 100000.0f;
                            } else {
                                float f6 = jVar7.n;
                                f2 = f5 - f6;
                                f3 = f4 - f6;
                            }
                            if (b.j.b(jVar7, b.f.SCROLL_UP) || b.j.b(jVar7, b.f.SCROLL_DOWN)) {
                                a6.setScrollY((int) f3);
                                a6.setMaxScrollY((int) f2);
                            } else if (b.j.b(jVar7, b.f.SCROLL_LEFT) || b.j.b(jVar7, b.f.SCROLL_RIGHT)) {
                                a6.setScrollX((int) f3);
                                a6.setMaxScrollX((int) f2);
                            }
                            int i19 = jVar7.j;
                            if (i19 > 0) {
                                a6.setItemCount(i19);
                                a6.setFromIndex(jVar7.k);
                                int i20 = 0;
                                for (b.j jVar8 : jVar7.I) {
                                    if (!jVar8.a(b.h.IS_HIDDEN)) {
                                        i20++;
                                    }
                                }
                                a6.setToIndex((jVar7.k + i20) - 1);
                            }
                            bVar.a(a6);
                        }
                        String str4 = "";
                        if (jVar7.a(b.h.IS_LIVE_REGION)) {
                            String str5 = jVar7.o;
                            if (str5 == null) {
                                str5 = str4;
                            }
                            if (jVar7.A == null) {
                                str3 = str4;
                            } else {
                                str3 = jVar7.o;
                            }
                            if (!str5.equals(str3) || !b.j.a(jVar7, b.h.IS_LIVE_REGION)) {
                                bVar.c(jVar7.f797b);
                            }
                        } else if (jVar7.a(b.h.IS_TEXT_FIELD)) {
                            if ((!(jVar7.o == null && jVar7.A == null) && ((str = jVar7.o) == null || (str2 = jVar7.A) == null || !str.equals(str2))) && (jVar3 = bVar.m) != null && jVar3.f797b == (i4 = jVar7.f797b)) {
                                bVar.c(i4);
                            }
                        }
                        b.j jVar9 = bVar.f792i;
                        if (jVar9 != null && jVar9.f797b == jVar7.f797b && !b.j.a(jVar7, b.h.IS_SELECTED) && jVar7.a(b.h.IS_SELECTED)) {
                            AccessibilityEvent a7 = bVar.a(jVar7.f797b, 4);
                            a7.getText().add(jVar7.o);
                            bVar.a(a7);
                        }
                        b.j jVar10 = bVar.m;
                        if (jVar10 != null && (i3 = jVar10.f797b) == jVar7.f797b && ((jVar2 = bVar.n) == null || jVar2.f797b != i3)) {
                            bVar.n = bVar.m;
                            bVar.a(bVar.a(jVar7.f797b, 8));
                        } else if (bVar.m == null) {
                            bVar.n = null;
                        }
                        b.j jVar11 = bVar.m;
                        if (jVar11 != null && jVar11.f797b == jVar7.f797b && b.j.a(jVar7, b.h.IS_TEXT_FIELD) && jVar7.a(b.h.IS_TEXT_FIELD) && ((jVar = bVar.f792i) == null || jVar.f797b == bVar.m.f797b)) {
                            String str6 = jVar7.z;
                            if (str6 == null) {
                                str6 = str4;
                            }
                            String str7 = jVar7.p;
                            if (str7 != null) {
                                str4 = str7;
                            }
                            AccessibilityEvent a8 = bVar.a(jVar7.f797b, i2);
                            a8.setBeforeText(str6);
                            a8.getText().add(str4);
                            int i21 = 0;
                            while (i21 < str6.length() && i21 < str4.length() && str6.charAt(i21) == str4.charAt(i21)) {
                                i21++;
                            }
                            if (i21 < str6.length() || i21 < str4.length()) {
                                a8.setFromIndex(i21);
                                int length = str6.length() - 1;
                                int length2 = str4.length() - 1;
                                while (length >= i21 && length2 >= i21 && str6.charAt(length) == str4.charAt(length2)) {
                                    length--;
                                    length2--;
                                }
                                a8.setRemovedCount((length - i21) + 1);
                                a8.setAddedCount((length2 - i21) + 1);
                            } else {
                                a8 = null;
                            }
                            if (a8 != null) {
                                bVar.a(a8);
                            }
                            if (jVar7.w != jVar7.f801g || jVar7.x != jVar7.f802h) {
                                AccessibilityEvent a9 = bVar.a(jVar7.f797b, 8192);
                                a9.getText().add(str4);
                                a9.setFromIndex(jVar7.f801g);
                                a9.setToIndex(jVar7.f802h);
                                a9.setItemCount(str4.length());
                                bVar.a(a9);
                            }
                        }
                        i2 = 16;
                    }
                    return;
                }
                throw null;
            }
            throw null;
        }
    }

    public void addEngineLifecycleListener(a.b bVar) {
        ensureRunningOnMainThread();
        this.engineLifecycleListeners.add(bVar);
    }

    public void addIsDisplayingFlutterUiListener(g.a.a.b.h.b bVar) {
        ensureRunningOnMainThread();
        this.flutterUiDisplayListeners.add(bVar);
    }

    public void attachToNative(boolean z) {
        ensureRunningOnMainThread();
        ensureNotAttachedToNative();
        this.nativePlatformViewId = Long.valueOf(nativeAttach(this, z));
    }

    public void detachFromNativeAndReleaseResources() {
        ensureRunningOnMainThread();
        ensureAttachedToNative();
        nativeDestroy(this.nativePlatformViewId.longValue());
        this.nativePlatformViewId = null;
    }

    public void dispatchEmptyPlatformMessage(String str, int i2) {
        ensureRunningOnMainThread();
        if (isAttached()) {
            nativeDispatchEmptyPlatformMessage(this.nativePlatformViewId.longValue(), str, i2);
            return;
        }
        Log.w(TAG, "Tried to send a platform message to Flutter, but FlutterJNI was detached from native C++. Could not send. Channel: " + str + ". Response ID: " + i2);
    }

    public void dispatchPlatformMessage(String str, ByteBuffer byteBuffer, int i2, int i3) {
        ensureRunningOnMainThread();
        if (isAttached()) {
            nativeDispatchPlatformMessage(this.nativePlatformViewId.longValue(), str, byteBuffer, i2, i3);
            return;
        }
        Log.w(TAG, "Tried to send a platform message to Flutter, but FlutterJNI was detached from native C++. Could not send. Channel: " + str + ". Response ID: " + i3);
    }

    public void dispatchPointerDataPacket(ByteBuffer byteBuffer, int i2) {
        ensureRunningOnMainThread();
        ensureAttachedToNative();
        nativeDispatchPointerDataPacket(this.nativePlatformViewId.longValue(), byteBuffer, i2);
    }

    public void dispatchSemanticsAction(int i2, b.f fVar) {
        dispatchSemanticsAction(i2, fVar, null);
    }

    public Bitmap getBitmap() {
        ensureRunningOnMainThread();
        ensureAttachedToNative();
        return nativeGetBitmap(this.nativePlatformViewId.longValue());
    }

    public void invokePlatformMessageEmptyResponseCallback(int i2) {
        ensureRunningOnMainThread();
        if (isAttached()) {
            nativeInvokePlatformMessageEmptyResponseCallback(this.nativePlatformViewId.longValue(), i2);
            return;
        }
        Log.w(TAG, "Tried to send a platform message response, but FlutterJNI was detached from native C++. Could not send. Response ID: " + i2);
    }

    public void invokePlatformMessageResponseCallback(int i2, ByteBuffer byteBuffer, int i3) {
        ensureRunningOnMainThread();
        if (isAttached()) {
            nativeInvokePlatformMessageResponseCallback(this.nativePlatformViewId.longValue(), i2, byteBuffer, i3);
            return;
        }
        Log.w(TAG, "Tried to send a platform message response, but FlutterJNI was detached from native C++. Could not send. Response ID: " + i2);
    }

    public boolean isAttached() {
        return this.nativePlatformViewId != null;
    }

    public void markTextureFrameAvailable(long j) {
        ensureRunningOnMainThread();
        ensureAttachedToNative();
        nativeMarkTextureFrameAvailable(this.nativePlatformViewId.longValue(), j);
    }

    public native boolean nativeGetIsSoftwareRenderingEnabled();

    public void onFirstFrame() {
        ensureRunningOnMainThread();
        for (g.a.a.b.h.b bVar : this.flutterUiDisplayListeners) {
            bVar.d();
        }
    }

    public void onRenderingStopped() {
        ensureRunningOnMainThread();
        for (g.a.a.b.h.b bVar : this.flutterUiDisplayListeners) {
            bVar.c();
        }
    }

    public void onSurfaceChanged(int i2, int i3) {
        ensureRunningOnMainThread();
        ensureAttachedToNative();
        nativeSurfaceChanged(this.nativePlatformViewId.longValue(), i2, i3);
    }

    public void onSurfaceCreated(Surface surface) {
        ensureRunningOnMainThread();
        ensureAttachedToNative();
        nativeSurfaceCreated(this.nativePlatformViewId.longValue(), surface);
    }

    public void onSurfaceDestroyed() {
        ensureRunningOnMainThread();
        ensureAttachedToNative();
        onRenderingStopped();
        nativeSurfaceDestroyed(this.nativePlatformViewId.longValue());
    }

    public void registerTexture(long j, SurfaceTexture surfaceTexture) {
        ensureRunningOnMainThread();
        ensureAttachedToNative();
        nativeRegisterTexture(this.nativePlatformViewId.longValue(), j, surfaceTexture);
    }

    public void removeEngineLifecycleListener(a.b bVar) {
        ensureRunningOnMainThread();
        this.engineLifecycleListeners.remove(bVar);
    }

    public void removeIsDisplayingFlutterUiListener(g.a.a.b.h.b bVar) {
        ensureRunningOnMainThread();
        this.flutterUiDisplayListeners.remove(bVar);
    }

    public void runBundleAndSnapshotFromLibrary(String str, String str2, String str3, AssetManager assetManager) {
        ensureRunningOnMainThread();
        ensureAttachedToNative();
        nativeRunBundleAndSnapshotFromLibrary(this.nativePlatformViewId.longValue(), str, str2, str3, assetManager);
    }

    public void setAccessibilityDelegate(a aVar) {
        ensureRunningOnMainThread();
        this.accessibilityDelegate = aVar;
    }

    public void setAccessibilityFeatures(int i2) {
        ensureRunningOnMainThread();
        ensureAttachedToNative();
        nativeSetAccessibilityFeatures(this.nativePlatformViewId.longValue(), i2);
    }

    public void setPlatformMessageHandler(c cVar) {
        ensureRunningOnMainThread();
        this.platformMessageHandler = cVar;
    }

    public void setSemanticsEnabled(boolean z) {
        ensureRunningOnMainThread();
        ensureAttachedToNative();
        nativeSetSemanticsEnabled(this.nativePlatformViewId.longValue(), z);
    }

    public void setViewportMetrics(float f2, int i2, int i3, int i4, int i5, int i6, int i7, int i8, int i9, int i10, int i11, int i12, int i13, int i14, int i15) {
        ensureRunningOnMainThread();
        ensureAttachedToNative();
        nativeSetViewportMetrics(this.nativePlatformViewId.longValue(), f2, i2, i3, i4, i5, i6, i7, i8, i9, i10, i11, i12, i13, i14, i15);
    }

    public void unregisterTexture(long j) {
        ensureRunningOnMainThread();
        ensureAttachedToNative();
        nativeUnregisterTexture(this.nativePlatformViewId.longValue(), j);
    }

    public void dispatchSemanticsAction(int i2, b.f fVar, Object obj) {
        ByteBuffer byteBuffer;
        int i3;
        ensureAttachedToNative();
        if (obj != null) {
            byteBuffer = p.a.a(obj);
            i3 = byteBuffer.position();
        } else {
            byteBuffer = null;
            i3 = 0;
        }
        dispatchSemanticsAction(i2, fVar.x, byteBuffer, i3);
    }

    public void dispatchSemanticsAction(int i2, int i3, ByteBuffer byteBuffer, int i4) {
        ensureRunningOnMainThread();
        ensureAttachedToNative();
        nativeDispatchSemanticsAction(this.nativePlatformViewId.longValue(), i2, i3, byteBuffer, i4);
    }
}
