package javax.xml.datatype;

import java.math.BigDecimal;
import java.math.BigInteger;
import java.util.GregorianCalendar;
import java.util.Locale;
import java.util.TimeZone;
import javax.xml.namespace.QName;

public abstract class XMLGregorianCalendar implements Cloneable {
    public abstract void add(Duration duration);

    public abstract void clear();

    @Override // java.lang.Object
    public abstract Object clone();

    public abstract int compare(XMLGregorianCalendar xMLGregorianCalendar);

    public boolean equals(Object obj) {
        if (obj == this) {
            return true;
        }
        return (obj instanceof XMLGregorianCalendar) && compare((XMLGregorianCalendar) obj) == 0;
    }

    public abstract int getDay();

    public abstract BigInteger getEon();

    public abstract BigInteger getEonAndYear();

    public abstract BigDecimal getFractionalSecond();

    public abstract int getHour();

    public int getMillisecond() {
        if (getFractionalSecond() == null) {
            return Integer.MIN_VALUE;
        }
        return getFractionalSecond().movePointRight(3).intValue();
    }

    public abstract int getMinute();

    public abstract int getMonth();

    public abstract int getSecond();

    public abstract TimeZone getTimeZone(int i2);

    public abstract int getTimezone();

    public abstract QName getXMLSchemaType();

    public abstract int getYear();

    public int hashCode() {
        int timezone = getTimezone();
        if (timezone == Integer.MIN_VALUE) {
            timezone = 0;
        }
        XMLGregorianCalendar normalize = timezone != 0 ? normalize() : this;
        return normalize.getSecond() + normalize.getMinute() + normalize.getHour() + normalize.getDay() + normalize.getMonth() + normalize.getYear();
    }

    public abstract boolean isValid();

    public abstract XMLGregorianCalendar normalize();

    public abstract void reset();

    public abstract void setDay(int i2);

    public abstract void setFractionalSecond(BigDecimal bigDecimal);

    public abstract void setHour(int i2);

    public abstract void setMillisecond(int i2);

    public abstract void setMinute(int i2);

    public abstract void setMonth(int i2);

    public abstract void setSecond(int i2);

    public void setTime(int i2, int i3, int i4) {
        setTime(i2, i3, i4, (BigDecimal) null);
    }

    public void setTime(int i2, int i3, int i4, int i5) {
        setHour(i2);
        setMinute(i3);
        setSecond(i4);
        setMillisecond(i5);
    }

    public void setTime(int i2, int i3, int i4, BigDecimal bigDecimal) {
        setHour(i2);
        setMinute(i3);
        setSecond(i4);
        setFractionalSecond(bigDecimal);
    }

    public abstract void setTimezone(int i2);

    public abstract void setYear(int i2);

    public abstract void setYear(BigInteger bigInteger);

    public abstract GregorianCalendar toGregorianCalendar();

    public abstract GregorianCalendar toGregorianCalendar(TimeZone timeZone, Locale locale, XMLGregorianCalendar xMLGregorianCalendar);

    public String toString() {
        return toXMLFormat();
    }

    public abstract String toXMLFormat();
}
