package javax.xml.transform.stax;

import javax.xml.stream.XMLEventReader;
import javax.xml.stream.XMLStreamReader;
import javax.xml.stream.events.XMLEvent;
import javax.xml.transform.Source;

public class StAXSource implements Source {
    public static final String FEATURE = "http://javax.xml.transform.stax.StAXSource/feature";
    public final String systemId;
    public final XMLEventReader xmlEventReader;
    public final XMLStreamReader xmlStreamReader;

    public StAXSource(XMLEventReader xMLEventReader) {
        if (xMLEventReader != null) {
            XMLEvent peek = xMLEventReader.peek();
            if (peek.isStartDocument() || peek.isStartElement()) {
                this.xmlStreamReader = null;
                this.xmlEventReader = xMLEventReader;
                this.systemId = peek.getLocation().getSystemId();
                return;
            }
            throw new IllegalStateException("The state of the XMLEventReader must be START_DOCUMENT or START_ELEMENT");
        }
        throw new IllegalArgumentException("XMLEventReader cannot be null.");
    }

    public StAXSource(XMLStreamReader xMLStreamReader) {
        if (xMLStreamReader != null) {
            int eventType = xMLStreamReader.getEventType();
            if (eventType == 7 || eventType == 1) {
                this.xmlStreamReader = xMLStreamReader;
                this.xmlEventReader = null;
                this.systemId = xMLStreamReader.getLocation().getSystemId();
                return;
            }
            throw new IllegalStateException("The state of the XMLStreamReader must be START_DOCUMENT or START_ELEMENT");
        }
        throw new IllegalArgumentException("XMLStreamReader cannot be null.");
    }

    @Override // javax.xml.transform.Source
    public String getSystemId() {
        return this.systemId;
    }

    public XMLEventReader getXMLEventReader() {
        return this.xmlEventReader;
    }

    public XMLStreamReader getXMLStreamReader() {
        return this.xmlStreamReader;
    }

    @Override // javax.xml.transform.Source
    public void setSystemId(String str) {
        throw new UnsupportedOperationException("Setting systemId is not supported.");
    }
}
