package org.apache.lucene.codecs;

import b.b.a.a.a;
import i.a.b.c.a1;
import i.a.b.c.b0;
import i.a.b.c.c0;
import i.a.b.c.k0;
import i.a.b.c.k3;
import i.a.b.c.l0;
import i.a.b.c.n3;
import i.a.b.c.o3;
import i.a.b.c.q;
import i.a.b.c.q2;
import i.a.b.f.n;
import i.a.b.f.t;
import i.a.b.f.u;
import i.a.b.g.c;
import i.a.b.g.e1.b;
import i.a.b.g.f1.b;
import i.a.b.g.f1.e;
import i.a.b.g.f1.j;
import i.a.b.g.l;
import i.a.b.g.o0;
import i.a.b.g.w0;
import i.a.b.g.x;
import java.io.ByteArrayOutputStream;
import java.io.Closeable;
import java.io.PrintStream;
import java.io.UnsupportedEncodingException;
import java.util.Collections;
import java.util.Comparator;
import java.util.Iterator;
import java.util.Locale;
import java.util.TreeMap;
import org.apache.poi.xssf.usermodel.XSSFDataValidationConstraint;

public class BlockTreeTermsReader extends FieldsProducer {
    public static final /* synthetic */ boolean $assertionsDisabled = false;
    public final l NO_OUTPUT;
    public long dirOffset;
    public final TreeMap<String, FieldReader> fields;
    public final j<l> fstOutputs;
    public final u in;
    public long indexDirOffset;
    public final PostingsReaderBase postingsReader;
    public String segment;
    public final int version;

    public static class Stats {
        public static final /* synthetic */ boolean $assertionsDisabled = false;
        public int[] blockCountByPrefixLen = new int[10];
        public int endBlockCount;
        public final String field;
        public int floorBlockCount;
        public int floorSubBlockCount;
        public long indexArcCount;
        public long indexNodeCount;
        public long indexNumBytes;
        public int mixedBlockCount;
        public int nonFloorBlockCount;
        public final String segment;
        public int startBlockCount;
        public int subBlocksOnlyBlockCount;
        public int termsOnlyBlockCount;
        public int totalBlockCount;
        public long totalBlockOtherBytes;
        public long totalBlockStatsBytes;
        public long totalBlockSuffixBytes;
        public long totalTermBytes;
        public long totalTermCount;

        public Stats(String str, String str2) {
            this.segment = str;
            this.field = str2;
        }

        public void endBlock(FieldReader.SegmentTermsEnum.Frame frame) {
            int i2 = frame.isLeafBlock ? frame.entCount : frame.state.termBlockOrd;
            int i3 = frame.entCount - i2;
            this.totalTermCount += (long) i2;
            if (i2 != 0 && i3 != 0) {
                this.mixedBlockCount++;
            } else if (i2 != 0) {
                this.termsOnlyBlockCount++;
            } else if (i3 != 0) {
                this.subBlocksOnlyBlockCount++;
            } else {
                throw new IllegalStateException();
            }
            this.endBlockCount++;
            this.totalBlockOtherBytes += ((frame.fpEnd - frame.fp) - ((long) frame.suffixesReader.z)) - ((long) frame.statsReader.z);
        }

        public void finish() {
        }

        public void startBlock(FieldReader.SegmentTermsEnum.Frame frame, boolean z) {
            this.totalBlockCount++;
            if (z) {
                if (frame.fp == frame.fpOrig) {
                    this.floorBlockCount++;
                }
                this.floorSubBlockCount++;
            } else {
                this.nonFloorBlockCount++;
            }
            int[] iArr = this.blockCountByPrefixLen;
            int length = iArr.length;
            int i2 = frame.prefix;
            if (length <= i2) {
                this.blockCountByPrefixLen = c.a(iArr, i2 + 1);
            }
            int[] iArr2 = this.blockCountByPrefixLen;
            int i3 = frame.prefix;
            iArr2[i3] = iArr2[i3] + 1;
            this.startBlockCount++;
            this.totalBlockSuffixBytes += (long) frame.suffixesReader.z;
            this.totalBlockStatsBytes += (long) frame.statsReader.z;
        }

        public void term(l lVar) {
            this.totalTermBytes += (long) lVar.z;
        }

        public String toString() {
            String str;
            String str2;
            String str3;
            ByteArrayOutputStream byteArrayOutputStream = new ByteArrayOutputStream(1024);
            try {
                PrintStream printStream = new PrintStream(byteArrayOutputStream, false, "UTF-8");
                printStream.println("  index FST:");
                printStream.println("    " + this.indexNodeCount + " nodes");
                printStream.println("    " + this.indexArcCount + " arcs");
                printStream.println("    " + this.indexNumBytes + " bytes");
                printStream.println("  terms:");
                printStream.println("    " + this.totalTermCount + " terms");
                StringBuilder sb = new StringBuilder();
                sb.append("    ");
                sb.append(this.totalTermBytes);
                sb.append(" bytes");
                String str4 = "";
                if (this.totalTermCount != 0) {
                    StringBuilder b2 = a.b(" (");
                    b2.append(String.format(Locale.ROOT, "%.1f", Double.valueOf(((double) this.totalTermBytes) / ((double) this.totalTermCount))));
                    b2.append(" bytes/term)");
                    str = b2.toString();
                    sb = sb;
                } else {
                    str = str4;
                }
                sb.append(str);
                printStream.println(sb.toString());
                printStream.println("  blocks:");
                printStream.println("    " + this.totalBlockCount + " blocks");
                printStream.println("    " + this.termsOnlyBlockCount + " terms-only blocks");
                printStream.println("    " + this.subBlocksOnlyBlockCount + " sub-block-only blocks");
                printStream.println("    " + this.mixedBlockCount + " mixed blocks");
                printStream.println("    " + this.floorBlockCount + " floor blocks");
                printStream.println("    " + (this.totalBlockCount - this.floorSubBlockCount) + " non-floor blocks");
                printStream.println("    " + this.floorSubBlockCount + " floor sub-blocks");
                StringBuilder sb2 = new StringBuilder();
                sb2.append("    ");
                sb2.append(this.totalBlockSuffixBytes);
                sb2.append(" term suffix bytes");
                if (this.totalBlockCount != 0) {
                    StringBuilder b3 = a.b(" (");
                    b3.append(String.format(Locale.ROOT, "%.1f", Double.valueOf(((double) this.totalBlockSuffixBytes) / ((double) this.totalBlockCount))));
                    b3.append(" suffix-bytes/block)");
                    str2 = b3.toString();
                } else {
                    str2 = str4;
                }
                sb2.append(str2);
                printStream.println(sb2.toString());
                StringBuilder sb3 = new StringBuilder();
                sb3.append("    ");
                sb3.append(this.totalBlockStatsBytes);
                sb3.append(" term stats bytes");
                if (this.totalBlockCount != 0) {
                    StringBuilder b4 = a.b(" (");
                    b4.append(String.format(Locale.ROOT, "%.1f", Double.valueOf(((double) this.totalBlockStatsBytes) / ((double) this.totalBlockCount))));
                    b4.append(" stats-bytes/block)");
                    str3 = b4.toString();
                } else {
                    str3 = str4;
                }
                sb3.append(str3);
                printStream.println(sb3.toString());
                StringBuilder sb4 = new StringBuilder();
                sb4.append("    ");
                sb4.append(this.totalBlockOtherBytes);
                sb4.append(" other bytes");
                if (this.totalBlockCount != 0) {
                    StringBuilder b5 = a.b(" (");
                    b5.append(String.format(Locale.ROOT, "%.1f", Double.valueOf(((double) this.totalBlockOtherBytes) / ((double) this.totalBlockCount))));
                    b5.append(" other-bytes/block)");
                    str4 = b5.toString();
                }
                sb4.append(str4);
                printStream.println(sb4.toString());
                if (this.totalBlockCount != 0) {
                    printStream.println("    by prefix length:");
                    int i2 = 0;
                    while (true) {
                        int[] iArr = this.blockCountByPrefixLen;
                        if (i2 < iArr.length) {
                            int i3 = iArr[i2];
                            if (i3 != 0) {
                                StringBuilder b6 = a.b("      ");
                                b6.append(String.format(Locale.ROOT, "%2d", Integer.valueOf(i2)));
                                b6.append(": ");
                                b6.append(i3);
                                printStream.println(b6.toString());
                            }
                            i2++;
                        }
                    }
                }
                try {
                    return byteArrayOutputStream.toString("UTF-8");
                } catch (UnsupportedEncodingException e2) {
                    throw new RuntimeException(e2);
                }
            } catch (UnsupportedEncodingException e3) {
                throw new RuntimeException(e3);
            }
        }
    }

    /* JADX DEBUG: Failed to insert an additional move for type inference into block B:45:0x0189 */
    /* JADX WARN: Type inference failed for: r3v12, types: [i.a.b.c.k0] */
    /* JADX WARN: Type inference failed for: r3v13 */
    /* JADX WARN: Type inference failed for: r3v15, types: [org.apache.lucene.codecs.BlockTreeTermsReader] */
    /* JADX WARNING: Unknown variable types count: 1 */
    public BlockTreeTermsReader(n nVar, l0 l0Var, q2 q2Var, PostingsReaderBase postingsReaderBase, t tVar, String str, int i2) {
        char c;
        BlockTreeTermsReader blockTreeTermsReader;
        Throwable th;
        u uVar;
        BlockTreeTermsReader blockTreeTermsReader2 = this;
        int i3 = i2;
        blockTreeTermsReader2.fields = new TreeMap<>();
        b bVar = b.f1426b;
        blockTreeTermsReader2.fstOutputs = bVar;
        blockTreeTermsReader2.NO_OUTPUT = (l) bVar.a();
        blockTreeTermsReader2.postingsReader = postingsReaderBase;
        String str2 = q2Var.a;
        blockTreeTermsReader2.segment = str2;
        u c2 = nVar.c(a1.a(str2, str, BlockTreeTermsWriter.TERMS_EXTENSION), tVar);
        blockTreeTermsReader2.in = c2;
        u uVar2 = null;
        int i4 = 0;
        try {
            blockTreeTermsReader2.version = blockTreeTermsReader2.readHeader(c2);
            if (i3 != -1) {
                uVar2 = nVar.c(a1.a(blockTreeTermsReader2.segment, str, BlockTreeTermsWriter.TERMS_INDEX_EXTENSION), tVar);
                int readIndexHeader = blockTreeTermsReader2.readIndexHeader(uVar2);
                if (readIndexHeader != blockTreeTermsReader2.version) {
                    throw new q("mixmatched version files: " + blockTreeTermsReader2.in + "=" + blockTreeTermsReader2.version + XSSFDataValidationConstraint.LIST_SEPARATOR + uVar2 + "=" + readIndexHeader);
                }
            }
            u uVar3 = uVar2;
            try {
                postingsReaderBase.init(blockTreeTermsReader2.in);
                blockTreeTermsReader2.seekDir(blockTreeTermsReader2.in, blockTreeTermsReader2.dirOffset);
                if (i3 != -1) {
                    try {
                        blockTreeTermsReader2.seekDir(uVar3, blockTreeTermsReader2.indexDirOffset);
                    } catch (Throwable th2) {
                        th = th2;
                        uVar2 = uVar3;
                    }
                }
                int readVInt = blockTreeTermsReader2.in.readVInt();
                String str3 = ")";
                String str4 = " (resource=";
                if (readVInt >= 0) {
                    int i5 = 0;
                    while (i5 < readVInt) {
                        int readVInt2 = blockTreeTermsReader2.in.readVInt();
                        long readVLong = blockTreeTermsReader2.in.readVLong();
                        int readVInt3 = blockTreeTermsReader2.in.readVInt();
                        l lVar = new l(new byte[readVInt3]);
                        blockTreeTermsReader2.in.readBytes(lVar.x, i4, readVInt3);
                        lVar.z = readVInt3;
                        k0 a = l0Var.a(readVInt2);
                        long readVLong2 = a.f954h == k0.b.DOCS_ONLY ? -1 : blockTreeTermsReader2.in.readVLong();
                        long readVLong3 = blockTreeTermsReader2.in.readVLong();
                        int readVInt4 = blockTreeTermsReader2.in.readVInt();
                        int readVInt5 = blockTreeTermsReader2.version >= 2 ? blockTreeTermsReader2.in.readVInt() : 0;
                        if (readVInt4 < 0 || readVInt4 > q2Var.b()) {
                            throw new q("invalid docCount: " + readVInt4 + " maxDoc: " + q2Var.b() + str4 + blockTreeTermsReader2.in + str3);
                        } else if (readVLong3 < ((long) readVInt4)) {
                            throw new q("invalid sumDocFreq: " + readVLong3 + " docCount: " + readVInt4 + str4 + blockTreeTermsReader2.in + str3);
                        } else if (readVLong2 == -1 || readVLong2 >= readVLong3) {
                            ?? r3 = a;
                            uVar = uVar3;
                            c = 0;
                            try {
                                if (blockTreeTermsReader2.fields.put(a.a, new FieldReader(r3, readVLong, lVar, readVLong2, readVLong3, readVInt4, i2 != -1 ? uVar3.readVLong() : 0, readVInt5, uVar)) == null) {
                                    i5++;
                                    blockTreeTermsReader2 = this;
                                    readVInt = readVInt;
                                    i3 = i2;
                                    uVar3 = uVar;
                                    str3 = str3;
                                    str4 = str4;
                                    i4 = 0;
                                } else {
                                    StringBuilder sb = new StringBuilder();
                                    sb.append("duplicate field: ");
                                    sb.append(a.a);
                                    sb.append(str4);
                                    r3 = this;
                                    sb.append(r3.in);
                                    sb.append(str3);
                                    throw new q(sb.toString());
                                }
                            } catch (Throwable th3) {
                                th = th3;
                                blockTreeTermsReader = r3;
                                uVar2 = uVar;
                                Closeable[] closeableArr = new Closeable[2];
                                closeableArr[c] = uVar2;
                                closeableArr[1] = blockTreeTermsReader;
                                x.b(closeableArr);
                                throw th;
                            }
                        } else {
                            throw new q("invalid sumTotalTermFreq: " + readVLong2 + " sumDocFreq: " + readVLong3 + str4 + blockTreeTermsReader2.in + str3);
                        }
                    }
                    if (i3 != -1) {
                        uVar3.close();
                        return;
                    }
                    return;
                }
                throw new q("invalid numFields: " + readVInt + str4 + blockTreeTermsReader2.in + str3);
            } catch (Throwable th4) {
                th = th4;
                uVar = uVar3;
                blockTreeTermsReader = blockTreeTermsReader2;
                c = 0;
                uVar2 = uVar;
                Closeable[] closeableArr2 = new Closeable[2];
                closeableArr2[c] = uVar2;
                closeableArr2[1] = blockTreeTermsReader;
                x.b(closeableArr2);
                throw th;
            }
        } catch (Throwable th5) {
            th = th5;
            blockTreeTermsReader = blockTreeTermsReader2;
            c = 0;
            Closeable[] closeableArr22 = new Closeable[2];
            closeableArr22[c] = uVar2;
            closeableArr22[1] = blockTreeTermsReader;
            x.b(closeableArr22);
            throw th;
        }
    }

    public String brToString(l lVar) {
        if (lVar == null) {
            return "null";
        }
        try {
            return lVar.a() + " " + lVar;
        } catch (Throwable unused) {
            return lVar.toString();
        }
    }

    @Override // org.apache.lucene.codecs.FieldsProducer, java.io.Closeable, java.lang.AutoCloseable
    public void close() {
        try {
            x.a(this.in, this.postingsReader);
        } finally {
            this.fields.clear();
        }
    }

    @Override // i.a.b.c.n0, java.lang.Iterable
    public Iterator<String> iterator() {
        return Collections.unmodifiableSet(this.fields.keySet()).iterator();
    }

    @Override // org.apache.lucene.codecs.FieldsProducer
    public long ramBytesUsed() {
        PostingsReaderBase postingsReaderBase = this.postingsReader;
        long ramBytesUsed = postingsReaderBase != null ? postingsReaderBase.ramBytesUsed() : 0;
        for (FieldReader fieldReader : this.fields.values()) {
            ramBytesUsed += fieldReader.ramBytesUsed();
        }
        return ramBytesUsed;
    }

    public int readHeader(u uVar) {
        int checkHeader = CodecUtil.checkHeader(uVar, BlockTreeTermsWriter.TERMS_CODEC_NAME, 0, 2);
        if (checkHeader < 1) {
            this.dirOffset = uVar.readLong();
        }
        return checkHeader;
    }

    public int readIndexHeader(u uVar) {
        int checkHeader = CodecUtil.checkHeader(uVar, BlockTreeTermsWriter.TERMS_INDEX_CODEC_NAME, 0, 2);
        if (checkHeader < 1) {
            this.indexDirOffset = uVar.readLong();
        }
        return checkHeader;
    }

    public void seekDir(u uVar, long j) {
        if (this.version >= 1) {
            uVar.seek(uVar.length() - 8);
            j = uVar.readLong();
        }
        uVar.seek(j);
    }

    @Override // i.a.b.c.n0
    public int size() {
        return this.fields.size();
    }

    @Override // i.a.b.c.n0
    public n3 terms(String str) {
        return this.fields.get(str);
    }

    public final class FieldReader extends n3 {
        public static final /* synthetic */ boolean $assertionsDisabled = false;
        public final int docCount;
        public final k0 fieldInfo;
        public final e<l> index;
        public final long indexStartFP;
        public final int longsSize;
        public final long numTerms;
        public final long rootBlockFP;
        public final l rootCode;
        public final long sumDocFreq;
        public final long sumTotalTermFreq;

        public final class IntersectEnum extends o3 {
            public static final /* synthetic */ boolean $assertionsDisabled = false;
            public e.a<l>[] arcs = new e.a[5];
            public final i.a.b.g.e1.b compiledAutomaton;
            public Frame currentFrame;
            public final e.b fstReader;
            public final u in;
            public final i.a.b.g.e1.c runAutomaton = null;
            public l savedStartTerm;
            public Frame[] stack;
            public final l term = new l(l.A);

            public final class Frame {
                public static final /* synthetic */ boolean $assertionsDisabled = false;
                public e.a<l> arc;
                public byte[] bytes;
                public i.a.b.f.e bytesReader;
                public int curTransitionMax;
                public int entCount;
                public byte[] floorData = new byte[32];
                public final i.a.b.f.e floorDataReader = new i.a.b.f.e();
                public long fp;
                public long fpEnd;
                public long fpOrig;
                public boolean isLastInFloor;
                public boolean isLeafBlock;
                public long lastSubFP;
                public long[] longs;
                public int metaDataUpto;
                public int nextEnt;
                public int nextFloorLabel;
                public int numFollowFloorBlocks;
                public final int ord;
                public l outputPrefix;
                public int prefix;
                public int startBytePos;
                public byte[] statBytes = new byte[64];
                public int state;
                public final i.a.b.f.e statsReader = new i.a.b.f.e();
                public int suffix;
                public byte[] suffixBytes = new byte[128];
                public final i.a.b.f.e suffixesReader = new i.a.b.f.e();
                public final BlockTermState termState;
                public int transitionIndex;
                public i.a.b.g.e1.e[] transitions;

                public Frame(int i2) {
                    this.ord = i2;
                    BlockTermState newTermState = BlockTreeTermsReader.this.postingsReader.newTermState();
                    this.termState = newTermState;
                    newTermState.totalTermFreq = -1;
                    this.longs = new long[FieldReader.this.longsSize];
                }

                public void decodeMetaData() {
                    FieldReader fieldReader;
                    int termBlockOrd = getTermBlockOrd();
                    boolean z = this.metaDataUpto == 0;
                    while (true) {
                        int i2 = this.metaDataUpto;
                        if (i2 < termBlockOrd) {
                            this.termState.docFreq = this.statsReader.readVInt();
                            if (FieldReader.this.fieldInfo.f954h != k0.b.DOCS_ONLY) {
                                BlockTermState blockTermState = this.termState;
                                blockTermState.totalTermFreq = this.statsReader.readVLong() + ((long) blockTermState.docFreq);
                            }
                            int i3 = 0;
                            while (true) {
                                fieldReader = FieldReader.this;
                                if (i3 >= fieldReader.longsSize) {
                                    break;
                                }
                                this.longs[i3] = this.bytesReader.readVLong();
                                i3++;
                            }
                            BlockTreeTermsReader.this.postingsReader.decodeTerm(this.longs, this.bytesReader, FieldReader.this.fieldInfo, this.termState, z);
                            this.metaDataUpto++;
                            z = false;
                        } else {
                            this.termState.termBlockOrd = i2;
                            return;
                        }
                    }
                }

                public int getTermBlockOrd() {
                    return this.isLeafBlock ? this.nextEnt : this.termState.termBlockOrd;
                }

                public void load(l lVar) {
                    if (!(lVar == null || this.transitions.length == 0)) {
                        int length = this.floorData.length;
                        int i2 = lVar.z;
                        if (length < i2) {
                            this.floorData = new byte[c.a(i2, 1)];
                        }
                        System.arraycopy(lVar.x, lVar.y, this.floorData, 0, lVar.z);
                        this.floorDataReader.a(this.floorData, 0, lVar.z);
                        if ((this.floorDataReader.readVLong() & 1) != 0) {
                            this.numFollowFloorBlocks = this.floorDataReader.readVInt();
                            this.nextFloorLabel = this.floorDataReader.readByte() & 255;
                            IntersectEnum.access$200(IntersectEnum.this);
                            throw null;
                        }
                    }
                    IntersectEnum.this.in.seek(this.fp);
                    int readVInt = IntersectEnum.this.in.readVInt();
                    this.entCount = readVInt >>> 1;
                    this.isLastInFloor = (readVInt & 1) != 0;
                    int readVInt2 = IntersectEnum.this.in.readVInt();
                    this.isLeafBlock = (readVInt2 & 1) != 0;
                    int i3 = readVInt2 >>> 1;
                    if (this.suffixBytes.length < i3) {
                        this.suffixBytes = new byte[c.a(i3, 1)];
                    }
                    IntersectEnum.this.in.readBytes(this.suffixBytes, 0, i3);
                    this.suffixesReader.a(this.suffixBytes, 0, i3);
                    int readVInt3 = IntersectEnum.this.in.readVInt();
                    if (this.statBytes.length < readVInt3) {
                        this.statBytes = new byte[c.a(readVInt3, 1)];
                    }
                    IntersectEnum.this.in.readBytes(this.statBytes, 0, readVInt3);
                    this.statsReader.a(this.statBytes, 0, readVInt3);
                    this.metaDataUpto = 0;
                    this.termState.termBlockOrd = 0;
                    this.nextEnt = 0;
                    int readVInt4 = IntersectEnum.this.in.readVInt();
                    byte[] bArr = this.bytes;
                    if (bArr == null) {
                        this.bytes = new byte[c.a(readVInt4, 1)];
                        this.bytesReader = new i.a.b.f.e();
                    } else if (bArr.length < readVInt4) {
                        this.bytes = new byte[c.a(readVInt4, 1)];
                    }
                    IntersectEnum.this.in.readBytes(this.bytes, 0, readVInt4);
                    this.bytesReader.a(this.bytes, 0, readVInt4);
                    if (!this.isLastInFloor) {
                        this.fpEnd = IntersectEnum.this.in.getFilePointer();
                    }
                }

                public void loadNextFloorBlock() {
                    int i2;
                    do {
                        this.fp = this.fpOrig + (this.floorDataReader.readVLong() >>> 1);
                        int i3 = this.numFollowFloorBlocks - 1;
                        this.numFollowFloorBlocks = i3;
                        if (i3 != 0) {
                            this.nextFloorLabel = this.floorDataReader.readByte() & 255;
                        } else {
                            this.nextFloorLabel = 256;
                        }
                        if (this.numFollowFloorBlocks == 0) {
                            break;
                        }
                        i2 = this.nextFloorLabel;
                        if (this.transitions[this.transitionIndex] == null) {
                            throw null;
                        }
                    } while (i2 <= 0);
                    load(null);
                }

                public boolean next() {
                    return this.isLeafBlock ? nextLeaf() : nextNonLeaf();
                }

                public boolean nextLeaf() {
                    this.nextEnt++;
                    int readVInt = this.suffixesReader.readVInt();
                    this.suffix = readVInt;
                    i.a.b.f.e eVar = this.suffixesReader;
                    this.startBytePos = eVar.y;
                    eVar.a(readVInt);
                    return false;
                }

                public boolean nextNonLeaf() {
                    this.nextEnt++;
                    int readVInt = this.suffixesReader.readVInt();
                    int i2 = readVInt >>> 1;
                    this.suffix = i2;
                    i.a.b.f.e eVar = this.suffixesReader;
                    this.startBytePos = eVar.y;
                    eVar.a(i2);
                    if ((readVInt & 1) == 0) {
                        this.termState.termBlockOrd++;
                        return false;
                    }
                    this.lastSubFP = this.fp - this.suffixesReader.readVLong();
                    return true;
                }

                public void setState(int i2) {
                    this.state = i2;
                    this.transitionIndex = 0;
                    i.a.b.g.e1.e[] eVarArr = IntersectEnum.this.compiledAutomaton.f1409b[i2];
                    this.transitions = eVarArr;
                    if (eVarArr.length == 0) {
                        this.curTransitionMax = -1;
                    } else if (eVarArr[0] != null) {
                        this.curTransitionMax = 0;
                    } else {
                        throw null;
                    }
                }
            }

            public IntersectEnum(i.a.b.g.e1.b bVar, l lVar) {
                this.compiledAutomaton = bVar;
                this.in = BlockTreeTermsReader.this.in.clone();
                this.stack = new Frame[5];
                int i2 = 0;
                while (true) {
                    Frame[] frameArr = this.stack;
                    if (i2 >= frameArr.length) {
                        break;
                    }
                    frameArr[i2] = new Frame(i2);
                    i2++;
                }
                int i3 = 0;
                while (true) {
                    e.a<l>[] aVarArr = this.arcs;
                    if (i3 >= aVarArr.length) {
                        break;
                    }
                    aVarArr[i3] = new e.a<>();
                    i3++;
                }
                if (FieldReader.this.index == null) {
                    this.fstReader = null;
                } else {
                    this.fstReader = FieldReader.this.index.b();
                }
                FieldReader.this.index.a(this.arcs[0]);
                Frame frame = this.stack[0];
                long j = FieldReader.this.rootBlockFP;
                frame.fpOrig = j;
                frame.fp = j;
                frame.prefix = 0;
                throw null;
            }

            public static /* synthetic */ i.a.b.g.e1.c access$200(IntersectEnum intersectEnum) {
                return null;
            }

            private void copyTerm() {
                Frame frame = this.currentFrame;
                int i2 = frame.suffix + frame.prefix;
                l lVar = this.term;
                byte[] bArr = lVar.x;
                if (bArr.length < i2) {
                    lVar.x = c.a(bArr, i2);
                }
                Frame frame2 = this.currentFrame;
                byte[] bArr2 = frame2.suffixBytes;
                int i3 = frame2.startBytePos;
                byte[] bArr3 = this.term.x;
                Frame frame3 = this.currentFrame;
                System.arraycopy(bArr2, i3, bArr3, frame3.prefix, frame3.suffix);
                this.term.z = i2;
            }

            private e.a<l> getArc(int i2) {
                if (i2 >= this.arcs.length) {
                    int a = c.a(i2 + 1, o0.a);
                    e.a<l>[] aVarArr = new e.a[a];
                    e.a<l>[] aVarArr2 = this.arcs;
                    System.arraycopy(aVarArr2, 0, aVarArr, 0, aVarArr2.length);
                    for (int length = this.arcs.length; length < a; length++) {
                        aVarArr[length] = new e.a<>();
                    }
                    this.arcs = aVarArr;
                }
                return this.arcs[i2];
            }

            private Frame getFrame(int i2) {
                if (i2 >= this.stack.length) {
                    int a = c.a(i2 + 1, o0.a);
                    Frame[] frameArr = new Frame[a];
                    Frame[] frameArr2 = this.stack;
                    System.arraycopy(frameArr2, 0, frameArr, 0, frameArr2.length);
                    for (int length = this.stack.length; length < a; length++) {
                        frameArr[length] = new Frame(length);
                    }
                    this.stack = frameArr;
                }
                return this.stack[i2];
            }

            private int getState() {
                Frame frame = this.currentFrame;
                int i2 = frame.state;
                if (frame.suffix <= 0) {
                    return i2;
                }
                Frame frame2 = this.currentFrame;
                byte b2 = frame2.suffixBytes[frame2.startBytePos + 0];
                throw null;
            }

            private Frame pushFrame(int i2) {
                Frame frame = this.currentFrame;
                Frame frame2 = getFrame(frame == null ? 0 : frame.ord + 1);
                Frame frame3 = this.currentFrame;
                long j = frame3.lastSubFP;
                frame2.fpOrig = j;
                frame2.fp = j;
                frame2.prefix = frame3.suffix + frame3.prefix;
                frame2.setState(i2);
                Frame frame4 = this.currentFrame;
                e.a<l> aVar = frame4.arc;
                int i3 = frame4.prefix;
                l lVar = frame4.outputPrefix;
                while (i3 < frame2.prefix) {
                    i3++;
                    aVar = FieldReader.this.index.a(this.term.x[i3] & 255, aVar, getArc(i3), this.fstReader);
                    lVar = BlockTreeTermsReader.this.fstOutputs.a(lVar, (l) aVar.f1437b);
                }
                frame2.arc = aVar;
                frame2.outputPrefix = lVar;
                frame2.load(BlockTreeTermsReader.this.fstOutputs.a(lVar, (l) aVar.f1440f));
                return frame2;
            }

            /* JADX WARNING: Code restructure failed: missing block: B:13:0x0073, code lost:
                r14.currentFrame = pushFrame(getState());
                r0 = r0 + 1;
             */
            private void seekToStartTerm(l lVar) {
                l lVar2 = this.term;
                int i2 = lVar2.z;
                int i3 = lVar.z;
                if (i2 < i3) {
                    lVar2.x = c.a(lVar2.x, i3);
                }
                e.a<l> aVar = this.arcs[0];
                int i4 = 0;
                while (i4 <= lVar.z) {
                    while (true) {
                        Frame frame = this.currentFrame;
                        int i5 = frame.suffixesReader.y;
                        int i6 = frame.startBytePos;
                        int i7 = this.currentFrame.suffix;
                        Frame frame2 = this.currentFrame;
                        long j = frame2.lastSubFP;
                        int i8 = frame2.termState.termBlockOrd;
                        boolean next = frame2.next();
                        l lVar3 = this.term;
                        Frame frame3 = this.currentFrame;
                        lVar3.z = frame3.suffix + frame3.prefix;
                        l lVar4 = this.term;
                        byte[] bArr = lVar4.x;
                        int length = bArr.length;
                        int i9 = lVar4.z;
                        if (length < i9) {
                            lVar4.x = c.a(bArr, i9);
                        }
                        Frame frame4 = this.currentFrame;
                        byte[] bArr2 = frame4.suffixBytes;
                        int i10 = frame4.startBytePos;
                        byte[] bArr3 = this.term.x;
                        Frame frame5 = this.currentFrame;
                        System.arraycopy(bArr2, i10, bArr3, frame5.prefix, frame5.suffix);
                        if (next && w0.a(lVar, this.term, 0)) {
                            break;
                        }
                        int b2 = this.term.compareTo(lVar);
                        if (b2 < 0) {
                            Frame frame6 = this.currentFrame;
                            if (frame6.nextEnt == frame6.entCount) {
                                if (!frame6.isLastInFloor) {
                                    frame6.loadNextFloorBlock();
                                } else {
                                    return;
                                }
                            }
                        } else if (b2 != 0) {
                            Frame frame7 = this.currentFrame;
                            frame7.nextEnt--;
                            frame7.lastSubFP = j;
                            frame7.startBytePos = i6;
                            this.currentFrame.suffix = i7;
                            Frame frame8 = this.currentFrame;
                            frame8.suffixesReader.y = i5;
                            frame8.termState.termBlockOrd = i8;
                            byte[] bArr4 = frame8.suffixBytes;
                            int i11 = frame8.startBytePos;
                            byte[] bArr5 = this.term.x;
                            Frame frame9 = this.currentFrame;
                            System.arraycopy(bArr4, i11, bArr5, frame9.prefix, frame9.suffix);
                            l lVar5 = this.term;
                            Frame frame10 = this.currentFrame;
                            lVar5.z = frame10.suffix + frame10.prefix;
                            return;
                        } else {
                            return;
                        }
                    }
                }
            }

            private boolean setSavedStartTerm(l lVar) {
                this.savedStartTerm = lVar == null ? null : l.d(lVar);
                return true;
            }

            @Override // i.a.b.c.o3
            public int docFreq() {
                this.currentFrame.decodeMetaData();
                return this.currentFrame.termState.docFreq;
            }

            @Override // i.a.b.c.o3
            public c0 docs(i.a.b.g.j jVar, c0 c0Var, int i2) {
                this.currentFrame.decodeMetaData();
                return BlockTreeTermsReader.this.postingsReader.docs(FieldReader.this.fieldInfo, this.currentFrame.termState, jVar, c0Var, i2);
            }

            @Override // i.a.b.c.o3
            public b0 docsAndPositions(i.a.b.g.j jVar, b0 b0Var, int i2) {
                if (FieldReader.this.fieldInfo.f954h.compareTo((Enum) k0.b.DOCS_AND_FREQS_AND_POSITIONS) < 0) {
                    return null;
                }
                this.currentFrame.decodeMetaData();
                return BlockTreeTermsReader.this.postingsReader.docsAndPositions(FieldReader.this.fieldInfo, this.currentFrame.termState, jVar, b0Var, i2);
            }

            @Override // i.a.b.g.n
            public Comparator<l> getComparator() {
                return l.C;
            }

            @Override // i.a.b.g.n
            public l next() {
                int i2;
                int i3;
                while (true) {
                    Frame frame = this.currentFrame;
                    if (frame.nextEnt != frame.entCount) {
                        boolean next = frame.next();
                        if (this.currentFrame.suffix != 0) {
                            Frame frame2 = this.currentFrame;
                            int i4 = frame2.suffixBytes[frame2.startBytePos] & 255;
                            while (true) {
                                Frame frame3 = this.currentFrame;
                                if (i4 <= frame3.curTransitionMax) {
                                    break;
                                }
                                int i5 = frame3.transitionIndex;
                                i.a.b.g.e1.e[] eVarArr = frame3.transitions;
                                if (i5 >= eVarArr.length - 1) {
                                    frame3.isLastInFloor = true;
                                    frame3.nextEnt = frame3.entCount;
                                    break;
                                }
                                int i6 = i5 + 1;
                                frame3.transitionIndex = i6;
                                if (eVarArr[i6] != null) {
                                    frame3.curTransitionMax = 0;
                                } else {
                                    throw null;
                                }
                            }
                        }
                        if (this.compiledAutomaton.c != null && !next) {
                            Frame frame4 = this.currentFrame;
                            int i7 = frame4.suffix + frame4.prefix;
                            l lVar = this.compiledAutomaton.c;
                            int i8 = lVar.z;
                            if (i7 >= i8) {
                                Frame frame5 = this.currentFrame;
                                byte[] bArr = frame5.suffixBytes;
                                byte[] bArr2 = lVar.x;
                                int i9 = i8 - frame5.suffix;
                                if (i9 > 0) {
                                    byte[] bArr3 = this.term.x;
                                    int i10 = this.currentFrame.prefix;
                                    int i11 = i10 - i9;
                                    i2 = 0;
                                    while (true) {
                                        if (i11 >= i10) {
                                            i3 = this.currentFrame.startBytePos;
                                            break;
                                        }
                                        int i12 = i11 + 1;
                                        int i13 = i2 + 1;
                                        if (bArr3[i11] != bArr2[i2]) {
                                            break;
                                        }
                                        i11 = i12;
                                        i2 = i13;
                                    }
                                } else {
                                    i3 = (this.currentFrame.suffix + this.currentFrame.startBytePos) - this.compiledAutomaton.c.z;
                                    i2 = 0;
                                }
                                int i14 = this.compiledAutomaton.c.z;
                                while (true) {
                                    if (i2 >= i14) {
                                        break;
                                    }
                                    int i15 = i3 + 1;
                                    int i16 = i2 + 1;
                                    if (bArr[i3] != bArr2[i2]) {
                                        break;
                                    }
                                    i3 = i15;
                                    i2 = i16;
                                }
                            } else {
                                continue;
                            }
                        }
                        Frame frame6 = this.currentFrame;
                        int i17 = frame6.state;
                        if (frame6.suffix > 0) {
                            Frame frame7 = this.currentFrame;
                            byte b2 = frame7.suffixBytes[frame7.startBytePos + 0];
                            throw null;
                        } else if (next) {
                            copyTerm();
                            this.currentFrame = pushFrame(i17);
                        } else {
                            throw null;
                        }
                    } else if (!frame.isLastInFloor) {
                        frame.loadNextFloorBlock();
                    } else {
                        int i18 = frame.ord;
                        if (i18 == 0) {
                            return null;
                        }
                        long j = frame.fpOrig;
                        this.currentFrame = this.stack[i18 - 1];
                    }
                }
            }

            @Override // i.a.b.c.o3
            public long ord() {
                throw new UnsupportedOperationException();
            }

            @Override // i.a.b.c.o3
            public o3.c seekCeil(l lVar) {
                throw new UnsupportedOperationException();
            }

            @Override // i.a.b.c.o3
            public boolean seekExact(l lVar) {
                throw new UnsupportedOperationException();
            }

            @Override // i.a.b.c.o3
            public l term() {
                return this.term;
            }

            @Override // i.a.b.c.o3
            public k3 termState() {
                this.currentFrame.decodeMetaData();
                return this.currentFrame.termState.clone();
            }

            @Override // i.a.b.c.o3
            public long totalTermFreq() {
                this.currentFrame.decodeMetaData();
                return this.currentFrame.termState.totalTermFreq;
            }

            @Override // i.a.b.c.o3
            public void seekExact(long j) {
                throw new UnsupportedOperationException();
            }
        }

        public FieldReader(k0 k0Var, long j, l lVar, long j2, long j3, int i2, long j4, int i3, u uVar) {
            this.fieldInfo = k0Var;
            this.numTerms = j;
            this.sumTotalTermFreq = j2;
            this.sumDocFreq = j3;
            this.docCount = i2;
            this.indexStartFP = j4;
            this.rootCode = lVar;
            this.longsSize = i3;
            this.rootBlockFP = new i.a.b.f.e(lVar.x, lVar.y, lVar.z).readVLong() >>> 2;
            if (uVar != null) {
                u clone = uVar.clone();
                clone.seek(j4);
                this.index = new e<>(clone, b.f1426b);
                return;
            }
            this.index = null;
        }

        public Stats computeStats() {
            return new SegmentTermsEnum().computeBlockStats();
        }

        @Override // i.a.b.c.n3
        public Comparator<l> getComparator() {
            return l.C;
        }

        @Override // i.a.b.c.n3
        public int getDocCount() {
            return this.docCount;
        }

        @Override // i.a.b.c.n3
        public long getSumDocFreq() {
            return this.sumDocFreq;
        }

        @Override // i.a.b.c.n3
        public long getSumTotalTermFreq() {
            return this.sumTotalTermFreq;
        }

        @Override // i.a.b.c.n3
        public boolean hasFreqs() {
            return this.fieldInfo.f954h.compareTo(k0.b.DOCS_AND_FREQS) >= 0;
        }

        @Override // i.a.b.c.n3
        public boolean hasOffsets() {
            return this.fieldInfo.f954h.compareTo(k0.b.DOCS_AND_FREQS_AND_POSITIONS_AND_OFFSETS) >= 0;
        }

        @Override // i.a.b.c.n3
        public boolean hasPayloads() {
            return this.fieldInfo.f955i;
        }

        @Override // i.a.b.c.n3
        public boolean hasPositions() {
            return this.fieldInfo.f954h.compareTo(k0.b.DOCS_AND_FREQS_AND_POSITIONS) >= 0;
        }

        @Override // i.a.b.c.n3
        public o3 intersect(i.a.b.g.e1.b bVar, l lVar) {
            if (bVar.a == b.a.NORMAL) {
                return new IntersectEnum(bVar, lVar);
            }
            throw new IllegalArgumentException("please use CompiledAutomaton.getTermsEnum instead");
        }

        @Override // i.a.b.c.n3
        public o3 iterator(o3 o3Var) {
            return new SegmentTermsEnum();
        }

        public long ramBytesUsed() {
            e<l> eVar = this.index;
            if (eVar != null) {
                return eVar.c();
            }
            return 0;
        }

        @Override // i.a.b.c.n3
        public long size() {
            return this.numTerms;
        }

        public final class SegmentTermsEnum extends o3 {
            public static final /* synthetic */ boolean $assertionsDisabled = false;
            public e.a<l>[] arcs = new e.a[1];
            public Frame currentFrame;
            public boolean eof;
            public final e.b fstReader;
            public u in;
            public final i.a.b.f.e scratchReader = new i.a.b.f.e();
            public Frame[] stack = new Frame[0];
            public final Frame staticFrame = new Frame(-1);
            public int targetBeforeCurrentLength;
            public final l term = new l(l.A);
            public boolean termExists;
            public int validIndexPrefix;

            public final class Frame {
                public static final /* synthetic */ boolean $assertionsDisabled = false;
                public e.a<l> arc;
                public byte[] bytes;
                public i.a.b.f.e bytesReader;
                public int entCount;
                public byte[] floorData = new byte[32];
                public final i.a.b.f.e floorDataReader = new i.a.b.f.e();
                public long fp;
                public long fpEnd;
                public long fpOrig;
                public boolean hasTerms;
                public boolean hasTermsOrig;
                public boolean isFloor;
                public boolean isLastInFloor;
                public boolean isLeafBlock;
                public long lastSubFP;
                public long[] longs;
                public int metaDataUpto;
                public int nextEnt;
                public int nextFloorLabel;
                public int numFollowFloorBlocks;
                public final int ord;
                public int prefix;
                public int startBytePos;
                public byte[] statBytes = new byte[64];
                public final BlockTermState state;
                public final i.a.b.f.e statsReader = new i.a.b.f.e();
                public long subCode;
                public int suffix;
                public byte[] suffixBytes = new byte[128];
                public final i.a.b.f.e suffixesReader = new i.a.b.f.e();

                public Frame(int i2) {
                    this.ord = i2;
                    BlockTermState newTermState = BlockTreeTermsReader.this.postingsReader.newTermState();
                    this.state = newTermState;
                    newTermState.totalTermFreq = -1;
                    this.longs = new long[FieldReader.this.longsSize];
                }

                private void fillTerm() {
                    int i2 = this.prefix;
                    int i3 = this.suffix;
                    int i4 = i2 + i3;
                    l lVar = SegmentTermsEnum.this.term;
                    lVar.z = i2 + i3;
                    if (lVar.x.length < i4) {
                        lVar.a(i4);
                    }
                    System.arraycopy(this.suffixBytes, this.startBytePos, SegmentTermsEnum.this.term.x, this.prefix, this.suffix);
                }

                private boolean prefixMatches(l lVar) {
                    for (int i2 = 0; i2 < this.prefix; i2++) {
                        if (lVar.x[lVar.y + i2] != SegmentTermsEnum.this.term.x[i2]) {
                            return false;
                        }
                    }
                    return true;
                }

                public void decodeMetaData() {
                    FieldReader fieldReader;
                    int termBlockOrd = getTermBlockOrd();
                    boolean z = this.metaDataUpto == 0;
                    while (true) {
                        int i2 = this.metaDataUpto;
                        if (i2 < termBlockOrd) {
                            this.state.docFreq = this.statsReader.readVInt();
                            if (FieldReader.this.fieldInfo.f954h != k0.b.DOCS_ONLY) {
                                BlockTermState blockTermState = this.state;
                                blockTermState.totalTermFreq = this.statsReader.readVLong() + ((long) blockTermState.docFreq);
                            }
                            int i3 = 0;
                            while (true) {
                                fieldReader = FieldReader.this;
                                if (i3 >= fieldReader.longsSize) {
                                    break;
                                }
                                this.longs[i3] = this.bytesReader.readVLong();
                                i3++;
                            }
                            BlockTreeTermsReader.this.postingsReader.decodeTerm(this.longs, this.bytesReader, FieldReader.this.fieldInfo, this.state, z);
                            this.metaDataUpto++;
                            z = false;
                        } else {
                            this.state.termBlockOrd = i2;
                            return;
                        }
                    }
                }

                public int getTermBlockOrd() {
                    return this.isLeafBlock ? this.nextEnt : this.state.termBlockOrd;
                }

                public void loadBlock() {
                    SegmentTermsEnum.this.initIndexInput();
                    if (this.nextEnt == -1) {
                        SegmentTermsEnum.this.in.seek(this.fp);
                        int readVInt = SegmentTermsEnum.this.in.readVInt();
                        this.entCount = readVInt >>> 1;
                        this.isLastInFloor = (readVInt & 1) != 0;
                        int readVInt2 = SegmentTermsEnum.this.in.readVInt();
                        this.isLeafBlock = (readVInt2 & 1) != 0;
                        int i2 = readVInt2 >>> 1;
                        if (this.suffixBytes.length < i2) {
                            this.suffixBytes = new byte[c.a(i2, 1)];
                        }
                        SegmentTermsEnum.this.in.readBytes(this.suffixBytes, 0, i2);
                        this.suffixesReader.a(this.suffixBytes, 0, i2);
                        int readVInt3 = SegmentTermsEnum.this.in.readVInt();
                        if (this.statBytes.length < readVInt3) {
                            this.statBytes = new byte[c.a(readVInt3, 1)];
                        }
                        SegmentTermsEnum.this.in.readBytes(this.statBytes, 0, readVInt3);
                        this.statsReader.a(this.statBytes, 0, readVInt3);
                        this.metaDataUpto = 0;
                        this.state.termBlockOrd = 0;
                        this.nextEnt = 0;
                        this.lastSubFP = -1;
                        int readVInt4 = SegmentTermsEnum.this.in.readVInt();
                        byte[] bArr = this.bytes;
                        if (bArr == null) {
                            this.bytes = new byte[c.a(readVInt4, 1)];
                            this.bytesReader = new i.a.b.f.e();
                        } else if (bArr.length < readVInt4) {
                            this.bytes = new byte[c.a(readVInt4, 1)];
                        }
                        SegmentTermsEnum.this.in.readBytes(this.bytes, 0, readVInt4);
                        this.bytesReader.a(this.bytes, 0, readVInt4);
                        this.fpEnd = SegmentTermsEnum.this.in.getFilePointer();
                    }
                }

                public void loadNextFloorBlock() {
                    this.fp = this.fpEnd;
                    this.nextEnt = -1;
                    loadBlock();
                }

                public boolean next() {
                    return this.isLeafBlock ? nextLeaf() : nextNonLeaf();
                }

                public boolean nextLeaf() {
                    this.nextEnt++;
                    int readVInt = this.suffixesReader.readVInt();
                    this.suffix = readVInt;
                    this.startBytePos = this.suffixesReader.y;
                    l lVar = SegmentTermsEnum.this.term;
                    int i2 = this.prefix + readVInt;
                    lVar.z = i2;
                    if (lVar.x.length < i2) {
                        lVar.a(i2);
                    }
                    this.suffixesReader.readBytes(SegmentTermsEnum.this.term.x, this.prefix, this.suffix);
                    SegmentTermsEnum.this.termExists = true;
                    return false;
                }

                public boolean nextNonLeaf() {
                    this.nextEnt++;
                    int readVInt = this.suffixesReader.readVInt();
                    int i2 = readVInt >>> 1;
                    this.suffix = i2;
                    this.startBytePos = this.suffixesReader.y;
                    l lVar = SegmentTermsEnum.this.term;
                    int i3 = this.prefix + i2;
                    lVar.z = i3;
                    if (lVar.x.length < i3) {
                        lVar.a(i3);
                    }
                    this.suffixesReader.readBytes(SegmentTermsEnum.this.term.x, this.prefix, this.suffix);
                    if ((readVInt & 1) == 0) {
                        SegmentTermsEnum.this.termExists = true;
                        this.subCode = 0;
                        this.state.termBlockOrd++;
                        return false;
                    }
                    SegmentTermsEnum.this.termExists = false;
                    long readVLong = this.suffixesReader.readVLong();
                    this.subCode = readVLong;
                    this.lastSubFP = this.fp - readVLong;
                    return true;
                }

                public void rewind() {
                    this.fp = this.fpOrig;
                    this.nextEnt = -1;
                    this.hasTerms = this.hasTermsOrig;
                    if (this.isFloor) {
                        i.a.b.f.e eVar = this.floorDataReader;
                        eVar.y = 0;
                        this.numFollowFloorBlocks = eVar.readVInt();
                        this.nextFloorLabel = this.floorDataReader.readByte() & 255;
                    }
                }

                public void scanToFloorFrame(l lVar) {
                    int i2;
                    int i3;
                    long j;
                    if (this.isFloor && lVar.z > (i2 = this.prefix) && (i3 = lVar.x[lVar.y + i2] & 255) >= this.nextFloorLabel) {
                        while (true) {
                            long readVLong = this.floorDataReader.readVLong();
                            j = this.fpOrig + (readVLong >>> 1);
                            boolean z = false;
                            this.hasTerms = (readVLong & 1) != 0;
                            if (this.numFollowFloorBlocks == 1) {
                                z = true;
                            }
                            this.isLastInFloor = z;
                            this.numFollowFloorBlocks--;
                            if (!z) {
                                int readByte = this.floorDataReader.readByte() & 255;
                                this.nextFloorLabel = readByte;
                                if (i3 < readByte) {
                                    break;
                                }
                            } else {
                                this.nextFloorLabel = 256;
                                break;
                            }
                        }
                        if (j != this.fp) {
                            this.nextEnt = -1;
                            this.fp = j;
                        }
                    }
                }

                public void scanToSubBlock(long j) {
                    if (this.lastSubFP != j) {
                        long j2 = this.fp - j;
                        while (true) {
                            this.nextEnt++;
                            int readVInt = this.suffixesReader.readVInt();
                            this.suffixesReader.a(this.isLeafBlock ? readVInt : readVInt >>> 1);
                            if ((readVInt & 1) == 0) {
                                this.state.termBlockOrd++;
                            } else if (j2 == this.suffixesReader.readVLong()) {
                                this.lastSubFP = j;
                                return;
                            }
                        }
                    }
                }

                public o3.c scanToTerm(l lVar, boolean z) {
                    return this.isLeafBlock ? scanToTermLeaf(lVar, z) : scanToTermNonLeaf(lVar, z);
                }

                public o3.c scanToTermLeaf(l lVar, boolean z) {
                    int i2;
                    int i3;
                    int i4;
                    boolean z2;
                    SegmentTermsEnum.this.termExists = true;
                    this.subCode = 0;
                    if (this.nextEnt == this.entCount) {
                        if (z) {
                            fillTerm();
                        }
                        return o3.c.END;
                    }
                    do {
                        this.nextEnt++;
                        int readVInt = this.suffixesReader.readVInt();
                        this.suffix = readVInt;
                        int i5 = this.prefix + readVInt;
                        i.a.b.f.e eVar = this.suffixesReader;
                        this.startBytePos = eVar.y;
                        eVar.a(readVInt);
                        int i6 = lVar.y;
                        int i7 = lVar.z;
                        if (i7 >= i5) {
                            i7 = i5;
                        }
                        int i8 = i6 + i7;
                        int i9 = lVar.y + this.prefix;
                        int i10 = this.startBytePos;
                        while (true) {
                            if (i9 < i8) {
                                i3 = i10 + 1;
                                i2 = i9 + 1;
                                i4 = (this.suffixBytes[i10] & 255) - (lVar.x[i9] & 255);
                                z2 = false;
                            } else {
                                i2 = i9;
                                i3 = i10;
                                i4 = i5 - lVar.z;
                                z2 = true;
                            }
                            if (i4 < 0) {
                                break;
                            } else if (i4 > 0) {
                                fillTerm();
                                if (!z && !SegmentTermsEnum.this.termExists) {
                                    SegmentTermsEnum segmentTermsEnum = SegmentTermsEnum.this;
                                    segmentTermsEnum.currentFrame = segmentTermsEnum.pushFrame((e.a<l>) null, segmentTermsEnum.currentFrame.lastSubFP, i5);
                                    SegmentTermsEnum.this.currentFrame.loadBlock();
                                    while (SegmentTermsEnum.this.currentFrame.next()) {
                                        SegmentTermsEnum segmentTermsEnum2 = SegmentTermsEnum.this;
                                        segmentTermsEnum2.currentFrame = segmentTermsEnum2.pushFrame((e.a<l>) null, segmentTermsEnum2.currentFrame.lastSubFP, SegmentTermsEnum.this.term.z);
                                        SegmentTermsEnum.this.currentFrame.loadBlock();
                                    }
                                }
                                return o3.c.NOT_FOUND;
                            } else if (z2) {
                                fillTerm();
                                return o3.c.FOUND;
                            } else {
                                i10 = i3;
                                i9 = i2;
                            }
                        }
                    } while (this.nextEnt != this.entCount);
                    if (z) {
                        fillTerm();
                    }
                    if (z) {
                        fillTerm();
                    }
                    return o3.c.END;
                }

                public o3.c scanToTermNonLeaf(l lVar, boolean z) {
                    int i2;
                    boolean z2;
                    int i3;
                    boolean z3 = false;
                    if (this.nextEnt == this.entCount) {
                        if (z) {
                            fillTerm();
                            SegmentTermsEnum segmentTermsEnum = SegmentTermsEnum.this;
                            if (this.subCode == 0) {
                                z3 = true;
                            }
                            segmentTermsEnum.termExists = z3;
                        }
                        return o3.c.END;
                    }
                    do {
                        this.nextEnt++;
                        int readVInt = this.suffixesReader.readVInt();
                        this.suffix = readVInt >>> 1;
                        SegmentTermsEnum.this.termExists = (readVInt & 1) == 0;
                        int i4 = this.prefix;
                        int i5 = this.suffix;
                        int i6 = i4 + i5;
                        i.a.b.f.e eVar = this.suffixesReader;
                        this.startBytePos = eVar.y;
                        eVar.a(i5);
                        if (SegmentTermsEnum.this.termExists) {
                            this.state.termBlockOrd++;
                            this.subCode = 0;
                        } else {
                            long readVLong = this.suffixesReader.readVLong();
                            this.subCode = readVLong;
                            this.lastSubFP = this.fp - readVLong;
                        }
                        int i7 = lVar.y;
                        int i8 = lVar.z;
                        if (i8 >= i6) {
                            i8 = i6;
                        }
                        int i9 = i7 + i8;
                        int i10 = lVar.y + this.prefix;
                        int i11 = this.startBytePos;
                        while (true) {
                            if (i10 < i9) {
                                i2 = i11 + 1;
                                i3 = (this.suffixBytes[i11] & 255) - (lVar.x[i10] & 255);
                                i10++;
                                z2 = false;
                            } else {
                                i2 = i11;
                                i3 = i6 - lVar.z;
                                z2 = true;
                            }
                            if (i3 < 0) {
                                break;
                            } else if (i3 > 0) {
                                fillTerm();
                                if (!z && !SegmentTermsEnum.this.termExists) {
                                    SegmentTermsEnum segmentTermsEnum2 = SegmentTermsEnum.this;
                                    segmentTermsEnum2.currentFrame = segmentTermsEnum2.pushFrame((e.a<l>) null, segmentTermsEnum2.currentFrame.lastSubFP, i6);
                                    SegmentTermsEnum.this.currentFrame.loadBlock();
                                    while (SegmentTermsEnum.this.currentFrame.next()) {
                                        SegmentTermsEnum segmentTermsEnum3 = SegmentTermsEnum.this;
                                        segmentTermsEnum3.currentFrame = segmentTermsEnum3.pushFrame((e.a<l>) null, segmentTermsEnum3.currentFrame.lastSubFP, SegmentTermsEnum.this.term.z);
                                        SegmentTermsEnum.this.currentFrame.loadBlock();
                                    }
                                }
                                return o3.c.NOT_FOUND;
                            } else if (z2) {
                                fillTerm();
                                return o3.c.FOUND;
                            } else {
                                i11 = i2;
                            }
                        }
                    } while (this.nextEnt != this.entCount);
                    if (z) {
                        fillTerm();
                    }
                    if (z) {
                        fillTerm();
                    }
                    return o3.c.END;
                }

                public void setFloorData(i.a.b.f.e eVar, l lVar) {
                    int i2 = lVar.z - (eVar.y - lVar.y);
                    if (i2 > this.floorData.length) {
                        this.floorData = new byte[c.a(i2, 1)];
                    }
                    System.arraycopy(lVar.x, lVar.y + eVar.y, this.floorData, 0, i2);
                    this.floorDataReader.a(this.floorData, 0, i2);
                    this.numFollowFloorBlocks = this.floorDataReader.readVInt();
                    this.nextFloorLabel = this.floorDataReader.readByte() & 255;
                }
            }

            public SegmentTermsEnum() {
                if (FieldReader.this.index == null) {
                    this.fstReader = null;
                } else {
                    this.fstReader = FieldReader.this.index.b();
                }
                int i2 = 0;
                while (true) {
                    e.a<l>[] aVarArr = this.arcs;
                    if (i2 >= aVarArr.length) {
                        break;
                    }
                    aVarArr[i2] = new e.a<>();
                    i2++;
                }
                this.currentFrame = this.staticFrame;
                if (FieldReader.this.index != null) {
                    FieldReader.this.index.a(this.arcs[0]);
                }
                this.currentFrame = this.staticFrame;
                this.validIndexPrefix = 0;
            }

            private boolean clearEOF() {
                this.eof = false;
                return true;
            }

            private e.a<l> getArc(int i2) {
                if (i2 >= this.arcs.length) {
                    int a = c.a(i2 + 1, o0.a);
                    e.a<l>[] aVarArr = new e.a[a];
                    e.a<l>[] aVarArr2 = this.arcs;
                    System.arraycopy(aVarArr2, 0, aVarArr, 0, aVarArr2.length);
                    for (int length = this.arcs.length; length < a; length++) {
                        aVarArr[length] = new e.a<>();
                    }
                    this.arcs = aVarArr;
                }
                return this.arcs[i2];
            }

            private Frame getFrame(int i2) {
                if (i2 >= this.stack.length) {
                    int a = c.a(i2 + 1, o0.a);
                    Frame[] frameArr = new Frame[a];
                    Frame[] frameArr2 = this.stack;
                    System.arraycopy(frameArr2, 0, frameArr, 0, frameArr2.length);
                    for (int length = this.stack.length; length < a; length++) {
                        frameArr[length] = new Frame(length);
                    }
                    this.stack = frameArr;
                }
                return this.stack[i2];
            }

            private void printSeekState(PrintStream printStream) {
                boolean z;
                int i2;
                PrintStream printStream2;
                T t;
                String str;
                boolean z2;
                int i3;
                String str2;
                SegmentTermsEnum segmentTermsEnum = this;
                if (segmentTermsEnum.currentFrame == segmentTermsEnum.staticFrame) {
                    printStream.println("  no prior seek");
                    return;
                }
                printStream.println("  prior seek state:");
                int i4 = 0;
                int i5 = 0;
                boolean z3 = true;
                while (true) {
                    Frame frame = segmentTermsEnum.getFrame(i5);
                    l lVar = new l(segmentTermsEnum.term.x, i4, frame.prefix);
                    String str3 = "";
                    if (frame.nextEnt == -1) {
                        StringBuilder b2 = a.b("    frame ");
                        b2.append(z3 ? "(seek)" : "(next)");
                        b2.append(" ord=");
                        b2.append(i5);
                        b2.append(" fp=");
                        b2.append(frame.fp);
                        if (frame.isFloor) {
                            StringBuilder b3 = a.b(" (fpOrig=");
                            i3 = i5;
                            z2 = z3;
                            b3.append(frame.fpOrig);
                            b3.append(")");
                            str2 = b3.toString();
                        } else {
                            i3 = i5;
                            z2 = z3;
                            str2 = str3;
                        }
                        b2.append(str2);
                        b2.append(" prefixLen=");
                        b2.append(frame.prefix);
                        b2.append(" prefix=");
                        b2.append(lVar);
                        if (frame.nextEnt != -1) {
                            str3 = a.a(a.b(" (of "), frame.entCount, ")");
                        }
                        b2.append(str3);
                        b2.append(" hasTerms=");
                        b2.append(frame.hasTerms);
                        b2.append(" isFloor=");
                        b2.append(frame.isFloor);
                        b2.append(" code=");
                        b2.append((frame.fp << 2) + ((long) (frame.hasTerms ? 2 : 0)) + (frame.isFloor ? 1 : 0));
                        b2.append(" isLastInFloor=");
                        b2.append(frame.isLastInFloor);
                        b2.append(" mdUpto=");
                        b2.append(frame.metaDataUpto);
                        b2.append(" tbOrd=");
                        b2.append(frame.getTermBlockOrd());
                        printStream.println(b2.toString());
                        segmentTermsEnum = this;
                        z = z2;
                        i2 = i3;
                        printStream2 = printStream;
                    } else {
                        StringBuilder b4 = a.b("    frame ");
                        z = z3;
                        b4.append(z3 ? "(seek, loaded)" : "(next, loaded)");
                        b4.append(" ord=");
                        b4.append(i5);
                        b4.append(" fp=");
                        b4.append(frame.fp);
                        if (frame.isFloor) {
                            StringBuilder b5 = a.b(" (fpOrig=");
                            i2 = i5;
                            b5.append(frame.fpOrig);
                            b5.append(")");
                            str = b5.toString();
                        } else {
                            i2 = i5;
                            str = str3;
                        }
                        b4.append(str);
                        b4.append(" prefixLen=");
                        b4.append(frame.prefix);
                        b4.append(" prefix=");
                        b4.append(lVar);
                        b4.append(" nextEnt=");
                        b4.append(frame.nextEnt);
                        if (frame.nextEnt != -1) {
                            str3 = a.a(a.b(" (of "), frame.entCount, ")");
                        }
                        b4.append(str3);
                        b4.append(" hasTerms=");
                        b4.append(frame.hasTerms);
                        b4.append(" isFloor=");
                        b4.append(frame.isFloor);
                        b4.append(" code=");
                        b4.append((frame.fp << 2) + ((long) (frame.hasTerms ? 2 : 0)) + (frame.isFloor ? 1 : 0));
                        b4.append(" lastSubFP=");
                        b4.append(frame.lastSubFP);
                        b4.append(" isLastInFloor=");
                        b4.append(frame.isLastInFloor);
                        b4.append(" mdUpto=");
                        b4.append(frame.metaDataUpto);
                        b4.append(" tbOrd=");
                        b4.append(frame.getTermBlockOrd());
                        printStream2 = printStream;
                        printStream2.println(b4.toString());
                        segmentTermsEnum = this;
                    }
                    if (FieldReader.this.index != null) {
                        int i6 = frame.prefix;
                        if (i6 <= 0 || !z || frame.arc.a == (segmentTermsEnum.term.x[i6 - 1] & 255)) {
                            e eVar = FieldReader.this.index;
                            e.b b6 = eVar.b();
                            e.a aVar = new e.a();
                            eVar.a(aVar);
                            T a = eVar.f1433f.a();
                            int i7 = 0;
                            while (true) {
                                t = null;
                                if (i7 < lVar.z) {
                                    if (eVar.a(lVar.x[lVar.y + i7] & 255, aVar, aVar, b6) == null) {
                                        break;
                                    }
                                    a = eVar.f1433f.a((Object) a, (Object) aVar.f1437b);
                                    i7++;
                                } else if (aVar.a()) {
                                    t = eVar.f1433f.a((Object) a, (Object) aVar.f1440f);
                                }
                            }
                            T t2 = t;
                            if (t2 == null) {
                                printStream2.println("      broken seek state: prefix is not final in index");
                                throw new RuntimeException("seek state is broken");
                            } else if (z && !frame.isFloor) {
                                long readVLong = new i.a.b.f.e(t2.x, t2.y, t2.z).readVLong();
                                long j = (frame.fp << 2) | ((long) (frame.hasTerms ? 2 : 0)) | (frame.isFloor ? 1 : 0);
                                if (readVLong != j) {
                                    printStream2.println("      broken seek state: output code=" + readVLong + " doesn't match frame code=" + j);
                                    throw new RuntimeException("seek state is broken");
                                }
                            }
                        } else {
                            StringBuilder b7 = a.b("      broken seek state: arc.label=");
                            b7.append((char) frame.arc.a);
                            b7.append(" vs term byte=");
                            b7.append((char) (segmentTermsEnum.term.x[frame.prefix - 1] & 255));
                            printStream2.println(b7.toString());
                            throw new RuntimeException("seek state is broken");
                        }
                    }
                    if (frame != segmentTermsEnum.currentFrame) {
                        z3 = frame.prefix == segmentTermsEnum.validIndexPrefix ? false : z;
                        i5 = i2 + 1;
                        i4 = 0;
                    } else {
                        return;
                    }
                }
            }

            private boolean setEOF() {
                this.eof = true;
                return true;
            }

            public Stats computeBlockStats() {
                e.a<l> aVar;
                Stats stats = new Stats(BlockTreeTermsReader.this.segment, FieldReader.this.fieldInfo.a);
                if (FieldReader.this.index != null) {
                    stats.indexNodeCount = FieldReader.this.index.f1436i + 1;
                    stats.indexArcCount = FieldReader.this.index.j;
                    stats.indexNumBytes = FieldReader.this.index.c();
                }
                this.currentFrame = this.staticFrame;
                e.a<l> aVar2 = null;
                if (FieldReader.this.index != null) {
                    e eVar = FieldReader.this.index;
                    aVar = this.arcs[0];
                    eVar.a(aVar);
                } else {
                    aVar = null;
                }
                Frame pushFrame = pushFrame(aVar, FieldReader.this.rootCode, 0);
                this.currentFrame = pushFrame;
                pushFrame.fpOrig = pushFrame.fp;
                pushFrame.loadBlock();
                this.validIndexPrefix = 0;
                Frame frame = this.currentFrame;
                stats.startBlock(frame, !frame.isLastInFloor);
                while (true) {
                    Frame frame2 = this.currentFrame;
                    if (frame2.nextEnt == frame2.entCount) {
                        stats.endBlock(frame2);
                        Frame frame3 = this.currentFrame;
                        if (!frame3.isLastInFloor) {
                            frame3.loadNextFloorBlock();
                            stats.startBlock(this.currentFrame, true);
                        } else {
                            int i2 = frame3.ord;
                            if (i2 == 0) {
                                break;
                            }
                            this.currentFrame = this.stack[i2 - 1];
                        }
                    } else {
                        while (this.currentFrame.next()) {
                            Frame pushFrame2 = pushFrame((e.a<l>) null, this.currentFrame.lastSubFP, this.term.z);
                            this.currentFrame = pushFrame2;
                            pushFrame2.fpOrig = pushFrame2.fp;
                            pushFrame2.isFloor = false;
                            pushFrame2.loadBlock();
                            Frame frame4 = this.currentFrame;
                            stats.startBlock(frame4, !frame4.isLastInFloor);
                        }
                        stats.term(this.term);
                    }
                }
                stats.finish();
                this.currentFrame = this.staticFrame;
                if (FieldReader.this.index != null) {
                    e eVar2 = FieldReader.this.index;
                    aVar2 = this.arcs[0];
                    eVar2.a(aVar2);
                }
                Frame pushFrame3 = pushFrame(aVar2, FieldReader.this.rootCode, 0);
                this.currentFrame = pushFrame3;
                pushFrame3.rewind();
                this.currentFrame.loadBlock();
                this.validIndexPrefix = 0;
                this.term.z = 0;
                return stats;
            }

            @Override // i.a.b.c.o3
            public int docFreq() {
                this.currentFrame.decodeMetaData();
                return this.currentFrame.state.docFreq;
            }

            @Override // i.a.b.c.o3
            public c0 docs(i.a.b.g.j jVar, c0 c0Var, int i2) {
                this.currentFrame.decodeMetaData();
                return BlockTreeTermsReader.this.postingsReader.docs(FieldReader.this.fieldInfo, this.currentFrame.state, jVar, c0Var, i2);
            }

            @Override // i.a.b.c.o3
            public b0 docsAndPositions(i.a.b.g.j jVar, b0 b0Var, int i2) {
                if (FieldReader.this.fieldInfo.f954h.compareTo((Enum) k0.b.DOCS_AND_FREQS_AND_POSITIONS) < 0) {
                    return null;
                }
                this.currentFrame.decodeMetaData();
                return BlockTreeTermsReader.this.postingsReader.docsAndPositions(FieldReader.this.fieldInfo, this.currentFrame.state, jVar, b0Var, i2);
            }

            @Override // i.a.b.g.n
            public Comparator<l> getComparator() {
                return l.C;
            }

            public void initIndexInput() {
                if (this.in == null) {
                    this.in = BlockTreeTermsReader.this.in.clone();
                }
            }

            @Override // i.a.b.g.n
            public l next() {
                e.a<l> aVar;
                if (this.in == null) {
                    if (FieldReader.this.index != null) {
                        e eVar = FieldReader.this.index;
                        aVar = this.arcs[0];
                        eVar.a(aVar);
                    } else {
                        aVar = null;
                    }
                    Frame pushFrame = pushFrame(aVar, FieldReader.this.rootCode, 0);
                    this.currentFrame = pushFrame;
                    pushFrame.loadBlock();
                }
                Frame frame = this.currentFrame;
                this.targetBeforeCurrentLength = frame.ord;
                if (frame == this.staticFrame) {
                    seekExact(this.term);
                }
                while (true) {
                    Frame frame2 = this.currentFrame;
                    if (frame2.nextEnt != frame2.entCount) {
                        while (this.currentFrame.next()) {
                            Frame pushFrame2 = pushFrame((e.a<l>) null, this.currentFrame.lastSubFP, this.term.z);
                            this.currentFrame = pushFrame2;
                            pushFrame2.isFloor = false;
                            pushFrame2.loadBlock();
                        }
                        return this.term;
                    } else if (!frame2.isLastInFloor) {
                        frame2.loadNextFloorBlock();
                    } else {
                        int i2 = frame2.ord;
                        if (i2 == 0) {
                            this.term.z = 0;
                            this.validIndexPrefix = 0;
                            frame2.rewind();
                            this.termExists = false;
                            return null;
                        }
                        long j = frame2.fpOrig;
                        Frame frame3 = this.stack[i2 - 1];
                        this.currentFrame = frame3;
                        if (frame3.nextEnt == -1 || frame3.lastSubFP != j) {
                            this.currentFrame.scanToFloorFrame(this.term);
                            this.currentFrame.loadBlock();
                            this.currentFrame.scanToSubBlock(j);
                        }
                        this.validIndexPrefix = Math.min(this.validIndexPrefix, this.currentFrame.prefix);
                    }
                }
            }

            @Override // i.a.b.c.o3
            public long ord() {
                throw new UnsupportedOperationException();
            }

            public Frame pushFrame(e.a<l> aVar, l lVar, int i2) {
                this.scratchReader.a(lVar.x, lVar.y, lVar.z);
                long readVLong = this.scratchReader.readVLong();
                long j = readVLong >>> 2;
                boolean z = true;
                Frame frame = getFrame(this.currentFrame.ord + 1);
                boolean z2 = (2 & readVLong) != 0;
                frame.hasTerms = z2;
                frame.hasTermsOrig = z2;
                if ((readVLong & 1) == 0) {
                    z = false;
                }
                frame.isFloor = z;
                if (z) {
                    frame.setFloorData(this.scratchReader, lVar);
                }
                pushFrame(aVar, j, i2);
                return frame;
            }

            @Override // i.a.b.c.o3
            public o3.c seekCeil(l lVar) {
                int i2;
                l lVar2;
                e.a<l> aVar;
                if (FieldReader.this.index != null) {
                    l lVar3 = this.term;
                    byte[] bArr = lVar3.x;
                    int length = bArr.length;
                    int i3 = lVar.z;
                    if (length <= i3) {
                        lVar3.x = c.a(bArr, i3 + 1);
                    }
                    Frame frame = this.currentFrame;
                    this.targetBeforeCurrentLength = frame.ord;
                    if (frame != this.staticFrame) {
                        aVar = this.arcs[0];
                        lVar2 = aVar.f1437b;
                        Frame frame2 = this.stack[0];
                        int min = Math.min(lVar.z, this.validIndexPrefix);
                        i2 = 0;
                        int i4 = 0;
                        while (i2 < min) {
                            i4 = (this.term.x[i2] & 255) - (lVar.x[lVar.y + i2] & 255);
                            if (i4 != 0) {
                                break;
                            }
                            i2++;
                            aVar = this.arcs[i2];
                            T t = aVar.f1437b;
                            BlockTreeTermsReader blockTreeTermsReader = BlockTreeTermsReader.this;
                            if (t != blockTreeTermsReader.NO_OUTPUT) {
                                lVar2 = blockTreeTermsReader.fstOutputs.a(lVar2, (l) t);
                            }
                            if (aVar.a()) {
                                frame2 = this.stack[frame2.ord + 1];
                            }
                        }
                        if (i4 == 0) {
                            int min2 = Math.min(lVar.z, this.term.z);
                            for (int i5 = i2; i5 < min2; i5++) {
                                i4 = (this.term.x[i5] & 255) - (lVar.x[lVar.y + i5] & 255);
                                if (i4 != 0) {
                                    break;
                                }
                            }
                            if (i4 == 0) {
                                i4 = this.term.z - lVar.z;
                            }
                        }
                        if (i4 < 0) {
                            this.currentFrame = frame2;
                        } else if (i4 > 0) {
                            this.targetBeforeCurrentLength = 0;
                            this.currentFrame = frame2;
                            frame2.rewind();
                        } else if (this.termExists) {
                            return o3.c.FOUND;
                        }
                    } else {
                        this.targetBeforeCurrentLength = -1;
                        e eVar = FieldReader.this.index;
                        e.a<l> aVar2 = this.arcs[0];
                        eVar.a(aVar2);
                        T t2 = aVar2.f1437b;
                        this.currentFrame = this.staticFrame;
                        this.currentFrame = pushFrame(aVar2, BlockTreeTermsReader.this.fstOutputs.a((l) t2, (l) aVar2.f1440f), 0);
                        i2 = 0;
                        lVar2 = t2;
                        aVar = aVar2;
                    }
                    while (i2 < lVar.z) {
                        int i6 = lVar.x[lVar.y + i2] & 255;
                        int i7 = i2 + 1;
                        aVar = FieldReader.this.index.a(i6, aVar, getArc(i7), this.fstReader);
                        if (aVar == null) {
                            Frame frame3 = this.currentFrame;
                            this.validIndexPrefix = frame3.prefix;
                            frame3.scanToFloorFrame(lVar);
                            this.currentFrame.loadBlock();
                            o3.c scanToTerm = this.currentFrame.scanToTerm(lVar, false);
                            if (scanToTerm != o3.c.END) {
                                return scanToTerm;
                            }
                            this.term.c(lVar);
                            this.termExists = false;
                            if (next() != null) {
                                return o3.c.NOT_FOUND;
                            }
                            return o3.c.END;
                        }
                        this.term.x[i2] = (byte) i6;
                        T t3 = aVar.f1437b;
                        BlockTreeTermsReader blockTreeTermsReader2 = BlockTreeTermsReader.this;
                        if (t3 != blockTreeTermsReader2.NO_OUTPUT) {
                            lVar2 = blockTreeTermsReader2.fstOutputs.a(lVar2, (l) t3);
                        }
                        if (aVar.a()) {
                            this.currentFrame = pushFrame(aVar, BlockTreeTermsReader.this.fstOutputs.a(lVar2, (l) aVar.f1440f), i7);
                        }
                        i2 = i7;
                    }
                    Frame frame4 = this.currentFrame;
                    this.validIndexPrefix = frame4.prefix;
                    frame4.scanToFloorFrame(lVar);
                    this.currentFrame.loadBlock();
                    o3.c scanToTerm2 = this.currentFrame.scanToTerm(lVar, false);
                    if (scanToTerm2 != o3.c.END) {
                        return scanToTerm2;
                    }
                    this.term.c(lVar);
                    this.termExists = false;
                    if (next() != null) {
                        return o3.c.NOT_FOUND;
                    }
                    return o3.c.END;
                }
                throw new IllegalStateException("terms index was not loaded");
            }

            @Override // i.a.b.c.o3
            public boolean seekExact(l lVar) {
                int i2;
                l lVar2;
                e.a<l> aVar;
                if (FieldReader.this.index != null) {
                    l lVar3 = this.term;
                    byte[] bArr = lVar3.x;
                    int length = bArr.length;
                    int i3 = lVar.z;
                    if (length <= i3) {
                        lVar3.x = c.a(bArr, i3 + 1);
                    }
                    Frame frame = this.currentFrame;
                    this.targetBeforeCurrentLength = frame.ord;
                    if (frame != this.staticFrame) {
                        aVar = this.arcs[0];
                        lVar2 = aVar.f1437b;
                        Frame frame2 = this.stack[0];
                        int min = Math.min(lVar.z, this.validIndexPrefix);
                        i2 = 0;
                        int i4 = 0;
                        while (i2 < min) {
                            i4 = (this.term.x[i2] & 255) - (lVar.x[lVar.y + i2] & 255);
                            if (i4 != 0) {
                                break;
                            }
                            i2++;
                            aVar = this.arcs[i2];
                            T t = aVar.f1437b;
                            BlockTreeTermsReader blockTreeTermsReader = BlockTreeTermsReader.this;
                            if (t != blockTreeTermsReader.NO_OUTPUT) {
                                lVar2 = blockTreeTermsReader.fstOutputs.a(lVar2, (l) t);
                            }
                            if (aVar.a()) {
                                frame2 = this.stack[frame2.ord + 1];
                            }
                        }
                        if (i4 == 0) {
                            int min2 = Math.min(lVar.z, this.term.z);
                            for (int i5 = i2; i5 < min2; i5++) {
                                i4 = (this.term.x[i5] & 255) - (lVar.x[lVar.y + i5] & 255);
                                if (i4 != 0) {
                                    break;
                                }
                            }
                            if (i4 == 0) {
                                i4 = this.term.z - lVar.z;
                            }
                        }
                        if (i4 < 0) {
                            this.currentFrame = frame2;
                        } else if (i4 > 0) {
                            this.targetBeforeCurrentLength = 0;
                            this.currentFrame = frame2;
                            frame2.rewind();
                        } else if (this.termExists) {
                            return true;
                        }
                    } else {
                        this.targetBeforeCurrentLength = -1;
                        e eVar = FieldReader.this.index;
                        e.a<l> aVar2 = this.arcs[0];
                        eVar.a(aVar2);
                        T t2 = aVar2.f1437b;
                        this.currentFrame = this.staticFrame;
                        this.currentFrame = pushFrame(aVar2, BlockTreeTermsReader.this.fstOutputs.a((l) t2, (l) aVar2.f1440f), 0);
                        i2 = 0;
                        lVar2 = t2;
                        aVar = aVar2;
                    }
                    while (i2 < lVar.z) {
                        int i6 = lVar.x[lVar.y + i2] & 255;
                        int i7 = i2 + 1;
                        aVar = FieldReader.this.index.a(i6, aVar, getArc(i7), this.fstReader);
                        if (aVar == null) {
                            Frame frame3 = this.currentFrame;
                            this.validIndexPrefix = frame3.prefix;
                            frame3.scanToFloorFrame(lVar);
                            Frame frame4 = this.currentFrame;
                            if (!frame4.hasTerms) {
                                this.termExists = false;
                                l lVar4 = this.term;
                                lVar4.x[i2] = (byte) i6;
                                lVar4.z = i7;
                                return false;
                            }
                            frame4.loadBlock();
                            if (this.currentFrame.scanToTerm(lVar, true) == o3.c.FOUND) {
                                return true;
                            }
                            return false;
                        }
                        this.term.x[i2] = (byte) i6;
                        T t3 = aVar.f1437b;
                        BlockTreeTermsReader blockTreeTermsReader2 = BlockTreeTermsReader.this;
                        if (t3 != blockTreeTermsReader2.NO_OUTPUT) {
                            lVar2 = blockTreeTermsReader2.fstOutputs.a(lVar2, (l) t3);
                        }
                        if (aVar.a()) {
                            this.currentFrame = pushFrame(aVar, BlockTreeTermsReader.this.fstOutputs.a(lVar2, (l) aVar.f1440f), i7);
                        }
                        i2 = i7;
                    }
                    Frame frame5 = this.currentFrame;
                    this.validIndexPrefix = frame5.prefix;
                    frame5.scanToFloorFrame(lVar);
                    Frame frame6 = this.currentFrame;
                    if (!frame6.hasTerms) {
                        this.termExists = false;
                        this.term.z = i2;
                        return false;
                    }
                    frame6.loadBlock();
                    if (this.currentFrame.scanToTerm(lVar, true) == o3.c.FOUND) {
                        return true;
                    }
                    return false;
                }
                throw new IllegalStateException("terms index was not loaded");
            }

            @Override // i.a.b.c.o3
            public l term() {
                return this.term;
            }

            @Override // i.a.b.c.o3
            public k3 termState() {
                this.currentFrame.decodeMetaData();
                return this.currentFrame.state.clone();
            }

            @Override // i.a.b.c.o3
            public long totalTermFreq() {
                this.currentFrame.decodeMetaData();
                return this.currentFrame.state.totalTermFreq;
            }

            public Frame pushFrame(e.a<l> aVar, long j, int i2) {
                Frame frame = getFrame(this.currentFrame.ord + 1);
                frame.arc = aVar;
                if (frame.fpOrig != j || frame.nextEnt == -1) {
                    frame.nextEnt = -1;
                    frame.prefix = i2;
                    frame.state.termBlockOrd = 0;
                    frame.fp = j;
                    frame.fpOrig = j;
                    frame.lastSubFP = -1;
                } else if (frame.prefix > this.targetBeforeCurrentLength) {
                    frame.rewind();
                }
                return frame;
            }

            @Override // i.a.b.c.o3
            public void seekExact(l lVar, k3 k3Var) {
                if (lVar.compareTo(this.term) != 0 || !this.termExists) {
                    Frame frame = this.staticFrame;
                    this.currentFrame = frame;
                    frame.state.copyFrom(k3Var);
                    this.term.c(lVar);
                    Frame frame2 = this.currentFrame;
                    frame2.metaDataUpto = frame2.getTermBlockOrd();
                    this.validIndexPrefix = 0;
                }
            }

            @Override // i.a.b.c.o3
            public void seekExact(long j) {
                throw new UnsupportedOperationException();
            }
        }
    }
}
