package org.apache.lucene.codecs.compressing;

import b.b.a.a.a;
import i.a.b.c.q;
import i.a.b.f.l;
import i.a.b.f.m;
import i.a.b.g.c;
import java.io.IOException;
import java.util.zip.DataFormatException;
import java.util.zip.Deflater;
import java.util.zip.Inflater;
import org.apache.lucene.codecs.compressing.LZ4;

public abstract class CompressionMode {
    public static final CompressionMode FAST = new CompressionMode() {
        /* class org.apache.lucene.codecs.compressing.CompressionMode.AnonymousClass1 */

        @Override // org.apache.lucene.codecs.compressing.CompressionMode
        public Compressor newCompressor() {
            return new LZ4FastCompressor();
        }

        @Override // org.apache.lucene.codecs.compressing.CompressionMode
        public Decompressor newDecompressor() {
            return CompressionMode.LZ4_DECOMPRESSOR;
        }

        public String toString() {
            return "FAST";
        }
    };
    public static final CompressionMode FAST_DECOMPRESSION = new CompressionMode() {
        /* class org.apache.lucene.codecs.compressing.CompressionMode.AnonymousClass3 */

        @Override // org.apache.lucene.codecs.compressing.CompressionMode
        public Compressor newCompressor() {
            return new LZ4HighCompressor();
        }

        @Override // org.apache.lucene.codecs.compressing.CompressionMode
        public Decompressor newDecompressor() {
            return CompressionMode.LZ4_DECOMPRESSOR;
        }

        public String toString() {
            return "FAST_DECOMPRESSION";
        }
    };
    public static final CompressionMode HIGH_COMPRESSION = new CompressionMode() {
        /* class org.apache.lucene.codecs.compressing.CompressionMode.AnonymousClass2 */

        @Override // org.apache.lucene.codecs.compressing.CompressionMode
        public Compressor newCompressor() {
            return new DeflateCompressor(9);
        }

        @Override // org.apache.lucene.codecs.compressing.CompressionMode
        public Decompressor newDecompressor() {
            return new DeflateDecompressor();
        }

        public String toString() {
            return "HIGH_COMPRESSION";
        }
    };
    public static final Decompressor LZ4_DECOMPRESSOR = new Decompressor() {
        /* class org.apache.lucene.codecs.compressing.CompressionMode.AnonymousClass4 */
        public static final /* synthetic */ boolean $assertionsDisabled = false;

        @Override // org.apache.lucene.codecs.compressing.Decompressor, org.apache.lucene.codecs.compressing.Decompressor, java.lang.Object
        public Decompressor clone() {
            return this;
        }

        @Override // org.apache.lucene.codecs.compressing.Decompressor
        public void decompress(l lVar, int i2, int i3, int i4, i.a.b.g.l lVar2) {
            int i5 = i2 + 7;
            if (lVar2.x.length < i5) {
                lVar2.x = new byte[c.a(i5, 1)];
            }
            int decompress = LZ4.decompress(lVar, i3 + i4, lVar2.x, 0);
            if (decompress <= i2) {
                lVar2.y = i3;
                lVar2.z = i4;
                return;
            }
            StringBuilder a = a.a("Corrupted: lengths mismatch: ", decompress, " > ", i2, " (resource=");
            a.append(lVar);
            a.append(")");
            throw new q(a.toString());
        }
    };

    public static class DeflateCompressor extends Compressor {
        public static final /* synthetic */ boolean $assertionsDisabled = false;
        public byte[] compressed = new byte[64];
        public final Deflater compressor;

        public DeflateCompressor(int i2) {
            this.compressor = new Deflater(i2);
        }

        @Override // org.apache.lucene.codecs.compressing.Compressor
        public void compress(byte[] bArr, int i2, int i3, m mVar) {
            this.compressor.reset();
            this.compressor.setInput(bArr, i2, i3);
            this.compressor.finish();
            if (this.compressor.needsInput()) {
                mVar.b(0);
                return;
            }
            int i4 = 0;
            while (true) {
                Deflater deflater = this.compressor;
                byte[] bArr2 = this.compressed;
                i4 += deflater.deflate(bArr2, i4, bArr2.length - i4);
                if (this.compressor.finished()) {
                    mVar.b(i4);
                    mVar.a(this.compressed, 0, i4);
                    return;
                }
                this.compressed = c.a(this.compressed);
            }
        }
    }

    public static final class DeflateDecompressor extends Decompressor {
        public static final /* synthetic */ boolean $assertionsDisabled = false;
        public byte[] compressed = new byte[0];
        public final Inflater decompressor = new Inflater();

        @Override // org.apache.lucene.codecs.compressing.Decompressor
        public void decompress(l lVar, int i2, int i3, int i4, i.a.b.g.l lVar2) {
            if (i4 == 0) {
                lVar2.z = 0;
                return;
            }
            int readVInt = lVar.readVInt();
            if (readVInt > this.compressed.length) {
                this.compressed = new byte[c.a(readVInt, 1)];
            }
            lVar.readBytes(this.compressed, 0, readVInt);
            this.decompressor.reset();
            this.decompressor.setInput(this.compressed, 0, readVInt);
            lVar2.z = 0;
            lVar2.y = 0;
            while (true) {
                try {
                    lVar2.z += this.decompressor.inflate(lVar2.x, lVar2.z, lVar2.x.length - lVar2.z);
                    if (this.decompressor.finished()) {
                        break;
                    }
                    lVar2.x = c.a(lVar2.x);
                } catch (DataFormatException e2) {
                    throw new IOException(e2);
                }
            }
            if (lVar2.z == i2) {
                lVar2.y = i3;
                lVar2.z = i4;
                return;
            }
            StringBuilder b2 = a.b("Lengths mismatch: ");
            b2.append(lVar2.z);
            b2.append(" != ");
            b2.append(i2);
            b2.append(" (resource=");
            b2.append(lVar);
            b2.append(")");
            throw new q(b2.toString());
        }

        @Override // org.apache.lucene.codecs.compressing.Decompressor, org.apache.lucene.codecs.compressing.Decompressor, java.lang.Object
        public Decompressor clone() {
            return new DeflateDecompressor();
        }
    }

    public static final class LZ4FastCompressor extends Compressor {
        public final LZ4.HashTable ht = new LZ4.HashTable();

        @Override // org.apache.lucene.codecs.compressing.Compressor
        public void compress(byte[] bArr, int i2, int i3, m mVar) {
            LZ4.compress(bArr, i2, i3, mVar, this.ht);
        }
    }

    public static final class LZ4HighCompressor extends Compressor {
        public final LZ4.HCHashTable ht = new LZ4.HCHashTable();

        @Override // org.apache.lucene.codecs.compressing.Compressor
        public void compress(byte[] bArr, int i2, int i3, m mVar) {
            LZ4.compressHC(bArr, i2, i3, mVar, this.ht);
        }
    }

    public abstract Compressor newCompressor();

    public abstract Decompressor newDecompressor();
}
