package org.apache.lucene.codecs.compressing;

import i.a.b.f.l;
import i.a.b.f.m;
import i.a.b.g.g1.x0;
import java.util.Arrays;

public final class LZ4 {
    public static final /* synthetic */ boolean $assertionsDisabled = false;
    public static final int HASH_LOG_HC = 15;
    public static final int HASH_TABLE_SIZE_HC = 32768;
    public static final int LAST_LITERALS = 5;
    public static final int MAX_DISTANCE = 65536;
    public static final int MEMORY_USAGE = 14;
    public static final int MIN_MATCH = 4;
    public static final int OPTIMAL_ML = 18;

    public static final class HCHashTable {
        public static final /* synthetic */ boolean $assertionsDisabled = false;
        public static final int MASK = 65535;
        public static final int MAX_ATTEMPTS = 256;
        public int base;
        public final short[] chainTable = new short[65536];
        public final int[] hashTable = new int[32768];
        public int nextToUpdate;

        private void addHash(byte[] bArr, int i2) {
            int hashHC = LZ4.hashHC(LZ4.readInt(bArr, i2));
            int i3 = i2 - this.hashTable[hashHC];
            if (i3 >= 65536) {
                i3 = 65535;
            }
            this.chainTable[65535 & i2] = (short) i3;
            this.hashTable[hashHC] = i2;
        }

        private int hashPointer(byte[] bArr, int i2) {
            return this.hashTable[LZ4.hashHC(LZ4.readInt(bArr, i2))];
        }

        private int next(int i2) {
            return i2 - (this.chainTable[i2 & 65535] & 65535);
        }

        /* access modifiers changed from: private */
        /* access modifiers changed from: public */
        private void reset(int i2) {
            this.base = i2;
            this.nextToUpdate = i2;
            Arrays.fill(this.hashTable, -1);
            Arrays.fill(this.chainTable, (short) 0);
        }

        public void insert(int i2, byte[] bArr) {
            while (true) {
                int i3 = this.nextToUpdate;
                if (i3 < i2) {
                    addHash(bArr, i3);
                    this.nextToUpdate++;
                } else {
                    return;
                }
            }
        }

        public boolean insertAndFindBestMatch(byte[] bArr, int i2, int i3, Match match) {
            int i4;
            int i5;
            int commonBytes;
            match.start = i2;
            match.len = 0;
            insert(i2, bArr);
            int hashPointer = hashPointer(bArr, i2);
            if (hashPointer < i2 - 4 || hashPointer > i2 || hashPointer < this.base) {
                i5 = 0;
                i4 = 0;
            } else {
                if (LZ4.readIntEquals(bArr, hashPointer, i2)) {
                    i5 = i2 - hashPointer;
                    i4 = LZ4.commonBytes(bArr, hashPointer + 4, i2 + 4, i3) + 4;
                    match.len = i4;
                    match.ref = hashPointer;
                } else {
                    i5 = 0;
                    i4 = 0;
                }
                hashPointer = next(hashPointer);
            }
            for (int i6 = 0; i6 < 256 && hashPointer >= Math.max(this.base, (i2 - 65536) + 1) && hashPointer <= i2; i6++) {
                int i7 = match.len;
                if (bArr[hashPointer + i7] == bArr[i7 + i2] && LZ4.readIntEquals(bArr, hashPointer, i2) && (commonBytes = LZ4.commonBytes(bArr, hashPointer + 4, i2 + 4, i3) + 4) > match.len) {
                    match.ref = hashPointer;
                    match.len = commonBytes;
                }
                hashPointer = next(hashPointer);
            }
            if (i4 != 0) {
                int i8 = (i4 + i2) - 3;
                while (i2 < i8 - i5) {
                    this.chainTable[65535 & i2] = (short) i5;
                    i2++;
                }
                do {
                    this.chainTable[i2 & 65535] = (short) i5;
                    this.hashTable[LZ4.hashHC(LZ4.readInt(bArr, i2))] = i2;
                    i2++;
                } while (i2 < i8);
                this.nextToUpdate = i8;
            }
            if (match.len != 0) {
                return true;
            }
            return false;
        }

        public boolean insertAndFindWiderMatch(byte[] bArr, int i2, int i3, int i4, int i5, Match match) {
            int commonBytesBackward;
            int commonBytes;
            match.len = i5;
            insert(i2, bArr);
            int i6 = i2 - i3;
            int hashPointer = hashPointer(bArr, i2);
            for (int i7 = 0; i7 < 256 && hashPointer >= Math.max(this.base, (i2 - 65536) + 1) && hashPointer <= i2; i7++) {
                int i8 = match.len;
                if (bArr[(hashPointer - i6) + i8] == bArr[i8 + i3] && LZ4.readIntEquals(bArr, hashPointer, i2) && (commonBytes = LZ4.commonBytes(bArr, hashPointer + 4, i2 + 4, i4) + 4 + (commonBytesBackward = LZ4.commonBytesBackward(bArr, hashPointer, i2, this.base, i3))) > match.len) {
                    match.len = commonBytes;
                    match.ref = hashPointer - commonBytesBackward;
                    match.start = i2 - commonBytesBackward;
                }
                hashPointer = next(hashPointer);
            }
            if (match.len > i5) {
                return true;
            }
            return false;
        }
    }

    public static final class HashTable {
        public int hashLog;
        public x0.f hashTable;

        public void reset(int i2) {
            int a = x0.a((long) (i2 - 5));
            this.hashLog = 17 - (32 - Integer.numberOfLeadingZeros(a - 1));
            x0.f fVar = this.hashTable;
            if (fVar == null || fVar.c() < (1 << this.hashLog) || this.hashTable.a() < a) {
                this.hashTable = x0.b(1 << this.hashLog, a, 0.2f);
            } else {
                this.hashTable.d();
            }
        }
    }

    public static class Match {
        public int len;
        public int ref;
        public int start;

        public Match() {
        }

        public int end() {
            return this.start + this.len;
        }

        public void fix(int i2) {
            this.start += i2;
            this.ref += i2;
            this.len -= i2;
        }
    }

    public static int commonBytes(byte[] bArr, int i2, int i3, int i4) {
        int i5 = 0;
        while (i3 < i4) {
            int i6 = i2 + 1;
            int i7 = i3 + 1;
            if (bArr[i2] != bArr[i3]) {
                break;
            }
            i5++;
            i2 = i6;
            i3 = i7;
        }
        return i5;
    }

    public static int commonBytesBackward(byte[] bArr, int i2, int i3, int i4, int i5) {
        int i6 = 0;
        while (i2 > i4 && i3 > i5) {
            i2--;
            i3--;
            if (bArr[i2] != bArr[i3]) {
                break;
            }
            i6++;
        }
        return i6;
    }

    public static void compress(byte[] bArr, int i2, int i3, m mVar, HashTable hashTable) {
        int i4 = i2 + i3;
        int i5 = i2 + 1;
        if (i3 > 9) {
            int i6 = i4 - 5;
            int i7 = i6 - 4;
            hashTable.reset(i3);
            int i8 = hashTable.hashLog;
            x0.f fVar = hashTable.hashTable;
            int i9 = i2;
            loop0:
            while (i5 <= i6) {
                while (i5 < i7) {
                    int readInt = readInt(bArr, i5);
                    int hash = hash(readInt, i8);
                    int i10 = i2 + ((int) fVar.get(hash));
                    fVar.a(hash, (long) (i5 - i2));
                    if (i5 - i10 >= 65536 || readInt(bArr, i10) != readInt) {
                        i5++;
                    } else {
                        int commonBytes = commonBytes(bArr, i10 + 4, i5 + 4, i6) + 4;
                        encodeSequence(bArr, i9, i10, i5, commonBytes, mVar);
                        i9 = commonBytes + i5;
                        i5 = i9;
                    }
                }
                break loop0;
            }
            i2 = i9;
        }
        encodeLastLiterals(bArr, i2, i4 - i2, mVar);
    }

    /* JADX WARNING: Code restructure failed: missing block: B:59:0x0173, code lost:
        if (r14.start >= r13.end()) goto L_0x017c;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:60:0x0175, code lost:
        r13.len = r14.start - r13.start;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:61:0x017c, code lost:
        encodeSequence(r18, r16, r13.ref, r13.start, r13.len, r21);
        encodeSequence(r18, r13.end(), r14.ref, r14.start, r14.len, r21);
        r1 = r14.end();
     */
    public static void compressHC(byte[] bArr, int i2, int i3, m mVar, HCHashTable hCHashTable) {
        int i4 = i2;
        HCHashTable hCHashTable2 = hCHashTable;
        int i5 = i4 + i3;
        int i6 = i5 - 5;
        int i7 = i6 - 4;
        int i8 = i4 + 1;
        hCHashTable2.reset(i4);
        Match match = new Match();
        Match match2 = new Match();
        Match match3 = new Match();
        Match match4 = new Match();
        while (i8 <= i7) {
            if (!hCHashTable2.insertAndFindBestMatch(bArr, i8, i6, match2)) {
                i8++;
            } else {
                copyTo(match2, match);
                int i9 = i4;
                while (true) {
                    if (match2.end() >= i7 || !hCHashTable.insertAndFindWiderMatch(bArr, match2.end() - 2, match2.start + 1, i6, match2.len, match3)) {
                        encodeSequence(bArr, i9, match2.ref, match2.start, match2.len, mVar);
                        i8 = match2.end();
                    } else {
                        int i10 = match.start;
                        int i11 = match2.start;
                        if (i10 < i11 && match3.start < i11 + match.len) {
                            copyTo(match, match2);
                        }
                        if (match3.start - match2.start < 3) {
                            copyTo(match3, match2);
                        } else {
                            while (true) {
                                if (match3.start - match2.start < 18) {
                                    int i12 = match2.len;
                                    if (i12 > 18) {
                                        i12 = 18;
                                    }
                                    if (match2.start + i12 > match3.end() - 4) {
                                        i12 = ((match3.start - match2.start) + match3.len) - 4;
                                    }
                                    int i13 = i12 - (match3.start - match2.start);
                                    if (i13 > 0) {
                                        match3.fix(i13);
                                    }
                                }
                                if (match3.start + match3.len < i7 && hCHashTable.insertAndFindWiderMatch(bArr, match3.end() - 3, match3.start, i6, match3.len, match4)) {
                                    if (match4.start >= match2.end() + 3) {
                                        if (match3.start < match2.end()) {
                                            int i14 = match3.start;
                                            int i15 = match2.start;
                                            if (i14 - i15 < 15) {
                                                if (match2.len > 18) {
                                                    match2.len = 18;
                                                }
                                                if (match2.end() > match3.end() - 4) {
                                                    match2.len = (match3.end() - match2.start) - 4;
                                                }
                                                match3.fix(match2.end() - match3.start);
                                            } else {
                                                match2.len = i14 - i15;
                                            }
                                        }
                                        encodeSequence(bArr, i9, match2.ref, match2.start, match2.len, mVar);
                                        i9 = match2.end();
                                        copyTo(match3, match2);
                                        copyTo(match4, match3);
                                    } else if (match4.start >= match2.end()) {
                                        if (match3.start < match2.end()) {
                                            match3.fix(match2.end() - match3.start);
                                            if (match3.len < 4) {
                                                copyTo(match4, match3);
                                            }
                                        }
                                        encodeSequence(bArr, i9, match2.ref, match2.start, match2.len, mVar);
                                        i9 = match2.end();
                                        copyTo(match4, match2);
                                        copyTo(match3, match);
                                    } else {
                                        copyTo(match4, match3);
                                    }
                                }
                            }
                        }
                    }
                    hCHashTable2 = hCHashTable;
                    i4 = i8;
                }
                encodeSequence(bArr, i9, match2.ref, match2.start, match2.len, mVar);
                i8 = match2.end();
                hCHashTable2 = hCHashTable;
                i4 = i8;
            }
        }
        encodeLastLiterals(bArr, i4, i5 - i4, mVar);
    }

    public static void copyTo(Match match, Match match2) {
        match2.len = match.len;
        match2.start = match.start;
        match2.ref = match.ref;
    }

    public static int decompress(l lVar, int i2, byte[] bArr, int i3) {
        byte readByte;
        byte readByte2;
        int length = bArr.length;
        do {
            int readByte3 = lVar.readByte() & 255;
            int i4 = readByte3 >>> 4;
            if (i4 != 0) {
                if (i4 == 15) {
                    while (true) {
                        readByte2 = lVar.readByte();
                        if (readByte2 != -1) {
                            break;
                        }
                        i4 += 255;
                    }
                    i4 += readByte2 & 255;
                }
                lVar.readBytes(bArr, i3, i4);
                i3 += i4;
            }
            if (i3 >= i2) {
                break;
            }
            int readByte4 = (lVar.readByte() & 255) | ((lVar.readByte() & 255) << 8);
            int i5 = readByte3 & 15;
            if (i5 == 15) {
                while (true) {
                    readByte = lVar.readByte();
                    if (readByte != -1) {
                        break;
                    }
                    i5 += 255;
                }
                i5 += readByte & 255;
            }
            int i6 = i5 + 4;
            int i7 = (i6 + 7) & -8;
            if (readByte4 < i6 || i3 + i7 > length) {
                int i8 = i3 - readByte4;
                int i9 = i6 + i3;
                while (i3 < i9) {
                    bArr[i3] = bArr[i8];
                    i8++;
                    i3++;
                }
                continue;
            } else {
                System.arraycopy(bArr, i3 - readByte4, bArr, i3, i7);
                i3 += i6;
                continue;
            }
        } while (i3 < i2);
        return i3;
    }

    public static void encodeLastLiterals(byte[] bArr, int i2, int i3, m mVar) {
        encodeLiterals(bArr, Math.min(i3, 15) << 4, i2, i3, mVar);
    }

    public static void encodeLen(int i2, m mVar) {
        while (i2 >= 255) {
            mVar.a((byte) -1);
            i2 -= 255;
        }
        mVar.a((byte) i2);
    }

    public static void encodeLiterals(byte[] bArr, int i2, int i3, int i4, m mVar) {
        mVar.a((byte) i2);
        if (i4 >= 15) {
            encodeLen(i4 - 15, mVar);
        }
        mVar.a(bArr, i3, i4);
    }

    public static void encodeSequence(byte[] bArr, int i2, int i3, int i4, int i5, m mVar) {
        int i6 = i4 - i2;
        encodeLiterals(bArr, (Math.min(i6, 15) << 4) | Math.min(i5 - 4, 15), i2, i6, mVar);
        int i7 = i4 - i3;
        mVar.a((byte) i7);
        mVar.a((byte) (i7 >>> 8));
        if (i5 >= 19) {
            encodeLen((i5 - 15) - 4, mVar);
        }
    }

    public static int hash(int i2, int i3) {
        return (i2 * -1640531535) >>> (32 - i3);
    }

    public static int hashHC(int i2) {
        return hash(i2, 15);
    }

    public static int readInt(byte[] bArr, int i2) {
        return (bArr[i2 + 3] & 255) | ((bArr[i2] & 255) << 24) | ((bArr[i2 + 1] & 255) << 16) | ((bArr[i2 + 2] & 255) << 8);
    }

    public static boolean readIntEquals(byte[] bArr, int i2, int i3) {
        return readInt(bArr, i2) == readInt(bArr, i3);
    }
}
