package org.apache.lucene.codecs.perfield;

import b.b.a.a.a;
import i.a.b.c.b3;
import i.a.b.c.e;
import i.a.b.c.e2;
import i.a.b.c.k0;
import i.a.b.c.u2;
import i.a.b.c.w2;
import i.a.b.c.y2;
import i.a.b.g.j;
import i.a.b.g.l;
import i.a.b.g.x;
import java.io.Closeable;
import java.util.HashMap;
import java.util.IdentityHashMap;
import java.util.Iterator;
import java.util.Map;
import java.util.TreeMap;
import org.apache.lucene.codecs.DocValuesConsumer;
import org.apache.lucene.codecs.DocValuesFormat;
import org.apache.lucene.codecs.DocValuesProducer;

public abstract class PerFieldDocValuesFormat extends DocValuesFormat {
    public static final String PER_FIELD_FORMAT_KEY = (PerFieldDocValuesFormat.class.getSimpleName() + ".format");
    public static final String PER_FIELD_NAME = "PerFieldDV40";
    public static final String PER_FIELD_SUFFIX_KEY = (PerFieldDocValuesFormat.class.getSimpleName() + ".suffix");

    public static class ConsumerAndSuffix implements Closeable {
        public DocValuesConsumer consumer;
        public int suffix;

        @Override // java.io.Closeable, java.lang.AutoCloseable
        public void close() {
            this.consumer.close();
        }
    }

    public class FieldsReader extends DocValuesProducer {
        public static final /* synthetic */ boolean $assertionsDisabled = false;
        public final Map<String, DocValuesProducer> fields = new TreeMap();
        public final Map<String, DocValuesProducer> formats = new HashMap();

        public FieldsReader(u2 u2Var) {
            try {
                Iterator<k0> it = u2Var.c.iterator();
                while (it.hasNext()) {
                    k0 next = it.next();
                    if (next.a()) {
                        String str = next.a;
                        String a = next.a(PerFieldDocValuesFormat.PER_FIELD_FORMAT_KEY);
                        if (a != null) {
                            String a2 = next.a(PerFieldDocValuesFormat.PER_FIELD_SUFFIX_KEY);
                            DocValuesFormat forName = DocValuesFormat.forName(a);
                            String fullSegmentSuffix = PerFieldDocValuesFormat.getFullSegmentSuffix(u2Var.f1061f, PerFieldDocValuesFormat.getSuffix(a, a2));
                            if (!this.formats.containsKey(fullSegmentSuffix)) {
                                this.formats.put(fullSegmentSuffix, forName.fieldsProducer(new u2(u2Var, fullSegmentSuffix)));
                            }
                            this.fields.put(str, this.formats.get(fullSegmentSuffix));
                        }
                    }
                }
            } catch (Throwable th) {
                x.b(this.formats.values());
                throw th;
            }
        }

        @Override // java.io.Closeable, java.lang.AutoCloseable
        public void close() {
            x.a(this.formats.values());
        }

        @Override // org.apache.lucene.codecs.DocValuesProducer
        public e getBinary(k0 k0Var) {
            DocValuesProducer docValuesProducer = this.fields.get(k0Var.a);
            if (docValuesProducer == null) {
                return null;
            }
            return docValuesProducer.getBinary(k0Var);
        }

        @Override // org.apache.lucene.codecs.DocValuesProducer
        public j getDocsWithField(k0 k0Var) {
            DocValuesProducer docValuesProducer = this.fields.get(k0Var.a);
            if (docValuesProducer == null) {
                return null;
            }
            return docValuesProducer.getDocsWithField(k0Var);
        }

        @Override // org.apache.lucene.codecs.DocValuesProducer
        public e2 getNumeric(k0 k0Var) {
            DocValuesProducer docValuesProducer = this.fields.get(k0Var.a);
            if (docValuesProducer == null) {
                return null;
            }
            return docValuesProducer.getNumeric(k0Var);
        }

        @Override // org.apache.lucene.codecs.DocValuesProducer
        public y2 getSorted(k0 k0Var) {
            DocValuesProducer docValuesProducer = this.fields.get(k0Var.a);
            if (docValuesProducer == null) {
                return null;
            }
            return docValuesProducer.getSorted(k0Var);
        }

        @Override // org.apache.lucene.codecs.DocValuesProducer
        public b3 getSortedSet(k0 k0Var) {
            DocValuesProducer docValuesProducer = this.fields.get(k0Var.a);
            if (docValuesProducer == null) {
                return null;
            }
            return docValuesProducer.getSortedSet(k0Var);
        }

        @Override // org.apache.lucene.codecs.DocValuesProducer
        public long ramBytesUsed() {
            long j = 0;
            for (Map.Entry<String, DocValuesProducer> entry : this.formats.entrySet()) {
                j += entry.getValue().ramBytesUsed() + ((long) (entry.getKey().length() * 2));
            }
            return j;
        }

        @Override // java.lang.Object
        public DocValuesProducer clone() {
            return new FieldsReader(this);
        }

        public FieldsReader(FieldsReader fieldsReader) {
            IdentityHashMap identityHashMap = new IdentityHashMap();
            for (Map.Entry<String, DocValuesProducer> entry : fieldsReader.formats.entrySet()) {
                DocValuesProducer value = entry.getValue();
                this.formats.put(entry.getKey(), value);
                identityHashMap.put(entry.getValue(), value);
            }
            for (Map.Entry<String, DocValuesProducer> entry2 : fieldsReader.fields.entrySet()) {
                this.fields.put(entry2.getKey(), (DocValuesProducer) identityHashMap.get(entry2.getValue()));
            }
        }
    }

    public class FieldsWriter extends DocValuesConsumer {
        public static final /* synthetic */ boolean $assertionsDisabled = false;
        public final Map<DocValuesFormat, ConsumerAndSuffix> formats = new HashMap();
        public final w2 segmentWriteState;
        public final Map<String, Integer> suffixes = new HashMap();

        public FieldsWriter(w2 w2Var) {
            this.segmentWriteState = w2Var;
        }

        private DocValuesConsumer getInstance(k0 k0Var) {
            String a;
            String a2;
            Integer num = null;
            DocValuesFormat forName = (k0Var.k == -1 || (a2 = k0Var.a(PerFieldDocValuesFormat.PER_FIELD_FORMAT_KEY)) == null) ? null : DocValuesFormat.forName(a2);
            if (forName == null) {
                forName = PerFieldDocValuesFormat.this.getDocValuesFormatForField(k0Var.a);
            }
            if (forName != null) {
                String name = forName.getName();
                k0Var.a(PerFieldDocValuesFormat.PER_FIELD_FORMAT_KEY, name);
                ConsumerAndSuffix consumerAndSuffix = this.formats.get(forName);
                if (consumerAndSuffix == null) {
                    if (!(k0Var.k == -1 || (a = k0Var.a(PerFieldDocValuesFormat.PER_FIELD_SUFFIX_KEY)) == null)) {
                        num = Integer.valueOf(a);
                    }
                    if (num == null) {
                        Integer num2 = this.suffixes.get(name);
                        if (num2 == null) {
                            num = 0;
                        } else {
                            num = Integer.valueOf(num2.intValue() + 1);
                        }
                    }
                    this.suffixes.put(name, num);
                    String fullSegmentSuffix = PerFieldDocValuesFormat.getFullSegmentSuffix(this.segmentWriteState.f1088h, PerFieldDocValuesFormat.getSuffix(name, Integer.toString(num.intValue())));
                    consumerAndSuffix = new ConsumerAndSuffix();
                    consumerAndSuffix.consumer = forName.fieldsConsumer(new w2(this.segmentWriteState, fullSegmentSuffix));
                    consumerAndSuffix.suffix = num.intValue();
                    this.formats.put(forName, consumerAndSuffix);
                } else {
                    num = Integer.valueOf(consumerAndSuffix.suffix);
                }
                k0Var.a(PerFieldDocValuesFormat.PER_FIELD_SUFFIX_KEY, Integer.toString(num.intValue()));
                return consumerAndSuffix.consumer;
            }
            throw new IllegalStateException(a.a(a.b("invalid null DocValuesFormat for field=\""), k0Var.a, "\""));
        }

        @Override // org.apache.lucene.codecs.DocValuesConsumer
        public void addBinaryField(k0 k0Var, Iterable<l> iterable) {
            getInstance(k0Var).addBinaryField(k0Var, iterable);
        }

        @Override // org.apache.lucene.codecs.DocValuesConsumer
        public void addNumericField(k0 k0Var, Iterable<Number> iterable) {
            getInstance(k0Var).addNumericField(k0Var, iterable);
        }

        @Override // org.apache.lucene.codecs.DocValuesConsumer
        public void addSortedField(k0 k0Var, Iterable<l> iterable, Iterable<Number> iterable2) {
            getInstance(k0Var).addSortedField(k0Var, iterable, iterable2);
        }

        @Override // org.apache.lucene.codecs.DocValuesConsumer
        public void addSortedSetField(k0 k0Var, Iterable<l> iterable, Iterable<Number> iterable2, Iterable<Number> iterable3) {
            getInstance(k0Var).addSortedSetField(k0Var, iterable, iterable2, iterable3);
        }

        @Override // java.io.Closeable, java.lang.AutoCloseable
        public void close() {
            x.a(this.formats.values());
        }
    }

    public PerFieldDocValuesFormat() {
        super(PER_FIELD_NAME);
    }

    public static String getFullSegmentSuffix(String str, String str2) {
        if (str.length() == 0) {
            return str2;
        }
        return a.b(str, "_", str2);
    }

    public static String getSuffix(String str, String str2) {
        return a.b(str, "_", str2);
    }

    @Override // org.apache.lucene.codecs.DocValuesFormat
    public final DocValuesConsumer fieldsConsumer(w2 w2Var) {
        return new FieldsWriter(w2Var);
    }

    @Override // org.apache.lucene.codecs.DocValuesFormat
    public final DocValuesProducer fieldsProducer(u2 u2Var) {
        return new FieldsReader(u2Var);
    }

    public abstract DocValuesFormat getDocValuesFormatForField(String str);
}
