package org.apache.lucene.codecs.perfield;

import b.b.a.a.a;
import i.a.b.c.k0;
import i.a.b.c.n3;
import i.a.b.c.u2;
import i.a.b.c.w2;
import i.a.b.g.x;
import java.io.Closeable;
import java.util.Collections;
import java.util.HashMap;
import java.util.Iterator;
import java.util.Map;
import java.util.TreeMap;
import org.apache.lucene.codecs.FieldsConsumer;
import org.apache.lucene.codecs.FieldsProducer;
import org.apache.lucene.codecs.PostingsFormat;
import org.apache.lucene.codecs.TermsConsumer;

public abstract class PerFieldPostingsFormat extends PostingsFormat {
    public static final String PER_FIELD_FORMAT_KEY = (PerFieldPostingsFormat.class.getSimpleName() + ".format");
    public static final String PER_FIELD_NAME = "PerField40";
    public static final String PER_FIELD_SUFFIX_KEY = (PerFieldPostingsFormat.class.getSimpleName() + ".suffix");

    public static class FieldsConsumerAndSuffix implements Closeable {
        public FieldsConsumer consumer;
        public int suffix;

        @Override // java.io.Closeable, java.lang.AutoCloseable
        public void close() {
            this.consumer.close();
        }
    }

    public class FieldsReader extends FieldsProducer {
        public static final /* synthetic */ boolean $assertionsDisabled = false;
        public final Map<String, FieldsProducer> fields = new TreeMap();
        public final Map<String, FieldsProducer> formats = new HashMap();

        public FieldsReader(u2 u2Var) {
            try {
                Iterator<k0> it = u2Var.c.iterator();
                while (it.hasNext()) {
                    k0 next = it.next();
                    if (next.c) {
                        String str = next.a;
                        String a = next.a(PerFieldPostingsFormat.PER_FIELD_FORMAT_KEY);
                        if (a != null) {
                            String a2 = next.a(PerFieldPostingsFormat.PER_FIELD_SUFFIX_KEY);
                            PostingsFormat forName = PostingsFormat.forName(a);
                            String suffix = PerFieldPostingsFormat.getSuffix(a, a2);
                            if (!this.formats.containsKey(suffix)) {
                                this.formats.put(suffix, forName.fieldsProducer(new u2(u2Var, suffix)));
                            }
                            this.fields.put(str, this.formats.get(suffix));
                        }
                    }
                }
            } catch (Throwable th) {
                x.b(this.formats.values());
                throw th;
            }
        }

        @Override // org.apache.lucene.codecs.FieldsProducer, java.io.Closeable, java.lang.AutoCloseable
        public void close() {
            x.a(this.formats.values());
        }

        @Override // i.a.b.c.n0, java.lang.Iterable
        public Iterator<String> iterator() {
            return Collections.unmodifiableSet(this.fields.keySet()).iterator();
        }

        @Override // org.apache.lucene.codecs.FieldsProducer
        public long ramBytesUsed() {
            long j = 0;
            for (Map.Entry<String, FieldsProducer> entry : this.formats.entrySet()) {
                j = j + ((long) (entry.getKey().length() * 2)) + entry.getValue().ramBytesUsed();
            }
            return j;
        }

        @Override // i.a.b.c.n0
        public int size() {
            return this.fields.size();
        }

        @Override // i.a.b.c.n0
        public n3 terms(String str) {
            FieldsProducer fieldsProducer = this.fields.get(str);
            if (fieldsProducer == null) {
                return null;
            }
            return fieldsProducer.terms(str);
        }
    }

    public class FieldsWriter extends FieldsConsumer {
        public static final /* synthetic */ boolean $assertionsDisabled = false;
        public final Map<PostingsFormat, FieldsConsumerAndSuffix> formats = new HashMap();
        public final w2 segmentWriteState;
        public final Map<String, Integer> suffixes = new HashMap();

        public FieldsWriter(w2 w2Var) {
            this.segmentWriteState = w2Var;
        }

        @Override // org.apache.lucene.codecs.FieldsConsumer
        public TermsConsumer addField(k0 k0Var) {
            FieldsConsumerAndSuffix fieldsConsumerAndSuffix;
            Integer num;
            PostingsFormat postingsFormatForField = PerFieldPostingsFormat.this.getPostingsFormatForField(k0Var.a);
            if (postingsFormatForField != null) {
                String name = postingsFormatForField.getName();
                k0Var.a(PerFieldPostingsFormat.PER_FIELD_FORMAT_KEY, name);
                FieldsConsumerAndSuffix fieldsConsumerAndSuffix2 = this.formats.get(postingsFormatForField);
                if (fieldsConsumerAndSuffix2 == null) {
                    Integer num2 = this.suffixes.get(name);
                    if (num2 == null) {
                        num = 0;
                    } else {
                        num = Integer.valueOf(num2.intValue() + 1);
                    }
                    this.suffixes.put(name, num);
                    String fullSegmentSuffix = PerFieldPostingsFormat.getFullSegmentSuffix(k0Var.a, this.segmentWriteState.f1088h, PerFieldPostingsFormat.getSuffix(name, Integer.toString(num.intValue())));
                    fieldsConsumerAndSuffix = new FieldsConsumerAndSuffix();
                    fieldsConsumerAndSuffix.consumer = postingsFormatForField.fieldsConsumer(new w2(this.segmentWriteState, fullSegmentSuffix));
                    fieldsConsumerAndSuffix.suffix = num.intValue();
                    this.formats.put(postingsFormatForField, fieldsConsumerAndSuffix);
                } else {
                    fieldsConsumerAndSuffix = fieldsConsumerAndSuffix2;
                    num = Integer.valueOf(fieldsConsumerAndSuffix2.suffix);
                }
                k0Var.a(PerFieldPostingsFormat.PER_FIELD_SUFFIX_KEY, Integer.toString(num.intValue()));
                return fieldsConsumerAndSuffix.consumer.addField(k0Var);
            }
            throw new IllegalStateException(a.a(a.b("invalid null PostingsFormat for field=\""), k0Var.a, "\""));
        }

        @Override // java.io.Closeable, org.apache.lucene.codecs.FieldsConsumer, java.lang.AutoCloseable
        public void close() {
            x.a(this.formats.values());
        }
    }

    public PerFieldPostingsFormat() {
        super(PER_FIELD_NAME);
    }

    public static String getFullSegmentSuffix(String str, String str2, String str3) {
        if (str2.length() == 0) {
            return str3;
        }
        throw new IllegalStateException(a.b("cannot embed PerFieldPostingsFormat inside itself (field \"", str, "\" returned PerFieldPostingsFormat)"));
    }

    public static String getSuffix(String str, String str2) {
        return a.b(str, "_", str2);
    }

    @Override // org.apache.lucene.codecs.PostingsFormat
    public final FieldsConsumer fieldsConsumer(w2 w2Var) {
        return new FieldsWriter(w2Var);
    }

    @Override // org.apache.lucene.codecs.PostingsFormat
    public final FieldsProducer fieldsProducer(u2 u2Var) {
        return new FieldsReader(u2Var);
    }

    public abstract PostingsFormat getPostingsFormatForField(String str);
}
