package org.apache.poi;

import b.b.a.a.a;
import org.apache.poi.POIXMLProperties;
import org.apache.poi.openxml4j.opc.OPCPackage;
import org.apache.poi.openxml4j.util.ZipSecureFile;

public abstract class POIXMLTextExtractor extends POITextExtractor {
    public final POIXMLDocument _document;

    public POIXMLTextExtractor(POIXMLDocument pOIXMLDocument) {
        this._document = pOIXMLDocument;
    }

    public void checkMaxTextSize(StringBuffer stringBuffer, String str) {
        if (str != null) {
            int length = str.length() + stringBuffer.length();
            if (((long) length) > ZipSecureFile.getMaxTextSize()) {
                StringBuilder a = a.a("The text would exceed the max allowed overall size of extracted text. By default this is prevented as some documents may exhaust available memory and it may indicate that the file is used to inflate memory usage and thus could pose a security risk. You can adjust this limit via ZipSecureFile.setMaxTextSize() if you need to work with files which have a lot of text. Size: ", length, ", limit: MAX_TEXT_SIZE: ");
                a.append(ZipSecureFile.getMaxTextSize());
                throw new IllegalStateException(a.toString());
            }
        }
    }

    @Override // org.apache.poi.POITextExtractor, java.io.Closeable, java.lang.AutoCloseable
    public void close() {
        OPCPackage oPCPackage;
        POIXMLDocument pOIXMLDocument = this._document;
        if (!(pOIXMLDocument == null || (oPCPackage = pOIXMLDocument.getPackage()) == null)) {
            oPCPackage.revert();
        }
        super.close();
    }

    public POIXMLProperties.CoreProperties getCoreProperties() {
        return this._document.getProperties().getCoreProperties();
    }

    public POIXMLProperties.CustomProperties getCustomProperties() {
        return this._document.getProperties().getCustomProperties();
    }

    public final POIXMLDocument getDocument() {
        return this._document;
    }

    public POIXMLProperties.ExtendedProperties getExtendedProperties() {
        return this._document.getProperties().getExtendedProperties();
    }

    public OPCPackage getPackage() {
        return this._document.getPackage();
    }

    @Override // org.apache.poi.POITextExtractor
    public POIXMLPropertiesTextExtractor getMetadataTextExtractor() {
        return new POIXMLPropertiesTextExtractor(this._document);
    }
}
