package org.apache.poi.common.usermodel.fonts;

import b.b.a.a.a;
import java.nio.charset.Charset;
import java.nio.charset.UnsupportedCharsetException;
import org.apache.poi.util.POILogFactory;

public enum FontCharset {
    ANSI(0, "Cp1252"),
    DEFAULT(1, "Cp1252"),
    SYMBOL(2, ""),
    MAC(77, "MacRoman"),
    SHIFTJIS(128, "Shift_JIS"),
    HANGUL(129, "cp949"),
    JOHAB(130, "x-Johab"),
    GB2312(134, "GB2312"),
    CHINESEBIG5(136, "Big5"),
    GREEK(161, "Cp1253"),
    TURKISH(162, "Cp1254"),
    VIETNAMESE(163, "Cp1258"),
    HEBREW(177, "Cp1255"),
    ARABIC(178, "Cp1256"),
    BALTIC(186, "Cp1257"),
    RUSSIAN(204, "Cp1251"),
    THAI_(222, "x-windows-874"),
    EASTEUROPE(238, "Cp1250"),
    OEM(255, "Cp1252");
    
    public static FontCharset[] _table = new FontCharset[256];
    public Charset charset;
    public int nativeId;

    /* access modifiers changed from: public */
    static {
        FontCharset[] values = values();
        for (FontCharset fontCharset : values) {
            _table[fontCharset.getNativeId()] = fontCharset;
        }
    }

    /* access modifiers changed from: public */
    FontCharset(int i2, String str) {
        this.nativeId = i2;
        if (str.length() > 0) {
            try {
                this.charset = Charset.forName(str);
                return;
            } catch (UnsupportedCharsetException unused) {
                POILogFactory.getLogger(FontCharset.class).log(5, a.b("Unsupported charset: ", str));
            }
        }
        this.charset = null;
    }

    public Charset getCharset() {
        return this.charset;
    }

    public int getNativeId() {
        return this.nativeId;
    }

    public static FontCharset valueOf(int i2) {
        if (i2 >= 0) {
            FontCharset[] fontCharsetArr = _table;
            if (i2 < fontCharsetArr.length) {
                return fontCharsetArr[i2];
            }
        }
        return null;
    }
}
