package org.apache.poi.common.usermodel.fonts;

import java.util.ArrayList;
import java.util.List;
import java.util.Map;
import java.util.NavigableMap;
import java.util.TreeMap;

public enum FontGroup {
    LATIN,
    EAST_ASIAN,
    SYMBOL,
    COMPLEX_SCRIPT;
    
    public static NavigableMap<Integer, Range> UCS_RANGES;

    public static class FontGroupRange {
        public FontGroup fontGroup;
        public int len;

        public static /* synthetic */ int access$112(FontGroupRange fontGroupRange, int i2) {
            int i3 = fontGroupRange.len + i2;
            fontGroupRange.len = i3;
            return i3;
        }

        public FontGroup getFontGroup() {
            return this.fontGroup;
        }

        public int getLength() {
            return this.len;
        }
    }

    public static class Range {
        public FontGroup fontGroup;
        public int upper;

        public Range(int i2, FontGroup fontGroup2) {
            this.upper = i2;
            this.fontGroup = fontGroup2;
        }
    }

    /* access modifiers changed from: public */
    static {
        TreeMap treeMap = new TreeMap();
        UCS_RANGES = treeMap;
        treeMap.put(0, new Range(127, LATIN));
        UCS_RANGES.put(128, new Range(166, LATIN));
        UCS_RANGES.put(169, new Range(175, LATIN));
        UCS_RANGES.put(178, new Range(179, LATIN));
        UCS_RANGES.put(181, new Range(214, LATIN));
        UCS_RANGES.put(216, new Range(246, LATIN));
        UCS_RANGES.put(248, new Range(1423, LATIN));
        UCS_RANGES.put(1424, new Range(1871, COMPLEX_SCRIPT));
        UCS_RANGES.put(1920, new Range(1983, COMPLEX_SCRIPT));
        UCS_RANGES.put(2304, new Range(4255, COMPLEX_SCRIPT));
        UCS_RANGES.put(4256, new Range(4351, LATIN));
        UCS_RANGES.put(4608, new Range(4991, LATIN));
        UCS_RANGES.put(5024, new Range(6015, LATIN));
        UCS_RANGES.put(7424, new Range(7551, LATIN));
        UCS_RANGES.put(7680, new Range(8191, LATIN));
        UCS_RANGES.put(6016, new Range(6319, COMPLEX_SCRIPT));
        UCS_RANGES.put(8192, new Range(8203, LATIN));
        UCS_RANGES.put(8204, new Range(8207, COMPLEX_SCRIPT));
        UCS_RANGES.put(8208, new Range(8233, LATIN));
        UCS_RANGES.put(8234, new Range(8239, COMPLEX_SCRIPT));
        UCS_RANGES.put(8240, new Range(8262, LATIN));
        UCS_RANGES.put(8266, new Range(9311, LATIN));
        UCS_RANGES.put(9840, new Range(9841, COMPLEX_SCRIPT));
        UCS_RANGES.put(10176, new Range(11263, LATIN));
        UCS_RANGES.put(12441, new Range(12442, EAST_ASIAN));
        UCS_RANGES.put(55349, new Range(55349, LATIN));
        UCS_RANGES.put(61440, new Range(61695, SYMBOL));
        UCS_RANGES.put(64256, new Range(64279, LATIN));
        UCS_RANGES.put(64285, new Range(64335, COMPLEX_SCRIPT));
        UCS_RANGES.put(65104, new Range(65135, LATIN));
    }

    public static FontGroup getFontGroupFirst(String str) {
        return (str == null || str.isEmpty()) ? LATIN : lookup(str.codePointAt(0));
    }

    public static List<FontGroupRange> getFontGroupRanges(String str) {
        FontGroup fontGroup;
        ArrayList arrayList = new ArrayList();
        int i2 = 0;
        int length = str != null ? str.length() : 0;
        FontGroupRange fontGroupRange = null;
        while (i2 < length) {
            int codePointAt = str.codePointAt(i2);
            int charCount = Character.charCount(codePointAt);
            if (fontGroupRange == null || " \n\r".indexOf(codePointAt) <= -1) {
                fontGroup = lookup(codePointAt);
            } else {
                fontGroup = fontGroupRange.fontGroup;
            }
            if (fontGroupRange == null || fontGroupRange.fontGroup != fontGroup) {
                fontGroupRange = new FontGroupRange();
                fontGroupRange.fontGroup = fontGroup;
                arrayList.add(fontGroupRange);
            }
            FontGroupRange.access$112(fontGroupRange, charCount);
            i2 += charCount;
        }
        return arrayList;
    }

    public static FontGroup lookup(int i2) {
        Map.Entry<Integer, Range> floorEntry = UCS_RANGES.floorEntry(Integer.valueOf(i2));
        Range value = floorEntry != null ? floorEntry.getValue() : null;
        return (value == null || i2 > value.upper) ? EAST_ASIAN : value.fontGroup;
    }
}
