package org.apache.poi.ddf;

import java.util.ArrayList;
import java.util.Collections;
import java.util.Comparator;
import java.util.Iterator;
import java.util.List;
import org.apache.poi.util.LittleEndian;

public abstract class AbstractEscherOptRecord extends EscherRecord {
    public List<EscherProperty> properties = new ArrayList();

    private int getPropertiesSize() {
        int i2 = 0;
        for (EscherProperty escherProperty : this.properties) {
            i2 += escherProperty.getPropertySize();
        }
        return i2;
    }

    public void addEscherProperty(EscherProperty escherProperty) {
        this.properties.add(escherProperty);
    }

    @Override // org.apache.poi.ddf.EscherRecord
    public int fillFields(byte[] bArr, int i2, EscherRecordFactory escherRecordFactory) {
        int readHeader = readHeader(bArr, i2);
        short readInstance = EscherRecord.readInstance(bArr, i2);
        this.properties = new EscherPropertyFactory().createProperties(bArr, i2 + 8, readInstance);
        return readHeader + 8;
    }

    @Override // org.apache.poi.ddf.EscherRecord
    public Object[][] getAttributeMap() {
        ArrayList arrayList = new ArrayList((this.properties.size() * 2) + 2);
        arrayList.add("properties");
        arrayList.add(Integer.valueOf(this.properties.size()));
        for (EscherProperty escherProperty : this.properties) {
            arrayList.add(escherProperty.getName());
            arrayList.add(escherProperty);
        }
        return new Object[][]{new Object[]{"isContainer", Boolean.valueOf(isContainerRecord())}, new Object[]{"numchildren", Integer.valueOf(getChildRecords().size())}, arrayList.toArray()};
    }

    public List<EscherProperty> getEscherProperties() {
        return this.properties;
    }

    public EscherProperty getEscherProperty(int i2) {
        return this.properties.get(i2);
    }

    @Override // org.apache.poi.ddf.EscherRecord
    public int getRecordSize() {
        return getPropertiesSize() + 8;
    }

    public <T extends EscherProperty> T lookup(int i2) {
        Iterator<EscherProperty> it = this.properties.iterator();
        while (it.hasNext()) {
            T t = (T) it.next();
            if (t.getPropertyNumber() == i2) {
                return t;
            }
        }
        return null;
    }

    public void removeEscherProperty(int i2) {
        Iterator<EscherProperty> it = getEscherProperties().iterator();
        while (it.hasNext()) {
            if (it.next().getPropertyNumber() == i2) {
                it.remove();
            }
        }
    }

    @Override // org.apache.poi.ddf.EscherRecord
    public int serialize(int i2, byte[] bArr, EscherSerializationListener escherSerializationListener) {
        escherSerializationListener.beforeRecordSerialize(i2, getRecordId(), this);
        LittleEndian.putShort(bArr, i2, getOptions());
        LittleEndian.putShort(bArr, i2 + 2, getRecordId());
        LittleEndian.putInt(bArr, i2 + 4, getPropertiesSize());
        int i3 = i2 + 8;
        for (EscherProperty escherProperty : this.properties) {
            i3 += escherProperty.serializeSimplePart(bArr, i3);
        }
        for (EscherProperty escherProperty2 : this.properties) {
            i3 += escherProperty2.serializeComplexPart(bArr, i3);
        }
        int i4 = i3 - i2;
        escherSerializationListener.afterRecordSerialize(i3, getRecordId(), i4, this);
        return i4;
    }

    public void setEscherProperty(EscherProperty escherProperty) {
        Iterator<EscherProperty> it = this.properties.iterator();
        while (it.hasNext()) {
            if (it.next().getId() == escherProperty.getId()) {
                it.remove();
            }
        }
        this.properties.add(escherProperty);
        sortProperties();
    }

    public void sortProperties() {
        Collections.sort(this.properties, new Comparator<EscherProperty>() {
            /* class org.apache.poi.ddf.AbstractEscherOptRecord.AnonymousClass1 */

            public int compare(EscherProperty escherProperty, EscherProperty escherProperty2) {
                short propertyNumber = escherProperty.getPropertyNumber();
                short propertyNumber2 = escherProperty2.getPropertyNumber();
                if (propertyNumber < propertyNumber2) {
                    return -1;
                }
                return propertyNumber == propertyNumber2 ? 0 : 1;
            }
        });
    }
}
