package org.apache.poi.ddf;

import java.lang.reflect.Constructor;
import java.util.HashMap;
import java.util.Map;
import org.apache.poi.util.LittleEndian;

public class DefaultEscherRecordFactory implements EscherRecordFactory {
    public static Class<?>[] escherRecordClasses;
    public static Map<Short, Constructor<? extends EscherRecord>> recordsMap;

    static {
        Class<?>[] clsArr = {EscherBSERecord.class, EscherOptRecord.class, EscherTertiaryOptRecord.class, EscherClientAnchorRecord.class, EscherDgRecord.class, EscherSpgrRecord.class, EscherSpRecord.class, EscherClientDataRecord.class, EscherDggRecord.class, EscherSplitMenuColorsRecord.class, EscherChildAnchorRecord.class, EscherTextboxRecord.class};
        escherRecordClasses = clsArr;
        recordsMap = recordsToMap(clsArr);
    }

    public static boolean isContainer(short s, short s2) {
        if (s2 < -4096 || s2 > -4091) {
            return s2 != -4083 && (s & 15) == 15;
        }
        return true;
    }

    public static Map<Short, Constructor<? extends EscherRecord>> recordsToMap(Class<?>[] clsArr) {
        HashMap hashMap = new HashMap();
        Class<?>[] clsArr2 = new Class[0];
        for (Class<?> cls : clsArr) {
            try {
                try {
                    hashMap.put(Short.valueOf(cls.getField("RECORD_ID").getShort(null)), cls.getConstructor(clsArr2));
                } catch (NoSuchMethodException e2) {
                    throw new RuntimeException(e2);
                }
            } catch (IllegalArgumentException e3) {
                throw new RuntimeException(e3);
            } catch (IllegalAccessException e4) {
                throw new RuntimeException(e4);
            } catch (NoSuchFieldException e5) {
                throw new RuntimeException(e5);
            }
        }
        return hashMap;
    }

    @Override // org.apache.poi.ddf.EscherRecordFactory
    public EscherRecord createRecord(byte[] bArr, int i2) {
        EscherRecord escherRecord;
        short s = LittleEndian.getShort(bArr, i2);
        short s2 = LittleEndian.getShort(bArr, i2 + 2);
        if (isContainer(s, s2)) {
            EscherContainerRecord escherContainerRecord = new EscherContainerRecord();
            escherContainerRecord.setRecordId(s2);
            escherContainerRecord.setOptions(s);
            return escherContainerRecord;
        } else if (s2 < -4072 || s2 > -3817) {
            Constructor<? extends EscherRecord> constructor = recordsMap.get(Short.valueOf(s2));
            if (constructor == null) {
                return new UnknownEscherRecord();
            }
            try {
                EscherRecord escherRecord2 = (EscherRecord) constructor.newInstance(new Object[0]);
                escherRecord2.setRecordId(s2);
                escherRecord2.setOptions(s);
                return escherRecord2;
            } catch (Exception unused) {
                return new UnknownEscherRecord();
            }
        } else {
            if (s2 == -4065 || s2 == -4067 || s2 == -4066) {
                escherRecord = new EscherBitmapBlip();
            } else if (s2 == -4070 || s2 == -4069 || s2 == -4068) {
                escherRecord = new EscherMetafileBlip();
            } else {
                escherRecord = new EscherBlipRecord();
            }
            escherRecord.setRecordId(s2);
            escherRecord.setOptions(s);
            return escherRecord;
        }
    }
}
