package org.apache.poi.ddf;

import b.b.a.a.a;
import java.util.Iterator;
import java.util.NoSuchElementException;
import org.apache.poi.ss.formula.ptg.GreaterThanPtg;
import org.apache.poi.ss.formula.ptg.LessThanPtg;
import org.apache.poi.util.HexDump;
import org.apache.poi.util.LittleEndian;

public final class EscherArrayProperty extends EscherComplexProperty implements Iterable<byte[]> {
    public static final int FIXED_SIZE = 6;
    public boolean emptyComplexPart;
    public boolean sizeIncludesHeaderSize = true;

    public EscherArrayProperty(short s, byte[] bArr) {
        super(s, checkComplexData(bArr));
        boolean z = true;
        if (!(bArr == null || bArr.length == 0)) {
            z = false;
        }
        this.emptyComplexPart = z;
    }

    public static byte[] checkComplexData(byte[] bArr) {
        return (bArr == null || bArr.length == 0) ? new byte[6] : bArr;
    }

    public static int getActualSizeOfElements(short s) {
        return s < 0 ? (short) ((-s) >> 2) : s;
    }

    public byte[] getElement(int i2) {
        int actualSizeOfElements = getActualSizeOfElements(getSizeOfElements());
        byte[] bArr = new byte[actualSizeOfElements];
        System.arraycopy(getComplexData(), (i2 * actualSizeOfElements) + 6, bArr, 0, actualSizeOfElements);
        return bArr;
    }

    public int getNumberOfElementsInArray() {
        if (this.emptyComplexPart) {
            return 0;
        }
        return LittleEndian.getUShort(getComplexData(), 0);
    }

    public int getNumberOfElementsInMemory() {
        if (this.emptyComplexPart) {
            return 0;
        }
        return LittleEndian.getUShort(getComplexData(), 2);
    }

    public short getSizeOfElements() {
        if (this.emptyComplexPart) {
            return 0;
        }
        return LittleEndian.getShort(getComplexData(), 4);
    }

    @Override // java.lang.Iterable
    public Iterator<byte[]> iterator() {
        return new Iterator<byte[]>() {
            /* class org.apache.poi.ddf.EscherArrayProperty.AnonymousClass1 */
            public int idx;

            public boolean hasNext() {
                return this.idx < EscherArrayProperty.this.getNumberOfElementsInArray();
            }

            public void remove() {
                throw new UnsupportedOperationException("not yet implemented");
            }

            @Override // java.util.Iterator
            public byte[] next() {
                if (hasNext()) {
                    EscherArrayProperty escherArrayProperty = EscherArrayProperty.this;
                    int i2 = this.idx;
                    this.idx = i2 + 1;
                    return escherArrayProperty.getElement(i2);
                }
                throw new NoSuchElementException();
            }
        };
    }

    @Override // org.apache.poi.ddf.EscherProperty, org.apache.poi.ddf.EscherComplexProperty
    public int serializeSimplePart(byte[] bArr, int i2) {
        LittleEndian.putShort(bArr, i2, getId());
        int length = getComplexData().length;
        if (!this.sizeIncludesHeaderSize) {
            length -= 6;
        }
        LittleEndian.putInt(bArr, i2 + 2, length);
        return 6;
    }

    public int setArrayData(byte[] bArr, int i2) {
        if (this.emptyComplexPart) {
            setComplexData(new byte[0]);
        } else {
            int actualSizeOfElements = getActualSizeOfElements(LittleEndian.getShort(bArr, i2 + 4)) * LittleEndian.getShort(bArr, i2);
            if (actualSizeOfElements == getComplexData().length) {
                setComplexData(new byte[(actualSizeOfElements + 6)]);
                this.sizeIncludesHeaderSize = false;
            }
            System.arraycopy(bArr, i2, getComplexData(), 0, getComplexData().length);
        }
        return getComplexData().length;
    }

    public void setElement(int i2, byte[] bArr) {
        int actualSizeOfElements = getActualSizeOfElements(getSizeOfElements());
        System.arraycopy(bArr, 0, getComplexData(), (i2 * actualSizeOfElements) + 6, actualSizeOfElements);
    }

    public void setNumberOfElementsInArray(int i2) {
        int actualSizeOfElements = (getActualSizeOfElements(getSizeOfElements()) * i2) + 6;
        if (actualSizeOfElements != getComplexData().length) {
            byte[] bArr = new byte[actualSizeOfElements];
            System.arraycopy(getComplexData(), 0, bArr, 0, getComplexData().length);
            setComplexData(bArr);
        }
        LittleEndian.putShort(getComplexData(), 0, (short) i2);
    }

    public void setNumberOfElementsInMemory(int i2) {
        int actualSizeOfElements = (getActualSizeOfElements(getSizeOfElements()) * i2) + 6;
        if (actualSizeOfElements != getComplexData().length) {
            byte[] bArr = new byte[actualSizeOfElements];
            System.arraycopy(getComplexData(), 0, bArr, 0, actualSizeOfElements);
            setComplexData(bArr);
        }
        LittleEndian.putShort(getComplexData(), 2, (short) i2);
    }

    public void setSizeOfElements(int i2) {
        LittleEndian.putShort(getComplexData(), 4, (short) i2);
        int actualSizeOfElements = (getActualSizeOfElements(getSizeOfElements()) * getNumberOfElementsInArray()) + 6;
        if (actualSizeOfElements != getComplexData().length) {
            byte[] bArr = new byte[actualSizeOfElements];
            System.arraycopy(getComplexData(), 0, bArr, 0, 6);
            setComplexData(bArr);
        }
    }

    @Override // org.apache.poi.ddf.EscherProperty, org.apache.poi.ddf.EscherComplexProperty
    public String toString() {
        StringBuilder b2 = a.b("propNum: ");
        b2.append((int) getPropertyNumber());
        b2.append(", propName: ");
        b2.append(EscherProperties.getPropertyName(getPropertyNumber()));
        b2.append(", complex: ");
        b2.append(isComplex());
        b2.append(", blipId: ");
        b2.append(isBlipId());
        b2.append(", data: \n");
        b2.append("    {EscherArrayProperty:\n");
        b2.append("     Num Elements: ");
        b2.append(getNumberOfElementsInArray());
        b2.append('\n');
        b2.append("     Num Elements In Memory: ");
        b2.append(getNumberOfElementsInMemory());
        b2.append('\n');
        b2.append("     Size of elements: ");
        b2.append((int) getSizeOfElements());
        b2.append('\n');
        for (int i2 = 0; i2 < getNumberOfElementsInArray(); i2++) {
            b2.append("     Element ");
            b2.append(i2);
            b2.append(": ");
            b2.append(HexDump.toHex(getElement(i2)));
            b2.append('\n');
        }
        b2.append("}\n");
        return b2.toString();
    }

    @Override // org.apache.poi.ddf.EscherProperty, org.apache.poi.ddf.EscherComplexProperty
    public String toXml(String str) {
        StringBuilder d2 = a.d(str, LessThanPtg.LESSTHAN);
        d2.append(EscherArrayProperty.class.getSimpleName());
        d2.append(" id=\"0x");
        d2.append(HexDump.toHex(getId()));
        d2.append("\" name=\"");
        d2.append(getName());
        d2.append("\" blipId=\"");
        d2.append(isBlipId());
        d2.append("\">\n");
        for (int i2 = 0; i2 < getNumberOfElementsInArray(); i2++) {
            d2.append("\t");
            d2.append(str);
            d2.append("<Element>");
            d2.append(HexDump.toHex(getElement(i2)));
            d2.append("</Element>\n");
        }
        d2.append(str);
        d2.append("</");
        d2.append(EscherArrayProperty.class.getSimpleName());
        d2.append(GreaterThanPtg.GREATERTHAN);
        return d2.toString();
    }

    public EscherArrayProperty(short s, boolean z, byte[] bArr) {
        super(s, z, checkComplexData(bArr));
    }
}
