package org.apache.poi.ddf;

import org.apache.poi.sl.image.ImageHeaderEMF;
import org.apache.poi.util.LittleEndian;
import org.apache.xerces.impl.xs.SchemaSymbols;

public final class EscherBSERecord extends EscherRecord {
    public static final byte BT_DIB = 7;
    public static final byte BT_EMF = 2;
    public static final byte BT_ERROR = 0;
    public static final byte BT_JPEG = 5;
    public static final byte BT_PICT = 4;
    public static final byte BT_PNG = 6;
    public static final byte BT_UNKNOWN = 1;
    public static final byte BT_WMF = 3;
    public static final String RECORD_DESCRIPTION = "MsofbtBSE";
    public static final short RECORD_ID = -4089;
    public byte[] _remainingData = new byte[0];
    public byte field_10_unused2;
    public byte field_11_unused3;
    public EscherBlipRecord field_12_blipRecord;
    public byte field_1_blipTypeWin32;
    public byte field_2_blipTypeMacOS;
    public final byte[] field_3_uid = new byte[16];
    public short field_4_tag;
    public int field_5_size;
    public int field_6_ref;
    public int field_7_offset;
    public byte field_8_usage;
    public byte field_9_name;

    public EscherBSERecord() {
        setRecordId(RECORD_ID);
    }

    public static String getBlipType(byte b2) {
        switch (b2) {
            case 0:
                return " ERROR";
            case 1:
                return " UNKNOWN";
            case 2:
                return ImageHeaderEMF.EMF_SIGNATURE;
            case 3:
                return " WMF";
            case 4:
                return " PICT";
            case 5:
                return " JPEG";
            case 6:
                return " PNG";
            case 7:
                return " DIB";
            default:
                return b2 < 32 ? " NotKnown" : " Client";
        }
    }

    @Override // org.apache.poi.ddf.EscherRecord
    public int fillFields(byte[] bArr, int i2, EscherRecordFactory escherRecordFactory) {
        int i3;
        int readHeader = readHeader(bArr, i2);
        int i4 = i2 + 8;
        this.field_1_blipTypeWin32 = bArr[i4];
        this.field_2_blipTypeMacOS = bArr[i4 + 1];
        int i5 = 0;
        System.arraycopy(bArr, i4 + 2, this.field_3_uid, 0, 16);
        this.field_4_tag = LittleEndian.getShort(bArr, i4 + 18);
        this.field_5_size = LittleEndian.getInt(bArr, i4 + 20);
        this.field_6_ref = LittleEndian.getInt(bArr, i4 + 24);
        this.field_7_offset = LittleEndian.getInt(bArr, i4 + 28);
        this.field_8_usage = bArr[i4 + 32];
        this.field_9_name = bArr[i4 + 33];
        this.field_10_unused2 = bArr[i4 + 34];
        this.field_11_unused3 = bArr[i4 + 35];
        int i6 = readHeader - 36;
        if (i6 > 0) {
            int i7 = i4 + 36;
            EscherBlipRecord escherBlipRecord = (EscherBlipRecord) escherRecordFactory.createRecord(bArr, i7);
            this.field_12_blipRecord = escherBlipRecord;
            i3 = escherBlipRecord.fillFields(bArr, i7, escherRecordFactory);
        } else {
            i3 = 0;
        }
        int i8 = i3 + 36 + i4;
        int i9 = i6 - i3;
        byte[] bArr2 = new byte[i9];
        this._remainingData = bArr2;
        System.arraycopy(bArr, i8, bArr2, 0, i9);
        int i10 = i9 + 8 + 36;
        EscherBlipRecord escherBlipRecord2 = this.field_12_blipRecord;
        if (escherBlipRecord2 != null) {
            i5 = escherBlipRecord2.getRecordSize();
        }
        return i10 + i5;
    }

    @Override // org.apache.poi.ddf.EscherRecord
    public Object[][] getAttributeMap() {
        return new Object[][]{new Object[]{"BlipTypeWin32", Byte.valueOf(this.field_1_blipTypeWin32)}, new Object[]{"BlipTypeMacOS", Byte.valueOf(this.field_2_blipTypeMacOS)}, new Object[]{"SUID", this.field_3_uid}, new Object[]{"Tag", Short.valueOf(this.field_4_tag)}, new Object[]{"Size", Integer.valueOf(this.field_5_size)}, new Object[]{"Ref", Integer.valueOf(this.field_6_ref)}, new Object[]{"Offset", Integer.valueOf(this.field_7_offset)}, new Object[]{"Usage", Byte.valueOf(this.field_8_usage)}, new Object[]{SchemaSymbols.ATTVAL_NAME, Byte.valueOf(this.field_9_name)}, new Object[]{"Unused2", Byte.valueOf(this.field_10_unused2)}, new Object[]{"Unused3", Byte.valueOf(this.field_11_unused3)}, new Object[]{"Blip Record", this.field_12_blipRecord}, new Object[]{"Extra Data", this._remainingData}};
    }

    public EscherBlipRecord getBlipRecord() {
        return this.field_12_blipRecord;
    }

    public byte getBlipTypeMacOS() {
        return this.field_2_blipTypeMacOS;
    }

    public byte getBlipTypeWin32() {
        return this.field_1_blipTypeWin32;
    }

    public byte getName() {
        return this.field_9_name;
    }

    public int getOffset() {
        return this.field_7_offset;
    }

    @Override // org.apache.poi.ddf.EscherRecord
    public String getRecordName() {
        return "BSE";
    }

    @Override // org.apache.poi.ddf.EscherRecord
    public int getRecordSize() {
        EscherBlipRecord escherBlipRecord = this.field_12_blipRecord;
        int i2 = 0;
        int recordSize = escherBlipRecord != null ? escherBlipRecord.getRecordSize() : 0;
        byte[] bArr = this._remainingData;
        if (bArr != null) {
            i2 = bArr.length;
        }
        return recordSize + 44 + i2;
    }

    public int getRef() {
        return this.field_6_ref;
    }

    public byte[] getRemainingData() {
        return this._remainingData;
    }

    public int getSize() {
        return this.field_5_size;
    }

    public short getTag() {
        return this.field_4_tag;
    }

    public byte[] getUid() {
        return this.field_3_uid;
    }

    public byte getUnused2() {
        return this.field_10_unused2;
    }

    public byte getUnused3() {
        return this.field_11_unused3;
    }

    public byte getUsage() {
        return this.field_8_usage;
    }

    @Override // org.apache.poi.ddf.EscherRecord
    public int serialize(int i2, byte[] bArr, EscherSerializationListener escherSerializationListener) {
        escherSerializationListener.beforeRecordSerialize(i2, getRecordId(), this);
        if (this._remainingData == null) {
            this._remainingData = new byte[0];
        }
        LittleEndian.putShort(bArr, i2, getOptions());
        LittleEndian.putShort(bArr, i2 + 2, getRecordId());
        EscherBlipRecord escherBlipRecord = this.field_12_blipRecord;
        LittleEndian.putInt(bArr, i2 + 4, this._remainingData.length + 36 + (escherBlipRecord == null ? 0 : escherBlipRecord.getRecordSize()));
        int i3 = i2 + 8;
        bArr[i3] = this.field_1_blipTypeWin32;
        bArr[i2 + 9] = this.field_2_blipTypeMacOS;
        System.arraycopy(this.field_3_uid, 0, bArr, i2 + 10, 16);
        LittleEndian.putShort(bArr, i2 + 26, this.field_4_tag);
        LittleEndian.putInt(bArr, i2 + 28, this.field_5_size);
        LittleEndian.putInt(bArr, i2 + 32, this.field_6_ref);
        LittleEndian.putInt(bArr, i2 + 36, this.field_7_offset);
        bArr[i2 + 40] = this.field_8_usage;
        bArr[i2 + 41] = this.field_9_name;
        bArr[i2 + 42] = this.field_10_unused2;
        bArr[i2 + 43] = this.field_11_unused3;
        EscherBlipRecord escherBlipRecord2 = this.field_12_blipRecord;
        int serialize = escherBlipRecord2 != null ? escherBlipRecord2.serialize(i2 + 44, bArr, new NullEscherSerializationListener()) : 0;
        byte[] bArr2 = this._remainingData;
        System.arraycopy(bArr2, 0, bArr, i2 + 44 + serialize, bArr2.length);
        int length = i3 + 36 + this._remainingData.length + serialize;
        int i4 = length - i2;
        escherSerializationListener.afterRecordSerialize(length, getRecordId(), i4, this);
        return i4;
    }

    public void setBlipRecord(EscherBlipRecord escherBlipRecord) {
        this.field_12_blipRecord = escherBlipRecord;
    }

    public void setBlipTypeMacOS(byte b2) {
        this.field_2_blipTypeMacOS = b2;
    }

    public void setBlipTypeWin32(byte b2) {
        this.field_1_blipTypeWin32 = b2;
    }

    public void setName(byte b2) {
        this.field_9_name = b2;
    }

    public void setOffset(int i2) {
        this.field_7_offset = i2;
    }

    public void setRef(int i2) {
        this.field_6_ref = i2;
    }

    public void setRemainingData(byte[] bArr) {
        this._remainingData = bArr == null ? new byte[0] : (byte[]) bArr.clone();
    }

    public void setSize(int i2) {
        this.field_5_size = i2;
    }

    public void setTag(short s) {
        this.field_4_tag = s;
    }

    public void setUid(byte[] bArr) {
        if (bArr == null || bArr.length != 16) {
            throw new IllegalArgumentException("uid must be byte[16]");
        }
        byte[] bArr2 = this.field_3_uid;
        System.arraycopy(bArr, 0, bArr2, 0, bArr2.length);
    }

    public void setUnused2(byte b2) {
        this.field_10_unused2 = b2;
    }

    public void setUnused3(byte b2) {
        this.field_11_unused3 = b2;
    }

    public void setUsage(byte b2) {
        this.field_8_usage = b2;
    }
}
