package org.apache.poi.ddf;

import org.apache.poi.util.LittleEndian;

public class EscherChildAnchorRecord extends EscherRecord {
    public static final String RECORD_DESCRIPTION = "MsofbtChildAnchor";
    public static final short RECORD_ID = -4081;
    public int field_1_dx1;
    public int field_2_dy1;
    public int field_3_dx2;
    public int field_4_dy2;

    @Override // org.apache.poi.ddf.EscherRecord
    public int fillFields(byte[] bArr, int i2, EscherRecordFactory escherRecordFactory) {
        int readHeader = readHeader(bArr, i2);
        int i3 = i2 + 8;
        int i4 = 16;
        if (readHeader == 8) {
            this.field_1_dx1 = LittleEndian.getShort(bArr, i3 + 0);
            this.field_2_dy1 = LittleEndian.getShort(bArr, i3 + 2);
            this.field_3_dx2 = LittleEndian.getShort(bArr, i3 + 4);
            this.field_4_dy2 = LittleEndian.getShort(bArr, i3 + 6);
            i4 = 8;
        } else if (readHeader == 16) {
            this.field_1_dx1 = LittleEndian.getInt(bArr, i3 + 0);
            this.field_2_dy1 = LittleEndian.getInt(bArr, i3 + 4);
            this.field_3_dx2 = LittleEndian.getInt(bArr, i3 + 8);
            this.field_4_dy2 = LittleEndian.getInt(bArr, i3 + 12);
        } else {
            throw new RuntimeException("Invalid EscherChildAnchorRecord - neither 8 nor 16 bytes.");
        }
        return i4 + 8;
    }

    @Override // org.apache.poi.ddf.EscherRecord
    public Object[][] getAttributeMap() {
        return new Object[][]{new Object[]{"X1", Integer.valueOf(this.field_1_dx1)}, new Object[]{"Y1", Integer.valueOf(this.field_2_dy1)}, new Object[]{"X2", Integer.valueOf(this.field_3_dx2)}, new Object[]{"Y2", Integer.valueOf(this.field_4_dy2)}};
    }

    public int getDx1() {
        return this.field_1_dx1;
    }

    public int getDx2() {
        return this.field_3_dx2;
    }

    public int getDy1() {
        return this.field_2_dy1;
    }

    public int getDy2() {
        return this.field_4_dy2;
    }

    @Override // org.apache.poi.ddf.EscherRecord
    public short getRecordId() {
        return RECORD_ID;
    }

    @Override // org.apache.poi.ddf.EscherRecord
    public String getRecordName() {
        return "ChildAnchor";
    }

    @Override // org.apache.poi.ddf.EscherRecord
    public int getRecordSize() {
        return 24;
    }

    @Override // org.apache.poi.ddf.EscherRecord
    public int serialize(int i2, byte[] bArr, EscherSerializationListener escherSerializationListener) {
        escherSerializationListener.beforeRecordSerialize(i2, getRecordId(), this);
        LittleEndian.putShort(bArr, i2, getOptions());
        int i3 = i2 + 2;
        LittleEndian.putShort(bArr, i3, getRecordId());
        int i4 = i3 + 2;
        LittleEndian.putInt(bArr, i4, getRecordSize() - 8);
        int i5 = i4 + 4;
        LittleEndian.putInt(bArr, i5, this.field_1_dx1);
        int i6 = i5 + 4;
        LittleEndian.putInt(bArr, i6, this.field_2_dy1);
        int i7 = i6 + 4;
        LittleEndian.putInt(bArr, i7, this.field_3_dx2);
        int i8 = i7 + 4;
        LittleEndian.putInt(bArr, i8, this.field_4_dy2);
        int i9 = i8 + 4;
        int i10 = i9 - i2;
        escherSerializationListener.afterRecordSerialize(i9, getRecordId(), i10, this);
        return i10;
    }

    public void setDx1(int i2) {
        this.field_1_dx1 = i2;
    }

    public void setDx2(int i2) {
        this.field_3_dx2 = i2;
    }

    public void setDy1(int i2) {
        this.field_2_dy1 = i2;
    }

    public void setDy2(int i2) {
        this.field_4_dy2 = i2;
    }
}
