package org.apache.poi.ddf;

import org.apache.poi.util.BitField;
import org.apache.poi.util.LittleEndian;

public class EscherColorRef {
    public static final /* synthetic */ boolean $assertionsDisabled = false;
    public static final BitField FLAG_BLUE = new BitField(16711680);
    public static final BitField FLAG_GREEN = new BitField(65280);
    public static final BitField FLAG_PALETTE_INDEX = new BitField(16777216);
    public static final BitField FLAG_PALETTE_RGB = new BitField(33554432);
    public static final BitField FLAG_RED = new BitField(255);
    public static final BitField FLAG_SCHEME_INDEX = new BitField(134217728);
    public static final BitField FLAG_SYSTEM_RGB = new BitField(67108864);
    public static final BitField FLAG_SYS_INDEX = new BitField(268435456);
    public int colorRef = 0;
    public int opid = -1;

    public enum SysIndexProcedure {
        DARKEN_COLOR(1),
        LIGHTEN_COLOR(2),
        ADD_GRAY_LEVEL(3),
        SUB_GRAY_LEVEL(4),
        REVERSE_GRAY_LEVEL(5),
        THRESHOLD(6),
        INVERT_AFTER(32),
        INVERT_HIGHBIT_AFTER(64);
        
        public BitField mask;

        /* access modifiers changed from: public */
        SysIndexProcedure(int i2) {
            this.mask = new BitField(i2);
        }
    }

    public enum SysIndexSource {
        FILL_COLOR(240),
        LINE_OR_FILL_COLOR(241),
        LINE_COLOR(242),
        SHADOW_COLOR(243),
        CURRENT_OR_LAST_COLOR(244),
        FILL_BACKGROUND_COLOR(245),
        LINE_BACKGROUND_COLOR(246),
        FILL_OR_LINE_COLOR(247);
        
        public int value;

        /* access modifiers changed from: public */
        SysIndexSource(int i2) {
            this.value = i2;
        }
    }

    public EscherColorRef(int i2) {
        this.colorRef = i2;
    }

    private int getIndex() {
        return (FLAG_GREEN.getValue(this.colorRef) << 8) | FLAG_RED.getValue(this.colorRef);
    }

    public int getPaletteIndex() {
        if (hasPaletteIndexFlag()) {
            return getIndex();
        }
        return -1;
    }

    public int[] getRGB() {
        return new int[]{FLAG_RED.getValue(this.colorRef), FLAG_GREEN.getValue(this.colorRef), FLAG_BLUE.getValue(this.colorRef)};
    }

    public int getSchemeIndex() {
        if (!hasSchemeIndexFlag()) {
            return -1;
        }
        return FLAG_RED.getValue(this.colorRef);
    }

    public int getSysIndex() {
        if (hasSysIndexFlag()) {
            return getIndex();
        }
        return -1;
    }

    public int getSysIndexInvert() {
        if (!hasSysIndexFlag()) {
            return 0;
        }
        int value = FLAG_GREEN.getValue(this.colorRef);
        if (SysIndexProcedure.INVERT_AFTER.mask.isSet(value)) {
            return 1;
        }
        if (SysIndexProcedure.INVERT_HIGHBIT_AFTER.mask.isSet(value)) {
            return 2;
        }
        return 0;
    }

    public SysIndexProcedure getSysIndexProcedure() {
        if (!hasSysIndexFlag()) {
            return null;
        }
        int value = FLAG_GREEN.getValue(this.colorRef);
        SysIndexProcedure[] values = SysIndexProcedure.values();
        for (SysIndexProcedure sysIndexProcedure : values) {
            if (!(sysIndexProcedure == SysIndexProcedure.INVERT_AFTER || sysIndexProcedure == SysIndexProcedure.INVERT_HIGHBIT_AFTER || !sysIndexProcedure.mask.isSet(value))) {
                return sysIndexProcedure;
            }
        }
        return null;
    }

    public SysIndexSource getSysIndexSource() {
        if (!hasSysIndexFlag()) {
            return null;
        }
        int value = FLAG_RED.getValue(this.colorRef);
        SysIndexSource[] values = SysIndexSource.values();
        for (SysIndexSource sysIndexSource : values) {
            if (sysIndexSource.value == value) {
                return sysIndexSource;
            }
        }
        return null;
    }

    public boolean hasPaletteIndexFlag() {
        return FLAG_PALETTE_INDEX.isSet(this.colorRef);
    }

    public boolean hasPaletteRGBFlag() {
        return FLAG_PALETTE_RGB.isSet(this.colorRef);
    }

    public boolean hasSchemeIndexFlag() {
        return FLAG_SCHEME_INDEX.isSet(this.colorRef);
    }

    public boolean hasSysIndexFlag() {
        return FLAG_SYS_INDEX.isSet(this.colorRef);
    }

    public boolean hasSystemRGBFlag() {
        return FLAG_SYSTEM_RGB.isSet(this.colorRef);
    }

    public void setPaletteIndexFlag(boolean z) {
        this.colorRef = FLAG_PALETTE_INDEX.setBoolean(this.colorRef, z);
    }

    public void setPaletteRGBFlag(boolean z) {
        this.colorRef = FLAG_PALETTE_RGB.setBoolean(this.colorRef, z);
    }

    public void setSchemeIndexFlag(boolean z) {
        this.colorRef = FLAG_SCHEME_INDEX.setBoolean(this.colorRef, z);
    }

    public void setSysIndexFlag(boolean z) {
        this.colorRef = FLAG_SYS_INDEX.setBoolean(this.colorRef, z);
    }

    public void setSystemRGBFlag(boolean z) {
        this.colorRef = FLAG_SYSTEM_RGB.setBoolean(this.colorRef, z);
    }

    public EscherColorRef(byte[] bArr, int i2, int i3) {
        if (i3 == 6) {
            this.opid = LittleEndian.getUShort(bArr, i2);
            i2 += 2;
        }
        this.colorRef = LittleEndian.getInt(bArr, i2);
    }
}
