package org.apache.poi.ddf;

import b.b.a.a.a;
import java.util.Arrays;
import org.apache.poi.ss.formula.ptg.GreaterThanPtg;
import org.apache.poi.ss.formula.ptg.LessThanPtg;
import org.apache.poi.util.HexDump;
import org.apache.poi.util.LittleEndian;

public class EscherComplexProperty extends EscherProperty {
    public byte[] _complexData;

    public EscherComplexProperty(short s, byte[] bArr) {
        super(s);
        if (bArr != null) {
            this._complexData = (byte[]) bArr.clone();
            return;
        }
        throw new IllegalArgumentException("complexData can't be null");
    }

    public boolean equals(Object obj) {
        if (this == obj) {
            return true;
        }
        if (obj == null || !(obj instanceof EscherComplexProperty)) {
            return false;
        }
        return Arrays.equals(this._complexData, ((EscherComplexProperty) obj)._complexData);
    }

    public byte[] getComplexData() {
        return this._complexData;
    }

    @Override // org.apache.poi.ddf.EscherProperty
    public int getPropertySize() {
        return this._complexData.length + 6;
    }

    public int hashCode() {
        return getId() * 11;
    }

    @Override // org.apache.poi.ddf.EscherProperty
    public int serializeComplexPart(byte[] bArr, int i2) {
        byte[] bArr2 = this._complexData;
        System.arraycopy(bArr2, 0, bArr, i2, bArr2.length);
        return this._complexData.length;
    }

    @Override // org.apache.poi.ddf.EscherProperty
    public int serializeSimplePart(byte[] bArr, int i2) {
        LittleEndian.putShort(bArr, i2, getId());
        LittleEndian.putInt(bArr, i2 + 2, this._complexData.length);
        return 6;
    }

    public void setComplexData(byte[] bArr) {
        this._complexData = bArr;
    }

    @Override // org.apache.poi.ddf.EscherProperty
    public String toString() {
        String hex = HexDump.toHex(this._complexData, 32);
        StringBuilder b2 = a.b("propNum: ");
        b2.append((int) getPropertyNumber());
        b2.append(", propName: ");
        b2.append(EscherProperties.getPropertyName(getPropertyNumber()));
        b2.append(", complex: ");
        b2.append(isComplex());
        b2.append(", blipId: ");
        b2.append(isBlipId());
        b2.append(", data: ");
        b2.append(System.getProperty("line.separator"));
        b2.append(hex);
        return b2.toString();
    }

    @Override // org.apache.poi.ddf.EscherProperty
    public String toXml(String str) {
        StringBuilder d2 = a.d(str, LessThanPtg.LESSTHAN);
        d2.append(getClass().getSimpleName());
        d2.append(" id=\"0x");
        d2.append(HexDump.toHex(getId()));
        d2.append("\" name=\"");
        d2.append(getName());
        d2.append("\" blipId=\"");
        d2.append(isBlipId());
        d2.append("\">\n");
        d2.append(str);
        d2.append("</");
        d2.append(getClass().getSimpleName());
        d2.append(GreaterThanPtg.GREATERTHAN);
        return d2.toString();
    }

    public EscherComplexProperty(short s, boolean z, byte[] bArr) {
        super(s, true, z);
        if (bArr != null) {
            this._complexData = (byte[]) bArr.clone();
            return;
        }
        throw new IllegalArgumentException("complexData can't be null");
    }
}
