package org.apache.poi.ddf;

import org.apache.poi.util.LittleEndian;

public class EscherDgRecord extends EscherRecord {
    public static final String RECORD_DESCRIPTION = "MsofbtDg";
    public static final short RECORD_ID = -4088;
    public int field_1_numShapes;
    public int field_2_lastMSOSPID;

    @Override // org.apache.poi.ddf.EscherRecord
    public int fillFields(byte[] bArr, int i2, EscherRecordFactory escherRecordFactory) {
        readHeader(bArr, i2);
        int i3 = i2 + 8;
        this.field_1_numShapes = LittleEndian.getInt(bArr, i3 + 0);
        this.field_2_lastMSOSPID = LittleEndian.getInt(bArr, i3 + 4);
        return getRecordSize();
    }

    @Override // org.apache.poi.ddf.EscherRecord
    public Object[][] getAttributeMap() {
        return new Object[][]{new Object[]{"NumShapes", Integer.valueOf(this.field_1_numShapes)}, new Object[]{"LastMSOSPID", Integer.valueOf(this.field_2_lastMSOSPID)}};
    }

    public short getDrawingGroupId() {
        return (short) (getOptions() >> 4);
    }

    public int getLastMSOSPID() {
        return this.field_2_lastMSOSPID;
    }

    public int getNumShapes() {
        return this.field_1_numShapes;
    }

    @Override // org.apache.poi.ddf.EscherRecord
    public short getRecordId() {
        return RECORD_ID;
    }

    @Override // org.apache.poi.ddf.EscherRecord
    public String getRecordName() {
        return "Dg";
    }

    @Override // org.apache.poi.ddf.EscherRecord
    public int getRecordSize() {
        return 16;
    }

    public void incrementShapeCount() {
        this.field_1_numShapes++;
    }

    @Override // org.apache.poi.ddf.EscherRecord
    public int serialize(int i2, byte[] bArr, EscherSerializationListener escherSerializationListener) {
        escherSerializationListener.beforeRecordSerialize(i2, getRecordId(), this);
        LittleEndian.putShort(bArr, i2, getOptions());
        LittleEndian.putShort(bArr, i2 + 2, getRecordId());
        LittleEndian.putInt(bArr, i2 + 4, 8);
        LittleEndian.putInt(bArr, i2 + 8, this.field_1_numShapes);
        LittleEndian.putInt(bArr, i2 + 12, this.field_2_lastMSOSPID);
        escherSerializationListener.afterRecordSerialize(i2 + 16, getRecordId(), getRecordSize(), this);
        return getRecordSize();
    }

    public void setLastMSOSPID(int i2) {
        this.field_2_lastMSOSPID = i2;
    }

    public void setNumShapes(int i2) {
        this.field_1_numShapes = i2;
    }
}
