package org.apache.poi.ddf;

import b.b.a.a.a;
import java.util.ArrayList;
import java.util.Arrays;
import java.util.BitSet;
import java.util.Collections;
import java.util.Comparator;
import java.util.Iterator;
import java.util.List;
import org.apache.poi.util.LittleEndian;
import org.apache.poi.util.RecordFormatException;

public final class EscherDggRecord extends EscherRecord {
    public static final String RECORD_DESCRIPTION = "MsofbtDgg";
    public static final short RECORD_ID = -4090;
    public int field_1_shapeIdMax;
    public int field_3_numShapesSaved;
    public int field_4_drawingsSaved;
    public final List<FileIdCluster> field_5_fileIdClusters = new ArrayList();
    public int maxDgId;

    public static class FileIdCluster {
        public int field_1_drawingGroupId;
        public int field_2_numShapeIdsUsed;

        public FileIdCluster(int i2, int i3) {
            this.field_1_drawingGroupId = i2;
            this.field_2_numShapeIdsUsed = i3;
        }

        /* access modifiers changed from: private */
        /* access modifiers changed from: public */
        private void incrementUsedShapeId() {
            this.field_2_numShapeIdsUsed++;
        }

        public int getDrawingGroupId() {
            return this.field_1_drawingGroupId;
        }

        public int getNumShapeIdsUsed() {
            return this.field_2_numShapeIdsUsed;
        }
    }

    private void sortCluster() {
        Collections.sort(this.field_5_fileIdClusters, new Comparator<FileIdCluster>() {
            /* class org.apache.poi.ddf.EscherDggRecord.AnonymousClass1 */

            public int compare(FileIdCluster fileIdCluster, FileIdCluster fileIdCluster2) {
                int drawingGroupId = fileIdCluster.getDrawingGroupId() - fileIdCluster2.getDrawingGroupId();
                return drawingGroupId != 0 ? drawingGroupId : fileIdCluster2.getNumShapeIdsUsed() - fileIdCluster.getNumShapeIdsUsed();
            }
        });
    }

    public FileIdCluster addCluster(int i2, int i3) {
        return addCluster(i2, i3, true);
    }

    public int allocateShapeId(EscherDgRecord escherDgRecord, boolean z) {
        FileIdCluster fileIdCluster;
        short drawingGroupId = escherDgRecord.getDrawingGroupId();
        this.field_3_numShapesSaved++;
        Iterator<FileIdCluster> it = this.field_5_fileIdClusters.iterator();
        int i2 = 1;
        while (true) {
            if (!it.hasNext()) {
                fileIdCluster = null;
                break;
            }
            fileIdCluster = it.next();
            if (fileIdCluster.getDrawingGroupId() == drawingGroupId && fileIdCluster.getNumShapeIdsUsed() < 1024) {
                break;
            }
            i2++;
        }
        if (fileIdCluster == null) {
            fileIdCluster = addCluster(drawingGroupId, 0, z);
            this.maxDgId = Math.max(this.maxDgId, (int) drawingGroupId);
        }
        int numShapeIdsUsed = fileIdCluster.getNumShapeIdsUsed() + (i2 * 1024);
        fileIdCluster.incrementUsedShapeId();
        escherDgRecord.setNumShapes(escherDgRecord.getNumShapes() + 1);
        escherDgRecord.setLastMSOSPID(numShapeIdsUsed);
        this.field_1_shapeIdMax = Math.max(this.field_1_shapeIdMax, numShapeIdsUsed + 1);
        return numShapeIdsUsed;
    }

    @Override // org.apache.poi.ddf.EscherRecord
    public int fillFields(byte[] bArr, int i2, EscherRecordFactory escherRecordFactory) {
        int readHeader = readHeader(bArr, i2);
        int i3 = i2 + 8;
        this.field_1_shapeIdMax = LittleEndian.getInt(bArr, i3 + 0);
        this.field_3_numShapesSaved = LittleEndian.getInt(bArr, i3 + 8);
        this.field_4_drawingsSaved = LittleEndian.getInt(bArr, i3 + 12);
        this.field_5_fileIdClusters.clear();
        int i4 = (readHeader - 16) / 8;
        int i5 = 16;
        for (int i6 = 0; i6 < i4; i6++) {
            int i7 = i3 + i5;
            int i8 = LittleEndian.getInt(bArr, i7);
            this.field_5_fileIdClusters.add(new FileIdCluster(i8, LittleEndian.getInt(bArr, i7 + 4)));
            this.maxDgId = Math.max(this.maxDgId, i8);
            i5 += 8;
        }
        int i9 = readHeader - i5;
        if (i9 == 0) {
            return i5 + 8;
        }
        throw new RecordFormatException(a.b("Expecting no remaining data but got ", i9, " byte(s)."));
    }

    public short findNewDrawingGroupId() {
        BitSet bitSet = new BitSet();
        bitSet.set(0);
        for (FileIdCluster fileIdCluster : this.field_5_fileIdClusters) {
            bitSet.set(fileIdCluster.getDrawingGroupId());
        }
        return (short) bitSet.nextClearBit(0);
    }

    @Override // org.apache.poi.ddf.EscherRecord
    public Object[][] getAttributeMap() {
        ArrayList arrayList = new ArrayList();
        arrayList.add("FileId Clusters");
        arrayList.add(Integer.valueOf(this.field_5_fileIdClusters.size()));
        for (FileIdCluster fileIdCluster : this.field_5_fileIdClusters) {
            StringBuilder b2 = a.b("Group");
            b2.append(fileIdCluster.field_1_drawingGroupId);
            arrayList.add(b2.toString());
            arrayList.add(Integer.valueOf(fileIdCluster.field_2_numShapeIdsUsed));
        }
        return new Object[][]{new Object[]{"ShapeIdMax", Integer.valueOf(this.field_1_shapeIdMax)}, new Object[]{"NumIdClusters", Integer.valueOf(getNumIdClusters())}, new Object[]{"NumShapesSaved", Integer.valueOf(this.field_3_numShapesSaved)}, new Object[]{"DrawingsSaved", Integer.valueOf(this.field_4_drawingsSaved)}, arrayList.toArray()};
    }

    public int getDrawingsSaved() {
        return this.field_4_drawingsSaved;
    }

    public FileIdCluster[] getFileIdClusters() {
        List<FileIdCluster> list = this.field_5_fileIdClusters;
        return (FileIdCluster[]) list.toArray(new FileIdCluster[list.size()]);
    }

    public int getMaxDrawingGroupId() {
        return this.maxDgId;
    }

    public int getNumIdClusters() {
        if (this.field_5_fileIdClusters.isEmpty()) {
            return 0;
        }
        return this.field_5_fileIdClusters.size() + 1;
    }

    public int getNumShapesSaved() {
        return this.field_3_numShapesSaved;
    }

    @Override // org.apache.poi.ddf.EscherRecord
    public short getRecordId() {
        return RECORD_ID;
    }

    @Override // org.apache.poi.ddf.EscherRecord
    public String getRecordName() {
        return "Dgg";
    }

    @Override // org.apache.poi.ddf.EscherRecord
    public int getRecordSize() {
        return (this.field_5_fileIdClusters.size() * 8) + 24;
    }

    public int getShapeIdMax() {
        return this.field_1_shapeIdMax;
    }

    @Override // org.apache.poi.ddf.EscherRecord
    public int serialize(int i2, byte[] bArr, EscherSerializationListener escherSerializationListener) {
        escherSerializationListener.beforeRecordSerialize(i2, getRecordId(), this);
        LittleEndian.putShort(bArr, i2, getOptions());
        int i3 = i2 + 2;
        LittleEndian.putShort(bArr, i3, getRecordId());
        int i4 = i3 + 2;
        LittleEndian.putInt(bArr, i4, getRecordSize() - 8);
        int i5 = i4 + 4;
        LittleEndian.putInt(bArr, i5, this.field_1_shapeIdMax);
        int i6 = i5 + 4;
        LittleEndian.putInt(bArr, i6, getNumIdClusters());
        int i7 = i6 + 4;
        LittleEndian.putInt(bArr, i7, this.field_3_numShapesSaved);
        int i8 = i7 + 4;
        LittleEndian.putInt(bArr, i8, this.field_4_drawingsSaved);
        int i9 = i8 + 4;
        for (FileIdCluster fileIdCluster : this.field_5_fileIdClusters) {
            LittleEndian.putInt(bArr, i9, fileIdCluster.getDrawingGroupId());
            int i10 = i9 + 4;
            LittleEndian.putInt(bArr, i10, fileIdCluster.getNumShapeIdsUsed());
            i9 = i10 + 4;
        }
        escherSerializationListener.afterRecordSerialize(i9, getRecordId(), getRecordSize(), this);
        return getRecordSize();
    }

    public void setDrawingsSaved(int i2) {
        this.field_4_drawingsSaved = i2;
    }

    public void setFileIdClusters(FileIdCluster[] fileIdClusterArr) {
        this.field_5_fileIdClusters.clear();
        if (fileIdClusterArr != null) {
            this.field_5_fileIdClusters.addAll(Arrays.asList(fileIdClusterArr));
        }
    }

    public void setNumShapesSaved(int i2) {
        this.field_3_numShapesSaved = i2;
    }

    public void setShapeIdMax(int i2) {
        this.field_1_shapeIdMax = i2;
    }

    public FileIdCluster addCluster(int i2, int i3, boolean z) {
        FileIdCluster fileIdCluster = new FileIdCluster(i2, i3);
        this.field_5_fileIdClusters.add(fileIdCluster);
        this.maxDgId = Math.min(this.maxDgId, i2);
        if (z) {
            sortCluster();
        }
        return fileIdCluster;
    }
}
