package org.apache.poi.ddf;

import b.b.a.a.a;
import java.io.PrintWriter;
import java.util.Collections;
import java.util.List;
import org.apache.poi.ss.formula.ptg.GreaterThanPtg;
import org.apache.poi.ss.formula.ptg.LessThanPtg;
import org.apache.poi.util.BitField;
import org.apache.poi.util.BitFieldFactory;
import org.apache.poi.util.HexDump;
import org.apache.poi.util.Internal;
import org.apache.poi.util.LittleEndian;
import org.apache.xmlbeans.impl.common.NameUtil;
import org.apache.xmlbeans.impl.jam.internal.JamPrinter;

public abstract class EscherRecord implements Cloneable {
    public static final BitField fInstance = BitFieldFactory.getInstance(65520);
    public static final BitField fVersion = BitFieldFactory.getInstance(15);
    public short _options;
    public short _recordId;

    public static boolean appendValue(StringBuilder sb, Object obj, boolean z, String str) {
        String property = System.getProperty("line.separator");
        if (obj instanceof String) {
            if (z) {
                escapeXML((String) obj, sb);
            } else {
                sb.append((String) obj);
            }
        } else if (obj instanceof Byte) {
            sb.append("0x");
            sb.append(HexDump.toHex(((Byte) obj).byteValue()));
        } else if (obj instanceof Short) {
            sb.append("0x");
            sb.append(HexDump.toHex(((Short) obj).shortValue()));
        } else if (obj instanceof Integer) {
            sb.append("0x");
            sb.append(HexDump.toHex(((Integer) obj).intValue()));
        } else if (obj instanceof byte[]) {
            sb.append(property);
            String hex = HexDump.toHex((byte[]) obj, 32);
            sb.append(hex.replaceAll("(?m)^", str + "   "));
        } else if (obj instanceof Boolean) {
            sb.append(((Boolean) obj).booleanValue());
        } else if (obj instanceof EscherRecord) {
            EscherRecord escherRecord = (EscherRecord) obj;
            if (z) {
                sb.append(property);
                sb.append(escherRecord.toXml(str + "    "));
                return true;
            }
            sb.append(escherRecord.toString().replaceAll("(?m)^", str));
            return true;
        } else if (obj instanceof EscherProperty) {
            EscherProperty escherProperty = (EscherProperty) obj;
            if (z) {
                sb.append(property);
                sb.append(escherProperty.toXml(str + JamPrinter.INDENT));
                return true;
            }
            sb.append(escherProperty.toString().replaceAll("(?m)^", str));
            return true;
        } else {
            StringBuilder b2 = a.b("unknown attribute type ");
            b2.append(obj.getClass().getSimpleName());
            throw new IllegalArgumentException(b2.toString());
        }
        return false;
    }

    public static String capitalizeAndTrim(String str) {
        if (str == null || str.length() == 0) {
            return str;
        }
        StringBuilder sb = new StringBuilder(str.length());
        char[] charArray = str.toCharArray();
        boolean z = true;
        for (char c : charArray) {
            if (!Character.isLetterOrDigit(c)) {
                z = true;
            } else {
                if (z) {
                    if (!Character.isLetter(c)) {
                        sb.append(NameUtil.USCORE);
                    } else {
                        c = Character.toTitleCase(c);
                    }
                    z = false;
                }
                sb.append(c);
            }
        }
        return sb.toString();
    }

    public static void escapeXML(String str, StringBuilder sb) {
        if (!(str == null || str.isEmpty())) {
            char[] charArray = str.toCharArray();
            for (char c : charArray) {
                if (c > 127 || c == '\"' || c == '<' || c == '>' || c == '&') {
                    sb.append("&#");
                    sb.append((int) c);
                    sb.append(';');
                } else {
                    sb.append(c);
                }
            }
        }
    }

    public static short readInstance(byte[] bArr, int i2) {
        return fInstance.getShortValue(LittleEndian.getShort(bArr, i2));
    }

    public void display(PrintWriter printWriter, int i2) {
        for (int i3 = 0; i3 < i2 * 4; i3++) {
            printWriter.print(' ');
        }
        printWriter.println(getRecordName());
    }

    public abstract int fillFields(byte[] bArr, int i2, EscherRecordFactory escherRecordFactory);

    public int fillFields(byte[] bArr, EscherRecordFactory escherRecordFactory) {
        return fillFields(bArr, 0, escherRecordFactory);
    }

    @Internal
    public abstract Object[][] getAttributeMap();

    public EscherRecord getChild(int i2) {
        return getChildRecords().get(i2);
    }

    public List<EscherRecord> getChildRecords() {
        return Collections.emptyList();
    }

    public short getInstance() {
        return fInstance.getShortValue(this._options);
    }

    @Internal
    public short getOptions() {
        return this._options;
    }

    public short getRecordId() {
        return this._recordId;
    }

    public abstract String getRecordName();

    public abstract int getRecordSize();

    public short getVersion() {
        return fVersion.getShortValue(this._options);
    }

    public boolean isContainerRecord() {
        return getVersion() == 15;
    }

    public int readHeader(byte[] bArr, int i2) {
        this._options = LittleEndian.getShort(bArr, i2);
        this._recordId = LittleEndian.getShort(bArr, i2 + 2);
        return LittleEndian.getInt(bArr, i2 + 4);
    }

    public abstract int serialize(int i2, byte[] bArr, EscherSerializationListener escherSerializationListener);

    public byte[] serialize() {
        byte[] bArr = new byte[getRecordSize()];
        serialize(0, bArr);
        return bArr;
    }

    public void setChildRecords(List<EscherRecord> list) {
        throw new UnsupportedOperationException("This record does not support child records.");
    }

    public void setInstance(short s) {
        this._options = fInstance.setShortValue(this._options, s);
    }

    @Internal
    public void setOptions(short s) {
        setVersion(fVersion.getShortValue(s));
        setInstance(fInstance.getShortValue(s));
        this._options = s;
    }

    public void setRecordId(short s) {
        this._recordId = s;
    }

    public void setVersion(short s) {
        this._options = fVersion.setShortValue(this._options, s);
    }

    public final String toString() {
        String property = System.getProperty("line.separator");
        StringBuilder sb = new StringBuilder(1000);
        sb.append(getClass().getName());
        sb.append(" (");
        sb.append(getRecordName());
        sb.append("):");
        sb.append(property);
        sb.append("  RecordId: 0x");
        sb.append(HexDump.toHex(getRecordId()));
        sb.append(property);
        sb.append("  Version: 0x");
        sb.append(HexDump.toHex(getVersion()));
        sb.append(property);
        sb.append("  Instance: 0x");
        sb.append(HexDump.toHex(getInstance()));
        sb.append(property);
        sb.append("  Options: 0x");
        sb.append(HexDump.toHex(getOptions()));
        sb.append(property);
        sb.append("  Record Size: ");
        sb.append(getRecordSize());
        Object[][] attributeMap = getAttributeMap();
        if (attributeMap != null && attributeMap.length > 0) {
            for (Object[] objArr : attributeMap) {
                for (int i2 = 0; i2 < objArr.length; i2 += 2) {
                    Object obj = objArr[i2 + 1];
                    if (obj != null) {
                        sb.append(property);
                        sb.append(JamPrinter.INDENT);
                        sb.append((String) objArr[i2 + 0]);
                        sb.append(": ");
                        appendValue(sb, obj, false, JamPrinter.INDENT);
                    }
                }
            }
        }
        return sb.toString();
    }

    public String toXml() {
        return toXml("");
    }

    @Override // java.lang.Object
    public EscherRecord clone() {
        return (EscherRecord) super.clone();
    }

    public final String toXml(String str) {
        String property = System.getProperty("line.separator");
        String simpleName = getClass().getSimpleName();
        StringBuilder sb = new StringBuilder(1000);
        sb.append(str);
        sb.append(LessThanPtg.LESSTHAN);
        sb.append(simpleName);
        sb.append(" recordId=\"0x");
        sb.append(HexDump.toHex(getRecordId()));
        sb.append("\" version=\"0x");
        sb.append(HexDump.toHex(getVersion()));
        sb.append("\" instance=\"0x");
        sb.append(HexDump.toHex(getInstance()));
        sb.append("\" options=\"0x");
        sb.append(HexDump.toHex(getOptions()));
        sb.append("\" recordSize=\"");
        sb.append(getRecordSize());
        Object[][] attributeMap = getAttributeMap();
        if (attributeMap == null || attributeMap.length == 0) {
            sb.append("\" />");
            sb.append(property);
        } else {
            sb.append("\">");
            sb.append(property);
            String str2 = str + "   ";
            int length = attributeMap.length;
            char c = 0;
            int i2 = 0;
            while (i2 < length) {
                Object[] objArr = attributeMap[i2];
                String capitalizeAndTrim = capitalizeAndTrim((String) objArr[c]);
                int i3 = 0;
                boolean z = false;
                boolean z2 = false;
                while (i3 < objArr.length) {
                    Object obj = objArr[i3 + 1];
                    if (obj != null) {
                        if (!z) {
                            sb.append(str2);
                            sb.append(LessThanPtg.LESSTHAN);
                            sb.append(capitalizeAndTrim);
                            sb.append(GreaterThanPtg.GREATERTHAN);
                        }
                        String capitalizeAndTrim2 = capitalizeAndTrim((String) objArr[i3 + 0]);
                        if (i3 > 0) {
                            sb.append(property);
                            sb.append(str2);
                            sb.append("  <");
                            sb.append(capitalizeAndTrim2);
                            sb.append(GreaterThanPtg.GREATERTHAN);
                        }
                        z2 = appendValue(sb, obj, true, str2);
                        if (i3 > 0) {
                            sb.append(property);
                            sb.append(str2);
                            sb.append("  </");
                            sb.append(capitalizeAndTrim2);
                            sb.append(GreaterThanPtg.GREATERTHAN);
                        }
                        z = true;
                    }
                    i3 += 2;
                    attributeMap = attributeMap;
                }
                if (z) {
                    if (z2) {
                        sb.append(property);
                        sb.append(str2);
                    }
                    sb.append("</");
                    sb.append(capitalizeAndTrim);
                    sb.append(GreaterThanPtg.GREATERTHAN);
                    sb.append(property);
                }
                i2++;
                attributeMap = attributeMap;
                c = 0;
            }
            sb.append(str);
            sb.append("</");
            sb.append(simpleName);
            sb.append(GreaterThanPtg.GREATERTHAN);
        }
        return sb.toString();
    }

    public int serialize(int i2, byte[] bArr) {
        return serialize(i2, bArr, new NullEscherSerializationListener());
    }
}
