package org.apache.poi.ddf;

import org.apache.poi.util.HexDump;
import org.apache.poi.util.LittleEndian;

public class EscherSpRecord extends EscherRecord {
    public static final int FLAG_BACKGROUND = 1024;
    public static final int FLAG_CHILD = 2;
    public static final int FLAG_CONNECTOR = 256;
    public static final int FLAG_DELETED = 8;
    public static final int FLAG_FLIPHORIZ = 64;
    public static final int FLAG_FLIPVERT = 128;
    public static final int FLAG_GROUP = 1;
    public static final int FLAG_HASSHAPETYPE = 2048;
    public static final int FLAG_HAVEANCHOR = 512;
    public static final int FLAG_HAVEMASTER = 32;
    public static final int FLAG_OLESHAPE = 16;
    public static final int FLAG_PATRIARCH = 4;
    public static final String RECORD_DESCRIPTION = "MsofbtSp";
    public static final short RECORD_ID = -4086;
    public int field_1_shapeId;
    public int field_2_flags;

    private String decodeFlags(int i2) {
        StringBuffer stringBuffer = new StringBuffer();
        String str = "";
        stringBuffer.append((i2 & 1) != 0 ? "|GROUP" : str);
        stringBuffer.append((i2 & 2) != 0 ? "|CHILD" : str);
        stringBuffer.append((i2 & 4) != 0 ? "|PATRIARCH" : str);
        stringBuffer.append((i2 & 8) != 0 ? "|DELETED" : str);
        stringBuffer.append((i2 & 16) != 0 ? "|OLESHAPE" : str);
        stringBuffer.append((i2 & 32) != 0 ? "|HAVEMASTER" : str);
        stringBuffer.append((i2 & 64) != 0 ? "|FLIPHORIZ" : str);
        stringBuffer.append((i2 & 128) != 0 ? "|FLIPVERT" : str);
        stringBuffer.append((i2 & 256) != 0 ? "|CONNECTOR" : str);
        stringBuffer.append((i2 & 512) != 0 ? "|HAVEANCHOR" : str);
        stringBuffer.append((i2 & 1024) != 0 ? "|BACKGROUND" : str);
        if ((i2 & 2048) != 0) {
            str = "|HASSHAPETYPE";
        }
        stringBuffer.append(str);
        if (stringBuffer.length() > 0) {
            stringBuffer.deleteCharAt(0);
        }
        return stringBuffer.toString();
    }

    @Override // org.apache.poi.ddf.EscherRecord
    public int fillFields(byte[] bArr, int i2, EscherRecordFactory escherRecordFactory) {
        readHeader(bArr, i2);
        int i3 = i2 + 8;
        this.field_1_shapeId = LittleEndian.getInt(bArr, i3 + 0);
        this.field_2_flags = LittleEndian.getInt(bArr, i3 + 4);
        return getRecordSize();
    }

    @Override // org.apache.poi.ddf.EscherRecord
    public Object[][] getAttributeMap() {
        Object[] objArr = {"ShapeType", Short.valueOf(getShapeType())};
        Object[] objArr2 = {"ShapeId", Integer.valueOf(this.field_1_shapeId)};
        return new Object[][]{objArr, objArr2, new Object[]{"Flags", decodeFlags(this.field_2_flags) + " (0x" + HexDump.toHex(this.field_2_flags) + ")"}};
    }

    public int getFlags() {
        return this.field_2_flags;
    }

    @Override // org.apache.poi.ddf.EscherRecord
    public short getRecordId() {
        return RECORD_ID;
    }

    @Override // org.apache.poi.ddf.EscherRecord
    public String getRecordName() {
        return "Sp";
    }

    @Override // org.apache.poi.ddf.EscherRecord
    public int getRecordSize() {
        return 16;
    }

    public int getShapeId() {
        return this.field_1_shapeId;
    }

    public short getShapeType() {
        return getInstance();
    }

    @Override // org.apache.poi.ddf.EscherRecord
    public int serialize(int i2, byte[] bArr, EscherSerializationListener escherSerializationListener) {
        escherSerializationListener.beforeRecordSerialize(i2, getRecordId(), this);
        LittleEndian.putShort(bArr, i2, getOptions());
        LittleEndian.putShort(bArr, i2 + 2, getRecordId());
        LittleEndian.putInt(bArr, i2 + 4, 8);
        LittleEndian.putInt(bArr, i2 + 8, this.field_1_shapeId);
        LittleEndian.putInt(bArr, i2 + 12, this.field_2_flags);
        escherSerializationListener.afterRecordSerialize(getRecordSize() + i2, getRecordId(), getRecordSize(), this);
        return 16;
    }

    public void setFlags(int i2) {
        this.field_2_flags = i2;
    }

    public void setShapeId(int i2) {
        this.field_1_shapeId = i2;
    }

    public void setShapeType(short s) {
        setInstance(s);
    }
}
