package org.apache.poi.ddf;

import b.b.a.a.a;
import org.apache.poi.util.LittleEndian;
import org.apache.poi.util.RecordFormatException;

public class EscherSpgrRecord extends EscherRecord {
    public static final String RECORD_DESCRIPTION = "MsofbtSpgr";
    public static final short RECORD_ID = -4087;
    public int field_1_rectX1;
    public int field_2_rectY1;
    public int field_3_rectX2;
    public int field_4_rectY2;

    @Override // org.apache.poi.ddf.EscherRecord
    public int fillFields(byte[] bArr, int i2, EscherRecordFactory escherRecordFactory) {
        int readHeader = readHeader(bArr, i2);
        int i3 = i2 + 8;
        this.field_1_rectX1 = LittleEndian.getInt(bArr, i3 + 0);
        this.field_2_rectY1 = LittleEndian.getInt(bArr, i3 + 4);
        this.field_3_rectX2 = LittleEndian.getInt(bArr, i3 + 8);
        this.field_4_rectY2 = LittleEndian.getInt(bArr, i3 + 12);
        int i4 = readHeader - 16;
        if (i4 == 0) {
            return i4 + 24;
        }
        throw new RecordFormatException(a.c("Expected no remaining bytes but got ", i4));
    }

    @Override // org.apache.poi.ddf.EscherRecord
    public Object[][] getAttributeMap() {
        return new Object[][]{new Object[]{"RectX", Integer.valueOf(this.field_1_rectX1)}, new Object[]{"RectY", Integer.valueOf(this.field_2_rectY1)}, new Object[]{"RectWidth", Integer.valueOf(this.field_3_rectX2)}, new Object[]{"RectHeight", Integer.valueOf(this.field_4_rectY2)}};
    }

    @Override // org.apache.poi.ddf.EscherRecord
    public short getRecordId() {
        return RECORD_ID;
    }

    @Override // org.apache.poi.ddf.EscherRecord
    public String getRecordName() {
        return "Spgr";
    }

    @Override // org.apache.poi.ddf.EscherRecord
    public int getRecordSize() {
        return 24;
    }

    public int getRectX1() {
        return this.field_1_rectX1;
    }

    public int getRectX2() {
        return this.field_3_rectX2;
    }

    public int getRectY1() {
        return this.field_2_rectY1;
    }

    public int getRectY2() {
        return this.field_4_rectY2;
    }

    @Override // org.apache.poi.ddf.EscherRecord
    public int serialize(int i2, byte[] bArr, EscherSerializationListener escherSerializationListener) {
        escherSerializationListener.beforeRecordSerialize(i2, getRecordId(), this);
        LittleEndian.putShort(bArr, i2, getOptions());
        LittleEndian.putShort(bArr, i2 + 2, getRecordId());
        LittleEndian.putInt(bArr, i2 + 4, 16);
        LittleEndian.putInt(bArr, i2 + 8, this.field_1_rectX1);
        LittleEndian.putInt(bArr, i2 + 12, this.field_2_rectY1);
        LittleEndian.putInt(bArr, i2 + 16, this.field_3_rectX2);
        LittleEndian.putInt(bArr, i2 + 20, this.field_4_rectY2);
        escherSerializationListener.afterRecordSerialize(getRecordSize() + i2, getRecordId(), getRecordSize() + i2, this);
        return 24;
    }

    public void setRectX1(int i2) {
        this.field_1_rectX1 = i2;
    }

    public void setRectX2(int i2) {
        this.field_3_rectX2 = i2;
    }

    public void setRectY1(int i2) {
        this.field_2_rectY1 = i2;
    }

    public void setRectY2(int i2) {
        this.field_4_rectY2 = i2;
    }
}
