package org.apache.poi.ddf;

import b.b.a.a.a;
import org.apache.poi.util.LittleEndian;
import org.apache.poi.util.RecordFormatException;

public class EscherSplitMenuColorsRecord extends EscherRecord {
    public static final String RECORD_DESCRIPTION = "MsofbtSplitMenuColors";
    public static final short RECORD_ID = -3810;
    public int field_1_color1;
    public int field_2_color2;
    public int field_3_color3;
    public int field_4_color4;

    @Override // org.apache.poi.ddf.EscherRecord
    public int fillFields(byte[] bArr, int i2, EscherRecordFactory escherRecordFactory) {
        int readHeader = readHeader(bArr, i2);
        int i3 = i2 + 8;
        this.field_1_color1 = LittleEndian.getInt(bArr, i3 + 0);
        this.field_2_color2 = LittleEndian.getInt(bArr, i3 + 4);
        this.field_3_color3 = LittleEndian.getInt(bArr, i3 + 8);
        this.field_4_color4 = LittleEndian.getInt(bArr, i3 + 12);
        int i4 = readHeader - 16;
        if (i4 == 0) {
            return i4 + 24;
        }
        throw new RecordFormatException(a.b("Expecting no remaining data but got ", i4, " byte(s)."));
    }

    @Override // org.apache.poi.ddf.EscherRecord
    public Object[][] getAttributeMap() {
        return new Object[][]{new Object[]{"Color1", Integer.valueOf(this.field_1_color1)}, new Object[]{"Color2", Integer.valueOf(this.field_2_color2)}, new Object[]{"Color3", Integer.valueOf(this.field_3_color3)}, new Object[]{"Color4", Integer.valueOf(this.field_4_color4)}};
    }

    public int getColor1() {
        return this.field_1_color1;
    }

    public int getColor2() {
        return this.field_2_color2;
    }

    public int getColor3() {
        return this.field_3_color3;
    }

    public int getColor4() {
        return this.field_4_color4;
    }

    @Override // org.apache.poi.ddf.EscherRecord
    public short getRecordId() {
        return RECORD_ID;
    }

    @Override // org.apache.poi.ddf.EscherRecord
    public String getRecordName() {
        return "SplitMenuColors";
    }

    @Override // org.apache.poi.ddf.EscherRecord
    public int getRecordSize() {
        return 24;
    }

    @Override // org.apache.poi.ddf.EscherRecord
    public int serialize(int i2, byte[] bArr, EscherSerializationListener escherSerializationListener) {
        escherSerializationListener.beforeRecordSerialize(i2, getRecordId(), this);
        LittleEndian.putShort(bArr, i2, getOptions());
        int i3 = i2 + 2;
        LittleEndian.putShort(bArr, i3, getRecordId());
        int i4 = i3 + 2;
        LittleEndian.putInt(bArr, i4, getRecordSize() - 8);
        int i5 = i4 + 4;
        LittleEndian.putInt(bArr, i5, this.field_1_color1);
        int i6 = i5 + 4;
        LittleEndian.putInt(bArr, i6, this.field_2_color2);
        int i7 = i6 + 4;
        LittleEndian.putInt(bArr, i7, this.field_3_color3);
        int i8 = i7 + 4;
        LittleEndian.putInt(bArr, i8, this.field_4_color4);
        int i9 = i8 + 4;
        escherSerializationListener.afterRecordSerialize(i9, getRecordId(), i9 - i2, this);
        return getRecordSize();
    }

    public void setColor1(int i2) {
        this.field_1_color1 = i2;
    }

    public void setColor2(int i2) {
        this.field_2_color2 = i2;
    }

    public void setColor3(int i2) {
        this.field_3_color3 = i2;
    }

    public void setColor4(int i2) {
        this.field_4_color4 = i2;
    }
}
