package org.apache.poi.ddf;

import b.b.a.a.a;
import java.util.ArrayList;
import java.util.List;
import org.apache.poi.util.HexDump;
import org.apache.poi.util.LittleEndian;

public final class UnknownEscherRecord extends EscherRecord implements Cloneable {
    public static final byte[] NO_BYTES = new byte[0];
    public List<EscherRecord> _childRecords = new ArrayList();
    public byte[] thedata = NO_BYTES;

    public void addChildRecord(EscherRecord escherRecord) {
        getChildRecords().add(escherRecord);
    }

    @Override // org.apache.poi.ddf.EscherRecord
    public int fillFields(byte[] bArr, int i2, EscherRecordFactory escherRecordFactory) {
        int readHeader = readHeader(bArr, i2);
        int i3 = 8;
        int i4 = i2 + 8;
        int length = bArr.length - i4;
        if (readHeader > length) {
            readHeader = length;
        }
        if (isContainerRecord()) {
            this.thedata = new byte[0];
            while (readHeader > 0) {
                EscherRecord createRecord = escherRecordFactory.createRecord(bArr, i4);
                int fillFields = createRecord.fillFields(bArr, i4, escherRecordFactory);
                i3 += fillFields;
                i4 += fillFields;
                readHeader -= fillFields;
                getChildRecords().add(createRecord);
            }
            return i3;
        }
        if (readHeader < 0) {
            readHeader = 0;
        }
        byte[] bArr2 = new byte[readHeader];
        this.thedata = bArr2;
        System.arraycopy(bArr, i4, bArr2, 0, readHeader);
        return readHeader + 8;
    }

    @Override // org.apache.poi.ddf.EscherRecord
    public Object[][] getAttributeMap() {
        int size = getChildRecords().size();
        ArrayList arrayList = new ArrayList((size * 2) + 2);
        arrayList.add("children");
        arrayList.add(Integer.valueOf(size));
        for (EscherRecord escherRecord : this._childRecords) {
            arrayList.add(escherRecord.getRecordName());
            arrayList.add(escherRecord);
        }
        return new Object[][]{new Object[]{"isContainer", Boolean.valueOf(isContainerRecord())}, arrayList.toArray(), new Object[]{"Extra Data", this.thedata}};
    }

    @Override // org.apache.poi.ddf.EscherRecord
    public List<EscherRecord> getChildRecords() {
        return this._childRecords;
    }

    public byte[] getData() {
        return this.thedata;
    }

    @Override // org.apache.poi.ddf.EscherRecord
    public String getRecordName() {
        StringBuilder b2 = a.b("Unknown 0x");
        b2.append(HexDump.toHex(getRecordId()));
        return b2.toString();
    }

    @Override // org.apache.poi.ddf.EscherRecord
    public int getRecordSize() {
        return this.thedata.length + 8;
    }

    @Override // org.apache.poi.ddf.EscherRecord
    public int serialize(int i2, byte[] bArr, EscherSerializationListener escherSerializationListener) {
        escherSerializationListener.beforeRecordSerialize(i2, getRecordId(), this);
        LittleEndian.putShort(bArr, i2, getOptions());
        LittleEndian.putShort(bArr, i2 + 2, getRecordId());
        int length = this.thedata.length;
        for (EscherRecord escherRecord : this._childRecords) {
            length += escherRecord.getRecordSize();
        }
        LittleEndian.putInt(bArr, i2 + 4, length);
        byte[] bArr2 = this.thedata;
        int i3 = i2 + 8;
        System.arraycopy(bArr2, 0, bArr, i3, bArr2.length);
        int length2 = i3 + this.thedata.length;
        for (EscherRecord escherRecord2 : this._childRecords) {
            length2 += escherRecord2.serialize(length2, bArr, escherSerializationListener);
        }
        int i4 = length2 - i2;
        escherSerializationListener.afterRecordSerialize(length2, getRecordId(), i4, this);
        return i4;
    }

    @Override // org.apache.poi.ddf.EscherRecord
    public void setChildRecords(List<EscherRecord> list) {
        this._childRecords = list;
    }

    @Override // java.lang.Object, org.apache.poi.ddf.EscherRecord, org.apache.poi.ddf.EscherRecord
    public UnknownEscherRecord clone() {
        UnknownEscherRecord unknownEscherRecord = new UnknownEscherRecord();
        unknownEscherRecord.thedata = (byte[]) this.thedata.clone();
        unknownEscherRecord.setOptions(getOptions());
        unknownEscherRecord.setRecordId(getRecordId());
        return unknownEscherRecord;
    }
}
