package org.apache.poi.dev;

import b.b.a.a.a;
import java.io.Closeable;
import java.io.File;
import java.io.InputStream;
import java.io.PrintStream;
import java.util.Iterator;
import org.apache.poi.openxml4j.opc.OPCPackage;
import org.apache.poi.openxml4j.opc.PackageAccess;
import org.apache.poi.openxml4j.opc.PackagePart;
import org.apache.poi.openxml4j.opc.PackageRelationship;

public class OOXMLLister implements Closeable {
    public final OPCPackage container;
    public final PrintStream disp;

    public OOXMLLister(OPCPackage oPCPackage) {
        this(oPCPackage, System.out);
    }

    private void displayRelation(PackageRelationship packageRelationship, String str) {
        PrintStream printStream = this.disp;
        printStream.println(str + "Relationship:");
        PrintStream printStream2 = this.disp;
        StringBuilder d2 = a.d(str, "\tFrom: ");
        d2.append(packageRelationship.getSourceURI());
        printStream2.println(d2.toString());
        PrintStream printStream3 = this.disp;
        StringBuilder d3 = a.d(str, "\tTo:   ");
        d3.append(packageRelationship.getTargetURI());
        printStream3.println(d3.toString());
        PrintStream printStream4 = this.disp;
        StringBuilder d4 = a.d(str, "\tID:   ");
        d4.append(packageRelationship.getId());
        printStream4.println(d4.toString());
        PrintStream printStream5 = this.disp;
        StringBuilder d5 = a.d(str, "\tMode: ");
        d5.append(packageRelationship.getTargetMode());
        printStream5.println(d5.toString());
        PrintStream printStream6 = this.disp;
        StringBuilder d6 = a.d(str, "\tType: ");
        d6.append(packageRelationship.getRelationshipType());
        printStream6.println(d6.toString());
    }

    public static long getSize(PackagePart packagePart) {
        InputStream inputStream = packagePart.getInputStream();
        try {
            byte[] bArr = new byte[8192];
            long j = 0;
            int i2 = 0;
            while (i2 > -1) {
                i2 = inputStream.read(bArr);
                if (i2 > 0) {
                    j += (long) i2;
                }
            }
            return j;
        } finally {
            inputStream.close();
        }
    }

    public static void main(String[] strArr) {
        if (strArr.length == 0) {
            System.err.println("Use:");
            System.err.println("\tjava OOXMLLister <filename>");
            System.exit(1);
        }
        File file = new File(strArr[0]);
        if (!file.exists()) {
            System.err.println("Error, file not found!");
            PrintStream printStream = System.err;
            printStream.println("\t" + file);
            System.exit(2);
        }
        OOXMLLister oOXMLLister = new OOXMLLister(OPCPackage.open(file.toString(), PackageAccess.READ));
        try {
            PrintStream printStream2 = oOXMLLister.disp;
            printStream2.println(file + "\n");
            oOXMLLister.displayParts();
            oOXMLLister.disp.println();
            oOXMLLister.displayRelations();
        } finally {
            oOXMLLister.close();
        }
    }

    @Override // java.io.Closeable, java.lang.AutoCloseable
    public void close() {
        this.container.close();
    }

    public void displayParts() {
        Iterator<PackagePart> it = this.container.getParts().iterator();
        while (it.hasNext()) {
            PackagePart next = it.next();
            this.disp.println(next.getPartName());
            PrintStream printStream = this.disp;
            StringBuilder b2 = a.b("\t");
            b2.append(next.getContentType());
            printStream.println(b2.toString());
            if (!next.getPartName().toString().equals("/docProps/core.xml")) {
                PrintStream printStream2 = this.disp;
                StringBuilder b3 = a.b("\t");
                b3.append(getSize(next));
                b3.append(" bytes");
                printStream2.println(b3.toString());
            }
            if (!next.isRelationshipPart()) {
                PrintStream printStream3 = this.disp;
                StringBuilder b4 = a.b("\t");
                b4.append(next.getRelationships().size());
                b4.append(" relations");
                printStream3.println(b4.toString());
                Iterator<PackageRelationship> it2 = next.getRelationships().iterator();
                while (it2.hasNext()) {
                    displayRelation(it2.next(), "\t  ");
                }
            }
        }
    }

    public void displayRelations() {
        Iterator<PackageRelationship> it = this.container.getRelationships().iterator();
        while (it.hasNext()) {
            displayRelation(it.next(), "");
        }
    }

    public OOXMLLister(OPCPackage oPCPackage, PrintStream printStream) {
        this.container = oPCPackage;
        this.disp = printStream;
    }
}
