package org.apache.poi.extractor;

import java.io.ByteArrayInputStream;
import java.io.FileNotFoundException;
import java.io.InputStream;
import java.util.Iterator;
import java.util.List;
import org.apache.poi.POIOLE2TextExtractor;
import org.apache.poi.POITextExtractor;
import org.apache.poi.hdgf.extractor.VisioTextExtractor;
import org.apache.poi.hpbf.extractor.PublisherTextExtractor;
import org.apache.poi.hslf.extractor.PowerPointExtractor;
import org.apache.poi.hslf.usermodel.HSLFSlideShow;
import org.apache.poi.hsmf.datatypes.AttachmentChunks;
import org.apache.poi.hsmf.extractor.OutlookTextExtactor;
import org.apache.poi.hwpf.HWPFDocumentCore;
import org.apache.poi.hwpf.OldWordFileFormatException;
import org.apache.poi.hwpf.extractor.Word6Extractor;
import org.apache.poi.hwpf.extractor.WordExtractor;
import org.apache.poi.poifs.filesystem.DirectoryEntry;
import org.apache.poi.poifs.filesystem.DirectoryNode;
import org.apache.poi.poifs.filesystem.Entry;

public class OLE2ScratchpadExtractorFactory {
    public static POITextExtractor createExtractor(DirectoryNode directoryNode) {
        if (directoryNode.hasEntry(HWPFDocumentCore.STREAM_WORD_DOCUMENT)) {
            try {
                return new WordExtractor(directoryNode);
            } catch (OldWordFileFormatException unused) {
                return new Word6Extractor(directoryNode);
            }
        } else if (directoryNode.hasEntry(HSLFSlideShow.POWERPOINT_DOCUMENT)) {
            return new PowerPointExtractor(directoryNode);
        } else {
            if (directoryNode.hasEntry("VisioDocument")) {
                return new VisioTextExtractor(directoryNode);
            }
            if (directoryNode.hasEntry("Quill")) {
                return new PublisherTextExtractor(directoryNode);
            }
            String[] strArr = {"__substg1.0_1000001E", "__substg1.0_1000001F", "__substg1.0_0047001E", "__substg1.0_0047001F", "__substg1.0_0037001E", "__substg1.0_0037001F"};
            for (int i2 = 0; i2 < 6; i2++) {
                if (directoryNode.hasEntry(strArr[i2])) {
                    return new OutlookTextExtactor(directoryNode);
                }
            }
            throw new IllegalArgumentException("No supported documents found in the OLE2 stream");
        }
    }

    public static void identifyEmbeddedResources(POIOLE2TextExtractor pOIOLE2TextExtractor, List<Entry> list, List<InputStream> list2) {
        DirectoryEntry root = pOIOLE2TextExtractor.getRoot();
        if (root == null) {
            throw new IllegalStateException("The extractor didn't know which POIFS it came from!");
        } else if (pOIOLE2TextExtractor instanceof WordExtractor) {
            try {
                Iterator<Entry> entries = ((DirectoryEntry) root.getEntry(HWPFDocumentCore.STREAM_OBJECT_POOL)).getEntries();
                while (entries.hasNext()) {
                    Entry next = entries.next();
                    if (next.getName().startsWith("_")) {
                        list.add(next);
                    }
                }
            } catch (FileNotFoundException unused) {
            }
        } else if (pOIOLE2TextExtractor instanceof OutlookTextExtactor) {
            AttachmentChunks[] attachmentFiles = ((OutlookTextExtactor) pOIOLE2TextExtractor).getMAPIMessage().getAttachmentFiles();
            for (AttachmentChunks attachmentChunks : attachmentFiles) {
                if (attachmentChunks.getAttachData() != null) {
                    list2.add(new ByteArrayInputStream(attachmentChunks.getAttachData().getValue()));
                } else if (attachmentChunks.getAttachmentDirectory() != null) {
                    list.add(attachmentChunks.getAttachmentDirectory().getDirectory());
                }
            }
        }
    }
}
