package org.apache.poi.hdgf;

import b.b.a.a.a;
import java.io.File;
import java.io.PrintStream;
import org.apache.poi.POIReadOnlyDocument;
import org.apache.poi.hdgf.chunks.ChunkFactory;
import org.apache.poi.hdgf.pointers.Pointer;
import org.apache.poi.hdgf.pointers.PointerFactory;
import org.apache.poi.hdgf.streams.PointerContainingStream;
import org.apache.poi.hdgf.streams.Stream;
import org.apache.poi.hdgf.streams.StringsStream;
import org.apache.poi.hdgf.streams.TrailerStream;
import org.apache.poi.poifs.filesystem.DirectoryNode;
import org.apache.poi.poifs.filesystem.DocumentInputStream;
import org.apache.poi.poifs.filesystem.NPOIFSFileSystem;
import org.apache.poi.poifs.filesystem.POIFSFileSystem;
import org.apache.poi.util.IOUtils;
import org.apache.poi.util.LittleEndian;
import org.apache.poi.util.LocaleUtil;

public final class HDGFDiagram extends POIReadOnlyDocument {
    public static final String VISIO_HEADER = "Visio (TM) Drawing\r\n";
    public byte[] _docstream;
    public ChunkFactory chunkFactory;
    public long docSize;
    public PointerFactory ptrFactory;
    public TrailerStream trailer;
    public Pointer trailerPointer;
    public short version;

    public HDGFDiagram(POIFSFileSystem pOIFSFileSystem) {
        this(pOIFSFileSystem.getRoot());
    }

    public static void main(String[] strArr) {
        NPOIFSFileSystem nPOIFSFileSystem = new NPOIFSFileSystem(new File(strArr[0]));
        HDGFDiagram hDGFDiagram = new HDGFDiagram(nPOIFSFileSystem);
        hDGFDiagram.debug();
        hDGFDiagram.close();
        nPOIFSFileSystem.close();
    }

    public void debug() {
        PrintStream printStream = System.err;
        StringBuilder b2 = a.b("Trailer is at ");
        b2.append(this.trailerPointer.getOffset());
        printStream.println(b2.toString());
        PrintStream printStream2 = System.err;
        StringBuilder b3 = a.b("Trailer has type ");
        b3.append(this.trailerPointer.getType());
        printStream2.println(b3.toString());
        PrintStream printStream3 = System.err;
        StringBuilder b4 = a.b("Trailer has length ");
        b4.append(this.trailerPointer.getLength());
        printStream3.println(b4.toString());
        PrintStream printStream4 = System.err;
        StringBuilder b5 = a.b("Trailer has format ");
        b5.append((int) this.trailerPointer.getFormat());
        printStream4.println(b5.toString());
        for (int i2 = 0; i2 < this.trailer.getPointedToStreams().length; i2++) {
            Stream stream = this.trailer.getPointedToStreams()[i2];
            Pointer pointer = stream.getPointer();
            PrintStream printStream5 = System.err;
            printStream5.println("Looking at pointer " + i2);
            PrintStream printStream6 = System.err;
            StringBuilder b6 = a.b("\tType is ");
            b6.append(pointer.getType());
            b6.append("\t\t");
            b6.append(Integer.toHexString(pointer.getType()));
            printStream6.println(b6.toString());
            PrintStream printStream7 = System.err;
            StringBuilder b7 = a.b("\tOffset is ");
            b7.append(pointer.getOffset());
            b7.append("\t\t");
            b7.append(Long.toHexString((long) pointer.getOffset()));
            printStream7.println(b7.toString());
            PrintStream printStream8 = System.err;
            StringBuilder b8 = a.b("\tAddress is ");
            b8.append(pointer.getAddress());
            b8.append("\t");
            b8.append(Long.toHexString((long) pointer.getAddress()));
            printStream8.println(b8.toString());
            PrintStream printStream9 = System.err;
            StringBuilder b9 = a.b("\tLength is ");
            b9.append(pointer.getLength());
            b9.append("\t\t");
            b9.append(Long.toHexString((long) pointer.getLength()));
            printStream9.println(b9.toString());
            PrintStream printStream10 = System.err;
            StringBuilder b10 = a.b("\tFormat is ");
            b10.append((int) pointer.getFormat());
            b10.append("\t\t");
            b10.append(Long.toHexString((long) pointer.getFormat()));
            printStream10.println(b10.toString());
            PrintStream printStream11 = System.err;
            StringBuilder b11 = a.b("\tCompressed is ");
            b11.append(pointer.destinationCompressed());
            printStream11.println(b11.toString());
            PrintStream printStream12 = System.err;
            StringBuilder b12 = a.b("\tStream is ");
            b12.append(stream.getClass());
            printStream12.println(b12.toString());
            if (stream instanceof PointerContainingStream) {
                PointerContainingStream pointerContainingStream = (PointerContainingStream) stream;
                if (pointerContainingStream.getPointedToStreams() != null && pointerContainingStream.getPointedToStreams().length > 0) {
                    PrintStream printStream13 = System.err;
                    StringBuilder b13 = a.b("\tContains ");
                    b13.append(pointerContainingStream.getPointedToStreams().length);
                    b13.append(" other pointers/streams");
                    printStream13.println(b13.toString());
                    for (int i3 = 0; i3 < pointerContainingStream.getPointedToStreams().length; i3++) {
                        Pointer pointer2 = pointerContainingStream.getPointedToStreams()[i3].getPointer();
                        PrintStream printStream14 = System.err;
                        StringBuilder a = a.a("\t\t", i3, " - Type is ");
                        a.append(pointer2.getType());
                        a.append("\t\t");
                        a.append(Integer.toHexString(pointer2.getType()));
                        printStream14.println(a.toString());
                        PrintStream printStream15 = System.err;
                        StringBuilder a2 = a.a("\t\t", i3, " - Length is ");
                        a2.append(pointer2.getLength());
                        a2.append("\t\t");
                        a2.append(Long.toHexString((long) pointer2.getLength()));
                        printStream15.println(a2.toString());
                    }
                }
            }
            if (stream instanceof StringsStream) {
                System.err.println("\t\t**strings**");
                PrintStream printStream16 = System.err;
                StringBuilder b14 = a.b("\t\t");
                b14.append(((StringsStream) stream)._getContentsLength());
                printStream16.println(b14.toString());
            }
        }
    }

    public long getDocumentSize() {
        return this.docSize;
    }

    public Stream[] getTopLevelStreams() {
        return this.trailer.getPointedToStreams();
    }

    public TrailerStream getTrailerStream() {
        return this.trailer;
    }

    public HDGFDiagram(NPOIFSFileSystem nPOIFSFileSystem) {
        this(nPOIFSFileSystem.getRoot());
    }

    public HDGFDiagram(DirectoryNode directoryNode) {
        super(directoryNode);
        DocumentInputStream createDocumentInputStream = directoryNode.createDocumentInputStream("VisioDocument");
        this._docstream = IOUtils.toByteArray(createDocumentInputStream);
        createDocumentInputStream.close();
        String str = new String(this._docstream, 0, 20, LocaleUtil.CHARSET_1252);
        if (str.equals(VISIO_HEADER)) {
            this.version = LittleEndian.getShort(this._docstream, 26);
            this.docSize = LittleEndian.getUInt(this._docstream, 28);
            this.ptrFactory = new PointerFactory(this.version);
            this.chunkFactory = new ChunkFactory(this.version);
            Pointer createPointer = this.ptrFactory.createPointer(this._docstream, 36);
            this.trailerPointer = createPointer;
            TrailerStream trailerStream = (TrailerStream) Stream.createStream(createPointer, this._docstream, this.chunkFactory, this.ptrFactory);
            this.trailer = trailerStream;
            trailerStream.findChildren(this._docstream);
            return;
        }
        throw new IllegalArgumentException(a.b("Wasn't a valid visio document, started with ", str));
    }
}
