package org.apache.poi.hdgf;

import java.io.InputStream;
import java.io.OutputStream;
import org.apache.poi.util.LZWDecompresser;

public final class HDGFLZWCompressor {
    public byte[] buffer = new byte[16];
    public int bufferLen = 0;
    public byte[] dict = new byte[4096];
    public int maskBitsSet = 0;
    public int nextMask = 0;
    public int posInp = 0;
    public int posOut = 0;
    public byte[] rawCode = new byte[18];
    public int rawCodeLen = 0;

    private int findRawCodeInBuffer() {
        for (int i2 = 4096 - this.rawCodeLen; i2 > 0; i2--) {
            boolean z = true;
            int i3 = 0;
            while (z && i3 < this.rawCodeLen) {
                if (this.dict[i2 + i3] != this.rawCode[i3]) {
                    z = false;
                }
                i3++;
            }
            if (z) {
                return i2;
            }
        }
        return -1;
    }

    private void output8Codes(OutputStream outputStream) {
        outputStream.write(new byte[]{LZWDecompresser.fromInt(this.nextMask)});
        outputStream.write(this.buffer, 0, this.bufferLen);
        this.nextMask = 0;
        this.maskBitsSet = 0;
        this.bufferLen = 0;
    }

    private void outputCompressed(OutputStream outputStream) {
        int i2 = 0;
        if (this.rawCodeLen < 3) {
            while (i2 < this.rawCodeLen) {
                outputUncompressed(this.rawCode[i2], outputStream);
                i2++;
            }
            return;
        }
        int findRawCodeInBuffer = findRawCodeInBuffer() - 18;
        if (findRawCodeInBuffer < 0) {
            findRawCodeInBuffer += 4096;
        }
        this.maskBitsSet++;
        int i3 = findRawCodeInBuffer & 255;
        int i4 = (this.rawCodeLen - 3) + ((findRawCodeInBuffer - i3) >> 4);
        this.buffer[this.bufferLen] = LZWDecompresser.fromInt(i3);
        int i5 = this.bufferLen + 1;
        this.bufferLen = i5;
        this.buffer[i5] = LZWDecompresser.fromInt(i4);
        this.bufferLen++;
        while (i2 < this.rawCodeLen) {
            byte[] bArr = this.dict;
            int i6 = this.posOut;
            bArr[i6 & 4095] = this.rawCode[i2];
            this.posOut = i6 + 1;
            i2++;
        }
        if (this.maskBitsSet == 8) {
            output8Codes(outputStream);
        }
    }

    private void outputUncompressed(byte b2, OutputStream outputStream) {
        int i2 = this.nextMask;
        int i3 = this.maskBitsSet;
        this.nextMask = i2 + (1 << i3);
        int i4 = i3 + 1;
        this.maskBitsSet = i4;
        byte[] bArr = this.buffer;
        int i5 = this.bufferLen;
        bArr[i5] = b2;
        this.bufferLen = i5 + 1;
        byte[] bArr2 = this.dict;
        int i6 = this.posOut;
        bArr2[i6 & 4095] = b2;
        this.posOut = i6 + 1;
        if (i4 == 8) {
            output8Codes(outputStream);
        }
    }

    public void compress(InputStream inputStream, OutputStream outputStream) {
        boolean z = true;
        while (z) {
            int read = inputStream.read();
            this.posInp++;
            if (read == -1) {
                z = false;
            }
            byte fromInt = LZWDecompresser.fromInt(read);
            if (z) {
                byte[] bArr = this.rawCode;
                int i2 = this.rawCodeLen;
                bArr[i2] = fromInt;
                this.rawCodeLen = i2 + 1;
                int findRawCodeInBuffer = findRawCodeInBuffer();
                if (this.rawCodeLen == 18 && findRawCodeInBuffer > -1) {
                    outputCompressed(outputStream);
                    this.rawCodeLen = 0;
                } else if (findRawCodeInBuffer <= -1) {
                    int i3 = this.rawCodeLen - 1;
                    this.rawCodeLen = i3;
                    if (i3 > 0) {
                        outputCompressed(outputStream);
                        this.rawCode[0] = fromInt;
                        this.rawCodeLen = 1;
                        if (findRawCodeInBuffer() <= -1) {
                            outputUncompressed(fromInt, outputStream);
                            this.rawCodeLen = 0;
                        }
                    } else {
                        outputUncompressed(fromInt, outputStream);
                    }
                }
            } else if (this.rawCodeLen > 0) {
                outputCompressed(outputStream);
                if (this.maskBitsSet > 0) {
                    output8Codes(outputStream);
                    return;
                }
                return;
            } else {
                return;
            }
        }
    }
}
