package org.apache.poi.hdgf.chunks;

import b.b.a.a.a;
import java.util.ArrayList;
import org.apache.poi.hdgf.chunks.ChunkFactory;
import org.apache.poi.util.LittleEndian;
import org.apache.poi.util.POILogFactory;
import org.apache.poi.util.POILogger;

public final class Chunk {
    public ChunkFactory.CommandDefinition[] commandDefinitions;
    public Command[] commands;
    public byte[] contents;
    public ChunkHeader header;
    public POILogger logger = POILogFactory.getLogger(Chunk.class);
    public String name;
    public ChunkSeparator separator;
    public ChunkTrailer trailer;

    public static class BlockOffsetCommand extends Command {
        /* access modifiers changed from: private */
        /* access modifiers changed from: public */
        private void setOffset(int i2) {
            this.value = Integer.valueOf(i2);
        }

        public BlockOffsetCommand(ChunkFactory.CommandDefinition commandDefinition) {
            super(commandDefinition, null);
        }
    }

    public Chunk(ChunkHeader chunkHeader, ChunkTrailer chunkTrailer, ChunkSeparator chunkSeparator, byte[] bArr) {
        this.header = chunkHeader;
        this.trailer = chunkTrailer;
        this.separator = chunkSeparator;
        this.contents = (byte[]) bArr.clone();
    }

    public byte[] _getContents() {
        return this.contents;
    }

    public ChunkFactory.CommandDefinition[] getCommandDefinitions() {
        return this.commandDefinitions;
    }

    public Command[] getCommands() {
        return this.commands;
    }

    public ChunkHeader getHeader() {
        return this.header;
    }

    public String getName() {
        return this.name;
    }

    public int getOnDiskSize() {
        int sizeInBytes = this.header.getSizeInBytes() + this.contents.length;
        ChunkTrailer chunkTrailer = this.trailer;
        if (chunkTrailer != null) {
            sizeInBytes += chunkTrailer.getTrailerData().length;
        }
        ChunkSeparator chunkSeparator = this.separator;
        return chunkSeparator != null ? sizeInBytes + chunkSeparator.separatorData.length : sizeInBytes;
    }

    public ChunkSeparator getSeparator() {
        return this.separator;
    }

    public ChunkTrailer getTrailer() {
        return this.trailer;
    }

    public void processCommands() {
        Command command;
        if (this.commandDefinitions != null) {
            ArrayList arrayList = new ArrayList();
            ChunkFactory.CommandDefinition[] commandDefinitionArr = this.commandDefinitions;
            for (ChunkFactory.CommandDefinition commandDefinition : commandDefinitionArr) {
                int type = commandDefinition.getType();
                int offset = commandDefinition.getOffset();
                if (type == 10) {
                    this.name = commandDefinition.getName();
                } else if (type != 18) {
                    if (type == 11 || type == 21) {
                        command = new BlockOffsetCommand(commandDefinition);
                    } else {
                        command = new Command(commandDefinition);
                    }
                    if (!(type == 11 || type == 12 || type == 21 || type == 28 || type == 29)) {
                        switch (type) {
                            case 0:
                            case 1:
                            case 2:
                            case 3:
                            case 4:
                            case 5:
                            case 6:
                            case 7:
                                break;
                            default:
                                switch (type) {
                                    case 16:
                                    case 17:
                                    case 18:
                                        break;
                                    default:
                                        if (offset >= 19) {
                                            offset -= 19;
                                            break;
                                        }
                                        break;
                                }
                        }
                    }
                    byte[] bArr = this.contents;
                    if (offset >= bArr.length) {
                        POILogger pOILogger = this.logger;
                        StringBuilder a = a.a("Command offset ", offset, " past end of data at ");
                        a.append(this.contents.length);
                        pOILogger.log(5, a.toString());
                    } else {
                        if (type != 11) {
                            if (type != 12) {
                                if (type != 21) {
                                    if (type == 25) {
                                        command.value = Short.valueOf(LittleEndian.getShort(bArr, offset));
                                    } else if (type != 26) {
                                        switch (type) {
                                            case 0:
                                            case 1:
                                            case 2:
                                            case 3:
                                            case 4:
                                            case 5:
                                            case 6:
                                            case 7:
                                                command.value = Boolean.valueOf((bArr[offset] & (1 << type)) > 0);
                                                break;
                                            case 8:
                                                command.value = Byte.valueOf(bArr[offset]);
                                                break;
                                            case 9:
                                                command.value = new Double(LittleEndian.getDouble(this.contents, offset));
                                                break;
                                            default:
                                                try {
                                                    this.logger.log(3, "Command of type " + type + " not processed!");
                                                    break;
                                                } catch (Exception e2) {
                                                    this.logger.log(7, "Unexpected error processing command, ignoring and continuing. Command: " + command, e2);
                                                    break;
                                                }
                                        }
                                    } else {
                                        command.value = Integer.valueOf(LittleEndian.getInt(bArr, offset));
                                    }
                                }
                            } else if (bArr.length < 8) {
                                command.value = "";
                            } else {
                                int i2 = 8;
                                for (int i3 = 8; i3 < this.contents.length - 1 && i2 == 8; i3++) {
                                    if (this.contents[i3] == 0 && this.contents[i3 + 1] == 0) {
                                        i2 = i3;
                                    }
                                }
                                if (i2 == 8) {
                                    i2 = this.contents.length;
                                }
                                command.value = new String(this.contents, 8, i2 - 8, this.header.getChunkCharset().name());
                            }
                            arrayList.add(command);
                        }
                        if (offset < this.contents.length - 3) {
                            ((BlockOffsetCommand) command).setOffset((int) LittleEndian.getUInt(this.contents, offset));
                        }
                        arrayList.add(command);
                    }
                }
            }
            this.commands = (Command[]) arrayList.toArray(new Command[arrayList.size()]);
            return;
        }
        throw new IllegalStateException("You must supply the command definitions before calling processCommands!");
    }

    public static class Command {
        public ChunkFactory.CommandDefinition definition;
        public Object value;

        public ChunkFactory.CommandDefinition getDefinition() {
            return this.definition;
        }

        public Object getValue() {
            return this.value;
        }

        public Command(ChunkFactory.CommandDefinition commandDefinition, Object obj) {
            this.definition = commandDefinition;
            this.value = obj;
        }

        public Command(ChunkFactory.CommandDefinition commandDefinition) {
            this(commandDefinition, (Object) null);
        }
    }
}
