package org.apache.poi.hdgf.chunks;

import b.b.a.a.a;
import java.nio.charset.Charset;
import org.apache.poi.util.LittleEndian;

public abstract class ChunkHeader {
    public int id;
    public int length;
    public int type;
    public int unknown1;

    public static ChunkHeader createChunkHeader(int i2, byte[] bArr, int i3) {
        ChunkHeaderV6 chunkHeaderV6;
        if (i2 >= 6) {
            if (i2 > 6) {
                chunkHeaderV6 = new ChunkHeaderV11();
            } else {
                chunkHeaderV6 = new ChunkHeaderV6();
            }
            chunkHeaderV6.setType((int) LittleEndian.getUInt(bArr, i3 + 0));
            chunkHeaderV6.setId((int) LittleEndian.getUInt(bArr, i3 + 4));
            chunkHeaderV6.setUnknown1((int) LittleEndian.getUInt(bArr, i3 + 8));
            chunkHeaderV6.setLength((int) LittleEndian.getUInt(bArr, i3 + 12));
            chunkHeaderV6.setUnknown2(LittleEndian.getShort(bArr, i3 + 16));
            chunkHeaderV6.setUnknown3(LittleEndian.getUByte(bArr, i3 + 18));
            return chunkHeaderV6;
        } else if (i2 == 5 || i2 == 4) {
            ChunkHeaderV4V5 chunkHeaderV4V5 = new ChunkHeaderV4V5();
            chunkHeaderV4V5.setType(LittleEndian.getShort(bArr, i3 + 0));
            chunkHeaderV4V5.setId(LittleEndian.getShort(bArr, i3 + 2));
            chunkHeaderV4V5.setUnknown2(LittleEndian.getUByte(bArr, i3 + 4));
            chunkHeaderV4V5.setUnknown3(LittleEndian.getUByte(bArr, i3 + 5));
            chunkHeaderV4V5.setUnknown1(LittleEndian.getShort(bArr, i3 + 6));
            chunkHeaderV4V5.setLength((int) LittleEndian.getUInt(bArr, i3 + 8));
            return chunkHeaderV4V5;
        } else {
            throw new IllegalArgumentException(a.c("Visio files with versions below 4 are not supported, yours was ", i2));
        }
    }

    public static int getHeaderSize(int i2) {
        if (i2 > 6) {
            return ChunkHeaderV6.getHeaderSize();
        }
        if (i2 == 6) {
            return ChunkHeaderV6.getHeaderSize();
        }
        return ChunkHeaderV4V5.getHeaderSize();
    }

    public abstract Charset getChunkCharset();

    public int getId() {
        return this.id;
    }

    public int getLength() {
        return this.length;
    }

    public abstract int getSizeInBytes();

    public int getType() {
        return this.type;
    }

    public int getUnknown1() {
        return this.unknown1;
    }

    public abstract boolean hasSeparator();

    public abstract boolean hasTrailer();

    public void setId(int i2) {
        this.id = i2;
    }

    public void setLength(int i2) {
        this.length = i2;
    }

    public void setType(int i2) {
        this.type = i2;
    }

    public void setUnknown1(int i2) {
        this.unknown1 = i2;
    }
}
