package org.apache.poi.hdgf.dev;

import b.b.a.a.a;
import java.io.File;
import java.io.PrintStream;
import java.util.Arrays;
import org.apache.poi.hdgf.HDGFDiagram;
import org.apache.poi.hdgf.chunks.Chunk;
import org.apache.poi.hdgf.pointers.Pointer;
import org.apache.poi.hdgf.streams.ChunkStream;
import org.apache.poi.hdgf.streams.PointerContainingStream;
import org.apache.poi.hdgf.streams.Stream;
import org.apache.poi.poifs.filesystem.NPOIFSFileSystem;

public final class VSDDumper {
    public static final String tabs = "\t\t\t\t\t\t\t\t\t\t\t\t\t\t\t\t\t\t";
    public final HDGFDiagram hdgf;
    public final PrintStream ps;

    public VSDDumper(PrintStream printStream, HDGFDiagram hDGFDiagram) {
        this.ps = printStream;
        this.hdgf = hDGFDiagram;
    }

    private void dumpChunk(Chunk chunk, int i2) {
        dumpVal(chunk.getName(), "", i2);
        dumpVal("Length is", (long) chunk._getContents().length, i2);
        dumpVal("OD Size is", (long) chunk.getOnDiskSize(), i2);
        dumpVal("T / S is", chunk.getTrailer() + " / " + chunk.getSeparator(), i2);
        Chunk.Command[] commands = chunk.getCommands();
        dumpVal("Nbr of commands", (long) commands.length, i2);
        for (Chunk.Command command : commands) {
            String name = command.getDefinition().getName();
            StringBuilder b2 = a.b("");
            b2.append(command.getValue());
            dumpVal(name, b2.toString(), i2 + 1);
        }
    }

    private void dumpStream(Stream stream, int i2) {
        Pointer pointer = stream.getPointer();
        dumpVal("Stream at", (long) pointer.getOffset(), i2);
        int i3 = i2 + 1;
        dumpVal("Type is", (long) pointer.getType(), i3);
        dumpVal("Format is", (long) pointer.getFormat(), i3);
        dumpVal("Length is", (long) pointer.getLength(), i3);
        if (pointer.destinationCompressed()) {
            dumpVal("DC.Length is", (long) stream._getContentsLength(), i3);
        }
        dumpVal("Compressed is", pointer.destinationCompressed(), i3);
        dumpVal("Stream is", stream.getClass().getName(), i3);
        byte[] _getContents = stream._getStore()._getContents();
        dumpVal("First few bytes are", _getContents.length >= 8 ? Arrays.toString(_getContents) : "[]", i3);
        if (stream instanceof PointerContainingStream) {
            Stream[] pointedToStreams = ((PointerContainingStream) stream).getPointedToStreams();
            dumpVal("Nbr of children", (long) pointedToStreams.length, i3);
            for (Stream stream2 : pointedToStreams) {
                dumpStream(stream2, i3);
            }
        }
        if (stream instanceof ChunkStream) {
            Chunk[] chunks = ((ChunkStream) stream).getChunks();
            dumpVal("Nbr of chunks", (long) chunks.length, i3);
            for (Chunk chunk : chunks) {
                dumpChunk(chunk, i3);
            }
        }
    }

    private void dumpVal(String str, long j, int i2) {
        this.ps.print("\t\t\t\t\t\t\t\t\t\t\t\t\t\t\t\t\t\t".substring(0, i2));
        this.ps.print(str);
        this.ps.print('\t');
        this.ps.print(j);
        this.ps.print(" (0x");
        this.ps.print(Long.toHexString(j));
        this.ps.println(")");
    }

    public static void main(String[] strArr) {
        if (strArr.length == 0) {
            System.err.println("Use:");
            System.err.println("  VSDDumper <filename>");
            System.exit(1);
        }
        NPOIFSFileSystem nPOIFSFileSystem = new NPOIFSFileSystem(new File(strArr[0]));
        try {
            HDGFDiagram hDGFDiagram = new HDGFDiagram(nPOIFSFileSystem);
            PrintStream printStream = System.out;
            printStream.println("Opened " + strArr[0]);
            new VSDDumper(printStream, hDGFDiagram).dumpFile();
        } finally {
            nPOIFSFileSystem.close();
        }
    }

    public void dumpFile() {
        dumpVal("Claimed document size", this.hdgf.getDocumentSize(), 0);
        this.ps.println();
        dumpStream(this.hdgf.getTrailerStream(), 0);
    }

    private void dumpVal(String str, boolean z, int i2) {
        dumpVal(str, Boolean.toString(z), i2);
    }

    private void dumpVal(String str, String str2, int i2) {
        this.ps.print("\t\t\t\t\t\t\t\t\t\t\t\t\t\t\t\t\t\t".substring(0, i2));
        this.ps.print(str);
        this.ps.print('\t');
        this.ps.println(str2);
    }
}
