package org.apache.poi.hdgf.extractor;

import java.io.FileInputStream;
import java.io.InputStream;
import java.util.ArrayList;
import org.apache.poi.POIOLE2TextExtractor;
import org.apache.poi.hdgf.HDGFDiagram;
import org.apache.poi.hdgf.chunks.Chunk;
import org.apache.poi.hdgf.streams.ChunkStream;
import org.apache.poi.hdgf.streams.PointerContainingStream;
import org.apache.poi.hdgf.streams.Stream;
import org.apache.poi.poifs.filesystem.DirectoryNode;
import org.apache.poi.poifs.filesystem.NPOIFSFileSystem;
import org.apache.poi.poifs.filesystem.POIFSFileSystem;

public final class VisioTextExtractor extends POIOLE2TextExtractor {
    public HDGFDiagram hdgf;

    public VisioTextExtractor(HDGFDiagram hDGFDiagram) {
        super(hDGFDiagram);
        this.hdgf = hDGFDiagram;
    }

    private void findText(Stream stream, ArrayList<String> arrayList) {
        Chunk.Command command;
        if (stream instanceof PointerContainingStream) {
            PointerContainingStream pointerContainingStream = (PointerContainingStream) stream;
            for (int i2 = 0; i2 < pointerContainingStream.getPointedToStreams().length; i2++) {
                findText(pointerContainingStream.getPointedToStreams()[i2], arrayList);
            }
        }
        if (stream instanceof ChunkStream) {
            ChunkStream chunkStream = (ChunkStream) stream;
            for (int i3 = 0; i3 < chunkStream.getChunks().length; i3++) {
                Chunk chunk = chunkStream.getChunks()[i3];
                if (!(chunk == null || chunk.getName() == null || !chunk.getName().equals("Text") || chunk.getCommands().length <= 0 || (command = chunk.getCommands()[0]) == null || command.getValue() == null)) {
                    String obj = command.getValue().toString();
                    if (!obj.equals("") && !obj.equals("\n")) {
                        arrayList.add(obj);
                    }
                }
            }
        }
    }

    public static void main(String[] strArr) {
        if (strArr.length == 0) {
            System.err.println("Use:");
            System.err.println("   VisioTextExtractor <file.vsd>");
            System.exit(1);
        }
        VisioTextExtractor visioTextExtractor = new VisioTextExtractor(new FileInputStream(strArr[0]));
        System.out.print(visioTextExtractor.getText());
        visioTextExtractor.close();
    }

    public String[] getAllText() {
        ArrayList<String> arrayList = new ArrayList<>();
        for (Stream stream : this.hdgf.getTopLevelStreams()) {
            findText(stream, arrayList);
        }
        return (String[]) arrayList.toArray(new String[arrayList.size()]);
    }

    @Override // org.apache.poi.POITextExtractor
    public String getText() {
        StringBuffer stringBuffer = new StringBuffer();
        String[] allText = getAllText();
        for (String str : allText) {
            stringBuffer.append(str);
            if (!str.endsWith("\r") && !str.endsWith("\n")) {
                stringBuffer.append('\n');
            }
        }
        return stringBuffer.toString();
    }

    public VisioTextExtractor(POIFSFileSystem pOIFSFileSystem) {
        this(pOIFSFileSystem.getRoot());
    }

    public VisioTextExtractor(NPOIFSFileSystem nPOIFSFileSystem) {
        this(nPOIFSFileSystem.getRoot());
    }

    public VisioTextExtractor(DirectoryNode directoryNode) {
        this(new HDGFDiagram(directoryNode));
    }

    public VisioTextExtractor(InputStream inputStream) {
        this(new NPOIFSFileSystem(inputStream));
    }
}
