package org.apache.poi.hdgf.pointers;

import b.b.a.a.a;
import org.apache.poi.util.LittleEndian;

public final class PointerFactory {
    public int version;

    public PointerFactory(int i2) {
        this.version = i2;
    }

    public Pointer[] createContainerPointers(Pointer pointer, byte[] bArr) {
        int numPointersOffset = pointer.getNumPointersOffset(bArr);
        int numPointers = pointer.getNumPointers(numPointersOffset, bArr);
        int postNumPointersSkip = pointer.getPostNumPointersSkip() + numPointersOffset;
        Pointer[] pointerArr = new Pointer[numPointers];
        for (int i2 = 0; i2 < numPointers; i2++) {
            pointerArr[i2] = createPointer(bArr, postNumPointersSkip);
            postNumPointersSkip += pointerArr[i2].getSizeInBytes();
        }
        return pointerArr;
    }

    public Pointer createPointer(byte[] bArr, int i2) {
        int i3 = this.version;
        if (i3 >= 6) {
            PointerV6 pointerV6 = new PointerV6();
            pointerV6.setType(LittleEndian.getInt(bArr, i2 + 0));
            pointerV6.setAddress((int) LittleEndian.getUInt(bArr, i2 + 4));
            pointerV6.setOffset((int) LittleEndian.getUInt(bArr, i2 + 8));
            pointerV6.setLength((int) LittleEndian.getUInt(bArr, i2 + 12));
            pointerV6.setFormat(LittleEndian.getShort(bArr, i2 + 16));
            return pointerV6;
        } else if (i3 == 5) {
            PointerV5 pointerV5 = new PointerV5();
            pointerV5.setType(LittleEndian.getShort(bArr, i2 + 0));
            pointerV5.setFormat(LittleEndian.getShort(bArr, i2 + 2));
            pointerV5.setAddress((int) LittleEndian.getUInt(bArr, i2 + 4));
            pointerV5.setOffset((int) LittleEndian.getUInt(bArr, i2 + 8));
            pointerV5.setLength((int) LittleEndian.getUInt(bArr, i2 + 12));
            return pointerV5;
        } else {
            StringBuilder b2 = a.b("Visio files with versions below 5 are not supported, yours was ");
            b2.append(this.version);
            throw new IllegalArgumentException(b2.toString());
        }
    }

    public int getVersion() {
        return this.version;
    }
}
