package org.apache.poi.hdgf.streams;

import java.util.ArrayList;
import org.apache.poi.hdgf.chunks.Chunk;
import org.apache.poi.hdgf.chunks.ChunkFactory;
import org.apache.poi.hdgf.chunks.ChunkHeader;
import org.apache.poi.hdgf.pointers.Pointer;
import org.apache.poi.util.POILogFactory;
import org.apache.poi.util.POILogger;

public final class ChunkStream extends Stream {
    public static final POILogger logger = POILogFactory.getLogger(ChunkStream.class);
    public ChunkFactory chunkFactory;
    public Chunk[] chunks;

    public ChunkStream(Pointer pointer, StreamStore streamStore, ChunkFactory chunkFactory2) {
        super(pointer, streamStore);
        this.chunkFactory = chunkFactory2;
        streamStore.copyBlockHeaderToContents();
    }

    public void findChunks() {
        ArrayList arrayList = new ArrayList();
        getPointer().getOffset();
        byte[] contents = getStore().getContents();
        int i2 = 0;
        while (i2 < contents.length) {
            try {
                int headerSize = ChunkHeader.getHeaderSize(this.chunkFactory.getVersion());
                if (i2 + headerSize <= contents.length) {
                    Chunk createChunk = this.chunkFactory.createChunk(contents, i2);
                    arrayList.add(createChunk);
                    i2 += createChunk.getOnDiskSize();
                } else {
                    POILogger pOILogger = logger;
                    pOILogger.log(5, "Needed " + headerSize + " bytes to create the next chunk header, but only found " + (contents.length - i2) + " bytes, ignoring rest of data");
                    i2 = contents.length;
                }
            } catch (Exception e2) {
                POILogger pOILogger2 = logger;
                pOILogger2.log(7, "Failed to create chunk at " + i2 + ", ignoring rest of data." + e2);
            }
        }
        this.chunks = (Chunk[]) arrayList.toArray(new Chunk[arrayList.size()]);
    }

    public Chunk[] getChunks() {
        return this.chunks;
    }
}
