package org.apache.poi.hdgf.streams;

import java.io.IOException;
import org.apache.poi.hdgf.chunks.ChunkFactory;
import org.apache.poi.hdgf.exceptions.HDGFException;
import org.apache.poi.hdgf.pointers.Pointer;
import org.apache.poi.hdgf.pointers.PointerFactory;

public abstract class Stream {
    public Pointer pointer;
    public StreamStore store;

    public Stream(Pointer pointer2, StreamStore streamStore) {
        this.pointer = pointer2;
        this.store = streamStore;
    }

    public static Stream createStream(Pointer pointer2, byte[] bArr, ChunkFactory chunkFactory, PointerFactory pointerFactory) {
        StreamStore streamStore;
        if (pointer2.destinationCompressed()) {
            try {
                streamStore = new CompressedStreamStore(bArr, pointer2.getOffset(), pointer2.getLength());
            } catch (IOException e2) {
                throw new HDGFException(e2);
            }
        } else {
            streamStore = new StreamStore(bArr, pointer2.getOffset(), pointer2.getLength());
        }
        if (pointer2.getType() == 20) {
            return new TrailerStream(pointer2, streamStore, chunkFactory, pointerFactory);
        }
        if (pointer2.destinationHasPointers()) {
            return new PointerContainingStream(pointer2, streamStore, chunkFactory, pointerFactory);
        }
        if (pointer2.destinationHasChunks()) {
            return new ChunkStream(pointer2, streamStore, chunkFactory);
        }
        if (pointer2.destinationHasStrings()) {
            return new StringsStream(pointer2, streamStore, chunkFactory);
        }
        return new UnknownStream(pointer2, streamStore);
    }

    public int _getContentsLength() {
        return this.store.getContents().length;
    }

    public StreamStore _getStore() {
        return this.store;
    }

    public Pointer getPointer() {
        return this.pointer;
    }

    public StreamStore getStore() {
        return this.store;
    }
}
