package org.apache.poi.hemf.extractor;

import java.io.IOException;
import java.io.InputStream;
import java.util.Iterator;
import org.apache.poi.hemf.record.HemfHeader;
import org.apache.poi.hemf.record.HemfRecord;
import org.apache.poi.hemf.record.HemfRecordType;
import org.apache.poi.util.Internal;
import org.apache.poi.util.LittleEndianInputStream;
import org.apache.poi.util.RecordFormatException;

@Internal
public class HemfExtractor implements Iterable<HemfRecord> {
    public HemfHeader header = new HemfHeader();
    public final LittleEndianInputStream stream;

    public class HemfRecordIterator implements Iterator<HemfRecord> {
        public HemfRecord currentRecord;

        public HemfRecordIterator() {
            this.currentRecord = null;
            this.currentRecord = _next();
        }

        private HemfRecord _next() {
            HemfRecord hemfRecord = this.currentRecord;
            if (hemfRecord != null && hemfRecord.getRecordType().equals(HemfRecordType.eof)) {
                return null;
            }
            long readUInt = HemfExtractor.this.stream.readUInt();
            long readUInt2 = HemfExtractor.this.stream.readUInt();
            HemfRecordType byId = HemfRecordType.getById(readUInt);
            if (byId != null) {
                try {
                    HemfRecord hemfRecord2 = (HemfRecord) byId.clazz.newInstance();
                    try {
                        hemfRecord2.init(HemfExtractor.this.stream, readUInt, readUInt2 - 8);
                        return hemfRecord2;
                    } catch (IOException e2) {
                        throw new RecordFormatException(e2);
                    }
                } catch (InstantiationException e3) {
                    throw new RuntimeException(e3);
                } catch (IllegalAccessException e4) {
                    throw new RuntimeException(e4);
                }
            } else {
                throw new RuntimeException("Undefined record of type:" + readUInt);
            }
        }

        public boolean hasNext() {
            return this.currentRecord != null;
        }

        public void remove() {
            throw new UnsupportedOperationException("Remove not supported");
        }

        @Override // java.util.Iterator
        public HemfRecord next() {
            HemfRecord hemfRecord = this.currentRecord;
            this.currentRecord = _next();
            return hemfRecord;
        }
    }

    public HemfExtractor(InputStream inputStream) {
        this.stream = new LittleEndianInputStream(inputStream);
        long readUInt = this.stream.readUInt();
        long readUInt2 = this.stream.readUInt();
        HemfHeader hemfHeader = new HemfHeader();
        this.header = hemfHeader;
        hemfHeader.init(this.stream, readUInt, readUInt2 - 8);
    }

    public HemfHeader getHeader() {
        return this.header;
    }

    @Override // java.lang.Iterable
    public Iterator<HemfRecord> iterator() {
        return new HemfRecordIterator();
    }
}
