package org.apache.poi.hemf.record;

import b.b.a.a.a;
import java.io.IOException;
import java.util.ArrayList;
import java.util.List;
import org.apache.poi.hemf.hemfplus.record.HemfPlusRecord;
import org.apache.poi.hemf.hemfplus.record.HemfPlusRecordType;
import org.apache.poi.util.IOUtils;
import org.apache.poi.util.Internal;
import org.apache.poi.util.LittleEndian;
import org.apache.poi.util.RecordFormatException;

@Internal
public class HemfCommentEMFPlus extends AbstractHemfComment {
    public static final int MAX_RECORD_LENGTH = 1000000;
    public long dataSize;

    public static class HemfPlusParser {
        public static HemfPlusRecord buildRecord(int i2, int i3, int i4, int i5, byte[] bArr) {
            HemfPlusRecordType byId = HemfPlusRecordType.getById((long) i2);
            if (byId != null) {
                try {
                    HemfPlusRecord hemfPlusRecord = (HemfPlusRecord) byId.clazz.newInstance();
                    byte[] safelyAllocate = IOUtils.safelyAllocate((long) i4, 1000000);
                    System.arraycopy(bArr, i5, safelyAllocate, 0, i4);
                    try {
                        hemfPlusRecord.init(safelyAllocate, i2, i3);
                        return hemfPlusRecord;
                    } catch (IOException e2) {
                        throw new RuntimeException(e2);
                    }
                } catch (InstantiationException e3) {
                    throw new RuntimeException(e3);
                } catch (IllegalAccessException e4) {
                    throw new RuntimeException(e4);
                }
            } else {
                throw new RuntimeException(a.c("Undefined record of type:", i2));
            }
        }

        public static List<HemfPlusRecord> parse(byte[] bArr) {
            ArrayList arrayList = new ArrayList();
            int i2 = 0;
            while (i2 < bArr.length && i2 + 12 <= bArr.length) {
                int uShort = LittleEndian.getUShort(bArr, i2);
                int i3 = i2 + 2;
                int uShort2 = LittleEndian.getUShort(bArr, i3);
                int i4 = i3 + 2;
                long uInt = LittleEndian.getUInt(bArr, i4);
                int i5 = i4 + 4;
                if (uInt < 2147483647L) {
                    long uInt2 = LittleEndian.getUInt(bArr, i5);
                    int i6 = i5 + 4;
                    if (uInt2 < 2147483647L) {
                        int i7 = (int) uInt2;
                        int i8 = i7 + i6;
                        if (i8 > bArr.length) {
                            break;
                        }
                        arrayList.add(buildRecord(uShort, uShort2, i7, i6, bArr));
                        i2 = i8;
                    } else {
                        throw new RuntimeException("data size of emfplus record cannot be >= Integer.MAX_VALUE");
                    }
                } else {
                    throw new RecordFormatException("size of emf record >= Integer.MAX_VALUE");
                }
            }
            return arrayList;
        }
    }

    public HemfCommentEMFPlus(byte[] bArr) {
        super(bArr);
    }

    public List<HemfPlusRecord> getRecords() {
        return HemfPlusParser.parse(getRawBytes());
    }
}
