package org.apache.poi.hemf.record;

import b.b.a.a.a;
import java.awt.Rectangle;
import java.io.IOException;
import org.apache.poi.util.IOUtils;
import org.apache.poi.util.Internal;
import org.apache.poi.util.LittleEndian;
import org.apache.poi.util.LittleEndianInputStream;

@Internal
public class HemfHeader implements HemfRecord {
    public static final int MAX_RECORD_LENGTH = 1000000;
    public long bOpenGL;
    public Rectangle boundsRectangle;
    public long bytes;
    public long cbPixelFormat;
    public Rectangle frameRectangle;
    public int handles;
    public boolean hasExtension1;
    public boolean hasExtension2;
    public long micrometersX;
    public long micrometersY;
    public long nDescription;
    public long nPalEntries;
    public long offDescription;
    public long offPixelFormat;
    public long records;

    public Rectangle getBoundsRectangle() {
        return this.boundsRectangle;
    }

    public long getBytes() {
        return this.bytes;
    }

    public long getCbPixelFormat() {
        return this.cbPixelFormat;
    }

    public Rectangle getFrameRectangle() {
        return this.frameRectangle;
    }

    public int getHandles() {
        return this.handles;
    }

    public long getMicrometersX() {
        return this.micrometersX;
    }

    public long getMicrometersY() {
        return this.micrometersY;
    }

    public long getOffDescription() {
        return this.offDescription;
    }

    public long getOffPixelFormat() {
        return this.offPixelFormat;
    }

    @Override // org.apache.poi.hemf.record.HemfRecord
    public HemfRecordType getRecordType() {
        return HemfRecordType.header;
    }

    public long getRecords() {
        return this.records;
    }

    public long getbOpenGL() {
        return this.bOpenGL;
    }

    public long getnDescription() {
        return this.nDescription;
    }

    public long getnPalEntries() {
        return this.nPalEntries;
    }

    @Override // org.apache.poi.hemf.record.HemfRecord
    public long init(LittleEndianInputStream littleEndianInputStream, long j, long j2) {
        if (j == 1) {
            byte[] safelyAllocate = IOUtils.safelyAllocate(j2, 1000000);
            IOUtils.readFully(littleEndianInputStream, safelyAllocate);
            int i2 = LittleEndian.getInt(safelyAllocate, 0);
            int i3 = LittleEndian.getInt(safelyAllocate, 4);
            this.boundsRectangle = new Rectangle(i2, i3, LittleEndian.getInt(safelyAllocate, 8) - i2, LittleEndian.getInt(safelyAllocate, 12) - i3);
            int i4 = LittleEndian.getInt(safelyAllocate, 16);
            int i5 = LittleEndian.getInt(safelyAllocate, 20);
            this.frameRectangle = new Rectangle(i4, i5, LittleEndian.getInt(safelyAllocate, 24) - i4, LittleEndian.getInt(safelyAllocate, 28) - i5);
            long j3 = (long) LittleEndian.getInt(safelyAllocate, 32);
            if (j3 == 1179469088) {
                LittleEndian.getInt(safelyAllocate, 36);
                this.bytes = LittleEndian.getUInt(safelyAllocate, 40);
                this.records = LittleEndian.getUInt(safelyAllocate, 44);
                this.handles = LittleEndian.getUShort(safelyAllocate, 48);
                this.nDescription = LittleEndian.getUInt(safelyAllocate, 52);
                this.offDescription = LittleEndian.getUInt(safelyAllocate, 56);
                this.nPalEntries = LittleEndian.getUInt(safelyAllocate, 60);
                int i6 = 80;
                long j4 = 8 + j2;
                if (j4 >= 100) {
                    this.hasExtension1 = true;
                    this.cbPixelFormat = LittleEndian.getUInt(safelyAllocate, 80);
                    this.offPixelFormat = LittleEndian.getUInt(safelyAllocate, 84);
                    this.bOpenGL = LittleEndian.getUInt(safelyAllocate, 88);
                    i6 = 92;
                }
                if (j4 >= 108) {
                    this.hasExtension2 = true;
                    this.micrometersX = LittleEndian.getUInt(safelyAllocate, i6);
                    this.micrometersY = LittleEndian.getUInt(safelyAllocate, i6 + 4);
                }
                return j2;
            }
            throw new IOException("bad record signature: " + j3);
        }
        throw new IOException("Not a valid EMF header. Record type:" + j);
    }

    public boolean isHasExtension1() {
        return this.hasExtension1;
    }

    public boolean isHasExtension2() {
        return this.hasExtension2;
    }

    public String toString() {
        StringBuilder b2 = a.b("HemfHeader{boundsRectangle=");
        b2.append(this.boundsRectangle);
        b2.append(", frameRectangle=");
        b2.append(this.frameRectangle);
        b2.append(", bytes=");
        b2.append(this.bytes);
        b2.append(", records=");
        b2.append(this.records);
        b2.append(", handles=");
        b2.append(this.handles);
        b2.append(", nDescription=");
        b2.append(this.nDescription);
        b2.append(", offDescription=");
        b2.append(this.offDescription);
        b2.append(", nPalEntries=");
        b2.append(this.nPalEntries);
        b2.append(", hasExtension1=");
        b2.append(this.hasExtension1);
        b2.append(", cbPixelFormat=");
        b2.append(this.cbPixelFormat);
        b2.append(", offPixelFormat=");
        b2.append(this.offPixelFormat);
        b2.append(", bOpenGL=");
        b2.append(this.bOpenGL);
        b2.append(", hasExtension2=");
        b2.append(this.hasExtension2);
        b2.append(", micrometersX=");
        b2.append(this.micrometersX);
        b2.append(", micrometersY=");
        b2.append(this.micrometersY);
        b2.append('}');
        return b2.toString();
    }
}
