package org.apache.poi.hmef.attribute;

import b.b.a.a.a;
import java.io.ByteArrayInputStream;
import java.io.InputStream;
import java.util.ArrayList;
import java.util.List;
import org.apache.poi.hsmf.datatypes.MAPIProperty;
import org.apache.poi.hsmf.datatypes.Types;
import org.apache.poi.util.HexDump;
import org.apache.poi.util.IOUtils;
import org.apache.poi.util.LittleEndian;
import org.apache.poi.util.StringUtil;

public class MAPIAttribute {
    public final byte[] data;
    public final MAPIProperty property;
    public final int type;

    public MAPIAttribute(MAPIProperty mAPIProperty, int i2, byte[] bArr) {
        this.property = mAPIProperty;
        this.type = i2;
        this.data = (byte[]) bArr.clone();
    }

    public static List<MAPIAttribute> create(TNEFAttribute tNEFAttribute) {
        boolean z;
        Object obj;
        String str;
        if (tNEFAttribute.getProperty() == TNEFProperty.ID_MAPIPROPERTIES || tNEFAttribute.getProperty() == TNEFProperty.ID_ATTACHMENT) {
            ByteArrayInputStream byteArrayInputStream = new ByteArrayInputStream(tNEFAttribute.getData());
            int readInt = LittleEndian.readInt(byteArrayInputStream);
            ArrayList arrayList = new ArrayList();
            for (int i2 = 0; i2 < readInt; i2++) {
                int readUShort = LittleEndian.readUShort(byteArrayInputStream);
                int readUShort2 = LittleEndian.readUShort(byteArrayInputStream);
                int i3 = 1;
                if ((readUShort & 4096) != 0) {
                    readUShort -= 4096;
                    z = true;
                } else {
                    z = false;
                }
                boolean z2 = readUShort == Types.ASCII_STRING.getId() || readUShort == Types.UNICODE_STRING.getId() || readUShort == Types.BINARY.getId() || readUShort == Types.DIRECTORY.getId();
                Types.MAPIType byId = Types.getById(readUShort);
                if (byId == null) {
                    byId = Types.createCustom(readUShort);
                }
                MAPIProperty mAPIProperty = MAPIProperty.get(readUShort2);
                if (readUShort2 >= 32768 && readUShort2 <= 65535) {
                    IOUtils.readFully(byteArrayInputStream, new byte[16]);
                    if (LittleEndian.readInt(byteArrayInputStream) == 0) {
                        str = MAPIProperty.get(LittleEndian.readInt(byteArrayInputStream)).name;
                    } else {
                        int readInt2 = LittleEndian.readInt(byteArrayInputStream);
                        byte[] bArr = new byte[readInt2];
                        IOUtils.readFully(byteArrayInputStream, bArr);
                        String fromUnicodeLE = StringUtil.getFromUnicodeLE(bArr, 0, (readInt2 / 2) - 1);
                        skipToBoundary(readInt2, byteArrayInputStream);
                        str = fromUnicodeLE;
                    }
                    mAPIProperty = MAPIProperty.createCustom(readUShort2, byId, str);
                }
                if (mAPIProperty == MAPIProperty.UNKNOWN) {
                    StringBuilder b2 = a.b("(unknown ");
                    b2.append(Integer.toHexString(readUShort2));
                    b2.append(")");
                    mAPIProperty = MAPIProperty.createCustom(readUShort2, byId, b2.toString());
                }
                if (z || z2) {
                    i3 = LittleEndian.readInt(byteArrayInputStream);
                }
                for (int i4 = 0; i4 < i3; i4++) {
                    int length = getLength(byId, byteArrayInputStream);
                    byte[] bArr2 = new byte[length];
                    IOUtils.readFully(byteArrayInputStream, bArr2);
                    skipToBoundary(length, byteArrayInputStream);
                    if (byId == Types.UNICODE_STRING || byId == Types.ASCII_STRING) {
                        obj = new MAPIStringAttribute(mAPIProperty, readUShort, bArr2);
                    } else if (byId == Types.APP_TIME || byId == Types.TIME) {
                        obj = new MAPIDateAttribute(mAPIProperty, readUShort, bArr2);
                    } else if (readUShort2 == MAPIProperty.RTF_COMPRESSED.id) {
                        obj = new MAPIRtfAttribute(mAPIProperty, readUShort, bArr2);
                    } else {
                        obj = new MAPIAttribute(mAPIProperty, readUShort, bArr2);
                    }
                    arrayList.add(obj);
                }
            }
            return arrayList;
        }
        StringBuilder b3 = a.b("Can only create from a MAPIProperty attribute, instead received a ");
        b3.append(tNEFAttribute.getProperty());
        b3.append(" one");
        throw new IllegalArgumentException(b3.toString());
    }

    public static int getLength(Types.MAPIType mAPIType, InputStream inputStream) {
        if (mAPIType.isFixedLength()) {
            return mAPIType.getLength();
        }
        if (mAPIType == Types.ASCII_STRING || mAPIType == Types.UNICODE_STRING || mAPIType == Types.DIRECTORY || mAPIType == Types.BINARY) {
            return LittleEndian.readInt(inputStream);
        }
        throw new IllegalArgumentException("Unknown type " + mAPIType);
    }

    public static void skipToBoundary(int i2, InputStream inputStream) {
        int i3 = i2 % 4;
        if (i3 != 0) {
            IOUtils.readFully(inputStream, new byte[(4 - i3)]);
        }
    }

    public byte[] getData() {
        return this.data;
    }

    public MAPIProperty getProperty() {
        return this.property;
    }

    public int getType() {
        return this.type;
    }

    public String toString() {
        String str;
        byte[] bArr = this.data;
        if (bArr.length <= 16) {
            str = HexDump.toHex(bArr);
        } else {
            byte[] bArr2 = new byte[16];
            System.arraycopy(bArr, 0, bArr2, 0, 16);
            String hex = HexDump.toHex(bArr2);
            str = hex.substring(0, hex.length() - 1) + ", ....]";
        }
        return this.property + " " + str;
    }
}
