package org.apache.poi.hmef.attribute;

import b.b.a.a.a;
import java.nio.charset.Charset;
import org.apache.poi.hsmf.datatypes.MAPIProperty;
import org.apache.poi.hsmf.datatypes.Types;
import org.apache.poi.util.POILogFactory;
import org.apache.poi.util.POILogger;
import org.apache.poi.util.StringUtil;

public final class MAPIStringAttribute extends MAPIAttribute {
    public static final String CODEPAGE = "CP1252";
    public static final POILogger logger = POILogFactory.getLogger(MAPIStringAttribute.class);
    public final String data;

    public MAPIStringAttribute(MAPIProperty mAPIProperty, int i2, byte[] bArr) {
        super(mAPIProperty, i2, bArr);
        String str;
        if (i2 == Types.ASCII_STRING.getId()) {
            str = new String(bArr, Charset.forName("CP1252"));
        } else if (i2 == Types.UNICODE_STRING.getId()) {
            str = StringUtil.getFromUnicodeLE(bArr);
        } else {
            throw new IllegalArgumentException(a.c("Not a string type ", i2));
        }
        this.data = str.endsWith("\u0000") ? str.substring(0, str.length() - 1) : str;
    }

    public static String getAsString(MAPIAttribute mAPIAttribute) {
        if (mAPIAttribute == null) {
            return null;
        }
        if (mAPIAttribute instanceof MAPIStringAttribute) {
            return ((MAPIStringAttribute) mAPIAttribute).getDataString();
        }
        if (mAPIAttribute instanceof MAPIRtfAttribute) {
            return ((MAPIRtfAttribute) mAPIAttribute).getDataString();
        }
        POILogger pOILogger = logger;
        pOILogger.log(5, "Warning, non string property found: " + mAPIAttribute);
        return null;
    }

    public String getDataString() {
        return this.data;
    }

    @Override // org.apache.poi.hmef.attribute.MAPIAttribute
    public String toString() {
        return getProperty() + " " + this.data;
    }
}
