package org.apache.poi.hmef.attribute;

import b.b.a.a.a;
import java.io.InputStream;
import org.apache.poi.util.IOUtils;
import org.apache.poi.util.LittleEndian;

public class TNEFAttribute {
    public final int checksum;
    public final byte[] data;
    public final TNEFProperty property;
    public final int type;

    public TNEFAttribute(int i2, int i3, InputStream inputStream) {
        this.type = i3;
        int readInt = LittleEndian.readInt(inputStream);
        this.property = TNEFProperty.getBest(i2, i3);
        byte[] bArr = new byte[readInt];
        this.data = bArr;
        IOUtils.readFully(inputStream, bArr);
        this.checksum = LittleEndian.readUShort(inputStream);
    }

    public static TNEFAttribute create(InputStream inputStream) {
        int readUShort = LittleEndian.readUShort(inputStream);
        int readUShort2 = LittleEndian.readUShort(inputStream);
        if (readUShort == TNEFProperty.ID_MAPIPROPERTIES.id || readUShort == TNEFProperty.ID_ATTACHMENT.id) {
            return new TNEFMAPIAttribute(readUShort, readUShort2, inputStream);
        }
        if (readUShort2 == 1 || readUShort2 == 2) {
            return new TNEFStringAttribute(readUShort, readUShort2, inputStream);
        }
        if (readUShort2 == 3) {
            return new TNEFDateAttribute(readUShort, readUShort2, inputStream);
        }
        return new TNEFAttribute(readUShort, readUShort2, inputStream);
    }

    public byte[] getData() {
        return this.data;
    }

    public TNEFProperty getProperty() {
        return this.property;
    }

    public int getType() {
        return this.type;
    }

    public String toString() {
        StringBuilder b2 = a.b("Attribute ");
        b2.append(this.property);
        b2.append(", type=");
        b2.append(this.type);
        b2.append(", data length=");
        b2.append(this.data.length);
        return b2.toString();
    }
}
