package org.apache.poi.hmef.attribute;

import b.b.a.a.a;
import java.io.InputStream;
import java.text.DateFormatSymbols;
import java.text.SimpleDateFormat;
import java.util.Calendar;
import java.util.Date;
import java.util.Locale;
import org.apache.poi.hpsf.Filetime;
import org.apache.poi.util.LittleEndian;
import org.apache.poi.util.LocaleUtil;
import org.apache.poi.util.POILogFactory;
import org.apache.poi.util.POILogger;

public final class TNEFDateAttribute extends TNEFAttribute {
    public static final POILogger logger = POILogFactory.getLogger(TNEFDateAttribute.class);
    public Date data;

    public TNEFDateAttribute(int i2, int i3, InputStream inputStream) {
        super(i2, i3, inputStream);
        byte[] data2 = getData();
        if (data2.length == 8) {
            this.data = Filetime.filetimeToDate(LittleEndian.getLong(getData(), 0));
        } else if (data2.length == 14) {
            Calendar localeCalendar = LocaleUtil.getLocaleCalendar(LocaleUtil.TIMEZONE_UTC);
            localeCalendar.set(1, LittleEndian.getUShort(data2, 0));
            localeCalendar.set(2, LittleEndian.getUShort(data2, 2) - 1);
            localeCalendar.set(5, LittleEndian.getUShort(data2, 4));
            localeCalendar.set(11, LittleEndian.getUShort(data2, 6));
            localeCalendar.set(12, LittleEndian.getUShort(data2, 8));
            localeCalendar.set(13, LittleEndian.getUShort(data2, 10));
            localeCalendar.clear(14);
            this.data = localeCalendar.getTime();
        } else {
            throw new IllegalArgumentException(a.a(a.b("Invalid date, found "), data2.length, " bytes"));
        }
    }

    public static Date getAsDate(TNEFAttribute tNEFAttribute) {
        if (tNEFAttribute == null) {
            return null;
        }
        if (tNEFAttribute instanceof TNEFDateAttribute) {
            return ((TNEFDateAttribute) tNEFAttribute).getDate();
        }
        POILogger pOILogger = logger;
        pOILogger.log(5, "Warning, non date property found: " + tNEFAttribute);
        return null;
    }

    public Date getDate() {
        return this.data;
    }

    @Override // org.apache.poi.hmef.attribute.TNEFAttribute
    public String toString() {
        SimpleDateFormat simpleDateFormat = new SimpleDateFormat("EEE MMM dd HH:mm:ss zzz yyyy", DateFormatSymbols.getInstance(Locale.ROOT));
        simpleDateFormat.setTimeZone(LocaleUtil.TIMEZONE_UTC);
        return "Attribute " + getProperty() + ", type=" + getType() + ", date=" + simpleDateFormat.format(this.data);
    }
}
