package org.apache.poi.hmef.dev;

import b.b.a.a.a;
import java.io.FileInputStream;
import java.io.InputStream;
import java.io.PrintStream;
import java.util.Iterator;
import org.apache.poi.hmef.attribute.MAPIAttribute;
import org.apache.poi.hmef.attribute.TNEFAttribute;
import org.apache.poi.hmef.attribute.TNEFDateAttribute;
import org.apache.poi.hmef.attribute.TNEFProperty;
import org.apache.poi.hmef.attribute.TNEFStringAttribute;
import org.apache.poi.util.HexDump;
import org.apache.poi.util.LittleEndian;
import org.apache.xmlbeans.impl.jam.internal.JamPrinter;

public final class HMEFDumper {
    public InputStream inp;
    public boolean truncatePropertyData;

    public HMEFDumper(InputStream inputStream) {
        this.inp = inputStream;
        int readInt = LittleEndian.readInt(inputStream);
        if (readInt == 574529400) {
            LittleEndian.readUShort(inputStream);
            return;
        }
        throw new IllegalArgumentException(a.c("TNEF signature not detected in file, expected 574529400 but got ", readInt));
    }

    private void dump() {
        int i2 = 0;
        while (true) {
            int read = this.inp.read();
            if (read != -1) {
                TNEFAttribute create = TNEFAttribute.create(this.inp);
                if (read == 2 && create.getProperty() == TNEFProperty.ID_ATTACHRENDERDATA) {
                    i2++;
                    System.out.println();
                    PrintStream printStream = System.out;
                    printStream.println("Attachment # " + i2);
                    System.out.println();
                }
                PrintStream printStream2 = System.out;
                StringBuilder a = a.a("Level ", read, " : Type ");
                a.append(create.getType());
                a.append(" : ID ");
                a.append(create.getProperty());
                printStream2.println(a.toString());
                if (create instanceof TNEFStringAttribute) {
                    PrintStream printStream3 = System.out;
                    StringBuilder d2 = a.d(JamPrinter.INDENT, JamPrinter.INDENT, JamPrinter.INDENT);
                    d2.append(((TNEFStringAttribute) create).getString());
                    printStream3.println(d2.toString());
                }
                if (create instanceof TNEFDateAttribute) {
                    PrintStream printStream4 = System.out;
                    StringBuilder d3 = a.d(JamPrinter.INDENT, JamPrinter.INDENT, JamPrinter.INDENT);
                    d3.append(((TNEFDateAttribute) create).getDate());
                    printStream4.println(d3.toString());
                }
                PrintStream printStream5 = System.out;
                StringBuilder d4 = a.d(JamPrinter.INDENT, "Data of length ");
                d4.append(create.getData().length);
                printStream5.println(d4.toString());
                if (create.getData().length > 0) {
                    int length = create.getData().length;
                    if (this.truncatePropertyData) {
                        length = Math.min(create.getData().length, 48);
                    }
                    int i3 = length / 16;
                    if (i3 == 0) {
                        i3 = 1;
                    }
                    int i4 = 0;
                    while (i4 < i3) {
                        int i5 = i4 * 16;
                        int i6 = i4 == i3 + -1 ? length - i5 : 16;
                        byte[] bArr = new byte[i6];
                        System.arraycopy(create.getData(), i5, bArr, 0, i6);
                        PrintStream printStream6 = System.out;
                        StringBuilder b2 = a.b(JamPrinter.INDENT);
                        b2.append(HexDump.dump(bArr, 0, 0));
                        printStream6.print(b2.toString());
                        i4++;
                    }
                }
                System.out.println();
                if (create.getProperty() == TNEFProperty.ID_MAPIPROPERTIES || create.getProperty() == TNEFProperty.ID_ATTACHMENT) {
                    Iterator<MAPIAttribute> it = MAPIAttribute.create(create).iterator();
                    while (it.hasNext()) {
                        PrintStream printStream7 = System.out;
                        printStream7.println(JamPrinter.INDENT + JamPrinter.INDENT + it.next());
                    }
                    System.out.println();
                }
            } else {
                return;
            }
        }
    }

    public static void main(String[] strArr) {
        boolean z = true;
        if (strArr.length >= 1) {
            for (String str : strArr) {
                if (str.equalsIgnoreCase("--full")) {
                    z = false;
                } else {
                    FileInputStream fileInputStream = new FileInputStream(str);
                    try {
                        HMEFDumper hMEFDumper = new HMEFDumper(fileInputStream);
                        hMEFDumper.setTruncatePropertyData(z);
                        hMEFDumper.dump();
                    } finally {
                        fileInputStream.close();
                    }
                }
            }
            return;
        }
        throw new IllegalArgumentException("Filename must be given");
    }

    public void setTruncatePropertyData(boolean z) {
        this.truncatePropertyData = z;
    }
}
