package org.apache.poi.hmef.extractor;

import b.b.a.a.a;
import java.io.File;
import java.io.FileInputStream;
import java.io.FileNotFoundException;
import java.io.FileOutputStream;
import java.io.OutputStream;
import java.io.PrintStream;
import org.apache.poi.hmef.Attachment;
import org.apache.poi.hmef.HMEFMessage;
import org.apache.poi.hmef.attribute.MAPIAttribute;
import org.apache.poi.hmef.attribute.MAPIRtfAttribute;
import org.apache.poi.hmef.attribute.MAPIStringAttribute;
import org.apache.poi.hsmf.datatypes.MAPIProperty;
import org.apache.poi.hsmf.datatypes.Types;
import org.apache.poi.util.StringUtil;

public final class HMEFContentsExtractor {
    public final HMEFMessage message;

    public HMEFContentsExtractor(File file) {
        this(new HMEFMessage(new FileInputStream(file)));
    }

    public static void main(String[] strArr) {
        if (strArr.length < 2) {
            System.err.println("Use:");
            System.err.println("  HMEFContentsExtractor <filename> <output dir>");
            System.err.println("");
            System.err.println("");
            System.err.println("Where <filename> is the winmail.dat file to extract,");
            System.err.println(" and <output dir> is where to place the extracted files");
            System.exit(2);
        }
        String str = strArr[0];
        String str2 = strArr[1];
        HMEFContentsExtractor hMEFContentsExtractor = new HMEFContentsExtractor(new File(str));
        File file = new File(str2);
        File file2 = new File(file, "message.rtf");
        if (file.exists()) {
            System.out.println("Extracting...");
            hMEFContentsExtractor.extractMessageBody(file2);
            hMEFContentsExtractor.extractAttachments(file);
            System.out.println("Extraction completed");
            return;
        }
        StringBuilder b2 = a.b("Output directory ");
        b2.append(file.getName());
        b2.append(" not found");
        throw new FileNotFoundException(b2.toString());
    }

    public void extractAttachments(File file) {
        int i2 = 0;
        for (Attachment attachment : this.message.getAttachments()) {
            i2++;
            String longFilename = attachment.getLongFilename();
            if (longFilename == null || longFilename.length() == 0) {
                longFilename = attachment.getFilename();
            }
            if (longFilename == null || longFilename.length() == 0) {
                longFilename = a.c("attachment", i2);
                if (attachment.getExtension() != null) {
                    StringBuilder b2 = a.b(longFilename);
                    b2.append(attachment.getExtension());
                    longFilename = b2.toString();
                }
            }
            FileOutputStream fileOutputStream = new FileOutputStream(new File(file, longFilename));
            try {
                fileOutputStream.write(attachment.getContents());
            } finally {
                fileOutputStream.close();
            }
        }
    }

    public void extractMessageBody(File file) {
        MAPIAttribute bodyAttribute = getBodyAttribute();
        if (bodyAttribute == null) {
            PrintStream printStream = System.err;
            printStream.println("No message body found, " + file + " not created");
            return;
        }
        if (bodyAttribute instanceof MAPIStringAttribute) {
            String file2 = file.toString();
            if (file2.endsWith(".rtf")) {
                file2 = file2.substring(0, file2.length() - 4);
            }
            file = new File(a.b(file2, ".txt"));
        }
        FileOutputStream fileOutputStream = new FileOutputStream(file);
        try {
            if (bodyAttribute instanceof MAPIStringAttribute) {
                fileOutputStream.write(((MAPIStringAttribute) bodyAttribute).getDataString().getBytes(StringUtil.UTF8));
            } else {
                fileOutputStream.write(bodyAttribute.getData());
            }
        } finally {
            fileOutputStream.close();
        }
    }

    public MAPIAttribute getBodyAttribute() {
        MAPIAttribute messageMAPIAttribute = this.message.getMessageMAPIAttribute(MAPIProperty.RTF_COMPRESSED);
        if (messageMAPIAttribute != null) {
            return messageMAPIAttribute;
        }
        return this.message.getMessageMAPIAttribute(MAPIProperty.createCustom(16345, Types.ASCII_STRING, "Uncompressed Body"));
    }

    public HMEFContentsExtractor(HMEFMessage hMEFMessage) {
        this.message = hMEFMessage;
    }

    public void extractMessageBody(OutputStream outputStream) {
        MAPIRtfAttribute mAPIRtfAttribute = (MAPIRtfAttribute) this.message.getMessageMAPIAttribute(MAPIProperty.RTF_COMPRESSED);
        if (mAPIRtfAttribute != null) {
            outputStream.write(mAPIRtfAttribute.getData());
        }
    }
}
