package org.apache.poi.hpbf;

import java.io.InputStream;
import org.apache.poi.POIReadOnlyDocument;
import org.apache.poi.hpbf.model.EscherDelayStm;
import org.apache.poi.hpbf.model.EscherStm;
import org.apache.poi.hpbf.model.MainContents;
import org.apache.poi.hpbf.model.QuillContents;
import org.apache.poi.poifs.filesystem.DirectoryNode;
import org.apache.poi.poifs.filesystem.NPOIFSFileSystem;
import org.apache.poi.poifs.filesystem.POIFSFileSystem;

public final class HPBFDocument extends POIReadOnlyDocument {
    public EscherDelayStm escherDelayStm;
    public EscherStm escherStm;
    public MainContents mainContents;
    public QuillContents quillContents;

    public HPBFDocument(POIFSFileSystem pOIFSFileSystem) {
        this(pOIFSFileSystem.getRoot());
    }

    public EscherDelayStm getEscherDelayStm() {
        return this.escherDelayStm;
    }

    public EscherStm getEscherStm() {
        return this.escherStm;
    }

    public MainContents getMainContents() {
        return this.mainContents;
    }

    public QuillContents getQuillContents() {
        return this.quillContents;
    }

    public HPBFDocument(NPOIFSFileSystem nPOIFSFileSystem) {
        this(nPOIFSFileSystem.getRoot());
    }

    public HPBFDocument(InputStream inputStream) {
        this(new NPOIFSFileSystem(inputStream));
    }

    public HPBFDocument(DirectoryNode directoryNode) {
        super(directoryNode);
        this.mainContents = new MainContents(directoryNode);
        this.quillContents = new QuillContents(directoryNode);
        this.escherStm = new EscherStm(directoryNode);
        this.escherDelayStm = new EscherDelayStm(directoryNode);
    }
}
