package org.apache.poi.hpbf.dev;

import b.b.a.a.a;
import java.io.File;
import java.io.InputStream;
import java.io.PrintStream;
import org.apache.poi.ddf.DefaultEscherRecordFactory;
import org.apache.poi.ddf.EscherRecord;
import org.apache.poi.poifs.filesystem.DirectoryNode;
import org.apache.poi.poifs.filesystem.DocumentInputStream;
import org.apache.poi.poifs.filesystem.NPOIFSFileSystem;
import org.apache.poi.ss.util.SheetUtil;
import org.apache.poi.util.IOUtils;
import org.apache.poi.util.LittleEndian;
import org.apache.poi.util.LocaleUtil;
import org.apache.poi.util.StringUtil;

public final class HPBFDumper {
    public NPOIFSFileSystem fs;

    public HPBFDumper(NPOIFSFileSystem nPOIFSFileSystem) {
        this.fs = nPOIFSFileSystem;
    }

    private String dumpBytes(byte[] bArr, int i2, int i3) {
        StringBuffer stringBuffer = new StringBuffer();
        for (int i4 = 0; i4 < i3; i4++) {
            byte b2 = bArr[i4 + i2];
            int i5 = b2;
            if (b2 < 0) {
                i5 = b2 + 256;
            }
            String hexString = Integer.toHexString(i5 == 1 ? 1 : 0);
            if (hexString.length() == 1) {
                stringBuffer.append(SheetUtil.defaultChar);
            }
            stringBuffer.append(hexString);
            stringBuffer.append(' ');
        }
        return stringBuffer.toString();
    }

    private void dumpEscherStream(byte[] bArr) {
        DefaultEscherRecordFactory defaultEscherRecordFactory = new DefaultEscherRecordFactory();
        int length = bArr.length;
        while (length > 0) {
            EscherRecord createRecord = defaultEscherRecordFactory.createRecord(bArr, 0);
            createRecord.fillFields(bArr, 0, defaultEscherRecordFactory);
            length -= createRecord.getRecordSize();
            System.out.println(createRecord);
        }
    }

    public static byte[] getData(DirectoryNode directoryNode, String str) {
        DocumentInputStream createDocumentInputStream = directoryNode.createDocumentInputStream(str);
        byte[] byteArray = IOUtils.toByteArray(createDocumentInputStream);
        createDocumentInputStream.close();
        return byteArray;
    }

    public static void main(String[] strArr) {
        if (strArr.length < 1) {
            System.err.println("Use:");
            System.err.println("  HPBFDumper <filename>");
            System.exit(1);
        }
        HPBFDumper hPBFDumper = new HPBFDumper(new NPOIFSFileSystem(new File(strArr[0])));
        PrintStream printStream = System.out;
        StringBuilder b2 = a.b("Dumping ");
        b2.append(strArr[0]);
        printStream.println(b2.toString());
        hPBFDumper.dumpContents();
        hPBFDumper.dumpEnvelope();
        hPBFDumper.dumpEscher();
        hPBFDumper.dump001CompObj(hPBFDumper.fs.getRoot());
        hPBFDumper.dumpQuill();
    }

    public void dump001CompObj(DirectoryNode directoryNode) {
    }

    public void dumpCONTENTSguessed(DirectoryNode directoryNode) {
        byte[] bArr;
        String str;
        byte[] data = getData(directoryNode, "CONTENTS");
        System.out.println("");
        PrintStream printStream = System.out;
        StringBuilder b2 = a.b("CONTENTS - ");
        b2.append(data.length);
        b2.append(" bytes long:");
        printStream.println(b2.toString());
        String[] strArr = new String[20];
        String[] strArr2 = new String[20];
        int[] iArr = new int[20];
        int[] iArr2 = new int[20];
        int[] iArr3 = new int[20];
        int[] iArr4 = new int[20];
        int[] iArr5 = new int[20];
        int i2 = 0;
        for (int i3 = 20; i2 < i3; i3 = 20) {
            int i4 = (i2 * 24) + 32;
            if (data[i4] == 24 && data[i4 + 1] == 0) {
                strArr[i2] = new String(data, i4 + 2, 4, LocaleUtil.CHARSET_1252);
                iArr[i2] = LittleEndian.getUShort(data, i4 + 6);
                iArr2[i2] = LittleEndian.getUShort(data, i4 + 8);
                iArr3[i2] = LittleEndian.getUShort(data, i4 + 10);
                strArr2[i2] = new String(data, i4 + 12, 4, LocaleUtil.CHARSET_1252);
                iArr4[i2] = (int) LittleEndian.getUInt(data, i4 + 16);
                iArr5[i2] = (int) LittleEndian.getUInt(data, i4 + 20);
            }
            i2++;
        }
        String fromUnicodeLE = StringUtil.getFromUnicodeLE(data, iArr4[0], iArr5[0] / 2);
        int i5 = 0;
        while (i5 < 20) {
            String c = i5 < 10 ? a.c("0", i5) : Integer.toString(i5);
            PrintStream printStream2 = System.out;
            printStream2.print(c + " ");
            if (strArr[i5] == null) {
                System.out.println("(not present)");
                str = fromUnicodeLE;
            } else {
                PrintStream printStream3 = System.out;
                StringBuilder b3 = a.b("\t");
                str = fromUnicodeLE;
                b3.append(strArr[i5]);
                b3.append(" ");
                b3.append(iArr[i5]);
                b3.append(" ");
                b3.append(iArr2[i5]);
                b3.append(" ");
                b3.append(iArr3[i5]);
                printStream3.println(b3.toString());
                PrintStream printStream4 = System.out;
                StringBuilder b4 = a.b("\t");
                b4.append(strArr2[i5]);
                b4.append(" ");
                b4.append("from: ");
                b4.append(Integer.toHexString(iArr4[i5]));
                b4.append(" (");
                b4.append(iArr4[i5]);
                b4.append(")");
                b4.append(", len: ");
                b4.append(Integer.toHexString(iArr5[i5]));
                b4.append(" (");
                b4.append(iArr5[i5]);
                b4.append(")");
                printStream4.println(b4.toString());
            }
            i5++;
            data = data;
            fromUnicodeLE = str;
        }
        byte[] bArr2 = data;
        System.out.println("");
        System.out.println("TEXT:");
        System.out.println(fromUnicodeLE);
        System.out.println("");
        int i6 = 0;
        while (i6 < 20) {
            if (strArr[i6] == null) {
                bArr = bArr2;
            } else {
                int i7 = iArr4[i6];
                PrintStream printStream5 = System.out;
                printStream5.println(strArr[i6] + " -> " + strArr2[i6] + " @ " + Integer.toHexString(i7) + " (" + i7 + ")");
                PrintStream printStream6 = System.out;
                StringBuilder b5 = a.b("\t");
                bArr = bArr2;
                b5.append(dumpBytes(bArr, i7, 4));
                printStream6.println(b5.toString());
                PrintStream printStream7 = System.out;
                StringBuilder b6 = a.b("\t");
                b6.append(dumpBytes(bArr, i7 + 4, 4));
                printStream7.println(b6.toString());
                PrintStream printStream8 = System.out;
                StringBuilder b7 = a.b("\t");
                b7.append(dumpBytes(bArr, i7 + 8, 4));
                printStream8.println(b7.toString());
                System.out.println("\t(etc)");
            }
            i6++;
            bArr2 = bArr;
        }
    }

    public void dumpCONTENTSraw(DirectoryNode directoryNode) {
        byte[] data = getData(directoryNode, "CONTENTS");
        System.out.println("");
        PrintStream printStream = System.out;
        StringBuilder b2 = a.b("CONTENTS - ");
        b2.append(data.length);
        b2.append(" bytes long:");
        printStream.println(b2.toString());
        System.out.println(new String(data, 0, 8, LocaleUtil.CHARSET_1252) + dumpBytes(data, 8, 24));
        boolean z = true;
        int i2 = 32;
        while (i2 < 512) {
            if (z) {
                System.out.println(dumpBytes(data, i2, 2));
                i2 += 2;
            }
            String str = new String(data, i2, 4, LocaleUtil.CHARSET_1252);
            int i3 = z ? 6 : 8;
            PrintStream printStream2 = System.out;
            StringBuilder d2 = a.d(str, " ");
            d2.append(dumpBytes(data, i2 + 4, i3));
            printStream2.println(d2.toString());
            i2 += i3 + 4;
            z = !z;
        }
        int i4 = -1;
        for (int i5 = 512; i5 < data.length - 2 && i4 == -1; i5++) {
            if (data[i5] == 0 && data[i5 + 1] == 0 && data[i5 + 2] == 0) {
                i4 = i5;
            }
        }
        if (i4 > 0) {
            System.out.println("");
            System.out.println(StringUtil.getFromUnicodeLE(data, 512, (i4 - 512) / 2));
        }
    }

    public void dumpContents() {
        byte[] data = getData(this.fs.getRoot(), "Contents");
        System.out.println("");
        PrintStream printStream = System.out;
        StringBuilder b2 = a.b("Contents - ");
        b2.append(data.length);
        b2.append(" bytes long:");
        printStream.println(b2.toString());
    }

    public void dumpEnvelope() {
        byte[] data = getData(this.fs.getRoot(), "Envelope");
        System.out.println("");
        PrintStream printStream = System.out;
        StringBuilder b2 = a.b("Envelope - ");
        b2.append(data.length);
        b2.append(" bytes long:");
        printStream.println(b2.toString());
    }

    public void dumpEscher() {
        DirectoryNode directoryNode = (DirectoryNode) this.fs.getRoot().getEntry("Escher");
        dumpEscherStm(directoryNode);
        dumpEscherDelayStm(directoryNode);
    }

    public void dumpEscherDelayStm(DirectoryNode directoryNode) {
        byte[] data = getData(directoryNode, "EscherDelayStm");
        System.out.println("");
        PrintStream printStream = System.out;
        StringBuilder b2 = a.b("EscherDelayStm - ");
        b2.append(data.length);
        b2.append(" bytes long:");
        printStream.println(b2.toString());
        if (data.length > 0) {
            dumpEscherStream(data);
        }
    }

    public void dumpEscherStm(DirectoryNode directoryNode) {
        byte[] data = getData(directoryNode, "EscherStm");
        System.out.println("");
        PrintStream printStream = System.out;
        StringBuilder b2 = a.b("EscherStm - ");
        b2.append(data.length);
        b2.append(" bytes long:");
        printStream.println(b2.toString());
        if (data.length > 0) {
            dumpEscherStream(data);
        }
    }

    public void dumpQuill() {
        DirectoryNode directoryNode = (DirectoryNode) ((DirectoryNode) this.fs.getRoot().getEntry("Quill")).getEntry("QuillSub");
        dump001CompObj(directoryNode);
        dumpCONTENTSraw(directoryNode);
        dumpCONTENTSguessed(directoryNode);
    }

    public HPBFDumper(InputStream inputStream) {
        this(new NPOIFSFileSystem(inputStream));
    }
}
