package org.apache.poi.hpbf.model;

import b.b.a.a.a;
import org.apache.poi.hpbf.model.qcbits.QCBit;
import org.apache.poi.hpbf.model.qcbits.QCPLCBit;
import org.apache.poi.hpbf.model.qcbits.QCTextBit;
import org.apache.poi.hpbf.model.qcbits.UnknownQCBit;
import org.apache.poi.poifs.filesystem.DirectoryNode;
import org.apache.poi.util.LittleEndian;
import org.apache.poi.util.LocaleUtil;
import org.apache.poi.util.POILogFactory;
import org.apache.poi.util.POILogger;

public final class QuillContents extends HPBFPart {
    public static final String[] PATH = {"Quill", "QuillSub", "CONTENTS"};
    public static POILogger logger = POILogFactory.getLogger(QuillContents.class);
    public QCBit[] bits;

    public QuillContents(DirectoryNode directoryNode) {
        super(directoryNode, PATH);
        byte[] data = getData();
        String str = new String(data, 0, 8, LocaleUtil.CHARSET_1252);
        if (str.equals("CHNKINK ")) {
            this.bits = new QCBit[20];
            for (int i2 = 0; i2 < 20; i2++) {
                int i3 = (i2 * 24) + 32;
                if (data[i3] == 24 && data[i3 + 1] == 0) {
                    String str2 = new String(data, i3 + 2, 4, LocaleUtil.CHARSET_1252);
                    int uShort = LittleEndian.getUShort(data, i3 + 6);
                    int uShort2 = LittleEndian.getUShort(data, i3 + 8);
                    int uShort3 = LittleEndian.getUShort(data, i3 + 10);
                    String str3 = new String(data, i3 + 12, 4, LocaleUtil.CHARSET_1252);
                    int uInt = (int) LittleEndian.getUInt(data, i3 + 16);
                    int uInt2 = (int) LittleEndian.getUInt(data, i3 + 20);
                    byte[] bArr = new byte[uInt2];
                    System.arraycopy(data, uInt, bArr, 0, uInt2);
                    if (str3.equals("TEXT")) {
                        this.bits[i2] = new QCTextBit(str2, str3, bArr);
                    } else if (str3.equals("PLC ")) {
                        try {
                            this.bits[i2] = QCPLCBit.createQCPLCBit(str2, str3, bArr);
                        } catch (ArrayIndexOutOfBoundsException unused) {
                            logger.log(5, "Unable to read Quill Contents PLC Bit record. Ignoring this record.");
                            this.bits[i2] = new UnknownQCBit(str2, str3, bArr);
                        }
                    } else {
                        this.bits[i2] = new UnknownQCBit(str2, str3, bArr);
                    }
                    this.bits[i2].setOptA(uShort);
                    this.bits[i2].setOptB(uShort2);
                    this.bits[i2].setOptC(uShort3);
                    this.bits[i2].setDataOffset(uInt);
                }
            }
            return;
        }
        throw new IllegalArgumentException(a.b("Expecting 'CHNKINK ' but was '", str, "'"));
    }

    @Override // org.apache.poi.hpbf.model.HPBFPart
    public void generateData() {
        throw new IllegalStateException("Not done yet!");
    }

    public QCBit[] getBits() {
        return this.bits;
    }
}
