package org.apache.poi.hpbf.model.qcbits;

import b.b.a.a.a;
import org.apache.poi.util.LittleEndian;
import org.apache.poi.util.StringUtil;

public abstract class QCPLCBit extends QCBit {
    public int numberOfPLCs;
    public long[] plcValA;
    public long[] plcValB;
    public int[] preData;
    public int typeOfPLCS;

    public static class Type0 extends QCPLCBit {
        public Type0(String str, String str2, byte[] bArr) {
            super(str, str2, bArr);
            setPreData(new int[]{LittleEndian.getUShort(bArr, 8), LittleEndian.getUShort(bArr, 10), LittleEndian.getUShort(bArr, 12), LittleEndian.getUShort(bArr, 14)});
            int numberOfPLCs = getNumberOfPLCs();
            long[] jArr = new long[numberOfPLCs];
            long[] jArr2 = new long[numberOfPLCs];
            for (int i2 = 0; i2 < numberOfPLCs; i2++) {
                int i3 = (i2 * 4) + 16;
                jArr[i2] = (long) LittleEndian.getUShort(bArr, i3);
                jArr2[i2] = (long) LittleEndian.getUShort(bArr, i3 + 2);
            }
            setPlcValA(jArr);
            setPlcValB(jArr2);
        }
    }

    public static class Type12 extends QCPLCBit {
        public static final int oneStartsAt = 76;
        public static final int threePlusIncrement = 22;
        public static final int twoStartsAt = 104;
        public String[] hyperlinks;

        public int getAllTextEndAt() {
            return getPreData()[getNumberOfPLCs() + 1];
        }

        public String getHyperlink(int i2) {
            return this.hyperlinks[i2];
        }

        public int getNumberOfHyperlinks() {
            return this.hyperlinks.length;
        }

        public int getTextStartAt(int i2) {
            return getPreData()[i2 + 1];
        }

        public Type12(String str, String str2, byte[] bArr) {
            super(str, str2, bArr);
            int numberOfPLCs = getNumberOfPLCs();
            int i2 = 52;
            this.hyperlinks = new String[(bArr.length == 52 ? 0 : numberOfPLCs)];
            int i3 = numberOfPLCs + 1 + 1;
            int[] iArr = new int[i3];
            for (int i4 = 0; i4 < i3; i4++) {
                iArr[i4] = (int) LittleEndian.getUInt(bArr, (i4 * 4) + 8);
            }
            setPreData(iArr);
            int i5 = (numberOfPLCs * 4) + 12 + 4;
            if (numberOfPLCs == 1 && this.hyperlinks.length == 1) {
                i2 = 76;
            } else if (numberOfPLCs >= 2) {
                i2 = ((numberOfPLCs - 2) * 22) + 104;
            }
            int i6 = (i2 - i5) / 2;
            long[] jArr = new long[i6];
            long[] jArr2 = new long[0];
            for (int i7 = 0; i7 < i6; i7++) {
                jArr[i7] = (long) LittleEndian.getUShort(bArr, (i7 * 2) + i5);
            }
            setPlcValA(jArr);
            setPlcValB(jArr2);
            for (int i8 = 0; i8 < this.hyperlinks.length; i8++) {
                int uShort = LittleEndian.getUShort(bArr, i2);
                int i9 = i2 + 2;
                if (LittleEndian.getUShort(bArr, i9) == 0) {
                    this.hyperlinks[i8] = "";
                    i2 += uShort;
                } else {
                    this.hyperlinks[i8] = StringUtil.getFromUnicodeLE(bArr, i9, uShort);
                    i2 = (uShort * 2) + 2 + i2;
                }
            }
        }
    }

    public static class Type4 extends QCPLCBit {
        public Type4(String str, String str2, byte[] bArr) {
            super(str, str2, bArr);
            setPreData(new int[]{LittleEndian.getUShort(bArr, 8), LittleEndian.getUShort(bArr, 10), LittleEndian.getUShort(bArr, 12), LittleEndian.getUShort(bArr, 14)});
            int numberOfPLCs = getNumberOfPLCs();
            long[] jArr = new long[numberOfPLCs];
            long[] jArr2 = new long[numberOfPLCs];
            for (int i2 = 0; i2 < numberOfPLCs; i2++) {
                int i3 = (i2 * 8) + 16;
                jArr[i2] = LittleEndian.getUInt(bArr, i3);
                jArr2[i2] = LittleEndian.getUInt(bArr, i3 + 4);
            }
            setPlcValA(jArr);
            setPlcValB(jArr2);
        }
    }

    public static class Type8 extends QCPLCBit {
        public Type8(String str, String str2, byte[] bArr) {
            super(str, str2, bArr);
            setPreData(new int[]{LittleEndian.getUShort(bArr, 8), LittleEndian.getUShort(bArr, 10), LittleEndian.getUShort(bArr, 12), LittleEndian.getUShort(bArr, 14), LittleEndian.getUShort(bArr, 16), LittleEndian.getUShort(bArr, 18), LittleEndian.getUShort(bArr, 20)});
            int numberOfPLCs = getNumberOfPLCs();
            long[] jArr = new long[numberOfPLCs];
            long[] jArr2 = new long[numberOfPLCs];
            for (int i2 = 0; i2 < numberOfPLCs; i2++) {
                int i3 = (i2 * 8) + 22;
                jArr[i2] = LittleEndian.getUInt(bArr, i3);
                jArr2[i2] = LittleEndian.getUInt(bArr, i3 + 4);
            }
            setPlcValA(jArr);
            setPlcValB(jArr2);
        }
    }

    public static QCPLCBit createQCPLCBit(String str, String str2, byte[] bArr) {
        int uInt = (int) LittleEndian.getUInt(bArr, 4);
        if (uInt == 0) {
            return new Type0(str, str2, bArr);
        }
        if (uInt == 4) {
            return new Type4(str, str2, bArr);
        }
        if (uInt == 8) {
            return new Type8(str, str2, bArr);
        }
        if (uInt == 12) {
            return new Type12(str, str2, bArr);
        }
        throw new IllegalArgumentException(a.c("Sorry, I don't know how to deal with PLCs of type ", uInt));
    }

    public int getNumberOfPLCs() {
        return this.numberOfPLCs;
    }

    public long[] getPlcValA() {
        return this.plcValA;
    }

    public long[] getPlcValB() {
        return this.plcValB;
    }

    public int[] getPreData() {
        return this.preData;
    }

    public int getTypeOfPLCS() {
        return this.typeOfPLCS;
    }

    public final void setPlcValA(long[] jArr) {
        this.plcValA = (long[]) jArr.clone();
    }

    public final void setPlcValB(long[] jArr) {
        this.plcValB = (long[]) jArr.clone();
    }

    public final void setPreData(int[] iArr) {
        this.preData = (int[]) iArr.clone();
    }

    public QCPLCBit(String str, String str2, byte[] bArr) {
        super(str, str2, bArr);
        this.numberOfPLCs = (int) LittleEndian.getUInt(bArr, 0);
        this.typeOfPLCS = (int) LittleEndian.getUInt(bArr, 4);
        int i2 = this.numberOfPLCs;
        this.plcValA = new long[i2];
        this.plcValB = new long[i2];
    }
}
