package org.apache.poi.hpsf;

import b.b.a.a.a;
import java.io.OutputStream;
import org.apache.poi.util.CodePageUtil;
import org.apache.poi.util.Internal;
import org.apache.poi.util.LittleEndian;
import org.apache.poi.util.LittleEndianByteArrayInputStream;
import org.apache.poi.util.POILogFactory;
import org.apache.poi.util.POILogger;

@Internal
public class CodePageString {
    public static final POILogger LOG = POILogFactory.getLogger(CodePageString.class);
    public byte[] _value;

    public String getJavaValue(int i2) {
        if (i2 == -1) {
            i2 = 1252;
        }
        String stringFromCodePage = CodePageUtil.getStringFromCodePage(this._value, i2);
        int indexOf = stringFromCodePage.indexOf(0);
        if (indexOf == -1) {
            LOG.log(5, "String terminator (\\0) for CodePageString property value not found.Continue without trimming and hope for the best.");
            return stringFromCodePage;
        }
        if (indexOf != stringFromCodePage.length() - 1) {
            LOG.log(5, "String terminator (\\0) for CodePageString property value occured before the end of string. Trimming and hope for the best.");
        }
        return stringFromCodePage.substring(0, indexOf);
    }

    public int getSize() {
        return this._value.length + 4;
    }

    public void read(LittleEndianByteArrayInputStream littleEndianByteArrayInputStream) {
        int readIndex = littleEndianByteArrayInputStream.getReadIndex();
        int readInt = littleEndianByteArrayInputStream.readInt();
        byte[] bArr = new byte[readInt];
        this._value = bArr;
        if (readInt != 0) {
            littleEndianByteArrayInputStream.readFully(bArr);
            if (this._value[readInt - 1] != 0) {
                String b2 = a.b("CodePageString started at offset #", readIndex, " is not NULL-terminated");
                LOG.log(5, b2);
            }
            TypedPropertyValue.skipPadding(littleEndianByteArrayInputStream);
        }
    }

    public void setJavaValue(String str, int i2) {
        if (i2 == -1) {
            i2 = 1252;
        }
        this._value = CodePageUtil.getBytesInCodePage(str + "\u0000", i2);
    }

    public int write(OutputStream outputStream) {
        LittleEndian.putUInt((long) this._value.length, outputStream);
        outputStream.write(this._value);
        return this._value.length + 4;
    }
}
