package org.apache.poi.hpsf;

import b.b.a.a.a;
import java.io.InputStream;
import java.util.Iterator;
import java.util.LinkedList;
import java.util.Map;
import org.apache.poi.hpsf.wellknown.PropertyIDMap;
import org.apache.poi.hpsf.wellknown.SectionIDMap;

public class DocumentSummaryInformation extends SpecialPropertySet {
    public static final String DEFAULT_STREAM_NAME = "\u0005DocumentSummaryInformation";

    public DocumentSummaryInformation() {
        getFirstSection().setFormatID(SectionIDMap.DOCUMENT_SUMMARY_INFORMATION_ID[0]);
    }

    private void ensureSection2() {
        if (getSectionCount() < 2) {
            MutableSection mutableSection = new MutableSection();
            mutableSection.setFormatID(SectionIDMap.DOCUMENT_SUMMARY_INFORMATION_ID[1]);
            addSection(mutableSection);
        }
    }

    private void notYetImplemented(String str) {
        throw new UnsupportedOperationException(a.b(str, " is not yet implemented."));
    }

    public int getApplicationVersion() {
        return getPropertyIntValue(23);
    }

    public int getByteCount() {
        return getPropertyIntValue(4);
    }

    public String getCategory() {
        return getPropertyStringValue(2);
    }

    public int getCharCountWithSpaces() {
        return getPropertyIntValue(17);
    }

    public String getCompany() {
        return getPropertyStringValue(15);
    }

    public String getContentStatus() {
        return getPropertyStringValue(27);
    }

    public String getContentType() {
        return getPropertyStringValue(26);
    }

    public CustomProperties getCustomProperties() {
        if (getSectionCount() < 2) {
            return null;
        }
        CustomProperties customProperties = new CustomProperties();
        Section section = getSections().get(1);
        Map<Long, String> dictionary = section.getDictionary();
        Property[] properties = section.getProperties();
        int i2 = 0;
        for (Property property : properties) {
            long id = property.getID();
            int i3 = (id > 1 ? 1 : (id == 1 ? 0 : -1));
            if (i3 == 0) {
                customProperties.setCodepage(((Integer) property.getValue()).intValue());
            } else if (i3 > 0) {
                i2++;
                CustomProperty customProperty = new CustomProperty(property, dictionary.get(Long.valueOf(id)));
                customProperties.put(customProperty.getName(), customProperty);
            }
        }
        if (customProperties.size() == i2) {
            return customProperties;
        }
        customProperties.setPure(false);
        return customProperties;
    }

    public byte[] getDocparts() {
        notYetImplemented("Reading byte arrays");
        return (byte[]) getProperty(13);
    }

    public String getDocumentVersion() {
        return getPropertyStringValue(29);
    }

    public byte[] getHeadingPair() {
        notYetImplemented("Reading byte arrays ");
        return (byte[]) getProperty(12);
    }

    public int getHiddenCount() {
        return getPropertyIntValue(9);
    }

    public boolean getHyperlinksChanged() {
        return getPropertyBooleanValue(22);
    }

    public String getLanguage() {
        return getPropertyStringValue(28);
    }

    public int getLineCount() {
        return getPropertyIntValue(5);
    }

    public boolean getLinksDirty() {
        return getPropertyBooleanValue(16);
    }

    public int getMMClipCount() {
        return getPropertyIntValue(10);
    }

    public String getManager() {
        return getPropertyStringValue(14);
    }

    public int getNoteCount() {
        return getPropertyIntValue(8);
    }

    public int getParCount() {
        return getPropertyIntValue(6);
    }

    public String getPresentationFormat() {
        return getPropertyStringValue(3);
    }

    @Override // org.apache.poi.hpsf.PropertySet
    public PropertyIDMap getPropertySetIDMap() {
        return PropertyIDMap.getDocumentSummaryInformationProperties();
    }

    public boolean getScale() {
        return getPropertyBooleanValue(11);
    }

    public int getSlideCount() {
        return getPropertyIntValue(7);
    }

    public byte[] getVBADigitalSignature() {
        Object property = getProperty(24);
        if (property == null || !(property instanceof byte[])) {
            return null;
        }
        return (byte[]) property;
    }

    public void removeApplicationVersion() {
        remove1stProperty(23);
    }

    public void removeByteCount() {
        remove1stProperty(4);
    }

    public void removeCategory() {
        remove1stProperty(2);
    }

    public void removeCharCountWithSpaces() {
        remove1stProperty(17);
    }

    public void removeCompany() {
        remove1stProperty(15);
    }

    public void removeContentStatus() {
        remove1stProperty(27);
    }

    public void removeContentType() {
        remove1stProperty(26);
    }

    public void removeCustomProperties() {
        if (getSectionCount() >= 2) {
            LinkedList linkedList = new LinkedList(getSections());
            clearSections();
            int i2 = 0;
            Iterator it = linkedList.iterator();
            while (it.hasNext()) {
                Section section = (Section) it.next();
                int i3 = i2 + 1;
                if (i2 != 1) {
                    addSection(section);
                }
                i2 = i3;
            }
            return;
        }
        throw new HPSFRuntimeException("Illegal internal format of Document SummaryInformation stream: second section is missing.");
    }

    public void removeDocparts() {
        remove1stProperty(13);
    }

    public void removeDocumentVersion() {
        remove1stProperty(29);
    }

    public void removeHeadingPair() {
        remove1stProperty(12);
    }

    public void removeHiddenCount() {
        remove1stProperty(9);
    }

    public void removeHyperlinksChanged() {
        remove1stProperty(22);
    }

    public void removeLanguage() {
        remove1stProperty(28);
    }

    public void removeLineCount() {
        remove1stProperty(5);
    }

    public void removeLinksDirty() {
        remove1stProperty(16);
    }

    public void removeMMClipCount() {
        remove1stProperty(10);
    }

    public void removeManager() {
        remove1stProperty(14);
    }

    public void removeNoteCount() {
        remove1stProperty(8);
    }

    public void removeParCount() {
        remove1stProperty(6);
    }

    public void removePresentationFormat() {
        remove1stProperty(3);
    }

    public void removeScale() {
        remove1stProperty(11);
    }

    public void removeSlideCount() {
        remove1stProperty(7);
    }

    public void removeVBADigitalSignature() {
        remove1stProperty(24);
    }

    public void setApplicationVersion(int i2) {
        set1stProperty(23, i2);
    }

    public void setByteCount(int i2) {
        set1stProperty(4, i2);
    }

    public void setCategory(String str) {
        getFirstSection().setProperty(2, str);
    }

    public void setCharCountWithSpaces(int i2) {
        set1stProperty(17, i2);
    }

    public void setCompany(String str) {
        set1stProperty(15, str);
    }

    public void setContentStatus(String str) {
        set1stProperty(27, str);
    }

    public void setContentType(String str) {
        set1stProperty(26, str);
    }

    public void setCustomProperties(CustomProperties customProperties) {
        ensureSection2();
        Section section = getSections().get(1);
        Map<Long, String> dictionary = customProperties.getDictionary();
        int codepage = customProperties.getCodepage();
        if (codepage < 0) {
            codepage = section.getCodepage();
        }
        if (codepage < 0) {
            codepage = 1252;
        }
        customProperties.setCodepage(codepage);
        section.setCodepage(codepage);
        section.setDictionary(dictionary);
        for (CustomProperty customProperty : customProperties.properties()) {
            section.setProperty(customProperty);
        }
    }

    public void setDocparts(byte[] bArr) {
        notYetImplemented("Writing byte arrays");
    }

    public void setDocumentVersion(String str) {
        set1stProperty(29, str);
    }

    public void setHeadingPair(byte[] bArr) {
        notYetImplemented("Writing byte arrays ");
    }

    public void setHiddenCount(int i2) {
        set1stProperty(9, i2);
    }

    public void setHyperlinksChanged(boolean z) {
        set1stProperty(22, z);
    }

    public void setLanguage(String str) {
        set1stProperty(28, str);
    }

    public void setLineCount(int i2) {
        set1stProperty(5, i2);
    }

    public void setLinksDirty(boolean z) {
        set1stProperty(16, z);
    }

    public void setMMClipCount(int i2) {
        set1stProperty(10, i2);
    }

    public void setManager(String str) {
        set1stProperty(14, str);
    }

    public void setNoteCount(int i2) {
        set1stProperty(8, i2);
    }

    public void setParCount(int i2) {
        set1stProperty(6, i2);
    }

    public void setPresentationFormat(String str) {
        getFirstSection().setProperty(3, str);
    }

    public void setScale(boolean z) {
        set1stProperty(11, z);
    }

    public void setSlideCount(int i2) {
        set1stProperty(7, i2);
    }

    public void setVBADigitalSignature(byte[] bArr) {
        set1stProperty(24, bArr);
    }

    public DocumentSummaryInformation(PropertySet propertySet) {
        super(propertySet);
        if (!isDocumentSummaryInformation()) {
            StringBuilder b2 = a.b("Not a ");
            b2.append(DocumentSummaryInformation.class.getName());
            throw new UnexpectedPropertySetTypeException(b2.toString());
        }
    }

    public DocumentSummaryInformation(InputStream inputStream) {
        super(inputStream);
    }
}
