package org.apache.poi.hpsf;

import java.io.OutputStream;
import java.util.Date;
import org.apache.poi.util.LittleEndian;
import org.apache.poi.util.LittleEndianByteArrayInputStream;

public class Filetime {
    public static final long EPOCH_DIFF = -11644473600000L;
    public static final long NANO_100 = 10000;
    public static final int SIZE = 8;
    public static final long UINT_MASK = 4294967295L;
    public int _dwHighDateTime;
    public int _dwLowDateTime;

    public Filetime() {
    }

    public static long dateToFileTime(Date date) {
        return (date.getTime() - EPOCH_DIFF) * NANO_100;
    }

    public static Date filetimeToDate(long j) {
        return new Date((j / NANO_100) + EPOCH_DIFF);
    }

    public static boolean isUndefined(Date date) {
        return date == null || dateToFileTime(date) == 0;
    }

    public long getHigh() {
        return (long) this._dwHighDateTime;
    }

    public Date getJavaValue() {
        return filetimeToDate((((long) this._dwHighDateTime) << 32) | (((long) this._dwLowDateTime) & UINT_MASK));
    }

    public long getLow() {
        return (long) this._dwLowDateTime;
    }

    public void read(LittleEndianByteArrayInputStream littleEndianByteArrayInputStream) {
        this._dwLowDateTime = littleEndianByteArrayInputStream.readInt();
        this._dwHighDateTime = littleEndianByteArrayInputStream.readInt();
    }

    public byte[] toByteArray() {
        byte[] bArr = new byte[8];
        LittleEndian.putInt(bArr, 0, this._dwLowDateTime);
        LittleEndian.putInt(bArr, 4, this._dwHighDateTime);
        return bArr;
    }

    public int write(OutputStream outputStream) {
        LittleEndian.putInt(this._dwLowDateTime, outputStream);
        LittleEndian.putInt(this._dwHighDateTime, outputStream);
        return 8;
    }

    public Filetime(int i2, int i3) {
        this._dwLowDateTime = i2;
        this._dwHighDateTime = i3;
    }

    public Filetime(Date date) {
        long dateToFileTime = dateToFileTime(date);
        this._dwHighDateTime = (int) ((dateToFileTime >>> 32) & UINT_MASK);
        this._dwLowDateTime = (int) (dateToFileTime & UINT_MASK);
    }
}
