package org.apache.poi.hpsf;

import i.a.a.a.m.a;
import java.io.ByteArrayOutputStream;
import java.io.OutputStream;
import java.util.Date;
import java.util.HashMap;
import java.util.HashSet;
import java.util.Iterator;
import java.util.LinkedHashMap;
import java.util.Map;
import java.util.NoSuchElementException;
import java.util.TreeMap;
import org.apache.poi.hpsf.wellknown.PropertyIDMap;
import org.apache.poi.hpsf.wellknown.SectionIDMap;
import org.apache.poi.util.CodePageUtil;
import org.apache.poi.util.LittleEndian;
import org.apache.poi.util.LittleEndianByteArrayInputStream;
import org.apache.poi.util.POILogFactory;
import org.apache.poi.util.POILogger;
import org.apache.xerces.util.SecurityManager;

public class Section {
    public static final POILogger LOG = POILogFactory.getLogger(Section.class);
    public final long _offset;
    public Map<Long, String> dictionary;
    public ClassID formatID;
    public final Map<Long, Property> properties;
    public final ByteArrayOutputStream sectionBytes;
    public boolean wasNull;

    public Section() {
        this.sectionBytes = new ByteArrayOutputStream();
        this.properties = new LinkedHashMap();
        this._offset = -1;
    }

    private int calcSize() {
        this.sectionBytes.reset();
        write(this.sectionBytes);
        padSectionBytes();
        return this.sectionBytes.size();
    }

    private void padSectionBytes() {
        int size = 3 & (4 - (this.sectionBytes.size() & 3));
        this.sectionBytes.write(new byte[]{0, 0, 0}, 0, size);
    }

    public static int propLen(a<Long, Long> aVar, Long l, long j) {
        K k = null;
        if (aVar != null) {
            a.c(l, a.EnumC0057a.KEY);
            a.h<Long, Long> g2 = aVar.g(aVar.d(l), a.EnumC0057a.KEY);
            if (g2 != null) {
                k = g2.x;
            }
            Long l2 = (Long) k;
            long longValue = l.longValue();
            if (l2 != null) {
                j = l2.longValue();
            }
            return (int) (j - longValue);
        }
        throw null;
    }

    private boolean readDictionary(LittleEndianByteArrayInputStream littleEndianByteArrayInputStream, int i2, int i3) {
        HashMap hashMap = new HashMap();
        long readUInt = littleEndianByteArrayInputStream.readUInt();
        boolean z = false;
        long j = -1;
        int i4 = 0;
        while (true) {
            if (((long) i4) >= readUInt) {
                break;
            }
            String str = "The property set's dictionary contains bogus data. All dictionary entries starting with the one with ID " + j + " will be ignored.";
            long readUInt2 = littleEndianByteArrayInputStream.readUInt();
            long readUInt3 = littleEndianByteArrayInputStream.readUInt();
            int i5 = i3 == -1 ? 1252 : i3;
            int i6 = (int) ((readUInt3 - 1) * ((long) (i5 == 1200 ? 2 : 1)));
            if (i6 > 16777215) {
                LOG.log(5, str);
                break;
            }
            try {
                byte[] bArr = new byte[i6];
                littleEndianByteArrayInputStream.readFully(bArr, 0, i6);
                String stringFromCodePage = CodePageUtil.getStringFromCodePage(bArr, 0, i6, i5);
                littleEndianByteArrayInputStream.skip((long) (i5 == 1200 ? ((4 - ((i6 + 2) & 3)) & 3) + 2 : 1));
                hashMap.put(Long.valueOf(readUInt2), stringFromCodePage);
                i4++;
                j = readUInt2;
            } catch (RuntimeException e2) {
                LOG.log(5, str, e2);
                z = true;
                setDictionary(hashMap);
                return !z;
            }
        }
        setDictionary(hashMap);
        return !z;
    }

    private int writeDictionary(OutputStream outputStream, int i2) {
        byte[] bArr = new byte[4];
        Map<Long, String> dictionary2 = getDictionary();
        LittleEndian.putUInt((long) dictionary2.size(), outputStream);
        int i3 = 4;
        for (Map.Entry<Long, String> entry : dictionary2.entrySet()) {
            LittleEndian.putUInt(entry.getKey().longValue(), outputStream);
            String a = b.b.a.a.a.a(new StringBuilder(), entry.getValue(), "\u0000");
            LittleEndian.putUInt((long) a.length(), outputStream);
            byte[] bytesInCodePage = CodePageUtil.getBytesInCodePage(a, i2);
            outputStream.write(bytesInCodePage);
            i3 = i3 + 4 + 4 + bytesInCodePage.length;
            if (i2 == 1200) {
                int i4 = (4 - (i3 & 3)) & 3;
                outputStream.write(bArr, 0, i4);
                i3 += i4;
            }
        }
        int i5 = (4 - (i3 & 3)) & 3;
        outputStream.write(bArr, 0, i5);
        return i3 + i5;
    }

    public void clear() {
        for (Property property : getProperties()) {
            removeProperty(property.getID());
        }
    }

    /* JADX WARNING: Removed duplicated region for block: B:9:0x0047  */
    public boolean equals(Object obj) {
        if (!(obj instanceof Section)) {
            return false;
        }
        Section section = (Section) obj;
        if (!section.getFormatID().equals(getFormatID())) {
            return false;
        }
        HashSet hashSet = new HashSet(this.properties.keySet());
        hashSet.addAll(section.properties.keySet());
        hashSet.remove(0L);
        hashSet.remove(1L);
        Iterator it = hashSet.iterator();
        while (it.hasNext()) {
            Long l = (Long) it.next();
            Property property = this.properties.get(l);
            Property property2 = section.properties.get(l);
            if (property == null || property2 == null || !property.equals(property2)) {
                return false;
            }
            while (it.hasNext()) {
            }
        }
        Map<Long, String> dictionary2 = getDictionary();
        Map<Long, String> dictionary3 = section.getDictionary();
        if ((dictionary2 != null || dictionary3 != null) && (dictionary2 == null || dictionary3 == null || !dictionary2.equals(dictionary3))) {
            return false;
        }
        return true;
    }

    public int getCodepage() {
        Integer num = (Integer) getProperty(1);
        if (num == null) {
            return -1;
        }
        return num.intValue();
    }

    public Map<Long, String> getDictionary() {
        if (this.dictionary == null) {
            this.dictionary = (Map) getProperty(0);
        }
        return this.dictionary;
    }

    public ClassID getFormatID() {
        return this.formatID;
    }

    public long getOffset() {
        return this._offset;
    }

    public String getPIDString(long j) {
        Map<Long, String> dictionary2 = getDictionary();
        String str = dictionary2 != null ? dictionary2.get(Long.valueOf(j)) : null;
        return str == null ? SectionIDMap.getPIDString(getFormatID(), j) : str;
    }

    public Property[] getProperties() {
        return (Property[]) this.properties.values().toArray(new Property[this.properties.size()]);
    }

    public Object getProperty(long j) {
        boolean z = !this.properties.containsKey(Long.valueOf(j));
        this.wasNull = z;
        if (z) {
            return null;
        }
        return this.properties.get(Long.valueOf(j)).getValue();
    }

    public boolean getPropertyBooleanValue(int i2) {
        Boolean bool = (Boolean) getProperty((long) i2);
        if (bool == null) {
            return false;
        }
        return bool.booleanValue();
    }

    public int getPropertyCount() {
        return this.properties.size();
    }

    public int getPropertyIntValue(long j) {
        Object property = getProperty(j);
        if (property == null) {
            return 0;
        }
        if ((property instanceof Long) || (property instanceof Integer)) {
            return ((Number) property).intValue();
        }
        StringBuilder b2 = b.b.a.a.a.b("This property is not an integer type, but ");
        b2.append(property.getClass().getName());
        b2.append(".");
        throw new HPSFRuntimeException(b2.toString());
    }

    public int getSize() {
        int size = this.sectionBytes.size();
        if (size > 0) {
            return size;
        }
        try {
            return calcSize();
        } catch (HPSFRuntimeException e2) {
            throw e2;
        } catch (Exception e3) {
            throw new HPSFRuntimeException(e3);
        }
    }

    public int hashCode() {
        Property[] properties2;
        long hashCode = ((long) getFormatID().hashCode()) + 0;
        for (Property property : getProperties()) {
            hashCode += (long) property.hashCode();
        }
        return (int) (hashCode & Filetime.UINT_MASK);
    }

    public void removeProperty(long j) {
        if (this.properties.remove(Long.valueOf(j)) != null) {
            this.sectionBytes.reset();
        }
    }

    public void setCodepage(int i2) {
        setProperty(1, 2, Integer.valueOf(i2));
    }

    public void setDictionary(Map<Long, String> map) {
        if (map != null) {
            if (this.dictionary == null) {
                this.dictionary = new TreeMap();
            }
            this.dictionary.putAll(map);
            if (getCodepage() == -1) {
                setCodepage(1252);
            }
            setProperty(0, -1, map);
            return;
        }
        removeProperty(0);
        this.dictionary = null;
    }

    public void setFormatID(ClassID classID) {
        this.formatID = classID;
    }

    public void setProperties(Property[] propertyArr) {
        this.properties.clear();
        for (Property property : propertyArr) {
            setProperty(property);
        }
    }

    public void setProperty(int i2, String str) {
        setProperty(i2, 30, str);
    }

    public void setPropertyBooleanValue(int i2, boolean z) {
        setProperty(i2, 11, Boolean.valueOf(z));
    }

    public String toString() {
        return toString(null);
    }

    public boolean wasNull() {
        return this.wasNull;
    }

    public int write(OutputStream outputStream) {
        if (this.sectionBytes.size() > 0) {
            this.sectionBytes.writeTo(outputStream);
            return this.sectionBytes.size();
        }
        int codepage = getCodepage();
        if (codepage == -1) {
            LOG.log(5, "The codepage property is not set although a dictionary is present. Defaulting to ISO-8859-1.");
            codepage = 1252;
        }
        ByteArrayOutputStream byteArrayOutputStream = new ByteArrayOutputStream();
        ByteArrayOutputStream byteArrayOutputStream2 = new ByteArrayOutputStream();
        int propertyCount = (getPropertyCount() * 2 * 4) + 8 + 0;
        for (Property property : this.properties.values()) {
            long id = property.getID();
            LittleEndian.putUInt(id, byteArrayOutputStream2);
            LittleEndian.putUInt((long) propertyCount, byteArrayOutputStream2);
            if (id != 0) {
                propertyCount = property.write(byteArrayOutputStream, codepage) + propertyCount;
            } else if (codepage != -1) {
                propertyCount += writeDictionary(byteArrayOutputStream, codepage);
            } else {
                throw new IllegalPropertySetDataException("Codepage (property 1) is undefined.");
            }
        }
        int size = byteArrayOutputStream.size() + byteArrayOutputStream2.size() + 8;
        LittleEndian.putInt(size, outputStream);
        LittleEndian.putInt(getPropertyCount(), outputStream);
        byteArrayOutputStream2.writeTo(outputStream);
        byteArrayOutputStream.writeTo(outputStream);
        return size;
    }

    public void setFormatID(byte[] bArr) {
        ClassID formatID2 = getFormatID();
        if (formatID2 == null) {
            formatID2 = new ClassID();
            setFormatID(formatID2);
        }
        formatID2.setBytes(bArr);
    }

    public void setProperty(int i2, int i3) {
        setProperty(i2, 3, Integer.valueOf(i3));
    }

    public String toString(PropertyIDMap propertyIDMap) {
        StringBuffer stringBuffer = new StringBuffer();
        Property[] properties2 = getProperties();
        stringBuffer.append("\n\n\n");
        stringBuffer.append(getClass().getName());
        stringBuffer.append('[');
        stringBuffer.append("formatID: ");
        stringBuffer.append(getFormatID());
        stringBuffer.append(", offset: ");
        stringBuffer.append(getOffset());
        stringBuffer.append(", propertyCount: ");
        stringBuffer.append(getPropertyCount());
        stringBuffer.append(", size: ");
        stringBuffer.append(getSize());
        stringBuffer.append(", properties: [\n");
        int codepage = getCodepage();
        if (codepage == -1) {
            codepage = 1252;
        }
        for (Property property : properties2) {
            stringBuffer.append(property.toString(codepage, propertyIDMap));
            stringBuffer.append(",\n");
        }
        stringBuffer.append(']');
        stringBuffer.append(']');
        return stringBuffer.toString();
    }

    public void setProperty(int i2, long j) {
        setProperty(i2, 20, Long.valueOf(j));
    }

    public void setProperty(int i2, boolean z) {
        setProperty(i2, 11, Boolean.valueOf(z));
    }

    public Section(Section section) {
        this.sectionBytes = new ByteArrayOutputStream();
        this.properties = new LinkedHashMap();
        this._offset = -1;
        setFormatID(section.getFormatID());
        for (Property property : section.properties.values()) {
            this.properties.put(Long.valueOf(property.getID()), new MutableProperty(property));
        }
        setDictionary(section.getDictionary());
    }

    public void setProperty(int i2, long j, Object obj) {
        setProperty(new MutableProperty((long) i2, j, obj));
    }

    public void setProperty(Property property) {
        Property property2 = this.properties.get(Long.valueOf(property.getID()));
        if (property2 == null || !property2.equals(property)) {
            this.properties.put(Long.valueOf(property.getID()), property);
            this.sectionBytes.reset();
        }
    }

    public void setProperty(int i2, Object obj) {
        if (obj instanceof String) {
            setProperty(i2, (String) obj);
        } else if (obj instanceof Long) {
            setProperty(i2, ((Long) obj).longValue());
        } else if (obj instanceof Integer) {
            setProperty(i2, ((Integer) obj).intValue());
        } else if (obj instanceof Short) {
            setProperty(i2, ((Short) obj).intValue());
        } else if (obj instanceof Boolean) {
            setProperty(i2, ((Boolean) obj).booleanValue());
        } else if (obj instanceof Date) {
            setProperty(i2, 64, obj);
        } else {
            StringBuilder b2 = b.b.a.a.a.b("HPSF does not support properties of type ");
            b2.append(obj.getClass().getName());
            b2.append(".");
            throw new HPSFRuntimeException(b2.toString());
        }
    }

    public Section(byte[] bArr, int i2) {
        int i3;
        this.sectionBytes = new ByteArrayOutputStream();
        this.properties = new LinkedHashMap();
        this.formatID = new ClassID(bArr, i2);
        int uInt = (int) LittleEndian.getUInt(bArr, i2 + 16);
        if (bArr[uInt] == 0) {
            int i4 = 0;
            while (i4 < 3 && bArr[uInt] == 0) {
                i4++;
                uInt++;
            }
            int i5 = 0;
            while (i5 < 3 && (bArr[uInt + 3] != 0 || bArr[uInt + 7] != 0 || bArr[uInt + 11] != 0)) {
                i5++;
                uInt--;
            }
        }
        this._offset = (long) uInt;
        LittleEndianByteArrayInputStream littleEndianByteArrayInputStream = new LittleEndianByteArrayInputStream(bArr, uInt);
        int min = (int) Math.min(littleEndianByteArrayInputStream.readUInt(), ((long) bArr.length) - this._offset);
        int readUInt = (int) littleEndianByteArrayInputStream.readUInt();
        a aVar = new a();
        for (int i6 = 0; i6 < readUInt; i6++) {
            aVar.put(Long.valueOf((long) ((int) littleEndianByteArrayInputStream.readUInt())), Long.valueOf((long) ((int) littleEndianByteArrayInputStream.readUInt())));
        }
        long j = 1;
        Long l = (Long) aVar.c((Object) 1L);
        if (l != null) {
            littleEndianByteArrayInputStream.setReadIndex((int) (l.longValue() + this._offset));
            long readUInt2 = littleEndianByteArrayInputStream.readUInt();
            if (readUInt2 == 2) {
                i3 = littleEndianByteArrayInputStream.readUShort();
                setCodepage(i3);
            } else {
                throw new HPSFRuntimeException("Value type of property ID 1 is not VT_I2 but " + readUInt2 + ".");
            }
        } else {
            i3 = -1;
        }
        for (Map.Entry entry : aVar.entrySet()) {
            long longValue = ((Long) entry.getKey()).longValue();
            long longValue2 = ((Long) entry.getValue()).longValue();
            if (longValue2 != j) {
                int propLen = propLen(aVar, Long.valueOf(longValue), (long) min);
                littleEndianByteArrayInputStream.setReadIndex((int) (this._offset + longValue));
                if (longValue2 == 0) {
                    littleEndianByteArrayInputStream.mark(SecurityManager.DEFAULT_ENTITY_EXPANSION_LIMIT);
                    if (!readDictionary(littleEndianByteArrayInputStream, propLen, i3)) {
                        littleEndianByteArrayInputStream.reset();
                        try {
                            if (aVar.F == null) {
                                aVar.F = new a.c();
                            }
                            a aVar2 = a.this;
                            if (aVar2.y != 0) {
                                j = 1;
                                try {
                                    setProperty(new MutableProperty(Math.max(31L, ((Long) aVar2.f(aVar2.x[1], a.EnumC0057a.VALUE).y).longValue()) + 1, littleEndianByteArrayInputStream, propLen, i3));
                                } catch (RuntimeException unused) {
                                    LOG.log(3, "Dictionary fallback failed - ignoring property");
                                }
                            } else {
                                throw new NoSuchElementException("Map is empty");
                            }
                        } catch (RuntimeException unused2) {
                            j = 1;
                            LOG.log(3, "Dictionary fallback failed - ignoring property");
                        }
                    } else {
                        j = 1;
                    }
                } else {
                    j = 1;
                    setProperty(new MutableProperty(longValue2, littleEndianByteArrayInputStream, propLen, i3));
                }
            }
        }
        this.sectionBytes.write(bArr, (int) this._offset, min);
        padSectionBytes();
    }
}
