package org.apache.poi.hpsf;

import b.b.a.a.a;
import java.io.InputStream;
import java.util.Date;
import org.apache.poi.hpsf.wellknown.PropertyIDMap;
import org.apache.poi.hpsf.wellknown.SectionIDMap;

public final class SummaryInformation extends SpecialPropertySet {
    public static final String DEFAULT_STREAM_NAME = "\u0005SummaryInformation";

    public SummaryInformation() {
        getFirstSection().setFormatID(SectionIDMap.SUMMARY_INFORMATION_ID);
    }

    public String getApplicationName() {
        return getPropertyStringValue(18);
    }

    public String getAuthor() {
        return getPropertyStringValue(4);
    }

    public int getCharCount() {
        return getPropertyIntValue(16);
    }

    public String getComments() {
        return getPropertyStringValue(6);
    }

    public Date getCreateDateTime() {
        return (Date) getProperty(12);
    }

    public long getEditTime() {
        Date date = (Date) getProperty(10);
        if (date == null) {
            return 0;
        }
        return Filetime.dateToFileTime(date);
    }

    public String getKeywords() {
        return getPropertyStringValue(5);
    }

    public String getLastAuthor() {
        return getPropertyStringValue(8);
    }

    public Date getLastPrinted() {
        return (Date) getProperty(11);
    }

    public Date getLastSaveDateTime() {
        return (Date) getProperty(13);
    }

    public int getPageCount() {
        return getPropertyIntValue(14);
    }

    @Override // org.apache.poi.hpsf.PropertySet
    public PropertyIDMap getPropertySetIDMap() {
        return PropertyIDMap.getSummaryInformationProperties();
    }

    public String getRevNumber() {
        return getPropertyStringValue(9);
    }

    public int getSecurity() {
        return getPropertyIntValue(19);
    }

    public String getSubject() {
        return getPropertyStringValue(3);
    }

    public String getTemplate() {
        return getPropertyStringValue(7);
    }

    public byte[] getThumbnail() {
        return (byte[]) getProperty(17);
    }

    public Thumbnail getThumbnailThumbnail() {
        byte[] thumbnail = getThumbnail();
        if (thumbnail == null) {
            return null;
        }
        return new Thumbnail(thumbnail);
    }

    public String getTitle() {
        return getPropertyStringValue(2);
    }

    public int getWordCount() {
        return getPropertyIntValue(15);
    }

    public void removeApplicationName() {
        remove1stProperty(18);
    }

    public void removeAuthor() {
        remove1stProperty(4);
    }

    public void removeCharCount() {
        remove1stProperty(16);
    }

    public void removeComments() {
        remove1stProperty(6);
    }

    public void removeCreateDateTime() {
        remove1stProperty(12);
    }

    public void removeEditTime() {
        remove1stProperty(10);
    }

    public void removeKeywords() {
        remove1stProperty(5);
    }

    public void removeLastAuthor() {
        remove1stProperty(8);
    }

    public void removeLastPrinted() {
        remove1stProperty(11);
    }

    public void removeLastSaveDateTime() {
        remove1stProperty(13);
    }

    public void removePageCount() {
        remove1stProperty(14);
    }

    public void removeRevNumber() {
        remove1stProperty(9);
    }

    public void removeSecurity() {
        remove1stProperty(19);
    }

    public void removeSubject() {
        remove1stProperty(3);
    }

    public void removeTemplate() {
        remove1stProperty(7);
    }

    public void removeThumbnail() {
        remove1stProperty(17);
    }

    public void removeTitle() {
        remove1stProperty(2);
    }

    public void removeWordCount() {
        remove1stProperty(15);
    }

    public void setApplicationName(String str) {
        set1stProperty(18, str);
    }

    public void setAuthor(String str) {
        set1stProperty(4, str);
    }

    public void setCharCount(int i2) {
        set1stProperty(16, i2);
    }

    public void setComments(String str) {
        set1stProperty(6, str);
    }

    public void setCreateDateTime(Date date) {
        getFirstSection().setProperty(12, 64, date);
    }

    public void setEditTime(long j) {
        getFirstSection().setProperty(10, 64, Filetime.filetimeToDate(j));
    }

    public void setKeywords(String str) {
        set1stProperty(5, str);
    }

    public void setLastAuthor(String str) {
        set1stProperty(8, str);
    }

    public void setLastPrinted(Date date) {
        getFirstSection().setProperty(11, 64, date);
    }

    public void setLastSaveDateTime(Date date) {
        getFirstSection().setProperty(13, 64, date);
    }

    public void setPageCount(int i2) {
        set1stProperty(14, i2);
    }

    public void setRevNumber(String str) {
        set1stProperty(9, str);
    }

    public void setSecurity(int i2) {
        set1stProperty(19, i2);
    }

    public void setSubject(String str) {
        set1stProperty(3, str);
    }

    public void setTemplate(String str) {
        set1stProperty(7, str);
    }

    public void setThumbnail(byte[] bArr) {
        getFirstSection().setProperty(17, 30, bArr);
    }

    public void setTitle(String str) {
        set1stProperty(2, str);
    }

    public void setWordCount(int i2) {
        set1stProperty(15, i2);
    }

    public SummaryInformation(PropertySet propertySet) {
        super(propertySet);
        if (!isSummaryInformation()) {
            StringBuilder b2 = a.b("Not a ");
            b2.append(SummaryInformation.class.getName());
            throw new UnexpectedPropertySetTypeException(b2.toString());
        }
    }

    public SummaryInformation(InputStream inputStream) {
        super(inputStream);
    }
}
