package org.apache.poi.hpsf;

import org.apache.poi.util.LittleEndian;

public final class Thumbnail {
    public static final int CFTAG_FMTID = -3;
    public static final int CFTAG_MACINTOSH = -2;
    public static final int CFTAG_NODATA = 0;
    public static final int CFTAG_WINDOWS = -1;
    public static final int CF_BITMAP = 2;
    public static final int CF_DIB = 8;
    public static final int CF_ENHMETAFILE = 14;
    public static final int CF_METAFILEPICT = 3;
    public static final int OFFSET_CF = 8;
    public static final int OFFSET_CFTAG = 4;
    public static final int OFFSET_WMFDATA = 20;
    public byte[] _thumbnailData = null;

    public Thumbnail() {
    }

    public long getClipboardFormat() {
        if (getClipboardFormatTag() == -1) {
            return (long) LittleEndian.getInt(getThumbnail(), 8);
        }
        throw new HPSFException("Clipboard Format Tag of Thumbnail must be CFTAG_WINDOWS.");
    }

    public long getClipboardFormatTag() {
        return (long) LittleEndian.getInt(getThumbnail(), 4);
    }

    public byte[] getThumbnail() {
        return this._thumbnailData;
    }

    public byte[] getThumbnailAsWMF() {
        if (getClipboardFormatTag() != -1) {
            throw new HPSFException("Clipboard Format Tag of Thumbnail must be CFTAG_WINDOWS.");
        } else if (getClipboardFormat() == 3) {
            byte[] thumbnail = getThumbnail();
            int length = thumbnail.length - 20;
            byte[] bArr = new byte[length];
            System.arraycopy(thumbnail, 20, bArr, 0, length);
            return bArr;
        } else {
            throw new HPSFException("Clipboard Format of Thumbnail must be CF_METAFILEPICT.");
        }
    }

    public void setThumbnail(byte[] bArr) {
        this._thumbnailData = bArr;
    }

    public Thumbnail(byte[] bArr) {
        this._thumbnailData = bArr;
    }
}
