package org.apache.poi.hpsf.wellknown;

import java.util.HashMap;
import java.util.Map;
import org.apache.poi.POIXMLProperties;
import org.apache.poi.hpsf.ClassID;
import org.apache.poi.util.Internal;

@Internal
public class SectionIDMap {
    public static final ClassID[] DOCUMENT_SUMMARY_INFORMATION_ID;
    public static final ClassID DOC_SUMMARY_INFORMATION = new ClassID("{D5CDD502-2E9C-101B-9397-08002B2CF9AE}");
    public static final ClassID SUMMARY_INFORMATION_ID = new ClassID("{F29F85E0-4FF9-1068-AB91-08002B27B3D9}");
    public static final String UNDEFINED = "[undefined]";
    public static final ClassID USER_DEFINED_PROPERTIES;
    public static ThreadLocal<Map<ClassID, PropertyIDMap>> defaultMap = new ThreadLocal<>();

    static {
        ClassID classID = new ClassID(POIXMLProperties.CustomProperties.FORMAT_ID);
        USER_DEFINED_PROPERTIES = classID;
        DOCUMENT_SUMMARY_INFORMATION_ID = new ClassID[]{DOC_SUMMARY_INFORMATION, classID};
    }

    public static SectionIDMap getInstance() {
        if (defaultMap.get() == null) {
            HashMap hashMap = new HashMap();
            hashMap.put(SUMMARY_INFORMATION_ID, PropertyIDMap.getSummaryInformationProperties());
            hashMap.put(DOCUMENT_SUMMARY_INFORMATION_ID[0], PropertyIDMap.getDocumentSummaryInformationProperties());
            defaultMap.set(hashMap);
        }
        return new SectionIDMap();
    }

    public static String getPIDString(ClassID classID, long j) {
        String str;
        PropertyIDMap propertyIDMap = getInstance().get(classID);
        if (propertyIDMap == null || (str = propertyIDMap.get((Object) Long.valueOf(j))) == null) {
            return UNDEFINED;
        }
        return str;
    }

    public PropertyIDMap get(ClassID classID) {
        return getInstance().get(classID);
    }

    public PropertyIDMap put(ClassID classID, PropertyIDMap propertyIDMap) {
        return getInstance().put(classID, propertyIDMap);
    }

    public PropertyIDMap put(String str, PropertyIDMap propertyIDMap) {
        return put(new ClassID(str), propertyIDMap);
    }
}
