package org.apache.poi.hslf.blip;

import java.awt.Dimension;
import java.awt.image.BufferedImage;
import java.io.ByteArrayInputStream;
import java.io.ByteArrayOutputStream;
import java.io.IOException;
import javax.imageio.ImageIO;
import org.apache.poi.hslf.usermodel.HSLFPictureData;
import org.apache.poi.hssf.usermodel.HSSFShapeTypes;
import org.apache.poi.util.Units;

public abstract class Bitmap extends HSLFPictureData {
    @Override // org.apache.poi.sl.usermodel.PictureData
    public byte[] getData() {
        byte[] rawData = getRawData();
        int uIDInstanceCount = (getUIDInstanceCount() * 16) + 1;
        int length = rawData.length - uIDInstanceCount;
        byte[] bArr = new byte[length];
        System.arraycopy(rawData, uIDInstanceCount, bArr, 0, length);
        return bArr;
    }

    @Override // org.apache.poi.sl.usermodel.PictureData
    public Dimension getImageDimension() {
        try {
            BufferedImage read = ImageIO.read(new ByteArrayInputStream(getData()));
            return new Dimension((int) Units.pixelToPoints(read.getWidth()), (int) Units.pixelToPoints(read.getHeight()));
        } catch (IOException unused) {
            return new Dimension((int) HSSFShapeTypes.ActionButtonMovie, (int) HSSFShapeTypes.ActionButtonMovie);
        }
    }

    @Override // org.apache.poi.sl.usermodel.PictureData
    public void setData(byte[] bArr) {
        byte[] checksum = HSLFPictureData.getChecksum(bArr);
        ByteArrayOutputStream byteArrayOutputStream = new ByteArrayOutputStream();
        byteArrayOutputStream.write(checksum);
        if (getUIDInstanceCount() == 2) {
            byteArrayOutputStream.write(checksum);
        }
        byteArrayOutputStream.write(0);
        byteArrayOutputStream.write(bArr);
        setRawData(byteArrayOutputStream.toByteArray());
    }
}
