package org.apache.poi.hslf.blip;

import org.apache.poi.sl.usermodel.PictureData;
import org.apache.poi.util.LittleEndian;

public final class DIB extends Bitmap {
    public static final int HEADER_SIZE = 14;

    public static byte[] addBMPHeader(byte[] bArr) {
        byte[] bArr2 = new byte[14];
        LittleEndian.putInt(bArr2, 0, 19778);
        int i2 = LittleEndian.getInt(bArr, 20);
        int length = bArr.length + 14;
        LittleEndian.putInt(bArr2, 2, length);
        LittleEndian.putInt(bArr2, 6, 0);
        LittleEndian.putInt(bArr2, 10, length - i2);
        byte[] bArr3 = new byte[(bArr.length + 14)];
        System.arraycopy(bArr2, 0, bArr3, 0, 14);
        System.arraycopy(bArr, 0, bArr3, 14, bArr.length);
        return bArr3;
    }

    @Override // org.apache.poi.hslf.blip.Bitmap, org.apache.poi.sl.usermodel.PictureData
    public byte[] getData() {
        return addBMPHeader(super.getData());
    }

    @Override // org.apache.poi.hslf.usermodel.HSLFPictureData
    public int getSignature() {
        return getUIDInstanceCount() == 1 ? 31360 : 31376;
    }

    @Override // org.apache.poi.sl.usermodel.PictureData
    public PictureData.PictureType getType() {
        return PictureData.PictureType.DIB;
    }

    @Override // org.apache.poi.hslf.blip.Bitmap, org.apache.poi.sl.usermodel.PictureData
    public void setData(byte[] bArr) {
        int length = bArr.length - 14;
        byte[] bArr2 = new byte[length];
        System.arraycopy(bArr, 14, bArr2, 0, length);
        super.setData(bArr2);
    }

    @Override // org.apache.poi.hslf.usermodel.HSLFPictureData
    public void setSignature(int i2) {
        if (i2 == 31360) {
            setUIDInstanceCount(1);
        } else if (i2 == 31376) {
            setUIDInstanceCount(2);
        } else {
            throw new IllegalArgumentException(i2 + " is not a valid instance/signature value for DIB");
        }
    }
}
