package org.apache.poi.hslf.blip;

import java.awt.Dimension;
import java.awt.Rectangle;
import java.io.ByteArrayOutputStream;
import java.io.OutputStream;
import java.util.zip.DeflaterOutputStream;
import org.apache.poi.hslf.usermodel.HSLFPictureData;
import org.apache.poi.util.LittleEndian;
import org.apache.poi.util.Units;

public abstract class Metafile extends HSLFPictureData {

    public static class Header {
        public final Rectangle bounds = new Rectangle();
        public int compression = 0;
        public int filter = 254;
        public final Dimension size = new Dimension();
        public int wmfsize;
        public int zipsize;

        public Rectangle getBounds() {
            return (Rectangle) this.bounds.clone();
        }

        public int getSize() {
            return 34;
        }

        public int getWmfSize() {
            return this.wmfsize;
        }

        public void read(byte[] bArr, int i2) {
            this.wmfsize = LittleEndian.getInt(bArr, i2);
            int i3 = i2 + 4;
            int i4 = LittleEndian.getInt(bArr, i3);
            int i5 = i3 + 4;
            int i6 = LittleEndian.getInt(bArr, i5);
            int i7 = i5 + 4;
            int i8 = LittleEndian.getInt(bArr, i7);
            int i9 = i7 + 4;
            int i10 = LittleEndian.getInt(bArr, i9);
            int i11 = i9 + 4;
            this.bounds.setBounds(i4, i6, i8 - i4, i10 - i6);
            int i12 = LittleEndian.getInt(bArr, i11);
            int i13 = i11 + 4;
            int i14 = LittleEndian.getInt(bArr, i13);
            int i15 = i13 + 4;
            this.size.setSize(i12, i14);
            this.zipsize = LittleEndian.getInt(bArr, i15);
            int i16 = i15 + 4;
            this.compression = LittleEndian.getUByte(bArr, i16);
            this.filter = LittleEndian.getUByte(bArr, i16 + 1);
        }

        public void setBounds(Rectangle rectangle) {
            this.bounds.setBounds(rectangle);
        }

        public void setDimension(Dimension dimension) {
            this.size.setSize(dimension);
        }

        public void setWmfSize(int i2) {
            this.wmfsize = i2;
        }

        public void setZipSize(int i2) {
            this.zipsize = i2;
        }

        public void write(OutputStream outputStream) {
            byte[] bArr = new byte[34];
            LittleEndian.putInt(bArr, 0, this.wmfsize);
            LittleEndian.putInt(bArr, 4, this.bounds.x);
            LittleEndian.putInt(bArr, 8, this.bounds.y);
            LittleEndian.putInt(bArr, 12, this.bounds.x + this.bounds.width);
            LittleEndian.putInt(bArr, 16, this.bounds.y + this.bounds.height);
            LittleEndian.putInt(bArr, 20, this.size.width);
            LittleEndian.putInt(bArr, 24, this.size.height);
            LittleEndian.putInt(bArr, 28, this.zipsize);
            bArr[32] = 0;
            bArr[33] = (byte) this.filter;
            outputStream.write(bArr);
        }
    }

    public static byte[] compress(byte[] bArr, int i2, int i3) {
        ByteArrayOutputStream byteArrayOutputStream = new ByteArrayOutputStream();
        DeflaterOutputStream deflaterOutputStream = new DeflaterOutputStream(byteArrayOutputStream);
        deflaterOutputStream.write(bArr, i2, i3);
        deflaterOutputStream.close();
        return byteArrayOutputStream.toByteArray();
    }

    @Override // org.apache.poi.sl.usermodel.PictureData
    public Dimension getImageDimension() {
        Header header = new Header();
        header.read(getRawData(), getUIDInstanceCount() * 16);
        return new Dimension((int) Math.round(Units.toPoints((long) header.size.getWidth())), (int) Math.round(Units.toPoints((long) header.size.getHeight())));
    }
}
