package org.apache.poi.hslf.blip;

import java.awt.Dimension;
import java.io.ByteArrayInputStream;
import java.io.ByteArrayOutputStream;
import java.io.EOFException;
import java.io.IOException;
import java.util.zip.InflaterInputStream;
import org.apache.poi.hslf.blip.Metafile;
import org.apache.poi.hslf.exceptions.HSLFException;
import org.apache.poi.hslf.usermodel.HSLFPictureData;
import org.apache.poi.sl.image.ImageHeaderPICT;
import org.apache.poi.sl.usermodel.PictureData;
import org.apache.poi.util.POILogFactory;
import org.apache.poi.util.POILogger;
import org.apache.poi.util.Units;

public final class PICT extends Metafile {
    public static final POILogger LOG = POILogFactory.getLogger(PICT.class);

    public static void bytefill(byte[] bArr, byte b2) {
        int length = bArr.length;
        if (length > 0) {
            bArr[0] = b2;
        }
        for (int i2 = 1; i2 < length; i2 += i2) {
            int i3 = length - i2;
            if (i3 >= i2) {
                i3 = i2;
            }
            System.arraycopy(bArr, 0, bArr, i2, i3);
        }
    }

    private byte[] read(byte[] bArr, int i2) {
        ByteArrayInputStream byteArrayInputStream = new ByteArrayInputStream(bArr);
        Metafile.Header header = new Metafile.Header();
        header.read(bArr, i2);
        long size = ((long) i2) + ((long) header.getSize());
        if (size == byteArrayInputStream.skip(size)) {
            byte[] bArr2 = new byte[4096];
            ByteArrayOutputStream byteArrayOutputStream = new ByteArrayOutputStream(header.getWmfSize());
            InflaterInputStream inflaterInputStream = new InflaterInputStream(byteArrayInputStream);
            while (true) {
                try {
                    int read = inflaterInputStream.read(bArr2);
                    if (read < 0) {
                        break;
                    }
                    byteArrayOutputStream.write(bArr2, 0, read);
                    bytefill(bArr2, (byte) 0);
                } catch (Exception e2) {
                    int i3 = 4095;
                    while (i3 >= 0) {
                        if (bArr2[i3] != 0) {
                            break;
                        }
                        i3--;
                    }
                    int i4 = i3 + 1;
                    if (i4 > 0) {
                        if (header.getWmfSize() > byteArrayOutputStream.size()) {
                            i4 = Math.min(i4, header.getWmfSize() - byteArrayOutputStream.size());
                        }
                        byteArrayOutputStream.write(bArr2, 0, i4);
                    }
                    LOG.log(7, "PICT zip-stream is invalid, read as much as possible. Uncompressed length of header: " + header.getWmfSize() + " / Read bytes: " + byteArrayOutputStream.size(), e2);
                } catch (Throwable th) {
                    inflaterInputStream.close();
                    throw th;
                }
            }
            inflaterInputStream.close();
            return byteArrayOutputStream.toByteArray();
        }
        throw new EOFException();
    }

    @Override // org.apache.poi.sl.usermodel.PictureData
    public byte[] getData() {
        byte[] rawData = getRawData();
        try {
            ByteArrayOutputStream byteArrayOutputStream = new ByteArrayOutputStream();
            byteArrayOutputStream.write(new byte[512]);
            byteArrayOutputStream.write(read(rawData, getUIDInstanceCount() * 16));
            return byteArrayOutputStream.toByteArray();
        } catch (IOException e2) {
            throw new HSLFException(e2);
        }
    }

    @Override // org.apache.poi.hslf.usermodel.HSLFPictureData
    public int getSignature() {
        return getUIDInstanceCount() == 1 ? 21536 : 21552;
    }

    @Override // org.apache.poi.sl.usermodel.PictureData
    public PictureData.PictureType getType() {
        return PictureData.PictureType.PICT;
    }

    @Override // org.apache.poi.sl.usermodel.PictureData
    public void setData(byte[] bArr) {
        ImageHeaderPICT imageHeaderPICT = new ImageHeaderPICT(bArr, 512);
        Metafile.Header header = new Metafile.Header();
        int length = bArr.length - 512;
        header.setWmfSize(length);
        byte[] compress = Metafile.compress(bArr, 512, length);
        header.setZipSize(compress.length);
        header.setBounds(imageHeaderPICT.getBounds());
        Dimension size = imageHeaderPICT.getSize();
        header.setDimension(new Dimension(Units.toEMU(size.getWidth()), Units.toEMU(size.getHeight())));
        byte[] checksum = HSLFPictureData.getChecksum(bArr);
        ByteArrayOutputStream byteArrayOutputStream = new ByteArrayOutputStream();
        byteArrayOutputStream.write(checksum);
        if (getUIDInstanceCount() == 2) {
            byteArrayOutputStream.write(checksum);
        }
        header.write(byteArrayOutputStream);
        byteArrayOutputStream.write(compress);
        setRawData(byteArrayOutputStream.toByteArray());
    }

    @Override // org.apache.poi.hslf.usermodel.HSLFPictureData
    public void setSignature(int i2) {
        if (i2 == 21536) {
            setUIDInstanceCount(1);
        } else if (i2 == 21552) {
            setUIDInstanceCount(2);
        } else {
            throw new IllegalArgumentException(i2 + " is not a valid instance/signature value for PICT");
        }
    }
}
