package org.apache.poi.hslf.blip;

import org.apache.poi.sl.usermodel.PictureData;
import org.apache.poi.util.PngUtils;

public final class PNG extends Bitmap {
    @Override // org.apache.poi.hslf.blip.Bitmap, org.apache.poi.sl.usermodel.PictureData
    public byte[] getData() {
        byte[] data = super.getData();
        if (!PngUtils.matchesPngHeader(data, 16)) {
            return data;
        }
        int length = data.length - 16;
        byte[] bArr = new byte[length];
        System.arraycopy(data, 16, bArr, 0, length);
        return bArr;
    }

    @Override // org.apache.poi.hslf.usermodel.HSLFPictureData
    public int getSignature() {
        return getUIDInstanceCount() == 1 ? 28160 : 28176;
    }

    @Override // org.apache.poi.sl.usermodel.PictureData
    public PictureData.PictureType getType() {
        return PictureData.PictureType.PNG;
    }

    @Override // org.apache.poi.hslf.usermodel.HSLFPictureData
    public void setSignature(int i2) {
        if (i2 == 28160) {
            setUIDInstanceCount(1);
        } else if (i2 == 28176) {
            setUIDInstanceCount(2);
        } else {
            throw new IllegalArgumentException(i2 + " is not a valid instance/signature value for PNG");
        }
    }
}
