package org.apache.poi.hslf.dev;

import b.b.a.a.a;
import java.io.ByteArrayOutputStream;
import java.io.File;
import java.io.FileOutputStream;
import java.io.OutputStreamWriter;
import java.io.PrintStream;
import java.io.StringWriter;
import java.io.Writer;
import java.nio.charset.Charset;
import org.apache.lucene.codecs.lucene3x.Lucene3xFields;
import org.apache.poi.hslf.record.RecordTypes;
import org.apache.poi.hslf.usermodel.HSLFSlideShow;
import org.apache.poi.hssf.record.PaletteRecord;
import org.apache.poi.hwpf.model.types.CHPAbstractType;
import org.apache.poi.openxml4j.opc.ContentTypes;
import org.apache.poi.poifs.filesystem.DirectoryNode;
import org.apache.poi.poifs.filesystem.DocumentInputStream;
import org.apache.poi.poifs.filesystem.NPOIFSFileSystem;
import org.apache.poi.ss.formula.ptg.GreaterThanPtg;
import org.apache.poi.ss.formula.ptg.LessThanPtg;
import org.apache.poi.ss.formula.ptg.UnaryMinusPtg;
import org.apache.poi.util.IOUtils;
import org.apache.poi.util.LittleEndian;
import org.apache.xmlbeans.impl.jam.internal.JamPrinter;

public final class PPTXMLDump {
    public static final String CR = System.getProperty("line.separator");
    public static final int HEADER_SIZE = 8;
    public static final String PICTURES_ENTRY = "Pictures";
    public static final int PICT_HEADER_SIZE = 25;
    public static final byte[] hexval = {48, 49, 50, 51, 52, 53, 54, CHPAbstractType.KUL_DASH_LONG_HEAVY, PaletteRecord.STANDARD_PALETTE_SIZE, 57, 65, 66, 67, 68, 69, 70};
    public byte[] docstream;
    public boolean hexHeader = true;
    public Writer out;
    public byte[] pictstream;

    public PPTXMLDump(File file) {
        NPOIFSFileSystem nPOIFSFileSystem = new NPOIFSFileSystem(file, true);
        try {
            this.docstream = readEntry(nPOIFSFileSystem, HSLFSlideShow.POWERPOINT_DOCUMENT);
            this.pictstream = readEntry(nPOIFSFileSystem, PICTURES_ENTRY);
        } finally {
            nPOIFSFileSystem.close();
        }
    }

    private String getPictureType(byte[] bArr) {
        int uShort = LittleEndian.getUShort(bArr, 0);
        if (uShort == 8544) {
            return "wmf";
        }
        if (uShort != 18080) {
            return uShort != 28160 ? "unknown" : ContentTypes.EXTENSION_PNG;
        }
        return ContentTypes.EXTENSION_JPG_2;
    }

    public static void main(String[] strArr) {
        if (strArr.length == 0) {
            System.out.println("Usage: PPTXMLDump (options) pptfile\nWhere options include:\n    -f     write output to <pptfile>.xml file in the current directory");
            return;
        }
        boolean z = false;
        for (int i2 = 0; i2 < strArr.length; i2++) {
            if (!strArr[i2].startsWith(UnaryMinusPtg.MINUS)) {
                File file = new File(strArr[i2]);
                PPTXMLDump pPTXMLDump = new PPTXMLDump(file);
                PrintStream printStream = System.out;
                StringBuilder b2 = a.b("Dumping ");
                b2.append(strArr[i2]);
                printStream.println(b2.toString());
                if (z) {
                    OutputStreamWriter outputStreamWriter = new OutputStreamWriter(new FileOutputStream(file.getName() + ".xml"), Charset.forName("UTF8"));
                    pPTXMLDump.dump(outputStreamWriter);
                    outputStreamWriter.close();
                } else {
                    StringWriter stringWriter = new StringWriter();
                    pPTXMLDump.dump(stringWriter);
                    System.out.println(stringWriter);
                }
            } else if ("-f".equals(strArr[i2])) {
                z = true;
            }
        }
    }

    public static byte[] readEntry(NPOIFSFileSystem nPOIFSFileSystem, String str) {
        DirectoryNode root = nPOIFSFileSystem.getRoot();
        if (!root.hasEntry(str)) {
            return null;
        }
        DocumentInputStream createDocumentInputStream = root.createDocumentInputStream(str);
        try {
            ByteArrayOutputStream byteArrayOutputStream = new ByteArrayOutputStream();
            IOUtils.copy(createDocumentInputStream, byteArrayOutputStream);
            return byteArrayOutputStream.toByteArray();
        } finally {
            createDocumentInputStream.close();
        }
    }

    public static void write(Writer writer, String str, int i2) {
        for (int i3 = 0; i3 < i2; i3++) {
            writer.write(JamPrinter.INDENT);
        }
        writer.write(str);
    }

    public void dump(Writer writer) {
        this.out = writer;
        StringBuilder b2 = a.b("<Presentation>");
        b2.append(CR);
        write(writer, b2.toString(), 0);
        if (this.pictstream != null) {
            Writer writer2 = this.out;
            StringBuilder b3 = a.b("<Pictures>");
            b3.append(CR);
            write(writer2, b3.toString(), 1);
            dumpPictures(this.pictstream, 1);
            Writer writer3 = this.out;
            StringBuilder b4 = a.b("</Pictures>");
            b4.append(CR);
            write(writer3, b4.toString(), 1);
        }
        Writer writer4 = this.out;
        StringBuilder b5 = a.b("<PowerPointDocument>");
        b5.append(CR);
        write(writer4, b5.toString(), 1);
        byte[] bArr = this.docstream;
        dump(bArr, 0, bArr.length, 2);
        Writer writer5 = this.out;
        StringBuilder b6 = a.b("</PowerPointDocument>");
        b6.append(CR);
        write(writer5, b6.toString(), 1);
        write(this.out, "</Presentation>", 0);
    }

    public void dumpPictures(byte[] bArr, int i2) {
        int i3 = 0;
        while (i3 < bArr.length) {
            byte[] bArr2 = new byte[25];
            System.arraycopy(bArr, i3, bArr2, 0, 25);
            int i4 = LittleEndian.getInt(bArr2, 4) - 17;
            byte[] bArr3 = new byte[i4];
            System.arraycopy(bArr, i3 + 25, bArr3, 0, i4);
            i3 += i4 + 25;
            int i5 = i2 + 1;
            Writer writer = this.out;
            StringBuilder a = a.a("<picture size=\"", i4, "\" type=\"");
            a.append(getPictureType(bArr2));
            a.append("\">");
            a.append(CR);
            write(writer, a.toString(), i5);
            int i6 = i5 + 1;
            Writer writer2 = this.out;
            StringBuilder b2 = a.b("<header>");
            b2.append(CR);
            write(writer2, b2.toString(), i6);
            dump(this.out, bArr2, 0, 25, i6, true);
            Writer writer3 = this.out;
            StringBuilder b3 = a.b("</header>");
            b3.append(CR);
            write(writer3, b3.toString(), i6);
            Writer writer4 = this.out;
            StringBuilder b4 = a.b("<imgdata>");
            b4.append(CR);
            write(writer4, b4.toString(), i6);
            dump(this.out, bArr3, 0, Math.min(i4, 100), i6, true);
            Writer writer5 = this.out;
            StringBuilder b5 = a.b("</imgdata>");
            b5.append(CR);
            write(writer5, b5.toString(), i6);
            int i7 = i6 - 1;
            Writer writer6 = this.out;
            StringBuilder b6 = a.b("</picture>");
            b6.append(CR);
            write(writer6, b6.toString(), i7);
            i2 = i7 - 1;
        }
    }

    public void dump(byte[] bArr, int i2, int i3, int i4) {
        int i5 = i2;
        int i6 = i4;
        while (i5 <= (i2 + i3) - 8 && i5 >= 0) {
            int uShort = LittleEndian.getUShort(bArr, i5);
            int i7 = i5 + 2;
            int uShort2 = LittleEndian.getUShort(bArr, i7);
            int i8 = i7 + 2;
            int uInt = (int) LittleEndian.getUInt(bArr, i8);
            int i9 = i8 + 4;
            String name = RecordTypes.forTypeID(uShort2).name();
            Writer writer = this.out;
            StringBuilder sb = new StringBuilder();
            sb.append(LessThanPtg.LESSTHAN);
            sb.append(name);
            sb.append(" info=\"");
            sb.append(uShort);
            sb.append("\" type=\"");
            sb.append(uShort2);
            sb.append("\" size=\"");
            sb.append(uInt);
            sb.append("\" offset=\"");
            int i10 = i9 - 8;
            sb.append(i10);
            sb.append("\"");
            write(writer, sb.toString(), i6);
            if (this.hexHeader) {
                this.out.write(" header=\"");
                dump(this.out, bArr, i10, 8, 0, false);
                this.out.write("\"");
            }
            Writer writer2 = this.out;
            StringBuilder b2 = a.b(GreaterThanPtg.GREATERTHAN);
            b2.append(CR);
            writer2.write(b2.toString());
            int i11 = i6 + 1;
            if ((uShort & 15) == 15) {
                dump(bArr, i9, uInt, i11);
            } else {
                dump(this.out, bArr, i9, Math.min(uInt, bArr.length - i9), i11, true);
            }
            i6 = i11 - 1;
            Writer writer3 = this.out;
            StringBuilder d2 = a.d("</", name, GreaterThanPtg.GREATERTHAN);
            d2.append(CR);
            write(writer3, d2.toString(), i6);
            i5 = i9 + uInt;
        }
    }

    public static void dump(Writer writer, byte[] bArr, int i2, int i3, int i4, boolean z) {
        for (int i5 = 0; i5 < i4; i5++) {
            writer.write(JamPrinter.INDENT);
        }
        int i6 = i2;
        while (true) {
            int i7 = i2 + i3;
            if (i6 >= i7) {
                break;
            }
            byte b2 = bArr[i6];
            writer.write((char) hexval[(b2 & Lucene3xFields.PreTermsEnum.UTF8_NON_BMP_LEAD) >> 4]);
            writer.write((char) hexval[(b2 & 15) >> 0]);
            writer.write(32);
            int i8 = i6 + 1;
            if ((i8 - i2) % 25 == 0 && i6 != i7 - 1) {
                writer.write(CR);
                for (int i9 = 0; i9 < i4; i9++) {
                    writer.write(JamPrinter.INDENT);
                }
            }
            i6 = i8;
        }
        if (z && i3 > 0) {
            writer.write(CR);
        }
    }
}
