package org.apache.poi.hslf.dev;

import b.b.a.a.a;
import java.io.ByteArrayOutputStream;
import java.io.PrintStream;
import java.util.Map;
import org.apache.poi.hslf.record.Document;
import org.apache.poi.hslf.record.Notes;
import org.apache.poi.hslf.record.NotesAtom;
import org.apache.poi.hslf.record.PersistPtrHolder;
import org.apache.poi.hslf.record.PositionDependentRecord;
import org.apache.poi.hslf.record.Record;
import org.apache.poi.hslf.record.Slide;
import org.apache.poi.hslf.record.SlideAtom;
import org.apache.poi.hslf.record.SlideListWithText;
import org.apache.poi.hslf.record.SlidePersistAtom;
import org.apache.poi.hslf.usermodel.HSLFSlideShow;
import org.apache.poi.hslf.usermodel.HSLFSlideShowImpl;
import org.apache.poi.util.LittleEndian;

public final class SlideIdListing {
    public static byte[] fileContents;

    public static Record findRecordAtPos(int i2) {
        return Record.createRecordForType((long) LittleEndian.getUShort(fileContents, i2 + 2), fileContents, i2, ((int) LittleEndian.getUInt(fileContents, i2 + 4)) + 8);
    }

    public static void main(String[] strArr) {
        SlideListWithText[] slideListWithTexts;
        if (strArr.length < 1) {
            System.err.println("Need to give a filename");
            System.exit(1);
        }
        HSLFSlideShowImpl hSLFSlideShowImpl = new HSLFSlideShowImpl(strArr[0]);
        HSLFSlideShow hSLFSlideShow = new HSLFSlideShow(hSLFSlideShowImpl);
        fileContents = hSLFSlideShowImpl.getUnderlyingBytes();
        Record[] records = hSLFSlideShowImpl.getRecords();
        Record[] mostRecentCoreRecords = hSLFSlideShow.getMostRecentCoreRecords();
        Document document = null;
        for (int i2 = 0; i2 < mostRecentCoreRecords.length; i2++) {
            if (mostRecentCoreRecords[i2] instanceof Document) {
                document = (Document) mostRecentCoreRecords[i2];
            }
        }
        System.out.println("");
        for (SlideListWithText slideListWithText : document.getSlideListWithTexts()) {
            Record[] childRecords = slideListWithText.getChildRecords();
            for (int i3 = 0; i3 < childRecords.length; i3++) {
                if (childRecords[i3] instanceof SlidePersistAtom) {
                    SlidePersistAtom slidePersistAtom = (SlidePersistAtom) childRecords[i3];
                    System.out.println("SlidePersistAtom knows about slide:");
                    PrintStream printStream = System.out;
                    StringBuilder b2 = a.b("\t");
                    b2.append(slidePersistAtom.getRefID());
                    printStream.println(b2.toString());
                    PrintStream printStream2 = System.out;
                    StringBuilder b3 = a.b("\t");
                    b3.append(slidePersistAtom.getSlideIdentifier());
                    printStream2.println(b3.toString());
                }
            }
        }
        System.out.println("");
        for (int i4 = 0; i4 < mostRecentCoreRecords.length; i4++) {
            if (mostRecentCoreRecords[i4] instanceof Slide) {
                Slide slide = (Slide) mostRecentCoreRecords[i4];
                SlideAtom slideAtom = slide.getSlideAtom();
                System.out.println("Found the latest version of a slide record:");
                PrintStream printStream3 = System.out;
                StringBuilder b4 = a.b("\tCore ID is ");
                b4.append(slide.getSheetId());
                printStream3.println(b4.toString());
                System.out.println("\t(Core Records count is " + i4 + ")");
                PrintStream printStream4 = System.out;
                StringBuilder b5 = a.b("\tDisk Position is ");
                b5.append(slide.getLastOnDiskOffset());
                printStream4.println(b5.toString());
                PrintStream printStream5 = System.out;
                StringBuilder b6 = a.b("\tMaster ID is ");
                b6.append(slideAtom.getMasterID());
                printStream5.println(b6.toString());
                PrintStream printStream6 = System.out;
                StringBuilder b7 = a.b("\tNotes ID is ");
                b7.append(slideAtom.getNotesID());
                printStream6.println(b7.toString());
            }
        }
        System.out.println("");
        for (int i5 = 0; i5 < mostRecentCoreRecords.length; i5++) {
            if (mostRecentCoreRecords[i5] instanceof Notes) {
                Notes notes = (Notes) mostRecentCoreRecords[i5];
                NotesAtom notesAtom = notes.getNotesAtom();
                System.out.println("Found the latest version of a notes record:");
                PrintStream printStream7 = System.out;
                StringBuilder b8 = a.b("\tCore ID is ");
                b8.append(notes.getSheetId());
                printStream7.println(b8.toString());
                System.out.println("\t(Core Records count is " + i5 + ")");
                PrintStream printStream8 = System.out;
                StringBuilder b9 = a.b("\tDisk Position is ");
                b9.append(notes.getLastOnDiskOffset());
                printStream8.println(b9.toString());
                PrintStream printStream9 = System.out;
                StringBuilder b10 = a.b("\tMatching slide is ");
                b10.append(notesAtom.getSlideID());
                printStream9.println(b10.toString());
            }
        }
        System.out.println("");
        int i6 = 0;
        for (Record record : records) {
            if (record.getRecordType() == 6001) {
                PrintStream printStream10 = System.out;
                StringBuilder a = a.a("Found PersistPtrFullBlock at ", i6, " (");
                a.append(Integer.toHexString(i6));
                a.append(")");
                printStream10.println(a.toString());
            }
            if (record.getRecordType() == 6002) {
                PrintStream printStream11 = System.out;
                StringBuilder a2 = a.a("Found PersistPtrIncrementalBlock at ", i6, " (");
                a2.append(Integer.toHexString(i6));
                a2.append(")");
                printStream11.println(a2.toString());
                PersistPtrHolder persistPtrHolder = (PersistPtrHolder) record;
                int[] knownSlideIDs = persistPtrHolder.getKnownSlideIDs();
                Map<Integer, Integer> slideLocationsLookup = persistPtrHolder.getSlideLocationsLookup();
                for (int i7 : knownSlideIDs) {
                    Integer valueOf = Integer.valueOf(i7);
                    Integer num = slideLocationsLookup.get(valueOf);
                    System.out.println("  Knows about sheet " + valueOf);
                    System.out.println("    That sheet lives at " + num);
                    Record findRecordAtPos = findRecordAtPos(num.intValue());
                    PrintStream printStream12 = System.out;
                    StringBuilder b11 = a.b("    The record at that pos is of type ");
                    b11.append(findRecordAtPos.getRecordType());
                    printStream12.println(b11.toString());
                    PrintStream printStream13 = System.out;
                    StringBuilder b12 = a.b("    The record at that pos has class ");
                    b12.append(findRecordAtPos.getClass().getName());
                    printStream13.println(b12.toString());
                    if (!(findRecordAtPos instanceof PositionDependentRecord)) {
                        System.out.println("    ** The record class isn't position aware! **");
                    }
                }
            }
            ByteArrayOutputStream byteArrayOutputStream = new ByteArrayOutputStream();
            record.writeOut(byteArrayOutputStream);
            i6 += byteArrayOutputStream.size();
        }
        hSLFSlideShow.close();
        System.out.println("");
    }
}
