package org.apache.poi.hslf.dev;

import b.b.a.a.a;
import java.io.File;
import java.io.PrintStream;
import java.util.Locale;
import org.apache.lucene.codecs.lucene3x.Lucene3xNormsProducer;
import org.apache.poi.ddf.EscherContainerRecord;
import org.apache.poi.ddf.EscherRecord;
import org.apache.poi.ddf.EscherTextboxRecord;
import org.apache.poi.hslf.record.HSLFEscherRecordFactory;
import org.apache.poi.hslf.record.RecordTypes;
import org.apache.poi.hslf.usermodel.HSLFSlideShow;
import org.apache.poi.poifs.filesystem.DocumentInputStream;
import org.apache.poi.poifs.filesystem.NPOIFSFileSystem;
import org.apache.poi.util.HexDump;
import org.apache.poi.util.IOUtils;
import org.apache.poi.util.LittleEndian;

public final class SlideShowDumper {
    public boolean basicEscher;
    public boolean ddfEscher;
    public byte[] docstream;
    public PrintStream out;

    public SlideShowDumper(NPOIFSFileSystem nPOIFSFileSystem, PrintStream printStream) {
        DocumentInputStream createDocumentInputStream = nPOIFSFileSystem.createDocumentInputStream(HSLFSlideShow.POWERPOINT_DOCUMENT);
        this.docstream = IOUtils.toByteArray(createDocumentInputStream);
        createDocumentInputStream.close();
        this.out = printStream;
    }

    public static void main(String[] strArr) {
        if (strArr.length == 0) {
            System.err.println("Useage: SlideShowDumper [-escher|-basicescher] <filename>");
            return;
        }
        String str = strArr[0];
        if (strArr.length > 1) {
            str = strArr[1];
        }
        NPOIFSFileSystem nPOIFSFileSystem = new NPOIFSFileSystem(new File(str));
        SlideShowDumper slideShowDumper = new SlideShowDumper(nPOIFSFileSystem, System.out);
        nPOIFSFileSystem.close();
        if (strArr.length > 1) {
            if (strArr[0].equalsIgnoreCase("-escher")) {
                slideShowDumper.setDDFEscher(true);
            } else {
                slideShowDumper.setBasicEscher(true);
            }
        }
        slideShowDumper.printDump();
    }

    public void printDump() {
        walkTree(0, 0, this.docstream.length);
    }

    public void setBasicEscher(boolean z) {
        this.basicEscher = z;
        this.ddfEscher = !z;
    }

    public void setDDFEscher(boolean z) {
        this.ddfEscher = z;
        this.basicEscher = !z;
    }

    public void walkEscherBasic(int i2, int i3, int i4) {
        if (i4 >= 8) {
            String b2 = i2 == 0 ? "%1$s" : a.b("%1$", i2, Lucene3xNormsProducer.SEPARATE_NORMS_EXTENSION);
            long uShort = (long) LittleEndian.getUShort(this.docstream, i3 + 2);
            long uInt = LittleEndian.getUInt(this.docstream, i3 + 4);
            this.out.println(String.format(Locale.ROOT, a.b(b2, "At position %2$d ($2$04x): type is %3$d (%3$04x), len is %4$d (%4$04x)"), "", Integer.valueOf(i3), Long.valueOf(uShort), Long.valueOf(uInt)));
            this.out.println(String.format(Locale.ROOT, a.b(b2, "%2$s"), "That's an Escher Record: ", RecordTypes.forTypeID((short) ((int) uShort)).name()));
            if (uShort == 61453) {
                HexDump.dump(this.docstream, 0, this.out, i3 + 8, 8);
                HexDump.dump(this.docstream, 0, this.out, i3 + 20, 8);
                this.out.println();
            }
            this.out.println();
            if (uShort == 61443 || uShort == 61444) {
                walkEscherBasic(i2 + 3, i3 + 8, (int) uInt);
            }
            if (uInt < ((long) i4)) {
                int i5 = (int) uInt;
                walkEscherBasic(i2, i3 + i5 + 8, (i4 - i5) - 8);
            }
        }
    }

    public void walkEscherDDF(int i2, int i3, int i4) {
        int i5;
        int i6;
        int i7;
        int i8;
        int i9;
        if (i4 >= 8) {
            String b2 = i2 == 0 ? "%1$s" : a.b("%1$", i2, Lucene3xNormsProducer.SEPARATE_NORMS_EXTENSION);
            byte[] bArr = new byte[i4];
            System.arraycopy(this.docstream, i3, bArr, 0, i4);
            HSLFEscherRecordFactory hSLFEscherRecordFactory = new HSLFEscherRecordFactory();
            EscherRecord createRecord = hSLFEscherRecordFactory.createRecord(bArr, 0);
            createRecord.fillFields(bArr, 0, hSLFEscherRecordFactory);
            long uShort = (long) LittleEndian.getUShort(bArr, 2);
            long uShort2 = (long) LittleEndian.getUShort(bArr, 4);
            int recordSize = createRecord.getRecordSize();
            long j = uShort2 + 8;
            this.out.println(String.format(Locale.ROOT, a.b(b2, "At position %2$d (%2$04x): type is %3$d (%3$04x), len is %4$d (%4$04x) (%5$d) - record claims %6$d"), "", Integer.valueOf(i3), Long.valueOf(uShort), Long.valueOf(uShort2), Long.valueOf(j), Integer.valueOf(recordSize)));
            if (!(recordSize == 8 || ((long) recordSize) == j)) {
                this.out.println(String.format(Locale.ROOT, a.b(b2, "** Atom length of $2d ($3d) doesn't match record length of %4d"), "", Long.valueOf(uShort2), Long.valueOf(j), Integer.valueOf(recordSize)));
            }
            this.out.println(String.format(Locale.ROOT, a.b(b2, "%2$s"), "", createRecord.toString().replace("\n", String.format(Locale.ROOT, a.b("\n", b2), ""))));
            if (createRecord instanceof EscherContainerRecord) {
                walkEscherDDF(i2 + 3, i3 + 8, (int) uShort2);
            }
            if (uShort == 61451) {
                i6 = 8;
                i5 = ((int) uShort2) + 8;
            } else {
                i6 = 8;
                i5 = recordSize;
            }
            if (uShort == 61453) {
                i5 = ((int) uShort2) + i6;
                createRecord.fillFields(bArr, 0, hSLFEscherRecordFactory);
                if (!(createRecord instanceof EscherTextboxRecord)) {
                    this.out.println(String.format(Locale.ROOT, a.b(b2, "%2$s"), "", "** Really a msofbtClientTextbox !"));
                }
            }
            if (i5 != 8 || uShort2 <= 8) {
                i7 = i4;
                i8 = ((int) (((long) i3) + uShort2)) + 8;
                i9 = 8;
            } else {
                walkEscherDDF(i2 + 3, i3 + 8, (int) uShort2);
                i9 = 8;
                i8 = ((int) (((long) i3) + uShort2)) + 8;
                i7 = i4;
            }
            int i10 = ((int) (((long) i7) - uShort2)) - 8;
            if (i10 >= i9) {
                walkEscherDDF(i2, i8, i10);
            }
        }
    }

    public void walkTree(int i2, int i3, int i4) {
        int i5 = i3 + i4;
        String b2 = i2 == 0 ? "%1$s" : a.b("%1$", i2, Lucene3xNormsProducer.SEPARATE_NORMS_EXTENSION);
        int i6 = i3;
        while (i6 <= i5 - 8) {
            long uShort = (long) LittleEndian.getUShort(this.docstream, i6 + 2);
            long uInt = LittleEndian.getUInt(this.docstream, i6 + 4);
            byte b3 = this.docstream[i6];
            this.out.println(String.format(Locale.ROOT, a.b(b2, "At position %2$d (%2$04x): type is %3$d (%3$04x), len is %4$d (%4$04x)"), "", Integer.valueOf(i6), Long.valueOf(uShort), Long.valueOf(uInt)));
            int i7 = i6 + 8;
            this.out.println(String.format(Locale.ROOT, a.b(b2, "That's a %2$s"), "", RecordTypes.forTypeID((short) ((int) uShort)).name()));
            int i8 = b3 & 15;
            if (uShort == 5003 && ((long) b3) == 0) {
                i8 = 15;
            }
            this.out.println();
            if (uShort != 0 && i8 == 15) {
                if (uShort != 1035 && uShort != 1036) {
                    walkTree(i2 + 2, i7, (int) uInt);
                } else if (this.ddfEscher) {
                    walkEscherDDF(i2 + 3, i7 + 8, ((int) uInt) - 8);
                } else if (this.basicEscher) {
                    walkEscherBasic(i2 + 3, i7 + 8, ((int) uInt) - 8);
                }
            }
            i6 = i7 + ((int) uInt);
        }
    }
}
