package org.apache.poi.hslf.dev;

import b.b.a.a.a;
import java.io.ByteArrayOutputStream;
import java.io.PrintStream;
import java.util.List;
import java.util.Locale;
import org.apache.poi.ddf.EscherContainerRecord;
import org.apache.poi.ddf.EscherRecord;
import org.apache.poi.ddf.EscherTextboxRecord;
import org.apache.poi.hslf.record.EscherTextboxWrapper;
import org.apache.poi.hslf.record.HSLFEscherRecordFactory;
import org.apache.poi.hslf.record.Record;
import org.apache.poi.hslf.record.StyleTextPropAtom;
import org.apache.poi.hslf.record.TextBytesAtom;
import org.apache.poi.hslf.record.TextCharsAtom;
import org.apache.poi.hslf.usermodel.HSLFSlideShowImpl;
import org.apache.poi.ss.formula.ptg.UnaryMinusPtg;
import org.apache.poi.util.HexDump;

public final class SlideShowRecordDumper {
    public static final String tabs = "\t\t\t\t\t\t\t\t\t\t\t\t\t\t\t\t\t\t";
    public HSLFSlideShowImpl doc;
    public boolean optEscher;
    public boolean optVerbose;
    public final PrintStream ps;

    public SlideShowRecordDumper(PrintStream printStream, String str, boolean z, boolean z2) {
        this.ps = printStream;
        this.optVerbose = z;
        this.optEscher = z2;
        this.doc = new HSLFSlideShowImpl(str);
    }

    public static void main(String[] strArr) {
        int i2 = 0;
        boolean z = false;
        boolean z2 = false;
        while (i2 < strArr.length && strArr[i2].substring(0, 1).equals(UnaryMinusPtg.MINUS)) {
            if (strArr[i2].equals("-escher")) {
                z2 = true;
            } else if (strArr[i2].equals("-verbose")) {
                z = true;
            } else {
                printUsage();
                return;
            }
            i2++;
        }
        if (i2 != strArr.length - 1) {
            printUsage();
            return;
        }
        new SlideShowRecordDumper(System.out, strArr[i2], z, z2).printDump();
    }

    private void printEscherContainerRecord(EscherContainerRecord escherContainerRecord, int i2) {
        int i3 = 0;
        String substring = "\t\t\t\t\t\t\t\t\t\t\t\t\t\t\t\t\t\t".substring(0, i2);
        PrintStream printStream = this.ps;
        StringBuilder b2 = a.b(substring);
        b2.append(escherContainerRecord.getClass().getName());
        b2.append(" (");
        b2.append(escherContainerRecord.getRecordName());
        b2.append("):");
        printStream.println(b2.toString());
        PrintStream printStream2 = this.ps;
        StringBuilder d2 = a.d(substring, "  isContainer: ");
        d2.append(escherContainerRecord.isContainerRecord());
        printStream2.println(d2.toString());
        PrintStream printStream3 = this.ps;
        StringBuilder d3 = a.d(substring, "  options: 0x");
        d3.append(HexDump.toHex(escherContainerRecord.getOptions()));
        printStream3.println(d3.toString());
        PrintStream printStream4 = this.ps;
        StringBuilder d4 = a.d(substring, "  recordId: 0x");
        d4.append(HexDump.toHex(escherContainerRecord.getRecordId()));
        printStream4.println(d4.toString());
        List<EscherRecord> childRecords = escherContainerRecord.getChildRecords();
        PrintStream printStream5 = this.ps;
        StringBuilder d5 = a.d(substring, "  numchildren: ");
        d5.append(childRecords.size());
        printStream5.println(d5.toString());
        PrintStream printStream6 = this.ps;
        printStream6.println(substring + "  children: ");
        for (EscherRecord escherRecord : childRecords) {
            PrintStream printStream7 = this.ps;
            printStream7.println(substring + "   Child " + i3 + ":");
            printEscherRecord(escherRecord, i2 + 1);
            i3++;
        }
    }

    private void printEscherTextBox(EscherTextboxRecord escherTextboxRecord, int i2) {
        String str;
        String substring = "\t\t\t\t\t\t\t\t\t\t\t\t\t\t\t\t\t\t".substring(0, i2);
        this.ps.println(substring + "EscherTextboxRecord:");
        Record[] childRecords = new EscherTextboxWrapper(escherTextboxRecord).getChildRecords();
        TextCharsAtom textCharsAtom = null;
        for (Record record : childRecords) {
            if (record instanceof StyleTextPropAtom) {
                if (textCharsAtom instanceof TextCharsAtom) {
                    str = textCharsAtom.getText();
                } else if (textCharsAtom instanceof TextBytesAtom) {
                    str = ((TextBytesAtom) textCharsAtom).getText();
                } else {
                    this.ps.println(substring + "Error! Couldn't find preceding TextAtom for style");
                }
                ((StyleTextPropAtom) record).setParentTextSize(str.length());
            }
            this.ps.println(substring + record);
            textCharsAtom = record;
        }
    }

    public static void printUsage() {
        System.err.println("Usage: SlideShowRecordDumper [-escher] [-verbose] <filename>");
        System.err.println("Valid Options:");
        System.err.println("-escher\t\t: dump contents of escher records");
        System.err.println("-verbose\t: dump binary contents of each record");
    }

    public int getDiskLen(Record record) {
        if (record == null) {
            return 0;
        }
        ByteArrayOutputStream byteArrayOutputStream = new ByteArrayOutputStream();
        record.writeOut(byteArrayOutputStream);
        return byteArrayOutputStream.size();
    }

    public String getPrintableRecordContents(Record record) {
        if (record == null) {
            return "<<null>>";
        }
        ByteArrayOutputStream byteArrayOutputStream = new ByteArrayOutputStream();
        record.writeOut(byteArrayOutputStream);
        return HexDump.dump(byteArrayOutputStream.toByteArray(), 0, 0);
    }

    public String makeHex(int i2, int i3) {
        String upperCase = Integer.toHexString(i2).toUpperCase(Locale.ROOT);
        while (upperCase.length() < i3) {
            upperCase = a.b("0", upperCase);
        }
        return upperCase;
    }

    public void printDump() {
        walkTree(0, 0, this.doc.getRecords(), 0);
    }

    public void printEscherRecord(EscherRecord escherRecord, int i2) {
        if (escherRecord instanceof EscherContainerRecord) {
            printEscherContainerRecord((EscherContainerRecord) escherRecord, i2);
        } else if (escherRecord instanceof EscherTextboxRecord) {
            printEscherTextBox((EscherTextboxRecord) escherRecord, i2);
        } else {
            this.ps.print("\t\t\t\t\t\t\t\t\t\t\t\t\t\t\t\t\t\t".substring(0, i2));
            this.ps.println(escherRecord);
        }
    }

    public String reverseHex(String str) {
        StringBuilder sb = new StringBuilder();
        int i2 = 1;
        if ((str.length() & 1) == 1) {
            sb.append(0);
        } else {
            i2 = 0;
        }
        char[] charArray = str.toCharArray();
        for (char c : charArray) {
            if (i2 > 0 && (i2 & 1) == 0) {
                sb.append(' ');
            }
            sb.append(c);
            i2++;
        }
        return sb.toString();
    }

    public void walkTree(int i2, int i3, Record[] recordArr, int i4) {
        int i5;
        String substring = "\t\t\t\t\t\t\t\t\t\t\t\t\t\t\t\t\t\t".substring(0, i4);
        int i6 = i3;
        int i7 = 0;
        while (i7 < recordArr.length) {
            Record record = recordArr[i7];
            if (record == null) {
                this.ps.println(substring + "At position " + i6 + " (" + makeHex(i6, 6) + "):");
                PrintStream printStream = this.ps;
                StringBuilder sb = new StringBuilder();
                sb.append(substring);
                sb.append("Warning! Null record found.");
                printStream.println(sb.toString());
                i5 = i7;
            } else {
                int diskLen = getDiskLen(record);
                String makeHex = makeHex((int) record.getRecordType(), 4);
                String reverseHex = reverseHex(makeHex);
                String cls = record.getClass().toString();
                if (cls.startsWith("class ")) {
                    cls = cls.substring(6);
                }
                if (cls.startsWith("org.apache.poi.hslf.record.")) {
                    cls = cls.substring(27);
                }
                this.ps.println(substring + "At position " + i6 + " (" + makeHex(i6, 6) + "):");
                PrintStream printStream2 = this.ps;
                StringBuilder sb2 = new StringBuilder();
                sb2.append(substring);
                sb2.append(" Record is of type ");
                sb2.append(cls);
                printStream2.println(sb2.toString());
                PrintStream printStream3 = this.ps;
                StringBuilder d2 = a.d(substring, " Type is ");
                i5 = i7;
                d2.append(record.getRecordType());
                d2.append(" (");
                d2.append(makeHex);
                d2.append(" -> ");
                d2.append(reverseHex);
                d2.append(" )");
                printStream3.println(d2.toString());
                PrintStream printStream4 = this.ps;
                StringBuilder d3 = a.d(substring, " Len is ");
                int i8 = diskLen - 8;
                d3.append(i8);
                d3.append(" (");
                d3.append(makeHex(i8, 8));
                d3.append("), on disk len is ");
                d3.append(diskLen);
                printStream4.println(d3.toString());
                if (this.optEscher && cls.equals("PPDrawing")) {
                    HSLFEscherRecordFactory hSLFEscherRecordFactory = new HSLFEscherRecordFactory();
                    ByteArrayOutputStream byteArrayOutputStream = new ByteArrayOutputStream();
                    record.writeOut(byteArrayOutputStream);
                    byte[] byteArray = byteArrayOutputStream.toByteArray();
                    EscherRecord createRecord = hSLFEscherRecordFactory.createRecord(byteArray, 0);
                    createRecord.fillFields(byteArray, 0, hSLFEscherRecordFactory);
                    printEscherRecord(createRecord, i4 + 1);
                } else if (this.optVerbose && record.getChildRecords() == null) {
                    String printableRecordContents = getPrintableRecordContents(record);
                    this.ps.println(substring + printableRecordContents);
                }
                this.ps.println();
                if (record.getChildRecords() != null) {
                    walkTree(i2 + 3, i6 + 8, record.getChildRecords(), i4 + 1);
                }
                i6 += diskLen;
            }
            i7 = i5 + 1;
        }
    }
}
