package org.apache.poi.hslf.extractor;

import java.io.File;
import java.io.InputStream;
import java.util.ArrayList;
import java.util.HashSet;
import java.util.List;
import org.apache.poi.POIOLE2TextExtractor;
import org.apache.poi.hslf.model.Comment;
import org.apache.poi.hslf.model.HSLFMetroShape;
import org.apache.poi.hslf.model.HeadersFooters;
import org.apache.poi.hslf.model.OLEShape;
import org.apache.poi.hslf.usermodel.HSLFMasterSheet;
import org.apache.poi.hslf.usermodel.HSLFNotes;
import org.apache.poi.hslf.usermodel.HSLFShape;
import org.apache.poi.hslf.usermodel.HSLFSlide;
import org.apache.poi.hslf.usermodel.HSLFSlideMaster;
import org.apache.poi.hslf.usermodel.HSLFSlideShow;
import org.apache.poi.hslf.usermodel.HSLFSlideShowImpl;
import org.apache.poi.hslf.usermodel.HSLFTable;
import org.apache.poi.hslf.usermodel.HSLFTableCell;
import org.apache.poi.hslf.usermodel.HSLFTextParagraph;
import org.apache.poi.hslf.usermodel.HSLFTextShape;
import org.apache.poi.poifs.filesystem.DirectoryNode;
import org.apache.poi.poifs.filesystem.NPOIFSFileSystem;
import org.apache.poi.poifs.filesystem.POIFSFileSystem;
import org.apache.poi.util.POILogFactory;
import org.apache.poi.util.POILogger;

public final class PowerPointExtractor extends POIOLE2TextExtractor {
    public static final POILogger LOG = POILogFactory.getLogger(PowerPointExtractor.class);
    public boolean _commentsByDefault;
    public boolean _masterByDefault;
    public boolean _notesByDefault;
    public final HSLFSlideShow _show;
    public final List<HSLFSlide> _slides;
    public boolean _slidesByDefault;

    public PowerPointExtractor(String str) {
        this(new NPOIFSFileSystem(new File(str)));
    }

    private void extractTableText(StringBuffer stringBuffer, HSLFTable hSLFTable) {
        int numberOfRows = hSLFTable.getNumberOfRows();
        int numberOfColumns = hSLFTable.getNumberOfColumns();
        for (int i2 = 0; i2 < numberOfRows; i2++) {
            for (int i3 = 0; i3 < numberOfColumns; i3++) {
                HSLFTableCell cell = hSLFTable.getCell(i2, i3);
                if (cell != null) {
                    String text = cell.getText();
                    if (text == null) {
                        text = "";
                    }
                    stringBuffer.append(text);
                    if (i3 < numberOfColumns - 1) {
                        stringBuffer.append('\t');
                    }
                }
            }
            stringBuffer.append('\n');
        }
    }

    public static void main(String[] strArr) {
        boolean z;
        String str;
        if (strArr.length < 1) {
            System.err.println("Useage:");
            System.err.println("\tPowerPointExtractor [-notes] <file>");
            System.exit(1);
        }
        boolean z2 = false;
        if (strArr.length > 1) {
            str = strArr[1];
            z = strArr.length > 2;
            z2 = true;
        } else {
            str = strArr[0];
            z = false;
        }
        PowerPointExtractor powerPointExtractor = new PowerPointExtractor(str);
        System.out.println(powerPointExtractor.getText(true, z2, z, true));
        powerPointExtractor.close();
    }

    public static String safeLine(String str) {
        if (str == null) {
            return "";
        }
        return str + '\n';
    }

    private void textRunsToText(StringBuffer stringBuffer, List<List<HSLFTextParagraph>> list) {
        if (list != null) {
            for (List<HSLFTextParagraph> list2 : list) {
                stringBuffer.append(HSLFTextParagraph.getText(list2));
                if (stringBuffer.length() > 0 && stringBuffer.charAt(stringBuffer.length() - 1) != '\n') {
                    stringBuffer.append('\n');
                }
            }
        }
    }

    public String getNotes() {
        return getText(false, true);
    }

    public List<OLEShape> getOLEShapes() {
        ArrayList arrayList = new ArrayList();
        for (HSLFSlide hSLFSlide : this._slides) {
            for (HSLFShape hSLFShape : hSLFSlide.getShapes()) {
                if (hSLFShape instanceof OLEShape) {
                    arrayList.add((OLEShape) hSLFShape);
                }
            }
        }
        return arrayList;
    }

    @Override // org.apache.poi.POITextExtractor
    public String getText() {
        return getText(this._slidesByDefault, this._notesByDefault, this._commentsByDefault, this._masterByDefault);
    }

    public void setCommentsByDefault(boolean z) {
        this._commentsByDefault = z;
    }

    public void setMasterByDefault(boolean z) {
        this._masterByDefault = z;
    }

    public void setNotesByDefault(boolean z) {
        this._notesByDefault = z;
    }

    public void setSlidesByDefault(boolean z) {
        this._slidesByDefault = z;
    }

    public PowerPointExtractor(InputStream inputStream) {
        this(new POIFSFileSystem(inputStream));
    }

    public String getText(boolean z, boolean z2) {
        return getText(z, z2, this._commentsByDefault, this._masterByDefault);
    }

    public PowerPointExtractor(POIFSFileSystem pOIFSFileSystem) {
        this(pOIFSFileSystem.getRoot());
    }

    public String getText(boolean z, boolean z2, boolean z3, boolean z4) {
        String str;
        String str2;
        String str3;
        String text;
        StringBuffer stringBuffer = new StringBuffer();
        String str4 = "";
        if (z) {
            if (z4) {
                for (HSLFSlideMaster hSLFSlideMaster : this._show.getSlideMasters()) {
                    for (HSLFShape hSLFShape : hSLFSlideMaster.getShapes()) {
                        if ((hSLFShape instanceof HSLFTextShape) && (text = ((HSLFTextShape) hSLFShape).getText()) != null && !str4.equals(text) && !"*".equals(text)) {
                            if (!HSLFMasterSheet.isPlaceholder(hSLFShape) || new HSLFMetroShape(hSLFShape).hasMetroBlob()) {
                                stringBuffer.append(text);
                                if (!text.endsWith("\n")) {
                                    stringBuffer.append("\n");
                                }
                            } else {
                                LOG.log(3, "Ignoring boiler plate (placeholder) text on slide master:", text);
                            }
                        }
                    }
                }
            }
            for (HSLFSlide hSLFSlide : this._slides) {
                HeadersFooters headersFooters = hSLFSlide.getHeadersFooters();
                if (headersFooters != null) {
                    str2 = headersFooters.isHeaderVisible() ? safeLine(headersFooters.getHeaderText()) : str4;
                    str3 = headersFooters.isFooterVisible() ? safeLine(headersFooters.getFooterText()) : str4;
                } else {
                    str3 = str4;
                    str2 = str3;
                }
                stringBuffer.append(str2);
                textRunsToText(stringBuffer, hSLFSlide.getTextParagraphs());
                for (HSLFShape hSLFShape2 : hSLFSlide.getShapes()) {
                    if (hSLFShape2 instanceof HSLFTable) {
                        extractTableText(stringBuffer, (HSLFTable) hSLFShape2);
                    }
                }
                stringBuffer.append(str3);
                if (z3) {
                    Comment[] comments = hSLFSlide.getComments();
                    for (Comment comment : comments) {
                        stringBuffer.append(comment.getAuthor() + " - " + comment.getText() + "\n");
                    }
                }
            }
            if (z2) {
                stringBuffer.append('\n');
            }
        }
        if (z2) {
            HashSet hashSet = new HashSet();
            HeadersFooters notesHeadersFooters = this._show.getNotesHeadersFooters();
            if (notesHeadersFooters != null) {
                String safeLine = notesHeadersFooters.isHeaderVisible() ? safeLine(notesHeadersFooters.getHeaderText()) : str4;
                if (notesHeadersFooters.isFooterVisible()) {
                    str4 = safeLine(notesHeadersFooters.getFooterText());
                }
                str = str4;
                str4 = safeLine;
            } else {
                str = str4;
            }
            for (HSLFSlide hSLFSlide2 : this._slides) {
                HSLFNotes notes = hSLFSlide2.getNotes();
                if (notes != null) {
                    Integer valueOf = Integer.valueOf(notes._getSheetNumber());
                    if (!hashSet.contains(valueOf)) {
                        hashSet.add(valueOf);
                        stringBuffer.append(str4);
                        textRunsToText(stringBuffer, notes.getTextParagraphs());
                        stringBuffer.append(str);
                    }
                }
            }
        }
        return stringBuffer.toString();
    }

    public PowerPointExtractor(NPOIFSFileSystem nPOIFSFileSystem) {
        this(nPOIFSFileSystem.getRoot());
        setFilesystem(nPOIFSFileSystem);
    }

    public PowerPointExtractor(DirectoryNode directoryNode) {
        this(new HSLFSlideShowImpl(directoryNode));
    }

    public PowerPointExtractor(HSLFSlideShowImpl hSLFSlideShowImpl) {
        super(hSLFSlideShowImpl);
        this._slidesByDefault = true;
        this._notesByDefault = false;
        this._commentsByDefault = false;
        this._masterByDefault = false;
        HSLFSlideShow hSLFSlideShow = new HSLFSlideShow(hSLFSlideShowImpl);
        this._show = hSLFSlideShow;
        this._slides = hSLFSlideShow.getSlides();
    }
}
