package org.apache.poi.hslf.extractor;

import java.io.File;
import java.io.InputStream;
import java.util.ArrayList;
import java.util.List;
import org.apache.poi.hslf.record.CString;
import org.apache.poi.hslf.record.Record;
import org.apache.poi.hslf.record.RecordTypes;
import org.apache.poi.hslf.record.TextBytesAtom;
import org.apache.poi.hslf.record.TextCharsAtom;
import org.apache.poi.hslf.usermodel.HSLFSlideShow;
import org.apache.poi.hslf.usermodel.HSLFTextParagraph;
import org.apache.poi.poifs.filesystem.DocumentInputStream;
import org.apache.poi.poifs.filesystem.NPOIFSFileSystem;
import org.apache.poi.util.IOUtils;
import org.apache.poi.util.LittleEndian;

public final class QuickButCruddyTextExtractor {
    public NPOIFSFileSystem fs;
    public InputStream is;
    public byte[] pptContents;

    public QuickButCruddyTextExtractor(String str) {
        this(new NPOIFSFileSystem(new File(str)));
    }

    public static void main(String[] strArr) {
        if (strArr.length < 1) {
            System.err.println("Useage:");
            System.err.println("\tQuickButCruddyTextExtractor <file>");
            System.exit(1);
        }
        QuickButCruddyTextExtractor quickButCruddyTextExtractor = new QuickButCruddyTextExtractor(strArr[0]);
        System.out.println(quickButCruddyTextExtractor.getTextAsString());
        quickButCruddyTextExtractor.close();
    }

    public void close() {
        InputStream inputStream = this.is;
        if (inputStream != null) {
            inputStream.close();
        }
        this.fs = null;
    }

    public int findTextRecords(int i2, List<String> list) {
        int uInt = (int) LittleEndian.getUInt(this.pptContents, i2 + 4);
        byte[] bArr = this.pptContents;
        if ((bArr[i2] & 15) == 15) {
            return i2 + 8;
        }
        int uShort = LittleEndian.getUShort(bArr, i2 + 2);
        if (uShort == RecordTypes.TextBytesAtom.typeID) {
            list.add(HSLFTextParagraph.toExternalString(((TextBytesAtom) Record.createRecordForType((long) uShort, this.pptContents, i2, uInt + 8)).getText(), -1));
        }
        if (uShort == RecordTypes.TextCharsAtom.typeID) {
            list.add(HSLFTextParagraph.toExternalString(((TextCharsAtom) Record.createRecordForType((long) uShort, this.pptContents, i2, uInt + 8)).getText(), -1));
        }
        if (uShort == RecordTypes.CString.typeID) {
            String text = ((CString) Record.createRecordForType((long) uShort, this.pptContents, i2, uInt + 8)).getText();
            if (!text.equals("___PPT10") && !text.equals("Default Design")) {
                list.add(text);
            }
        }
        int i3 = i2 + 8 + uInt;
        if (i3 > this.pptContents.length - 8) {
            return -1;
        }
        return i3;
    }

    public String getTextAsString() {
        StringBuffer stringBuffer = new StringBuffer();
        for (String str : getTextAsVector()) {
            stringBuffer.append(str);
            if (!str.endsWith("\n")) {
                stringBuffer.append('\n');
            }
        }
        return stringBuffer.toString();
    }

    public List<String> getTextAsVector() {
        ArrayList arrayList = new ArrayList();
        int i2 = 0;
        while (i2 != -1) {
            i2 = findTextRecords(i2, arrayList);
        }
        return arrayList;
    }

    public QuickButCruddyTextExtractor(InputStream inputStream) {
        this(new NPOIFSFileSystem(inputStream));
        this.is = inputStream;
    }

    public QuickButCruddyTextExtractor(NPOIFSFileSystem nPOIFSFileSystem) {
        this.fs = nPOIFSFileSystem;
        DocumentInputStream createDocumentInputStream = nPOIFSFileSystem.createDocumentInputStream(HSLFSlideShow.POWERPOINT_DOCUMENT);
        this.pptContents = IOUtils.toByteArray(createDocumentInputStream);
        createDocumentInputStream.close();
    }
}
