package org.apache.poi.hslf.model;

import org.apache.poi.ddf.AbstractEscherOptRecord;
import org.apache.poi.ddf.EscherComplexProperty;
import org.apache.poi.hslf.usermodel.HSLFShape;
import org.apache.poi.sl.usermodel.Shape;
import org.apache.poi.util.Internal;
import org.apache.poi.util.POILogFactory;
import org.apache.poi.util.POILogger;

@Internal
public class HSLFMetroShape<T extends Shape<?, ?>> {
    public static final POILogger LOGGER = POILogFactory.getLogger(HSLFMetroShape.class);
    public final HSLFShape shape;

    public HSLFMetroShape(HSLFShape hSLFShape) {
        this.shape = hSLFShape;
    }

    private EscherComplexProperty getMetroProp() {
        AbstractEscherOptRecord abstractEscherOptRecord = (AbstractEscherOptRecord) this.shape.getEscherChild(-3806);
        if (abstractEscherOptRecord == null) {
            return null;
        }
        return (EscherComplexProperty) abstractEscherOptRecord.lookup(937);
    }

    public byte[] getMetroBytes() {
        EscherComplexProperty metroProp = getMetroProp();
        if (metroProp == null) {
            return null;
        }
        return metroProp.getComplexData();
    }

    public T getShape() {
        byte[] metroBytes = getMetroBytes();
        if (metroBytes == null) {
            return null;
        }
        try {
            return (T) ((Shape) Thread.currentThread().getContextClassLoader().loadClass("org.apache.poi.xslf.usermodel.XSLFMetroShape").getMethod("parseShape", byte[].class).invoke(null, metroBytes));
        } catch (Exception e2) {
            LOGGER.log(7, "can't process metro blob, check if all dependencies for POI OOXML are in the classpath.", e2);
            return null;
        }
    }

    public boolean hasMetroBlob() {
        return getMetroProp() != null;
    }
}
