package org.apache.poi.hslf.model;

import org.apache.poi.hslf.record.CString;
import org.apache.poi.hslf.record.Document;
import org.apache.poi.hslf.record.HeadersFootersContainer;
import org.apache.poi.hslf.record.Record;
import org.apache.poi.hslf.record.RecordTypes;
import org.apache.poi.hslf.usermodel.HSLFSheet;
import org.apache.poi.hslf.usermodel.HSLFSimpleShape;
import org.apache.poi.hslf.usermodel.HSLFSlideMaster;
import org.apache.poi.hslf.usermodel.HSLFSlideShow;
import org.apache.poi.hslf.usermodel.HSLFTextShape;
import org.apache.poi.sl.usermodel.Placeholder;

public final class HeadersFooters {
    public static final String _ppt2007tag = "___PPT12";
    public final HeadersFootersContainer _container;
    public final boolean _ppt2007;
    public final HSLFSheet _sheet;

    public HeadersFooters(HSLFSlideShow hSLFSlideShow, short s) {
        this((HSLFSheet) hSLFSlideShow.getSlideMasters().get(0), s);
    }

    private String getPlaceholderText(Placeholder placeholder, CString cString) {
        if (this._ppt2007) {
            HSLFSimpleShape placeholder2 = this._sheet.getPlaceholder(placeholder);
            String text = placeholder2 instanceof HSLFTextShape ? ((HSLFTextShape) placeholder2).getText() : null;
            if ("*".equals(text)) {
                return null;
            }
            return text;
        } else if (cString == null) {
            return null;
        } else {
            return cString.getText();
        }
    }

    private boolean isVisible(int i2, Placeholder placeholder) {
        if (!this._ppt2007) {
            return this._container.getHeadersFootersAtom().getFlag(i2);
        }
        HSLFSimpleShape placeholder2 = this._sheet.getPlaceholder(placeholder);
        return (placeholder2 instanceof HSLFTextShape) && ((HSLFTextShape) placeholder2).getText() != null;
    }

    private void setFlag(int i2, boolean z) {
        this._container.getHeadersFootersAtom().setFlag(i2, z);
    }

    public int getDateTimeFormat() {
        return this._container.getHeadersFootersAtom().getFormatId();
    }

    public String getDateTimeText() {
        HeadersFootersContainer headersFootersContainer = this._container;
        return getPlaceholderText(Placeholder.DATETIME, headersFootersContainer == null ? null : headersFootersContainer.getUserDateAtom());
    }

    public String getFooterText() {
        HeadersFootersContainer headersFootersContainer = this._container;
        return getPlaceholderText(Placeholder.FOOTER, headersFootersContainer == null ? null : headersFootersContainer.getFooterAtom());
    }

    public String getHeaderText() {
        HeadersFootersContainer headersFootersContainer = this._container;
        return getPlaceholderText(Placeholder.HEADER, headersFootersContainer == null ? null : headersFootersContainer.getHeaderAtom());
    }

    public boolean isDateTimeVisible() {
        return isVisible(1, Placeholder.DATETIME);
    }

    public boolean isFooterVisible() {
        return isVisible(32, Placeholder.FOOTER);
    }

    public boolean isHeaderVisible() {
        return isVisible(16, Placeholder.HEADER);
    }

    public boolean isSlideNumberVisible() {
        return isVisible(8, Placeholder.SLIDE_NUMBER);
    }

    public boolean isUserDateVisible() {
        return isVisible(4, Placeholder.DATETIME);
    }

    public void setDateTimeFormat(int i2) {
        this._container.getHeadersFootersAtom().setFormatId(i2);
    }

    public void setDateTimeText(String str) {
        setUserDateVisible(true);
        setDateTimeVisible(true);
        CString userDateAtom = this._container.getUserDateAtom();
        if (userDateAtom == null) {
            userDateAtom = this._container.addUserDateAtom();
        }
        userDateAtom.setText(str);
    }

    public void setDateTimeVisible(boolean z) {
        setFlag(1, z);
    }

    public void setFooterVisible(boolean z) {
        setFlag(32, z);
    }

    public void setFootersText(String str) {
        setFooterVisible(true);
        CString footerAtom = this._container.getFooterAtom();
        if (footerAtom == null) {
            footerAtom = this._container.addFooterAtom();
        }
        footerAtom.setText(str);
    }

    public void setHeaderText(String str) {
        setHeaderVisible(true);
        CString headerAtom = this._container.getHeaderAtom();
        if (headerAtom == null) {
            headerAtom = this._container.addHeaderAtom();
        }
        headerAtom.setText(str);
    }

    public void setHeaderVisible(boolean z) {
        setFlag(16, z);
    }

    public void setSlideNumberVisible(boolean z) {
        setFlag(8, z);
    }

    public void setUserDateVisible(boolean z) {
        setFlag(4, z);
    }

    public HeadersFooters(HSLFSheet hSLFSheet, short s) {
        this._sheet = hSLFSheet;
        HSLFSlideShow slideShow = hSLFSheet.getSlideShow();
        Document documentRecord = slideShow.getDocumentRecord();
        int i2 = 0;
        this._ppt2007 = _ppt2007tag.equals(((HSLFSlideMaster) slideShow.getSlideMasters().get(0)).getProgrammableTag());
        HeadersFootersContainer headersFootersContainer = (HeadersFootersContainer) this._sheet.getSheetContainer().findFirstOfType((long) RecordTypes.HeadersFooters.typeID);
        if (headersFootersContainer == null) {
            Record[] childRecords = documentRecord.getChildRecords();
            int length = childRecords.length;
            while (true) {
                if (i2 >= length) {
                    break;
                }
                Record record = childRecords[i2];
                if (record instanceof HeadersFootersContainer) {
                    HeadersFootersContainer headersFootersContainer2 = (HeadersFootersContainer) record;
                    if (headersFootersContainer2.getOptions() == s) {
                        headersFootersContainer = headersFootersContainer2;
                        break;
                    }
                }
                i2++;
            }
        }
        if (headersFootersContainer == null) {
            headersFootersContainer = new HeadersFootersContainer(s);
            documentRecord.addChildAfter(headersFootersContainer, documentRecord.findFirstOfType((long) RecordTypes.List.typeID));
        }
        this._container = headersFootersContainer;
    }
}
