package org.apache.poi.hslf.model;

import java.util.Iterator;
import org.apache.poi.ddf.EscherContainerRecord;
import org.apache.poi.ddf.EscherSpRecord;
import org.apache.poi.hslf.record.ExEmbed;
import org.apache.poi.hslf.record.ExObjList;
import org.apache.poi.hslf.record.ExObjRefAtom;
import org.apache.poi.hslf.record.HSLFEscherClientDataRecord;
import org.apache.poi.hslf.record.Record;
import org.apache.poi.hslf.record.RecordTypes;
import org.apache.poi.hslf.usermodel.HSLFObjectData;
import org.apache.poi.hslf.usermodel.HSLFPictureData;
import org.apache.poi.hslf.usermodel.HSLFPictureShape;
import org.apache.poi.hslf.usermodel.HSLFShape;
import org.apache.poi.hslf.usermodel.HSLFTextParagraph;
import org.apache.poi.sl.usermodel.ShapeContainer;
import org.apache.poi.util.POILogFactory;
import org.apache.poi.util.POILogger;

public final class OLEShape extends HSLFPictureShape {
    public static final POILogger LOG = POILogFactory.getLogger(OLEShape.class);
    public ExEmbed _exEmbed;

    public OLEShape(HSLFPictureData hSLFPictureData) {
        super(hSLFPictureData);
    }

    public ExEmbed getExEmbed() {
        if (this._exEmbed == null) {
            ExObjList exObjList = getSheet().getSlideShow().getDocumentRecord().getExObjList(false);
            if (exObjList == null) {
                LOG.log(5, "ExObjList not found");
                return null;
            }
            int objectID = getObjectID();
            Record[] childRecords = exObjList.getChildRecords();
            for (int i2 = 0; i2 < childRecords.length; i2++) {
                if (childRecords[i2] instanceof ExEmbed) {
                    ExEmbed exEmbed = (ExEmbed) childRecords[i2];
                    if (exEmbed.getExOleObjAtom().getObjID() == objectID) {
                        this._exEmbed = exEmbed;
                    }
                }
            }
        }
        return this._exEmbed;
    }

    public String getFullName() {
        ExEmbed exEmbed = getExEmbed();
        if (exEmbed == null) {
            return null;
        }
        return exEmbed.getClipboardName();
    }

    public String getInstanceName() {
        ExEmbed exEmbed = getExEmbed();
        if (exEmbed == null) {
            return null;
        }
        return exEmbed.getMenuName();
    }

    public HSLFObjectData getObjectData() {
        HSLFObjectData[] embeddedObjects = getSheet().getSlideShow().getEmbeddedObjects();
        ExEmbed exEmbed = getExEmbed();
        HSLFObjectData hSLFObjectData = null;
        if (exEmbed != null) {
            int objStgDataRef = exEmbed.getExOleObjAtom().getObjStgDataRef();
            for (int i2 = 0; i2 < embeddedObjects.length; i2++) {
                if (embeddedObjects[i2].getExOleObjStg().getPersistId() == objStgDataRef) {
                    hSLFObjectData = embeddedObjects[i2];
                }
            }
        }
        if (hSLFObjectData == null) {
            LOG.log(5, "OLE data not found");
        }
        return hSLFObjectData;
    }

    public int getObjectID() {
        return getEscherProperty(267);
    }

    public String getProgID() {
        ExEmbed exEmbed = getExEmbed();
        if (exEmbed == null) {
            return null;
        }
        return exEmbed.getProgId();
    }

    public void setObjectID(int i2) {
        ExObjRefAtom exObjRefAtom;
        setEscherProperty(267, i2);
        EscherSpRecord escherSpRecord = (EscherSpRecord) getSpContainer().getChildById(EscherSpRecord.RECORD_ID);
        escherSpRecord.setFlags(escherSpRecord.getFlags() | 16);
        HSLFEscherClientDataRecord clientData = getClientData(true);
        Iterator<? extends Record> it = clientData.getHSLFChildRecords().iterator();
        while (true) {
            if (!it.hasNext()) {
                exObjRefAtom = null;
                break;
            }
            Record record = (Record) it.next();
            if (record.getRecordType() == ((long) RecordTypes.ExObjRefAtom.typeID)) {
                exObjRefAtom = (ExObjRefAtom) record;
                break;
            }
        }
        if (exObjRefAtom == null) {
            exObjRefAtom = new ExObjRefAtom();
            clientData.addChild(exObjRefAtom);
        }
        exObjRefAtom.setExObjIdRef(i2);
    }

    public OLEShape(HSLFPictureData hSLFPictureData, ShapeContainer<HSLFShape, HSLFTextParagraph> shapeContainer) {
        super(hSLFPictureData, shapeContainer);
    }

    public OLEShape(EscherContainerRecord escherContainerRecord, ShapeContainer<HSLFShape, HSLFTextParagraph> shapeContainer) {
        super(escherContainerRecord, shapeContainer);
    }
}
