package org.apache.poi.hslf.model;

import java.awt.geom.Point2D;
import org.apache.poi.ddf.AbstractEscherOptRecord;
import org.apache.poi.ddf.EscherArrayProperty;
import org.apache.poi.ddf.EscherContainerRecord;
import org.apache.poi.ddf.EscherProperties;
import org.apache.poi.ddf.EscherSimpleProperty;
import org.apache.poi.hslf.usermodel.HSLFAutoShape;
import org.apache.poi.hslf.usermodel.HSLFGroupShape;
import org.apache.poi.hslf.usermodel.HSLFShape;
import org.apache.poi.hslf.usermodel.HSLFTextParagraph;
import org.apache.poi.sl.usermodel.ShapeContainer;
import org.apache.poi.sl.usermodel.ShapeType;
import org.apache.poi.util.LittleEndian;
import org.apache.poi.util.Units;

public final class Polygon extends HSLFAutoShape {
    public Polygon(EscherContainerRecord escherContainerRecord, ShapeContainer<HSLFShape, HSLFTextParagraph> shapeContainer) {
        super(escherContainerRecord, shapeContainer);
    }

    private float findBiggest(float[] fArr) {
        float f2 = Float.MIN_VALUE;
        for (int i2 = 0; i2 < fArr.length; i2++) {
            if (fArr[i2] > f2) {
                f2 = fArr[i2];
            }
        }
        return f2;
    }

    private float findSmallest(float[] fArr) {
        float f2 = Float.MAX_VALUE;
        for (int i2 = 0; i2 < fArr.length; i2++) {
            if (fArr[i2] < f2) {
                f2 = fArr[i2];
            }
        }
        return f2;
    }

    public void setPoints(float[] fArr, float[] fArr2) {
        float findBiggest = findBiggest(fArr);
        float findBiggest2 = findBiggest(fArr2);
        float findSmallest = findSmallest(fArr);
        float findSmallest2 = findSmallest(fArr2);
        AbstractEscherOptRecord escherOptRecord = getEscherOptRecord();
        escherOptRecord.addEscherProperty(new EscherSimpleProperty(EscherProperties.GEOMETRY__RIGHT, Units.pointsToMaster((double) (findBiggest - findSmallest))));
        escherOptRecord.addEscherProperty(new EscherSimpleProperty(EscherProperties.GEOMETRY__BOTTOM, Units.pointsToMaster((double) (findBiggest2 - findSmallest2))));
        for (int i2 = 0; i2 < fArr.length; i2++) {
            fArr[i2] = fArr[i2] + (-findSmallest);
            fArr2[i2] = fArr2[i2] + (-findSmallest2);
        }
        int length = fArr.length;
        EscherArrayProperty escherArrayProperty = new EscherArrayProperty(EscherProperties.GEOMETRY__VERTICES, false, new byte[0]);
        int i3 = length + 1;
        escherArrayProperty.setNumberOfElementsInArray(i3);
        escherArrayProperty.setNumberOfElementsInMemory(i3);
        escherArrayProperty.setSizeOfElements(65520);
        for (int i4 = 0; i4 < length; i4++) {
            byte[] bArr = new byte[4];
            LittleEndian.putShort(bArr, 0, (short) Units.pointsToMaster((double) fArr[i4]));
            LittleEndian.putShort(bArr, 2, (short) Units.pointsToMaster((double) fArr2[i4]));
            escherArrayProperty.setElement(i4, bArr);
        }
        byte[] bArr2 = new byte[4];
        LittleEndian.putShort(bArr2, 0, (short) Units.pointsToMaster((double) fArr[0]));
        LittleEndian.putShort(bArr2, 2, (short) Units.pointsToMaster((double) fArr2[0]));
        escherArrayProperty.setElement(length, bArr2);
        escherOptRecord.addEscherProperty(escherArrayProperty);
        EscherArrayProperty escherArrayProperty2 = new EscherArrayProperty(EscherProperties.GEOMETRY__SEGMENTINFO, false, null);
        escherArrayProperty2.setSizeOfElements(2);
        int i5 = (length * 2) + 4;
        escherArrayProperty2.setNumberOfElementsInArray(i5);
        escherArrayProperty2.setNumberOfElementsInMemory(i5);
        escherArrayProperty2.setElement(0, new byte[]{0, 64});
        escherArrayProperty2.setElement(1, new byte[]{0, -84});
        for (int i6 = 0; i6 < length; i6++) {
            int i7 = i6 * 2;
            escherArrayProperty2.setElement(i7 + 2, new byte[]{1, 0});
            escherArrayProperty2.setElement(i7 + 3, new byte[]{0, -84});
        }
        escherArrayProperty2.setElement(escherArrayProperty2.getNumberOfElementsInArray() - 2, new byte[]{1, 96});
        escherArrayProperty2.setElement(escherArrayProperty2.getNumberOfElementsInArray() - 1, new byte[]{0, Byte.MIN_VALUE});
        escherOptRecord.addEscherProperty(escherArrayProperty2);
        escherOptRecord.sortProperties();
    }

    public Polygon(ShapeContainer<HSLFShape, HSLFTextParagraph> shapeContainer) {
        super((EscherContainerRecord) null, shapeContainer);
        createSpContainer(ShapeType.NOT_PRIMITIVE, shapeContainer instanceof HSLFGroupShape);
    }

    public Polygon() {
        this(null);
    }

    public void setPoints(Point2D[] point2DArr) {
        float[] fArr = new float[point2DArr.length];
        float[] fArr2 = new float[point2DArr.length];
        for (int i2 = 0; i2 < point2DArr.length; i2++) {
            fArr[i2] = (float) point2DArr[i2].getX();
            fArr2[i2] = (float) point2DArr[i2].getY();
        }
        setPoints(fArr, fArr2);
    }
}
