package org.apache.poi.hslf.model.textproperties;

import b.b.a.a.a;
import org.apache.poi.util.POILogFactory;
import org.apache.poi.util.POILogger;
import org.apache.poi.xssf.usermodel.XSSFDataValidationConstraint;

public abstract class BitMaskTextProp extends TextProp implements Cloneable {
    public static final POILogger logger = POILogFactory.getLogger(BitMaskTextProp.class);
    public int[] subPropMasks;
    public boolean[] subPropMatches;
    public String[] subPropNames;

    public BitMaskTextProp(int i2, int i3, String str, String... strArr) {
        super(i2, i3, str);
        this.subPropNames = strArr;
        this.subPropMasks = new int[strArr.length];
        this.subPropMatches = new boolean[strArr.length];
        int lowestOneBit = Integer.lowestOneBit(i3);
        int i4 = 0;
        while (true) {
            int[] iArr = this.subPropMasks;
            if (i4 < iArr.length) {
                iArr[i4] = lowestOneBit << i4;
                i4++;
            } else {
                return;
            }
        }
    }

    private int maskValue(int i2) {
        int[] iArr = this.subPropMasks;
        int length = iArr.length;
        int i3 = 0;
        int i4 = 0;
        while (i3 < length) {
            int i5 = iArr[i3];
            int i6 = i4 + 1;
            if (!this.subPropMatches[i4]) {
                i2 &= ~i5;
            }
            i3++;
            i4 = i6;
        }
        return i2;
    }

    public BitMaskTextProp cloneAll() {
        return (BitMaskTextProp) super.clone();
    }

    public boolean[] getSubPropMatches() {
        return this.subPropMatches;
    }

    public String[] getSubPropNames() {
        return this.subPropNames;
    }

    public boolean getSubValue(int i2) {
        if (this.subPropMatches[i2]) {
            if ((this.subPropMasks[i2] & super.getValue()) != 0) {
                return true;
            }
        }
        return false;
    }

    @Override // org.apache.poi.hslf.model.textproperties.TextProp
    public int getValue() {
        return maskValue(super.getValue());
    }

    @Override // org.apache.poi.hslf.model.textproperties.TextProp
    public int getWriteMask() {
        int[] iArr = this.subPropMasks;
        int length = iArr.length;
        int i2 = 0;
        int i3 = 0;
        int i4 = 0;
        while (i2 < length) {
            int i5 = iArr[i2];
            int i6 = i4 + 1;
            if (this.subPropMatches[i4]) {
                i3 |= i5;
            }
            i2++;
            i4 = i6;
        }
        return i3;
    }

    public void setSubValue(boolean z, int i2) {
        int i3;
        this.subPropMatches[i2] = true;
        int value = super.getValue();
        if (z) {
            i3 = this.subPropMasks[i2] | value;
        } else {
            i3 = (~this.subPropMasks[i2]) & value;
        }
        super.setValue(i3);
    }

    @Override // org.apache.poi.hslf.model.textproperties.TextProp
    public void setValue(int i2) {
        super.setValue(i2);
        int[] iArr = this.subPropMasks;
        int length = iArr.length;
        int i3 = 0;
        int i4 = 0;
        while (i3 < length) {
            int i5 = i4 + 1;
            this.subPropMatches[i4] = (iArr[i3] & i2) != 0;
            i3++;
            i4 = i5;
        }
    }

    public void setValueWithMask(int i2, int i3) {
        setWriteMask(i3);
        super.setValue(maskValue(i2));
        if (i2 != super.getValue()) {
            POILogger pOILogger = logger;
            StringBuilder b2 = a.b("Style properties of '");
            b2.append(getName());
            b2.append("' don't match mask - output will be sanitized");
            pOILogger.log(5, b2.toString());
            if (logger.check(1)) {
                StringBuilder b3 = a.b("The following style attributes of the '");
                b3.append(getName());
                b3.append("' property will be ignored:\n");
                StringBuilder sb = new StringBuilder(b3.toString());
                int[] iArr = this.subPropMasks;
                int i4 = 0;
                for (int i5 : iArr) {
                    if (!this.subPropMatches[i4] && (i5 & i2) != 0) {
                        sb.append(this.subPropNames[i4]);
                        sb.append(XSSFDataValidationConstraint.LIST_SEPARATOR);
                    }
                    i4++;
                }
                logger.log(1, sb.toString());
            }
        }
    }

    public void setWriteMask(int i2) {
        int[] iArr = this.subPropMasks;
        int length = iArr.length;
        int i3 = 0;
        int i4 = 0;
        while (i3 < length) {
            int i5 = i4 + 1;
            this.subPropMatches[i4] = (iArr[i3] & i2) != 0;
            i3++;
            i4 = i5;
        }
    }

    @Override // java.lang.Object, org.apache.poi.hslf.model.textproperties.TextProp, org.apache.poi.hslf.model.textproperties.TextProp
    public BitMaskTextProp clone() {
        BitMaskTextProp bitMaskTextProp = (BitMaskTextProp) super.clone();
        bitMaskTextProp.subPropMatches = new boolean[this.subPropMatches.length];
        return bitMaskTextProp;
    }
}
