package org.apache.poi.hslf.model.textproperties;

import java.util.ArrayList;
import java.util.List;
import org.apache.poi.util.LittleEndian;

public class TabStopPropCollection extends TextProp {
    public List<TabStop> tabStops = new ArrayList();

    public static class TabStop {
        public int position;
        public TabStopType type;

        public TabStop(int i2, TabStopType tabStopType) {
            this.position = i2;
            this.type = tabStopType;
        }

        public int getPosition() {
            return this.position;
        }

        public TabStopType getType() {
            return this.type;
        }

        public void setPosition(int i2) {
            this.position = i2;
        }

        public void setType(TabStopType tabStopType) {
            this.type = tabStopType;
        }
    }

    public enum TabStopType {
        LEFT(0),
        CENTER(1),
        RIGHT(2),
        DECIMAL(3);
        
        public final int val;

        /* access modifiers changed from: public */
        TabStopType(int i2) {
            this.val = i2;
        }

        public static TabStopType fromRecordVal(int i2) {
            TabStopType[] values = values();
            for (TabStopType tabStopType : values) {
                if (tabStopType.val == i2) {
                    return tabStopType;
                }
            }
            return LEFT;
        }
    }

    public TabStopPropCollection() {
        super(0, 1048576, "tabStops");
    }

    @Override // org.apache.poi.hslf.model.textproperties.TextProp
    public int getSize() {
        return (this.tabStops.size() * 4) + 2;
    }

    public void parseProperty(byte[] bArr, int i2) {
        int uShort = LittleEndian.getUShort(bArr, i2);
        int i3 = i2 + 2;
        for (int i4 = 0; i4 < uShort; i4++) {
            short s = LittleEndian.getShort(bArr, i3);
            int i5 = i3 + 2;
            TabStopType fromRecordVal = TabStopType.fromRecordVal(LittleEndian.getShort(bArr, i5));
            i3 = i5 + 2;
            this.tabStops.add(new TabStop(s, fromRecordVal));
        }
    }

    @Override // java.lang.Object, org.apache.poi.hslf.model.textproperties.TextProp, org.apache.poi.hslf.model.textproperties.TextProp
    public TabStopPropCollection clone() {
        TabStopPropCollection tabStopPropCollection = (TabStopPropCollection) super.clone();
        tabStopPropCollection.tabStops = new ArrayList();
        for (TabStop tabStop : this.tabStops) {
            tabStopPropCollection.tabStops.add(new TabStop(tabStop.getPosition(), tabStop.getType()));
        }
        return tabStopPropCollection;
    }
}
