package org.apache.poi.hslf.model.textproperties;

import org.apache.poi.sl.usermodel.AutoNumberingScheme;
import org.apache.poi.util.LittleEndian;

public class TextPFException9 {
    public static final AutoNumberingScheme DEFAULT_AUTONUMBER_SHEME = AutoNumberingScheme.arabicPeriod;
    public static final Short DEFAULT_START_NUMBER = 1;
    public final AutoNumberingScheme autoNumberScheme;
    public final Short autoNumberStartNumber;
    public final Short bulletBlipRef;
    public final Short fBulletHasAutoNumber;
    public final byte mask3;
    public final byte mask4;
    public final int recordLength;

    public TextPFException9(byte[] bArr, int i2) {
        byte b2 = bArr[i2 + 2];
        this.mask3 = b2;
        this.mask4 = bArr[i2 + 3];
        int i3 = 4;
        int i4 = i2 + 4;
        if ((b2 & Byte.MIN_VALUE) == 0) {
            this.bulletBlipRef = null;
        } else {
            this.bulletBlipRef = Short.valueOf(LittleEndian.getShort(bArr, i4));
            i4 += 2;
            i3 = 6;
        }
        if ((this.mask4 & 2) == 0) {
            this.fBulletHasAutoNumber = null;
        } else {
            this.fBulletHasAutoNumber = Short.valueOf(LittleEndian.getShort(bArr, i4));
            i4 += 2;
            i3 += 2;
        }
        if ((this.mask4 & 1) == 0) {
            this.autoNumberScheme = null;
            this.autoNumberStartNumber = null;
        } else {
            this.autoNumberScheme = AutoNumberingScheme.forNativeID(LittleEndian.getShort(bArr, i4));
            this.autoNumberStartNumber = Short.valueOf(LittleEndian.getShort(bArr, i4 + 2));
            i3 += 4;
        }
        this.recordLength = i3;
    }

    public AutoNumberingScheme getAutoNumberScheme() {
        AutoNumberingScheme autoNumberingScheme = this.autoNumberScheme;
        if (autoNumberingScheme != null) {
            return autoNumberingScheme;
        }
        Short sh = this.fBulletHasAutoNumber;
        if (sh == null || 1 != sh.shortValue()) {
            return null;
        }
        return DEFAULT_AUTONUMBER_SHEME;
    }

    public Short getAutoNumberStartNumber() {
        Short sh = this.autoNumberStartNumber;
        if (sh != null) {
            return sh;
        }
        Short sh2 = this.fBulletHasAutoNumber;
        if (sh2 == null || 1 != sh2.shortValue()) {
            return null;
        }
        return DEFAULT_START_NUMBER;
    }

    public Short getBulletBlipRef() {
        return this.bulletBlipRef;
    }

    public int getRecordLength() {
        return this.recordLength;
    }

    public Short getfBulletHasAutoNumber() {
        return this.fBulletHasAutoNumber;
    }

    public String toString() {
        return "Record length: " + this.recordLength + " bytes\n" + "bulletBlipRef: " + this.bulletBlipRef + "\n" + "fBulletHasAutoNumber: " + this.fBulletHasAutoNumber + "\n" + "autoNumberScheme: " + this.autoNumberScheme + "\n" + "autoNumberStartNumber: " + this.autoNumberStartNumber + "\n";
    }
}
