package org.apache.poi.hslf.record;

import b.b.a.a.a;
import java.io.OutputStream;
import org.apache.poi.util.LittleEndian;

public final class AnimationInfoAtom extends RecordAtom {
    public static final int AnimateBg = 16384;
    public static final int Automatic = 4;
    public static final int Hide = 4096;
    public static final int Play = 256;
    public static final int Reverse = 1;
    public static final int Sound = 16;
    public static final int StopSound = 64;
    public static final int Synchronous = 1024;
    public byte[] _header;
    public byte[] _recdata;

    public AnimationInfoAtom() {
        this._recdata = new byte[28];
        byte[] bArr = new byte[8];
        this._header = bArr;
        LittleEndian.putShort(bArr, 0, 1);
        LittleEndian.putShort(this._header, 2, (short) ((int) getRecordType()));
        LittleEndian.putInt(this._header, 4, this._recdata.length);
    }

    public int getDelayTime() {
        return LittleEndian.getInt(this._recdata, 12);
    }

    public int getDimColor() {
        return LittleEndian.getInt(this._recdata, 0);
    }

    public boolean getFlag(int i2) {
        return (i2 & getMask()) != 0;
    }

    public int getMask() {
        return LittleEndian.getInt(this._recdata, 4);
    }

    public int getOrderID() {
        return LittleEndian.getInt(this._recdata, 16);
    }

    @Override // org.apache.poi.hslf.record.Record
    public long getRecordType() {
        return (long) RecordTypes.AnimationInfoAtom.typeID;
    }

    public int getSlideCount() {
        return LittleEndian.getInt(this._recdata, 18);
    }

    public int getSoundIdRef() {
        return LittleEndian.getInt(this._recdata, 8);
    }

    public void setDelayTime(int i2) {
        LittleEndian.putInt(this._recdata, 12, i2);
    }

    public void setDimColor(int i2) {
        LittleEndian.putInt(this._recdata, 0, i2);
    }

    public void setFlag(int i2, boolean z) {
        int mask = getMask();
        setMask(z ? i2 | mask : (~i2) & mask);
    }

    public void setMask(int i2) {
        LittleEndian.putInt(this._recdata, 4, i2);
    }

    public void setOrderID(int i2) {
        LittleEndian.putInt(this._recdata, 16, i2);
    }

    public void setSlideCount(int i2) {
        LittleEndian.putInt(this._recdata, 18, i2);
    }

    public void setSoundIdRef(int i2) {
        LittleEndian.putInt(this._recdata, 8, i2);
    }

    public String toString() {
        StringBuffer a = a.a("AnimationInfoAtom\n");
        StringBuilder b2 = a.b("\tDimColor: ");
        b2.append(getDimColor());
        b2.append("\n");
        a.append(b2.toString());
        int mask = getMask();
        StringBuilder a2 = a.a("\tMask: ", mask, ", 0x");
        a2.append(Integer.toHexString(mask));
        a2.append("\n");
        a.append(a2.toString());
        a.append("\t  Reverse: " + getFlag(1) + "\n");
        a.append("\t  Automatic: " + getFlag(4) + "\n");
        a.append("\t  Sound: " + getFlag(16) + "\n");
        a.append("\t  StopSound: " + getFlag(64) + "\n");
        a.append("\t  Play: " + getFlag(256) + "\n");
        a.append("\t  Synchronous: " + getFlag(1024) + "\n");
        a.append("\t  Hide: " + getFlag(4096) + "\n");
        a.append("\t  AnimateBg: " + getFlag(16384) + "\n");
        a.append("\tSoundIdRef: " + getSoundIdRef() + "\n");
        a.append("\tDelayTime: " + getDelayTime() + "\n");
        a.append("\tOrderID: " + getOrderID() + "\n");
        a.append("\tSlideCount: " + getSlideCount() + "\n");
        return a.toString();
    }

    @Override // org.apache.poi.hslf.record.Record
    public void writeOut(OutputStream outputStream) {
        outputStream.write(this._header);
        outputStream.write(this._recdata);
    }

    public AnimationInfoAtom(byte[] bArr, int i2, int i3) {
        byte[] bArr2 = new byte[8];
        this._header = bArr2;
        System.arraycopy(bArr, i2, bArr2, 0, 8);
        int i4 = i3 - 8;
        byte[] bArr3 = new byte[i4];
        this._recdata = bArr3;
        System.arraycopy(bArr, i2 + 8, bArr3, 0, i4);
    }
}
