package org.apache.poi.hslf.record;

import b.b.a.a.a;
import java.io.ByteArrayOutputStream;
import java.io.IOException;
import java.io.OutputStream;
import org.apache.poi.hslf.exceptions.HSLFException;
import org.apache.poi.util.LittleEndian;

public final class ColorSchemeAtom extends RecordAtom {
    public static long _type = 2032;
    public byte[] _header;
    public int accentAndFollowingHyperlinkColourRGB;
    public int accentAndHyperlinkColourRGB;
    public int accentColourRGB;
    public int backgroundColourRGB;
    public int fillsColourRGB;
    public int shadowsColourRGB;
    public int textAndLinesColourRGB;
    public int titleTextColourRGB;

    public ColorSchemeAtom(byte[] bArr, int i2, int i3) {
        if (i3 >= 40 || bArr.length - i2 >= 40) {
            byte[] bArr2 = new byte[8];
            this._header = bArr2;
            System.arraycopy(bArr, i2, bArr2, 0, 8);
            int i4 = i2 + 8;
            this.backgroundColourRGB = LittleEndian.getInt(bArr, i4 + 0);
            this.textAndLinesColourRGB = LittleEndian.getInt(bArr, i4 + 4);
            this.shadowsColourRGB = LittleEndian.getInt(bArr, i4 + 8);
            this.titleTextColourRGB = LittleEndian.getInt(bArr, i4 + 12);
            this.fillsColourRGB = LittleEndian.getInt(bArr, i4 + 16);
            this.accentColourRGB = LittleEndian.getInt(bArr, i4 + 20);
            this.accentAndHyperlinkColourRGB = LittleEndian.getInt(bArr, i4 + 24);
            this.accentAndFollowingHyperlinkColourRGB = LittleEndian.getInt(bArr, i4 + 28);
            return;
        }
        StringBuilder b2 = a.b("Not enough data to form a ColorSchemeAtom (always 40 bytes long) - found ");
        b2.append(bArr.length - i2);
        throw new HSLFException(b2.toString());
    }

    public static int joinRGB(byte b2, byte b3, byte b4) {
        return joinRGB(new byte[]{b2, b3, b4});
    }

    public static byte[] splitRGB(int i2) {
        byte[] bArr = new byte[3];
        ByteArrayOutputStream byteArrayOutputStream = new ByteArrayOutputStream();
        try {
            Record.writeLittleEndian(i2, byteArrayOutputStream);
            System.arraycopy(byteArrayOutputStream.toByteArray(), 0, bArr, 0, 3);
            return bArr;
        } catch (IOException e2) {
            throw new HSLFException(e2);
        }
    }

    public int getAccentAndFollowingHyperlinkColourRGB() {
        return this.accentAndFollowingHyperlinkColourRGB;
    }

    public int getAccentAndHyperlinkColourRGB() {
        return this.accentAndHyperlinkColourRGB;
    }

    public int getAccentColourRGB() {
        return this.accentColourRGB;
    }

    public int getBackgroundColourRGB() {
        return this.backgroundColourRGB;
    }

    public int getColor(int i2) {
        return new int[]{this.backgroundColourRGB, this.textAndLinesColourRGB, this.shadowsColourRGB, this.titleTextColourRGB, this.fillsColourRGB, this.accentColourRGB, this.accentAndHyperlinkColourRGB, this.accentAndFollowingHyperlinkColourRGB}[i2];
    }

    public int getFillsColourRGB() {
        return this.fillsColourRGB;
    }

    @Override // org.apache.poi.hslf.record.Record
    public long getRecordType() {
        return _type;
    }

    public int getShadowsColourRGB() {
        return this.shadowsColourRGB;
    }

    public int getTextAndLinesColourRGB() {
        return this.textAndLinesColourRGB;
    }

    public int getTitleTextColourRGB() {
        return this.titleTextColourRGB;
    }

    public void setAccentAndFollowingHyperlinkColourRGB(int i2) {
        this.accentAndFollowingHyperlinkColourRGB = i2;
    }

    public void setAccentAndHyperlinkColourRGB(int i2) {
        this.accentAndHyperlinkColourRGB = i2;
    }

    public void setAccentColourRGB(int i2) {
        this.accentColourRGB = i2;
    }

    public void setBackgroundColourRGB(int i2) {
        this.backgroundColourRGB = i2;
    }

    public void setFillsColourRGB(int i2) {
        this.fillsColourRGB = i2;
    }

    public void setShadowsColourRGB(int i2) {
        this.shadowsColourRGB = i2;
    }

    public void setTextAndLinesColourRGB(int i2) {
        this.textAndLinesColourRGB = i2;
    }

    public void setTitleTextColourRGB(int i2) {
        this.titleTextColourRGB = i2;
    }

    @Override // org.apache.poi.hslf.record.Record
    public void writeOut(OutputStream outputStream) {
        outputStream.write(this._header);
        Record.writeLittleEndian(this.backgroundColourRGB, outputStream);
        Record.writeLittleEndian(this.textAndLinesColourRGB, outputStream);
        Record.writeLittleEndian(this.shadowsColourRGB, outputStream);
        Record.writeLittleEndian(this.titleTextColourRGB, outputStream);
        Record.writeLittleEndian(this.fillsColourRGB, outputStream);
        Record.writeLittleEndian(this.accentColourRGB, outputStream);
        Record.writeLittleEndian(this.accentAndHyperlinkColourRGB, outputStream);
        Record.writeLittleEndian(this.accentAndFollowingHyperlinkColourRGB, outputStream);
    }

    public static int joinRGB(byte[] bArr) {
        if (bArr.length == 3) {
            byte[] bArr2 = new byte[4];
            System.arraycopy(bArr, 0, bArr2, 0, 3);
            bArr2[3] = 0;
            return LittleEndian.getInt(bArr2, 0);
        }
        throw new HSLFException(a.a(a.b("joinRGB accepts a byte array of 3 values, but got one of "), bArr.length, " values!"));
    }

    public ColorSchemeAtom() {
        byte[] bArr = new byte[8];
        this._header = bArr;
        LittleEndian.putUShort(bArr, 0, 16);
        LittleEndian.putUShort(this._header, 2, (int) _type);
        LittleEndian.putInt(this._header, 4, 32);
        this.backgroundColourRGB = 16777215;
        this.textAndLinesColourRGB = 0;
        this.shadowsColourRGB = 8421504;
        this.titleTextColourRGB = 0;
        this.fillsColourRGB = 10079232;
        this.accentColourRGB = 13382451;
        this.accentAndHyperlinkColourRGB = 16764108;
        this.accentAndFollowingHyperlinkColourRGB = 11711154;
    }
}
