package org.apache.poi.hslf.record;

import java.io.OutputStream;
import org.apache.poi.util.LittleEndian;

public final class DocumentAtom extends RecordAtom {
    public static long _type = 1001;
    public byte[] _header;
    public int firstSlideNum;
    public long handoutMasterPersist;
    public long notesMasterPersist;
    public long notesSizeX;
    public long notesSizeY;
    public byte omitTitlePlace;
    public byte[] reserved;
    public byte rightToLeft;
    public byte saveWithFonts;
    public long serverZoomFrom;
    public long serverZoomTo;
    public byte showComments;
    public int slideSizeType;
    public long slideSizeX;
    public long slideSizeY;

    public static final class SlideSize {
        public static final int A4_SIZED_PAPER = 2;
        public static final int BANNER = 5;
        public static final int CUSTOM = 6;
        public static final int LETTER_SIZED_PAPER = 1;
        public static final int ON_35MM = 3;
        public static final int ON_SCREEN = 0;
        public static final int OVERHEAD = 4;
    }

    public DocumentAtom(byte[] bArr, int i2, int i3) {
        i3 = i3 < 48 ? 48 : i3;
        byte[] bArr2 = new byte[8];
        this._header = bArr2;
        System.arraycopy(bArr, i2, bArr2, 0, 8);
        this.slideSizeX = (long) LittleEndian.getInt(bArr, i2 + 0 + 8);
        this.slideSizeY = (long) LittleEndian.getInt(bArr, i2 + 4 + 8);
        this.notesSizeX = (long) LittleEndian.getInt(bArr, i2 + 8 + 8);
        this.notesSizeY = (long) LittleEndian.getInt(bArr, i2 + 12 + 8);
        this.serverZoomFrom = (long) LittleEndian.getInt(bArr, i2 + 16 + 8);
        this.serverZoomTo = (long) LittleEndian.getInt(bArr, i2 + 20 + 8);
        this.notesMasterPersist = (long) LittleEndian.getInt(bArr, i2 + 24 + 8);
        this.handoutMasterPersist = (long) LittleEndian.getInt(bArr, i2 + 28 + 8);
        this.firstSlideNum = LittleEndian.getShort(bArr, i2 + 32 + 8);
        this.slideSizeType = LittleEndian.getShort(bArr, i2 + 34 + 8);
        this.saveWithFonts = bArr[i2 + 36 + 8];
        this.omitTitlePlace = bArr[i2 + 37 + 8];
        this.rightToLeft = bArr[i2 + 38 + 8];
        this.showComments = bArr[i2 + 39 + 8];
        byte[] bArr3 = new byte[((i3 - 40) - 8)];
        this.reserved = bArr3;
        System.arraycopy(bArr, i2 + 48, bArr3, 0, bArr3.length);
    }

    public int getFirstSlideNum() {
        return this.firstSlideNum;
    }

    public long getHandoutMasterPersist() {
        return this.handoutMasterPersist;
    }

    public long getNotesMasterPersist() {
        return this.notesMasterPersist;
    }

    public long getNotesSizeX() {
        return this.notesSizeX;
    }

    public long getNotesSizeY() {
        return this.notesSizeY;
    }

    public boolean getOmitTitlePlace() {
        return this.omitTitlePlace != 0;
    }

    @Override // org.apache.poi.hslf.record.Record
    public long getRecordType() {
        return _type;
    }

    public boolean getRightToLeft() {
        return this.rightToLeft != 0;
    }

    public boolean getSaveWithFonts() {
        return this.saveWithFonts != 0;
    }

    public long getServerZoomFrom() {
        return this.serverZoomFrom;
    }

    public long getServerZoomTo() {
        return this.serverZoomTo;
    }

    public boolean getShowComments() {
        return this.showComments != 0;
    }

    public int getSlideSizeType() {
        return this.slideSizeType;
    }

    public long getSlideSizeX() {
        return this.slideSizeX;
    }

    public long getSlideSizeY() {
        return this.slideSizeY;
    }

    public void setNotesSizeX(long j) {
        this.notesSizeX = j;
    }

    public void setNotesSizeY(long j) {
        this.notesSizeY = j;
    }

    public void setServerZoomFrom(long j) {
        this.serverZoomFrom = j;
    }

    public void setServerZoomTo(long j) {
        this.serverZoomTo = j;
    }

    public void setSlideSizeX(long j) {
        this.slideSizeX = j;
    }

    public void setSlideSizeY(long j) {
        this.slideSizeY = j;
    }

    @Override // org.apache.poi.hslf.record.Record
    public void writeOut(OutputStream outputStream) {
        outputStream.write(this._header);
        Record.writeLittleEndian((int) this.slideSizeX, outputStream);
        Record.writeLittleEndian((int) this.slideSizeY, outputStream);
        Record.writeLittleEndian((int) this.notesSizeX, outputStream);
        Record.writeLittleEndian((int) this.notesSizeY, outputStream);
        Record.writeLittleEndian((int) this.serverZoomFrom, outputStream);
        Record.writeLittleEndian((int) this.serverZoomTo, outputStream);
        Record.writeLittleEndian((int) this.notesMasterPersist, outputStream);
        Record.writeLittleEndian((int) this.handoutMasterPersist, outputStream);
        Record.writeLittleEndian((short) this.firstSlideNum, outputStream);
        Record.writeLittleEndian((short) this.slideSizeType, outputStream);
        outputStream.write(this.saveWithFonts);
        outputStream.write(this.omitTitlePlace);
        outputStream.write(this.rightToLeft);
        outputStream.write(this.showComments);
        outputStream.write(this.reserved);
    }
}
