package org.apache.poi.hslf.record;

import java.io.ByteArrayInputStream;
import java.io.OutputStream;
import java.util.Map;
import org.apache.poi.poifs.crypt.CipherAlgorithm;
import org.apache.poi.poifs.crypt.EncryptionInfo;
import org.apache.poi.poifs.crypt.EncryptionMode;
import org.apache.poi.poifs.crypt.HashAlgorithm;
import org.apache.poi.poifs.crypt.cryptoapi.CryptoAPIEncryptionHeader;
import org.apache.poi.poifs.crypt.cryptoapi.CryptoAPIEncryptionVerifier;
import org.apache.poi.util.LittleEndian;
import org.apache.poi.util.LittleEndianByteArrayOutputStream;
import org.apache.poi.util.LittleEndianInputStream;

public final class DocumentEncryptionAtom extends PositionDependentRecordAtom {
    public static final long _type = 12052;
    public final byte[] _header;
    public EncryptionInfo ei;

    public DocumentEncryptionAtom(byte[] bArr, int i2, int i3) {
        byte[] bArr2 = new byte[8];
        this._header = bArr2;
        System.arraycopy(bArr, i2, bArr2, 0, 8);
        LittleEndianInputStream littleEndianInputStream = new LittleEndianInputStream(new ByteArrayInputStream(bArr, i2 + 8, i3 - 8));
        this.ei = new EncryptionInfo(littleEndianInputStream, EncryptionMode.cryptoAPI);
        littleEndianInputStream.close();
    }

    public EncryptionInfo getEncryptionInfo() {
        return this.ei;
    }

    public String getEncryptionProviderName() {
        return this.ei.getHeader().getCspName();
    }

    public int getKeyLength() {
        return this.ei.getHeader().getKeySize();
    }

    @Override // org.apache.poi.hslf.record.Record
    public long getRecordType() {
        return _type;
    }

    public void initializeEncryptionInfo(int i2) {
        this.ei = new EncryptionInfo(EncryptionMode.cryptoAPI, CipherAlgorithm.rc4, HashAlgorithm.sha1, i2, -1, null);
    }

    @Override // org.apache.poi.hslf.record.PositionDependentRecordAtom, org.apache.poi.hslf.record.PositionDependentRecord
    public void updateOtherRecordReferences(Map<Integer, Integer> map) {
    }

    @Override // org.apache.poi.hslf.record.Record
    public void writeOut(OutputStream outputStream) {
        byte[] bArr = new byte[1024];
        LittleEndianByteArrayOutputStream littleEndianByteArrayOutputStream = new LittleEndianByteArrayOutputStream(bArr, 0);
        littleEndianByteArrayOutputStream.writeShort(this.ei.getVersionMajor());
        littleEndianByteArrayOutputStream.writeShort(this.ei.getVersionMinor());
        littleEndianByteArrayOutputStream.writeInt(this.ei.getEncryptionFlags());
        ((CryptoAPIEncryptionHeader) this.ei.getHeader()).write(littleEndianByteArrayOutputStream);
        ((CryptoAPIEncryptionVerifier) this.ei.getVerifier()).write(littleEndianByteArrayOutputStream);
        LittleEndian.putInt(this._header, 4, littleEndianByteArrayOutputStream.getWriteIndex());
        outputStream.write(this._header);
        outputStream.write(bArr, 0, littleEndianByteArrayOutputStream.getWriteIndex());
        littleEndianByteArrayOutputStream.close();
    }

    public DocumentEncryptionAtom() {
        byte[] bArr = new byte[8];
        this._header = bArr;
        LittleEndian.putShort(bArr, 0, 15);
        LittleEndian.putShort(this._header, 2, 12052);
        this.ei = new EncryptionInfo(EncryptionMode.cryptoAPI);
    }
}
