package org.apache.poi.hslf.record;

import org.apache.poi.ddf.EscherRecord;
import org.apache.poi.ddf.EscherRecordFactory;
import org.apache.poi.ddf.EscherSerializationListener;
import org.apache.poi.util.LittleEndian;

public class EscherPlaceholder extends EscherRecord {
    public static final /* synthetic */ boolean $assertionsDisabled = false;
    public static final String RECORD_DESCRIPTION = "msofbtClientTextboxPlaceholder";
    public static final short RECORD_ID = RecordTypes.OEPlaceholderAtom.typeID;
    public byte placementId = 0;
    public int position = -1;
    public byte size = 0;
    public short unused = 0;

    @Override // org.apache.poi.ddf.EscherRecord
    public int fillFields(byte[] bArr, int i2, EscherRecordFactory escherRecordFactory) {
        int readHeader = readHeader(bArr, i2);
        this.position = LittleEndian.getInt(bArr, i2 + 8);
        this.placementId = bArr[i2 + 12];
        this.size = bArr[i2 + 13];
        this.unused = LittleEndian.getShort(bArr, i2 + 14);
        return readHeader + 8;
    }

    @Override // org.apache.poi.ddf.EscherRecord
    public Object[][] getAttributeMap() {
        return new Object[][]{new Object[]{"position", Integer.valueOf(this.position)}, new Object[]{"placementId", Byte.valueOf(this.placementId)}, new Object[]{"placehoder size", Byte.valueOf(this.size)}, new Object[]{"unused", Short.valueOf(this.unused)}};
    }

    @Override // org.apache.poi.ddf.EscherRecord
    public String getRecordName() {
        return "ClientTextboxPlaceholder";
    }

    @Override // org.apache.poi.ddf.EscherRecord
    public int getRecordSize() {
        return 16;
    }

    @Override // org.apache.poi.ddf.EscherRecord
    public int serialize(int i2, byte[] bArr, EscherSerializationListener escherSerializationListener) {
        escherSerializationListener.beforeRecordSerialize(i2, getRecordId(), this);
        LittleEndian.putShort(bArr, i2, getOptions());
        LittleEndian.putShort(bArr, i2 + 2, getRecordId());
        LittleEndian.putInt(bArr, i2 + 4, 8);
        LittleEndian.putInt(bArr, i2 + 8, this.position);
        LittleEndian.putByte(bArr, i2 + 12, this.placementId);
        LittleEndian.putByte(bArr, i2 + 13, this.size);
        LittleEndian.putShort(bArr, i2 + 14, this.unused);
        escherSerializationListener.afterRecordSerialize(getRecordSize() + i2, getRecordId(), getRecordSize(), this);
        return getRecordSize();
    }
}
