package org.apache.poi.hslf.record;

import b.b.a.a.a;
import java.io.OutputStream;
import org.apache.poi.util.LittleEndian;
import org.apache.poi.util.POILogger;

public class ExEmbed extends RecordContainer {
    public byte[] _header;
    public CString clipboardName;
    public RecordAtom embedAtom;
    public CString menuName;
    public ExOleObjAtom oleObjAtom;
    public CString progId;

    public ExEmbed(byte[] bArr, int i2, int i3) {
        byte[] bArr2 = new byte[8];
        this._header = bArr2;
        System.arraycopy(bArr, i2, bArr2, 0, 8);
        this._children = Record.findChildRecords(bArr, i2 + 8, i3 - 8);
        findInterestingChildren();
    }

    private void findInterestingChildren() {
        Record[] recordArr = this._children;
        if (recordArr[0] instanceof ExEmbedAtom) {
            this.embedAtom = (ExEmbedAtom) recordArr[0];
        } else {
            POILogger pOILogger = Record.logger;
            StringBuilder b2 = a.b("First child record wasn't a ExEmbedAtom, was of type ");
            b2.append(this._children[0].getRecordType());
            pOILogger.log(7, b2.toString());
        }
        Record[] recordArr2 = this._children;
        if (recordArr2[1] instanceof ExOleObjAtom) {
            this.oleObjAtom = (ExOleObjAtom) recordArr2[1];
        } else {
            POILogger pOILogger2 = Record.logger;
            StringBuilder b3 = a.b("Second child record wasn't a ExOleObjAtom, was of type ");
            b3.append(this._children[1].getRecordType());
            pOILogger2.log(7, b3.toString());
        }
        int i2 = 2;
        while (true) {
            Record[] recordArr3 = this._children;
            if (i2 < recordArr3.length) {
                if (recordArr3[i2] instanceof CString) {
                    CString cString = (CString) recordArr3[i2];
                    int options = cString.getOptions() >> 4;
                    if (options == 1) {
                        this.menuName = cString;
                    } else if (options == 2) {
                        this.progId = cString;
                    } else if (options == 3) {
                        this.clipboardName = cString;
                    }
                }
                i2++;
            } else {
                return;
            }
        }
    }

    public String getClipboardName() {
        CString cString = this.clipboardName;
        if (cString == null) {
            return null;
        }
        return cString.getText();
    }

    public ExEmbedAtom getExEmbedAtom() {
        return (ExEmbedAtom) this.embedAtom;
    }

    public ExOleObjAtom getExOleObjAtom() {
        return this.oleObjAtom;
    }

    public String getMenuName() {
        CString cString = this.menuName;
        if (cString == null) {
            return null;
        }
        return cString.getText();
    }

    public String getProgId() {
        CString cString = this.progId;
        if (cString == null) {
            return null;
        }
        return cString.getText();
    }

    @Override // org.apache.poi.hslf.record.Record
    public long getRecordType() {
        return (long) RecordTypes.ExEmbed.typeID;
    }

    public void setClipboardName(String str) {
        CString cString = this.clipboardName;
        if (cString != null) {
            cString.setText(str);
        }
    }

    public void setMenuName(String str) {
        CString cString = this.menuName;
        if (cString != null) {
            cString.setText(str);
        }
    }

    public void setProgId(String str) {
        CString cString = this.progId;
        if (cString != null) {
            cString.setText(str);
        }
    }

    @Override // org.apache.poi.hslf.record.Record
    public void writeOut(OutputStream outputStream) {
        byte[] bArr = this._header;
        writeOut(bArr[0], bArr[1], getRecordType(), this._children, outputStream);
    }

    public ExEmbed(RecordAtom recordAtom) {
        this();
        Record[] recordArr = this._children;
        this.embedAtom = recordAtom;
        recordArr[0] = recordAtom;
    }

    public ExEmbed() {
        byte[] bArr = new byte[8];
        this._header = bArr;
        this._children = new Record[5];
        bArr[0] = 15;
        LittleEndian.putShort(bArr, 2, (short) ((int) getRecordType()));
        CString cString = new CString();
        cString.setOptions(16);
        CString cString2 = new CString();
        cString2.setOptions(32);
        CString cString3 = new CString();
        cString3.setOptions(48);
        this._children[0] = new ExEmbedAtom();
        this._children[1] = new ExOleObjAtom();
        Record[] recordArr = this._children;
        recordArr[2] = cString;
        recordArr[3] = cString2;
        recordArr[4] = cString3;
        findInterestingChildren();
    }
}
