package org.apache.poi.hslf.record;

import b.b.a.a.a;
import java.io.OutputStream;
import org.apache.poi.util.LittleEndian;
import org.apache.poi.util.POILogger;

public class ExHyperlink extends RecordContainer {
    public static long _type = 4055;
    public byte[] _header;
    public ExHyperlinkAtom linkAtom;
    public CString linkDetailsA;
    public CString linkDetailsB;

    public ExHyperlink(byte[] bArr, int i2, int i3) {
        byte[] bArr2 = new byte[8];
        this._header = bArr2;
        System.arraycopy(bArr, i2, bArr2, 0, 8);
        this._children = Record.findChildRecords(bArr, i2 + 8, i3 - 8);
        findInterestingChildren();
    }

    private void findInterestingChildren() {
        Record[] recordArr = this._children;
        if (recordArr[0] instanceof ExHyperlinkAtom) {
            this.linkAtom = (ExHyperlinkAtom) recordArr[0];
        } else {
            POILogger pOILogger = Record.logger;
            StringBuilder b2 = a.b("First child record wasn't a ExHyperlinkAtom, was of type ");
            b2.append(this._children[0].getRecordType());
            pOILogger.log(7, b2.toString());
        }
        int i2 = 1;
        while (true) {
            Record[] recordArr2 = this._children;
            if (i2 < recordArr2.length) {
                if (!(recordArr2[i2] instanceof CString)) {
                    POILogger pOILogger2 = Record.logger;
                    StringBuilder b3 = a.b("Record after ExHyperlinkAtom wasn't a CString, was of type ");
                    b3.append(this._children[1].getRecordType());
                    pOILogger2.log(7, b3.toString());
                } else if (this.linkDetailsA == null) {
                    this.linkDetailsA = (CString) recordArr2[i2];
                } else {
                    this.linkDetailsB = (CString) recordArr2[i2];
                }
                i2++;
            } else {
                return;
            }
        }
    }

    public String _getDetailsA() {
        CString cString = this.linkDetailsA;
        if (cString == null) {
            return null;
        }
        return cString.getText();
    }

    public String _getDetailsB() {
        CString cString = this.linkDetailsB;
        if (cString == null) {
            return null;
        }
        return cString.getText();
    }

    public ExHyperlinkAtom getExHyperlinkAtom() {
        return this.linkAtom;
    }

    public String getLinkTitle() {
        CString cString = this.linkDetailsA;
        if (cString == null) {
            return null;
        }
        return cString.getText();
    }

    public String getLinkURL() {
        CString cString = this.linkDetailsB;
        if (cString == null) {
            return null;
        }
        return cString.getText();
    }

    @Override // org.apache.poi.hslf.record.Record
    public long getRecordType() {
        return _type;
    }

    public void setLinkOptions(int i2) {
        CString cString = this.linkDetailsB;
        if (cString != null) {
            cString.setOptions(i2);
        }
    }

    public void setLinkTitle(String str) {
        CString cString = this.linkDetailsA;
        if (cString != null) {
            cString.setText(str);
        }
    }

    public void setLinkURL(String str) {
        CString cString = this.linkDetailsB;
        if (cString != null) {
            cString.setText(str);
        }
    }

    @Override // org.apache.poi.hslf.record.Record
    public void writeOut(OutputStream outputStream) {
        byte[] bArr = this._header;
        writeOut(bArr[0], bArr[1], _type, this._children, outputStream);
    }

    public ExHyperlink() {
        byte[] bArr = new byte[8];
        this._header = bArr;
        this._children = new Record[3];
        bArr[0] = 15;
        LittleEndian.putShort(bArr, 2, (short) ((int) _type));
        CString cString = new CString();
        CString cString2 = new CString();
        cString.setOptions(0);
        cString2.setOptions(16);
        this._children[0] = new ExHyperlinkAtom();
        Record[] recordArr = this._children;
        recordArr[1] = cString;
        recordArr[2] = cString2;
        findInterestingChildren();
    }
}
