package org.apache.poi.hslf.record;

import b.b.a.a.a;
import java.io.OutputStream;
import org.apache.poi.util.LittleEndian;

public class ExOleObjAtom extends RecordAtom {
    public static final int DRAW_ASPECT_DOCPRINT = 8;
    public static final int DRAW_ASPECT_ICON = 4;
    public static final int DRAW_ASPECT_THUMBNAIL = 2;
    public static final int DRAW_ASPECT_VISIBLE = 1;
    public static final int SUBTYPE_CLIPART_GALLERY = 1;
    public static final int SUBTYPE_DEFAULT = 0;
    public static final int SUBTYPE_EQUATION = 6;
    public static final int SUBTYPE_EXCEL = 3;
    public static final int SUBTYPE_EXCEL_CHART = 14;
    public static final int SUBTYPE_GRAPH = 4;
    public static final int SUBTYPE_IMAGE = 9;
    public static final int SUBTYPE_MEDIA_PLAYER = 15;
    public static final int SUBTYPE_NOTEIT = 13;
    public static final int SUBTYPE_ORGANIZATION_CHART = 5;
    public static final int SUBTYPE_POWERPOINT_PRESENTATION = 10;
    public static final int SUBTYPE_POWERPOINT_SLIDE = 11;
    public static final int SUBTYPE_PROJECT = 12;
    public static final int SUBTYPE_SOUND = 8;
    public static final int SUBTYPE_WORDART = 7;
    public static final int SUBTYPE_WORD_TABLE = 2;
    public static final int TYPE_CONTROL = 2;
    public static final int TYPE_EMBEDDED = 0;
    public static final int TYPE_LINKED = 1;
    public byte[] _data;
    public byte[] _header;

    public ExOleObjAtom() {
        byte[] bArr = new byte[8];
        this._header = bArr;
        this._data = new byte[24];
        LittleEndian.putShort(bArr, 0, 1);
        LittleEndian.putShort(this._header, 2, (short) ((int) getRecordType()));
        LittleEndian.putInt(this._header, 4, this._data.length);
    }

    public int getDrawAspect() {
        return LittleEndian.getInt(this._data, 0);
    }

    public boolean getIsBlank() {
        return LittleEndian.getInt(this._data, 20) != 0;
    }

    public int getObjID() {
        return LittleEndian.getInt(this._data, 8);
    }

    public int getObjStgDataRef() {
        return LittleEndian.getInt(this._data, 16);
    }

    public int getOptions() {
        return LittleEndian.getInt(this._data, 20);
    }

    @Override // org.apache.poi.hslf.record.Record
    public long getRecordType() {
        return (long) RecordTypes.ExOleObjAtom.typeID;
    }

    public int getSubType() {
        return LittleEndian.getInt(this._data, 12);
    }

    public int getType() {
        return LittleEndian.getInt(this._data, 4);
    }

    public void setDrawAspect(int i2) {
        LittleEndian.putInt(this._data, 0, i2);
    }

    public void setObjID(int i2) {
        LittleEndian.putInt(this._data, 8, i2);
    }

    public void setObjStgDataRef(int i2) {
        LittleEndian.putInt(this._data, 16, i2);
    }

    public void setOptions(int i2) {
        LittleEndian.putInt(this._data, 20, i2);
    }

    public void setSubType(int i2) {
        LittleEndian.putInt(this._data, 12, i2);
    }

    public void setType(int i2) {
        LittleEndian.putInt(this._data, 4, i2);
    }

    public String toString() {
        StringBuffer a = a.a("ExOleObjAtom\n");
        StringBuilder b2 = a.b("  drawAspect: ");
        b2.append(getDrawAspect());
        b2.append("\n");
        a.append(b2.toString());
        a.append("  type: " + getType() + "\n");
        a.append("  objID: " + getObjID() + "\n");
        a.append("  subType: " + getSubType() + "\n");
        a.append("  objStgDataRef: " + getObjStgDataRef() + "\n");
        a.append("  options: " + getOptions() + "\n");
        return a.toString();
    }

    @Override // org.apache.poi.hslf.record.Record
    public void writeOut(OutputStream outputStream) {
        outputStream.write(this._header);
        outputStream.write(this._data);
    }

    public ExOleObjAtom(byte[] bArr, int i2, int i3) {
        byte[] bArr2 = new byte[8];
        this._header = bArr2;
        System.arraycopy(bArr, i2, bArr2, 0, 8);
        int i4 = i3 - 8;
        byte[] bArr3 = new byte[i4];
        this._data = bArr3;
        System.arraycopy(bArr, i2 + 8, bArr3, 0, i4);
        if (this._data.length < 24) {
            StringBuilder b2 = a.b("The length of the data for a ExOleObjAtom must be at least 24 bytes, but was only ");
            b2.append(this._data.length);
            throw new IllegalArgumentException(b2.toString());
        }
    }
}
