package org.apache.poi.hslf.record;

import java.io.ByteArrayInputStream;
import java.io.ByteArrayOutputStream;
import java.io.InputStream;
import java.io.OutputStream;
import java.util.Map;
import java.util.zip.DeflaterOutputStream;
import java.util.zip.InflaterInputStream;
import org.apache.poi.util.BoundedInputStream;
import org.apache.poi.util.LittleEndian;

public class ExOleObjStg extends PositionDependentRecordAtom implements PersistRecord {
    public byte[] _data;
    public final byte[] _header;
    public int _persistId;

    public ExOleObjStg() {
        byte[] bArr = new byte[8];
        this._header = bArr;
        this._data = new byte[0];
        LittleEndian.putShort(bArr, 0, 16);
        LittleEndian.putShort(this._header, 2, (short) ((int) getRecordType()));
        LittleEndian.putInt(this._header, 4, this._data.length);
    }

    public InputStream getData() {
        if (isCompressed()) {
            int i2 = LittleEndian.getInt(this._data);
            byte[] bArr = this._data;
            return new BoundedInputStream(new InflaterInputStream(new ByteArrayInputStream(bArr, 4, bArr.length)), (long) i2);
        }
        byte[] bArr2 = this._data;
        return new ByteArrayInputStream(bArr2, 0, bArr2.length);
    }

    public int getDataLength() {
        if (isCompressed()) {
            return LittleEndian.getInt(this._data, 0);
        }
        return this._data.length;
    }

    @Override // org.apache.poi.hslf.record.PersistRecord
    public int getPersistId() {
        return this._persistId;
    }

    public byte[] getRawData() {
        return this._data;
    }

    public int getRecordInstance() {
        return LittleEndian.getUShort(this._header, 0) >>> 4;
    }

    @Override // org.apache.poi.hslf.record.Record
    public long getRecordType() {
        return (long) RecordTypes.ExOleObjStg.typeID;
    }

    public boolean isCompressed() {
        return LittleEndian.getShort(this._header, 0) != 0;
    }

    public void setData(byte[] bArr) {
        ByteArrayOutputStream byteArrayOutputStream = new ByteArrayOutputStream();
        byte[] bArr2 = new byte[4];
        LittleEndian.putInt(bArr2, 0, bArr.length);
        byteArrayOutputStream.write(bArr2);
        DeflaterOutputStream deflaterOutputStream = new DeflaterOutputStream(byteArrayOutputStream);
        deflaterOutputStream.write(bArr, 0, bArr.length);
        deflaterOutputStream.finish();
        byte[] byteArray = byteArrayOutputStream.toByteArray();
        this._data = byteArray;
        LittleEndian.putInt(this._header, 4, byteArray.length);
    }

    @Override // org.apache.poi.hslf.record.PersistRecord
    public void setPersistId(int i2) {
        this._persistId = i2;
    }

    @Override // org.apache.poi.hslf.record.PositionDependentRecordAtom, org.apache.poi.hslf.record.PositionDependentRecord
    public void updateOtherRecordReferences(Map<Integer, Integer> map) {
    }

    @Override // org.apache.poi.hslf.record.Record
    public void writeOut(OutputStream outputStream) {
        outputStream.write(this._header);
        outputStream.write(this._data);
    }

    public ExOleObjStg(byte[] bArr, int i2, int i3) {
        byte[] bArr2 = new byte[8];
        this._header = bArr2;
        System.arraycopy(bArr, i2, bArr2, 0, 8);
        int i4 = i3 - 8;
        byte[] bArr3 = new byte[i4];
        this._data = bArr3;
        System.arraycopy(bArr, i2 + 8, bArr3, 0, i4);
    }
}
