package org.apache.poi.hslf.record;

import b.b.a.a.a;
import java.io.OutputStream;
import java.util.LinkedHashMap;
import java.util.Map;
import org.apache.poi.common.usermodel.fonts.FontInfo;
import org.apache.poi.hslf.usermodel.HSLFFontInfo;
import org.apache.poi.util.POILogger;

public final class FontCollection extends RecordContainer {
    public byte[] _header;
    public final Map<String, HSLFFontInfo> fonts = new LinkedHashMap();

    public FontCollection(byte[] bArr, int i2, int i3) {
        byte[] bArr2 = new byte[8];
        this._header = bArr2;
        System.arraycopy(bArr, i2, bArr2, 0, 8);
        Record[] findChildRecords = Record.findChildRecords(bArr, i2 + 8, i3 - 8);
        this._children = findChildRecords;
        for (Record record : findChildRecords) {
            if (record instanceof FontEntityAtom) {
                HSLFFontInfo hSLFFontInfo = new HSLFFontInfo((FontEntityAtom) record);
                this.fonts.put(hSLFFontInfo.getTypeface(), hSLFFontInfo);
            } else {
                POILogger pOILogger = Record.logger;
                StringBuilder b2 = a.b("Warning: FontCollection child wasn't a FontEntityAtom, was ");
                b2.append(record.getClass().getSimpleName());
                pOILogger.log(5, b2.toString());
            }
        }
    }

    public HSLFFontInfo addFont(FontInfo fontInfo) {
        HSLFFontInfo fontInfo2 = getFontInfo(fontInfo.getTypeface());
        if (fontInfo2 != null) {
            return fontInfo2;
        }
        HSLFFontInfo hSLFFontInfo = new HSLFFontInfo(fontInfo);
        hSLFFontInfo.setIndex(this.fonts.size());
        this.fonts.put(hSLFFontInfo.getTypeface(), hSLFFontInfo);
        appendChildRecord(hSLFFontInfo.createRecord());
        return hSLFFontInfo;
    }

    public HSLFFontInfo getFontInfo(String str) {
        return this.fonts.get(str);
    }

    public int getNumberOfFonts() {
        return this.fonts.size();
    }

    @Override // org.apache.poi.hslf.record.Record
    public long getRecordType() {
        return (long) RecordTypes.FontCollection.typeID;
    }

    @Override // org.apache.poi.hslf.record.Record
    public void writeOut(OutputStream outputStream) {
        byte[] bArr = this._header;
        writeOut(bArr[0], bArr[1], getRecordType(), this._children, outputStream);
    }

    public HSLFFontInfo getFontInfo(int i2) {
        for (HSLFFontInfo hSLFFontInfo : this.fonts.values()) {
            if (hSLFFontInfo.getIndex().intValue() == i2) {
                return hSLFFontInfo;
            }
        }
        return null;
    }
}
