package org.apache.poi.hslf.record;

import java.io.OutputStream;
import java.util.Arrays;
import org.apache.poi.hslf.exceptions.HSLFException;
import org.apache.poi.util.LittleEndian;
import org.apache.poi.util.StringUtil;

public final class FontEntityAtom extends RecordAtom {
    public byte[] _header;
    public byte[] _recdata;

    public FontEntityAtom(byte[] bArr, int i2, int i3) {
        byte[] bArr2 = new byte[8];
        this._header = bArr2;
        System.arraycopy(bArr, i2, bArr2, 0, 8);
        int i4 = i3 - 8;
        byte[] bArr3 = new byte[i4];
        this._recdata = bArr3;
        System.arraycopy(bArr, i2 + 8, bArr3, 0, i4);
    }

    public int getCharSet() {
        return this._recdata[64];
    }

    public int getFontFlags() {
        return this._recdata[65];
    }

    public int getFontIndex() {
        return LittleEndian.getShort(this._header, 0) >> 4;
    }

    public String getFontName() {
        int min = Math.min(this._recdata.length, 64);
        for (int i2 = 0; i2 < min; i2 += 2) {
            byte[] bArr = this._recdata;
            if (bArr[i2] == 0 && bArr[i2 + 1] == 0) {
                return StringUtil.getFromUnicodeLE(bArr, 0, i2 / 2);
            }
        }
        return null;
    }

    public int getFontType() {
        return this._recdata[66];
    }

    public int getPitchAndFamily() {
        return this._recdata[67];
    }

    @Override // org.apache.poi.hslf.record.Record
    public long getRecordType() {
        return (long) RecordTypes.FontEntityAtom.typeID;
    }

    public void setCharSet(int i2) {
        this._recdata[64] = (byte) i2;
    }

    public void setFontFlags(int i2) {
        this._recdata[65] = (byte) i2;
    }

    public void setFontIndex(int i2) {
        LittleEndian.putShort(this._header, 0, (short) i2);
    }

    public void setFontName(String str) {
        if (str.length() + (!str.endsWith("\u0000")) <= 32) {
            byte[] toUnicodeLE = StringUtil.getToUnicodeLE(str);
            System.arraycopy(toUnicodeLE, 0, this._recdata, 0, toUnicodeLE.length);
            Arrays.fill(this._recdata, 64 - toUnicodeLE.length, 64, (byte) 0);
            return;
        }
        throw new HSLFException("The length of the font name, including null termination, must not exceed 32 characters");
    }

    public void setFontType(int i2) {
        this._recdata[66] = (byte) i2;
    }

    public void setPitchAndFamily(int i2) {
        this._recdata[67] = (byte) i2;
    }

    @Override // org.apache.poi.hslf.record.Record
    public void writeOut(OutputStream outputStream) {
        outputStream.write(this._header);
        outputStream.write(this._recdata);
    }

    public FontEntityAtom() {
        this._recdata = new byte[68];
        byte[] bArr = new byte[8];
        this._header = bArr;
        LittleEndian.putShort(bArr, 2, (short) ((int) getRecordType()));
        LittleEndian.putInt(this._header, 4, this._recdata.length);
    }
}
