package org.apache.poi.hslf.record;

import java.io.ByteArrayOutputStream;
import java.io.IOException;
import java.util.ArrayList;
import java.util.Iterator;
import java.util.List;
import org.apache.poi.ddf.EscherClientDataRecord;
import org.apache.poi.ddf.EscherRecordFactory;
import org.apache.poi.ddf.EscherSerializationListener;
import org.apache.poi.hslf.exceptions.HSLFException;
import org.apache.poi.util.LittleEndian;

public class HSLFEscherClientDataRecord extends EscherClientDataRecord {
    public final List<Record> _childRecords = new ArrayList();

    public void addChild(Record record) {
        this._childRecords.add(record);
    }

    @Override // org.apache.poi.ddf.EscherClientDataRecord, org.apache.poi.ddf.EscherRecord
    public int fillFields(byte[] bArr, int i2, EscherRecordFactory escherRecordFactory) {
        int readHeader = readHeader(bArr, i2);
        byte[] bArr2 = new byte[readHeader];
        System.arraycopy(bArr, i2 + 8, bArr2, 0, readHeader);
        setRemainingData(bArr2);
        return readHeader + 8;
    }

    public List<? extends Record> getHSLFChildRecords() {
        return this._childRecords;
    }

    @Override // org.apache.poi.ddf.EscherClientDataRecord, org.apache.poi.ddf.EscherRecord
    public String getRecordName() {
        return "HSLFClientData";
    }

    @Override // org.apache.poi.ddf.EscherClientDataRecord, org.apache.poi.ddf.EscherRecord
    public int getRecordSize() {
        return getRemainingData().length + 8;
    }

    @Override // org.apache.poi.ddf.EscherClientDataRecord
    public byte[] getRemainingData() {
        ByteArrayOutputStream byteArrayOutputStream = new ByteArrayOutputStream();
        try {
            for (Record record : this._childRecords) {
                record.writeOut(byteArrayOutputStream);
            }
            return byteArrayOutputStream.toByteArray();
        } catch (IOException e2) {
            throw new HSLFException(e2);
        }
    }

    public void removeChild(Class<? extends Record> cls) {
        Iterator<Record> it = this._childRecords.iterator();
        while (it.hasNext()) {
            if (cls.isInstance(it.next())) {
                it.remove();
            }
        }
    }

    @Override // org.apache.poi.ddf.EscherClientDataRecord, org.apache.poi.ddf.EscherRecord
    public int serialize(int i2, byte[] bArr, EscherSerializationListener escherSerializationListener) {
        escherSerializationListener.beforeRecordSerialize(i2, getRecordId(), this);
        LittleEndian.putShort(bArr, i2, getOptions());
        LittleEndian.putShort(bArr, i2 + 2, getRecordId());
        byte[] remainingData = getRemainingData();
        LittleEndian.putInt(bArr, i2 + 4, remainingData.length);
        System.arraycopy(remainingData, 0, bArr, i2 + 8, remainingData.length);
        int length = remainingData.length + 8;
        escherSerializationListener.afterRecordSerialize(i2 + length, getRecordId(), length, this);
        return length;
    }

    @Override // org.apache.poi.ddf.EscherClientDataRecord
    public void setRemainingData(byte[] bArr) {
        this._childRecords.clear();
        int i2 = 0;
        while (i2 < bArr.length) {
            this._childRecords.add(Record.buildRecordAtOffset(bArr, i2));
            i2 = (int) (LittleEndian.getUInt(bArr, i2 + 4) + 8 + ((long) i2));
        }
    }
}
