package org.apache.poi.hslf.record;

import java.lang.reflect.Constructor;
import java.util.Map;
import org.apache.poi.ddf.DefaultEscherRecordFactory;
import org.apache.poi.ddf.EscherContainerRecord;
import org.apache.poi.ddf.EscherRecord;
import org.apache.poi.util.LittleEndian;

public class HSLFEscherRecordFactory extends DefaultEscherRecordFactory {
    public static Class<?>[] escherRecordClasses;
    public static Map<Short, Constructor<? extends EscherRecord>> recordsMap;

    static {
        Class<?>[] clsArr = {EscherPlaceholder.class, HSLFEscherClientDataRecord.class};
        escherRecordClasses = clsArr;
        recordsMap = DefaultEscherRecordFactory.recordsToMap(clsArr);
    }

    @Override // org.apache.poi.ddf.EscherRecordFactory, org.apache.poi.ddf.DefaultEscherRecordFactory
    public EscherRecord createRecord(byte[] bArr, int i2) {
        short s = LittleEndian.getShort(bArr, i2);
        short s2 = LittleEndian.getShort(bArr, i2 + 2);
        Constructor<? extends EscherRecord> constructor = recordsMap.get(Short.valueOf(s2));
        if (constructor == null) {
            return super.createRecord(bArr, i2);
        }
        try {
            EscherRecord escherRecord = (EscherRecord) constructor.newInstance(new Object[0]);
            escherRecord.setRecordId(s2);
            escherRecord.setOptions(s);
            if (escherRecord instanceof EscherContainerRecord) {
                ((EscherContainerRecord) escherRecord).fillFields(bArr, i2, this);
            }
            return escherRecord;
        } catch (Exception unused) {
            return super.createRecord(bArr, i2);
        }
    }
}
