package org.apache.poi.hslf.record;

import b.b.a.a.a;
import java.io.OutputStream;
import org.apache.poi.util.LittleEndian;

public final class HeadersFootersAtom extends RecordAtom {
    public static final int fHasDate = 1;
    public static final int fHasFooter = 32;
    public static final int fHasHeader = 16;
    public static final int fHasSlideNumber = 8;
    public static final int fHasTodayDate = 2;
    public static final int fHasUserDate = 4;
    public byte[] _header;
    public byte[] _recdata;

    public HeadersFootersAtom(byte[] bArr, int i2, int i3) {
        byte[] bArr2 = new byte[8];
        this._header = bArr2;
        System.arraycopy(bArr, i2, bArr2, 0, 8);
        int i4 = i3 - 8;
        byte[] bArr3 = new byte[i4];
        this._recdata = bArr3;
        System.arraycopy(bArr, i2 + 8, bArr3, 0, i4);
    }

    public boolean getFlag(int i2) {
        return (i2 & getMask()) != 0;
    }

    public int getFormatId() {
        return LittleEndian.getShort(this._recdata, 0);
    }

    public int getMask() {
        return LittleEndian.getShort(this._recdata, 2);
    }

    @Override // org.apache.poi.hslf.record.Record
    public long getRecordType() {
        return (long) RecordTypes.HeadersFootersAtom.typeID;
    }

    public void setFlag(int i2, boolean z) {
        int mask = getMask();
        setMask(z ? i2 | mask : (~i2) & mask);
    }

    public void setFormatId(int i2) {
        LittleEndian.putUShort(this._recdata, 0, i2);
    }

    public void setMask(int i2) {
        LittleEndian.putUShort(this._recdata, 2, i2);
    }

    public String toString() {
        StringBuffer a = a.a("HeadersFootersAtom\n");
        StringBuilder b2 = a.b("\tFormatId: ");
        b2.append(getFormatId());
        b2.append("\n");
        a.append(b2.toString());
        a.append("\tMask    : " + getMask() + "\n");
        a.append("\t  fHasDate        : " + getFlag(1) + "\n");
        a.append("\t  fHasTodayDate   : " + getFlag(2) + "\n");
        a.append("\t  fHasUserDate    : " + getFlag(4) + "\n");
        a.append("\t  fHasSlideNumber : " + getFlag(8) + "\n");
        a.append("\t  fHasHeader      : " + getFlag(16) + "\n");
        a.append("\t  fHasFooter      : " + getFlag(32) + "\n");
        return a.toString();
    }

    @Override // org.apache.poi.hslf.record.Record
    public void writeOut(OutputStream outputStream) {
        outputStream.write(this._header);
        outputStream.write(this._recdata);
    }

    public HeadersFootersAtom() {
        this._recdata = new byte[4];
        byte[] bArr = new byte[8];
        this._header = bArr;
        LittleEndian.putShort(bArr, 2, (short) ((int) getRecordType()));
        LittleEndian.putInt(this._header, 4, this._recdata.length);
    }
}
