package org.apache.poi.hslf.record;

import b.b.a.a.a;
import java.io.OutputStream;
import org.apache.poi.util.LittleEndian;
import org.apache.poi.util.POILogger;

public final class HeadersFootersContainer extends RecordContainer {
    public static final int FOOTERATOM = 2;
    public static final int HEADERATOM = 1;
    public static final short NotesHeadersFootersContainer = 79;
    public static final short SlideHeadersFootersContainer = 63;
    public static final int USERDATEATOM = 0;
    public byte[] _header;
    public CString csDate;
    public CString csFooter;
    public CString csHeader;
    public HeadersFootersAtom hdAtom;

    public HeadersFootersContainer(byte[] bArr, int i2, int i3) {
        byte[] bArr2 = new byte[8];
        this._header = bArr2;
        System.arraycopy(bArr, i2, bArr2, 0, 8);
        this._children = Record.findChildRecords(bArr, i2 + 8, i3 - 8);
        int i4 = 0;
        while (true) {
            Record[] recordArr = this._children;
            if (i4 < recordArr.length) {
                if (recordArr[i4] instanceof HeadersFootersAtom) {
                    this.hdAtom = (HeadersFootersAtom) recordArr[i4];
                } else if (recordArr[i4] instanceof CString) {
                    CString cString = (CString) recordArr[i4];
                    int options = cString.getOptions() >> 4;
                    if (options == 0) {
                        this.csDate = cString;
                    } else if (options == 1) {
                        this.csHeader = cString;
                    } else if (options != 2) {
                        Record.logger.log(5, a.c("Unexpected CString.Options in HeadersFootersContainer: ", options));
                    } else {
                        this.csFooter = cString;
                    }
                } else {
                    POILogger pOILogger = Record.logger;
                    StringBuilder b2 = a.b("Unexpected record in HeadersFootersContainer: ");
                    b2.append(this._children[i4]);
                    pOILogger.log(5, b2.toString());
                }
                i4++;
            } else {
                return;
            }
        }
    }

    public CString addFooterAtom() {
        CString cString = this.csFooter;
        if (cString != null) {
            return cString;
        }
        CString cString2 = new CString();
        this.csFooter = cString2;
        cString2.setOptions(32);
        Record record = this.hdAtom;
        CString cString3 = this.csHeader;
        if (!(cString3 == null && (cString3 = this.csDate) == null)) {
            record = cString3;
        }
        addChildAfter(this.csFooter, record);
        return this.csFooter;
    }

    public CString addHeaderAtom() {
        CString cString = this.csHeader;
        if (cString != null) {
            return cString;
        }
        CString cString2 = new CString();
        this.csHeader = cString2;
        cString2.setOptions(16);
        HeadersFootersAtom headersFootersAtom = this.hdAtom;
        CString cString3 = this.csDate;
        addChildAfter(this.csHeader, headersFootersAtom);
        return this.csHeader;
    }

    public CString addUserDateAtom() {
        CString cString = this.csDate;
        if (cString != null) {
            return cString;
        }
        CString cString2 = new CString();
        this.csDate = cString2;
        cString2.setOptions(0);
        addChildAfter(this.csDate, this.hdAtom);
        return this.csDate;
    }

    public CString getFooterAtom() {
        return this.csFooter;
    }

    public CString getHeaderAtom() {
        return this.csHeader;
    }

    public HeadersFootersAtom getHeadersFootersAtom() {
        return this.hdAtom;
    }

    public int getOptions() {
        return LittleEndian.getShort(this._header, 0);
    }

    @Override // org.apache.poi.hslf.record.Record
    public long getRecordType() {
        return (long) RecordTypes.HeadersFooters.typeID;
    }

    public CString getUserDateAtom() {
        return this.csDate;
    }

    @Override // org.apache.poi.hslf.record.Record
    public void writeOut(OutputStream outputStream) {
        byte[] bArr = this._header;
        writeOut(bArr[0], bArr[1], getRecordType(), this._children, outputStream);
    }

    public HeadersFootersContainer(short s) {
        byte[] bArr = new byte[8];
        this._header = bArr;
        LittleEndian.putShort(bArr, 0, s);
        LittleEndian.putShort(this._header, 2, (short) ((int) getRecordType()));
        HeadersFootersAtom headersFootersAtom = new HeadersFootersAtom();
        this.hdAtom = headersFootersAtom;
        this._children = new Record[]{headersFootersAtom};
        this.csFooter = null;
        this.csHeader = null;
        this.csDate = null;
    }
}
