package org.apache.poi.hslf.record;

import java.io.OutputStream;
import org.apache.poi.util.LittleEndian;

public class InteractiveInfo extends RecordContainer {
    public static long _type = 4082;
    public byte[] _header;
    public InteractiveInfoAtom infoAtom;

    public InteractiveInfo(byte[] bArr, int i2, int i3) {
        byte[] bArr2 = new byte[8];
        this._header = bArr2;
        System.arraycopy(bArr, i2, bArr2, 0, 8);
        this._children = Record.findChildRecords(bArr, i2 + 8, i3 - 8);
        findInterestingChildren();
    }

    private void findInterestingChildren() {
        Record[] recordArr = this._children;
        if (recordArr == null || recordArr.length == 0 || !(recordArr[0] instanceof InteractiveInfoAtom)) {
            Record.logger.log(5, "First child record wasn't a InteractiveInfoAtom - leaving this atom in an invalid state...");
            return;
        }
        this.infoAtom = (InteractiveInfoAtom) recordArr[0];
    }

    public InteractiveInfoAtom getInteractiveInfoAtom() {
        return this.infoAtom;
    }

    @Override // org.apache.poi.hslf.record.Record
    public long getRecordType() {
        return _type;
    }

    @Override // org.apache.poi.hslf.record.Record
    public void writeOut(OutputStream outputStream) {
        byte[] bArr = this._header;
        writeOut(bArr[0], bArr[1], _type, this._children, outputStream);
    }

    public InteractiveInfo() {
        byte[] bArr = new byte[8];
        this._header = bArr;
        this._children = new Record[1];
        bArr[0] = 15;
        LittleEndian.putShort(bArr, 2, (short) ((int) _type));
        InteractiveInfoAtom interactiveInfoAtom = new InteractiveInfoAtom();
        this.infoAtom = interactiveInfoAtom;
        this._children[0] = interactiveInfoAtom;
    }
}
