package org.apache.poi.hslf.record;

import java.io.OutputStream;
import java.util.ArrayList;
import java.util.Collections;
import java.util.List;
import org.apache.poi.hslf.model.textproperties.IndentProp;
import org.apache.poi.util.LittleEndian;

public final class MasterTextPropAtom extends RecordAtom {
    public byte[] _data;
    public byte[] _header;
    public List<IndentProp> indents;

    public MasterTextPropAtom() {
        byte[] bArr = new byte[8];
        this._header = bArr;
        this._data = new byte[0];
        LittleEndian.putShort(bArr, 2, (short) ((int) getRecordType()));
        LittleEndian.putInt(this._header, 4, this._data.length);
        this.indents = new ArrayList();
    }

    private void read() {
        this.indents = new ArrayList(this._data.length / 6);
        int i2 = 0;
        while (true) {
            byte[] bArr = this._data;
            if (i2 <= bArr.length - 6) {
                this.indents.add(new IndentProp(LittleEndian.getInt(bArr, i2), LittleEndian.getShort(this._data, i2 + 4)));
                i2 += 6;
            } else {
                return;
            }
        }
    }

    private void write() {
        this._data = new byte[(this.indents.size() * 6)];
        int i2 = 0;
        for (IndentProp indentProp : this.indents) {
            LittleEndian.putInt(this._data, i2, indentProp.getCharactersCovered());
            LittleEndian.putShort(this._data, i2 + 4, (short) indentProp.getIndentLevel());
            i2 += 6;
        }
    }

    public int getIndentAt(int i2) {
        int i3 = 0;
        for (IndentProp indentProp : this.indents) {
            i3 += indentProp.getCharactersCovered();
            if (i2 < i3) {
                return indentProp.getIndentLevel();
            }
        }
        return -1;
    }

    public List<IndentProp> getIndents() {
        return Collections.unmodifiableList(this.indents);
    }

    @Override // org.apache.poi.hslf.record.Record
    public long getRecordType() {
        return (long) RecordTypes.MasterTextPropAtom.typeID;
    }

    @Override // org.apache.poi.hslf.record.Record
    public void writeOut(OutputStream outputStream) {
        write();
        outputStream.write(this._header);
        outputStream.write(this._data);
    }

    public MasterTextPropAtom(byte[] bArr, int i2, int i3) {
        byte[] bArr2 = new byte[8];
        this._header = bArr2;
        System.arraycopy(bArr, i2, bArr2, 0, 8);
        int i4 = i3 - 8;
        byte[] bArr3 = new byte[i4];
        this._data = bArr3;
        System.arraycopy(bArr, i2 + 8, bArr3, 0, i4);
        try {
            read();
        } catch (Exception e2) {
            Record.logger.log(7, "Failed to parse MasterTextPropAtom", e2);
        }
    }
}
