package org.apache.poi.hslf.record;

import java.io.OutputStream;
import org.apache.poi.util.LittleEndian;

public final class OEPlaceholderAtom extends RecordAtom {
    public static final int PLACEHOLDER_FULLSIZE = 0;
    public static final int PLACEHOLDER_HALFSIZE = 1;
    public static final int PLACEHOLDER_QUARTSIZE = 2;
    public byte[] _header;
    public int placeholderId;
    public int placeholderSize;
    public int placementId;
    public short unusedShort = 0;

    public OEPlaceholderAtom() {
        byte[] bArr = new byte[8];
        this._header = bArr;
        LittleEndian.putUShort(bArr, 0, 0);
        LittleEndian.putUShort(this._header, 2, (int) getRecordType());
        LittleEndian.putInt(this._header, 4, 8);
        this.placementId = 0;
        this.placeholderId = 0;
        this.placeholderSize = 0;
    }

    public int getPlaceholderId() {
        return this.placeholderId;
    }

    public int getPlaceholderSize() {
        return this.placeholderSize;
    }

    public int getPlacementId() {
        return this.placementId;
    }

    @Override // org.apache.poi.hslf.record.Record
    public long getRecordType() {
        return (long) RecordTypes.OEPlaceholderAtom.typeID;
    }

    public void setPlaceholderId(byte b2) {
        this.placeholderId = b2;
    }

    public void setPlaceholderSize(byte b2) {
        this.placeholderSize = b2;
    }

    public void setPlacementId(int i2) {
        this.placementId = i2;
    }

    @Override // org.apache.poi.hslf.record.Record
    public void writeOut(OutputStream outputStream) {
        outputStream.write(this._header);
        byte[] bArr = new byte[8];
        LittleEndian.putInt(bArr, 0, this.placementId);
        bArr[4] = (byte) this.placeholderId;
        bArr[5] = (byte) this.placeholderSize;
        LittleEndian.putShort(bArr, 6, this.unusedShort);
        outputStream.write(bArr);
    }

    public OEPlaceholderAtom(byte[] bArr, int i2, int i3) {
        byte[] bArr2 = new byte[8];
        this._header = bArr2;
        System.arraycopy(bArr, i2, bArr2, 0, 8);
        int length = i2 + this._header.length;
        this.placementId = LittleEndian.getInt(bArr, length);
        int i4 = length + 4;
        this.placeholderId = LittleEndian.getUByte(bArr, i4);
        int i5 = i4 + 1;
        this.placeholderSize = LittleEndian.getUByte(bArr, i5);
        this.unusedShort = LittleEndian.getShort(bArr, i5 + 1);
    }
}
