package org.apache.poi.hslf.record;

import b.b.a.a.a;
import java.io.OutputStream;
import java.util.ArrayList;
import java.util.Iterator;
import java.util.LinkedList;
import java.util.List;
import org.apache.poi.ddf.DefaultEscherRecordFactory;
import org.apache.poi.ddf.EscherBoolProperty;
import org.apache.poi.ddf.EscherContainerRecord;
import org.apache.poi.ddf.EscherDgRecord;
import org.apache.poi.ddf.EscherOptRecord;
import org.apache.poi.ddf.EscherProperties;
import org.apache.poi.ddf.EscherRGBProperty;
import org.apache.poi.ddf.EscherRecord;
import org.apache.poi.ddf.EscherSimpleProperty;
import org.apache.poi.ddf.EscherSpRecord;
import org.apache.poi.ddf.EscherSpgrRecord;
import org.apache.poi.ddf.EscherTextboxRecord;
import org.apache.poi.sl.usermodel.ShapeType;
import org.apache.poi.util.LittleEndian;
import org.apache.poi.util.POILogger;

public final class PPDrawing extends RecordAtom {
    public byte[] _header;
    public long _type;
    public final List<EscherRecord> childRecords = new ArrayList();
    public EscherDgRecord dg;
    public EscherTextboxWrapper[] textboxWrappers;

    public PPDrawing() {
        byte[] bArr = new byte[8];
        this._header = bArr;
        LittleEndian.putUShort(bArr, 0, 15);
        LittleEndian.putUShort(this._header, 2, RecordTypes.PPDrawing.typeID);
        LittleEndian.putInt(this._header, 4, 0);
        this.textboxWrappers = new EscherTextboxWrapper[0];
        create();
    }

    private void create() {
        EscherContainerRecord escherContainerRecord = new EscherContainerRecord();
        escherContainerRecord.setRecordId(EscherContainerRecord.DG_CONTAINER);
        escherContainerRecord.setOptions(15);
        EscherDgRecord escherDgRecord = new EscherDgRecord();
        this.dg = escherDgRecord;
        escherDgRecord.setOptions(16);
        this.dg.setNumShapes(1);
        escherContainerRecord.addChildRecord(this.dg);
        EscherContainerRecord escherContainerRecord2 = new EscherContainerRecord();
        escherContainerRecord2.setOptions(15);
        escherContainerRecord2.setRecordId(EscherContainerRecord.SPGR_CONTAINER);
        EscherContainerRecord escherContainerRecord3 = new EscherContainerRecord();
        escherContainerRecord3.setOptions(15);
        escherContainerRecord3.setRecordId(EscherContainerRecord.SP_CONTAINER);
        EscherSpgrRecord escherSpgrRecord = new EscherSpgrRecord();
        escherSpgrRecord.setOptions(1);
        escherContainerRecord3.addChildRecord(escherSpgrRecord);
        EscherSpRecord escherSpRecord = new EscherSpRecord();
        escherSpRecord.setOptions((short) ((ShapeType.NOT_PRIMITIVE.nativeId << 4) + 2));
        escherSpRecord.setFlags(5);
        escherContainerRecord3.addChildRecord(escherSpRecord);
        escherContainerRecord2.addChildRecord(escherContainerRecord3);
        escherContainerRecord.addChildRecord(escherContainerRecord2);
        EscherContainerRecord escherContainerRecord4 = new EscherContainerRecord();
        escherContainerRecord4.setOptions(15);
        escherContainerRecord4.setRecordId(EscherContainerRecord.SP_CONTAINER);
        EscherSpRecord escherSpRecord2 = new EscherSpRecord();
        escherSpRecord2.setOptions((short) ((ShapeType.RECT.nativeId << 4) + 2));
        escherSpRecord2.setFlags(3072);
        escherContainerRecord4.addChildRecord(escherSpRecord2);
        EscherOptRecord escherOptRecord = new EscherOptRecord();
        escherOptRecord.setRecordId(EscherOptRecord.RECORD_ID);
        escherOptRecord.addEscherProperty(new EscherRGBProperty(EscherProperties.FILL__FILLCOLOR, 134217728));
        escherOptRecord.addEscherProperty(new EscherRGBProperty(EscherProperties.FILL__FILLBACKCOLOR, 134217733));
        escherOptRecord.addEscherProperty(new EscherSimpleProperty(EscherProperties.FILL__RECTRIGHT, 10064750));
        escherOptRecord.addEscherProperty(new EscherSimpleProperty(EscherProperties.FILL__RECTBOTTOM, 7778750));
        escherOptRecord.addEscherProperty(new EscherBoolProperty(EscherProperties.FILL__NOFILLHITTEST, 1179666));
        escherOptRecord.addEscherProperty(new EscherBoolProperty(EscherProperties.LINESTYLE__NOLINEDRAWDASH, 524288));
        escherOptRecord.addEscherProperty(new EscherSimpleProperty(EscherProperties.SHAPE__BLACKANDWHITESETTINGS, 9));
        escherOptRecord.addEscherProperty(new EscherSimpleProperty(EscherProperties.SHAPE__BACKGROUNDSHAPE, 65537));
        escherContainerRecord4.addChildRecord(escherOptRecord);
        escherContainerRecord.addChildRecord(escherContainerRecord4);
        this.childRecords.add(escherContainerRecord);
    }

    private void findEscherChildren(DefaultEscherRecordFactory defaultEscherRecordFactory, byte[] bArr, int i2, int i3, List<EscherRecord> list) {
        int i4 = LittleEndian.getInt(bArr, i2 + 4) + 8;
        EscherRecord createRecord = defaultEscherRecordFactory.createRecord(bArr, i2);
        createRecord.fillFields(bArr, i2, defaultEscherRecordFactory);
        list.add(createRecord);
        int recordSize = createRecord.getRecordSize();
        if (recordSize < 8) {
            Record.logger.log(5, a.a("Hit short DDF record at ", i2, " - ", recordSize));
        }
        if (recordSize != i4) {
            POILogger pOILogger = Record.logger;
            StringBuilder a = a.a("Record length=", i4, " but getRecordSize() returned ");
            a.append(createRecord.getRecordSize());
            a.append("; record: ");
            a.append(createRecord.getClass());
            pOILogger.log(5, a.toString());
        } else {
            i4 = recordSize;
        }
        int i5 = i2 + i4;
        int i6 = i3 - i4;
        if (i6 >= 8) {
            findEscherChildren(defaultEscherRecordFactory, bArr, i5, i6, list);
        }
    }

    private void findEscherTextboxRecord(List<EscherRecord> list, List<EscherTextboxWrapper> list2) {
        EscherSpRecord escherSpRecord = null;
        for (EscherRecord escherRecord : list) {
            if (escherRecord instanceof EscherSpRecord) {
                escherSpRecord = (EscherSpRecord) escherRecord;
            } else if (escherRecord instanceof EscherTextboxRecord) {
                EscherTextboxWrapper escherTextboxWrapper = new EscherTextboxWrapper((EscherTextboxRecord) escherRecord);
                if (escherSpRecord != null) {
                    escherTextboxWrapper.setShapeId(escherSpRecord.getShapeId());
                }
                list2.add(escherTextboxWrapper);
            } else if (escherRecord.isContainerRecord()) {
                findEscherTextboxRecord(escherRecord.getChildRecords(), list2);
            }
        }
    }

    private EscherTextboxWrapper[] findInDgContainer(EscherContainerRecord escherContainerRecord) {
        LinkedList linkedList = new LinkedList();
        EscherContainerRecord[] findAllEscherContainerRecordOfType = findAllEscherContainerRecordOfType(RecordTypes.EscherSpContainer, findFirstEscherContainerRecordOfType(RecordTypes.EscherSpgrContainer, escherContainerRecord));
        for (EscherContainerRecord escherContainerRecord2 : findAllEscherContainerRecordOfType) {
            EscherSpRecord escherSpRecord = (EscherSpRecord) findFirstEscherRecordOfType(RecordTypes.EscherSp, escherContainerRecord2);
            EscherTextboxRecord escherTextboxRecord = (EscherTextboxRecord) findFirstEscherRecordOfType(RecordTypes.EscherClientTextbox, escherContainerRecord2);
            if (escherTextboxRecord != null) {
                EscherTextboxWrapper escherTextboxWrapper = new EscherTextboxWrapper(escherTextboxRecord);
                escherTextboxWrapper.setStyleTextProp9Atom(findInSpContainer(escherContainerRecord2));
                if (escherSpRecord != null) {
                    escherTextboxWrapper.setShapeId(escherSpRecord.getShapeId());
                }
                linkedList.add(escherTextboxWrapper);
            }
        }
        return (EscherTextboxWrapper[]) linkedList.toArray(new EscherTextboxWrapper[linkedList.size()]);
    }

    private StyleTextProp9Atom findInSpContainer(EscherContainerRecord escherContainerRecord) {
        DummyPositionSensitiveRecordWithChildren dummyPositionSensitiveRecordWithChildren;
        DummyPositionSensitiveRecordWithChildren dummyPositionSensitiveRecordWithChildren2;
        HSLFEscherClientDataRecord hSLFEscherClientDataRecord = (HSLFEscherClientDataRecord) escherContainerRecord.getChildById(RecordTypes.EscherClientData.typeID);
        if (hSLFEscherClientDataRecord == null || (dummyPositionSensitiveRecordWithChildren = (DummyPositionSensitiveRecordWithChildren) getChildRecord(hSLFEscherClientDataRecord.getHSLFChildRecords(), RecordTypes.ProgTags)) == null || (dummyPositionSensitiveRecordWithChildren2 = (DummyPositionSensitiveRecordWithChildren) dummyPositionSensitiveRecordWithChildren.findFirstOfType((long) RecordTypes.ProgBinaryTag.typeID)) == null || 2 != dummyPositionSensitiveRecordWithChildren2.getChildRecords().length) {
            return null;
        }
        Record record = dummyPositionSensitiveRecordWithChildren2.getChildRecords()[0];
        Record record2 = dummyPositionSensitiveRecordWithChildren2.getChildRecords()[1];
        if (!(record instanceof CString) || !"___PPT9".equals(((CString) record).getText()) || !(record2 instanceof BinaryTagDataBlob)) {
            return null;
        }
        BinaryTagDataBlob binaryTagDataBlob = (BinaryTagDataBlob) record2;
        if (1 != binaryTagDataBlob.getChildRecords().length) {
            return null;
        }
        return (StyleTextProp9Atom) binaryTagDataBlob.findFirstOfType((long) RecordTypes.StyleTextProp9Atom.typeID);
    }

    public static <T extends Record> T getChildRecord(List<? extends Record> list, RecordTypes recordTypes) {
        for (Record record : list) {
            T t = (T) record;
            if (t.getRecordType() == ((long) recordTypes.typeID)) {
                return t;
            }
        }
        return null;
    }

    public void addTextboxWrapper(EscherTextboxWrapper escherTextboxWrapper) {
        EscherTextboxWrapper[] escherTextboxWrapperArr = this.textboxWrappers;
        EscherTextboxWrapper[] escherTextboxWrapperArr2 = new EscherTextboxWrapper[(escherTextboxWrapperArr.length + 1)];
        System.arraycopy(escherTextboxWrapperArr, 0, escherTextboxWrapperArr2, 0, escherTextboxWrapperArr.length);
        escherTextboxWrapperArr2[this.textboxWrappers.length] = escherTextboxWrapper;
        this.textboxWrappers = escherTextboxWrapperArr2;
    }

    public EscherContainerRecord[] findAllEscherContainerRecordOfType(RecordTypes recordTypes, EscherContainerRecord escherContainerRecord) {
        if (escherContainerRecord == null) {
            return new EscherContainerRecord[0];
        }
        List<EscherContainerRecord> childContainers = escherContainerRecord.getChildContainers();
        LinkedList linkedList = new LinkedList();
        for (EscherContainerRecord escherContainerRecord2 : childContainers) {
            if (recordTypes.typeID == escherContainerRecord2.getRecordId()) {
                linkedList.add(escherContainerRecord2);
            }
        }
        return (EscherContainerRecord[]) linkedList.toArray(new EscherContainerRecord[linkedList.size()]);
    }

    public EscherContainerRecord findFirstEscherContainerRecordOfType(RecordTypes recordTypes, EscherContainerRecord escherContainerRecord) {
        if (escherContainerRecord == null) {
            return null;
        }
        for (EscherContainerRecord escherContainerRecord2 : escherContainerRecord.getChildContainers()) {
            if (recordTypes.typeID == escherContainerRecord2.getRecordId()) {
                return escherContainerRecord2;
            }
        }
        return null;
    }

    public EscherRecord findFirstEscherRecordOfType(RecordTypes recordTypes, EscherContainerRecord escherContainerRecord) {
        if (escherContainerRecord == null) {
            return null;
        }
        for (EscherRecord escherRecord : escherContainerRecord.getChildRecords()) {
            if (recordTypes.typeID == escherRecord.getRecordId()) {
                return escherRecord;
            }
        }
        return null;
    }

    @Override // org.apache.poi.hslf.record.Record, org.apache.poi.hslf.record.RecordAtom
    public Record[] getChildRecords() {
        return null;
    }

    public EscherContainerRecord getDgContainer() {
        if (this.childRecords.isEmpty()) {
            return null;
        }
        EscherRecord escherRecord = this.childRecords.get(0);
        if (!(escherRecord instanceof EscherContainerRecord) || escherRecord.getRecordId() != RecordTypes.EscherDgContainer.typeID) {
            return null;
        }
        return (EscherContainerRecord) escherRecord;
    }

    public EscherDgRecord getEscherDgRecord() {
        EscherContainerRecord dgContainer;
        if (this.dg == null && (dgContainer = getDgContainer()) != null) {
            Iterator<EscherRecord> it = dgContainer.getChildRecords().iterator();
            while (true) {
                if (!it.hasNext()) {
                    break;
                }
                EscherRecord next = it.next();
                if (next instanceof EscherDgRecord) {
                    this.dg = (EscherDgRecord) next;
                    break;
                }
            }
        }
        return this.dg;
    }

    public List<EscherRecord> getEscherRecords() {
        return this.childRecords;
    }

    public StyleTextProp9Atom[] getNumberedListInfo() {
        LinkedList linkedList = new LinkedList();
        for (EscherContainerRecord escherContainerRecord : findAllEscherContainerRecordOfType(RecordTypes.EscherSpContainer, findFirstEscherContainerRecordOfType(RecordTypes.EscherSpgrContainer, getDgContainer()))) {
            StyleTextProp9Atom findInSpContainer = findInSpContainer(escherContainerRecord);
            if (findInSpContainer != null) {
                linkedList.add(findInSpContainer);
            }
        }
        return (StyleTextProp9Atom[]) linkedList.toArray(new StyleTextProp9Atom[linkedList.size()]);
    }

    @Override // org.apache.poi.hslf.record.Record
    public long getRecordType() {
        return this._type;
    }

    public EscherTextboxWrapper[] getTextboxWrappers() {
        return this.textboxWrappers;
    }

    @Override // org.apache.poi.hslf.record.Record
    public void writeOut(OutputStream outputStream) {
        int i2 = 0;
        for (EscherTextboxWrapper escherTextboxWrapper : this.textboxWrappers) {
            escherTextboxWrapper.writeOut(null);
        }
        int i3 = 0;
        for (EscherRecord escherRecord : this.childRecords) {
            i3 += escherRecord.getRecordSize();
        }
        LittleEndian.putInt(this._header, 4, i3);
        outputStream.write(this._header);
        byte[] bArr = new byte[i3];
        for (EscherRecord escherRecord2 : this.childRecords) {
            i2 += escherRecord2.serialize(i2, bArr);
        }
        outputStream.write(bArr);
    }

    public PPDrawing(byte[] bArr, int i2, int i3) {
        byte[] bArr2 = new byte[8];
        this._header = bArr2;
        System.arraycopy(bArr, i2, bArr2, 0, 8);
        this._type = (long) LittleEndian.getUShort(this._header, 2);
        byte[] bArr3 = new byte[i3];
        System.arraycopy(bArr, i2, bArr3, 0, i3);
        findEscherChildren(new HSLFEscherRecordFactory(), bArr3, 8, i3 - 8, this.childRecords);
        EscherContainerRecord dgContainer = getDgContainer();
        if (dgContainer != null) {
            this.textboxWrappers = findInDgContainer(dgContainer);
            return;
        }
        ArrayList arrayList = new ArrayList();
        findEscherTextboxRecord(this.childRecords, arrayList);
        this.textboxWrappers = (EscherTextboxWrapper[]) arrayList.toArray(new EscherTextboxWrapper[arrayList.size()]);
    }
}
