package org.apache.poi.hslf.record;

import b.b.a.a.a;
import java.io.ByteArrayOutputStream;
import java.io.IOException;
import java.io.OutputStream;
import java.util.Collections;
import java.util.HashMap;
import java.util.Map;
import java.util.TreeMap;
import org.apache.poi.hslf.exceptions.CorruptPowerPointFileException;
import org.apache.poi.hslf.exceptions.HSLFException;
import org.apache.poi.util.BitField;
import org.apache.poi.util.LittleEndian;
import org.apache.poi.util.POILogger;

public final class PersistPtrHolder extends PositionDependentRecordAtom {
    public static final /* synthetic */ boolean $assertionsDisabled = false;
    public static final BitField cntPersistFld = new BitField(-1048576);
    public static final BitField persistIdFld = new BitField(1048575);
    public final byte[] _header;
    public byte[] _ptrData;
    public Map<Integer, Integer> _slideLocations;
    public long _type;

    public static class BufAccessBAOS extends ByteArrayOutputStream {
        public BufAccessBAOS() {
        }

        public byte[] getBuf() {
            return ((ByteArrayOutputStream) this).buf;
        }
    }

    public PersistPtrHolder(byte[] bArr, int i2, int i3) {
        i3 = i3 < 8 ? 8 : i3;
        byte[] bArr2 = new byte[8];
        this._header = bArr2;
        System.arraycopy(bArr, i2, bArr2, 0, 8);
        this._type = (long) LittleEndian.getUShort(this._header, 2);
        this._slideLocations = new HashMap();
        byte[] bArr3 = new byte[(i3 - 8)];
        this._ptrData = bArr3;
        System.arraycopy(bArr, i2 + 8, bArr3, 0, bArr3.length);
        int i4 = 0;
        while (true) {
            byte[] bArr4 = this._ptrData;
            if (i4 < bArr4.length) {
                int i5 = LittleEndian.getInt(bArr4, i4);
                int value = persistIdFld.getValue(i5);
                int value2 = cntPersistFld.getValue(i5);
                i4 += 4;
                for (int i6 = 0; i6 < value2; i6++) {
                    this._slideLocations.put(Integer.valueOf(value + i6), Integer.valueOf((int) LittleEndian.getUInt(this._ptrData, i4)));
                    i4 += 4;
                }
            } else {
                return;
            }
        }
    }

    private void normalizePersistDirectory() {
        TreeMap treeMap = new TreeMap(this._slideLocations);
        BufAccessBAOS bufAccessBAOS = new BufAccessBAOS();
        byte[] bArr = new byte[4];
        int i2 = -1;
        int i3 = -1;
        for (Map.Entry entry : treeMap.entrySet()) {
            int intValue = ((Integer) entry.getKey()).intValue();
            int intValue2 = ((Integer) entry.getValue()).intValue();
            if (i2 + 1 == intValue) {
                try {
                    int i4 = LittleEndian.getInt(bufAccessBAOS.getBuf(), i3);
                    LittleEndian.putInt(bufAccessBAOS.getBuf(), i3, cntPersistFld.setValue(i4, cntPersistFld.getValue(i4) + 1));
                } catch (IOException e2) {
                    throw new HSLFException(e2);
                }
            } else {
                int size = bufAccessBAOS.size();
                LittleEndian.putInt(bArr, 0, cntPersistFld.setValue(persistIdFld.setValue(0, intValue), 1));
                bufAccessBAOS.write(bArr);
                i3 = size;
            }
            LittleEndian.putInt(bArr, 0, intValue2);
            bufAccessBAOS.write(bArr);
            i2 = intValue;
        }
        this._ptrData = bufAccessBAOS.toByteArray();
        LittleEndian.putInt(this._header, 4, bufAccessBAOS.size());
    }

    public void addSlideLookup(int i2, int i3) {
        if (!this._slideLocations.containsKey(Integer.valueOf(i2))) {
            this._slideLocations.put(Integer.valueOf(i2), Integer.valueOf(i3));
            return;
        }
        throw new CorruptPowerPointFileException(a.b("A record with persistId ", i2, " already exists."));
    }

    public void clear() {
        this._slideLocations.clear();
    }

    public int[] getKnownSlideIDs() {
        int[] iArr = new int[this._slideLocations.size()];
        int i2 = 0;
        for (Integer num : this._slideLocations.keySet()) {
            iArr[i2] = num.intValue();
            i2++;
        }
        return iArr;
    }

    @Override // org.apache.poi.hslf.record.Record
    public long getRecordType() {
        return this._type;
    }

    public Map<Integer, Integer> getSlideLocationsLookup() {
        return Collections.unmodifiableMap(this._slideLocations);
    }

    @Override // org.apache.poi.hslf.record.PositionDependentRecordAtom, org.apache.poi.hslf.record.PositionDependentRecord
    public void updateOtherRecordReferences(Map<Integer, Integer> map) {
        for (Map.Entry<Integer, Integer> entry : this._slideLocations.entrySet()) {
            Integer value = entry.getValue();
            Integer num = map.get(value);
            if (num == null) {
                POILogger pOILogger = Record.logger;
                pOILogger.log(5, "Couldn't find the new location of the \"slide\" with id " + entry.getKey() + " that used to be at " + value);
                Record.logger.log(5, "Not updating the position of it, you probably won't be able to find it any more (if you ever could!)");
            } else {
                entry.setValue(num);
            }
        }
    }

    @Override // org.apache.poi.hslf.record.Record
    public void writeOut(OutputStream outputStream) {
        normalizePersistDirectory();
        outputStream.write(this._header);
        outputStream.write(this._ptrData);
    }
}
