package org.apache.poi.hslf.record;

import java.io.ByteArrayOutputStream;
import java.io.OutputStream;
import java.util.ArrayList;
import org.apache.poi.hslf.util.MutableByteArrayOutputStream;
import org.apache.poi.util.ArrayUtil;
import org.apache.poi.util.LittleEndian;
import org.apache.poi.util.Removal;

public abstract class RecordContainer extends Record {
    public Record[] _children;

    private void addChildAt(Record record, int i2) {
        appendChild(record);
        moveChildRecords(this._children.length - 1, i2, 1);
    }

    private int appendChild(Record record) {
        Record[] recordArr = this._children;
        Record[] recordArr2 = new Record[(recordArr.length + 1)];
        System.arraycopy(recordArr, 0, recordArr2, 0, recordArr.length);
        recordArr2[this._children.length] = record;
        this._children = recordArr2;
        return recordArr2.length;
    }

    private int findChildLocation(Record record) {
        int i2 = 0;
        for (Record record2 : this._children) {
            if (record2.equals(record)) {
                return i2;
            }
            i2++;
        }
        return -1;
    }

    public static void handleParentAwareRecords(RecordContainer recordContainer) {
        Record[] childRecords = recordContainer.getChildRecords();
        for (Record record : childRecords) {
            if (record instanceof ParentAwareRecord) {
                ((ParentAwareRecord) record).setParentRecord(recordContainer);
            }
            if (record instanceof RecordContainer) {
                handleParentAwareRecords((RecordContainer) record);
            }
        }
    }

    private void moveChildRecords(int i2, int i3, int i4) {
        if (i2 != i3 && i4 != 0) {
            int i5 = i2 + i4;
            Record[] recordArr = this._children;
            if (i5 <= recordArr.length) {
                ArrayUtil.arrayMoveWithin(recordArr, i2, i3, i4);
                return;
            }
            throw new IllegalArgumentException("Asked to move more records than there are!");
        }
    }

    public int addChildAfter(Record record, Record record2) {
        int findChildLocation = findChildLocation(record2);
        if (findChildLocation != -1) {
            int i2 = findChildLocation + 1;
            addChildAt(record, i2);
            return i2;
        }
        throw new IllegalArgumentException("Asked to add a new child after another record, but that record wasn't one of our children!");
    }

    public int addChildBefore(Record record, Record record2) {
        int findChildLocation = findChildLocation(record2);
        if (findChildLocation != -1) {
            addChildAt(record, findChildLocation);
            return findChildLocation;
        }
        throw new IllegalArgumentException("Asked to add a new child before another record, but that record wasn't one of our children!");
    }

    public int appendChildRecord(Record record) {
        return appendChild(record);
    }

    public Record findFirstOfType(long j) {
        Record[] recordArr = this._children;
        for (Record record : recordArr) {
            if (record.getRecordType() == j) {
                return record;
            }
        }
        return null;
    }

    @Override // org.apache.poi.hslf.record.Record
    public Record[] getChildRecords() {
        return this._children;
    }

    @Override // org.apache.poi.hslf.record.Record
    public boolean isAnAtom() {
        return false;
    }

    @Removal(version = "3.19")
    @Deprecated
    public void moveChildBefore(Record record, Record record2) {
        moveChildrenBefore(record, 1, record2);
    }

    @Removal(version = "3.19")
    @Deprecated
    public void moveChildrenAfter(Record record, int i2, Record record2) {
        if (i2 >= 1) {
            int findChildLocation = findChildLocation(record2);
            if (findChildLocation != -1) {
                int i3 = findChildLocation + 1;
                int findChildLocation2 = findChildLocation(record);
                if (findChildLocation2 != -1) {
                    moveChildRecords(findChildLocation2, i3, i2);
                    return;
                }
                throw new IllegalArgumentException("Asked to move a record that wasn't a child!");
            }
            throw new IllegalArgumentException("Asked to move children before another record, but that record wasn't one of our children!");
        }
    }

    @Removal(version = "3.19")
    @Deprecated
    public void moveChildrenBefore(Record record, int i2, Record record2) {
        if (i2 >= 1) {
            int findChildLocation = findChildLocation(record2);
            if (findChildLocation != -1) {
                int findChildLocation2 = findChildLocation(record);
                if (findChildLocation2 != -1) {
                    moveChildRecords(findChildLocation2, findChildLocation, i2);
                    return;
                }
                throw new IllegalArgumentException("Asked to move a record that wasn't a child!");
            }
            throw new IllegalArgumentException("Asked to move children before another record, but that record wasn't one of our children!");
        }
    }

    public Record removeChild(Record record) {
        ArrayList arrayList = new ArrayList();
        Record[] recordArr = this._children;
        Record record2 = null;
        for (Record record3 : recordArr) {
            if (record3 != record) {
                arrayList.add(record3);
            } else {
                record2 = record3;
            }
        }
        this._children = (Record[]) arrayList.toArray(new Record[arrayList.size()]);
        return record2;
    }

    public void setChildRecord(Record[] recordArr) {
        this._children = (Record[]) recordArr.clone();
    }

    public void writeOut(byte b2, byte b3, long j, Record[] recordArr, OutputStream outputStream) {
        if (outputStream instanceof MutableByteArrayOutputStream) {
            MutableByteArrayOutputStream mutableByteArrayOutputStream = (MutableByteArrayOutputStream) outputStream;
            int bytesWritten = mutableByteArrayOutputStream.getBytesWritten();
            mutableByteArrayOutputStream.write(new byte[]{b2, b3});
            byte[] bArr = new byte[2];
            LittleEndian.putShort(bArr, 0, (short) ((int) j));
            mutableByteArrayOutputStream.write(bArr);
            mutableByteArrayOutputStream.write(new byte[4]);
            for (Record record : recordArr) {
                record.writeOut(mutableByteArrayOutputStream);
            }
            byte[] bArr2 = new byte[4];
            LittleEndian.putInt(bArr2, 0, (mutableByteArrayOutputStream.getBytesWritten() - bytesWritten) - 8);
            mutableByteArrayOutputStream.overwrite(bArr2, bytesWritten + 4);
            return;
        }
        ByteArrayOutputStream byteArrayOutputStream = new ByteArrayOutputStream();
        byteArrayOutputStream.write(new byte[]{b2, b3});
        byte[] bArr3 = new byte[2];
        LittleEndian.putShort(bArr3, 0, (short) ((int) j));
        byteArrayOutputStream.write(bArr3);
        byteArrayOutputStream.write(new byte[]{0, 0, 0, 0});
        for (Record record2 : recordArr) {
            record2.writeOut(byteArrayOutputStream);
        }
        byte[] byteArray = byteArrayOutputStream.toByteArray();
        LittleEndian.putInt(byteArray, 4, byteArray.length - 8);
        outputStream.write(byteArray);
    }
}
