package org.apache.poi.hslf.record;

import java.io.OutputStream;
import org.apache.poi.util.LittleEndian;

public class SSSlideInfoAtom extends RecordAtom {
    public static final /* synthetic */ boolean $assertionsDisabled = false;
    public static final int AUTO_ADVANCE_BIT = 1024;
    public static final int CURSOR_VISIBLE_BIT = 4096;
    public static final int HIDDEN_BIT = 4;
    public static final int LOOP_SOUND_BIT = 64;
    public static final int MANUAL_ADVANCE_BIT = 1;
    public static final int SOUND_BIT = 16;
    public static final int STOP_SOUND_BIT = 256;
    public static final long _type = ((long) RecordTypes.SSSlideInfoAtom.typeID);
    public short _effectDirection = 0;
    public short _effectTransitionFlags = 0;
    public short _effectType = 0;
    public byte[] _header;
    public int _slideTime = 0;
    public int _soundIdRef = 0;
    public short _speed = 0;
    public byte[] _unused;

    public SSSlideInfoAtom() {
        byte[] bArr = new byte[8];
        this._header = bArr;
        LittleEndian.putShort(bArr, 0, 0);
        LittleEndian.putShort(this._header, 2, (short) ((int) _type));
        LittleEndian.putShort(this._header, 4, 16);
        LittleEndian.putShort(this._header, 6, 0);
        this._unused = new byte[3];
    }

    public short getEffectDirection() {
        return this._effectDirection;
    }

    public boolean getEffectTransitionFlagByBit(int i2) {
        return (i2 & this._effectTransitionFlags) != 0;
    }

    public short getEffectTransitionFlags() {
        return this._effectTransitionFlags;
    }

    public short getEffectType() {
        return this._effectType;
    }

    @Override // org.apache.poi.hslf.record.Record
    public long getRecordType() {
        return _type;
    }

    public int getSlideTime() {
        return this._slideTime;
    }

    public int getSoundIdRef() {
        return this._soundIdRef;
    }

    public short getSpeed() {
        return this._speed;
    }

    public void setEffectDirection(short s) {
        this._effectDirection = s;
    }

    public void setEffectTransitionFlagByBit(int i2, boolean z) {
        if (z) {
            this._effectTransitionFlags = (short) (i2 | this._effectTransitionFlags);
            return;
        }
        this._effectTransitionFlags = (short) ((i2 ^ 65535) & this._effectTransitionFlags);
    }

    public void setEffectTransitionFlags(short s) {
        this._effectTransitionFlags = s;
    }

    public void setEffectType(short s) {
        this._effectType = s;
    }

    public void setSlideTime(int i2) {
        this._slideTime = i2;
    }

    public void setSoundIdRef(int i2) {
        this._soundIdRef = i2;
    }

    public void setSpeed(short s) {
        this._speed = s;
    }

    @Override // org.apache.poi.hslf.record.Record
    public void writeOut(OutputStream outputStream) {
        outputStream.write(this._header);
        Record.writeLittleEndian(this._slideTime, outputStream);
        Record.writeLittleEndian(this._soundIdRef, outputStream);
        byte[] bArr = new byte[1];
        LittleEndian.putUByte(bArr, 0, this._effectDirection);
        outputStream.write(bArr);
        LittleEndian.putUByte(bArr, 0, this._effectType);
        outputStream.write(bArr);
        Record.writeLittleEndian(this._effectTransitionFlags, outputStream);
        LittleEndian.putUByte(bArr, 0, this._speed);
        outputStream.write(bArr);
        outputStream.write(this._unused);
    }

    public SSSlideInfoAtom(byte[] bArr, int i2, int i3) {
        byte[] byteArray = LittleEndian.getByteArray(bArr, i2, 8);
        this._header = byteArray;
        int length = i2 + byteArray.length;
        this._slideTime = LittleEndian.getInt(bArr, length);
        int i4 = length + 4;
        this._soundIdRef = LittleEndian.getInt(bArr, i4);
        int i5 = i4 + 4;
        this._effectDirection = LittleEndian.getUByte(bArr, i5);
        int i6 = i5 + 1;
        this._effectType = LittleEndian.getUByte(bArr, i6);
        int i7 = i6 + 1;
        this._effectTransitionFlags = LittleEndian.getShort(bArr, i7);
        int i8 = i7 + 2;
        this._speed = LittleEndian.getUByte(bArr, i8);
        this._unused = LittleEndian.getByteArray(bArr, i8 + 1, 3);
    }
}
