package org.apache.poi.hslf.record;

import java.io.OutputStream;
import org.apache.poi.util.LittleEndian;

public final class Slide extends SheetContainer {
    public static long _type = 1006;
    public ColorSchemeAtom _colorScheme;
    public byte[] _header;
    public PPDrawing ppDrawing;
    public SlideAtom slideAtom;

    public Slide(byte[] bArr, int i2, int i3) {
        byte[] bArr2 = new byte[8];
        this._header = bArr2;
        int i4 = 0;
        System.arraycopy(bArr, i2, bArr2, 0, 8);
        this._children = Record.findChildRecords(bArr, i2 + 8, i3 - 8);
        while (true) {
            Record[] recordArr = this._children;
            if (i4 < recordArr.length) {
                if (recordArr[i4] instanceof SlideAtom) {
                    this.slideAtom = (SlideAtom) recordArr[i4];
                } else if (recordArr[i4] instanceof PPDrawing) {
                    this.ppDrawing = (PPDrawing) recordArr[i4];
                }
                if (this.ppDrawing != null) {
                    Record[] recordArr2 = this._children;
                    if (recordArr2[i4] instanceof ColorSchemeAtom) {
                        this._colorScheme = (ColorSchemeAtom) recordArr2[i4];
                    }
                }
                i4++;
            } else {
                return;
            }
        }
    }

    @Override // org.apache.poi.hslf.record.SheetContainer
    public ColorSchemeAtom getColorScheme() {
        return this._colorScheme;
    }

    @Override // org.apache.poi.hslf.record.SheetContainer
    public PPDrawing getPPDrawing() {
        return this.ppDrawing;
    }

    @Override // org.apache.poi.hslf.record.Record
    public long getRecordType() {
        return _type;
    }

    public SlideAtom getSlideAtom() {
        return this.slideAtom;
    }

    @Override // org.apache.poi.hslf.record.Record
    public void writeOut(OutputStream outputStream) {
        byte[] bArr = this._header;
        writeOut(bArr[0], bArr[1], _type, this._children, outputStream);
    }

    public Slide() {
        byte[] bArr = new byte[8];
        this._header = bArr;
        LittleEndian.putUShort(bArr, 0, 15);
        LittleEndian.putUShort(this._header, 2, (int) _type);
        LittleEndian.putInt(this._header, 4, 0);
        this.slideAtom = new SlideAtom();
        this.ppDrawing = new PPDrawing();
        this._children = new Record[]{this.slideAtom, this.ppDrawing, new ColorSchemeAtom()};
    }
}
