package org.apache.poi.hslf.record;

import java.io.OutputStream;
import org.apache.poi.hslf.record.SlideAtomLayout;
import org.apache.poi.util.LittleEndian;

public final class SlideAtom extends RecordAtom {
    public static final int USES_MASTER_SLIDE_ID = Integer.MIN_VALUE;
    public static long _type = 1007;
    public byte[] _header;
    public boolean followMasterBackground;
    public boolean followMasterObjects;
    public boolean followMasterScheme;
    public SlideAtomLayout layoutAtom;
    public int masterID;
    public int notesID;
    public byte[] reserved;

    public SlideAtom(byte[] bArr, int i2, int i3) {
        i3 = i3 < 30 ? 30 : i3;
        byte[] bArr2 = new byte[8];
        this._header = bArr2;
        System.arraycopy(bArr, i2, bArr2, 0, 8);
        byte[] bArr3 = new byte[12];
        System.arraycopy(bArr, i2 + 8, bArr3, 0, 12);
        this.layoutAtom = new SlideAtomLayout(bArr3);
        this.masterID = LittleEndian.getInt(bArr, i2 + 12 + 8);
        this.notesID = LittleEndian.getInt(bArr, i2 + 16 + 8);
        int uShort = LittleEndian.getUShort(bArr, i2 + 20 + 8);
        if ((uShort & 4) == 4) {
            this.followMasterBackground = true;
        } else {
            this.followMasterBackground = false;
        }
        if ((uShort & 2) == 2) {
            this.followMasterScheme = true;
        } else {
            this.followMasterScheme = false;
        }
        if ((uShort & 1) == 1) {
            this.followMasterObjects = true;
        } else {
            this.followMasterObjects = false;
        }
        byte[] bArr4 = new byte[(i3 - 30)];
        this.reserved = bArr4;
        System.arraycopy(bArr, i2 + 30, bArr4, 0, bArr4.length);
    }

    public boolean getFollowMasterBackground() {
        return this.followMasterBackground;
    }

    public boolean getFollowMasterObjects() {
        return this.followMasterObjects;
    }

    public boolean getFollowMasterScheme() {
        return this.followMasterScheme;
    }

    public int getMasterID() {
        return this.masterID;
    }

    public int getNotesID() {
        return this.notesID;
    }

    @Override // org.apache.poi.hslf.record.Record
    public long getRecordType() {
        return _type;
    }

    public SlideAtomLayout getSSlideLayoutAtom() {
        return this.layoutAtom;
    }

    public void setFollowMasterBackground(boolean z) {
        this.followMasterBackground = z;
    }

    public void setFollowMasterObjects(boolean z) {
        this.followMasterObjects = z;
    }

    public void setFollowMasterScheme(boolean z) {
        this.followMasterScheme = z;
    }

    public void setMasterID(int i2) {
        this.masterID = i2;
    }

    public void setNotesID(int i2) {
        this.notesID = i2;
    }

    @Override // org.apache.poi.hslf.record.Record
    public void writeOut(OutputStream outputStream) {
        outputStream.write(this._header);
        this.layoutAtom.writeOut(outputStream);
        Record.writeLittleEndian(this.masterID, outputStream);
        Record.writeLittleEndian(this.notesID, outputStream);
        short s = this.followMasterObjects ? (short) 1 : 0;
        if (this.followMasterScheme) {
            s = (short) (s + 2);
        }
        if (this.followMasterBackground) {
            s = (short) (s + 4);
        }
        Record.writeLittleEndian(s, outputStream);
        outputStream.write(this.reserved);
    }

    public SlideAtom() {
        byte[] bArr = new byte[8];
        this._header = bArr;
        LittleEndian.putUShort(bArr, 0, 2);
        LittleEndian.putUShort(this._header, 2, (int) _type);
        LittleEndian.putInt(this._header, 4, 24);
        SlideAtomLayout slideAtomLayout = new SlideAtomLayout(new byte[12]);
        this.layoutAtom = slideAtomLayout;
        slideAtomLayout.setGeometryType(SlideAtomLayout.SlideLayoutType.BLANK_SLIDE);
        this.followMasterObjects = true;
        this.followMasterScheme = true;
        this.followMasterBackground = true;
        this.masterID = Integer.MIN_VALUE;
        this.notesID = 0;
        this.reserved = new byte[2];
    }
}
