package org.apache.poi.hslf.record;

import b.b.a.a.a;
import java.io.OutputStream;
import org.apache.poi.hslf.exceptions.HSLFException;
import org.apache.poi.util.Internal;
import org.apache.poi.util.LittleEndian;

@Internal
public class SlideAtomLayout {
    public SlideLayoutType geometry;
    public byte[] placeholderIDs;

    public enum SlideLayoutType {
        TITLE_SLIDE(0),
        TITLE_BODY(1),
        MASTER_TITLE(2),
        MASTER_SLIDE(3),
        MASTER_NOTES(4),
        NOTES_TITLE_BODY(5),
        HANDOUT(6),
        TITLE_ONLY(7),
        TWO_COLUMNS(8),
        TWO_ROWS(9),
        COLUMN_TWO_ROWS(10),
        TWO_ROWS_COLUMN(11),
        TITLE_2_ROW_BOTTOM_2_COLUMN_BODY(12),
        TWO_COLUMNS_ROW(13),
        FOUR_OBJECTS(14),
        BIG_OBJECT(15),
        BLANK_SLIDE(16),
        VERTICAL_TITLE_BODY(17),
        VERTICAL_TWO_ROWS(18);
        
        public int nativeId;

        /* access modifiers changed from: public */
        SlideLayoutType(int i2) {
            this.nativeId = i2;
        }

        public static SlideLayoutType forNativeID(int i2) {
            SlideLayoutType[] values = values();
            for (SlideLayoutType slideLayoutType : values) {
                if (slideLayoutType.nativeId == i2) {
                    return slideLayoutType;
                }
            }
            return null;
        }

        public int getNativeId() {
            return this.nativeId;
        }
    }

    public SlideAtomLayout(byte[] bArr) {
        if (bArr.length == 12) {
            this.geometry = SlideLayoutType.forNativeID(LittleEndian.getInt(bArr, 0));
            byte[] bArr2 = new byte[8];
            this.placeholderIDs = bArr2;
            System.arraycopy(bArr, 4, bArr2, 0, 8);
            return;
        }
        throw new HSLFException(a.a(a.b("SSlideLayoutAtom created with byte array not 12 bytes long - was "), bArr.length, " bytes in size"));
    }

    public SlideLayoutType getGeometryType() {
        return this.geometry;
    }

    public void setGeometryType(SlideLayoutType slideLayoutType) {
        this.geometry = slideLayoutType;
    }

    public void writeOut(OutputStream outputStream) {
        byte[] bArr = new byte[4];
        LittleEndian.putInt(bArr, 0, this.geometry.getNativeId());
        outputStream.write(bArr);
        outputStream.write(this.placeholderIDs);
    }
}
