package org.apache.poi.hslf.record;

import java.io.OutputStream;
import java.util.ArrayList;
import org.apache.poi.util.LittleEndian;

public final class SlideListWithText extends RecordContainer {
    public static final int MASTER = 1;
    public static final int NOTES = 2;
    public static final int SLIDES = 0;
    public static long _type = 4080;
    public byte[] _header;
    public SlideAtomsSet[] slideAtomsSets;

    public static class SlideAtomsSet {
        public SlidePersistAtom slidePersistAtom;
        public Record[] slideRecords;

        public SlideAtomsSet(SlidePersistAtom slidePersistAtom2, Record[] recordArr) {
            this.slidePersistAtom = slidePersistAtom2;
            this.slideRecords = (Record[]) recordArr.clone();
        }

        public SlidePersistAtom getSlidePersistAtom() {
            return this.slidePersistAtom;
        }

        public Record[] getSlideRecords() {
            return this.slideRecords;
        }
    }

    public SlideListWithText(byte[] bArr, int i2, int i3) {
        byte[] bArr2 = new byte[8];
        this._header = bArr2;
        System.arraycopy(bArr, i2, bArr2, 0, 8);
        this._children = Record.findChildRecords(bArr, i2 + 8, i3 - 8);
        ArrayList arrayList = new ArrayList();
        int i4 = 0;
        while (true) {
            Record[] recordArr = this._children;
            if (i4 < recordArr.length) {
                if (recordArr[i4] instanceof SlidePersistAtom) {
                    int i5 = i4 + 1;
                    int i6 = i5;
                    while (true) {
                        Record[] recordArr2 = this._children;
                        if (i6 >= recordArr2.length || (recordArr2[i6] instanceof SlidePersistAtom)) {
                            int i7 = (i6 - i4) - 1;
                            Record[] recordArr3 = new Record[i7];
                            System.arraycopy(this._children, i5, recordArr3, 0, i7);
                            arrayList.add(new SlideAtomsSet((SlidePersistAtom) this._children[i4], recordArr3));
                            i4 += i7;
                        } else {
                            i6++;
                        }
                    }
                    int i72 = (i6 - i4) - 1;
                    Record[] recordArr32 = new Record[i72];
                    System.arraycopy(this._children, i5, recordArr32, 0, i72);
                    arrayList.add(new SlideAtomsSet((SlidePersistAtom) this._children[i4], recordArr32));
                    i4 += i72;
                }
                i4++;
            } else {
                this.slideAtomsSets = (SlideAtomsSet[]) arrayList.toArray(new SlideAtomsSet[arrayList.size()]);
                return;
            }
        }
    }

    public void addSlidePersistAtom(SlidePersistAtom slidePersistAtom) {
        appendChildRecord(slidePersistAtom);
        SlideAtomsSet slideAtomsSet = new SlideAtomsSet(slidePersistAtom, new Record[0]);
        SlideAtomsSet[] slideAtomsSetArr = this.slideAtomsSets;
        int length = slideAtomsSetArr.length + 1;
        SlideAtomsSet[] slideAtomsSetArr2 = new SlideAtomsSet[length];
        System.arraycopy(slideAtomsSetArr, 0, slideAtomsSetArr2, 0, slideAtomsSetArr.length);
        slideAtomsSetArr2[length - 1] = slideAtomsSet;
        this.slideAtomsSets = slideAtomsSetArr2;
    }

    public int getInstance() {
        return LittleEndian.getShort(this._header, 0) >> 4;
    }

    @Override // org.apache.poi.hslf.record.Record
    public long getRecordType() {
        return _type;
    }

    public SlideAtomsSet[] getSlideAtomsSets() {
        return this.slideAtomsSets;
    }

    public void setInstance(int i2) {
        LittleEndian.putShort(this._header, 0, (short) ((i2 << 4) | 15));
    }

    public void setSlideAtomsSets(SlideAtomsSet[] slideAtomsSetArr) {
        this.slideAtomsSets = (SlideAtomsSet[]) slideAtomsSetArr.clone();
    }

    @Override // org.apache.poi.hslf.record.Record
    public void writeOut(OutputStream outputStream) {
        byte[] bArr = this._header;
        writeOut(bArr[0], bArr[1], _type, this._children, outputStream);
    }

    public SlideListWithText() {
        byte[] bArr = new byte[8];
        this._header = bArr;
        LittleEndian.putUShort(bArr, 0, 15);
        LittleEndian.putUShort(this._header, 2, (int) _type);
        LittleEndian.putInt(this._header, 4, 0);
        this._children = new Record[0];
        this.slideAtomsSets = new SlideAtomsSet[0];
    }
}
