package org.apache.poi.hslf.record;

import java.io.OutputStream;
import org.apache.poi.util.LittleEndian;

public final class SlidePersistAtom extends RecordAtom {
    public static long _type = 1011;
    public byte[] _header;
    public boolean hasShapesOtherThanPlaceholders;
    public int numPlaceholderTexts;
    public int refID;
    public byte[] reservedFields;
    public int slideIdentifier;

    public SlidePersistAtom(byte[] bArr, int i2, int i3) {
        i3 = i3 < 8 ? 8 : i3;
        byte[] bArr2 = new byte[8];
        this._header = bArr2;
        System.arraycopy(bArr, i2, bArr2, 0, 8);
        this.refID = LittleEndian.getInt(bArr, i2 + 8);
        if (LittleEndian.getInt(bArr, i2 + 12) == 4) {
            this.hasShapesOtherThanPlaceholders = true;
        } else {
            this.hasShapesOtherThanPlaceholders = false;
        }
        this.numPlaceholderTexts = LittleEndian.getInt(bArr, i2 + 16);
        this.slideIdentifier = LittleEndian.getInt(bArr, i2 + 20);
        byte[] bArr3 = new byte[(i3 - 24)];
        this.reservedFields = bArr3;
        System.arraycopy(bArr, i2 + 24, bArr3, 0, bArr3.length);
    }

    public boolean getHasShapesOtherThanPlaceholders() {
        return this.hasShapesOtherThanPlaceholders;
    }

    public int getNumPlaceholderTexts() {
        return this.numPlaceholderTexts;
    }

    @Override // org.apache.poi.hslf.record.Record
    public long getRecordType() {
        return _type;
    }

    public int getRefID() {
        return this.refID;
    }

    public int getSlideIdentifier() {
        return this.slideIdentifier;
    }

    public void setRefID(int i2) {
        this.refID = i2;
    }

    public void setSlideIdentifier(int i2) {
        this.slideIdentifier = i2;
    }

    @Override // org.apache.poi.hslf.record.Record
    public void writeOut(OutputStream outputStream) {
        outputStream.write(this._header);
        int i2 = this.hasShapesOtherThanPlaceholders ? 4 : 0;
        Record.writeLittleEndian(this.refID, outputStream);
        Record.writeLittleEndian(i2, outputStream);
        Record.writeLittleEndian(this.numPlaceholderTexts, outputStream);
        Record.writeLittleEndian(this.slideIdentifier, outputStream);
        outputStream.write(this.reservedFields);
    }

    public SlidePersistAtom() {
        byte[] bArr = new byte[8];
        this._header = bArr;
        LittleEndian.putUShort(bArr, 0, 0);
        LittleEndian.putUShort(this._header, 2, (int) _type);
        LittleEndian.putInt(this._header, 4, 20);
        this.hasShapesOtherThanPlaceholders = true;
        this.reservedFields = new byte[4];
    }
}
