package org.apache.poi.hslf.record;

import b.b.a.a.a;
import java.io.ByteArrayOutputStream;
import java.io.IOException;
import java.io.OutputStream;
import java.util.ArrayList;
import java.util.List;
import org.apache.poi.hslf.exceptions.HSLFException;
import org.apache.poi.hslf.model.textproperties.TextPropCollection;
import org.apache.poi.util.HexDump;
import org.apache.poi.util.LittleEndian;

public final class StyleTextPropAtom extends RecordAtom {
    public static final long _type = ((long) RecordTypes.StyleTextPropAtom.typeID);
    public byte[] _header;
    public List<TextPropCollection> charStyles;
    public boolean initialised = false;
    public List<TextPropCollection> paragraphStyles;
    public byte[] rawContents;
    public byte[] reserved;

    public StyleTextPropAtom(byte[] bArr, int i2, int i3) {
        if (i3 < 18) {
            if (bArr.length - i2 >= 18) {
                i3 = 18;
            } else {
                StringBuilder b2 = a.b("Not enough data to form a StyleTextPropAtom (min size 18 bytes long) - found ");
                b2.append(bArr.length - i2);
                throw new HSLFException(b2.toString());
            }
        }
        byte[] bArr2 = new byte[8];
        this._header = bArr2;
        System.arraycopy(bArr, i2, bArr2, 0, 8);
        byte[] bArr3 = new byte[(i3 - 8)];
        this.rawContents = bArr3;
        System.arraycopy(bArr, i2 + 8, bArr3, 0, bArr3.length);
        this.reserved = new byte[0];
        this.paragraphStyles = new ArrayList();
        this.charStyles = new ArrayList();
    }

    private int checkTextLength(int i2, int i3, int i4) {
        int i5 = i4 + 1;
        if (i2 + i3 <= i5) {
            return i2;
        }
        Record.logger.log(5, a.a(a.a("Style length of ", i2, " at ", i3, " larger than stated size of "), i4, ", truncating"));
        return i5 - i3;
    }

    private int getCharactersCovered(List<TextPropCollection> list) {
        int i2 = 0;
        for (TextPropCollection textPropCollection : list) {
            i2 += textPropCollection.getCharactersCovered();
        }
        return i2;
    }

    private void updateRawContents() {
        if (this.initialised) {
            ByteArrayOutputStream byteArrayOutputStream = new ByteArrayOutputStream();
            for (TextPropCollection textPropCollection : this.paragraphStyles) {
                textPropCollection.writeOut(byteArrayOutputStream);
            }
            for (TextPropCollection textPropCollection2 : this.charStyles) {
                textPropCollection2.writeOut(byteArrayOutputStream);
            }
            this.rawContents = byteArrayOutputStream.toByteArray();
        }
        LittleEndian.putInt(this._header, 4, this.rawContents.length + this.reserved.length);
    }

    public TextPropCollection addCharacterTextPropCollection(int i2) {
        TextPropCollection textPropCollection = new TextPropCollection(i2, TextPropCollection.TextPropType.character);
        this.charStyles.add(textPropCollection);
        return textPropCollection;
    }

    public TextPropCollection addParagraphTextPropCollection(int i2) {
        TextPropCollection textPropCollection = new TextPropCollection(i2, TextPropCollection.TextPropType.paragraph);
        this.paragraphStyles.add(textPropCollection);
        return textPropCollection;
    }

    public void clearStyles() {
        this.paragraphStyles.clear();
        this.charStyles.clear();
        this.reserved = new byte[0];
        this.initialised = true;
    }

    public List<TextPropCollection> getCharacterStyles() {
        return this.charStyles;
    }

    public int getCharacterTextLengthCovered() {
        return getCharactersCovered(this.charStyles);
    }

    public List<TextPropCollection> getParagraphStyles() {
        return this.paragraphStyles;
    }

    public int getParagraphTextLengthCovered() {
        return getCharactersCovered(this.paragraphStyles);
    }

    @Override // org.apache.poi.hslf.record.Record
    public long getRecordType() {
        return _type;
    }

    public void setCharacterStyles(List<TextPropCollection> list) {
        this.charStyles = list;
    }

    public void setParagraphStyles(List<TextPropCollection> list) {
        this.paragraphStyles = list;
    }

    public void setParentTextSize(int i2) {
        int i3;
        int i4;
        if (!this.initialised) {
            this.paragraphStyles.clear();
            this.charStyles.clear();
            int i5 = 0;
            int i6 = 0;
            int i7 = i2;
            while (true) {
                byte[] bArr = this.rawContents;
                if (i5 < bArr.length && i6 < i7) {
                    int checkTextLength = checkTextLength(LittleEndian.getInt(bArr, i5), i6, i2);
                    i6 += checkTextLength;
                    int i8 = i5 + 4;
                    short s = LittleEndian.getShort(this.rawContents, i8);
                    int i9 = i8 + 2;
                    int i10 = LittleEndian.getInt(this.rawContents, i9);
                    int i11 = i9 + 4;
                    TextPropCollection textPropCollection = new TextPropCollection(checkTextLength, TextPropCollection.TextPropType.paragraph);
                    textPropCollection.setIndentLevel(s);
                    i5 = i11 + textPropCollection.buildTextPropList(i10, this.rawContents, i11);
                    this.paragraphStyles.add(textPropCollection);
                    if (i5 < this.rawContents.length && i6 == i2) {
                        i7++;
                    }
                }
            }
            if (this.rawContents.length > 0 && i6 != (i4 = i2 + 1)) {
                Record.logger.log(5, a.a("Problem reading paragraph style runs: textHandled = ", i6, ", text.size+1 = ", i4));
            }
            int i12 = 0;
            int i13 = i2;
            while (true) {
                byte[] bArr2 = this.rawContents;
                if (i5 < bArr2.length && i12 < i13) {
                    int checkTextLength2 = checkTextLength(LittleEndian.getInt(bArr2, i5), i12, i2);
                    i12 += checkTextLength2;
                    int i14 = i5 + 4;
                    int i15 = LittleEndian.getInt(this.rawContents, i14);
                    int i16 = i14 + 4;
                    TextPropCollection textPropCollection2 = new TextPropCollection(checkTextLength2, TextPropCollection.TextPropType.character);
                    i5 = i16 + textPropCollection2.buildTextPropList(i15, this.rawContents, i16);
                    this.charStyles.add(textPropCollection2);
                    if (i5 < this.rawContents.length && i12 == i2) {
                        i13++;
                    }
                }
            }
            if (this.rawContents.length > 0 && i12 != (i3 = i2 + 1)) {
                Record.logger.log(5, a.a("Problem reading character style runs: textHandled = ", i12, ", text.size+1 = ", i3));
            }
            byte[] bArr3 = this.rawContents;
            if (i5 < bArr3.length) {
                byte[] bArr4 = new byte[(bArr3.length - i5)];
                this.reserved = bArr4;
                System.arraycopy(bArr3, i5, bArr4, 0, bArr4.length);
            }
            this.initialised = true;
        }
    }

    public String toString() {
        StringBuffer a = a.a("StyleTextPropAtom:\n");
        if (!this.initialised) {
            a.append("Uninitialised, dumping Raw Style Data\n");
        } else {
            a.append("Paragraph properties\n");
            for (TextPropCollection textPropCollection : getParagraphStyles()) {
                a.append(textPropCollection);
            }
            a.append("Character properties\n");
            for (TextPropCollection textPropCollection2 : getCharacterStyles()) {
                a.append(textPropCollection2);
            }
            a.append("Reserved bytes\n");
            a.append(HexDump.dump(this.reserved, 0, 0));
        }
        a.append("  original byte stream \n");
        byte[] bArr = this.rawContents;
        byte[] bArr2 = new byte[(bArr.length + this.reserved.length)];
        System.arraycopy(bArr, 0, bArr2, 0, bArr.length);
        byte[] bArr3 = this.reserved;
        System.arraycopy(bArr3, 0, bArr2, this.rawContents.length, bArr3.length);
        a.append(HexDump.dump(bArr2, 0, 0));
        return a.toString();
    }

    @Override // org.apache.poi.hslf.record.Record
    public void writeOut(OutputStream outputStream) {
        updateRawContents();
        outputStream.write(this._header);
        outputStream.write(this.rawContents);
        outputStream.write(this.reserved);
    }

    public StyleTextPropAtom(int i2) {
        byte[] bArr = new byte[8];
        this._header = bArr;
        this.rawContents = new byte[0];
        this.reserved = new byte[0];
        LittleEndian.putInt(bArr, 2, (short) ((int) _type));
        LittleEndian.putInt(this._header, 4, 10);
        this.paragraphStyles = new ArrayList();
        this.charStyles = new ArrayList();
        addParagraphTextPropCollection(i2);
        addCharacterTextPropCollection(i2);
        this.initialised = true;
        try {
            updateRawContents();
        } catch (IOException e2) {
            throw new HSLFException(e2);
        }
    }
}
