package org.apache.poi.hslf.record;

import b.b.a.a.a;
import java.io.OutputStream;
import org.apache.poi.hslf.exceptions.HSLFException;
import org.apache.poi.util.LittleEndian;

public final class TextHeaderAtom extends RecordAtom implements ParentAwareRecord {
    public static final int BODY_TYPE = 1;
    public static final int CENTER_TITLE_TYPE = 6;
    public static final int CENTRE_BODY_TYPE = 5;
    public static final int HALF_BODY_TYPE = 7;
    public static final int NOTES_TYPE = 2;
    public static final int OTHER_TYPE = 4;
    public static final int QUARTER_BODY_TYPE = 8;
    public static final int TITLE_TYPE = 0;
    public static final long _type = ((long) RecordTypes.TextHeaderAtom.typeID);
    public byte[] _header;
    public int index = -1;
    public RecordContainer parentRecord;
    public int textType;

    public TextHeaderAtom(byte[] bArr, int i2, int i3) {
        if (i3 >= 12 || bArr.length - i2 >= 12) {
            byte[] bArr2 = new byte[8];
            this._header = bArr2;
            System.arraycopy(bArr, i2, bArr2, 0, 8);
            this.textType = LittleEndian.getInt(bArr, i2 + 8);
            return;
        }
        StringBuilder b2 = a.b("Not enough data to form a TextHeaderAtom (always 12 bytes long) - found ");
        b2.append(bArr.length - i2);
        throw new HSLFException(b2.toString());
    }

    public int getIndex() {
        return this.index;
    }

    @Override // org.apache.poi.hslf.record.ParentAwareRecord
    public RecordContainer getParentRecord() {
        return this.parentRecord;
    }

    @Override // org.apache.poi.hslf.record.Record
    public long getRecordType() {
        return _type;
    }

    public int getTextType() {
        return this.textType;
    }

    public void setIndex(int i2) {
        this.index = i2;
    }

    @Override // org.apache.poi.hslf.record.ParentAwareRecord
    public void setParentRecord(RecordContainer recordContainer) {
        this.parentRecord = recordContainer;
    }

    public void setTextType(int i2) {
        this.textType = i2;
    }

    @Override // org.apache.poi.hslf.record.Record
    public void writeOut(OutputStream outputStream) {
        outputStream.write(this._header);
        Record.writeLittleEndian(this.textType, outputStream);
    }

    public TextHeaderAtom() {
        byte[] bArr = new byte[8];
        this._header = bArr;
        LittleEndian.putUShort(bArr, 0, 0);
        LittleEndian.putUShort(this._header, 2, (int) _type);
        LittleEndian.putInt(this._header, 4, 4);
        this.textType = 4;
    }
}
