package org.apache.poi.hslf.record;

import b.b.a.a.a;
import java.io.OutputStream;
import org.apache.poi.util.LittleEndian;
import org.apache.poi.util.POILogger;

public final class TextRulerAtom extends RecordAtom {
    public byte[] _data;
    public byte[] _header;
    public int[] bulletOffsets;
    public int defaultTabSize;
    public int numLevels;
    public int[] tabStops;
    public int[] textOffsets;

    public TextRulerAtom() {
        this.bulletOffsets = new int[5];
        this.textOffsets = new int[5];
        byte[] bArr = new byte[8];
        this._header = bArr;
        this._data = new byte[0];
        LittleEndian.putShort(bArr, 2, (short) ((int) getRecordType()));
        LittleEndian.putInt(this._header, 4, this._data.length);
    }

    public static TextRulerAtom getParagraphInstance() {
        return new TextRulerAtom(new byte[]{0, 0, -90, 15, 10, 0, 0, 0, 16, 3, 0, 0, -7, 0, 65, 1, 65, 1}, 0, 18);
    }

    private void read() {
        short s = LittleEndian.getShort(this._data);
        int[] iArr = {1, 0, 2, 3, 8, 4, 9, 5, 10, 6, 11, 7, 12};
        int i2 = 4;
        for (int i3 = 0; i3 < 13; i3++) {
            if (((1 << iArr[i3]) & s) != 0) {
                switch (iArr[i3]) {
                    case 0:
                        this.defaultTabSize = LittleEndian.getShort(this._data, i2);
                        i2 += 2;
                        break;
                    case 1:
                        this.numLevels = LittleEndian.getShort(this._data, i2);
                        i2 += 2;
                        break;
                    case 2:
                        short s2 = LittleEndian.getShort(this._data, i2);
                        i2 += 2;
                        this.tabStops = new int[(s2 * 2)];
                        int i4 = 0;
                        while (true) {
                            int[] iArr2 = this.tabStops;
                            if (i4 >= iArr2.length) {
                                break;
                            } else {
                                iArr2[i4] = LittleEndian.getUShort(this._data, i2);
                                i2 += 2;
                                i4++;
                            }
                        }
                    case 3:
                    case 4:
                    case 5:
                    case 6:
                    case 7:
                        int i5 = LittleEndian.getShort(this._data, i2);
                        i2 += 2;
                        this.bulletOffsets[iArr[i3] - 3] = i5;
                        break;
                    case 8:
                    case 9:
                    case 10:
                    case 11:
                    case 12:
                        int i6 = LittleEndian.getShort(this._data, i2);
                        i2 += 2;
                        this.textOffsets[iArr[i3] - 8] = i6;
                        break;
                }
            }
        }
    }

    public int[] getBulletOffsets() {
        return this.bulletOffsets;
    }

    public int getDefaultTabSize() {
        return this.defaultTabSize;
    }

    public int getNumberOfLevels() {
        return this.numLevels;
    }

    @Override // org.apache.poi.hslf.record.Record
    public long getRecordType() {
        return (long) RecordTypes.TextRulerAtom.typeID;
    }

    public int[] getTabStops() {
        return this.tabStops;
    }

    public int[] getTextOffsets() {
        return this.textOffsets;
    }

    public void setParagraphIndent(short s, short s2) {
        LittleEndian.putShort(this._data, 4, s);
        LittleEndian.putShort(this._data, 6, s2);
        LittleEndian.putShort(this._data, 8, s2);
    }

    @Override // org.apache.poi.hslf.record.Record
    public void writeOut(OutputStream outputStream) {
        outputStream.write(this._header);
        outputStream.write(this._data);
    }

    public TextRulerAtom(byte[] bArr, int i2, int i3) {
        this.bulletOffsets = new int[5];
        this.textOffsets = new int[5];
        byte[] bArr2 = new byte[8];
        this._header = bArr2;
        System.arraycopy(bArr, i2, bArr2, 0, 8);
        int i4 = i3 - 8;
        byte[] bArr3 = new byte[i4];
        this._data = bArr3;
        System.arraycopy(bArr, i2 + 8, bArr3, 0, i4);
        try {
            read();
        } catch (Exception e2) {
            POILogger pOILogger = Record.logger;
            StringBuilder b2 = a.b("Failed to parse TextRulerAtom: ");
            b2.append(e2.getMessage());
            pOILogger.log(7, b2.toString());
        }
    }
}
