package org.apache.poi.hslf.record;

import java.io.ByteArrayOutputStream;
import java.io.IOException;
import java.io.OutputStream;
import java.util.ArrayList;
import org.apache.poi.hslf.exceptions.HSLFException;
import org.apache.poi.util.LittleEndian;
import org.apache.poi.util.LittleEndianByteArrayInputStream;

public final class TextSpecInfoAtom extends RecordAtom {
    public static final /* synthetic */ boolean $assertionsDisabled = false;
    public static final long _type = ((long) RecordTypes.TextSpecInfoAtom.typeID);
    public byte[] _data;
    public byte[] _header;

    public TextSpecInfoAtom() {
        byte[] bArr = new byte[8];
        this._header = bArr;
        LittleEndian.putUInt(bArr, 4, _type);
        reset(1);
    }

    public int getCharactersCovered() {
        int i2 = 0;
        for (TextSpecInfoRun textSpecInfoRun : getTextSpecInfoRuns()) {
            i2 += textSpecInfoRun.getLength();
        }
        return i2;
    }

    @Override // org.apache.poi.hslf.record.Record
    public long getRecordType() {
        return _type;
    }

    public TextSpecInfoRun[] getTextSpecInfoRuns() {
        LittleEndianByteArrayInputStream littleEndianByteArrayInputStream = new LittleEndianByteArrayInputStream(this._data);
        ArrayList arrayList = new ArrayList();
        while (littleEndianByteArrayInputStream.available() > 0) {
            arrayList.add(new TextSpecInfoRun(littleEndianByteArrayInputStream));
        }
        return (TextSpecInfoRun[]) arrayList.toArray(new TextSpecInfoRun[arrayList.size()]);
    }

    public void reset(int i2) {
        TextSpecInfoRun textSpecInfoRun = new TextSpecInfoRun(i2);
        ByteArrayOutputStream byteArrayOutputStream = new ByteArrayOutputStream();
        try {
            textSpecInfoRun.writeOut(byteArrayOutputStream);
            byte[] byteArray = byteArrayOutputStream.toByteArray();
            this._data = byteArray;
            LittleEndian.putInt(this._header, 4, byteArray.length);
        } catch (IOException e2) {
            throw new HSLFException(e2);
        }
    }

    public void setParentSize(int i2) {
        ByteArrayOutputStream byteArrayOutputStream = new ByteArrayOutputStream();
        TextSpecInfoRun[] textSpecInfoRuns = getTextSpecInfoRuns();
        int i3 = 0;
        for (int i4 = 0; i4 < textSpecInfoRuns.length && i3 < i2; i4++) {
            TextSpecInfoRun textSpecInfoRun = textSpecInfoRuns[i4];
            if (textSpecInfoRun.getLength() + i3 > i2 || i4 == textSpecInfoRuns.length - 1) {
                textSpecInfoRun.setLength(i2 - i3);
            }
            i3 += textSpecInfoRun.getLength();
            try {
                textSpecInfoRun.writeOut(byteArrayOutputStream);
            } catch (IOException e2) {
                throw new HSLFException(e2);
            }
        }
        byte[] byteArray = byteArrayOutputStream.toByteArray();
        this._data = byteArray;
        LittleEndian.putInt(this._header, 4, byteArray.length);
    }

    public void setTextSize(int i2) {
        LittleEndian.putInt(this._data, 0, i2);
    }

    @Override // org.apache.poi.hslf.record.Record
    public void writeOut(OutputStream outputStream) {
        outputStream.write(this._header);
        outputStream.write(this._data);
    }

    public TextSpecInfoAtom(byte[] bArr, int i2, int i3) {
        byte[] bArr2 = new byte[8];
        this._header = bArr2;
        System.arraycopy(bArr, i2, bArr2, 0, 8);
        int i4 = i3 - 8;
        byte[] bArr3 = new byte[i4];
        this._data = bArr3;
        System.arraycopy(bArr, i2 + 8, bArr3, 0, i4);
    }
}
