package org.apache.poi.hslf.record;

import java.io.ByteArrayOutputStream;
import java.io.IOException;
import java.io.OutputStream;
import java.util.ArrayList;
import java.util.List;
import org.apache.poi.hslf.exceptions.HSLFException;
import org.apache.poi.hslf.model.textproperties.TextPropCollection;
import org.apache.poi.util.LittleEndian;
import org.apache.poi.util.LittleEndianOutputStream;
import org.apache.poi.util.POILogFactory;
import org.apache.poi.util.POILogger;

public final class TxMasterStyleAtom extends RecordAtom {
    public static final POILogger LOG = POILogFactory.getLogger(TxMasterStyleAtom.class);
    public static final int MAX_INDENT = 5;
    public static long _type = 4003;
    public byte[] _data;
    public byte[] _header;
    public List<TextPropCollection> charStyles;
    public List<TextPropCollection> paragraphStyles;

    public TxMasterStyleAtom(byte[] bArr, int i2, int i3) {
        byte[] bArr2 = new byte[8];
        this._header = bArr2;
        System.arraycopy(bArr, i2, bArr2, 0, 8);
        byte[] bArr3 = new byte[(i3 - 8)];
        this._data = bArr3;
        System.arraycopy(bArr, i2 + 8, bArr3, 0, bArr3.length);
        try {
            init();
        } catch (Exception e2) {
            LOG.log(5, "Exception when reading available styles", e2);
        }
    }

    public List<TextPropCollection> getCharacterStyles() {
        return this.charStyles;
    }

    public List<TextPropCollection> getParagraphStyles() {
        return this.paragraphStyles;
    }

    @Override // org.apache.poi.hslf.record.Record
    public long getRecordType() {
        return _type;
    }

    public int getTextType() {
        return LittleEndian.getShort(this._header, 0) >> 4;
    }

    public void init() {
        int textType = getTextType();
        short s = LittleEndian.getShort(this._data, 0);
        this.paragraphStyles = new ArrayList(s);
        this.charStyles = new ArrayList(s);
        int i2 = 2;
        for (short s2 = 0; s2 < s; s2 = (short) (s2 + 1)) {
            TextPropCollection textPropCollection = new TextPropCollection(0, TextPropCollection.TextPropType.paragraph);
            if (textType >= 5) {
                textPropCollection.setIndentLevel(LittleEndian.getShort(this._data, i2));
                i2 += 2;
            } else {
                textPropCollection.setIndentLevel(-1);
            }
            int i3 = LittleEndian.getInt(this._data, i2);
            int i4 = i2 + 4;
            int buildTextPropList = textPropCollection.buildTextPropList(i3, this._data, i4) + i4;
            this.paragraphStyles.add(textPropCollection);
            int i5 = LittleEndian.getInt(this._data, buildTextPropList);
            int i6 = buildTextPropList + 4;
            TextPropCollection textPropCollection2 = new TextPropCollection(0, TextPropCollection.TextPropType.character);
            i2 = textPropCollection2.buildTextPropList(i5, this._data, i6) + i6;
            this.charStyles.add(textPropCollection2);
        }
    }

    public void updateStyles() {
        int textType = getTextType();
        try {
            ByteArrayOutputStream byteArrayOutputStream = new ByteArrayOutputStream();
            LittleEndianOutputStream littleEndianOutputStream = new LittleEndianOutputStream(byteArrayOutputStream);
            int size = this.paragraphStyles.size();
            littleEndianOutputStream.writeShort(size);
            TextPropCollection textPropCollection = new TextPropCollection(0, TextPropCollection.TextPropType.paragraph);
            TextPropCollection textPropCollection2 = new TextPropCollection(0, TextPropCollection.TextPropType.character);
            for (int i2 = 0; i2 < size; i2++) {
                textPropCollection.copy(this.paragraphStyles.get(i2));
                textPropCollection2.copy(this.charStyles.get(i2));
                if (textType >= 5) {
                    littleEndianOutputStream.writeShort(textPropCollection.getIndentLevel());
                }
                textPropCollection.setIndentLevel(-1);
                textPropCollection.writeOut(byteArrayOutputStream, true);
                textPropCollection2.writeOut(byteArrayOutputStream, true);
            }
            this._data = byteArrayOutputStream.toByteArray();
            littleEndianOutputStream.close();
            LittleEndian.putInt(this._header, 4, this._data.length);
        } catch (IOException e2) {
            throw new HSLFException("error in updating master style properties", e2);
        }
    }

    @Override // org.apache.poi.hslf.record.Record
    public void writeOut(OutputStream outputStream) {
        outputStream.write(this._header);
        outputStream.write(this._data);
    }
}
