package org.apache.poi.hslf.record;

import b.b.a.a.a;
import java.io.OutputStream;
import java.util.Map;
import org.apache.poi.hslf.exceptions.HSLFException;
import org.apache.poi.util.LittleEndian;

public final class UserEditAtom extends PositionDependentRecordAtom {
    public static final /* synthetic */ boolean $assertionsDisabled = false;
    public static final int LAST_VIEW_NONE = 0;
    public static final int LAST_VIEW_NOTES = 3;
    public static final int LAST_VIEW_OUTLINE_VIEW = 2;
    public static final int LAST_VIEW_SLIDE_VIEW = 1;
    public static long _type = 4085;
    public byte[] _header;
    public int docPersistRef;
    public int encryptSessionPersistIdRef = -1;
    public int lastUserEditAtomOffset;
    public short lastViewType;
    public int lastViewedSlideID;
    public int maxPersistWritten;
    public int persistPointersOffset;
    public int pptVersion;
    public short unused;

    public UserEditAtom(byte[] bArr, int i2, int i3) {
        i3 = i3 < 34 ? 34 : i3;
        byte[] bArr2 = new byte[8];
        this._header = bArr2;
        System.arraycopy(bArr, i2, bArr2, 0, 8);
        int i4 = i2 + 8;
        this.lastViewedSlideID = LittleEndian.getInt(bArr, i4);
        int i5 = i4 + 4;
        this.pptVersion = LittleEndian.getInt(bArr, i5);
        int i6 = i5 + 4;
        this.lastUserEditAtomOffset = LittleEndian.getInt(bArr, i6);
        int i7 = i6 + 4;
        this.persistPointersOffset = LittleEndian.getInt(bArr, i7);
        int i8 = i7 + 4;
        this.docPersistRef = LittleEndian.getInt(bArr, i8);
        int i9 = i8 + 4;
        this.maxPersistWritten = LittleEndian.getInt(bArr, i9);
        int i10 = i9 + 4;
        this.lastViewType = LittleEndian.getShort(bArr, i10);
        int i11 = i10 + 2;
        this.unused = LittleEndian.getShort(bArr, i11);
        int i12 = i11 + 2;
        if (i12 - i2 < i3) {
            this.encryptSessionPersistIdRef = LittleEndian.getInt(bArr, i12);
        }
    }

    public int getDocPersistRef() {
        return this.docPersistRef;
    }

    public int getEncryptSessionPersistIdRef() {
        return this.encryptSessionPersistIdRef;
    }

    public int getLastUserEditAtomOffset() {
        return this.lastUserEditAtomOffset;
    }

    public short getLastViewType() {
        return this.lastViewType;
    }

    public int getLastViewedSlideID() {
        return this.lastViewedSlideID;
    }

    public int getMaxPersistWritten() {
        return this.maxPersistWritten;
    }

    public int getPersistPointersOffset() {
        return this.persistPointersOffset;
    }

    @Override // org.apache.poi.hslf.record.Record
    public long getRecordType() {
        return _type;
    }

    public void setEncryptSessionPersistIdRef(int i2) {
        this.encryptSessionPersistIdRef = i2;
        LittleEndian.putInt(this._header, 4, i2 == -1 ? 28 : 32);
    }

    public void setLastUserEditAtomOffset(int i2) {
        this.lastUserEditAtomOffset = i2;
    }

    public void setLastViewType(short s) {
        this.lastViewType = s;
    }

    public void setMaxPersistWritten(int i2) {
        this.maxPersistWritten = i2;
    }

    public void setPersistPointersOffset(int i2) {
        this.persistPointersOffset = i2;
    }

    @Override // org.apache.poi.hslf.record.PositionDependentRecordAtom, org.apache.poi.hslf.record.PositionDependentRecord
    public void updateOtherRecordReferences(Map<Integer, Integer> map) {
        int i2 = this.lastUserEditAtomOffset;
        if (i2 != 0) {
            Integer num = map.get(Integer.valueOf(i2));
            if (num != null) {
                this.lastUserEditAtomOffset = num.intValue();
            } else {
                StringBuilder b2 = a.b("Couldn't find the new location of the UserEditAtom that used to be at ");
                b2.append(this.lastUserEditAtomOffset);
                throw new HSLFException(b2.toString());
            }
        }
        Integer num2 = map.get(Integer.valueOf(this.persistPointersOffset));
        if (num2 != null) {
            this.persistPointersOffset = num2.intValue();
            return;
        }
        StringBuilder b3 = a.b("Couldn't find the new location of the PersistPtr that used to be at ");
        b3.append(this.persistPointersOffset);
        throw new HSLFException(b3.toString());
    }

    @Override // org.apache.poi.hslf.record.Record
    public void writeOut(OutputStream outputStream) {
        outputStream.write(this._header);
        Record.writeLittleEndian(this.lastViewedSlideID, outputStream);
        Record.writeLittleEndian(this.pptVersion, outputStream);
        Record.writeLittleEndian(this.lastUserEditAtomOffset, outputStream);
        Record.writeLittleEndian(this.persistPointersOffset, outputStream);
        Record.writeLittleEndian(this.docPersistRef, outputStream);
        Record.writeLittleEndian(this.maxPersistWritten, outputStream);
        Record.writeLittleEndian(this.lastViewType, outputStream);
        Record.writeLittleEndian(this.unused, outputStream);
        int i2 = this.encryptSessionPersistIdRef;
        if (i2 != -1) {
            Record.writeLittleEndian(i2, outputStream);
        }
    }
}
