package org.apache.poi.hslf.usermodel;

import org.apache.poi.ddf.EscherContainerRecord;
import org.apache.poi.ddf.EscherProperties;
import org.apache.poi.sl.usermodel.AutoShape;
import org.apache.poi.sl.usermodel.ShapeContainer;
import org.apache.poi.sl.usermodel.ShapeType;
import org.apache.poi.sl.usermodel.VerticalAlignment;

public class HSLFAutoShape extends HSLFTextShape implements AutoShape<HSLFShape, HSLFTextParagraph> {
    public HSLFAutoShape(EscherContainerRecord escherContainerRecord, ShapeContainer<HSLFShape, HSLFTextParagraph> shapeContainer) {
        super(escherContainerRecord, shapeContainer);
    }

    public EscherContainerRecord createSpContainer(ShapeType shapeType, boolean z) {
        EscherContainerRecord createSpContainer = super.createSpContainer(z);
        setShapeType(shapeType);
        setEscherProperty(127, 262144);
        setEscherProperty(EscherProperties.FILL__FILLCOLOR, 134217732);
        setEscherProperty(EscherProperties.FILL__FILLCOLOR, 134217732);
        setEscherProperty(EscherProperties.FILL__FILLBACKCOLOR, 134217728);
        setEscherProperty(EscherProperties.FILL__NOFILLHITTEST, 1048592);
        setEscherProperty(EscherProperties.LINESTYLE__COLOR, 134217729);
        setEscherProperty(EscherProperties.LINESTYLE__NOLINEDRAWDASH, 524296);
        setEscherProperty(513, 134217730);
        return createSpContainer;
    }

    public int getAdjustmentValue(int i2) {
        if (i2 >= 0 && i2 <= 9) {
            return getEscherProperty((short) (i2 + 327));
        }
        throw new IllegalArgumentException("The index of an adjustment value must be in the [0, 9] range");
    }

    public void setAdjustmentValue(int i2, int i3) {
        if (i2 < 0 || i2 > 9) {
            throw new IllegalArgumentException("The index of an adjustment value must be in the [0, 9] range");
        }
        setEscherProperty((short) (i2 + 327), i3);
    }

    @Override // org.apache.poi.hslf.usermodel.HSLFTextShape
    public void setDefaultTextProperties(HSLFTextParagraph hSLFTextParagraph) {
        setVerticalAlignment(VerticalAlignment.MIDDLE);
        setHorizontalCentered(true);
        setWordWrap(false);
    }

    public HSLFAutoShape(ShapeType shapeType, ShapeContainer<HSLFShape, HSLFTextParagraph> shapeContainer) {
        super(null, shapeContainer);
        createSpContainer(shapeType, shapeContainer instanceof HSLFGroupShape);
    }

    public HSLFAutoShape(ShapeType shapeType) {
        this(shapeType, (ShapeContainer<HSLFShape, HSLFTextParagraph>) null);
    }
}
