package org.apache.poi.hslf.usermodel;

import b.b.a.a.a;
import java.awt.Color;
import java.io.ByteArrayInputStream;
import java.io.InputStream;
import java.util.Iterator;
import java.util.List;
import org.apache.poi.ddf.AbstractEscherOptRecord;
import org.apache.poi.ddf.EscherArrayProperty;
import org.apache.poi.ddf.EscherBSERecord;
import org.apache.poi.ddf.EscherColorRef;
import org.apache.poi.ddf.EscherContainerRecord;
import org.apache.poi.ddf.EscherProperties;
import org.apache.poi.ddf.EscherRecord;
import org.apache.poi.ddf.EscherSimpleProperty;
import org.apache.poi.hslf.record.RecordTypes;
import org.apache.poi.sl.draw.DrawPaint;
import org.apache.poi.sl.usermodel.ColorStyle;
import org.apache.poi.sl.usermodel.FillStyle;
import org.apache.poi.sl.usermodel.PaintStyle;
import org.apache.poi.util.BitField;
import org.apache.poi.util.BitFieldFactory;
import org.apache.poi.util.LittleEndian;
import org.apache.poi.util.POILogFactory;
import org.apache.poi.util.POILogger;
import org.apache.poi.util.Units;

public final class HSLFFill {
    public static final int FILL_BACKGROUND = 9;
    public static final BitField FILL_FILLED = BitFieldFactory.getInstance(16);
    public static final BitField FILL_FILL_SHAPE = BitFieldFactory.getInstance(4);
    public static final BitField FILL_FILL_USE_RECT = BitFieldFactory.getInstance(2);
    public static final BitField FILL_HIT_TEST_FILL = BitFieldFactory.getInstance(8);
    public static final BitField FILL_NO_FILL_HIT_TEST = BitFieldFactory.getInstance(1);
    public static final int FILL_PATTERN = 1;
    public static final int FILL_PICTURE = 3;
    public static final BitField FILL_RECOLOR_FILL_AS_PICTURE = BitFieldFactory.getInstance(64);
    public static final int FILL_SHADE = 4;
    public static final int FILL_SHADE_CENTER = 5;
    public static final int FILL_SHADE_SCALE = 7;
    public static final int FILL_SHADE_SHAPE = 6;
    public static final int FILL_SHADE_TITLE = 8;
    public static final int FILL_SOLID = 0;
    public static final int FILL_TEXTURE = 2;
    public static final BitField FILL_USE_FILLED = BitFieldFactory.getInstance(1048576);
    public static final BitField FILL_USE_FILL_SHAPE = BitFieldFactory.getInstance(262144);
    public static final BitField FILL_USE_FILL_USE_RECT = BitFieldFactory.getInstance(131072);
    public static final BitField FILL_USE_HIT_TEST_FILL = BitFieldFactory.getInstance(524288);
    public static final BitField FILL_USE_NO_FILL_HIT_TEST = BitFieldFactory.getInstance(65536);
    public static final BitField FILL_USE_RECOLOR_FILL_AS_PICTURE = BitFieldFactory.getInstance(4194304);
    public static final BitField FILL_USE_SHAPE_ANCHOR = BitFieldFactory.getInstance(32);
    public static final BitField FILL_USE_USE_SHAPE_ANCHOR = BitFieldFactory.getInstance(2097152);
    public static final POILogger LOG = POILogFactory.getLogger(HSLFFill.class);
    public HSLFShape shape;

    public HSLFFill(HSLFShape hSLFShape) {
        this.shape = hSLFShape;
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private PaintStyle.GradientPaint getGradientPaint(final PaintStyle.GradientPaint.GradientType gradientType) {
        final int i2;
        int i3;
        final EscherArrayProperty escherArrayProperty = (EscherArrayProperty) HSLFShape.getEscherProperty(this.shape.getEscherOptRecord(), 407);
        if (escherArrayProperty == null) {
            i2 = 0;
        } else {
            i2 = escherArrayProperty.getNumberOfElementsInArray();
        }
        EscherSimpleProperty escherSimpleProperty = (EscherSimpleProperty) HSLFShape.getEscherProperty((AbstractEscherOptRecord) this.shape.getEscherChild(RecordTypes.EscherUserDefined), 447);
        if (escherSimpleProperty == null) {
            i3 = 0;
        } else {
            i3 = escherSimpleProperty.getPropertyValue();
        }
        final boolean z = FILL_USE_USE_SHAPE_ANCHOR.isSet(i3) && FILL_USE_SHAPE_ANCHOR.isSet(i3);
        return new PaintStyle.GradientPaint() {
            /* class org.apache.poi.hslf.usermodel.HSLFFill.AnonymousClass2 */

            private ColorStyle wrapColor(Color color) {
                if (color == null) {
                    return null;
                }
                return DrawPaint.createSolidPaint(color).getSolidColor();
            }

            @Override // org.apache.poi.sl.usermodel.PaintStyle.GradientPaint
            public double getGradientAngle() {
                return 90.0d - Units.fixedPointToDouble(HSLFFill.this.shape.getEscherProperty(EscherProperties.FILL__ANGLE));
            }

            @Override // org.apache.poi.sl.usermodel.PaintStyle.GradientPaint
            public ColorStyle[] getGradientColors() {
                int i2 = i2;
                if (i2 == 0) {
                    return new ColorStyle[]{wrapColor(HSLFFill.this.getBackgroundColor()), wrapColor(HSLFFill.this.getForegroundColor())};
                }
                ColorStyle[] colorStyleArr = new ColorStyle[i2];
                Iterator<byte[]> it = escherArrayProperty.iterator();
                int i3 = 0;
                while (it.hasNext()) {
                    colorStyleArr[i3] = wrapColor(HSLFFill.this.shape.getColor(new EscherColorRef(it.next(), 0, 4)));
                    i3++;
                }
                return colorStyleArr;
            }

            @Override // org.apache.poi.sl.usermodel.PaintStyle.GradientPaint
            public float[] getGradientFractions() {
                int i2 = i2;
                if (i2 == 0) {
                    return new float[]{0.0f, 1.0f};
                }
                float[] fArr = new float[i2];
                int i3 = 0;
                Iterator<byte[]> it = escherArrayProperty.iterator();
                while (it.hasNext()) {
                    fArr[i3] = (float) Units.fixedPointToDouble(LittleEndian.getInt(it.next(), 4));
                    i3++;
                }
                return fArr;
            }

            @Override // org.apache.poi.sl.usermodel.PaintStyle.GradientPaint
            public PaintStyle.GradientPaint.GradientType getGradientType() {
                return gradientType;
            }

            @Override // org.apache.poi.sl.usermodel.PaintStyle.GradientPaint
            public boolean isRotatedWithShape() {
                return z;
            }
        };
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private PaintStyle.TexturePaint getTexturePaint() {
        final HSLFPictureData pictureData = getPictureData();
        if (pictureData == null) {
            return null;
        }
        return new PaintStyle.TexturePaint() {
            /* class org.apache.poi.hslf.usermodel.HSLFFill.AnonymousClass3 */

            @Override // org.apache.poi.sl.usermodel.PaintStyle.TexturePaint
            public int getAlpha() {
                return (int) (HSLFFill.this.shape.getAlpha(EscherProperties.FILL__FILLOPACITY) * 100000.0d);
            }

            @Override // org.apache.poi.sl.usermodel.PaintStyle.TexturePaint
            public String getContentType() {
                return pictureData.getContentType();
            }

            @Override // org.apache.poi.sl.usermodel.PaintStyle.TexturePaint
            public InputStream getImageData() {
                return new ByteArrayInputStream(pictureData.getData());
            }
        };
    }

    public void afterInsert(HSLFSheet hSLFSheet) {
        EscherBSERecord escherBSERecord;
        EscherSimpleProperty escherSimpleProperty = (EscherSimpleProperty) HSLFShape.getEscherProperty(this.shape.getEscherOptRecord(), 390);
        if (escherSimpleProperty != null && (escherBSERecord = getEscherBSERecord(escherSimpleProperty.getPropertyValue())) != null) {
            escherBSERecord.setRef(escherBSERecord.getRef() + 1);
        }
    }

    public Color getBackgroundColor() {
        int i2;
        EscherSimpleProperty escherSimpleProperty = (EscherSimpleProperty) HSLFShape.getEscherProperty(this.shape.getEscherOptRecord(), 447);
        if (escherSimpleProperty == null) {
            i2 = 0;
        } else {
            i2 = escherSimpleProperty.getPropertyValue();
        }
        if (!FILL_USE_FILLED.isSet(i2) || FILL_FILLED.isSet(i2)) {
            return this.shape.getColor(EscherProperties.FILL__FILLBACKCOLOR, EscherProperties.FILL__FILLOPACITY, -1);
        }
        return null;
    }

    /* JADX WARN: Type inference failed for: r0v1, types: [org.apache.poi.hslf.usermodel.HSLFSheet] */
    /* JADX WARN: Type inference failed for: r0v2, types: [org.apache.poi.hslf.usermodel.HSLFSlideShow] */
    /* JADX WARNING: Unknown variable types count: 2 */
    public EscherBSERecord getEscherBSERecord(int i2) {
        ?? sheet = this.shape.getSheet();
        if (sheet == 0) {
            LOG.log(1, "Fill has not yet been assigned to a sheet");
            return null;
        }
        EscherContainerRecord escherContainerRecord = (EscherContainerRecord) HSLFShape.getEscherChild(sheet.getSlideShow().getDocumentRecord().getPPDrawingGroup().getDggContainer(), -4095);
        if (escherContainerRecord != null) {
            return (EscherBSERecord) escherContainerRecord.getChildRecords().get(i2 - 1);
        }
        LOG.log(1, "EscherContainerRecord.BSTORE_CONTAINER was not found ");
        return null;
    }

    public FillStyle getFillStyle() {
        return new FillStyle() {
            /* class org.apache.poi.hslf.usermodel.HSLFFill.AnonymousClass1 */

            @Override // org.apache.poi.sl.usermodel.FillStyle
            public PaintStyle getPaint() {
                int fillType = HSLFFill.this.getFillType();
                if (fillType == 0) {
                    return DrawPaint.createSolidPaint(HSLFFill.this.getForegroundColor());
                }
                switch (fillType) {
                    case 3:
                        return HSLFFill.this.getTexturePaint();
                    case 4:
                    case 7:
                        return HSLFFill.this.getGradientPaint(PaintStyle.GradientPaint.GradientType.linear);
                    case 5:
                    case 8:
                        return HSLFFill.this.getGradientPaint(PaintStyle.GradientPaint.GradientType.circular);
                    case 6:
                        return HSLFFill.this.getGradientPaint(PaintStyle.GradientPaint.GradientType.shape);
                    default:
                        HSLFFill.LOG.log(5, a.c("unsuported fill type: ", fillType));
                        return null;
                }
            }
        };
    }

    public int getFillType() {
        EscherSimpleProperty escherSimpleProperty = (EscherSimpleProperty) HSLFShape.getEscherProperty(this.shape.getEscherOptRecord(), 384);
        if (escherSimpleProperty == null) {
            return 0;
        }
        return escherSimpleProperty.getPropertyValue();
    }

    public Color getForegroundColor() {
        int i2;
        EscherSimpleProperty escherSimpleProperty = (EscherSimpleProperty) HSLFShape.getEscherProperty(this.shape.getEscherOptRecord(), 447);
        if (escherSimpleProperty == null) {
            i2 = 0;
        } else {
            i2 = escherSimpleProperty.getPropertyValue();
        }
        if (!FILL_USE_FILLED.isSet(i2) || FILL_FILLED.isSet(i2)) {
            return this.shape.getColor(EscherProperties.FILL__FILLCOLOR, EscherProperties.FILL__FILLOPACITY, -1);
        }
        return null;
    }

    /* JADX WARN: Type inference failed for: r2v1, types: [org.apache.poi.hslf.usermodel.HSLFSheet] */
    /* JADX WARN: Type inference failed for: r2v2, types: [org.apache.poi.hslf.usermodel.HSLFSlideShow] */
    /* JADX WARNING: Unknown variable types count: 2 */
    public HSLFPictureData getPictureData() {
        EscherSimpleProperty escherSimpleProperty = (EscherSimpleProperty) HSLFShape.getEscherProperty(this.shape.getEscherOptRecord(), 390);
        if (escherSimpleProperty == null) {
            return null;
        }
        ?? slideShow = this.shape.getSheet().getSlideShow();
        List<HSLFPictureData> pictureData = slideShow.getPictureData();
        List<EscherRecord> childRecords = ((EscherContainerRecord) HSLFShape.getEscherChild(slideShow.getDocumentRecord().getPPDrawingGroup().getDggContainer(), -4095)).getChildRecords();
        int propertyValue = escherSimpleProperty.getPropertyValue();
        if (propertyValue == 0) {
            LOG.log(5, "no reference to picture data found ");
        } else {
            EscherBSERecord escherBSERecord = (EscherBSERecord) childRecords.get(propertyValue - 1);
            for (HSLFPictureData hSLFPictureData : pictureData) {
                if (hSLFPictureData.getOffset() == escherBSERecord.getOffset()) {
                    return hSLFPictureData;
                }
            }
        }
        return null;
    }

    public void setBackgroundColor(Color color) {
        AbstractEscherOptRecord escherOptRecord = this.shape.getEscherOptRecord();
        if (color == null) {
            HSLFShape.setEscherProperty(escherOptRecord, EscherProperties.FILL__FILLBACKCOLOR, -1);
        } else {
            HSLFShape.setEscherProperty(escherOptRecord, EscherProperties.FILL__FILLBACKCOLOR, new Color(color.getBlue(), color.getGreen(), color.getRed(), 0).getRGB());
        }
    }

    public void setFillType(int i2) {
        HSLFShape.setEscherProperty(this.shape.getEscherOptRecord(), EscherProperties.FILL__FILLTYPE, i2);
    }

    public void setForegroundColor(Color color) {
        int i2;
        AbstractEscherOptRecord escherOptRecord = this.shape.getEscherOptRecord();
        escherOptRecord.removeEscherProperty(386);
        escherOptRecord.removeEscherProperty(385);
        boolean z = false;
        if (color != null) {
            HSLFShape.setEscherProperty(escherOptRecord, EscherProperties.FILL__FILLCOLOR, new Color(color.getBlue(), color.getGreen(), color.getRed(), 0).getRGB());
            int alpha = color.getAlpha();
            if (alpha < 255) {
                HSLFShape.setEscherProperty(escherOptRecord, EscherProperties.FILL__FILLOPACITY, Units.doubleToFixedPoint(((double) alpha) / 255.0d));
            }
        }
        EscherSimpleProperty escherSimpleProperty = (EscherSimpleProperty) HSLFShape.getEscherProperty(escherOptRecord, 447);
        if (escherSimpleProperty == null) {
            i2 = 0;
        } else {
            i2 = escherSimpleProperty.getPropertyValue();
        }
        int i3 = FILL_FILLED.setBoolean(i2, color != null);
        BitField bitField = FILL_NO_FILL_HIT_TEST;
        if (color != null) {
            z = true;
        }
        HSLFShape.setEscherProperty(escherOptRecord, EscherProperties.FILL__NOFILLHITTEST, FILL_FILL_SHAPE.clear(FILL_USE_NO_FILL_HIT_TEST.set(FILL_USE_FILL_SHAPE.set(FILL_USE_FILLED.set(bitField.setBoolean(i3, z))))));
    }

    public void setPictureData(HSLFPictureData hSLFPictureData) {
        int i2;
        EscherBSERecord escherBSERecord;
        AbstractEscherOptRecord escherOptRecord = this.shape.getEscherOptRecord();
        if (hSLFPictureData == null) {
            i2 = 0;
        } else {
            i2 = hSLFPictureData.getIndex();
        }
        HSLFShape.setEscherProperty(escherOptRecord, 16774, i2);
        if (hSLFPictureData != null && this.shape.getSheet() != null && (escherBSERecord = getEscherBSERecord(hSLFPictureData.getIndex())) != null) {
            escherBSERecord.setRef(escherBSERecord.getRef() + 1);
        }
    }
}
