package org.apache.poi.hslf.usermodel;

import b.b.a.a.a;
import java.awt.geom.Rectangle2D;
import java.util.ArrayList;
import java.util.Iterator;
import java.util.List;
import org.apache.poi.ddf.EscherChildAnchorRecord;
import org.apache.poi.ddf.EscherClientAnchorRecord;
import org.apache.poi.ddf.EscherContainerRecord;
import org.apache.poi.ddf.EscherRecord;
import org.apache.poi.ddf.EscherSpRecord;
import org.apache.poi.ddf.EscherSpgrRecord;
import org.apache.poi.sl.usermodel.GroupShape;
import org.apache.poi.sl.usermodel.PictureData;
import org.apache.poi.sl.usermodel.ShapeContainer;
import org.apache.poi.sl.usermodel.ShapeType;
import org.apache.poi.ss.formula.functions.NumericFunction;
import org.apache.poi.util.LittleEndian;
import org.apache.poi.util.POILogFactory;
import org.apache.poi.util.POILogger;
import org.apache.poi.util.Units;

public class HSLFGroupShape extends HSLFShape implements HSLFShapeContainer, GroupShape<HSLFShape, HSLFTextParagraph> {
    public static final POILogger LOG = POILogFactory.getLogger(HSLFGroupShape.class);

    public HSLFGroupShape() {
        this(null, null);
        createSpContainer(false);
    }

    @Override // org.apache.poi.hslf.usermodel.HSLFShape
    public EscherContainerRecord createSpContainer(boolean z) {
        EscherContainerRecord createSpContainer = super.createSpContainer(z);
        createSpContainer.setRecordId(EscherContainerRecord.SPGR_CONTAINER);
        EscherContainerRecord escherContainerRecord = new EscherContainerRecord();
        escherContainerRecord.setRecordId(EscherContainerRecord.SP_CONTAINER);
        escherContainerRecord.setOptions(15);
        EscherSpgrRecord escherSpgrRecord = new EscherSpgrRecord();
        escherSpgrRecord.setOptions(1);
        escherContainerRecord.addChildRecord(escherSpgrRecord);
        EscherSpRecord escherSpRecord = new EscherSpRecord();
        escherSpRecord.setOptions((short) ((ShapeType.NOT_PRIMITIVE.nativeId << 4) + 2));
        escherSpRecord.setFlags(513);
        escherContainerRecord.addChildRecord(escherSpRecord);
        escherContainerRecord.addChildRecord(new EscherClientAnchorRecord());
        createSpContainer.addChildRecord(escherContainerRecord);
        return createSpContainer;
    }

    @Override // org.apache.poi.hslf.usermodel.HSLFShape, org.apache.poi.sl.usermodel.Shape, org.apache.poi.sl.usermodel.PlaceableShape
    public Rectangle2D getAnchor() {
        int i2;
        int i3;
        int i4;
        int i5;
        EscherClientAnchorRecord escherClientAnchorRecord = (EscherClientAnchorRecord) getEscherChild(-4080);
        if (escherClientAnchorRecord == null) {
            LOG.log(3, "EscherClientAnchorRecord was not found for shape group. Searching for EscherChildAnchorRecord.");
            EscherChildAnchorRecord escherChildAnchorRecord = (EscherChildAnchorRecord) getEscherChild(-4081);
            i4 = escherChildAnchorRecord.getDx1();
            i3 = escherChildAnchorRecord.getDy1();
            i2 = escherChildAnchorRecord.getDx2();
            i5 = escherChildAnchorRecord.getDy2();
        } else {
            i4 = escherClientAnchorRecord.getCol1();
            i3 = escherClientAnchorRecord.getFlag();
            i2 = escherClientAnchorRecord.getDx1();
            i5 = escherClientAnchorRecord.getRow1();
        }
        return new Rectangle2D.Double(i4 == -1 ? -1.0d : Units.masterToPoints(i4), i3 == -1 ? -1.0d : Units.masterToPoints(i3), i2 == -1 ? -1.0d : Units.masterToPoints(i2 - i4), i5 == -1 ? -1.0d : Units.masterToPoints(i5 - i3));
    }

    @Override // org.apache.poi.hslf.usermodel.HSLFShape
    public <T extends EscherRecord> T getEscherChild(int i2) {
        return (T) ((EscherContainerRecord) getSpContainer().getChild(0)).getChildById((short) i2);
    }

    public HSLFHyperlink getHyperlink() {
        return null;
    }

    @Override // org.apache.poi.sl.usermodel.GroupShape
    public Rectangle2D getInteriorAnchor() {
        EscherSpgrRecord escherSpgrRecord = (EscherSpgrRecord) getEscherChild(-4087);
        double masterToPoints = Units.masterToPoints(escherSpgrRecord.getRectX1());
        double masterToPoints2 = Units.masterToPoints(escherSpgrRecord.getRectY1());
        return new Rectangle2D.Double(masterToPoints, masterToPoints2, Units.masterToPoints(escherSpgrRecord.getRectX2()) - masterToPoints, Units.masterToPoints(escherSpgrRecord.getRectY2()) - masterToPoints2);
    }

    @Override // org.apache.poi.hslf.usermodel.HSLFShape
    public ShapeType getShapeType() {
        return ShapeType.forId(((EscherSpRecord) getEscherChild(-4086)).getOptions() >> 4, false);
    }

    /* JADX DEBUG: Multi-variable search result rejected for r5v7, resolved type: org.apache.poi.hslf.usermodel.HSLFShape */
    /* JADX WARN: Multi-variable type inference failed */
    /* JADX WARN: Type inference failed for: r6v2, types: [org.apache.poi.hslf.usermodel.HSLFSheet] */
    /* JADX WARNING: Unknown variable types count: 1 */
    @Override // org.apache.poi.sl.usermodel.ShapeContainer
    public List<HSLFShape> getShapes() {
        ArrayList arrayList = new ArrayList();
        Iterator<EscherRecord> it = getSpContainer().iterator();
        boolean z = true;
        while (it.hasNext()) {
            EscherRecord next = it.next();
            if (z) {
                z = false;
            } else if (next instanceof EscherContainerRecord) {
                HSLFShape createShape = HSLFShapeFactory.createShape((EscherContainerRecord) next, this);
                createShape.setSheet(getSheet());
                arrayList.add(createShape);
            } else {
                POILogger pOILogger = LOG;
                StringBuilder b2 = a.b("Shape contained non container escher record, was ");
                b2.append(next.getClass().getName());
                pOILogger.log(7, b2.toString());
            }
        }
        return arrayList;
    }

    @Override // java.lang.Iterable
    public Iterator<HSLFShape> iterator() {
        return getShapes().iterator();
    }

    public void moveAndScale(Rectangle2D rectangle2D) {
        Rectangle2D anchor = getAnchor();
        double width = anchor.getWidth();
        double d2 = NumericFunction.LOG_10_TO_BASE_e;
        double width2 = width == NumericFunction.LOG_10_TO_BASE_e ? 0.0d : rectangle2D.getWidth() / anchor.getWidth();
        if (anchor.getHeight() != NumericFunction.LOG_10_TO_BASE_e) {
            d2 = rectangle2D.getHeight() / anchor.getHeight();
        }
        setExteriorAnchor(rectangle2D);
        for (HSLFShape hSLFShape : getShapes()) {
            Rectangle2D anchor2 = hSLFShape.getAnchor();
            hSLFShape.setAnchor(new Rectangle2D.Double(((anchor2.getX() - anchor.getX()) * width2) + rectangle2D.getX(), ((anchor2.getY() - anchor.getY()) * d2) + rectangle2D.getY(), anchor2.getWidth() * width2, anchor2.getHeight() * d2));
        }
    }

    @Override // org.apache.poi.hslf.usermodel.HSLFShape, org.apache.poi.sl.usermodel.PlaceableShape
    public void setAnchor(Rectangle2D rectangle2D) {
        EscherClientAnchorRecord escherClientAnchorRecord = (EscherClientAnchorRecord) getEscherChild(-4080);
        if ((escherClientAnchorRecord.getDx1() == 0 && escherClientAnchorRecord.getRow1() == 0) ? false : true) {
            moveAndScale(rectangle2D);
        } else {
            setExteriorAnchor(rectangle2D);
        }
    }

    public void setExteriorAnchor(Rectangle2D rectangle2D) {
        EscherClientAnchorRecord escherClientAnchorRecord = (EscherClientAnchorRecord) getEscherChild(-4080);
        byte[] bArr = new byte[16];
        LittleEndian.putUShort(bArr, 0, 0);
        LittleEndian.putUShort(bArr, 2, 0);
        LittleEndian.putInt(bArr, 4, 8);
        escherClientAnchorRecord.fillFields(bArr, 0, null);
        escherClientAnchorRecord.setFlag((short) Units.pointsToMaster(rectangle2D.getY()));
        escherClientAnchorRecord.setCol1((short) Units.pointsToMaster(rectangle2D.getX()));
        escherClientAnchorRecord.setDx1((short) Units.pointsToMaster(rectangle2D.getWidth() + rectangle2D.getX()));
        escherClientAnchorRecord.setRow1((short) Units.pointsToMaster(rectangle2D.getHeight() + rectangle2D.getY()));
        setInteriorAnchor(rectangle2D);
    }

    @Override // org.apache.poi.sl.usermodel.GroupShape
    public void setInteriorAnchor(Rectangle2D rectangle2D) {
        EscherSpgrRecord escherSpgrRecord = (EscherSpgrRecord) getEscherChild(-4087);
        int pointsToMaster = Units.pointsToMaster(rectangle2D.getX());
        int pointsToMaster2 = Units.pointsToMaster(rectangle2D.getY());
        int pointsToMaster3 = Units.pointsToMaster(rectangle2D.getX() + rectangle2D.getWidth());
        int pointsToMaster4 = Units.pointsToMaster(rectangle2D.getY() + rectangle2D.getHeight());
        escherSpgrRecord.setRectX1(pointsToMaster);
        escherSpgrRecord.setRectY1(pointsToMaster2);
        escherSpgrRecord.setRectX2(pointsToMaster3);
        escherSpgrRecord.setRectY2(pointsToMaster4);
    }

    /* JADX DEBUG: Multi-variable search result rejected for r3v0, resolved type: org.apache.poi.hslf.usermodel.HSLFShape */
    /* JADX WARN: Multi-variable type inference failed */
    /* JADX WARN: Type inference failed for: r0v1, types: [org.apache.poi.hslf.usermodel.HSLFSheet] */
    /* JADX WARNING: Unknown variable types count: 1 */
    public void addShape(HSLFShape hSLFShape) {
        getSpContainer().addChildRecord(hSLFShape.getSpContainer());
        ?? sheet = getSheet();
        hSLFShape.setSheet(sheet);
        hSLFShape.setShapeId(sheet.allocateShapeId());
        hSLFShape.afterInsert(sheet);
    }

    @Override // org.apache.poi.sl.usermodel.ShapeContainer, org.apache.poi.hslf.usermodel.HSLFShapeContainer
    public HSLFAutoShape createAutoShape() {
        HSLFAutoShape hSLFAutoShape = new HSLFAutoShape(ShapeType.RECT, this);
        hSLFAutoShape.setHorizontalCentered(true);
        hSLFAutoShape.setAnchor(new Rectangle2D.Double((double) NumericFunction.LOG_10_TO_BASE_e, (double) NumericFunction.LOG_10_TO_BASE_e, 100.0d, 100.0d));
        addShape((HSLFShape) hSLFAutoShape);
        return hSLFAutoShape;
    }

    @Override // org.apache.poi.sl.usermodel.ShapeContainer, org.apache.poi.hslf.usermodel.HSLFShapeContainer
    public HSLFConnectorShape createConnector() {
        HSLFConnectorShape hSLFConnectorShape = new HSLFConnectorShape(this);
        hSLFConnectorShape.setAnchor(new Rectangle2D.Double((double) NumericFunction.LOG_10_TO_BASE_e, (double) NumericFunction.LOG_10_TO_BASE_e, 100.0d, 100.0d));
        addShape((HSLFShape) hSLFConnectorShape);
        return hSLFConnectorShape;
    }

    @Override // org.apache.poi.sl.usermodel.ShapeContainer, org.apache.poi.hslf.usermodel.HSLFShapeContainer
    public HSLFFreeformShape createFreeform() {
        HSLFFreeformShape hSLFFreeformShape = new HSLFFreeformShape(this);
        hSLFFreeformShape.setHorizontalCentered(true);
        hSLFFreeformShape.setAnchor(new Rectangle2D.Double((double) NumericFunction.LOG_10_TO_BASE_e, (double) NumericFunction.LOG_10_TO_BASE_e, 100.0d, 100.0d));
        addShape((HSLFShape) hSLFFreeformShape);
        return hSLFFreeformShape;
    }

    @Override // org.apache.poi.sl.usermodel.ShapeContainer, org.apache.poi.hslf.usermodel.HSLFShapeContainer
    public HSLFGroupShape createGroup() {
        HSLFGroupShape hSLFGroupShape = new HSLFGroupShape(this);
        hSLFGroupShape.setAnchor(new Rectangle2D.Double((double) NumericFunction.LOG_10_TO_BASE_e, (double) NumericFunction.LOG_10_TO_BASE_e, 100.0d, 100.0d));
        addShape((HSLFShape) hSLFGroupShape);
        return hSLFGroupShape;
    }

    @Override // org.apache.poi.sl.usermodel.ShapeContainer, org.apache.poi.hslf.usermodel.HSLFShapeContainer
    public HSLFPictureShape createPicture(PictureData pictureData) {
        if (pictureData instanceof HSLFPictureData) {
            HSLFPictureShape hSLFPictureShape = new HSLFPictureShape((HSLFPictureData) pictureData, this);
            hSLFPictureShape.setAnchor(new Rectangle2D.Double((double) NumericFunction.LOG_10_TO_BASE_e, (double) NumericFunction.LOG_10_TO_BASE_e, 100.0d, 100.0d));
            addShape((HSLFShape) hSLFPictureShape);
            return hSLFPictureShape;
        }
        throw new IllegalArgumentException("pictureData needs to be of type HSLFPictureData");
    }

    @Override // org.apache.poi.sl.usermodel.ShapeContainer
    public HSLFTable createTable(int i2, int i3) {
        if (i2 < 1 || i3 < 1) {
            throw new IllegalArgumentException("numRows and numCols must be greater than 0");
        }
        HSLFTable hSLFTable = new HSLFTable(i2, i3, this);
        hSLFTable.setAnchor(new Rectangle2D.Double((double) NumericFunction.LOG_10_TO_BASE_e, (double) NumericFunction.LOG_10_TO_BASE_e, 100.0d, 100.0d));
        addShape((HSLFShape) hSLFTable);
        return hSLFTable;
    }

    @Override // org.apache.poi.sl.usermodel.ShapeContainer, org.apache.poi.hslf.usermodel.HSLFShapeContainer
    public HSLFTextBox createTextBox() {
        HSLFTextBox hSLFTextBox = new HSLFTextBox(this);
        hSLFTextBox.setHorizontalCentered(true);
        hSLFTextBox.setAnchor(new Rectangle2D.Double((double) NumericFunction.LOG_10_TO_BASE_e, (double) NumericFunction.LOG_10_TO_BASE_e, 100.0d, 100.0d));
        addShape((HSLFShape) hSLFTextBox);
        return hSLFTextBox;
    }

    public boolean removeShape(HSLFShape hSLFShape) {
        throw new UnsupportedOperationException();
    }

    public HSLFGroupShape(ShapeContainer<HSLFShape, HSLFTextParagraph> shapeContainer) {
        this(null, shapeContainer);
        createSpContainer(shapeContainer instanceof HSLFGroupShape);
    }

    public HSLFGroupShape(EscherContainerRecord escherContainerRecord, ShapeContainer<HSLFShape, HSLFTextParagraph> shapeContainer) {
        super(escherContainerRecord, shapeContainer);
    }
}
