package org.apache.poi.hslf.usermodel;

import java.awt.Graphics2D;
import java.awt.geom.Rectangle2D;
import java.util.ArrayList;
import java.util.Iterator;
import java.util.List;
import org.apache.poi.ddf.EscherContainerRecord;
import org.apache.poi.ddf.EscherRecord;
import org.apache.poi.hslf.exceptions.HSLFException;
import org.apache.poi.hslf.record.CString;
import org.apache.poi.hslf.record.ColorSchemeAtom;
import org.apache.poi.hslf.record.PPDrawing;
import org.apache.poi.hslf.record.RecordContainer;
import org.apache.poi.hslf.record.RecordTypes;
import org.apache.poi.hslf.record.SheetContainer;
import org.apache.poi.sl.draw.DrawFactory;
import org.apache.poi.sl.usermodel.Background;
import org.apache.poi.sl.usermodel.MasterSheet;
import org.apache.poi.sl.usermodel.PictureData;
import org.apache.poi.sl.usermodel.Placeholder;
import org.apache.poi.sl.usermodel.ShapeType;
import org.apache.poi.sl.usermodel.Sheet;
import org.apache.poi.sl.usermodel.SlideShow;
import org.apache.poi.ss.formula.functions.NumericFunction;
import org.apache.poi.util.Internal;

public abstract class HSLFSheet implements HSLFShapeContainer, Sheet<HSLFShape, HSLFTextParagraph> {
    public HSLFBackground _background;
    public SheetContainer _container;
    public int _sheetNo;
    public HSLFSlideShow _slideShow;

    public HSLFSheet(SheetContainer sheetContainer, int i2) {
        this._container = sheetContainer;
        this._sheetNo = i2;
    }

    public int _getSheetNumber() {
        return this._sheetNo;
    }

    public int _getSheetRefId() {
        return this._container.getSheetId();
    }

    public int allocateShapeId() {
        return this._slideShow.getDocumentRecord().getPPDrawingGroup().getEscherDggRecord().allocateShapeId(this._container.getPPDrawing().getEscherDgRecord(), false);
    }

    @Override // org.apache.poi.sl.usermodel.Sheet
    public void draw(Graphics2D graphics2D) {
        DrawFactory.getInstance(graphics2D).getDrawable(this).draw(graphics2D);
    }

    public ColorSchemeAtom getColorScheme() {
        return this._container.getColorScheme();
    }

    @Override // org.apache.poi.sl.usermodel.Sheet
    public boolean getFollowMasterGraphics() {
        return false;
    }

    /* Return type fixed from 'org.apache.poi.hslf.usermodel.HSLFMasterSheet' to match base method */
    @Override // org.apache.poi.sl.usermodel.Sheet
    public abstract MasterSheet<HSLFShape, HSLFTextParagraph> getMasterSheet();

    public PPDrawing getPPDrawing() {
        return this._container.getPPDrawing();
    }

    public HSLFSimpleShape getPlaceholder(Placeholder placeholder) {
        for (HSLFShape hSLFShape : getShapes()) {
            if (hSLFShape instanceof HSLFSimpleShape) {
                HSLFSimpleShape hSLFSimpleShape = (HSLFSimpleShape) hSLFShape;
                if (placeholder == hSLFSimpleShape.getPlaceholder()) {
                    return hSLFSimpleShape;
                }
            }
        }
        return null;
    }

    public HSLFTextShape getPlaceholderByTextType(int i2) {
        for (HSLFShape hSLFShape : getShapes()) {
            if (hSLFShape instanceof HSLFTextShape) {
                HSLFTextShape hSLFTextShape = (HSLFTextShape) hSLFShape;
                if (hSLFTextShape.getRunType() == i2) {
                    return hSLFTextShape;
                }
            }
        }
        return null;
    }

    public String getProgrammableTag() {
        RecordContainer recordContainer;
        CString cString;
        RecordContainer recordContainer2 = (RecordContainer) getSheetContainer().findFirstOfType((long) RecordTypes.ProgTags.typeID);
        if (recordContainer2 == null || (recordContainer = (RecordContainer) recordContainer2.findFirstOfType((long) RecordTypes.ProgBinaryTag.typeID)) == null || (cString = (CString) recordContainer.findFirstOfType((long) RecordTypes.CString.typeID)) == null) {
            return null;
        }
        return cString.getText();
    }

    @Override // org.apache.poi.sl.usermodel.ShapeContainer
    public List<HSLFShape> getShapes() {
        EscherContainerRecord escherContainerRecord;
        HSLFHyperlink find;
        Iterator<EscherRecord> it = getPPDrawing().getDgContainer().iterator();
        while (true) {
            if (!it.hasNext()) {
                escherContainerRecord = null;
                break;
            }
            EscherRecord next = it.next();
            if (next.getRecordId() == -4093) {
                escherContainerRecord = (EscherContainerRecord) next;
                break;
            }
        }
        if (escherContainerRecord != null) {
            ArrayList arrayList = new ArrayList();
            boolean z = true;
            Iterator<EscherRecord> it2 = escherContainerRecord.iterator();
            while (it2.hasNext()) {
                EscherRecord next2 = it2.next();
                if (z) {
                    z = false;
                } else {
                    HSLFShape createShape = HSLFShapeFactory.createShape((EscherContainerRecord) next2, null);
                    createShape.setSheet(this);
                    if ((createShape instanceof HSLFSimpleShape) && (find = HSLFHyperlink.find(createShape)) != null) {
                        ((HSLFSimpleShape) createShape).setHyperlink(find);
                    }
                    arrayList.add(createShape);
                }
            }
            return arrayList;
        }
        throw new IllegalStateException("spgr not found");
    }

    public SheetContainer getSheetContainer() {
        return this._container;
    }

    public abstract List<List<HSLFTextParagraph>> getTextParagraphs();

    @Override // java.lang.Iterable
    public Iterator<HSLFShape> iterator() {
        return getShapes().iterator();
    }

    public void onAddTextShape(HSLFTextShape hSLFTextShape) {
    }

    public void onCreate() {
    }

    @Internal
    public void setSlideShow(HSLFSlideShow hSLFSlideShow) {
        if (this._slideShow == null) {
            this._slideShow = hSLFSlideShow;
            List<List<HSLFTextParagraph>> textParagraphs = getTextParagraphs();
            if (textParagraphs != null) {
                for (List<HSLFTextParagraph> list : textParagraphs) {
                    HSLFTextParagraph.supplySheet(list, this);
                    HSLFTextParagraph.applyHyperlinks(list);
                }
                return;
            }
            return;
        }
        throw new HSLFException("Can't change existing slideshow reference");
    }

    public void addShape(HSLFShape hSLFShape) {
        ((EscherContainerRecord) HSLFShape.getEscherChild(getPPDrawing().getDgContainer(), -4093)).addChildRecord(hSLFShape.getSpContainer());
        hSLFShape.setSheet(this);
        hSLFShape.setShapeId(allocateShapeId());
        hSLFShape.afterInsert(this);
    }

    @Override // org.apache.poi.sl.usermodel.ShapeContainer, org.apache.poi.hslf.usermodel.HSLFShapeContainer
    public HSLFAutoShape createAutoShape() {
        HSLFAutoShape hSLFAutoShape = new HSLFAutoShape(ShapeType.RECT);
        hSLFAutoShape.setHorizontalCentered(true);
        hSLFAutoShape.setAnchor(new Rectangle2D.Double((double) NumericFunction.LOG_10_TO_BASE_e, (double) NumericFunction.LOG_10_TO_BASE_e, 100.0d, 100.0d));
        addShape((HSLFShape) hSLFAutoShape);
        return hSLFAutoShape;
    }

    @Override // org.apache.poi.sl.usermodel.ShapeContainer, org.apache.poi.hslf.usermodel.HSLFShapeContainer
    public HSLFConnectorShape createConnector() {
        HSLFConnectorShape hSLFConnectorShape = new HSLFConnectorShape();
        hSLFConnectorShape.setAnchor(new Rectangle2D.Double((double) NumericFunction.LOG_10_TO_BASE_e, (double) NumericFunction.LOG_10_TO_BASE_e, 100.0d, 100.0d));
        addShape((HSLFShape) hSLFConnectorShape);
        return hSLFConnectorShape;
    }

    @Override // org.apache.poi.sl.usermodel.ShapeContainer, org.apache.poi.hslf.usermodel.HSLFShapeContainer
    public HSLFFreeformShape createFreeform() {
        HSLFFreeformShape hSLFFreeformShape = new HSLFFreeformShape();
        hSLFFreeformShape.setHorizontalCentered(true);
        hSLFFreeformShape.setAnchor(new Rectangle2D.Double((double) NumericFunction.LOG_10_TO_BASE_e, (double) NumericFunction.LOG_10_TO_BASE_e, 100.0d, 100.0d));
        addShape((HSLFShape) hSLFFreeformShape);
        return hSLFFreeformShape;
    }

    @Override // org.apache.poi.sl.usermodel.ShapeContainer, org.apache.poi.hslf.usermodel.HSLFShapeContainer
    public HSLFGroupShape createGroup() {
        HSLFGroupShape hSLFGroupShape = new HSLFGroupShape();
        hSLFGroupShape.setAnchor(new Rectangle2D.Double((double) NumericFunction.LOG_10_TO_BASE_e, (double) NumericFunction.LOG_10_TO_BASE_e, 100.0d, 100.0d));
        addShape((HSLFShape) hSLFGroupShape);
        return hSLFGroupShape;
    }

    @Override // org.apache.poi.sl.usermodel.ShapeContainer, org.apache.poi.hslf.usermodel.HSLFShapeContainer
    public HSLFPictureShape createPicture(PictureData pictureData) {
        if (pictureData instanceof HSLFPictureData) {
            HSLFPictureShape hSLFPictureShape = new HSLFPictureShape((HSLFPictureData) pictureData);
            hSLFPictureShape.setAnchor(new Rectangle2D.Double((double) NumericFunction.LOG_10_TO_BASE_e, (double) NumericFunction.LOG_10_TO_BASE_e, 100.0d, 100.0d));
            addShape((HSLFShape) hSLFPictureShape);
            return hSLFPictureShape;
        }
        throw new IllegalArgumentException("pictureData needs to be of type HSLFPictureData");
    }

    @Override // org.apache.poi.sl.usermodel.ShapeContainer
    public HSLFTable createTable(int i2, int i3) {
        if (i2 < 1 || i3 < 1) {
            throw new IllegalArgumentException("numRows and numCols must be greater than 0");
        }
        HSLFTable hSLFTable = new HSLFTable(i2, i3);
        addShape((HSLFShape) hSLFTable);
        return hSLFTable;
    }

    @Override // org.apache.poi.sl.usermodel.ShapeContainer, org.apache.poi.hslf.usermodel.HSLFShapeContainer
    public HSLFTextBox createTextBox() {
        HSLFTextBox hSLFTextBox = new HSLFTextBox();
        hSLFTextBox.setHorizontalCentered(true);
        hSLFTextBox.setAnchor(new Rectangle2D.Double((double) NumericFunction.LOG_10_TO_BASE_e, (double) NumericFunction.LOG_10_TO_BASE_e, 100.0d, 100.0d));
        addShape((HSLFShape) hSLFTextBox);
        return hSLFTextBox;
    }

    /* Return type fixed from 'org.apache.poi.hslf.usermodel.HSLFBackground' to match base method */
    @Override // org.apache.poi.sl.usermodel.Sheet
    public Background<HSLFShape, HSLFTextParagraph> getBackground() {
        if (this._background == null) {
            HSLFBackground hSLFBackground = new HSLFBackground((EscherContainerRecord) getPPDrawing().getDgContainer().getChildById(EscherContainerRecord.SP_CONTAINER), null);
            this._background = hSLFBackground;
            hSLFBackground.setSheet(this);
        }
        return this._background;
    }

    /* Return type fixed from 'org.apache.poi.hslf.usermodel.HSLFSlideShow' to match base method */
    @Override // org.apache.poi.sl.usermodel.Sheet
    public SlideShow<HSLFShape, HSLFTextParagraph> getSlideShow() {
        return this._slideShow;
    }

    public boolean removeShape(HSLFShape hSLFShape) {
        EscherContainerRecord escherContainerRecord = (EscherContainerRecord) getPPDrawing().getDgContainer().getChildById(EscherContainerRecord.SPGR_CONTAINER);
        if (escherContainerRecord == null) {
            return false;
        }
        List<EscherRecord> childRecords = escherContainerRecord.getChildRecords();
        boolean remove = childRecords.remove(hSLFShape.getSpContainer());
        escherContainerRecord.setChildRecords(childRecords);
        return remove;
    }
}
