package org.apache.poi.hslf.usermodel;

import b.b.a.a.a;
import java.awt.geom.Rectangle2D;
import java.lang.reflect.Array;
import java.util.ArrayList;
import java.util.HashSet;
import java.util.Iterator;
import java.util.List;
import java.util.ListIterator;
import java.util.TreeSet;
import org.apache.poi.ddf.AbstractEscherOptRecord;
import org.apache.poi.ddf.EscherArrayProperty;
import org.apache.poi.ddf.EscherContainerRecord;
import org.apache.poi.ddf.EscherOptRecord;
import org.apache.poi.ddf.EscherProperties;
import org.apache.poi.ddf.EscherSimpleProperty;
import org.apache.poi.hslf.record.RecordTypes;
import org.apache.poi.sl.usermodel.ShapeContainer;
import org.apache.poi.sl.usermodel.TableCell;
import org.apache.poi.sl.usermodel.TableShape;
import org.apache.poi.ss.formula.functions.NumericFunction;
import org.apache.poi.util.LittleEndian;
import org.apache.poi.util.Units;

public final class HSLFTable extends HSLFGroupShape implements HSLFShapeContainer, TableShape<HSLFShape, HSLFTextParagraph> {
    public static final /* synthetic */ boolean $assertionsDisabled = false;
    public static final int BORDERS_ALL = 5;
    public static final int BORDERS_INSIDE = 7;
    public static final int BORDERS_NONE = 8;
    public static final int BORDERS_OUTSIDE = 6;
    public HSLFTableCell[][] cells;
    public int columnCount;

    public static class LineRect {
        public final HSLFLine l;
        public final double lx1;
        public final double lx2;
        public final double ly1;
        public final double ly2;

        public LineRect(HSLFLine hSLFLine) {
            this.l = hSLFLine;
            Rectangle2D anchor = hSLFLine.getAnchor();
            this.lx1 = anchor.getMinX();
            this.lx2 = anchor.getMaxX();
            this.ly1 = anchor.getMinY();
            this.ly2 = anchor.getMaxY();
        }

        public int bottomFit(double d2, double d3, double d4, double d5) {
            double abs = Math.abs(d5 - this.ly1) + Math.abs(d2 - this.lx1);
            return (int) (Math.abs(d5 - this.ly2) + Math.abs(d3 - this.lx2) + abs);
        }

        public int leftFit(double d2, double d3, double d4, double d5) {
            double abs = Math.abs(d4 - this.ly1) + Math.abs(d2 - this.lx1);
            return (int) (Math.abs(d5 - this.ly2) + Math.abs(d2 - this.lx2) + abs);
        }

        public int rightFit(double d2, double d3, double d4, double d5) {
            double abs = Math.abs(d4 - this.ly1) + Math.abs(d3 - this.lx1);
            return (int) (Math.abs(d5 - this.ly2) + Math.abs(d3 - this.lx2) + abs);
        }

        public int topFit(double d2, double d3, double d4, double d5) {
            double abs = Math.abs(d4 - this.ly1) + Math.abs(d2 - this.lx1);
            return (int) (Math.abs(d4 - this.ly2) + Math.abs(d3 - this.lx2) + abs);
        }
    }

    public HSLFTable(int i2, int i3) {
        this(i2, i3, null);
    }

    private int calcSpan(List<Double> list, double d2, int i2) {
        ListIterator<Double> listIterator = list.listIterator(i2);
        double doubleValue = listIterator.next().doubleValue();
        int i3 = 1;
        while (listIterator.hasNext() && listIterator.next().doubleValue() - doubleValue < d2) {
            i3++;
        }
        return i3;
    }

    private void cellListToArray() {
        ArrayList arrayList = new ArrayList();
        for (HSLFShape hSLFShape : getShapes()) {
            if (hSLFShape instanceof HSLFTableCell) {
                arrayList.add((HSLFTableCell) hSLFShape);
            }
        }
        if (!arrayList.isEmpty()) {
            TreeSet treeSet = new TreeSet();
            TreeSet treeSet2 = new TreeSet();
            Iterator it = arrayList.iterator();
            while (it.hasNext()) {
                Rectangle2D anchor = ((HSLFTableCell) it.next()).getAnchor();
                treeSet.add(Double.valueOf(anchor.getX()));
                treeSet2.add(Double.valueOf(anchor.getY()));
            }
            int size = treeSet2.size();
            int[] iArr = new int[2];
            iArr[1] = treeSet.size();
            iArr[0] = size;
            this.cells = (HSLFTableCell[][]) Array.newInstance(HSLFTableCell.class, iArr);
            ArrayList arrayList2 = new ArrayList(treeSet);
            ArrayList arrayList3 = new ArrayList(treeSet2);
            Iterator it2 = arrayList.iterator();
            while (it2.hasNext()) {
                HSLFTableCell hSLFTableCell = (HSLFTableCell) it2.next();
                Rectangle2D anchor2 = hSLFTableCell.getAnchor();
                int indexOf = arrayList3.indexOf(Double.valueOf(anchor2.getY()));
                int indexOf2 = arrayList2.indexOf(Double.valueOf(anchor2.getX()));
                this.cells[indexOf][indexOf2] = hSLFTableCell;
                int calcSpan = calcSpan(arrayList2, anchor2.getWidth(), indexOf2);
                int calcSpan2 = calcSpan(arrayList3, anchor2.getHeight(), indexOf);
                hSLFTableCell.setGridSpan(calcSpan);
                hSLFTableCell.setRowSpan(calcSpan2);
            }
            return;
        }
        throw new IllegalStateException("HSLFTable without HSLFTableCells");
    }

    private void fitLinesToCells() {
        int i2;
        HSLFTableCell[] hSLFTableCellArr;
        int i3;
        HSLFTableCell[][] hSLFTableCellArr2;
        ArrayList arrayList;
        ArrayList arrayList2 = new ArrayList();
        for (HSLFShape hSLFShape : getShapes()) {
            if (hSLFShape instanceof HSLFLine) {
                arrayList2.add(new LineRect((HSLFLine) hSLFShape));
            }
        }
        HSLFTableCell[][] hSLFTableCellArr3 = this.cells;
        int length = hSLFTableCellArr3.length;
        for (int i4 = 0; i4 < length; i4++) {
            HSLFTableCell[] hSLFTableCellArr4 = hSLFTableCellArr3[i4];
            int length2 = hSLFTableCellArr4.length;
            int i5 = 0;
            while (i5 < length2) {
                HSLFTableCell hSLFTableCell = hSLFTableCellArr4[i5];
                if (hSLFTableCell == null) {
                    arrayList = arrayList2;
                    hSLFTableCellArr2 = hSLFTableCellArr3;
                    i3 = length;
                    hSLFTableCellArr = hSLFTableCellArr4;
                    i2 = length2;
                } else {
                    Rectangle2D anchor = hSLFTableCell.getAnchor();
                    double minX = anchor.getMinX();
                    double maxX = anchor.getMaxX();
                    double minY = anchor.getMinY();
                    double maxY = anchor.getMaxY();
                    arrayList = arrayList2;
                    hSLFTableCellArr2 = hSLFTableCellArr3;
                    LineRect lineRect = null;
                    LineRect lineRect2 = null;
                    LineRect lineRect3 = null;
                    LineRect lineRect4 = null;
                    int i6 = Integer.MAX_VALUE;
                    int i7 = Integer.MAX_VALUE;
                    int i8 = Integer.MAX_VALUE;
                    int i9 = Integer.MAX_VALUE;
                    for (Iterator it = arrayList2.iterator(); it.hasNext(); it = it) {
                        LineRect lineRect5 = (LineRect) it.next();
                        LineRect lineRect6 = lineRect4;
                        int i10 = i6;
                        int i11 = i8;
                        int i12 = i9;
                        int leftFit = lineRect5.leftFit(minX, maxX, minY, maxY);
                        if (leftFit < i11) {
                            i11 = leftFit;
                            lineRect6 = lineRect5;
                        }
                        int i13 = lineRect5.topFit(minX, maxX, minY, maxY);
                        if (i13 < i12) {
                            i12 = i13;
                            lineRect3 = lineRect5;
                        }
                        int rightFit = lineRect5.rightFit(minX, maxX, minY, maxY);
                        if (rightFit < i10) {
                            i10 = rightFit;
                            lineRect = lineRect5;
                        }
                        int bottomFit = lineRect5.bottomFit(minX, maxX, minY, maxY);
                        if (bottomFit < i7) {
                            i7 = bottomFit;
                            lineRect2 = lineRect5;
                        } else {
                            i7 = i7;
                        }
                        lineRect4 = lineRect6;
                        i6 = i10;
                        i8 = i11;
                        i9 = i12;
                        length = length;
                        hSLFTableCellArr4 = hSLFTableCellArr4;
                        length2 = length2;
                    }
                    i3 = length;
                    hSLFTableCellArr = hSLFTableCellArr4;
                    i2 = length2;
                    if (i8 < 5 && lineRect4 != null) {
                        hSLFTableCell.borderLeft = lineRect4.l;
                    }
                    if (i9 < 5 && lineRect3 != null) {
                        hSLFTableCell.borderTop = lineRect3.l;
                    }
                    if (i6 < 5 && lineRect != null) {
                        hSLFTableCell.borderRight = lineRect.l;
                    }
                    if (i7 < 5 && lineRect2 != null) {
                        hSLFTableCell.borderBottom = lineRect2.l;
                    }
                }
                i5++;
                arrayList2 = arrayList;
                hSLFTableCellArr3 = hSLFTableCellArr2;
                length = i3;
                hSLFTableCellArr4 = hSLFTableCellArr;
                length2 = i2;
            }
        }
    }

    private void updateRowHeightsProperty() {
        EscherArrayProperty escherArrayProperty = (EscherArrayProperty) ((AbstractEscherOptRecord) getEscherChild(RecordTypes.EscherUserDefined.typeID)).lookup(928);
        byte[] bArr = new byte[4];
        int i2 = 0;
        while (true) {
            HSLFTableCell[][] hSLFTableCellArr = this.cells;
            if (i2 < hSLFTableCellArr.length) {
                LittleEndian.putInt(bArr, 0, Units.pointsToMaster(hSLFTableCellArr[i2][0].getAnchor().getHeight()));
                escherArrayProperty.setElement(i2, bArr);
                i2++;
            } else {
                return;
            }
        }
    }

    @Override // org.apache.poi.hslf.usermodel.HSLFShape
    public void afterInsert(HSLFSheet hSLFSheet) {
        super.afterInsert(hSLFSheet);
        HashSet hashSet = new HashSet();
        HSLFTableCell[][] hSLFTableCellArr = this.cells;
        for (HSLFTableCell[] hSLFTableCellArr2 : hSLFTableCellArr) {
            for (HSLFTableCell hSLFTableCell : hSLFTableCellArr2) {
                addShape((HSLFShape) hSLFTableCell);
                HSLFLine[] hSLFLineArr = {hSLFTableCell.borderTop, hSLFTableCell.borderRight, hSLFTableCell.borderBottom, hSLFTableCell.borderLeft};
                for (int i2 = 0; i2 < 4; i2++) {
                    HSLFLine hSLFLine = hSLFLineArr[i2];
                    if (hSLFLine != null) {
                        hashSet.add(hSLFLine);
                    }
                }
            }
        }
        Iterator it = hashSet.iterator();
        while (it.hasNext()) {
            addShape((HSLFLine) it.next());
        }
        updateRowHeightsProperty();
    }

    @Override // org.apache.poi.sl.usermodel.TableShape
    public double getColumnWidth(int i2) {
        if (i2 >= 0) {
            HSLFTableCell[][] hSLFTableCellArr = this.cells;
            if (i2 < hSLFTableCellArr[0].length) {
                return hSLFTableCellArr[0][i2].getAnchor().getWidth();
            }
        }
        StringBuilder a = a.a("Column index '", i2, "' is not within range [0-");
        a.append(this.cells[0].length - 1);
        a.append("]");
        throw new IllegalArgumentException(a.toString());
    }

    @Override // org.apache.poi.sl.usermodel.TableShape
    public int getNumberOfColumns() {
        if (this.columnCount == -1) {
            HSLFTableCell[][] hSLFTableCellArr = this.cells;
            for (HSLFTableCell[] hSLFTableCellArr2 : hSLFTableCellArr) {
                if (hSLFTableCellArr2 != null) {
                    this.columnCount = Math.max(this.columnCount, hSLFTableCellArr2.length);
                }
            }
        }
        return this.columnCount;
    }

    @Override // org.apache.poi.sl.usermodel.TableShape
    public int getNumberOfRows() {
        return this.cells.length;
    }

    public HSLFTableCell getRelativeCell(HSLFTableCell hSLFTableCell, int i2, int i3) {
        HSLFTableCell[][] hSLFTableCellArr = this.cells;
        int length = hSLFTableCellArr.length;
        boolean z = false;
        int i4 = 0;
        int i5 = 0;
        int i6 = 0;
        loop0:
        while (true) {
            if (i4 >= length) {
                break;
            }
            int i7 = 0;
            for (HSLFTableCell hSLFTableCell2 : hSLFTableCellArr[i4]) {
                if (hSLFTableCell2 == hSLFTableCell) {
                    z = true;
                    i6 = i7;
                    break loop0;
                }
                i7++;
            }
            i5++;
            i4++;
            i6 = i7;
        }
        int i8 = i5 + i2;
        int i9 = i6 + i3;
        if (z && i8 >= 0) {
            HSLFTableCell[][] hSLFTableCellArr2 = this.cells;
            if (i8 < hSLFTableCellArr2.length && i9 >= 0 && i9 < hSLFTableCellArr2[i8].length) {
                return hSLFTableCellArr2[i8][i9];
            }
        }
        return null;
    }

    @Override // org.apache.poi.sl.usermodel.TableShape
    public double getRowHeight(int i2) {
        if (i2 >= 0) {
            HSLFTableCell[][] hSLFTableCellArr = this.cells;
            if (i2 < hSLFTableCellArr.length) {
                return hSLFTableCellArr[i2][0].getAnchor().getHeight();
            }
        }
        StringBuilder a = a.a("Row index '", i2, "' is not within range [0-");
        a.append(this.cells.length - 1);
        a.append("]");
        throw new IllegalArgumentException(a.toString());
    }

    public void initTable() {
        cellListToArray();
        fitLinesToCells();
    }

    @Override // org.apache.poi.hslf.usermodel.HSLFGroupShape
    public void moveAndScale(Rectangle2D rectangle2D) {
        super.moveAndScale(rectangle2D);
        updateRowHeightsProperty();
    }

    @Override // org.apache.poi.sl.usermodel.TableShape
    public void setColumnWidth(int i2, double d2) {
        int i3 = 0;
        if (i2 >= 0) {
            HSLFTableCell[][] hSLFTableCellArr = this.cells;
            if (i2 < hSLFTableCellArr[0].length) {
                double width = d2 - hSLFTableCellArr[0][i2].getAnchor().getWidth();
                HSLFTableCell[][] hSLFTableCellArr2 = this.cells;
                for (int length = hSLFTableCellArr2.length; i3 < length; length = length) {
                    HSLFTableCell[] hSLFTableCellArr3 = hSLFTableCellArr2[i3];
                    Rectangle2D anchor = hSLFTableCellArr3[i2].getAnchor();
                    anchor.setRect(anchor.getX(), anchor.getY(), d2, anchor.getHeight());
                    hSLFTableCellArr3[i2].setAnchor(anchor);
                    if (i2 < hSLFTableCellArr3.length - 1) {
                        for (int i4 = i2 + 1; i4 < hSLFTableCellArr3.length; i4++) {
                            Rectangle2D anchor2 = hSLFTableCellArr3[i4].getAnchor();
                            anchor2.setRect(anchor2.getX() + width, anchor2.getY(), anchor2.getWidth(), anchor2.getHeight());
                            hSLFTableCellArr3[i4].setAnchor(anchor2);
                        }
                    }
                    i3++;
                    hSLFTableCellArr2 = hSLFTableCellArr2;
                }
                Rectangle2D anchor3 = getAnchor();
                anchor3.setRect(anchor3.getX(), anchor3.getY(), anchor3.getWidth() + width, anchor3.getHeight());
                setExteriorAnchor(anchor3);
                return;
            }
        }
        StringBuilder a = a.a("Column index '", i2, "' is not within range [0-");
        a.append(this.cells[0].length - 1);
        a.append("]");
        throw new IllegalArgumentException(a.toString());
    }

    @Override // org.apache.poi.sl.usermodel.TableShape
    public void setRowHeight(int i2, double d2) {
        HSLFTableCell[] hSLFTableCellArr;
        Rectangle2D rectangle2D;
        HSLFTableCell hSLFTableCell;
        if (i2 < 0 || i2 >= this.cells.length) {
            StringBuilder a = a.a("Row index '", i2, "' is not within range [0-");
            a.append(this.cells.length - 1);
            a.append("]");
            throw new IllegalArgumentException(a.toString());
        }
        EscherArrayProperty escherArrayProperty = (EscherArrayProperty) ((AbstractEscherOptRecord) getEscherChild(RecordTypes.EscherUserDefined.typeID)).lookup(928);
        byte[] element = escherArrayProperty.getElement(i2);
        double masterToPoints = Units.masterToPoints(LittleEndian.getInt(element, 0));
        LittleEndian.putInt(element, 0, Units.pointsToMaster(d2));
        escherArrayProperty.setElement(i2, element);
        double d3 = d2 - masterToPoints;
        int i3 = i2;
        while (true) {
            HSLFTableCell[][] hSLFTableCellArr2 = this.cells;
            if (i3 < hSLFTableCellArr2.length) {
                HSLFTableCell[] hSLFTableCellArr3 = hSLFTableCellArr2[i3];
                int length = hSLFTableCellArr3.length;
                int i4 = 0;
                while (i4 < length) {
                    HSLFTableCell hSLFTableCell2 = hSLFTableCellArr3[i4];
                    if (hSLFTableCell2 == null) {
                        hSLFTableCellArr = hSLFTableCellArr3;
                    } else {
                        Rectangle2D anchor = hSLFTableCell2.getAnchor();
                        if (i3 == i2) {
                            rectangle2D = anchor;
                            hSLFTableCellArr = hSLFTableCellArr3;
                            hSLFTableCell = hSLFTableCell2;
                            anchor.setRect(anchor.getX(), anchor.getY(), anchor.getWidth(), d2);
                        } else {
                            hSLFTableCellArr = hSLFTableCellArr3;
                            rectangle2D = anchor;
                            hSLFTableCell = hSLFTableCell2;
                            rectangle2D.setRect(rectangle2D.getX(), rectangle2D.getY() + d3, rectangle2D.getWidth(), rectangle2D.getHeight());
                        }
                        hSLFTableCell.setAnchor(rectangle2D);
                    }
                    i4++;
                    hSLFTableCellArr3 = hSLFTableCellArr;
                }
                i3++;
            } else {
                Rectangle2D anchor2 = getAnchor();
                anchor2.setRect(anchor2.getX(), anchor2.getY(), anchor2.getWidth(), anchor2.getHeight() + d3);
                setExteriorAnchor(anchor2);
                return;
            }
        }
    }

    @Override // org.apache.poi.hslf.usermodel.HSLFShape
    public void setSheet(HSLFSheet hSLFSheet) {
        super.setSheet(hSLFSheet);
        HSLFTableCell[][] hSLFTableCellArr = this.cells;
        if (hSLFTableCellArr == null) {
            initTable();
            return;
        }
        for (HSLFTableCell[] hSLFTableCellArr2 : hSLFTableCellArr) {
            for (HSLFTableCell hSLFTableCell : hSLFTableCellArr2) {
                hSLFTableCell.setSheet(hSLFSheet);
            }
        }
    }

    public HSLFTable(int i2, int i3, ShapeContainer<HSLFShape, HSLFTextParagraph> shapeContainer) {
        super(shapeContainer);
        this.columnCount = -1;
        if (i2 < 1) {
            throw new IllegalArgumentException("The number of rows must be greater than 1");
        } else if (i3 >= 1) {
            int[] iArr = new int[2];
            iArr[1] = i3;
            iArr[0] = i2;
            this.cells = (HSLFTableCell[][]) Array.newInstance(HSLFTableCell.class, iArr);
            double d2 = 0.0d;
            double d3 = 0.0d;
            for (int i4 = 0; i4 < this.cells.length; i4++) {
                d2 = 0.0d;
                int i5 = 0;
                while (true) {
                    HSLFTableCell[][] hSLFTableCellArr = this.cells;
                    if (i5 >= hSLFTableCellArr[i4].length) {
                        break;
                    }
                    hSLFTableCellArr[i4][i5] = new HSLFTableCell(this);
                    this.cells[i4][i5].setAnchor(new Rectangle2D.Double(d2, d3, 100.0d, 40.0d));
                    d2 += 100.0d;
                    i5++;
                }
                d3 += 40.0d;
            }
            setExteriorAnchor(new Rectangle2D.Double((double) NumericFunction.LOG_10_TO_BASE_e, (double) NumericFunction.LOG_10_TO_BASE_e, d2, d3));
            EscherOptRecord escherOptRecord = new EscherOptRecord();
            escherOptRecord.setRecordId(RecordTypes.EscherUserDefined.typeID);
            escherOptRecord.addEscherProperty(new EscherSimpleProperty(EscherProperties.GROUPSHAPE__TABLEPROPERTIES, 1));
            EscherArrayProperty escherArrayProperty = new EscherArrayProperty(17312, false, null);
            escherArrayProperty.setSizeOfElements(4);
            escherArrayProperty.setNumberOfElementsInArray(i2);
            escherArrayProperty.setNumberOfElementsInMemory(i2);
            escherOptRecord.addEscherProperty(escherArrayProperty);
            ((EscherContainerRecord) getSpContainer().getChild(0)).addChildBefore(escherOptRecord, RecordTypes.EscherClientAnchor.typeID);
        } else {
            throw new IllegalArgumentException("The number of columns must be greater than 1");
        }
    }

    /* Return type fixed from 'org.apache.poi.hslf.usermodel.HSLFTableCell' to match base method */
    @Override // org.apache.poi.sl.usermodel.TableShape
    public TableCell<HSLFShape, HSLFTextParagraph> getCell(int i2, int i3) {
        HSLFTableCell[] hSLFTableCellArr;
        if (i2 >= 0) {
            HSLFTableCell[][] hSLFTableCellArr2 = this.cells;
            if (hSLFTableCellArr2.length > i2 && (hSLFTableCellArr = hSLFTableCellArr2[i2]) != null && i3 >= 0 && hSLFTableCellArr.length > i3) {
                return hSLFTableCellArr[i3];
            }
        }
        return null;
    }

    public HSLFTable(EscherContainerRecord escherContainerRecord, ShapeContainer<HSLFShape, HSLFTextParagraph> shapeContainer) {
        super(escherContainerRecord, shapeContainer);
        this.columnCount = -1;
    }
}
