package org.apache.poi.hsmf.datatypes;

import b.b.a.a.a;
import java.io.Serializable;
import java.util.ArrayList;
import java.util.Comparator;
import java.util.List;
import org.apache.poi.hsmf.MAPIMessage;
import org.apache.poi.util.POILogFactory;
import org.apache.poi.util.POILogger;

public class AttachmentChunks implements ChunkGroup {
    public static final POILogger LOG = POILogFactory.getLogger(AttachmentChunks.class);
    public static final String PREFIX = "__attach_version1.0_#";
    public List<Chunk> allChunks = new ArrayList();
    public StringChunk attachContentId;
    public ByteChunk attachData;
    public StringChunk attachExtension;
    public StringChunk attachFileName;
    public StringChunk attachLongFileName;
    public StringChunk attachMimeTag;
    public ByteChunk attachRenderingWMF;
    public DirectoryChunk attachmentDirectory;
    public String poifsName;

    public static class AttachmentChunksSorter implements Comparator<AttachmentChunks>, Serializable {
        public int compare(AttachmentChunks attachmentChunks, AttachmentChunks attachmentChunks2) {
            return attachmentChunks.poifsName.compareTo(attachmentChunks2.poifsName);
        }
    }

    public AttachmentChunks(String str) {
        this.poifsName = str;
    }

    @Override // org.apache.poi.hsmf.datatypes.ChunkGroup
    public void chunksComplete() {
    }

    public Chunk[] getAll() {
        List<Chunk> list = this.allChunks;
        return (Chunk[]) list.toArray(new Chunk[list.size()]);
    }

    public StringChunk getAttachContentId() {
        return this.attachContentId;
    }

    public ByteChunk getAttachData() {
        return this.attachData;
    }

    public StringChunk getAttachExtension() {
        return this.attachExtension;
    }

    public StringChunk getAttachFileName() {
        return this.attachFileName;
    }

    public StringChunk getAttachLongFileName() {
        return this.attachLongFileName;
    }

    public StringChunk getAttachMimeTag() {
        return this.attachMimeTag;
    }

    public ByteChunk getAttachRenderingWMF() {
        return this.attachRenderingWMF;
    }

    public DirectoryChunk getAttachmentDirectory() {
        return this.attachmentDirectory;
    }

    @Override // org.apache.poi.hsmf.datatypes.ChunkGroup
    public Chunk[] getChunks() {
        return getAll();
    }

    public byte[] getEmbeddedAttachmentObject() {
        ByteChunk byteChunk = this.attachData;
        if (byteChunk != null) {
            return byteChunk.getValue();
        }
        return null;
    }

    public MAPIMessage getEmbeddedMessage() {
        DirectoryChunk directoryChunk = this.attachmentDirectory;
        if (directoryChunk != null) {
            return directoryChunk.getAsEmbededMessage();
        }
        return null;
    }

    public String getPOIFSName() {
        return this.poifsName;
    }

    public boolean isEmbeddedMessage() {
        return this.attachmentDirectory != null;
    }

    @Override // org.apache.poi.hsmf.datatypes.ChunkGroup
    public void record(Chunk chunk) {
        int chunkId = chunk.getChunkId();
        if (chunkId == MAPIProperty.ATTACH_DATA.id) {
            if (chunk instanceof ByteChunk) {
                this.attachData = (ByteChunk) chunk;
            } else if (chunk instanceof DirectoryChunk) {
                this.attachmentDirectory = (DirectoryChunk) chunk;
            } else {
                POILogger pOILogger = LOG;
                StringBuilder b2 = a.b("Unexpected data chunk of type ");
                b2.append(chunk.getEntryName());
                pOILogger.log(7, b2.toString());
            }
        } else if (chunkId == MAPIProperty.ATTACH_EXTENSION.id) {
            this.attachExtension = (StringChunk) chunk;
        } else if (chunkId == MAPIProperty.ATTACH_FILENAME.id) {
            this.attachFileName = (StringChunk) chunk;
        } else if (chunkId == MAPIProperty.ATTACH_LONG_FILENAME.id) {
            this.attachLongFileName = (StringChunk) chunk;
        } else if (chunkId == MAPIProperty.ATTACH_MIME_TAG.id) {
            this.attachMimeTag = (StringChunk) chunk;
        } else if (chunkId == MAPIProperty.ATTACH_RENDERING.id) {
            this.attachRenderingWMF = (ByteChunk) chunk;
        } else if (chunkId == MAPIProperty.ATTACH_CONTENT_ID.id) {
            this.attachContentId = (StringChunk) chunk;
        } else {
            POILogger pOILogger2 = LOG;
            StringBuilder b3 = a.b("Currently unsupported attachment chunk property will be ignored. ");
            b3.append(chunk.getEntryName());
            pOILogger2.log(5, b3.toString());
        }
        this.allChunks.add(chunk);
    }
}
