package org.apache.poi.hsmf.datatypes;

import b.b.a.a.a;
import java.io.InputStream;
import java.io.OutputStream;
import java.nio.charset.Charset;
import org.apache.poi.hsmf.datatypes.Types;
import org.apache.poi.util.IOUtils;
import org.apache.poi.util.StringUtil;

public class StringChunk extends Chunk {
    public static final String DEFAULT_ENCODING = "CP1252";
    public String encoding7Bit = "CP1252";
    public byte[] rawValue;
    public String value;

    public StringChunk(String str, int i2, Types.MAPIType mAPIType) {
        super(str, i2, mAPIType);
    }

    public static String parseAs7BitData(byte[] bArr) {
        return parseAs7BitData(bArr, "CP1252");
    }

    private void parseString() {
        String str;
        if (getType() == Types.ASCII_STRING) {
            str = parseAs7BitData(this.rawValue, this.encoding7Bit);
        } else if (getType() == Types.UNICODE_STRING) {
            str = StringUtil.getFromUnicodeLE(this.rawValue);
        } else {
            StringBuilder b2 = a.b("Invalid type ");
            b2.append(getType());
            b2.append(" for String Chunk");
            throw new IllegalArgumentException(b2.toString());
        }
        this.value = str.replace("\u0000", "");
    }

    private void storeString() {
        if (getType() == Types.ASCII_STRING) {
            this.rawValue = this.value.getBytes(Charset.forName(this.encoding7Bit));
        } else if (getType() == Types.UNICODE_STRING) {
            this.rawValue = StringUtil.getToUnicodeLE(this.value);
        } else {
            StringBuilder b2 = a.b("Invalid type ");
            b2.append(getType());
            b2.append(" for String Chunk");
            throw new IllegalArgumentException(b2.toString());
        }
    }

    public String get7BitEncoding() {
        return this.encoding7Bit;
    }

    public byte[] getRawValue() {
        return this.rawValue;
    }

    public String getValue() {
        return this.value;
    }

    @Override // org.apache.poi.hsmf.datatypes.Chunk
    public void readValue(InputStream inputStream) {
        this.rawValue = IOUtils.toByteArray(inputStream);
        parseString();
    }

    public void set7BitEncoding(String str) {
        this.encoding7Bit = str;
        if (getType() == Types.ASCII_STRING) {
            parseString();
        }
    }

    public void setValue(String str) {
        this.value = str;
        storeString();
    }

    public String toString() {
        return this.value;
    }

    @Override // org.apache.poi.hsmf.datatypes.Chunk
    public void writeValue(OutputStream outputStream) {
        outputStream.write(this.rawValue);
    }

    public static String parseAs7BitData(byte[] bArr, String str) {
        if ("ansi".equals(str)) {
            str = "CP1252";
        }
        return new String(bArr, Charset.forName(str));
    }

    public StringChunk(int i2, Types.MAPIType mAPIType) {
        super(i2, mAPIType);
    }
}
