package org.apache.poi.hsmf.datatypes;

import b.b.a.a.a;
import java.util.HashMap;
import java.util.Locale;
import java.util.Map;
import org.apache.poi.hmef.attribute.TNEFProperty;

public final class Types {
    public static final MAPIType APP_TIME = new MAPIType(7, "Application Time", 8);
    public static final MAPIType ASCII_STRING = new MAPIType(30, "ASCII String", -1);
    public static final MAPIType BINARY = new MAPIType(TNEFProperty.PTYPE_BINARY, "Binary", -1);
    public static final MAPIType BOOLEAN = new MAPIType(11, "Boolean", 2);
    public static final MAPIType CLS_ID = new MAPIType(72, "CLS ID GUID", 16);
    public static final MAPIType CURRENCY = new MAPIType(6, "Currency", 8);
    public static final MAPIType DIRECTORY = new MAPIType(13, "Directory", -1);
    public static final MAPIType DOUBLE = new MAPIType(5, "Double", 8);
    public static final MAPIType ERROR = new MAPIType(10, "Error", 4);
    public static final MAPIType FLOAT = new MAPIType(4, "Float", 4);
    public static final MAPIType LONG = new MAPIType(3, "Long", 4);
    public static final MAPIType LONG_LONG = new MAPIType(20, "Long Long", 8);
    public static final int MULTIVALUED_FLAG = 4096;
    public static final MAPIType NULL = new MAPIType(1, "Null", 0);
    public static final MAPIType SHORT = new MAPIType(2, "Short", 2);
    public static final MAPIType TIME = new MAPIType(64, "Time", 8);
    public static final MAPIType UNICODE_STRING = new MAPIType(31, "Unicode String", -1);
    public static final MAPIType UNKNOWN = new MAPIType(-1, "Unknown", -1);
    public static final MAPIType UNSPECIFIED = new MAPIType(0, "Unspecified", -1);
    public static Map<Integer, MAPIType> builtInTypes = new HashMap();
    public static Map<Integer, MAPIType> customTypes = new HashMap();

    public static String asCustomName(int i2) {
        StringBuilder b2 = a.b("0x");
        b2.append(Integer.toHexString(i2));
        return b2.toString();
    }

    public static String asFileEnding(int i2) {
        String upperCase = Integer.toHexString(i2).toUpperCase(Locale.ROOT);
        while (upperCase.length() < 4) {
            upperCase = a.b("0", upperCase);
        }
        return upperCase;
    }

    public static String asName(int i2) {
        MAPIType mAPIType = builtInTypes.get(Integer.valueOf(i2));
        if (mAPIType != null) {
            return mAPIType.name;
        }
        return asCustomName(i2);
    }

    public static MAPIType createCustom(int i2) {
        if (getById(i2) != null) {
            return getById(i2);
        }
        MAPIType mAPIType = customTypes.get(Integer.valueOf(i2));
        if (mAPIType == null) {
            synchronized (customTypes) {
                mAPIType = customTypes.get(Integer.valueOf(i2));
                if (mAPIType == null) {
                    mAPIType = new MAPIType(i2, -1);
                }
            }
        }
        return mAPIType;
    }

    public static MAPIType getById(int i2) {
        return builtInTypes.get(Integer.valueOf(i2));
    }

    public static final class MAPIType {
        public final int id;
        public final int length;
        public final String name;

        public String asFileEnding() {
            return Types.asFileEnding(this.id);
        }

        public int getId() {
            return this.id;
        }

        public int getLength() {
            return this.length;
        }

        public String getName() {
            return this.name;
        }

        public boolean isFixedLength() {
            return this.length != -1;
        }

        public String toString() {
            return this.id + " / 0x" + asFileEnding() + " - " + this.name + " @ " + this.length;
        }

        public MAPIType(int i2, String str, int i3) {
            this.id = i2;
            this.name = str;
            this.length = i3;
            Types.builtInTypes.put(Integer.valueOf(i2), this);
        }

        public MAPIType(int i2, int i3) {
            this.id = i2;
            this.name = Types.asCustomName(i2);
            this.length = i3;
            Types.customTypes.put(Integer.valueOf(i2), this);
        }
    }
}
