package org.apache.poi.hssf.dev;

import b.b.a.a.a;
import java.io.FileInputStream;
import java.io.FileOutputStream;
import java.io.InputStream;
import java.io.OutputStream;
import java.util.ArrayList;
import java.util.List;
import org.apache.poi.ddf.EscherRecord;
import org.apache.poi.hssf.record.DrawingGroupRecord;
import org.apache.poi.hssf.usermodel.HSSFPatriarch;
import org.apache.poi.hssf.usermodel.HSSFWorkbook;
import org.apache.poi.util.StringUtil;
import org.apache.poi.xssf.usermodel.XSSFDataValidationConstraint;

public class BiffDrawingToXml {
    public static final String EXCLUDE_WORKBOOK_RECORDS = "-exclude-workbook";
    public static final String SHEET_INDEXES_PARAM = "-sheet-indexes";
    public static final String SHEET_NAME_PARAM = "-sheet-name";

    public static int getAttributeIndex(String str, String[] strArr) {
        for (int i2 = 0; i2 < strArr.length; i2++) {
            if (str.equals(strArr[i2])) {
                return i2;
            }
        }
        return -1;
    }

    public static List<Integer> getIndexesByIdArray(String[] strArr) {
        ArrayList arrayList = new ArrayList();
        int attributeIndex = getAttributeIndex(SHEET_INDEXES_PARAM, strArr);
        if (-1 != attributeIndex) {
            if (attributeIndex < strArr.length) {
                for (String str : strArr[attributeIndex + 1].split(XSSFDataValidationConstraint.LIST_SEPARATOR)) {
                    arrayList.add(Integer.valueOf(Integer.parseInt(str)));
                }
            } else {
                throw new IllegalArgumentException("sheet list value was not specified");
            }
        }
        return arrayList;
    }

    public static List<Integer> getIndexesByName(String[] strArr, HSSFWorkbook hSSFWorkbook) {
        ArrayList arrayList = new ArrayList();
        int attributeIndex = getAttributeIndex(SHEET_NAME_PARAM, strArr);
        if (-1 != attributeIndex) {
            if (attributeIndex < strArr.length) {
                int sheetIndex = hSSFWorkbook.getSheetIndex(strArr[attributeIndex + 1]);
                if (-1 != sheetIndex) {
                    arrayList.add(Integer.valueOf(sheetIndex));
                } else {
                    throw new IllegalArgumentException("specified sheet name has not been found in xls file");
                }
            } else {
                throw new IllegalArgumentException("sheet name param value was not specified");
            }
        }
        return arrayList;
    }

    public static String getInputFileName(String[] strArr) {
        return strArr[strArr.length - 1];
    }

    public static String getOutputFileName(String str) {
        if (str.contains("xls")) {
            return str.replace(".xls", ".xml");
        }
        return a.b(str, ".xml");
    }

    public static List<Integer> getSheetsIndexes(String[] strArr, HSSFWorkbook hSSFWorkbook) {
        ArrayList arrayList = new ArrayList();
        arrayList.addAll(getIndexesByIdArray(strArr));
        arrayList.addAll(getIndexesByName(strArr, hSSFWorkbook));
        if (arrayList.size() == 0) {
            int numberOfSheets = hSSFWorkbook.getNumberOfSheets();
            for (int i2 = 0; i2 < numberOfSheets; i2++) {
                arrayList.add(Integer.valueOf(i2));
            }
        }
        return arrayList;
    }

    public static boolean isExcludeWorkbookRecords(String[] strArr) {
        return -1 != getAttributeIndex(EXCLUDE_WORKBOOK_RECORDS, strArr);
    }

    public static void main(String[] strArr) {
        if (strArr.length == 0) {
            System.out.println("Usage: BiffDrawingToXml [options] inputWorkbook");
            System.out.println("Options:");
            System.out.println("  -exclude-workbook            exclude workbook-level records");
            System.out.println("  -sheet-indexes   <indexes>   output sheets with specified indexes");
            System.out.println("  -sheet-namek  <names>        output sheets with specified name");
            return;
        }
        String inputFileName = getInputFileName(strArr);
        FileInputStream fileInputStream = new FileInputStream(inputFileName);
        FileOutputStream fileOutputStream = new FileOutputStream(getOutputFileName(inputFileName));
        writeToFile(fileOutputStream, fileInputStream, isExcludeWorkbookRecords(strArr), strArr);
        fileInputStream.close();
        fileOutputStream.close();
    }

    public static void writeToFile(OutputStream outputStream, InputStream inputStream, boolean z, String[] strArr) {
        HSSFWorkbook hSSFWorkbook = new HSSFWorkbook(inputStream);
        DrawingGroupRecord drawingGroupRecord = (DrawingGroupRecord) hSSFWorkbook.getInternalWorkbook().findFirstRecordBySid(DrawingGroupRecord.sid);
        StringBuilder b2 = a.b("<workbook>\n");
        if (!z && drawingGroupRecord != null) {
            drawingGroupRecord.decode();
            for (EscherRecord escherRecord : drawingGroupRecord.getEscherRecords()) {
                b2.append(escherRecord.toXml("\t"));
            }
        }
        for (Integer num : getSheetsIndexes(strArr, hSSFWorkbook)) {
            HSSFPatriarch drawingPatriarch = hSSFWorkbook.getSheetAt(num.intValue()).getDrawingPatriarch();
            if (drawingPatriarch != null) {
                b2.append("\t");
                b2.append("<sheet");
                b2.append(num);
                b2.append(">\n");
                b2.append(drawingPatriarch.getBoundAggregate().toXml("\t\t"));
                b2.append("\t");
                b2.append("</sheet");
                b2.append(num);
                b2.append(">\n");
            }
        }
        b2.append("</workbook>\n");
        outputStream.write(b2.toString().getBytes(StringUtil.UTF8));
        outputStream.close();
        hSSFWorkbook.close();
    }
}
