package org.apache.poi.hssf.dev;

import b.b.a.a.a;
import java.io.DataInputStream;
import java.io.File;
import java.io.FileOutputStream;
import java.io.IOException;
import java.io.InputStream;
import java.io.OutputStreamWriter;
import java.io.PrintWriter;
import java.io.Writer;
import java.nio.charset.Charset;
import java.util.ArrayList;
import java.util.List;
import org.apache.poi.hssf.record.ArrayRecord;
import org.apache.poi.hssf.record.AutoFilterInfoRecord;
import org.apache.poi.hssf.record.BOFRecord;
import org.apache.poi.hssf.record.BackupRecord;
import org.apache.poi.hssf.record.BlankRecord;
import org.apache.poi.hssf.record.BookBoolRecord;
import org.apache.poi.hssf.record.BoolErrRecord;
import org.apache.poi.hssf.record.BottomMarginRecord;
import org.apache.poi.hssf.record.BoundSheetRecord;
import org.apache.poi.hssf.record.CFHeader12Record;
import org.apache.poi.hssf.record.CFHeaderRecord;
import org.apache.poi.hssf.record.CFRule12Record;
import org.apache.poi.hssf.record.CFRuleRecord;
import org.apache.poi.hssf.record.CalcCountRecord;
import org.apache.poi.hssf.record.CalcModeRecord;
import org.apache.poi.hssf.record.CodepageRecord;
import org.apache.poi.hssf.record.ColumnInfoRecord;
import org.apache.poi.hssf.record.ContinueRecord;
import org.apache.poi.hssf.record.CountryRecord;
import org.apache.poi.hssf.record.DBCellRecord;
import org.apache.poi.hssf.record.DConRefRecord;
import org.apache.poi.hssf.record.DSFRecord;
import org.apache.poi.hssf.record.DVALRecord;
import org.apache.poi.hssf.record.DVRecord;
import org.apache.poi.hssf.record.DateWindow1904Record;
import org.apache.poi.hssf.record.DefaultColWidthRecord;
import org.apache.poi.hssf.record.DefaultRowHeightRecord;
import org.apache.poi.hssf.record.DeltaRecord;
import org.apache.poi.hssf.record.DimensionsRecord;
import org.apache.poi.hssf.record.DrawingGroupRecord;
import org.apache.poi.hssf.record.DrawingRecordForBiffViewer;
import org.apache.poi.hssf.record.DrawingSelectionRecord;
import org.apache.poi.hssf.record.EOFRecord;
import org.apache.poi.hssf.record.ExtSSTRecord;
import org.apache.poi.hssf.record.ExtendedFormatRecord;
import org.apache.poi.hssf.record.ExternSheetRecord;
import org.apache.poi.hssf.record.ExternalNameRecord;
import org.apache.poi.hssf.record.FeatHdrRecord;
import org.apache.poi.hssf.record.FeatRecord;
import org.apache.poi.hssf.record.FilePassRecord;
import org.apache.poi.hssf.record.FileSharingRecord;
import org.apache.poi.hssf.record.FnGroupCountRecord;
import org.apache.poi.hssf.record.FontRecord;
import org.apache.poi.hssf.record.FooterRecord;
import org.apache.poi.hssf.record.FormatRecord;
import org.apache.poi.hssf.record.FormulaRecord;
import org.apache.poi.hssf.record.GridsetRecord;
import org.apache.poi.hssf.record.GutsRecord;
import org.apache.poi.hssf.record.HCenterRecord;
import org.apache.poi.hssf.record.HeaderRecord;
import org.apache.poi.hssf.record.HideObjRecord;
import org.apache.poi.hssf.record.HorizontalPageBreakRecord;
import org.apache.poi.hssf.record.HyperlinkRecord;
import org.apache.poi.hssf.record.IndexRecord;
import org.apache.poi.hssf.record.InterfaceEndRecord;
import org.apache.poi.hssf.record.InterfaceHdrRecord;
import org.apache.poi.hssf.record.IterationRecord;
import org.apache.poi.hssf.record.LabelRecord;
import org.apache.poi.hssf.record.LabelSSTRecord;
import org.apache.poi.hssf.record.LeftMarginRecord;
import org.apache.poi.hssf.record.MMSRecord;
import org.apache.poi.hssf.record.MergeCellsRecord;
import org.apache.poi.hssf.record.MulBlankRecord;
import org.apache.poi.hssf.record.MulRKRecord;
import org.apache.poi.hssf.record.NameCommentRecord;
import org.apache.poi.hssf.record.NameRecord;
import org.apache.poi.hssf.record.NoteRecord;
import org.apache.poi.hssf.record.NumberRecord;
import org.apache.poi.hssf.record.ObjRecord;
import org.apache.poi.hssf.record.PaletteRecord;
import org.apache.poi.hssf.record.PaneRecord;
import org.apache.poi.hssf.record.PasswordRecord;
import org.apache.poi.hssf.record.PasswordRev4Record;
import org.apache.poi.hssf.record.PrecisionRecord;
import org.apache.poi.hssf.record.PrintGridlinesRecord;
import org.apache.poi.hssf.record.PrintHeadersRecord;
import org.apache.poi.hssf.record.PrintSetupRecord;
import org.apache.poi.hssf.record.ProtectRecord;
import org.apache.poi.hssf.record.ProtectionRev4Record;
import org.apache.poi.hssf.record.RKRecord;
import org.apache.poi.hssf.record.RecalcIdRecord;
import org.apache.poi.hssf.record.Record;
import org.apache.poi.hssf.record.RecordInputStream;
import org.apache.poi.hssf.record.RefModeRecord;
import org.apache.poi.hssf.record.RefreshAllRecord;
import org.apache.poi.hssf.record.RightMarginRecord;
import org.apache.poi.hssf.record.RowRecord;
import org.apache.poi.hssf.record.SCLRecord;
import org.apache.poi.hssf.record.SSTRecord;
import org.apache.poi.hssf.record.SaveRecalcRecord;
import org.apache.poi.hssf.record.SelectionRecord;
import org.apache.poi.hssf.record.SharedFormulaRecord;
import org.apache.poi.hssf.record.StringRecord;
import org.apache.poi.hssf.record.StyleRecord;
import org.apache.poi.hssf.record.SupBookRecord;
import org.apache.poi.hssf.record.TabIdRecord;
import org.apache.poi.hssf.record.TableRecord;
import org.apache.poi.hssf.record.TableStylesRecord;
import org.apache.poi.hssf.record.TextObjectRecord;
import org.apache.poi.hssf.record.TopMarginRecord;
import org.apache.poi.hssf.record.UncalcedRecord;
import org.apache.poi.hssf.record.UnknownRecord;
import org.apache.poi.hssf.record.UseSelFSRecord;
import org.apache.poi.hssf.record.VCenterRecord;
import org.apache.poi.hssf.record.VerticalPageBreakRecord;
import org.apache.poi.hssf.record.WSBoolRecord;
import org.apache.poi.hssf.record.WindowOneRecord;
import org.apache.poi.hssf.record.WindowProtectRecord;
import org.apache.poi.hssf.record.WindowTwoRecord;
import org.apache.poi.hssf.record.WriteAccessRecord;
import org.apache.poi.hssf.record.WriteProtectRecord;
import org.apache.poi.hssf.record.chart.AreaFormatRecord;
import org.apache.poi.hssf.record.chart.AreaRecord;
import org.apache.poi.hssf.record.chart.AxisLineFormatRecord;
import org.apache.poi.hssf.record.chart.AxisOptionsRecord;
import org.apache.poi.hssf.record.chart.AxisParentRecord;
import org.apache.poi.hssf.record.chart.AxisRecord;
import org.apache.poi.hssf.record.chart.AxisUsedRecord;
import org.apache.poi.hssf.record.chart.BarRecord;
import org.apache.poi.hssf.record.chart.BeginRecord;
import org.apache.poi.hssf.record.chart.CatLabRecord;
import org.apache.poi.hssf.record.chart.CategorySeriesAxisRecord;
import org.apache.poi.hssf.record.chart.ChartEndBlockRecord;
import org.apache.poi.hssf.record.chart.ChartEndObjectRecord;
import org.apache.poi.hssf.record.chart.ChartFRTInfoRecord;
import org.apache.poi.hssf.record.chart.ChartFormatRecord;
import org.apache.poi.hssf.record.chart.ChartRecord;
import org.apache.poi.hssf.record.chart.ChartStartBlockRecord;
import org.apache.poi.hssf.record.chart.ChartStartObjectRecord;
import org.apache.poi.hssf.record.chart.DatRecord;
import org.apache.poi.hssf.record.chart.DataFormatRecord;
import org.apache.poi.hssf.record.chart.DefaultDataLabelTextPropertiesRecord;
import org.apache.poi.hssf.record.chart.EndRecord;
import org.apache.poi.hssf.record.chart.FontBasisRecord;
import org.apache.poi.hssf.record.chart.FontIndexRecord;
import org.apache.poi.hssf.record.chart.FrameRecord;
import org.apache.poi.hssf.record.chart.LegendRecord;
import org.apache.poi.hssf.record.chart.LineFormatRecord;
import org.apache.poi.hssf.record.chart.LinkedDataRecord;
import org.apache.poi.hssf.record.chart.ObjectLinkRecord;
import org.apache.poi.hssf.record.chart.PlotAreaRecord;
import org.apache.poi.hssf.record.chart.PlotGrowthRecord;
import org.apache.poi.hssf.record.chart.SeriesIndexRecord;
import org.apache.poi.hssf.record.chart.SeriesListRecord;
import org.apache.poi.hssf.record.chart.SeriesRecord;
import org.apache.poi.hssf.record.chart.SeriesTextRecord;
import org.apache.poi.hssf.record.chart.SeriesToChartGroupRecord;
import org.apache.poi.hssf.record.chart.SheetPropertiesRecord;
import org.apache.poi.hssf.record.chart.TextRecord;
import org.apache.poi.hssf.record.chart.TickRecord;
import org.apache.poi.hssf.record.chart.UnitsRecord;
import org.apache.poi.hssf.record.chart.ValueRangeRecord;
import org.apache.poi.hssf.record.pivottable.DataItemRecord;
import org.apache.poi.hssf.record.pivottable.ExtendedPivotTableViewFieldsRecord;
import org.apache.poi.hssf.record.pivottable.PageItemRecord;
import org.apache.poi.hssf.record.pivottable.StreamIDRecord;
import org.apache.poi.hssf.record.pivottable.ViewDefinitionRecord;
import org.apache.poi.hssf.record.pivottable.ViewFieldsRecord;
import org.apache.poi.hssf.record.pivottable.ViewSourceRecord;
import org.apache.poi.hssf.usermodel.HSSFShapeTypes;
import org.apache.poi.hssf.usermodel.HSSFWorkbook;
import org.apache.poi.poifs.filesystem.NPOIFSFileSystem;
import org.apache.poi.util.HexDump;
import org.apache.poi.util.IOUtils;
import org.apache.poi.util.LittleEndian;
import org.apache.poi.util.POILogFactory;
import org.apache.poi.util.POILogger;
import org.apache.poi.util.StringUtil;
import org.apache.poi.util.SuppressForbidden;
import org.apache.xerces.impl.xs.SchemaSymbols;
import org.apache.xmlbeans.impl.common.NameUtil;

public final class BiffViewer {
    public static final char[] COLUMN_SEPARATOR = " | ".toCharArray();
    public static final int DUMP_LINE_LEN = 16;
    public static final char[] NEW_LINE_CHARS = System.getProperty("line.separator").toCharArray();
    public static final POILogger logger = POILogFactory.getLogger(BiffViewer.class);

    public static final class BiffRecordListener implements IBiffRecordListener {
        public List<String> _headers = new ArrayList();
        public final Writer _hexDumpWriter;
        public final boolean _noHeader;
        public final boolean _zeroAlignEachRecord;

        public BiffRecordListener(Writer writer, boolean z, boolean z2) {
            this._hexDumpWriter = writer;
            this._zeroAlignEachRecord = z;
            this._noHeader = z2;
        }

        public static String formatRecordDetails(int i2, int i3, int i4, int i5) {
            StringBuilder sb = new StringBuilder(64);
            sb.append("Offset=");
            sb.append(HexDump.intToHex(i2));
            sb.append("(");
            sb.append(i2);
            sb.append(")");
            sb.append(" recno=");
            sb.append(i5);
            sb.append(" sid=");
            sb.append(HexDump.shortToHex(i3));
            sb.append(" size=");
            sb.append(HexDump.shortToHex(i4));
            sb.append("(");
            return a.a(sb, i4, ")");
        }

        public List<String> getRecentHeaders() {
            List<String> list = this._headers;
            this._headers = new ArrayList();
            return list;
        }

        @Override // org.apache.poi.hssf.dev.BiffViewer.IBiffRecordListener
        public void processRecord(int i2, int i3, int i4, int i5, byte[] bArr) {
            String formatRecordDetails = formatRecordDetails(i2, i4, i5, i3);
            if (!this._noHeader) {
                this._headers.add(formatRecordDetails);
            }
            Writer writer = this._hexDumpWriter;
            if (writer != null) {
                try {
                    writer.write(formatRecordDetails);
                    writer.write(BiffViewer.NEW_LINE_CHARS);
                    BiffViewer.hexDumpAligned(writer, bArr, i5 + 4, i2, this._zeroAlignEachRecord);
                    writer.flush();
                } catch (IOException e2) {
                    throw new RuntimeException(e2);
                }
            }
        }
    }

    public static final class CommandArgs {
        public final boolean _biffhex;
        public final File _file;
        public final boolean _noHeader;
        public final boolean _noint;
        public final boolean _out;
        public final boolean _rawhex;

        public CommandArgs(boolean z, boolean z2, boolean z3, boolean z4, boolean z5, File file) {
            this._biffhex = z;
            this._noint = z2;
            this._out = z3;
            this._rawhex = z4;
            this._file = file;
            this._noHeader = z5;
        }

        public static CommandArgs parse(String[] strArr) {
            int length = strArr.length;
            boolean z = false;
            boolean z2 = false;
            boolean z3 = false;
            boolean z4 = false;
            boolean z5 = false;
            File file = null;
            for (int i2 = 0; i2 < length; i2++) {
                String str = strArr[i2];
                if (!str.startsWith("--")) {
                    file = new File(str);
                    if (!file.exists()) {
                        throw new CommandParseException(a.b("Specified file '", str, "' does not exist"));
                    } else if (i2 + 1 < length) {
                        throw new CommandParseException("File name must be the last arg");
                    }
                } else if ("--biffhex".equals(str)) {
                    z = true;
                } else if ("--noint".equals(str)) {
                    z2 = true;
                } else if ("--out".equals(str)) {
                    z3 = true;
                } else if ("--escher".equals(str)) {
                    System.setProperty("poi.deserialize.escher", SchemaSymbols.ATTVAL_TRUE);
                } else if ("--rawhex".equals(str)) {
                    z4 = true;
                } else if ("--noheader".equals(str)) {
                    z5 = true;
                } else {
                    throw new CommandParseException(a.b("Unexpected option '", str, "'"));
                }
            }
            if (file != null) {
                return new CommandArgs(z, z2, z3, z4, z5, file);
            }
            throw new CommandParseException("Biff viewer needs a filename");
        }

        public File getFile() {
            return this._file;
        }

        public boolean shouldDumpBiffHex() {
            return this._biffhex;
        }

        public boolean shouldDumpRecordInterpretations() {
            return !this._noint;
        }

        public boolean shouldOutputRawHexOnly() {
            return this._rawhex;
        }

        public boolean shouldOutputToFile() {
            return this._out;
        }

        public boolean suppressHeader() {
            return this._noHeader;
        }
    }

    public static final class CommandParseException extends Exception {
        public CommandParseException(String str) {
            super(str);
        }
    }

    public interface IBiffRecordListener {
        void processRecord(int i2, int i3, int i4, int i5, byte[] bArr);
    }

    public static int arraycopy(char[] cArr, char[] cArr2, int i2) {
        int length = cArr.length;
        int i3 = 0;
        while (i3 < length) {
            cArr2[i2] = cArr[i3];
            i3++;
            i2++;
        }
        return i2;
    }

    public static Record createRecord(RecordInputStream recordInputStream) {
        short sid = recordInputStream.getSid();
        if (sid == 34) {
            return new DateWindow1904Record(recordInputStream);
        }
        if (sid == 35) {
            return new ExternalNameRecord(recordInputStream);
        }
        if (sid == 60) {
            return new ContinueRecord(recordInputStream);
        }
        if (sid == 61) {
            return new WindowOneRecord(recordInputStream);
        }
        if (sid == 140) {
            return new CountryRecord(recordInputStream);
        }
        if (sid == 141) {
            return new HideObjRecord(recordInputStream);
        }
        if (sid == 156) {
            return new FnGroupCountRecord(recordInputStream);
        }
        if (sid == 157) {
            return new AutoFilterInfoRecord(recordInputStream);
        }
        switch (sid) {
            case 6:
                return new FormulaRecord(recordInputStream);
            case 10:
                return new EOFRecord(recordInputStream);
            case 12:
                return new CalcCountRecord(recordInputStream);
            case 13:
                return new CalcModeRecord(recordInputStream);
            case 14:
                return new PrecisionRecord(recordInputStream);
            case 15:
                return new RefModeRecord(recordInputStream);
            case 16:
                return new DeltaRecord(recordInputStream);
            case 17:
                return new IterationRecord(recordInputStream);
            case 18:
                return new ProtectRecord(recordInputStream);
            case 19:
                return new PasswordRecord(recordInputStream);
            case 20:
                return new HeaderRecord(recordInputStream);
            case 21:
                return new FooterRecord(recordInputStream);
            case 47:
                return new FilePassRecord(recordInputStream);
            case 49:
                return new FontRecord(recordInputStream);
            case 81:
                return new DConRefRecord(recordInputStream);
            case 85:
                return new DefaultColWidthRecord(recordInputStream);
            case 125:
                return new ColumnInfoRecord(recordInputStream);
            case 146:
                return new PaletteRecord(recordInputStream);
            case 160:
                return new SCLRecord(recordInputStream);
            case 161:
                return new PrintSetupRecord(recordInputStream);
            case 176:
                return new ViewDefinitionRecord(recordInputStream);
            case 177:
                return new ViewFieldsRecord(recordInputStream);
            case 182:
                return new PageItemRecord(recordInputStream);
            case 189:
                return new MulRKRecord(recordInputStream);
            case 190:
                return new MulBlankRecord(recordInputStream);
            case HSSFShapeTypes.ActionButtonForwardNext /*{ENCODED_INT: 193}*/:
                return new MMSRecord(recordInputStream);
            case HSSFShapeTypes.ActionButtonReturn /*{ENCODED_INT: 197}*/:
                return new DataItemRecord(recordInputStream);
            case 213:
                return new StreamIDRecord(recordInputStream);
            case 215:
                return new DBCellRecord(recordInputStream);
            case 218:
                return new BookBoolRecord(recordInputStream);
            case 224:
                return new ExtendedFormatRecord(recordInputStream);
            case 225:
                return new InterfaceHdrRecord(recordInputStream);
            case 226:
                return InterfaceEndRecord.create(recordInputStream);
            case 227:
                return new ViewSourceRecord(recordInputStream);
            case 229:
                return new MergeCellsRecord(recordInputStream);
            case 235:
                return new DrawingGroupRecord(recordInputStream);
            case 236:
                return new DrawingRecordForBiffViewer(recordInputStream);
            case 237:
                return new DrawingSelectionRecord(recordInputStream);
            case 252:
                return new SSTRecord(recordInputStream);
            case 253:
                return new LabelSSTRecord(recordInputStream);
            case 255:
                return new ExtSSTRecord(recordInputStream);
            case 256:
                return new ExtendedPivotTableViewFieldsRecord(recordInputStream);
            case 317:
                return new TabIdRecord(recordInputStream);
            case 352:
                return new UseSelFSRecord(recordInputStream);
            case 353:
                return new DSFRecord(recordInputStream);
            case 430:
                return new SupBookRecord(recordInputStream);
            case 431:
                return new ProtectionRev4Record(recordInputStream);
            case 432:
                return new CFHeaderRecord(recordInputStream);
            case 433:
                return new CFRuleRecord(recordInputStream);
            case 434:
                return new DVALRecord(recordInputStream);
            case 438:
                return new TextObjectRecord(recordInputStream);
            case 439:
                return new RefreshAllRecord(recordInputStream);
            case 440:
                return new HyperlinkRecord(recordInputStream);
            case 444:
                return new PasswordRev4Record(recordInputStream);
            case 446:
                return new DVRecord(recordInputStream);
            case 449:
                return new RecalcIdRecord(recordInputStream);
            case 512:
                return new DimensionsRecord(recordInputStream);
            case 513:
                return new BlankRecord(recordInputStream);
            case 515:
                return new NumberRecord(recordInputStream);
            case 516:
                return new LabelRecord(recordInputStream);
            case 517:
                return new BoolErrRecord(recordInputStream);
            case 519:
                return new StringRecord(recordInputStream);
            case 520:
                return new RowRecord(recordInputStream);
            case 523:
                return new IndexRecord(recordInputStream);
            case 545:
                return new ArrayRecord(recordInputStream);
            case 549:
                return new DefaultRowHeightRecord(recordInputStream);
            case 566:
                return new TableRecord(recordInputStream);
            case 574:
                return new WindowTwoRecord(recordInputStream);
            case 638:
                return new RKRecord(recordInputStream);
            case 659:
                return new StyleRecord(recordInputStream);
            case 1054:
                return new FormatRecord(recordInputStream);
            case 1212:
                return new SharedFormulaRecord(recordInputStream);
            case 2057:
                return new BOFRecord(recordInputStream);
            case 2128:
                return new ChartFRTInfoRecord(recordInputStream);
            case 2130:
                return new ChartStartBlockRecord(recordInputStream);
            case 2131:
                return new ChartEndBlockRecord(recordInputStream);
            case 2132:
                return new ChartStartObjectRecord(recordInputStream);
            case 2133:
                return new ChartEndObjectRecord(recordInputStream);
            case 2134:
                return new CatLabRecord(recordInputStream);
            case UnknownRecord.SHEETPROTECTION_0867:
                return new FeatHdrRecord(recordInputStream);
            case 2152:
                return new FeatRecord(recordInputStream);
            case 2169:
                return new CFHeader12Record(recordInputStream);
            case 2170:
                return new CFRule12Record(recordInputStream);
            case 2190:
                return new TableStylesRecord(recordInputStream);
            case 2196:
                return new NameCommentRecord(recordInputStream);
            case 4097:
                return new UnitsRecord(recordInputStream);
            case 4098:
                return new ChartRecord(recordInputStream);
            case 4099:
                return new SeriesRecord(recordInputStream);
            case 4102:
                return new DataFormatRecord(recordInputStream);
            case 4103:
                return new LineFormatRecord(recordInputStream);
            case 4106:
                return new AreaFormatRecord(recordInputStream);
            case 4109:
                return new SeriesTextRecord(recordInputStream);
            case 4116:
                return new ChartFormatRecord(recordInputStream);
            case 4117:
                return new LegendRecord(recordInputStream);
            case 4118:
                return new SeriesListRecord(recordInputStream);
            case 4119:
                return new BarRecord(recordInputStream);
            case 4122:
                return new AreaRecord(recordInputStream);
            case 4125:
                return new AxisRecord(recordInputStream);
            case 4126:
                return new TickRecord(recordInputStream);
            case 4127:
                return new ValueRangeRecord(recordInputStream);
            case 4128:
                return new CategorySeriesAxisRecord(recordInputStream);
            case 4129:
                return new AxisLineFormatRecord(recordInputStream);
            case 4132:
                return new DefaultDataLabelTextPropertiesRecord(recordInputStream);
            case 4133:
                return new TextRecord(recordInputStream);
            case 4134:
                return new FontIndexRecord(recordInputStream);
            case 4135:
                return new ObjectLinkRecord(recordInputStream);
            case 4146:
                return new FrameRecord(recordInputStream);
            case 4147:
                return new BeginRecord(recordInputStream);
            case 4148:
                return new EndRecord(recordInputStream);
            case 4149:
                return new PlotAreaRecord(recordInputStream);
            case 4161:
                return new AxisParentRecord(recordInputStream);
            case 4164:
                return new SheetPropertiesRecord(recordInputStream);
            case 4165:
                return new SeriesToChartGroupRecord(recordInputStream);
            case 4166:
                return new AxisUsedRecord(recordInputStream);
            case 4177:
                return new LinkedDataRecord(recordInputStream);
            case 4192:
                return new FontBasisRecord(recordInputStream);
            case 4194:
                return new AxisOptionsRecord(recordInputStream);
            case 4195:
                return new DatRecord(recordInputStream);
            case 4196:
                return new PlotGrowthRecord(recordInputStream);
            case 4197:
                return new SeriesIndexRecord(recordInputStream);
            default:
                switch (sid) {
                    case 23:
                        return new ExternSheetRecord(recordInputStream);
                    case 24:
                        return new NameRecord(recordInputStream);
                    case 25:
                        return new WindowProtectRecord(recordInputStream);
                    case 26:
                        return new VerticalPageBreakRecord(recordInputStream);
                    case 27:
                        return new HorizontalPageBreakRecord(recordInputStream);
                    case 28:
                        return new NoteRecord(recordInputStream);
                    case 29:
                        return new SelectionRecord(recordInputStream);
                    default:
                        switch (sid) {
                            case 38:
                                return new LeftMarginRecord(recordInputStream);
                            case 39:
                                return new RightMarginRecord(recordInputStream);
                            case 40:
                                return new TopMarginRecord(recordInputStream);
                            case 41:
                                return new BottomMarginRecord(recordInputStream);
                            case 42:
                                return new PrintHeadersRecord(recordInputStream);
                            case 43:
                                return new PrintGridlinesRecord(recordInputStream);
                            default:
                                switch (sid) {
                                    case 64:
                                        return new BackupRecord(recordInputStream);
                                    case 65:
                                        return new PaneRecord(recordInputStream);
                                    case 66:
                                        return new CodepageRecord(recordInputStream);
                                    default:
                                        switch (sid) {
                                            case 91:
                                                return new FileSharingRecord(recordInputStream);
                                            case 92:
                                                return new WriteAccessRecord(recordInputStream);
                                            case 93:
                                                return new ObjRecord(recordInputStream);
                                            case 94:
                                                return new UncalcedRecord(recordInputStream);
                                            case 95:
                                                return new SaveRecalcRecord(recordInputStream);
                                            default:
                                                switch (sid) {
                                                    case 128:
                                                        return new GutsRecord(recordInputStream);
                                                    case 129:
                                                        return new WSBoolRecord(recordInputStream);
                                                    case 130:
                                                        return new GridsetRecord(recordInputStream);
                                                    case 131:
                                                        return new HCenterRecord(recordInputStream);
                                                    case 132:
                                                        return new VCenterRecord(recordInputStream);
                                                    case 133:
                                                        return new BoundSheetRecord(recordInputStream);
                                                    case 134:
                                                        return new WriteProtectRecord(recordInputStream);
                                                    default:
                                                        return new UnknownRecord(recordInputStream);
                                                }
                                        }
                                }
                        }
                }
        }
    }

    public static Record[] createRecords(InputStream inputStream, PrintWriter printWriter, BiffRecordListener biffRecordListener, boolean z) {
        boolean z2;
        ArrayList arrayList = new ArrayList();
        RecordInputStream recordInputStream = new RecordInputStream(inputStream);
        while (true) {
            try {
                z2 = recordInputStream.hasNextRecord();
            } catch (RecordInputStream.LeftoverDataException e2) {
                POILogger pOILogger = logger;
                StringBuilder b2 = a.b("Discarding ");
                b2.append(recordInputStream.remaining());
                b2.append(" bytes and continuing");
                pOILogger.log(7, b2.toString(), e2);
                recordInputStream.readRemainder();
                z2 = recordInputStream.hasNextRecord();
            }
            if (!z2) {
                Record[] recordArr = new Record[arrayList.size()];
                arrayList.toArray(recordArr);
                return recordArr;
            }
            recordInputStream.nextRecord();
            if (recordInputStream.getSid() != 0) {
                if (z) {
                    Record createRecord = createRecord(recordInputStream);
                    if (createRecord.getSid() != 60) {
                        arrayList.add(createRecord);
                        for (String str : biffRecordListener.getRecentHeaders()) {
                            printWriter.println(str);
                        }
                        printWriter.print(createRecord);
                    }
                } else {
                    recordInputStream.readRemainder();
                }
                printWriter.println();
            }
        }
    }

    public static InputStream getPOIFSInputStream(NPOIFSFileSystem nPOIFSFileSystem) {
        return nPOIFSFileSystem.createDocumentInputStream(HSSFWorkbook.getWorkbookDirEntryName(nPOIFSFileSystem.getRoot()));
    }

    public static char getPrintableChar(byte b2) {
        char c = (char) (b2 & 255);
        return (c < ' ' || c > '~') ? NameUtil.PERIOD : c;
    }

    public static void hexDumpAligned(Writer writer, byte[] bArr, int i2, int i3, boolean z) {
        int i4;
        int i5;
        int i6;
        int i7;
        int i8 = i3 + 0;
        int i9 = i2 + i8;
        int i10 = i8 % 16;
        int i11 = i9 % 16;
        if (z) {
            int i12 = i11 - i10;
            if (i12 < 0) {
                i12 += 16;
            }
            i4 = i12;
            i5 = 0;
        } else {
            i5 = i10;
            i4 = i11;
        }
        if (z) {
            i7 = (i9 - i4) - (i8 - i5);
            i6 = 0;
        } else {
            i6 = i8 - i5;
            i7 = i9 - i4;
        }
        int i13 = 0 - i5;
        if (i6 == i7) {
            hexDumpLine(writer, bArr, i6, i13, i5, i4);
            return;
        }
        hexDumpLine(writer, bArr, i6, i13, i5, 16);
        while (true) {
            i6 += 16;
            i13 += 16;
            if (i6 >= i7) {
                break;
            }
            hexDumpLine(writer, bArr, i6, i13, 0, 16);
        }
        if (i4 != 0) {
            hexDumpLine(writer, bArr, i6, i13, 0, i4);
        }
    }

    public static void hexDumpLine(Writer writer, byte[] bArr, int i2, int i3, int i4, int i5) {
        char[] cArr = new char[(((((COLUMN_SEPARATOR.length * 2) + 8) + 48) - 1) + 16 + NEW_LINE_CHARS.length)];
        if (i4 < i5) {
            try {
                writeHex(cArr, 0, i2, 8);
                int arraycopy = arraycopy(COLUMN_SEPARATOR, cArr, 8);
                for (int i6 = 0; i6 < 16; i6++) {
                    if (i6 > 0) {
                        cArr[arraycopy] = ' ';
                        arraycopy++;
                    }
                    if (i6 < i4 || i6 >= i5) {
                        cArr[arraycopy] = ' ';
                        cArr[arraycopy + 1] = ' ';
                    } else {
                        writeHex(cArr, arraycopy, bArr[i3 + i6], 2);
                    }
                    arraycopy += 2;
                }
                int arraycopy2 = arraycopy(COLUMN_SEPARATOR, cArr, arraycopy);
                int i7 = 0;
                while (i7 < 16) {
                    cArr[arraycopy2] = (i7 < i4 || i7 >= i5) ? ' ' : getPrintableChar(bArr[i3 + i7]);
                    i7++;
                    arraycopy2++;
                }
                writer.write(cArr, 0, arraycopy(NEW_LINE_CHARS, cArr, arraycopy2));
            } catch (IOException e2) {
                throw new RuntimeException(e2);
            }
        } else {
            throw new IllegalArgumentException("Bad start/end delta");
        }
    }

    public static void main(String[] strArr) {
        PrintWriter printWriter;
        Throwable th;
        NPOIFSFileSystem nPOIFSFileSystem;
        CommandArgs parse = CommandArgs.parse(strArr);
        if (parse.shouldOutputToFile()) {
            printWriter = new PrintWriter(new OutputStreamWriter(new FileOutputStream(parse.getFile().getAbsolutePath() + ".out"), StringUtil.UTF8));
        } else {
            printWriter = new PrintWriter(new OutputStreamWriter(System.out, Charset.defaultCharset()));
        }
        try {
            nPOIFSFileSystem = new NPOIFSFileSystem(parse.getFile(), true);
            try {
                InputStream pOIFSInputStream = getPOIFSInputStream(nPOIFSFileSystem);
                if (parse.shouldOutputRawHexOnly()) {
                    HexDump.dump(IOUtils.toByteArray(pOIFSInputStream), 0, System.out, 0);
                } else {
                    boolean shouldDumpRecordInterpretations = parse.shouldDumpRecordInterpretations();
                    runBiffViewer(printWriter, pOIFSInputStream, shouldDumpRecordInterpretations, parse.shouldDumpBiffHex(), shouldDumpRecordInterpretations, parse.suppressHeader());
                }
                IOUtils.closeQuietly(pOIFSInputStream);
                IOUtils.closeQuietly(nPOIFSFileSystem);
                IOUtils.closeQuietly(printWriter);
            } catch (Throwable th2) {
                th = th2;
                IOUtils.closeQuietly(null);
                IOUtils.closeQuietly(nPOIFSFileSystem);
                IOUtils.closeQuietly(printWriter);
                throw th;
            }
        } catch (Throwable th3) {
            th = th3;
            nPOIFSFileSystem = null;
            IOUtils.closeQuietly(null);
            IOUtils.closeQuietly(nPOIFSFileSystem);
            IOUtils.closeQuietly(printWriter);
            throw th;
        }
    }

    public static void runBiffViewer(PrintWriter printWriter, InputStream inputStream, boolean z, boolean z2, boolean z3, boolean z4) {
        BiffRecordListener biffRecordListener = new BiffRecordListener(z2 ? printWriter : null, z3, z4);
        createRecords(new BiffDumpingStream(inputStream, biffRecordListener), printWriter, biffRecordListener, z);
    }

    public static void writeHex(char[] cArr, int i2, int i3, int i4) {
        for (int i5 = i4 - 1; i5 >= 0; i5--) {
            int i6 = i3 & 15;
            cArr[i2 + i5] = (char) (i6 < 10 ? i6 + 48 : (i6 + 65) - 10);
            i3 >>>= 4;
        }
    }

    public static final class BiffDumpingStream extends InputStream {
        public int _currentPos = 0;
        public int _currentSize = 0;
        public final byte[] _data = new byte[DrawingGroupRecord.MAX_RECORD_SIZE];
        public boolean _innerHasReachedEOF;
        public final DataInputStream _is;
        public final IBiffRecordListener _listener;
        public int _overallStreamPos = 0;
        public int _recordCounter = 0;

        public BiffDumpingStream(InputStream inputStream, IBiffRecordListener iBiffRecordListener) {
            this._is = new DataInputStream(inputStream);
            this._listener = iBiffRecordListener;
        }

        private void fillNextBuffer() {
            if (!this._innerHasReachedEOF) {
                int read = this._is.read();
                if (read == -1) {
                    this._innerHasReachedEOF = true;
                    return;
                }
                byte[] bArr = this._data;
                bArr[0] = (byte) read;
                this._is.readFully(bArr, 1, 3);
                short s = LittleEndian.getShort(this._data, 2);
                this._is.readFully(this._data, 4, s);
                this._currentPos = 0;
                this._currentSize = s + 4;
                this._recordCounter++;
            }
        }

        private void formatBufferIfAtEndOfRec() {
            int i2 = this._currentPos;
            int i3 = this._currentSize;
            if (i2 == i3) {
                short s = LittleEndian.getShort(this._data, 0);
                IBiffRecordListener iBiffRecordListener = this._listener;
                iBiffRecordListener.processRecord(this._overallStreamPos - this._currentSize, this._recordCounter, s, i3 - 4, this._data);
            }
        }

        @Override // java.io.InputStream
        @SuppressForbidden("just delegating the call")
        public int available() {
            return this._is.available() + (this._currentSize - this._currentPos);
        }

        @Override // java.io.Closeable, java.lang.AutoCloseable, java.io.InputStream
        public void close() {
            this._is.close();
        }

        @Override // java.io.InputStream
        public int read() {
            if (this._currentPos >= this._currentSize) {
                fillNextBuffer();
            }
            int i2 = this._currentPos;
            if (i2 >= this._currentSize) {
                return -1;
            }
            int i3 = this._data[i2] & 255;
            this._currentPos = i2 + 1;
            this._overallStreamPos++;
            formatBufferIfAtEndOfRec();
            return i3;
        }

        @Override // java.io.InputStream
        public int read(byte[] bArr, int i2, int i3) {
            if (this._currentPos >= this._currentSize) {
                fillNextBuffer();
            }
            int i4 = this._currentPos;
            int i5 = this._currentSize;
            if (i4 >= i5) {
                return -1;
            }
            int i6 = i5 - i4;
            if (i3 > i6) {
                System.err.println("Unexpected request to read past end of current biff record");
                i3 = i6;
            }
            System.arraycopy(this._data, this._currentPos, bArr, i2, i3);
            this._currentPos += i3;
            this._overallStreamPos += i3;
            formatBufferIfAtEndOfRec();
            return i3;
        }
    }
}
