package org.apache.poi.hssf.dev;

import b.b.a.a.a;
import java.io.File;
import java.io.InputStream;
import java.io.PrintStream;
import org.apache.poi.hssf.model.HSSFFormulaParser;
import org.apache.poi.hssf.record.FormulaRecord;
import org.apache.poi.hssf.record.Record;
import org.apache.poi.hssf.record.RecordFactory;
import org.apache.poi.poifs.filesystem.NPOIFSFileSystem;
import org.apache.poi.ss.formula.ptg.ExpPtg;
import org.apache.poi.ss.formula.ptg.FuncPtg;
import org.apache.poi.ss.formula.ptg.Ptg;

public class FormulaViewer {
    public String file;
    public boolean list = false;

    public static String composeFormula(FormulaRecord formulaRecord) {
        return HSSFFormulaParser.toFormulaString(null, formulaRecord.getParsedExpression());
    }

    private String formulaString(FormulaRecord formulaRecord) {
        StringBuilder sb = new StringBuilder();
        Ptg[] parsedExpression = formulaRecord.getParsedExpression();
        for (Ptg ptg : parsedExpression) {
            sb.append(ptg.toFormulaString());
            byte ptgClass = ptg.getPtgClass();
            if (ptgClass == 0) {
                sb.append("(R)");
            } else if (ptgClass == 32) {
                sb.append("(V)");
            } else if (ptgClass != 64) {
                throwInvalidRVAToken(ptg);
            } else {
                sb.append("(A)");
            }
            sb.append(' ');
        }
        return sb.toString();
    }

    private void listFormula(FormulaRecord formulaRecord) {
        String str;
        Ptg[] parsedExpression = formulaRecord.getParsedExpression();
        int length = parsedExpression.length;
        int i2 = length - 1;
        Ptg ptg = parsedExpression[i2];
        if (ptg instanceof FuncPtg) {
            str = String.valueOf(i2);
        } else {
            str = String.valueOf(-1);
        }
        StringBuilder sb = new StringBuilder();
        if (!(ptg instanceof ExpPtg)) {
            sb.append(ptg.toFormulaString());
            sb.append("~");
            byte ptgClass = ptg.getPtgClass();
            if (ptgClass == 0) {
                sb.append("REF");
            } else if (ptgClass == 32) {
                sb.append("VALUE");
            } else if (ptgClass != 64) {
                throwInvalidRVAToken(ptg);
            } else {
                sb.append("ARRAY");
            }
            sb.append("~");
            if (length > 1) {
                Ptg ptg2 = parsedExpression[length - 2];
                byte ptgClass2 = ptg2.getPtgClass();
                if (ptgClass2 == 0) {
                    sb.append("REF");
                } else if (ptgClass2 == 32) {
                    sb.append("VALUE");
                } else if (ptgClass2 != 64) {
                    throwInvalidRVAToken(ptg2);
                } else {
                    sb.append("ARRAY");
                }
            } else {
                sb.append("VALUE");
            }
            sb.append("~");
            sb.append(str);
            System.out.println(sb);
        }
    }

    public static void main(String[] strArr) {
        if (strArr == null || strArr.length > 2 || strArr[0].equals("--help")) {
            System.out.println("FormulaViewer .8 proof that the devil lies in the details (or just in BIFF8 files in general)");
            System.out.println("usage: Give me a big fat file name");
        } else if (strArr[0].equals("--listFunctions")) {
            FormulaViewer formulaViewer = new FormulaViewer();
            formulaViewer.setFile(strArr[1]);
            formulaViewer.setList(true);
            formulaViewer.run();
        } else {
            FormulaViewer formulaViewer2 = new FormulaViewer();
            formulaViewer2.setFile(strArr[0]);
            formulaViewer2.run();
        }
    }

    public static void throwInvalidRVAToken(Ptg ptg) {
        StringBuilder b2 = a.b("Invalid RVA type (");
        b2.append((int) ptg.getPtgClass());
        b2.append("). This should never happen.");
        throw new IllegalStateException(b2.toString());
    }

    public void parseFormulaRecord(FormulaRecord formulaRecord) {
        System.out.println("==============================");
        PrintStream printStream = System.out;
        StringBuilder b2 = a.b("row = ");
        b2.append(formulaRecord.getRow());
        printStream.print(b2.toString());
        PrintStream printStream2 = System.out;
        StringBuilder b3 = a.b(", col = ");
        b3.append((int) formulaRecord.getColumn());
        printStream2.println(b3.toString());
        PrintStream printStream3 = System.out;
        StringBuilder b4 = a.b("value = ");
        b4.append(formulaRecord.getValue());
        printStream3.println(b4.toString());
        PrintStream printStream4 = System.out;
        StringBuilder b5 = a.b("xf = ");
        b5.append((int) formulaRecord.getXFIndex());
        printStream4.print(b5.toString());
        PrintStream printStream5 = System.out;
        StringBuilder b6 = a.b(", number of ptgs = ");
        b6.append(formulaRecord.getParsedExpression().length);
        printStream5.print(b6.toString());
        PrintStream printStream6 = System.out;
        StringBuilder b7 = a.b(", options = ");
        b7.append((int) formulaRecord.getOptions());
        printStream6.println(b7.toString());
        PrintStream printStream7 = System.out;
        StringBuilder b8 = a.b("RPN List = ");
        b8.append(formulaString(formulaRecord));
        printStream7.println(b8.toString());
        PrintStream printStream8 = System.out;
        StringBuilder b9 = a.b("Formula text = ");
        b9.append(composeFormula(formulaRecord));
        printStream8.println(b9.toString());
    }

    /* JADX INFO: finally extract failed */
    public void run() {
        NPOIFSFileSystem nPOIFSFileSystem = new NPOIFSFileSystem(new File(this.file), true);
        try {
            InputStream pOIFSInputStream = BiffViewer.getPOIFSInputStream(nPOIFSFileSystem);
            try {
                for (Record record : RecordFactory.createRecords(pOIFSInputStream)) {
                    if (record.getSid() == 6) {
                        if (this.list) {
                            listFormula((FormulaRecord) record);
                        } else {
                            parseFormulaRecord((FormulaRecord) record);
                        }
                    }
                }
                pOIFSInputStream.close();
            } catch (Throwable th) {
                pOIFSInputStream.close();
                throw th;
            }
        } finally {
            nPOIFSFileSystem.close();
        }
    }

    public void setFile(String str) {
        this.file = str;
    }

    public void setList(boolean z) {
        this.list = z;
    }
}
