package org.apache.poi.hssf.eventusermodel;

import b.b.a.a.a;
import java.text.NumberFormat;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Locale;
import java.util.Map;
import org.apache.poi.hssf.record.CellValueRecordInterface;
import org.apache.poi.hssf.record.ExtendedFormatRecord;
import org.apache.poi.hssf.record.FormatRecord;
import org.apache.poi.hssf.record.FormulaRecord;
import org.apache.poi.hssf.record.NumberRecord;
import org.apache.poi.hssf.record.Record;
import org.apache.poi.hssf.usermodel.HSSFDataFormat;
import org.apache.poi.hssf.usermodel.HSSFDataFormatter;
import org.apache.poi.util.LocaleUtil;
import org.apache.poi.util.POILogFactory;
import org.apache.poi.util.POILogger;
import org.apache.poi.xssf.usermodel.XSSFDataValidationConstraint;

public class FormatTrackingHSSFListener implements HSSFListener {
    public static final POILogger logger = POILogFactory.getLogger(FormatTrackingHSSFListener.class);
    public final HSSFListener _childListener;
    public final Map<Integer, FormatRecord> _customFormatRecords;
    public final NumberFormat _defaultFormat;
    public final HSSFDataFormatter _formatter;
    public final List<ExtendedFormatRecord> _xfRecords;

    public FormatTrackingHSSFListener(HSSFListener hSSFListener) {
        this(hSSFListener, LocaleUtil.getUserLocale());
    }

    public String formatNumberDateCell(CellValueRecordInterface cellValueRecordInterface) {
        double d2;
        if (cellValueRecordInterface instanceof NumberRecord) {
            d2 = ((NumberRecord) cellValueRecordInterface).getValue();
        } else if (cellValueRecordInterface instanceof FormulaRecord) {
            d2 = ((FormulaRecord) cellValueRecordInterface).getValue();
        } else {
            throw new IllegalArgumentException("Unsupported CellValue Record passed in " + cellValueRecordInterface);
        }
        int formatIndex = getFormatIndex(cellValueRecordInterface);
        String formatString = getFormatString(cellValueRecordInterface);
        if (formatString == null) {
            return this._defaultFormat.format(d2);
        }
        return this._formatter.formatRawCellContents(d2, formatIndex, formatString);
    }

    public int getFormatIndex(CellValueRecordInterface cellValueRecordInterface) {
        ExtendedFormatRecord extendedFormatRecord = this._xfRecords.get(cellValueRecordInterface.getXFIndex());
        if (extendedFormatRecord != null) {
            return extendedFormatRecord.getFormatIndex();
        }
        POILogger pOILogger = logger;
        StringBuilder b2 = a.b("Cell ");
        b2.append(cellValueRecordInterface.getRow());
        b2.append(XSSFDataValidationConstraint.LIST_SEPARATOR);
        b2.append((int) cellValueRecordInterface.getColumn());
        b2.append(" uses XF with index ");
        b2.append((int) cellValueRecordInterface.getXFIndex());
        b2.append(", but we don't have that");
        pOILogger.log(7, b2.toString());
        return -1;
    }

    public String getFormatString(int i2) {
        if (i2 < HSSFDataFormat.getNumberOfBuiltinBuiltinFormats()) {
            return HSSFDataFormat.getBuiltinFormat((short) i2);
        }
        FormatRecord formatRecord = this._customFormatRecords.get(Integer.valueOf(i2));
        if (formatRecord != null) {
            return formatRecord.getFormatString();
        }
        logger.log(7, a.b("Requested format at index ", i2, ", but it wasn't found"));
        return null;
    }

    public int getNumberOfCustomFormats() {
        return this._customFormatRecords.size();
    }

    public int getNumberOfExtendedFormats() {
        return this._xfRecords.size();
    }

    @Override // org.apache.poi.hssf.eventusermodel.HSSFListener
    public void processRecord(Record record) {
        processRecordInternally(record);
        this._childListener.processRecord(record);
    }

    public void processRecordInternally(Record record) {
        if (record instanceof FormatRecord) {
            FormatRecord formatRecord = (FormatRecord) record;
            this._customFormatRecords.put(Integer.valueOf(formatRecord.getIndexCode()), formatRecord);
        }
        if (record instanceof ExtendedFormatRecord) {
            this._xfRecords.add((ExtendedFormatRecord) record);
        }
    }

    public FormatTrackingHSSFListener(HSSFListener hSSFListener, Locale locale) {
        this._customFormatRecords = new HashMap();
        this._xfRecords = new ArrayList();
        this._childListener = hSSFListener;
        this._formatter = new HSSFDataFormatter(locale);
        this._defaultFormat = NumberFormat.getInstance(locale);
    }

    public String getFormatString(CellValueRecordInterface cellValueRecordInterface) {
        int formatIndex = getFormatIndex(cellValueRecordInterface);
        if (formatIndex == -1) {
            return null;
        }
        return getFormatString(formatIndex);
    }
}
