package org.apache.poi.hssf.model;

import b.b.a.a.a;
import java.util.ArrayList;
import java.util.Iterator;
import java.util.List;
import org.apache.poi.hssf.record.BOFRecord;
import org.apache.poi.hssf.record.CalcCountRecord;
import org.apache.poi.hssf.record.CalcModeRecord;
import org.apache.poi.hssf.record.CellValueRecordInterface;
import org.apache.poi.hssf.record.ColumnInfoRecord;
import org.apache.poi.hssf.record.DefaultColWidthRecord;
import org.apache.poi.hssf.record.DefaultRowHeightRecord;
import org.apache.poi.hssf.record.DeltaRecord;
import org.apache.poi.hssf.record.DimensionsRecord;
import org.apache.poi.hssf.record.DrawingRecord;
import org.apache.poi.hssf.record.EOFRecord;
import org.apache.poi.hssf.record.EscherAggregate;
import org.apache.poi.hssf.record.GridsetRecord;
import org.apache.poi.hssf.record.GutsRecord;
import org.apache.poi.hssf.record.IterationRecord;
import org.apache.poi.hssf.record.NoteRecord;
import org.apache.poi.hssf.record.PaneRecord;
import org.apache.poi.hssf.record.PrintGridlinesRecord;
import org.apache.poi.hssf.record.PrintHeadersRecord;
import org.apache.poi.hssf.record.Record;
import org.apache.poi.hssf.record.RecordBase;
import org.apache.poi.hssf.record.RefModeRecord;
import org.apache.poi.hssf.record.RowRecord;
import org.apache.poi.hssf.record.SCLRecord;
import org.apache.poi.hssf.record.SaveRecalcRecord;
import org.apache.poi.hssf.record.SelectionRecord;
import org.apache.poi.hssf.record.UncalcedRecord;
import org.apache.poi.hssf.record.WSBoolRecord;
import org.apache.poi.hssf.record.WindowTwoRecord;
import org.apache.poi.hssf.record.aggregates.ChartSubstreamRecordAggregate;
import org.apache.poi.hssf.record.aggregates.ColumnInfoRecordsAggregate;
import org.apache.poi.hssf.record.aggregates.ConditionalFormattingTable;
import org.apache.poi.hssf.record.aggregates.CustomViewSettingsRecordAggregate;
import org.apache.poi.hssf.record.aggregates.DataValidityTable;
import org.apache.poi.hssf.record.aggregates.MergedCellsTable;
import org.apache.poi.hssf.record.aggregates.PageSettingsBlock;
import org.apache.poi.hssf.record.aggregates.RecordAggregate;
import org.apache.poi.hssf.record.aggregates.RowRecordsAggregate;
import org.apache.poi.hssf.record.aggregates.WorksheetProtectionBlock;
import org.apache.poi.hssf.usermodel.HSSFShapeTypes;
import org.apache.poi.ss.formula.FormulaShifter;
import org.apache.poi.ss.util.CellRangeAddress;
import org.apache.poi.ss.util.PaneInformation;
import org.apache.poi.util.Internal;
import org.apache.poi.util.POILogFactory;
import org.apache.poi.util.POILogger;
import org.apache.poi.util.RecordFormatException;

@Internal
public final class InternalSheet {
    public static final short BottomMargin = 3;
    public static final short LeftMargin = 0;
    public static final byte PANE_LOWER_LEFT = 2;
    public static final byte PANE_LOWER_RIGHT = 0;
    public static final byte PANE_UPPER_LEFT = 3;
    public static final byte PANE_UPPER_RIGHT = 1;
    public static final short RightMargin = 1;
    public static final short TopMargin = 2;
    public static POILogger log = POILogFactory.getLogger(InternalSheet.class);
    public ColumnInfoRecordsAggregate _columnInfos;
    public DataValidityTable _dataValidityTable = null;
    public DimensionsRecord _dimensions;
    public GutsRecord _gutsRecord;
    public boolean _isUncalced = false;
    public final MergedCellsTable _mergedCellsTable = new MergedCellsTable();
    public final WorksheetProtectionBlock _protectionBlock = new WorksheetProtectionBlock();
    public PageSettingsBlock _psBlock;
    public List<RecordBase> _records;
    public final RowRecordsAggregate _rowsAggregate;
    public SelectionRecord _selection = null;
    public ConditionalFormattingTable condFormatting;
    public DefaultColWidthRecord defaultcolwidth = new DefaultColWidthRecord();
    public DefaultRowHeightRecord defaultrowheight = new DefaultRowHeightRecord();
    public GridsetRecord gridset = null;
    public PrintGridlinesRecord printGridlines = null;
    public PrintHeadersRecord printHeaders = null;
    public Iterator<RowRecord> rowRecIterator = null;
    public WindowTwoRecord windowTwo = null;

    public static final class RecordCloner implements RecordAggregate.RecordVisitor {
        public final List<Record> _destList;

        public RecordCloner(List<Record> list) {
            this._destList = list;
        }

        @Override // org.apache.poi.hssf.record.aggregates.RecordAggregate.RecordVisitor
        public void visitRecord(Record record) {
            try {
                this._destList.add((Record) record.clone());
            } catch (CloneNotSupportedException e2) {
                throw new RecordFormatException(e2);
            }
        }
    }

    public static class UnsupportedBOFType extends RecordFormatException {
        public final int type;

        public UnsupportedBOFType(int i2) {
            super(a.c("BOF not of a supported type, found ", i2));
            this.type = i2;
        }

        public int getType() {
            return this.type;
        }
    }

    /* JADX WARNING: Removed duplicated region for block: B:8:0x0062 A[LOOP:0: B:8:0x0062->B:11:0x006e, LOOP_START] */
    public InternalSheet(RecordStream recordStream) {
        RowRecordsAggregate rowRecordsAggregate = null;
        ArrayList arrayList = new ArrayList(128);
        this._records = arrayList;
        if (recordStream.peekNextSid() == 2057) {
            BOFRecord bOFRecord = (BOFRecord) recordStream.getNext();
            if (bOFRecord.getType() == 16 || bOFRecord.getType() == 32 || bOFRecord.getType() == 64) {
                arrayList.add(bOFRecord);
                int i2 = -1;
                while (true) {
                    if (!recordStream.hasNext()) {
                        break;
                    }
                    int peekNextSid = recordStream.peekNextSid();
                    if (peekNextSid == 432 || peekNextSid == 2169) {
                        ConditionalFormattingTable conditionalFormattingTable = new ConditionalFormattingTable(recordStream);
                        this.condFormatting = conditionalFormattingTable;
                        arrayList.add(conditionalFormattingTable);
                    } else if (peekNextSid == 125) {
                        ColumnInfoRecordsAggregate columnInfoRecordsAggregate = new ColumnInfoRecordsAggregate(recordStream);
                        this._columnInfos = columnInfoRecordsAggregate;
                        arrayList.add(columnInfoRecordsAggregate);
                    } else if (peekNextSid == 434) {
                        DataValidityTable dataValidityTable = new DataValidityTable(recordStream);
                        this._dataValidityTable = dataValidityTable;
                        arrayList.add(dataValidityTable);
                    } else if (RecordOrderer.isRowBlockRecord(peekNextSid)) {
                        if (rowRecordsAggregate == null) {
                            RowBlocksReader rowBlocksReader = new RowBlocksReader(recordStream);
                            this._mergedCellsTable.addRecords(rowBlocksReader.getLooseMergedCells());
                            RowRecordsAggregate rowRecordsAggregate2 = new RowRecordsAggregate(rowBlocksReader.getPlainRecordStream(), rowBlocksReader.getSharedFormulaManager());
                            arrayList.add(rowRecordsAggregate2);
                            rowRecordsAggregate = rowRecordsAggregate2;
                        } else {
                            throw new RecordFormatException("row/cell records found in the wrong place");
                        }
                    } else if (CustomViewSettingsRecordAggregate.isBeginRecord(peekNextSid)) {
                        arrayList.add(new CustomViewSettingsRecordAggregate(recordStream));
                    } else if (PageSettingsBlock.isComponentRecord(peekNextSid)) {
                        PageSettingsBlock pageSettingsBlock = this._psBlock;
                        if (pageSettingsBlock == null) {
                            PageSettingsBlock pageSettingsBlock2 = new PageSettingsBlock(recordStream);
                            this._psBlock = pageSettingsBlock2;
                            arrayList.add(pageSettingsBlock2);
                        } else {
                            pageSettingsBlock.addLateRecords(recordStream);
                        }
                        this._psBlock.positionRecords(arrayList);
                    } else if (WorksheetProtectionBlock.isComponentRecord(peekNextSid)) {
                        this._protectionBlock.addRecords(recordStream);
                    } else if (peekNextSid == 229) {
                        this._mergedCellsTable.read(recordStream);
                    } else if (peekNextSid == 2057) {
                        spillAggregate(new ChartSubstreamRecordAggregate(recordStream), arrayList);
                    } else {
                        Record next = recordStream.getNext();
                        if (peekNextSid == 523) {
                            continue;
                        } else if (peekNextSid == 94) {
                            this._isUncalced = true;
                        } else if (peekNextSid == 2152 || peekNextSid == 2151) {
                            arrayList.add(next);
                        } else if (peekNextSid == 10) {
                            arrayList.add(next);
                            break;
                        } else {
                            if (peekNextSid == 512) {
                                if (this._columnInfos == null) {
                                    ColumnInfoRecordsAggregate columnInfoRecordsAggregate2 = new ColumnInfoRecordsAggregate();
                                    this._columnInfos = columnInfoRecordsAggregate2;
                                    arrayList.add(columnInfoRecordsAggregate2);
                                }
                                this._dimensions = (DimensionsRecord) next;
                                i2 = arrayList.size();
                            } else if (peekNextSid == 85) {
                                this.defaultcolwidth = (DefaultColWidthRecord) next;
                            } else if (peekNextSid == 549) {
                                this.defaultrowheight = (DefaultRowHeightRecord) next;
                            } else if (peekNextSid == 43) {
                                this.printGridlines = (PrintGridlinesRecord) next;
                            } else if (peekNextSid == 42) {
                                this.printHeaders = (PrintHeadersRecord) next;
                            } else if (peekNextSid == 130) {
                                this.gridset = (GridsetRecord) next;
                            } else if (peekNextSid == 29) {
                                this._selection = (SelectionRecord) next;
                            } else if (peekNextSid == 574) {
                                this.windowTwo = (WindowTwoRecord) next;
                            } else if (peekNextSid == 128) {
                                this._gutsRecord = (GutsRecord) next;
                            }
                            arrayList.add(next);
                        }
                    }
                }
                if (this.windowTwo != null) {
                    if (this._dimensions == null) {
                        if (rowRecordsAggregate == null) {
                            rowRecordsAggregate = new RowRecordsAggregate();
                        } else if (log.check(5)) {
                            log.log(5, "DIMENSION record not found even though row/cells present");
                        }
                        i2 = findFirstRecordLocBySid(574);
                        DimensionsRecord createDimensions = rowRecordsAggregate.createDimensions();
                        this._dimensions = createDimensions;
                        arrayList.add(i2, createDimensions);
                    }
                    if (rowRecordsAggregate == null) {
                        rowRecordsAggregate = new RowRecordsAggregate();
                        arrayList.add(i2 + 1, rowRecordsAggregate);
                    }
                    this._rowsAggregate = rowRecordsAggregate;
                    RecordOrderer.addNewSheetRecord(arrayList, this._mergedCellsTable);
                    RecordOrderer.addNewSheetRecord(arrayList, this._protectionBlock);
                    if (log.check(1)) {
                        log.log(1, "sheet createSheet (existing file) exited");
                        return;
                    }
                    return;
                }
                throw new RecordFormatException("WINDOW2 was not found");
            }
            while (recordStream.hasNext() && !(recordStream.getNext() instanceof EOFRecord)) {
            }
            throw new UnsupportedBOFType(bOFRecord.getType());
        }
        throw new RecordFormatException("BOF record expected");
    }

    public static BOFRecord createBOF() {
        BOFRecord bOFRecord = new BOFRecord();
        bOFRecord.setVersion(BOFRecord.VERSION);
        bOFRecord.setType(16);
        bOFRecord.setBuild(3515);
        bOFRecord.setBuildYear(BOFRecord.BUILD_YEAR);
        bOFRecord.setHistoryBitMask(HSSFShapeTypes.ActionButtonForwardNext);
        bOFRecord.setRequiredVersion(6);
        return bOFRecord;
    }

    public static CalcCountRecord createCalcCount() {
        CalcCountRecord calcCountRecord = new CalcCountRecord();
        calcCountRecord.setIterations(100);
        return calcCountRecord;
    }

    public static CalcModeRecord createCalcMode() {
        CalcModeRecord calcModeRecord = new CalcModeRecord();
        calcModeRecord.setCalcMode(1);
        return calcModeRecord;
    }

    public static DefaultColWidthRecord createDefaultColWidth() {
        DefaultColWidthRecord defaultColWidthRecord = new DefaultColWidthRecord();
        defaultColWidthRecord.setColWidth(8);
        return defaultColWidthRecord;
    }

    public static DefaultRowHeightRecord createDefaultRowHeight() {
        DefaultRowHeightRecord defaultRowHeightRecord = new DefaultRowHeightRecord();
        defaultRowHeightRecord.setOptionFlags(0);
        defaultRowHeightRecord.setRowHeight(255);
        return defaultRowHeightRecord;
    }

    public static DeltaRecord createDelta() {
        return new DeltaRecord(0.001d);
    }

    public static DimensionsRecord createDimensions() {
        DimensionsRecord dimensionsRecord = new DimensionsRecord();
        dimensionsRecord.setFirstCol(0);
        dimensionsRecord.setLastRow(1);
        dimensionsRecord.setFirstRow(0);
        dimensionsRecord.setLastCol(1);
        return dimensionsRecord;
    }

    public static GridsetRecord createGridset() {
        GridsetRecord gridsetRecord = new GridsetRecord();
        gridsetRecord.setGridset(true);
        return gridsetRecord;
    }

    public static GutsRecord createGuts() {
        GutsRecord gutsRecord = new GutsRecord();
        gutsRecord.setLeftRowGutter(0);
        gutsRecord.setTopColGutter(0);
        gutsRecord.setRowLevelMax(0);
        gutsRecord.setColLevelMax(0);
        return gutsRecord;
    }

    public static IterationRecord createIteration() {
        return new IterationRecord(false);
    }

    public static PrintGridlinesRecord createPrintGridlines() {
        PrintGridlinesRecord printGridlinesRecord = new PrintGridlinesRecord();
        printGridlinesRecord.setPrintGridlines(false);
        return printGridlinesRecord;
    }

    public static PrintHeadersRecord createPrintHeaders() {
        PrintHeadersRecord printHeadersRecord = new PrintHeadersRecord();
        printHeadersRecord.setPrintHeaders(false);
        return printHeadersRecord;
    }

    public static RefModeRecord createRefMode() {
        RefModeRecord refModeRecord = new RefModeRecord();
        refModeRecord.setMode(1);
        return refModeRecord;
    }

    public static SaveRecalcRecord createSaveRecalc() {
        SaveRecalcRecord saveRecalcRecord = new SaveRecalcRecord();
        saveRecalcRecord.setRecalc(true);
        return saveRecalcRecord;
    }

    public static SelectionRecord createSelection() {
        return new SelectionRecord(0, 0);
    }

    public static InternalSheet createSheet(RecordStream recordStream) {
        return new InternalSheet(recordStream);
    }

    public static WSBoolRecord createWSBool() {
        WSBoolRecord wSBoolRecord = new WSBoolRecord();
        wSBoolRecord.setWSBool1((byte) 4);
        wSBoolRecord.setWSBool2((byte) -63);
        return wSBoolRecord;
    }

    public static WindowTwoRecord createWindowTwo() {
        WindowTwoRecord windowTwoRecord = new WindowTwoRecord();
        windowTwoRecord.setOptions(1718);
        windowTwoRecord.setTopRow(0);
        windowTwoRecord.setLeftCol(0);
        windowTwoRecord.setHeaderColor(64);
        windowTwoRecord.setPageBreakZoom(0);
        windowTwoRecord.setNormalZoom(0);
        return windowTwoRecord;
    }

    private GutsRecord getGutsRecord() {
        if (this._gutsRecord == null) {
            GutsRecord createGuts = createGuts();
            RecordOrderer.addNewSheetRecord(this._records, createGuts);
            this._gutsRecord = createGuts;
        }
        return this._gutsRecord;
    }

    private MergedCellsTable getMergedRecords() {
        return this._mergedCellsTable;
    }

    private int getSizeOfInitialSheetRecords(int i2) {
        int i3 = 0;
        for (int i4 = i2 + 1; i4 < this._records.size(); i4++) {
            RecordBase recordBase = this._records.get(i4);
            if (recordBase instanceof RowRecordsAggregate) {
                break;
            }
            i3 += recordBase.getRecordSize();
        }
        return this._isUncalced ? i3 + UncalcedRecord.getStaticRecordSize() : i3;
    }

    private void recalcRowGutter() {
        Iterator<RowRecord> iterator = this._rowsAggregate.getIterator();
        int i2 = 0;
        while (iterator.hasNext()) {
            i2 = Math.max((int) iterator.next().getOutlineLevel(), i2);
        }
        GutsRecord gutsRecord = getGutsRecord();
        gutsRecord.setRowLevelMax((short) (i2 + 1));
        gutsRecord.setLeftRowGutter((short) ((i2 * 12) + 29));
    }

    private void setColumn(int i2, Short sh, Integer num, Integer num2, Boolean bool, Boolean bool2) {
        this._columnInfos.setColumn(i2, sh, num, num2, bool, bool2);
    }

    public static void spillAggregate(RecordAggregate recordAggregate, final List<RecordBase> list) {
        recordAggregate.visitContainedRecords(new RecordAggregate.RecordVisitor() {
            /* class org.apache.poi.hssf.model.InternalSheet.AnonymousClass1 */

            @Override // org.apache.poi.hssf.record.aggregates.RecordAggregate.RecordVisitor
            public void visitRecord(Record record) {
                list.add(record);
            }
        });
    }

    public int addMergedRegion(int i2, int i3, int i4, int i5) {
        if (i4 < i2) {
            throw new IllegalArgumentException(a.b("The 'to' row (", i4, ") must not be less than the 'from' row (", i2, ")"));
        } else if (i5 >= i3) {
            MergedCellsTable mergedRecords = getMergedRecords();
            mergedRecords.addArea(i2, i3, i4, i5);
            return mergedRecords.getNumberOfMergedRegions() - 1;
        } else {
            throw new IllegalArgumentException(a.b("The 'to' col (", i5, ") must not be less than the 'from' col (", i3, ")"));
        }
    }

    public void addRow(RowRecord rowRecord) {
        if (log.check(1)) {
            log.log(1, "addRow ");
        }
        DimensionsRecord dimensionsRecord = this._dimensions;
        if (rowRecord.getRowNumber() >= dimensionsRecord.getLastRow()) {
            dimensionsRecord.setLastRow(rowRecord.getRowNumber() + 1);
        }
        if (rowRecord.getRowNumber() < dimensionsRecord.getFirstRow()) {
            dimensionsRecord.setFirstRow(rowRecord.getRowNumber());
        }
        RowRecord row = this._rowsAggregate.getRow(rowRecord.getRowNumber());
        if (row != null) {
            this._rowsAggregate.removeRow(row);
        }
        this._rowsAggregate.insertRow(rowRecord);
        if (log.check(1)) {
            log.log(1, "exit addRow");
        }
    }

    public void addValueRecord(int i2, CellValueRecordInterface cellValueRecordInterface) {
        if (log.check(1)) {
            log.log(1, a.c("add value record  row", i2));
        }
        DimensionsRecord dimensionsRecord = this._dimensions;
        if (cellValueRecordInterface.getColumn() >= dimensionsRecord.getLastCol()) {
            dimensionsRecord.setLastCol((short) (cellValueRecordInterface.getColumn() + 1));
        }
        if (cellValueRecordInterface.getColumn() < dimensionsRecord.getFirstCol()) {
            dimensionsRecord.setFirstCol(cellValueRecordInterface.getColumn());
        }
        this._rowsAggregate.insertCell(cellValueRecordInterface);
    }

    public int aggregateDrawingRecords(DrawingManager2 drawingManager2, boolean z) {
        int findFirstRecordLocBySid = findFirstRecordLocBySid(236);
        if (!(findFirstRecordLocBySid == -1)) {
            EscherAggregate.createAggregate(getRecords(), findFirstRecordLocBySid);
            return findFirstRecordLocBySid;
        } else if (!z) {
            return -1;
        } else {
            EscherAggregate escherAggregate = new EscherAggregate(true);
            int findFirstRecordLocBySid2 = findFirstRecordLocBySid(EscherAggregate.sid);
            if (findFirstRecordLocBySid2 == -1) {
                findFirstRecordLocBySid2 = findFirstRecordLocBySid(574);
            } else {
                getRecords().remove(findFirstRecordLocBySid2);
            }
            getRecords().add(findFirstRecordLocBySid2, escherAggregate);
            return findFirstRecordLocBySid2;
        }
    }

    public InternalSheet cloneSheet() {
        ArrayList arrayList = new ArrayList(this._records.size());
        for (int i2 = 0; i2 < this._records.size(); i2++) {
            Object obj = (RecordBase) this._records.get(i2);
            if (obj instanceof RecordAggregate) {
                ((RecordAggregate) obj).visitContainedRecords(new RecordCloner(arrayList));
            } else {
                if (obj instanceof EscherAggregate) {
                    obj = new DrawingRecord();
                }
                try {
                    arrayList.add((Record) ((Record) obj).clone());
                } catch (CloneNotSupportedException e2) {
                    throw new RecordFormatException(e2);
                }
            }
        }
        return createSheet(new RecordStream(arrayList, 0));
    }

    public void createFreezePane(int i2, int i3, int i4, int i5) {
        int findFirstRecordLocBySid = findFirstRecordLocBySid(65);
        if (findFirstRecordLocBySid != -1) {
            this._records.remove(findFirstRecordLocBySid);
        }
        if (i2 == 0 && i3 == 0) {
            this.windowTwo.setFreezePanes(false);
            this.windowTwo.setFreezePanesNoSplit(false);
            ((SelectionRecord) findFirstRecordBySid(29)).setPane((byte) 3);
            return;
        }
        int findFirstRecordLocBySid2 = findFirstRecordLocBySid(574);
        PaneRecord paneRecord = new PaneRecord();
        paneRecord.setX((short) i2);
        paneRecord.setY((short) i3);
        paneRecord.setTopRow((short) i4);
        paneRecord.setLeftColumn((short) i5);
        if (i3 == 0) {
            paneRecord.setTopRow(0);
            paneRecord.setActivePane(1);
        } else if (i2 == 0) {
            paneRecord.setLeftColumn(0);
            paneRecord.setActivePane(2);
        } else {
            paneRecord.setActivePane(0);
        }
        this._records.add(findFirstRecordLocBySid2 + 1, paneRecord);
        this.windowTwo.setFreezePanes(true);
        this.windowTwo.setFreezePanesNoSplit(true);
        ((SelectionRecord) findFirstRecordBySid(29)).setPane((byte) paneRecord.getActivePane());
    }

    public void createSplitPane(int i2, int i3, int i4, int i5, int i6) {
        int findFirstRecordLocBySid = findFirstRecordLocBySid(65);
        if (findFirstRecordLocBySid != -1) {
            this._records.remove(findFirstRecordLocBySid);
        }
        int findFirstRecordLocBySid2 = findFirstRecordLocBySid(574);
        PaneRecord paneRecord = new PaneRecord();
        paneRecord.setX((short) i2);
        paneRecord.setY((short) i3);
        paneRecord.setTopRow((short) i4);
        paneRecord.setLeftColumn((short) i5);
        paneRecord.setActivePane((short) i6);
        this._records.add(findFirstRecordLocBySid2 + 1, paneRecord);
        this.windowTwo.setFreezePanes(false);
        this.windowTwo.setFreezePanesNoSplit(false);
        ((SelectionRecord) findFirstRecordBySid(29)).setPane((byte) 0);
    }

    public Record findFirstRecordBySid(short s) {
        int findFirstRecordLocBySid = findFirstRecordLocBySid(s);
        if (findFirstRecordLocBySid < 0) {
            return null;
        }
        return (Record) this._records.get(findFirstRecordLocBySid);
    }

    public int findFirstRecordLocBySid(short s) {
        int size = this._records.size();
        for (int i2 = 0; i2 < size; i2++) {
            RecordBase recordBase = this._records.get(i2);
            if ((recordBase instanceof Record) && ((Record) recordBase).getSid() == s) {
                return i2;
            }
        }
        return -1;
    }

    public short getActiveCellCol() {
        SelectionRecord selectionRecord = this._selection;
        if (selectionRecord == null) {
            return 0;
        }
        return (short) selectionRecord.getActiveCellCol();
    }

    public int getActiveCellRow() {
        SelectionRecord selectionRecord = this._selection;
        if (selectionRecord == null) {
            return 0;
        }
        return selectionRecord.getActiveCellRow();
    }

    public Iterator<CellValueRecordInterface> getCellValueIterator() {
        return this._rowsAggregate.getCellValueIterator();
    }

    public int getColumnOutlineLevel(int i2) {
        return this._columnInfos.getOutlineLevel(i2);
    }

    public int getColumnWidth(int i2) {
        ColumnInfoRecord findColumnInfo = this._columnInfos.findColumnInfo(i2);
        if (findColumnInfo != null) {
            return findColumnInfo.getColumnWidth();
        }
        return this.defaultcolwidth.getColWidth() * 256;
    }

    public ConditionalFormattingTable getConditionalFormattingTable() {
        if (this.condFormatting == null) {
            ConditionalFormattingTable conditionalFormattingTable = new ConditionalFormattingTable();
            this.condFormatting = conditionalFormattingTable;
            RecordOrderer.addNewSheetRecord(this._records, conditionalFormattingTable);
        }
        return this.condFormatting;
    }

    public int getDefaultColumnWidth() {
        return this.defaultcolwidth.getColWidth();
    }

    public short getDefaultRowHeight() {
        return this.defaultrowheight.getRowHeight();
    }

    public GridsetRecord getGridsetRecord() {
        return this.gridset;
    }

    public short getLeftCol() {
        WindowTwoRecord windowTwoRecord = this.windowTwo;
        if (windowTwoRecord == null) {
            return 0;
        }
        return windowTwoRecord.getLeftCol();
    }

    public CellRangeAddress getMergedRegionAt(int i2) {
        MergedCellsTable mergedRecords = getMergedRecords();
        if (i2 >= mergedRecords.getNumberOfMergedRegions()) {
            return null;
        }
        return mergedRecords.get(i2);
    }

    public RowRecord getNextRow() {
        if (this.rowRecIterator == null) {
            this.rowRecIterator = this._rowsAggregate.getIterator();
        }
        if (!this.rowRecIterator.hasNext()) {
            return null;
        }
        return this.rowRecIterator.next();
    }

    public NoteRecord[] getNoteRecords() {
        ArrayList arrayList = new ArrayList();
        for (int size = this._records.size() - 1; size >= 0; size--) {
            RecordBase recordBase = this._records.get(size);
            if (recordBase instanceof NoteRecord) {
                arrayList.add((NoteRecord) recordBase);
            }
        }
        if (arrayList.size() < 1) {
            return NoteRecord.EMPTY_ARRAY;
        }
        NoteRecord[] noteRecordArr = new NoteRecord[arrayList.size()];
        arrayList.toArray(noteRecordArr);
        return noteRecordArr;
    }

    public int getNumMergedRegions() {
        return getMergedRecords().getNumberOfMergedRegions();
    }

    public DataValidityTable getOrCreateDataValidityTable() {
        if (this._dataValidityTable == null) {
            DataValidityTable dataValidityTable = new DataValidityTable();
            RecordOrderer.addNewSheetRecord(this._records, dataValidityTable);
            this._dataValidityTable = dataValidityTable;
        }
        return this._dataValidityTable;
    }

    public PageSettingsBlock getPageSettings() {
        if (this._psBlock == null) {
            PageSettingsBlock pageSettingsBlock = new PageSettingsBlock();
            this._psBlock = pageSettingsBlock;
            RecordOrderer.addNewSheetRecord(this._records, pageSettingsBlock);
        }
        return this._psBlock;
    }

    public PaneInformation getPaneInformation() {
        PaneRecord paneRecord = (PaneRecord) findFirstRecordBySid(65);
        if (paneRecord == null) {
            return null;
        }
        return new PaneInformation(paneRecord.getX(), paneRecord.getY(), paneRecord.getTopRow(), paneRecord.getLeftColumn(), (byte) paneRecord.getActivePane(), this.windowTwo.getFreezePanes());
    }

    public PrintGridlinesRecord getPrintGridlines() {
        return this.printGridlines;
    }

    public PrintHeadersRecord getPrintHeaders() {
        return this.printHeaders;
    }

    public WorksheetProtectionBlock getProtectionBlock() {
        return this._protectionBlock;
    }

    public List<RecordBase> getRecords() {
        return this._records;
    }

    public RowRecord getRow(int i2) {
        return this._rowsAggregate.getRow(i2);
    }

    public RowRecordsAggregate getRowsAggregate() {
        return this._rowsAggregate;
    }

    public SelectionRecord getSelection() {
        return this._selection;
    }

    public short getTopRow() {
        WindowTwoRecord windowTwoRecord = this.windowTwo;
        if (windowTwoRecord == null) {
            return 0;
        }
        return windowTwoRecord.getTopRow();
    }

    public boolean getUncalced() {
        return this._isUncalced;
    }

    public WindowTwoRecord getWindowTwo() {
        return this.windowTwo;
    }

    public short getXFIndexForColAt(short s) {
        ColumnInfoRecord findColumnInfo = this._columnInfos.findColumnInfo(s);
        if (findColumnInfo != null) {
            return (short) findColumnInfo.getXFIndex();
        }
        return 15;
    }

    public void groupColumnRange(int i2, int i3, boolean z) {
        this._columnInfos.groupColumnRange(i2, i3, z);
        int maxOutlineLevel = this._columnInfos.getMaxOutlineLevel();
        GutsRecord gutsRecord = getGutsRecord();
        gutsRecord.setColLevelMax((short) (maxOutlineLevel + 1));
        if (maxOutlineLevel == 0) {
            gutsRecord.setTopColGutter(0);
        } else {
            gutsRecord.setTopColGutter((short) (((maxOutlineLevel - 1) * 12) + 29));
        }
    }

    public void groupRowRange(int i2, int i3, boolean z) {
        while (i2 <= i3) {
            RowRecord row = getRow(i2);
            if (row == null) {
                row = RowRecordsAggregate.createRow(i2);
                addRow(row);
            }
            short outlineLevel = row.getOutlineLevel();
            row.setOutlineLevel((short) Math.min(7, Math.max(0, z ? outlineLevel + 1 : outlineLevel - 1)));
            i2++;
        }
        recalcRowGutter();
    }

    public boolean isColumnHidden(int i2) {
        ColumnInfoRecord findColumnInfo = this._columnInfos.findColumnInfo(i2);
        if (findColumnInfo == null) {
            return false;
        }
        return findColumnInfo.getHidden();
    }

    public boolean isDisplayFormulas() {
        return this.windowTwo.getDisplayFormulas();
    }

    public boolean isDisplayGridlines() {
        return this.windowTwo.getDisplayGridlines();
    }

    public boolean isDisplayRowColHeadings() {
        return this.windowTwo.getDisplayRowColHeadings();
    }

    public boolean isGridsPrinted() {
        if (this.gridset == null) {
            this.gridset = createGridset();
            this._records.add(findFirstRecordLocBySid(10), this.gridset);
        }
        return !this.gridset.getGridset();
    }

    public boolean isPrintRowColHeadings() {
        return this.windowTwo.getDisplayRowColHeadings();
    }

    public void preSerialize() {
        for (RecordBase recordBase : getRecords()) {
            if (recordBase instanceof EscherAggregate) {
                recordBase.getRecordSize();
            }
        }
    }

    public void removeMergedRegion(int i2) {
        MergedCellsTable mergedRecords = getMergedRecords();
        if (i2 < mergedRecords.getNumberOfMergedRegions()) {
            mergedRecords.remove(i2);
        }
    }

    public void removeRow(RowRecord rowRecord) {
        this._rowsAggregate.removeRow(rowRecord);
    }

    public void removeValueRecord(int i2, CellValueRecordInterface cellValueRecordInterface) {
        log.log(1, a.c("remove value record row ", i2));
        this._rowsAggregate.removeCell(cellValueRecordInterface);
    }

    public void replaceValueRecord(CellValueRecordInterface cellValueRecordInterface) {
        if (log.check(1)) {
            log.log(1, "replaceValueRecord ");
        }
        this._rowsAggregate.removeCell(cellValueRecordInterface);
        this._rowsAggregate.insertCell(cellValueRecordInterface);
    }

    public void setActiveCellCol(short s) {
        SelectionRecord selectionRecord = this._selection;
        if (selectionRecord != null) {
            selectionRecord.setActiveCellCol(s);
        }
    }

    public void setActiveCellRow(int i2) {
        SelectionRecord selectionRecord = this._selection;
        if (selectionRecord != null) {
            selectionRecord.setActiveCellRow(i2);
        }
    }

    public void setColumnGroupCollapsed(int i2, boolean z) {
        if (z) {
            this._columnInfos.collapseColumn(i2);
        } else {
            this._columnInfos.expandColumn(i2);
        }
    }

    public void setColumnHidden(int i2, boolean z) {
        setColumn(i2, null, null, null, Boolean.valueOf(z), null);
    }

    public void setColumnWidth(int i2, int i3) {
        if (i3 <= 65280) {
            setColumn(i2, null, Integer.valueOf(i3), null, null, null);
            return;
        }
        throw new IllegalArgumentException("The maximum column width for an individual cell is 255 characters.");
    }

    public void setDefaultColumnStyle(int i2, int i3) {
        setColumn(i2, Short.valueOf((short) i3), null, null, null, null);
    }

    public void setDefaultColumnWidth(int i2) {
        this.defaultcolwidth.setColWidth(i2);
    }

    public void setDefaultRowHeight(short s) {
        this.defaultrowheight.setRowHeight(s);
        this.defaultrowheight.setOptionFlags(1);
    }

    public void setDimensions(int i2, short s, int i3, short s2) {
        if (log.check(1)) {
            log.log(1, "Sheet.setDimensions");
            POILogger pOILogger = log;
            StringBuffer stringBuffer = new StringBuffer("firstrow");
            stringBuffer.append(i2);
            stringBuffer.append("firstcol");
            stringBuffer.append((int) s);
            stringBuffer.append("lastrow");
            stringBuffer.append(i3);
            stringBuffer.append("lastcol");
            stringBuffer.append((int) s2);
            pOILogger.log(1, stringBuffer.toString());
        }
        this._dimensions.setFirstCol(s);
        this._dimensions.setFirstRow(i2);
        this._dimensions.setLastCol(s2);
        this._dimensions.setLastRow(i3);
        if (log.check(1)) {
            log.log(1, "Sheet.setDimensions exiting");
        }
    }

    public void setDisplayFormulas(boolean z) {
        this.windowTwo.setDisplayFormulas(z);
    }

    public void setDisplayGridlines(boolean z) {
        this.windowTwo.setDisplayGridlines(z);
    }

    public void setDisplayRowColHeadings(boolean z) {
        this.windowTwo.setDisplayRowColHeadings(z);
    }

    public void setGridsPrinted(boolean z) {
        this.gridset.setGridset(!z);
    }

    public void setLeftCol(short s) {
        WindowTwoRecord windowTwoRecord = this.windowTwo;
        if (windowTwoRecord != null) {
            windowTwoRecord.setLeftCol(s);
        }
    }

    public void setPrintGridlines(PrintGridlinesRecord printGridlinesRecord) {
        this.printGridlines = printGridlinesRecord;
    }

    public void setPrintHeaders(PrintHeadersRecord printHeadersRecord) {
        this.printHeaders = printHeadersRecord;
    }

    public void setPrintRowColHeadings(boolean z) {
        this.windowTwo.setDisplayRowColHeadings(z);
    }

    public void setSCLRecord(SCLRecord sCLRecord) {
        int findFirstRecordLocBySid = findFirstRecordLocBySid(160);
        if (findFirstRecordLocBySid == -1) {
            this._records.add(findFirstRecordLocBySid(574) + 1, sCLRecord);
            return;
        }
        this._records.set(findFirstRecordLocBySid, sCLRecord);
    }

    public void setSelected(boolean z) {
        this.windowTwo.setSelected(z);
    }

    public void setSelection(SelectionRecord selectionRecord) {
        this._selection = selectionRecord;
    }

    public void setTopRow(short s) {
        WindowTwoRecord windowTwoRecord = this.windowTwo;
        if (windowTwoRecord != null) {
            windowTwoRecord.setTopRow(s);
        }
    }

    public void setUncalced(boolean z) {
        this._isUncalced = z;
    }

    public void updateFormulasAfterCellShift(FormulaShifter formulaShifter, int i2) {
        getRowsAggregate().updateFormulasAfterRowShift(formulaShifter, i2);
        if (this.condFormatting != null) {
            getConditionalFormattingTable().updateFormulasAfterCellShift(formulaShifter, i2);
        }
    }

    public void visitContainedRecords(RecordAggregate.RecordVisitor recordVisitor, int i2) {
        RecordAggregate.PositionTrackingVisitor positionTrackingVisitor = new RecordAggregate.PositionTrackingVisitor(recordVisitor, i2);
        boolean z = false;
        for (int i3 = 0; i3 < this._records.size(); i3++) {
            RecordBase recordBase = this._records.get(i3);
            if (recordBase instanceof RecordAggregate) {
                ((RecordAggregate) recordBase).visitContainedRecords(positionTrackingVisitor);
            } else {
                positionTrackingVisitor.visitRecord((Record) recordBase);
            }
            if ((recordBase instanceof BOFRecord) && !z) {
                if (this._isUncalced) {
                    positionTrackingVisitor.visitRecord(new UncalcedRecord());
                }
                if (this._rowsAggregate != null) {
                    int sizeOfInitialSheetRecords = getSizeOfInitialSheetRecords(i3);
                    positionTrackingVisitor.visitRecord(this._rowsAggregate.createIndexRecord(positionTrackingVisitor.getPosition(), sizeOfInitialSheetRecords));
                }
                z = true;
            }
        }
    }

    public static InternalSheet createSheet() {
        return new InternalSheet();
    }

    public InternalSheet() {
        ArrayList arrayList = new ArrayList(32);
        if (log.check(1)) {
            log.log(1, "Sheet createsheet from scratch called");
        }
        arrayList.add(createBOF());
        arrayList.add(createCalcMode());
        arrayList.add(createCalcCount());
        arrayList.add(createRefMode());
        arrayList.add(createIteration());
        arrayList.add(createDelta());
        arrayList.add(createSaveRecalc());
        PrintHeadersRecord createPrintHeaders = createPrintHeaders();
        this.printHeaders = createPrintHeaders;
        arrayList.add(createPrintHeaders);
        PrintGridlinesRecord createPrintGridlines = createPrintGridlines();
        this.printGridlines = createPrintGridlines;
        arrayList.add(createPrintGridlines);
        GridsetRecord createGridset = createGridset();
        this.gridset = createGridset;
        arrayList.add(createGridset);
        GutsRecord createGuts = createGuts();
        this._gutsRecord = createGuts;
        arrayList.add(createGuts);
        DefaultRowHeightRecord createDefaultRowHeight = createDefaultRowHeight();
        this.defaultrowheight = createDefaultRowHeight;
        arrayList.add(createDefaultRowHeight);
        arrayList.add(createWSBool());
        PageSettingsBlock pageSettingsBlock = new PageSettingsBlock();
        this._psBlock = pageSettingsBlock;
        arrayList.add(pageSettingsBlock);
        arrayList.add(this._protectionBlock);
        DefaultColWidthRecord createDefaultColWidth = createDefaultColWidth();
        this.defaultcolwidth = createDefaultColWidth;
        arrayList.add(createDefaultColWidth);
        ColumnInfoRecordsAggregate columnInfoRecordsAggregate = new ColumnInfoRecordsAggregate();
        arrayList.add(columnInfoRecordsAggregate);
        this._columnInfos = columnInfoRecordsAggregate;
        DimensionsRecord createDimensions = createDimensions();
        this._dimensions = createDimensions;
        arrayList.add(createDimensions);
        RowRecordsAggregate rowRecordsAggregate = new RowRecordsAggregate();
        this._rowsAggregate = rowRecordsAggregate;
        arrayList.add(rowRecordsAggregate);
        WindowTwoRecord createWindowTwo = createWindowTwo();
        this.windowTwo = createWindowTwo;
        arrayList.add(createWindowTwo);
        SelectionRecord createSelection = createSelection();
        this._selection = createSelection;
        arrayList.add(createSelection);
        arrayList.add(this._mergedCellsTable);
        arrayList.add(EOFRecord.instance);
        this._records = arrayList;
        if (log.check(1)) {
            log.log(1, "Sheet createsheet from scratch exit");
        }
    }
}
