package org.apache.poi.hssf.model;

import b.b.a.a.a;
import java.security.AccessControlException;
import java.util.ArrayList;
import java.util.Iterator;
import java.util.LinkedHashMap;
import java.util.List;
import java.util.Map;
import org.apache.poi.ddf.EscherBSERecord;
import org.apache.poi.ddf.EscherBoolProperty;
import org.apache.poi.ddf.EscherContainerRecord;
import org.apache.poi.ddf.EscherDgRecord;
import org.apache.poi.ddf.EscherDggRecord;
import org.apache.poi.ddf.EscherOptRecord;
import org.apache.poi.ddf.EscherProperties;
import org.apache.poi.ddf.EscherRGBProperty;
import org.apache.poi.ddf.EscherRecord;
import org.apache.poi.ddf.EscherSimpleProperty;
import org.apache.poi.ddf.EscherSpRecord;
import org.apache.poi.ddf.EscherSplitMenuColorsRecord;
import org.apache.poi.hssf.record.BOFRecord;
import org.apache.poi.hssf.record.BackupRecord;
import org.apache.poi.hssf.record.BookBoolRecord;
import org.apache.poi.hssf.record.BoundSheetRecord;
import org.apache.poi.hssf.record.CodepageRecord;
import org.apache.poi.hssf.record.CountryRecord;
import org.apache.poi.hssf.record.DSFRecord;
import org.apache.poi.hssf.record.DateWindow1904Record;
import org.apache.poi.hssf.record.DrawingGroupRecord;
import org.apache.poi.hssf.record.EOFRecord;
import org.apache.poi.hssf.record.EscherAggregate;
import org.apache.poi.hssf.record.ExtSSTRecord;
import org.apache.poi.hssf.record.ExtendedFormatRecord;
import org.apache.poi.hssf.record.FileSharingRecord;
import org.apache.poi.hssf.record.FnGroupCountRecord;
import org.apache.poi.hssf.record.FontRecord;
import org.apache.poi.hssf.record.FormatRecord;
import org.apache.poi.hssf.record.HideObjRecord;
import org.apache.poi.hssf.record.HyperlinkRecord;
import org.apache.poi.hssf.record.InterfaceEndRecord;
import org.apache.poi.hssf.record.InterfaceHdrRecord;
import org.apache.poi.hssf.record.MMSRecord;
import org.apache.poi.hssf.record.NameCommentRecord;
import org.apache.poi.hssf.record.NameRecord;
import org.apache.poi.hssf.record.PaletteRecord;
import org.apache.poi.hssf.record.PasswordRecord;
import org.apache.poi.hssf.record.PasswordRev4Record;
import org.apache.poi.hssf.record.PrecisionRecord;
import org.apache.poi.hssf.record.ProtectRecord;
import org.apache.poi.hssf.record.ProtectionRev4Record;
import org.apache.poi.hssf.record.RecalcIdRecord;
import org.apache.poi.hssf.record.Record;
import org.apache.poi.hssf.record.RefreshAllRecord;
import org.apache.poi.hssf.record.SSTRecord;
import org.apache.poi.hssf.record.StyleRecord;
import org.apache.poi.hssf.record.TabIdRecord;
import org.apache.poi.hssf.record.UseSelFSRecord;
import org.apache.poi.hssf.record.WindowOneRecord;
import org.apache.poi.hssf.record.WindowProtectRecord;
import org.apache.poi.hssf.record.WriteAccessRecord;
import org.apache.poi.hssf.record.WriteProtectRecord;
import org.apache.poi.hssf.record.common.UnicodeString;
import org.apache.poi.hssf.usermodel.HSSFFont;
import org.apache.poi.hssf.usermodel.HSSFShape;
import org.apache.poi.hssf.util.HSSFColor;
import org.apache.poi.poifs.crypt.CryptoFunctions;
import org.apache.poi.ss.formula.EvaluationWorkbook;
import org.apache.poi.ss.formula.FormulaShifter;
import org.apache.poi.ss.formula.ptg.Area3DPtg;
import org.apache.poi.ss.formula.ptg.NameXPtg;
import org.apache.poi.ss.formula.ptg.OperandPtg;
import org.apache.poi.ss.formula.ptg.Ptg;
import org.apache.poi.ss.formula.ptg.Ref3DPtg;
import org.apache.poi.ss.formula.udf.UDFFinder;
import org.apache.poi.ss.usermodel.BuiltinFormats;
import org.apache.poi.ss.usermodel.Font;
import org.apache.poi.ss.usermodel.SheetVisibility;
import org.apache.poi.ss.usermodel.Workbook;
import org.apache.poi.ss.util.CellUtil;
import org.apache.poi.util.Internal;
import org.apache.poi.util.LocaleUtil;
import org.apache.poi.util.POILogFactory;
import org.apache.poi.util.POILogger;
import org.apache.poi.util.RecordFormatException;

@Internal
public final class InternalWorkbook {
    public static final short CODEPAGE = 1200;
    public static final POILogger LOG = POILogFactory.getLogger(InternalWorkbook.class);
    public static final int MAX_SENSITIVE_SHEET_NAME_LEN = 31;
    public static final String OLD_WORKBOOK_DIR_ENTRY_NAME = "Book";
    public static final String[] WORKBOOK_DIR_ENTRY_NAMES = {"Workbook", "WORKBOOK", "BOOK"};
    public final List<BoundSheetRecord> boundsheets = new ArrayList();
    public final Map<String, NameCommentRecord> commentRecords = new LinkedHashMap();
    public DrawingManager2 drawingManager;
    public List<EscherBSERecord> escherBSERecords = new ArrayList();
    public FileSharingRecord fileShare;
    public final List<FormatRecord> formats = new ArrayList();
    public final List<HyperlinkRecord> hyperlinks = new ArrayList();
    public LinkTable linkTable;
    public int maxformatid = -1;
    public int numfonts = 0;
    public int numxfs = 0;
    public final WorkbookRecordList records = new WorkbookRecordList();
    public SSTRecord sst;
    public boolean uses1904datewindowing = false;
    public WindowOneRecord windowOne;
    public WriteAccessRecord writeAccess;
    public WriteProtectRecord writeProtect;

    private void checkSheets(int i2) {
        if (this.boundsheets.size() > i2) {
            return;
        }
        if (this.boundsheets.size() + 1 > i2) {
            BoundSheetRecord createBoundSheet = createBoundSheet(i2);
            WorkbookRecordList workbookRecordList = this.records;
            workbookRecordList.add(workbookRecordList.getBspos() + 1, createBoundSheet);
            WorkbookRecordList workbookRecordList2 = this.records;
            workbookRecordList2.setBspos(workbookRecordList2.getBspos() + 1);
            this.boundsheets.add(createBoundSheet);
            getOrCreateLinkTable().checkExternSheet(i2);
            fixTabIdRecord();
            return;
        }
        throw new RuntimeException("Sheet number out of bounds!");
    }

    public static BOFRecord createBOF() {
        BOFRecord bOFRecord = new BOFRecord();
        bOFRecord.setVersion(BOFRecord.VERSION);
        bOFRecord.setType(5);
        bOFRecord.setBuild(BOFRecord.BUILD);
        bOFRecord.setBuildYear(BOFRecord.BUILD_YEAR);
        bOFRecord.setHistoryBitMask(65);
        bOFRecord.setRequiredVersion(6);
        return bOFRecord;
    }

    public static BackupRecord createBackup() {
        BackupRecord backupRecord = new BackupRecord();
        backupRecord.setBackup(0);
        return backupRecord;
    }

    public static BookBoolRecord createBookBool() {
        BookBoolRecord bookBoolRecord = new BookBoolRecord();
        bookBoolRecord.setSaveLinkValues(0);
        return bookBoolRecord;
    }

    public static BoundSheetRecord createBoundSheet(int i2) {
        StringBuilder b2 = a.b("Sheet");
        b2.append(i2 + 1);
        return new BoundSheetRecord(b2.toString());
    }

    public static CodepageRecord createCodepage() {
        CodepageRecord codepageRecord = new CodepageRecord();
        codepageRecord.setCodepage(1200);
        return codepageRecord;
    }

    public static CountryRecord createCountry() {
        CountryRecord countryRecord = new CountryRecord();
        countryRecord.setDefaultCountry(1);
        if ("ru_RU".equals(LocaleUtil.getUserLocale().toString())) {
            countryRecord.setCurrentCountry(7);
        } else {
            countryRecord.setCurrentCountry(1);
        }
        return countryRecord;
    }

    public static DSFRecord createDSF() {
        return new DSFRecord(false);
    }

    public static DateWindow1904Record createDateWindow1904() {
        DateWindow1904Record dateWindow1904Record = new DateWindow1904Record();
        dateWindow1904Record.setWindowing(0);
        return dateWindow1904Record;
    }

    public static ExtendedFormatRecord createExtendedFormat(int i2) {
        switch (i2) {
            case 0:
                return createExtendedFormat(0, 0, -11, 0);
            case 1:
            case 2:
                return createExtendedFormat(1, 0, -11, -3072);
            case 3:
            case 4:
                return createExtendedFormat(2, 0, -11, -3072);
            case 5:
            case 6:
            case 7:
            case 8:
            case 9:
            case 10:
            case 11:
            case 12:
            case 13:
            case 14:
                return createExtendedFormat(0, 0, -11, -3072);
            case 15:
                return createExtendedFormat(0, 0, 1, 0);
            case 16:
                return createExtendedFormat(1, 43, -11, -2048);
            case 17:
                return createExtendedFormat(1, 41, -11, -2048);
            case 18:
                return createExtendedFormat(1, 44, -11, -2048);
            case 19:
                return createExtendedFormat(1, 42, -11, -2048);
            case 20:
                return createExtendedFormat(1, 9, -11, -2048);
            case 21:
                return createExtendedFormat(5, 0, 1, 2048);
            case 22:
                return createExtendedFormat(6, 0, 1, 23552);
            case 23:
                return createExtendedFormat(0, 49, 1, 23552);
            case 24:
                return createExtendedFormat(0, 8, 1, 23552);
            case 25:
                return createExtendedFormat(6, 8, 1, 23552);
            default:
                throw new IllegalStateException(a.c("Unrecognized format id: ", i2));
        }
    }

    public static ExtSSTRecord createExtendedSST() {
        ExtSSTRecord extSSTRecord = new ExtSSTRecord();
        extSSTRecord.setNumStringsPerBucket(8);
        return extSSTRecord;
    }

    public static FnGroupCountRecord createFnGroupCount() {
        FnGroupCountRecord fnGroupCountRecord = new FnGroupCountRecord();
        fnGroupCountRecord.setCount(14);
        return fnGroupCountRecord;
    }

    public static FontRecord createFont() {
        FontRecord fontRecord = new FontRecord();
        fontRecord.setFontHeight(200);
        fontRecord.setAttributes(0);
        fontRecord.setColorPaletteIndex(Font.COLOR_NORMAL);
        fontRecord.setBoldWeight(400);
        fontRecord.setFontName(HSSFFont.FONT_ARIAL);
        return fontRecord;
    }

    public static FormatRecord createFormat(int i2) {
        int[] iArr = {5, 6, 7, 8, 42, 41, 44, 43};
        if (i2 >= 0 && i2 < 8) {
            return new FormatRecord(iArr[i2], BuiltinFormats.getBuiltinFormat(iArr[i2]));
        }
        throw new IllegalArgumentException(a.c("Unexpected id ", i2));
    }

    public static HideObjRecord createHideObj() {
        HideObjRecord hideObjRecord = new HideObjRecord();
        hideObjRecord.setHideObj(0);
        return hideObjRecord;
    }

    public static MMSRecord createMMS() {
        MMSRecord mMSRecord = new MMSRecord();
        mMSRecord.setAddMenuCount((byte) 0);
        mMSRecord.setDelMenuCount((byte) 0);
        return mMSRecord;
    }

    public static PaletteRecord createPalette() {
        return new PaletteRecord();
    }

    public static PasswordRecord createPassword() {
        return new PasswordRecord(0);
    }

    public static PasswordRev4Record createPasswordRev4() {
        return new PasswordRev4Record(0);
    }

    public static PrecisionRecord createPrecision() {
        PrecisionRecord precisionRecord = new PrecisionRecord();
        precisionRecord.setFullPrecision(true);
        return precisionRecord;
    }

    public static ProtectRecord createProtect() {
        return new ProtectRecord(false);
    }

    public static ProtectionRev4Record createProtectionRev4() {
        return new ProtectionRev4Record(false);
    }

    public static RefreshAllRecord createRefreshAll() {
        return new RefreshAllRecord(false);
    }

    public static StyleRecord createStyle(int i2) {
        int[][] iArr = {new int[]{16, 3}, new int[]{17, 6}, new int[]{18, 4}, new int[]{19, 7}, new int[]{0, 0}, new int[]{20, 5}};
        if (i2 < 0 || i2 >= 6) {
            throw new IllegalArgumentException(a.c("Unexpected style id ", i2));
        }
        StyleRecord styleRecord = new StyleRecord();
        styleRecord.setOutlineStyleLevel(-1);
        styleRecord.setXFIndex(iArr[i2][0]);
        styleRecord.setBuiltinStyle(iArr[i2][1]);
        return styleRecord;
    }

    public static TabIdRecord createTabId() {
        return new TabIdRecord();
    }

    public static UseSelFSRecord createUseSelFS() {
        return new UseSelFSRecord(false);
    }

    public static WindowOneRecord createWindowOne() {
        WindowOneRecord windowOneRecord = new WindowOneRecord();
        windowOneRecord.setHorizontalHold(360);
        windowOneRecord.setVerticalHold(270);
        windowOneRecord.setWidth(14940);
        windowOneRecord.setHeight(9150);
        windowOneRecord.setOptions(56);
        windowOneRecord.setActiveSheetIndex(0);
        windowOneRecord.setFirstVisibleTab(0);
        windowOneRecord.setNumSelectedTabs(1);
        windowOneRecord.setTabWidthRatio(600);
        return windowOneRecord;
    }

    public static WindowProtectRecord createWindowProtect() {
        return new WindowProtectRecord(false);
    }

    public static InternalWorkbook createWorkbook(List<Record> list) {
        String str;
        LOG.log(1, "Workbook (readfile) created with reclen=", Integer.valueOf(list.size()));
        InternalWorkbook internalWorkbook = new InternalWorkbook();
        ArrayList arrayList = new ArrayList(list.size() / 3);
        internalWorkbook.records.setRecords(arrayList);
        int i2 = 0;
        boolean z = false;
        while (i2 < list.size()) {
            Record record = list.get(i2);
            switch (record.getSid()) {
                case 10:
                    str = "workbook eof";
                    break;
                case 18:
                    internalWorkbook.records.setProtpos(i2);
                    str = "protect";
                    break;
                case 23:
                    throw new RecordFormatException("Extern sheet is part of LinkTable");
                case 24:
                case 430:
                    LOG.log(1, a.c("found SupBook record at ", i2));
                    LinkTable linkTable2 = new LinkTable(list, i2, internalWorkbook.records, internalWorkbook.commentRecords);
                    internalWorkbook.linkTable = linkTable2;
                    i2 += linkTable2.getRecordCount() - 1;
                    continue;
                    i2++;
                case 34:
                    internalWorkbook.uses1904datewindowing = ((DateWindow1904Record) record).getWindowing() == 1;
                    str = "datewindow1904";
                    break;
                case 49:
                    internalWorkbook.records.setFontpos(i2);
                    internalWorkbook.numfonts++;
                    str = CellUtil.FONT;
                    break;
                case 61:
                    internalWorkbook.windowOne = (WindowOneRecord) record;
                    str = "WindowOneRecord";
                    break;
                case 64:
                    internalWorkbook.records.setBackuppos(i2);
                    str = "backup";
                    break;
                case 91:
                    internalWorkbook.fileShare = (FileSharingRecord) record;
                    str = "FileSharing";
                    break;
                case 92:
                    internalWorkbook.writeAccess = (WriteAccessRecord) record;
                    str = "WriteAccess";
                    break;
                case 133:
                    internalWorkbook.boundsheets.add((BoundSheetRecord) record);
                    internalWorkbook.records.setBspos(i2);
                    str = "boundsheet";
                    break;
                case 134:
                    internalWorkbook.writeProtect = (WriteProtectRecord) record;
                    str = "WriteProtect";
                    break;
                case 146:
                    internalWorkbook.records.setPalettepos(i2);
                    str = "palette";
                    break;
                case 224:
                    internalWorkbook.records.setXfpos(i2);
                    internalWorkbook.numxfs++;
                    str = "XF";
                    break;
                case 252:
                    internalWorkbook.sst = (SSTRecord) record;
                    str = "sst";
                    break;
                case 317:
                    internalWorkbook.records.setTabpos(i2);
                    str = "tabid";
                    break;
                case 440:
                    internalWorkbook.hyperlinks.add((HyperlinkRecord) record);
                    str = "Hyperlink";
                    break;
                case 1054:
                    FormatRecord formatRecord = (FormatRecord) record;
                    internalWorkbook.formats.add(formatRecord);
                    internalWorkbook.maxformatid = internalWorkbook.maxformatid >= formatRecord.getIndexCode() ? internalWorkbook.maxformatid : formatRecord.getIndexCode();
                    str = "format";
                    break;
                case 2196:
                    NameCommentRecord nameCommentRecord = (NameCommentRecord) record;
                    internalWorkbook.commentRecords.put(nameCommentRecord.getNameText(), nameCommentRecord);
                    str = "NameComment";
                    break;
                default:
                    StringBuilder b2 = a.b("(sid=");
                    b2.append((int) record.getSid());
                    b2.append(")");
                    str = b2.toString();
                    break;
            }
            if (!z) {
                arrayList.add(record);
            }
            LOG.log(1, "found " + str + " record at " + i2);
            if (record.getSid() == 10) {
                z = true;
            }
            i2++;
        }
        if (internalWorkbook.windowOne == null) {
            internalWorkbook.windowOne = createWindowOne();
        }
        LOG.log(1, "exit create workbook from existing file function");
        return internalWorkbook;
    }

    public static WriteAccessRecord createWriteAccess() {
        WriteAccessRecord writeAccessRecord = new WriteAccessRecord();
        try {
            String property = System.getProperty("user.name");
            if (property == null) {
                property = "POI";
            }
            writeAccessRecord.setUsername(property);
        } catch (AccessControlException e2) {
            LOG.log(5, "can't determine user.name", e2);
            writeAccessRecord.setUsername("POI");
        }
        return writeAccessRecord;
    }

    public static DrawingManager2 findDrawingManager(DrawingGroupRecord drawingGroupRecord, List<EscherBSERecord> list) {
        EscherContainerRecord escherContainer;
        if (drawingGroupRecord == null || (escherContainer = drawingGroupRecord.getEscherContainer()) == null) {
            return null;
        }
        Iterator<EscherRecord> it = escherContainer.iterator();
        EscherDggRecord escherDggRecord = null;
        EscherContainerRecord escherContainerRecord = null;
        while (it.hasNext()) {
            EscherRecord next = it.next();
            if (next instanceof EscherDggRecord) {
                escherDggRecord = (EscherDggRecord) next;
            } else if (next.getRecordId() == -4095) {
                escherContainerRecord = (EscherContainerRecord) next;
            }
        }
        if (escherDggRecord == null) {
            return null;
        }
        DrawingManager2 drawingManager2 = new DrawingManager2(escherDggRecord);
        if (escherContainerRecord != null) {
            for (EscherRecord escherRecord : escherContainerRecord.getChildRecords()) {
                if (escherRecord instanceof EscherBSERecord) {
                    list.add((EscherBSERecord) escherRecord);
                }
            }
        }
        return drawingManager2;
    }

    private String findSheetNameFromIndex(int i2) {
        if (i2 >= 0 && i2 < this.boundsheets.size()) {
            return getSheetName(i2);
        }
        return "";
    }

    private void fixTabIdRecord() {
        WorkbookRecordList workbookRecordList = this.records;
        Record record = workbookRecordList.get(workbookRecordList.getTabpos());
        if (this.records.getTabpos() > 0) {
            TabIdRecord tabIdRecord = (TabIdRecord) record;
            int size = this.boundsheets.size();
            short[] sArr = new short[size];
            for (short s = 0; s < size; s = (short) (s + 1)) {
                sArr[s] = s;
            }
            tabIdRecord.setTabIdArray(sArr);
        }
    }

    private BoundSheetRecord getBoundSheetRec(int i2) {
        return this.boundsheets.get(i2);
    }

    private LinkTable getOrCreateLinkTable() {
        if (this.linkTable == null) {
            this.linkTable = new LinkTable((short) getNumSheets(), this.records);
        }
        return this.linkTable;
    }

    public int addBSERecord(EscherBSERecord escherBSERecord) {
        EscherContainerRecord escherContainerRecord;
        createDrawingGroup();
        this.escherBSERecords.add(escherBSERecord);
        EscherContainerRecord escherContainerRecord2 = (EscherContainerRecord) ((DrawingGroupRecord) getRecords().get(findFirstRecordLocBySid(DrawingGroupRecord.sid))).getEscherRecord(0);
        if (escherContainerRecord2.getChild(1).getRecordId() == -4095) {
            escherContainerRecord = (EscherContainerRecord) escherContainerRecord2.getChild(1);
        } else {
            EscherContainerRecord escherContainerRecord3 = new EscherContainerRecord();
            escherContainerRecord3.setRecordId(EscherContainerRecord.BSTORE_CONTAINER);
            List<EscherRecord> childRecords = escherContainerRecord2.getChildRecords();
            childRecords.add(1, escherContainerRecord3);
            escherContainerRecord2.setChildRecords(childRecords);
            escherContainerRecord = escherContainerRecord3;
        }
        escherContainerRecord.setOptions((short) ((this.escherBSERecords.size() << 4) | 15));
        escherContainerRecord.addChildRecord(escherBSERecord);
        return this.escherBSERecords.size();
    }

    public NameRecord addName(NameRecord nameRecord) {
        getOrCreateLinkTable().addName(nameRecord);
        return nameRecord;
    }

    public int addSSTString(UnicodeString unicodeString) {
        LOG.log(1, "insert to sst string='", unicodeString);
        if (this.sst == null) {
            insertSST();
        }
        return this.sst.addString(unicodeString);
    }

    public boolean changeExternalReference(String str, String str2) {
        return this.linkTable.changeExternalReference(str, str2);
    }

    public short checkExternSheet(int i2) {
        return (short) getOrCreateLinkTable().checkExternSheet(i2);
    }

    public void cloneDrawings(InternalSheet internalSheet) {
        EscherContainerRecord escherContainer;
        EscherSimpleProperty escherSimpleProperty;
        findDrawingGroup();
        DrawingManager2 drawingManager2 = this.drawingManager;
        if (drawingManager2 != null && internalSheet.aggregateDrawingRecords(drawingManager2, false) != -1 && (escherContainer = ((EscherAggregate) internalSheet.findFirstRecordBySid(EscherAggregate.sid)).getEscherContainer()) != null) {
            EscherDggRecord dgg = this.drawingManager.getDgg();
            short findNewDrawingGroupId = this.drawingManager.findNewDrawingGroupId();
            dgg.addCluster(findNewDrawingGroupId, 0);
            dgg.setDrawingsSaved(dgg.getDrawingsSaved() + 1);
            EscherDgRecord escherDgRecord = null;
            Iterator<EscherRecord> it = escherContainer.iterator();
            while (it.hasNext()) {
                EscherRecord next = it.next();
                if (next instanceof EscherDgRecord) {
                    EscherDgRecord escherDgRecord2 = (EscherDgRecord) next;
                    escherDgRecord2.setOptions((short) (findNewDrawingGroupId << 4));
                    escherDgRecord = escherDgRecord2;
                } else if (next instanceof EscherContainerRecord) {
                    Iterator<EscherRecord> it2 = ((EscherContainerRecord) next).iterator();
                    while (it2.hasNext()) {
                        Iterator<EscherRecord> it3 = ((EscherContainerRecord) it2.next()).iterator();
                        while (true) {
                            if (it3.hasNext()) {
                                EscherRecord next2 = it3.next();
                                short recordId = next2.getRecordId();
                                if (recordId == -4086) {
                                    if (escherDgRecord != null) {
                                        int allocateShapeId = this.drawingManager.allocateShapeId(escherDgRecord);
                                        escherDgRecord.setNumShapes(escherDgRecord.getNumShapes() - 1);
                                        ((EscherSpRecord) next2).setShapeId(allocateShapeId);
                                    } else {
                                        throw new RecordFormatException("EscherDgRecord wasn't set/processed before.");
                                    }
                                } else if (recordId == -4085 && (escherSimpleProperty = (EscherSimpleProperty) ((EscherOptRecord) next2).lookup(260)) != null) {
                                    EscherBSERecord bSERecord = getBSERecord(escherSimpleProperty.getPropertyValue());
                                    bSERecord.setRef(bSERecord.getRef() + 1);
                                }
                            }
                        }
                    }
                    continue;
                } else {
                    continue;
                }
            }
        }
    }

    /* JADX DEBUG: Multi-variable search result rejected for r2v1, resolved type: java.lang.Object[] */
    /* JADX WARN: Multi-variable type inference failed */
    public NameRecord cloneFilter(int i2, int i3) {
        NameRecord nameRecord = getNameRecord(i2);
        short checkExternSheet = checkExternSheet(i3);
        Ptg[] nameDefinition = nameRecord.getNameDefinition();
        for (int i4 = 0; i4 < nameDefinition.length; i4++) {
            Object[] objArr = nameDefinition[i4];
            if (objArr instanceof Area3DPtg) {
                Area3DPtg area3DPtg = (Area3DPtg) ((OperandPtg) objArr).copy();
                area3DPtg.setExternSheetIndex(checkExternSheet);
                nameDefinition[i4] = area3DPtg;
            } else if (objArr instanceof Ref3DPtg) {
                Ref3DPtg ref3DPtg = (Ref3DPtg) ((OperandPtg) objArr).copy();
                ref3DPtg.setExternSheetIndex(checkExternSheet);
                nameDefinition[i4] = ref3DPtg;
            }
        }
        NameRecord createBuiltInName = createBuiltInName((byte) 13, i3 + 1);
        createBuiltInName.setNameDefinition(nameDefinition);
        createBuiltInName.setHidden(true);
        return createBuiltInName;
    }

    public NameRecord createBuiltInName(byte b2, int i2) {
        if (i2 < 0 || i2 + 1 > 32767) {
            throw new IllegalArgumentException(a.b("Sheet number [", i2, "]is not valid "));
        }
        NameRecord nameRecord = new NameRecord(b2, i2);
        if (!this.linkTable.nameAlreadyExists(nameRecord)) {
            addName(nameRecord);
            return nameRecord;
        }
        throw new RuntimeException(a.b("Builtin (", b2, ") already exists for sheet (", i2, ")"));
    }

    public ExtendedFormatRecord createCellXF() {
        ExtendedFormatRecord createExtendedFormat = createExtendedFormat();
        WorkbookRecordList workbookRecordList = this.records;
        workbookRecordList.add(workbookRecordList.getXfpos() + 1, createExtendedFormat);
        WorkbookRecordList workbookRecordList2 = this.records;
        workbookRecordList2.setXfpos(workbookRecordList2.getXfpos() + 1);
        this.numxfs++;
        return createExtendedFormat;
    }

    public void createDrawingGroup() {
        if (this.drawingManager == null) {
            EscherContainerRecord escherContainerRecord = new EscherContainerRecord();
            EscherDggRecord escherDggRecord = new EscherDggRecord();
            EscherOptRecord escherOptRecord = new EscherOptRecord();
            EscherSplitMenuColorsRecord escherSplitMenuColorsRecord = new EscherSplitMenuColorsRecord();
            escherContainerRecord.setRecordId(EscherContainerRecord.DGG_CONTAINER);
            escherContainerRecord.setOptions(15);
            escherDggRecord.setRecordId(EscherDggRecord.RECORD_ID);
            escherDggRecord.setOptions(0);
            escherDggRecord.setShapeIdMax(1024);
            escherDggRecord.setNumShapesSaved(0);
            escherDggRecord.setDrawingsSaved(0);
            escherDggRecord.setFileIdClusters(new EscherDggRecord.FileIdCluster[0]);
            this.drawingManager = new DrawingManager2(escherDggRecord);
            EscherContainerRecord escherContainerRecord2 = null;
            if (!this.escherBSERecords.isEmpty()) {
                escherContainerRecord2 = new EscherContainerRecord();
                escherContainerRecord2.setRecordId(EscherContainerRecord.BSTORE_CONTAINER);
                escherContainerRecord2.setOptions((short) (15 | (this.escherBSERecords.size() << 4)));
                for (EscherBSERecord escherBSERecord : this.escherBSERecords) {
                    escherContainerRecord2.addChildRecord(escherBSERecord);
                }
            }
            escherOptRecord.setRecordId(EscherOptRecord.RECORD_ID);
            escherOptRecord.setOptions(51);
            escherOptRecord.addEscherProperty(new EscherBoolProperty(191, 524296));
            escherOptRecord.addEscherProperty(new EscherRGBProperty(EscherProperties.FILL__FILLCOLOR, 134217793));
            escherOptRecord.addEscherProperty(new EscherRGBProperty(EscherProperties.LINESTYLE__COLOR, HSSFShape.LINESTYLE__COLOR_DEFAULT));
            escherSplitMenuColorsRecord.setRecordId(EscherSplitMenuColorsRecord.RECORD_ID);
            escherSplitMenuColorsRecord.setOptions(64);
            escherSplitMenuColorsRecord.setColor1(134217741);
            escherSplitMenuColorsRecord.setColor2(134217740);
            escherSplitMenuColorsRecord.setColor3(134217751);
            escherSplitMenuColorsRecord.setColor4(268435703);
            escherContainerRecord.addChildRecord(escherDggRecord);
            if (escherContainerRecord2 != null) {
                escherContainerRecord.addChildRecord(escherContainerRecord2);
            }
            escherContainerRecord.addChildRecord(escherOptRecord);
            escherContainerRecord.addChildRecord(escherSplitMenuColorsRecord);
            int findFirstRecordLocBySid = findFirstRecordLocBySid(DrawingGroupRecord.sid);
            if (findFirstRecordLocBySid == -1) {
                DrawingGroupRecord drawingGroupRecord = new DrawingGroupRecord();
                drawingGroupRecord.addEscherRecord(escherContainerRecord);
                getRecords().add(findFirstRecordLocBySid(140) + 1, drawingGroupRecord);
                return;
            }
            DrawingGroupRecord drawingGroupRecord2 = new DrawingGroupRecord();
            drawingGroupRecord2.addEscherRecord(escherContainerRecord);
            getRecords().set(findFirstRecordLocBySid, drawingGroupRecord2);
        }
    }

    public NameRecord createName() {
        return addName(new NameRecord());
    }

    public FontRecord createNewFont() {
        FontRecord createFont = createFont();
        WorkbookRecordList workbookRecordList = this.records;
        workbookRecordList.add(workbookRecordList.getFontpos() + 1, createFont);
        WorkbookRecordList workbookRecordList2 = this.records;
        workbookRecordList2.setFontpos(workbookRecordList2.getFontpos() + 1);
        this.numfonts++;
        return createFont;
    }

    public StyleRecord createStyleRecord(int i2) {
        StyleRecord styleRecord = new StyleRecord();
        styleRecord.setXFIndex(i2);
        int i3 = -1;
        for (int xfpos = this.records.getXfpos(); xfpos < this.records.size() && i3 == -1; xfpos++) {
            Record record = this.records.get(xfpos);
            if (!(record instanceof ExtendedFormatRecord) && !(record instanceof StyleRecord)) {
                i3 = xfpos;
            }
        }
        if (i3 != -1) {
            this.records.add(i3, styleRecord);
            return styleRecord;
        }
        throw new IllegalStateException("No XF Records found!");
    }

    public boolean doesContainsSheetName(String str, int i2) {
        if (str.length() > 31) {
            str = str.substring(0, 31);
        }
        int i3 = 0;
        for (BoundSheetRecord boundSheetRecord : this.boundsheets) {
            int i4 = i3 + 1;
            if (i2 != i3) {
                String sheetname = boundSheetRecord.getSheetname();
                if (sheetname.length() > 31) {
                    sheetname = sheetname.substring(0, 31);
                }
                if (str.equalsIgnoreCase(sheetname)) {
                    return true;
                }
            }
            i3 = i4;
        }
        return false;
    }

    public DrawingManager2 findDrawingGroup() {
        DrawingManager2 drawingManager2 = this.drawingManager;
        if (drawingManager2 != null) {
            return drawingManager2;
        }
        for (Record record : this.records.getRecords()) {
            if (record instanceof DrawingGroupRecord) {
                DrawingGroupRecord drawingGroupRecord = (DrawingGroupRecord) record;
                drawingGroupRecord.processChildRecords();
                DrawingManager2 findDrawingManager = findDrawingManager(drawingGroupRecord, this.escherBSERecords);
                this.drawingManager = findDrawingManager;
                if (findDrawingManager != null) {
                    return findDrawingManager;
                }
            }
        }
        DrawingManager2 findDrawingManager2 = findDrawingManager((DrawingGroupRecord) findFirstRecordBySid(DrawingGroupRecord.sid), this.escherBSERecords);
        this.drawingManager = findDrawingManager2;
        return findDrawingManager2;
    }

    public Record findFirstRecordBySid(short s) {
        for (Record record : this.records.getRecords()) {
            if (record.getSid() == s) {
                return record;
            }
        }
        return null;
    }

    public int findFirstRecordLocBySid(short s) {
        int i2 = 0;
        for (Record record : this.records.getRecords()) {
            if (record.getSid() == s) {
                return i2;
            }
            i2++;
        }
        return -1;
    }

    public Record findNextRecordBySid(short s, int i2) {
        int i3 = 0;
        for (Record record : this.records.getRecords()) {
            if (record.getSid() == s) {
                int i4 = i3 + 1;
                if (i3 == i2) {
                    return record;
                }
                i3 = i4;
            }
        }
        return null;
    }

    public String findSheetFirstNameFromExternSheet(int i2) {
        return findSheetNameFromIndex(this.linkTable.getFirstInternalSheetIndexForExtIndex(i2));
    }

    public String findSheetLastNameFromExternSheet(int i2) {
        return findSheetNameFromIndex(this.linkTable.getLastInternalSheetIndexForExtIndex(i2));
    }

    public EscherBSERecord getBSERecord(int i2) {
        return this.escherBSERecords.get(i2 - 1);
    }

    public BackupRecord getBackupRecord() {
        WorkbookRecordList workbookRecordList = this.records;
        return (BackupRecord) workbookRecordList.get(workbookRecordList.getBackuppos());
    }

    public PaletteRecord getCustomPalette() {
        int palettepos = this.records.getPalettepos();
        if (palettepos != -1) {
            Record record = this.records.get(palettepos);
            if (record instanceof PaletteRecord) {
                return (PaletteRecord) record;
            }
            throw new RuntimeException("InternalError: Expected PaletteRecord but got a '" + record + "'");
        }
        PaletteRecord createPalette = createPalette();
        this.records.add(1, createPalette);
        this.records.setPalettepos(1);
        return createPalette;
    }

    public DrawingManager2 getDrawingManager() {
        return this.drawingManager;
    }

    public ExtendedFormatRecord getExFormatAt(int i2) {
        return (ExtendedFormatRecord) this.records.get((this.records.getXfpos() - (this.numxfs - 1)) + i2);
    }

    public EvaluationWorkbook.ExternalName getExternalName(int i2, int i3) {
        String resolveNameXText = this.linkTable.resolveNameXText(i2, i3, this);
        if (resolveNameXText == null) {
            return null;
        }
        return new EvaluationWorkbook.ExternalName(resolveNameXText, i3, this.linkTable.resolveNameXIx(i2, i3));
    }

    public EvaluationWorkbook.ExternalSheet getExternalSheet(int i2) {
        String[] externalBookAndSheetName = this.linkTable.getExternalBookAndSheetName(i2);
        if (externalBookAndSheetName == null) {
            return null;
        }
        if (externalBookAndSheetName.length == 2) {
            return new EvaluationWorkbook.ExternalSheet(externalBookAndSheetName[0], externalBookAndSheetName[1]);
        }
        return new EvaluationWorkbook.ExternalSheetRange(externalBookAndSheetName[0], externalBookAndSheetName[1], externalBookAndSheetName[2]);
    }

    public int getExternalSheetIndex(String str, String str2) {
        return getOrCreateLinkTable().getExternalSheetIndex(str, str2, str2);
    }

    public FileSharingRecord getFileSharing() {
        if (this.fileShare == null) {
            this.fileShare = new FileSharingRecord();
            this.records.add(findFirstRecordLocBySid(92) + 1, this.fileShare);
        }
        return this.fileShare;
    }

    public int getFirstSheetIndexFromExternSheetIndex(int i2) {
        return this.linkTable.getFirstInternalSheetIndexForExtIndex(i2);
    }

    public int getFontIndex(FontRecord fontRecord) {
        int i2 = 0;
        while (i2 <= this.numfonts) {
            WorkbookRecordList workbookRecordList = this.records;
            if (((FontRecord) workbookRecordList.get((workbookRecordList.getFontpos() - (this.numfonts - 1)) + i2)) == fontRecord) {
                return i2 > 3 ? i2 + 1 : i2;
            }
            i2++;
        }
        throw new IllegalArgumentException("Could not find that font!");
    }

    public FontRecord getFontRecordAt(int i2) {
        int i3 = i2 > 4 ? i2 - 1 : i2;
        if (i3 <= this.numfonts - 1) {
            WorkbookRecordList workbookRecordList = this.records;
            return (FontRecord) workbookRecordList.get((workbookRecordList.getFontpos() - (this.numfonts - 1)) + i3);
        }
        throw new ArrayIndexOutOfBoundsException(a.a(a.b("There are only "), this.numfonts, " font records, you asked for ", i2));
    }

    public short getFormat(String str, boolean z) {
        int createFormat;
        Iterator<FormatRecord> it = this.formats.iterator();
        while (true) {
            if (it.hasNext()) {
                FormatRecord next = it.next();
                if (next.getFormatString().equals(str)) {
                    createFormat = next.getIndexCode();
                    break;
                }
            } else if (!z) {
                return -1;
            } else {
                createFormat = createFormat(str);
            }
        }
        return (short) createFormat;
    }

    public List<FormatRecord> getFormats() {
        return this.formats;
    }

    public List<HyperlinkRecord> getHyperlinks() {
        return this.hyperlinks;
    }

    public int getLastSheetIndexFromExternSheetIndex(int i2) {
        return this.linkTable.getLastInternalSheetIndexForExtIndex(i2);
    }

    public NameCommentRecord getNameCommentRecord(NameRecord nameRecord) {
        return this.commentRecords.get(nameRecord.getNameText());
    }

    public NameRecord getNameRecord(int i2) {
        return this.linkTable.getNameRecord(i2);
    }

    public NameXPtg getNameXPtg(String str, int i2, UDFFinder uDFFinder) {
        LinkTable orCreateLinkTable = getOrCreateLinkTable();
        NameXPtg nameXPtg = orCreateLinkTable.getNameXPtg(str, i2);
        return (nameXPtg != null || uDFFinder.findFunction(str) == null) ? nameXPtg : orCreateLinkTable.addNameXPtg(str);
    }

    public int getNumExFormats() {
        LOG.log(1, "getXF=", Integer.valueOf(this.numxfs));
        return this.numxfs;
    }

    public int getNumNames() {
        LinkTable linkTable2 = this.linkTable;
        if (linkTable2 == null) {
            return 0;
        }
        return linkTable2.getNumNames();
    }

    public int getNumRecords() {
        return this.records.size();
    }

    public int getNumSheets() {
        LOG.log(1, "getNumSheets=", Integer.valueOf(this.boundsheets.size()));
        return this.boundsheets.size();
    }

    public int getNumberOfFontRecords() {
        return this.numfonts;
    }

    public RecalcIdRecord getRecalcId() {
        RecalcIdRecord recalcIdRecord = (RecalcIdRecord) findFirstRecordBySid(449);
        if (recalcIdRecord != null) {
            return recalcIdRecord;
        }
        RecalcIdRecord recalcIdRecord2 = new RecalcIdRecord();
        this.records.add(findFirstRecordLocBySid(140) + 1, recalcIdRecord2);
        return recalcIdRecord2;
    }

    public List<Record> getRecords() {
        return this.records.getRecords();
    }

    public UnicodeString getSSTString(int i2) {
        if (this.sst == null) {
            insertSST();
        }
        UnicodeString string = this.sst.getString(i2);
        LOG.log(1, "Returning SST for index=", Integer.valueOf(i2), " String= ", string);
        return string;
    }

    public int getSheetIndex(String str) {
        int size = this.boundsheets.size();
        for (int i2 = 0; i2 < size; i2++) {
            if (getSheetName(i2).equalsIgnoreCase(str)) {
                return i2;
            }
        }
        return -1;
    }

    public String getSheetName(int i2) {
        return getBoundSheetRec(i2).getSheetname();
    }

    public SheetVisibility getSheetVisibility(int i2) {
        BoundSheetRecord boundSheetRec = getBoundSheetRec(i2);
        if (boundSheetRec.isVeryHidden()) {
            return SheetVisibility.VERY_HIDDEN;
        }
        if (boundSheetRec.isHidden()) {
            return SheetVisibility.HIDDEN;
        }
        return SheetVisibility.VISIBLE;
    }

    public int getSize() {
        int i2;
        int i3 = 0;
        SSTRecord sSTRecord = null;
        for (Record record : this.records.getRecords()) {
            if (record instanceof SSTRecord) {
                sSTRecord = (SSTRecord) record;
            }
            if (record.getSid() != 255 || sSTRecord == null) {
                i2 = record.getRecordSize();
            } else {
                i2 = sSTRecord.calcExtSSTRecordSize();
            }
            i3 = i2 + i3;
        }
        return i3;
    }

    public NameRecord getSpecificBuiltinRecord(byte b2, int i2) {
        return getOrCreateLinkTable().getSpecificBuiltinRecord(b2, i2);
    }

    public StyleRecord getStyleRecord(int i2) {
        for (int xfpos = this.records.getXfpos(); xfpos < this.records.size(); xfpos++) {
            Record record = this.records.get(xfpos);
            if (record instanceof StyleRecord) {
                StyleRecord styleRecord = (StyleRecord) record;
                if (styleRecord.getXFIndex() == i2) {
                    return styleRecord;
                }
            }
        }
        return null;
    }

    public WindowOneRecord getWindowOne() {
        return this.windowOne;
    }

    @Internal
    public WorkbookRecordList getWorkbookRecordList() {
        return this.records;
    }

    public WriteAccessRecord getWriteAccess() {
        if (this.writeAccess == null) {
            this.writeAccess = createWriteAccess();
            this.records.add(findFirstRecordLocBySid(InterfaceEndRecord.sid) + 1, this.writeAccess);
        }
        return this.writeAccess;
    }

    public WriteProtectRecord getWriteProtect() {
        if (this.writeProtect == null) {
            this.writeProtect = new WriteProtectRecord();
            this.records.add(findFirstRecordLocBySid(2057) + 1, this.writeProtect);
        }
        return this.writeProtect;
    }

    public void insertSST() {
        LOG.log(1, "creating new SST via insertSST!");
        this.sst = new SSTRecord();
        WorkbookRecordList workbookRecordList = this.records;
        workbookRecordList.add(workbookRecordList.size() - 1, createExtendedSST());
        WorkbookRecordList workbookRecordList2 = this.records;
        workbookRecordList2.add(workbookRecordList2.size() - 2, this.sst);
    }

    public boolean isSheetHidden(int i2) {
        return getBoundSheetRec(i2).isHidden();
    }

    public boolean isSheetVeryHidden(int i2) {
        return getBoundSheetRec(i2).isVeryHidden();
    }

    public boolean isUsing1904DateWindowing() {
        return this.uses1904datewindowing;
    }

    public boolean isWriteProtected() {
        if (this.fileShare != null && getFileSharing().getReadOnly() == 1) {
            return true;
        }
        return false;
    }

    public int linkExternalWorkbook(String str, Workbook workbook) {
        return getOrCreateLinkTable().linkExternalWorkbook(str, workbook);
    }

    public void preSerialize() {
        if (this.records.getTabpos() > 0) {
            WorkbookRecordList workbookRecordList = this.records;
            if (((TabIdRecord) workbookRecordList.get(workbookRecordList.getTabpos()))._tabids.length < this.boundsheets.size()) {
                fixTabIdRecord();
            }
        }
    }

    public void removeBuiltinRecord(byte b2, int i2) {
        this.linkTable.removeBuiltinRecord(b2, i2);
    }

    public void removeExFormatRecord(ExtendedFormatRecord extendedFormatRecord) {
        this.records.remove(extendedFormatRecord);
        this.numxfs--;
    }

    public void removeFontRecord(FontRecord fontRecord) {
        this.records.remove(fontRecord);
        this.numfonts--;
    }

    public void removeName(int i2) {
        if (this.linkTable.getNumNames() > i2) {
            this.records.remove(findFirstRecordLocBySid(24) + i2);
            this.linkTable.removeName(i2);
        }
    }

    public void removeSheet(int i2) {
        if (this.boundsheets.size() > i2) {
            WorkbookRecordList workbookRecordList = this.records;
            workbookRecordList.remove((workbookRecordList.getBspos() - (this.boundsheets.size() - 1)) + i2);
            this.boundsheets.remove(i2);
            fixTabIdRecord();
        }
        int i3 = i2 + 1;
        for (int i4 = 0; i4 < getNumNames(); i4++) {
            NameRecord nameRecord = getNameRecord(i4);
            if (nameRecord.getSheetNumber() == i3) {
                nameRecord.setSheetNumber(0);
            } else if (nameRecord.getSheetNumber() > i3) {
                nameRecord.setSheetNumber(nameRecord.getSheetNumber() - 1);
            }
        }
        LinkTable linkTable2 = this.linkTable;
        if (linkTable2 != null) {
            linkTable2.removeSheet(i2);
        }
    }

    public String resolveNameXText(int i2, int i3) {
        return this.linkTable.resolveNameXText(i2, i3, this);
    }

    public int serialize(int i2, byte[] bArr) {
        int i3;
        LOG.log(1, "Serializing Workbook with offsets");
        Iterator<Record> it = this.records.getRecords().iterator();
        SSTRecord sSTRecord = null;
        int i4 = 0;
        int i5 = 0;
        boolean z = false;
        while (it.hasNext()) {
            Record next = it.next();
            if (next instanceof SSTRecord) {
                sSTRecord = (SSTRecord) next;
                i5 = i4;
            }
            if (next.getSid() == 255 && sSTRecord != null) {
                next = sSTRecord.createExtSSTRecord(i5 + i2);
            }
            if (!(next instanceof BoundSheetRecord)) {
                i3 = next.serialize(i4 + i2, bArr);
            } else if (!z) {
                i3 = 0;
                for (BoundSheetRecord boundSheetRecord : this.boundsheets) {
                    i3 += boundSheetRecord.serialize(i4 + i2 + i3, bArr);
                }
                z = true;
            } else {
                i3 = 0;
            }
            i4 += i3;
        }
        LOG.log(1, "Exiting serialize workbook");
        return i4;
    }

    public void setSheetBof(int i2, int i3) {
        LOG.log(1, "setting bof for sheetnum =", Integer.valueOf(i2), " at pos=", Integer.valueOf(i3));
        checkSheets(i2);
        getBoundSheetRec(i2).setPositionOfBof(i3);
    }

    public void setSheetHidden(int i2, boolean z) {
        setSheetHidden(i2, z ? SheetVisibility.HIDDEN : SheetVisibility.VISIBLE);
    }

    public void setSheetName(int i2, String str) {
        checkSheets(i2);
        if (str.length() > 31) {
            str = str.substring(0, 31);
        }
        this.boundsheets.get(i2).setSheetname(str);
    }

    public void setSheetOrder(String str, int i2) {
        int sheetIndex = getSheetIndex(str);
        List<BoundSheetRecord> list = this.boundsheets;
        list.add(i2, list.remove(sheetIndex));
        int bspos = this.records.getBspos();
        int size = bspos - (this.boundsheets.size() - 1);
        int i3 = sheetIndex + size;
        Record record = this.records.get(i3);
        this.records.remove(i3);
        this.records.add(size + i2, record);
        this.records.setBspos(bspos);
    }

    public void unwriteProtectWorkbook() {
        this.records.remove(this.fileShare);
        this.records.remove(this.writeProtect);
        this.fileShare = null;
        this.writeProtect = null;
    }

    public void updateNameCommentRecordCache(NameCommentRecord nameCommentRecord) {
        if (this.commentRecords.containsValue(nameCommentRecord)) {
            Iterator<Map.Entry<String, NameCommentRecord>> it = this.commentRecords.entrySet().iterator();
            while (true) {
                if (!it.hasNext()) {
                    break;
                }
                Map.Entry<String, NameCommentRecord> next = it.next();
                if (next.getValue().equals(nameCommentRecord)) {
                    this.commentRecords.remove(next.getKey());
                    break;
                }
            }
        }
        this.commentRecords.put(nameCommentRecord.getNameText(), nameCommentRecord);
    }

    public void updateNamesAfterCellShift(FormulaShifter formulaShifter) {
        for (int i2 = 0; i2 < getNumNames(); i2++) {
            NameRecord nameRecord = getNameRecord(i2);
            Ptg[] nameDefinition = nameRecord.getNameDefinition();
            if (formulaShifter.adjustFormula(nameDefinition, nameRecord.getSheetNumber())) {
                nameRecord.setNameDefinition(nameDefinition);
            }
        }
    }

    public void writeProtectWorkbook(String str, String str2) {
        FileSharingRecord fileSharing = getFileSharing();
        WriteAccessRecord writeAccess2 = getWriteAccess();
        getWriteProtect();
        fileSharing.setReadOnly(1);
        fileSharing.setPassword((short) CryptoFunctions.createXorVerifier1(str));
        fileSharing.setUsername(str2);
        writeAccess2.setUsername(str2);
    }

    public short checkExternSheet(int i2, int i3) {
        return (short) getOrCreateLinkTable().checkExternSheet(i2, i3);
    }

    public int getExternalSheetIndex(String str, String str2, String str3) {
        return getOrCreateLinkTable().getExternalSheetIndex(str, str2, str3);
    }

    public void setSheetHidden(int i2, SheetVisibility sheetVisibility) {
        BoundSheetRecord boundSheetRec = getBoundSheetRec(i2);
        boolean z = true;
        boundSheetRec.setHidden(sheetVisibility == SheetVisibility.HIDDEN);
        if (sheetVisibility != SheetVisibility.VERY_HIDDEN) {
            z = false;
        }
        boundSheetRec.setVeryHidden(z);
    }

    public void removeExFormatRecord(int i2) {
        this.records.remove((this.records.getXfpos() - (this.numxfs - 1)) + i2);
        this.numxfs--;
    }

    public int createFormat(String str) {
        int i2 = this.maxformatid;
        int i3 = 164;
        if (i2 >= 164) {
            i3 = i2 + 1;
        }
        this.maxformatid = i3;
        FormatRecord formatRecord = new FormatRecord(this.maxformatid, str);
        int i4 = 0;
        while (i4 < this.records.size() && this.records.get(i4).getSid() != 1054) {
            i4++;
        }
        int size = this.formats.size() + i4;
        this.formats.add(formatRecord);
        this.records.add(size, formatRecord);
        return this.maxformatid;
    }

    public NameXPtg getNameXPtg(String str, UDFFinder uDFFinder) {
        return getNameXPtg(str, -1, uDFFinder);
    }

    public static ExtendedFormatRecord createExtendedFormat(int i2, int i3, int i4, int i5) {
        ExtendedFormatRecord extendedFormatRecord = new ExtendedFormatRecord();
        extendedFormatRecord.setFontIndex((short) i2);
        extendedFormatRecord.setFormatIndex((short) i3);
        extendedFormatRecord.setCellOptions((short) i4);
        extendedFormatRecord.setAlignmentOptions(32);
        extendedFormatRecord.setIndentionOptions((short) i5);
        extendedFormatRecord.setBorderOptions(0);
        extendedFormatRecord.setPaletteOptions(0);
        extendedFormatRecord.setAdtlPaletteOptions(0);
        extendedFormatRecord.setFillPaletteOptions(8384);
        return extendedFormatRecord;
    }

    public static ExtendedFormatRecord createExtendedFormat() {
        ExtendedFormatRecord extendedFormatRecord = new ExtendedFormatRecord();
        extendedFormatRecord.setFontIndex(0);
        extendedFormatRecord.setFormatIndex(0);
        extendedFormatRecord.setCellOptions(1);
        extendedFormatRecord.setAlignmentOptions(32);
        extendedFormatRecord.setIndentionOptions(0);
        extendedFormatRecord.setBorderOptions(0);
        extendedFormatRecord.setPaletteOptions(0);
        extendedFormatRecord.setAdtlPaletteOptions(0);
        extendedFormatRecord.setFillPaletteOptions(8384);
        extendedFormatRecord.setTopBorderPaletteIdx(HSSFColor.HSSFColorPredefined.BLACK.getIndex());
        extendedFormatRecord.setBottomBorderPaletteIdx(HSSFColor.HSSFColorPredefined.BLACK.getIndex());
        extendedFormatRecord.setLeftBorderPaletteIdx(HSSFColor.HSSFColorPredefined.BLACK.getIndex());
        extendedFormatRecord.setRightBorderPaletteIdx(HSSFColor.HSSFColorPredefined.BLACK.getIndex());
        return extendedFormatRecord;
    }

    public static InternalWorkbook createWorkbook() {
        LOG.log(1, "creating new workbook from scratch");
        InternalWorkbook internalWorkbook = new InternalWorkbook();
        ArrayList arrayList = new ArrayList(30);
        internalWorkbook.records.setRecords(arrayList);
        List<FormatRecord> list = internalWorkbook.formats;
        arrayList.add(createBOF());
        arrayList.add(new InterfaceHdrRecord(1200));
        arrayList.add(createMMS());
        arrayList.add(InterfaceEndRecord.instance);
        arrayList.add(createWriteAccess());
        arrayList.add(createCodepage());
        arrayList.add(createDSF());
        arrayList.add(createTabId());
        internalWorkbook.records.setTabpos(arrayList.size() - 1);
        arrayList.add(createFnGroupCount());
        arrayList.add(createWindowProtect());
        arrayList.add(createProtect());
        internalWorkbook.records.setProtpos(arrayList.size() - 1);
        arrayList.add(createPassword());
        arrayList.add(createProtectionRev4());
        arrayList.add(createPasswordRev4());
        WindowOneRecord createWindowOne = createWindowOne();
        internalWorkbook.windowOne = createWindowOne;
        arrayList.add(createWindowOne);
        arrayList.add(createBackup());
        internalWorkbook.records.setBackuppos(arrayList.size() - 1);
        arrayList.add(createHideObj());
        arrayList.add(createDateWindow1904());
        arrayList.add(createPrecision());
        arrayList.add(createRefreshAll());
        arrayList.add(createBookBool());
        arrayList.add(createFont());
        arrayList.add(createFont());
        arrayList.add(createFont());
        arrayList.add(createFont());
        internalWorkbook.records.setFontpos(arrayList.size() - 1);
        internalWorkbook.numfonts = 4;
        for (int i2 = 0; i2 <= 7; i2++) {
            FormatRecord createFormat = createFormat(i2);
            internalWorkbook.maxformatid = internalWorkbook.maxformatid >= createFormat.getIndexCode() ? internalWorkbook.maxformatid : createFormat.getIndexCode();
            list.add(createFormat);
            arrayList.add(createFormat);
        }
        for (int i3 = 0; i3 < 21; i3++) {
            arrayList.add(createExtendedFormat(i3));
            internalWorkbook.numxfs++;
        }
        internalWorkbook.records.setXfpos(arrayList.size() - 1);
        for (int i4 = 0; i4 < 6; i4++) {
            arrayList.add(createStyle(i4));
        }
        arrayList.add(createUseSelFS());
        for (int i5 = 0; i5 < 1; i5++) {
            BoundSheetRecord createBoundSheet = createBoundSheet(i5);
            arrayList.add(createBoundSheet);
            internalWorkbook.boundsheets.add(createBoundSheet);
            internalWorkbook.records.setBspos(arrayList.size() - 1);
        }
        arrayList.add(createCountry());
        for (int i6 = 0; i6 < 1; i6++) {
            internalWorkbook.getOrCreateLinkTable().checkExternSheet(i6);
        }
        SSTRecord sSTRecord = new SSTRecord();
        internalWorkbook.sst = sSTRecord;
        arrayList.add(sSTRecord);
        arrayList.add(createExtendedSST());
        arrayList.add(EOFRecord.instance);
        LOG.log(1, "exit create new workbook from scratch");
        return internalWorkbook;
    }
}
