package org.apache.poi.hssf.model;

import b.b.a.a.a;
import java.util.ArrayList;
import java.util.List;
import java.util.Map;
import org.apache.poi.hssf.record.CRNCountRecord;
import org.apache.poi.hssf.record.CRNRecord;
import org.apache.poi.hssf.record.ExternSheetRecord;
import org.apache.poi.hssf.record.ExternalNameRecord;
import org.apache.poi.hssf.record.NameCommentRecord;
import org.apache.poi.hssf.record.NameRecord;
import org.apache.poi.hssf.record.Record;
import org.apache.poi.hssf.record.SupBookRecord;
import org.apache.poi.ss.formula.SheetNameFormatter;
import org.apache.poi.ss.formula.ptg.ErrPtg;
import org.apache.poi.ss.formula.ptg.NameXPtg;
import org.apache.poi.ss.formula.ptg.Ptg;
import org.apache.poi.ss.usermodel.Workbook;

public final class LinkTable {
    public final List<NameRecord> _definedNames;
    public final ExternSheetRecord _externSheetRecord;
    public ExternalBookBlock[] _externalBookBlocks;
    public final int _recordCount;
    public final WorkbookRecordList _workbookRecordList;

    public static final class CRNBlock {
        public final CRNCountRecord _countRecord;
        public final CRNRecord[] _crns;

        public CRNBlock(RecordStream recordStream) {
            CRNCountRecord cRNCountRecord = (CRNCountRecord) recordStream.getNext();
            this._countRecord = cRNCountRecord;
            int numberOfCRNs = cRNCountRecord.getNumberOfCRNs();
            CRNRecord[] cRNRecordArr = new CRNRecord[numberOfCRNs];
            for (int i2 = 0; i2 < numberOfCRNs; i2++) {
                cRNRecordArr[i2] = (CRNRecord) recordStream.getNext();
            }
            this._crns = cRNRecordArr;
        }

        public CRNRecord[] getCrns() {
            return (CRNRecord[]) this._crns.clone();
        }
    }

    public LinkTable(List<Record> list, int i2, WorkbookRecordList workbookRecordList, Map<String, NameCommentRecord> map) {
        this._workbookRecordList = workbookRecordList;
        RecordStream recordStream = new RecordStream(list, i2);
        ArrayList arrayList = new ArrayList();
        while (recordStream.peekNextClass() == SupBookRecord.class) {
            arrayList.add(new ExternalBookBlock(recordStream));
        }
        ExternalBookBlock[] externalBookBlockArr = new ExternalBookBlock[arrayList.size()];
        this._externalBookBlocks = externalBookBlockArr;
        arrayList.toArray(externalBookBlockArr);
        arrayList.clear();
        if (this._externalBookBlocks.length <= 0) {
            this._externSheetRecord = null;
        } else if (recordStream.peekNextClass() != ExternSheetRecord.class) {
            this._externSheetRecord = null;
        } else {
            this._externSheetRecord = readExtSheetRecord(recordStream);
        }
        this._definedNames = new ArrayList();
        while (true) {
            Class<? extends Record> peekNextClass = recordStream.peekNextClass();
            if (peekNextClass == NameRecord.class) {
                this._definedNames.add((NameRecord) recordStream.getNext());
            } else if (peekNextClass == NameCommentRecord.class) {
                NameCommentRecord nameCommentRecord = (NameCommentRecord) recordStream.getNext();
                map.put(nameCommentRecord.getNameText(), nameCommentRecord);
            } else {
                this._recordCount = recordStream.getCountRead();
                this._workbookRecordList.getRecords().addAll(list.subList(i2, this._recordCount + i2));
                return;
            }
        }
    }

    private int extendExternalBookBlocks(ExternalBookBlock externalBookBlock) {
        ExternalBookBlock[] externalBookBlockArr = this._externalBookBlocks;
        int length = externalBookBlockArr.length + 1;
        ExternalBookBlock[] externalBookBlockArr2 = new ExternalBookBlock[length];
        System.arraycopy(externalBookBlockArr, 0, externalBookBlockArr2, 0, externalBookBlockArr.length);
        externalBookBlockArr2[length - 1] = externalBookBlock;
        this._externalBookBlocks = externalBookBlockArr2;
        return externalBookBlockArr2.length - 1;
    }

    private int findFirstRecordLocBySid(short s) {
        int i2 = 0;
        for (Record record : this._workbookRecordList.getRecords()) {
            if (record.getSid() == s) {
                return i2;
            }
            i2++;
        }
        return -1;
    }

    private int findRefIndexFromExtBookIndex(int i2) {
        return this._externSheetRecord.findRefIndexFromExtBookIndex(i2);
    }

    private int getExternalWorkbookIndex(String str) {
        int i2 = 0;
        while (true) {
            ExternalBookBlock[] externalBookBlockArr = this._externalBookBlocks;
            if (i2 >= externalBookBlockArr.length) {
                return -1;
            }
            SupBookRecord externalBookRecord = externalBookBlockArr[i2].getExternalBookRecord();
            if (externalBookRecord.isExternalReferences() && str.equals(externalBookRecord.getURL())) {
                return i2;
            }
            i2++;
        }
    }

    public static int getSheetIndex(String[] strArr, String str) {
        for (int i2 = 0; i2 < strArr.length; i2++) {
            if (strArr[i2].equals(str)) {
                return i2;
            }
        }
        throw new RuntimeException(a.b("External workbook does not contain sheet '", str, "'"));
    }

    public static boolean isDuplicatedNames(NameRecord nameRecord, NameRecord nameRecord2) {
        return nameRecord2.getNameText().equalsIgnoreCase(nameRecord.getNameText()) && isSameSheetNames(nameRecord, nameRecord2);
    }

    public static boolean isSameSheetNames(NameRecord nameRecord, NameRecord nameRecord2) {
        return nameRecord2.getSheetNumber() == nameRecord.getSheetNumber();
    }

    public static ExternSheetRecord readExtSheetRecord(RecordStream recordStream) {
        ArrayList arrayList = new ArrayList(2);
        while (recordStream.peekNextClass() == ExternSheetRecord.class) {
            arrayList.add((ExternSheetRecord) recordStream.getNext());
        }
        int size = arrayList.size();
        if (size < 1) {
            StringBuilder b2 = a.b("Expected an EXTERNSHEET record but got (");
            b2.append(recordStream.peekNextClass().getName());
            b2.append(")");
            throw new RuntimeException(b2.toString());
        } else if (size == 1) {
            return (ExternSheetRecord) arrayList.get(0);
        } else {
            ExternSheetRecord[] externSheetRecordArr = new ExternSheetRecord[size];
            arrayList.toArray(externSheetRecordArr);
            return ExternSheetRecord.combine(externSheetRecordArr);
        }
    }

    public void addName(NameRecord nameRecord) {
        this._definedNames.add(nameRecord);
        int findFirstRecordLocBySid = findFirstRecordLocBySid(23);
        if (findFirstRecordLocBySid == -1) {
            findFirstRecordLocBySid = findFirstRecordLocBySid(SupBookRecord.sid);
        }
        if (findFirstRecordLocBySid == -1) {
            findFirstRecordLocBySid = findFirstRecordLocBySid(140);
        }
        this._workbookRecordList.add(findFirstRecordLocBySid + this._definedNames.size(), nameRecord);
    }

    public NameXPtg addNameXPtg(String str) {
        ExternalBookBlock externalBookBlock;
        int i2 = 0;
        int i3 = 0;
        while (true) {
            ExternalBookBlock[] externalBookBlockArr = this._externalBookBlocks;
            if (i3 >= externalBookBlockArr.length) {
                i3 = -1;
                externalBookBlock = null;
                break;
            } else if (externalBookBlockArr[i3].getExternalBookRecord().isAddInFunctions()) {
                externalBookBlock = this._externalBookBlocks[i3];
                break;
            } else {
                i3++;
            }
        }
        if (externalBookBlock == null) {
            externalBookBlock = new ExternalBookBlock();
            i3 = extendExternalBookBlocks(externalBookBlock);
            this._workbookRecordList.add(findFirstRecordLocBySid(23), externalBookBlock.getExternalBookRecord());
            this._externSheetRecord.addRef(this._externalBookBlocks.length - 1, -2, -2);
        }
        ExternalNameRecord externalNameRecord = new ExternalNameRecord();
        externalNameRecord.setText(str);
        externalNameRecord.setParsedExpression(new Ptg[]{ErrPtg.REF_INVALID});
        int addExternalName = externalBookBlock.addExternalName(externalNameRecord);
        for (Record record : this._workbookRecordList.getRecords()) {
            if ((record instanceof SupBookRecord) && ((SupBookRecord) record).isAddInFunctions()) {
                break;
            }
            i2++;
        }
        this._workbookRecordList.add(i2 + externalBookBlock.getNumberOfNames(), externalNameRecord);
        return new NameXPtg(this._externSheetRecord.getRefIxForSheet(i3, -2, -2), addExternalName);
    }

    public boolean changeExternalReference(String str, String str2) {
        for (ExternalBookBlock externalBookBlock : this._externalBookBlocks) {
            SupBookRecord externalBookRecord = externalBookBlock.getExternalBookRecord();
            if (externalBookRecord.isExternalReferences() && externalBookRecord.getURL().equals(str)) {
                externalBookRecord.setURL(str2);
                return true;
            }
        }
        return false;
    }

    public int checkExternSheet(int i2) {
        return checkExternSheet(i2, i2);
    }

    public String[] getExternalBookAndSheetName(int i2) {
        SupBookRecord externalBookRecord = this._externalBookBlocks[this._externSheetRecord.getExtbookIndexFromRefIndex(i2)].getExternalBookRecord();
        String str = null;
        if (!externalBookRecord.isExternalReferences()) {
            return null;
        }
        int firstSheetIndexFromRefIndex = this._externSheetRecord.getFirstSheetIndexFromRefIndex(i2);
        int lastSheetIndexFromRefIndex = this._externSheetRecord.getLastSheetIndexFromRefIndex(i2);
        String str2 = firstSheetIndexFromRefIndex >= 0 ? externalBookRecord.getSheetNames()[firstSheetIndexFromRefIndex] : null;
        if (lastSheetIndexFromRefIndex >= 0) {
            str = externalBookRecord.getSheetNames()[lastSheetIndexFromRefIndex];
        }
        if (firstSheetIndexFromRefIndex == lastSheetIndexFromRefIndex) {
            return new String[]{externalBookRecord.getURL(), str2};
        }
        return new String[]{externalBookRecord.getURL(), str2, str};
    }

    public int getExternalSheetIndex(String str, String str2, String str3) {
        int externalWorkbookIndex = getExternalWorkbookIndex(str);
        if (externalWorkbookIndex != -1) {
            SupBookRecord externalBookRecord = this._externalBookBlocks[externalWorkbookIndex].getExternalBookRecord();
            int sheetIndex = getSheetIndex(externalBookRecord.getSheetNames(), str2);
            int sheetIndex2 = getSheetIndex(externalBookRecord.getSheetNames(), str3);
            int refIxForSheet = this._externSheetRecord.getRefIxForSheet(externalWorkbookIndex, sheetIndex, sheetIndex2);
            return refIxForSheet < 0 ? this._externSheetRecord.addRef(externalWorkbookIndex, sheetIndex, sheetIndex2) : refIxForSheet;
        }
        throw new RuntimeException(a.b("No external workbook with name '", str, "'"));
    }

    public int getFirstInternalSheetIndexForExtIndex(int i2) {
        if (i2 >= this._externSheetRecord.getNumOfRefs() || i2 < 0) {
            return -1;
        }
        return this._externSheetRecord.getFirstSheetIndexFromRefIndex(i2);
    }

    public int getLastInternalSheetIndexForExtIndex(int i2) {
        if (i2 >= this._externSheetRecord.getNumOfRefs() || i2 < 0) {
            return -1;
        }
        return this._externSheetRecord.getLastSheetIndexFromRefIndex(i2);
    }

    public NameRecord getNameRecord(int i2) {
        return this._definedNames.get(i2);
    }

    public NameXPtg getNameXPtg(String str, int i2) {
        int indexOfName;
        int findRefIndexFromExtBookIndex;
        int i3 = 0;
        while (true) {
            ExternalBookBlock[] externalBookBlockArr = this._externalBookBlocks;
            if (i3 >= externalBookBlockArr.length) {
                return null;
            }
            indexOfName = externalBookBlockArr[i3].getIndexOfName(str);
            if (indexOfName < 0 || (findRefIndexFromExtBookIndex = findRefIndexFromExtBookIndex(i3)) < 0 || (i2 != -1 && findRefIndexFromExtBookIndex != i2)) {
                i3++;
            }
        }
        return new NameXPtg(findRefIndexFromExtBookIndex, indexOfName);
    }

    public int getNumNames() {
        return this._definedNames.size();
    }

    public int getRecordCount() {
        return this._recordCount;
    }

    public NameRecord getSpecificBuiltinRecord(byte b2, int i2) {
        for (NameRecord nameRecord : this._definedNames) {
            if (nameRecord.getBuiltInName() == b2 && nameRecord.getSheetNumber() == i2) {
                return nameRecord;
            }
        }
        return null;
    }

    public int linkExternalWorkbook(String str, Workbook workbook) {
        int externalWorkbookIndex = getExternalWorkbookIndex(str);
        if (externalWorkbookIndex != -1) {
            return externalWorkbookIndex;
        }
        int numberOfSheets = workbook.getNumberOfSheets();
        String[] strArr = new String[numberOfSheets];
        for (int i2 = 0; i2 < numberOfSheets; i2++) {
            strArr[i2] = workbook.getSheetName(i2);
        }
        ExternalBookBlock externalBookBlock = new ExternalBookBlock(a.b("\u0000", str), strArr);
        int extendExternalBookBlocks = extendExternalBookBlocks(externalBookBlock);
        int findFirstRecordLocBySid = findFirstRecordLocBySid(23);
        if (findFirstRecordLocBySid == -1) {
            findFirstRecordLocBySid = this._workbookRecordList.size();
        }
        this._workbookRecordList.add(findFirstRecordLocBySid, externalBookBlock.getExternalBookRecord());
        for (int i3 = 0; i3 < numberOfSheets; i3++) {
            this._externSheetRecord.addRef(extendExternalBookBlocks, i3, i3);
        }
        return extendExternalBookBlocks;
    }

    public boolean nameAlreadyExists(NameRecord nameRecord) {
        for (int numNames = getNumNames() - 1; numNames >= 0; numNames--) {
            NameRecord nameRecord2 = getNameRecord(numNames);
            if (nameRecord2 != nameRecord && isDuplicatedNames(nameRecord, nameRecord2)) {
                return true;
            }
        }
        return false;
    }

    public void removeBuiltinRecord(byte b2, int i2) {
        NameRecord specificBuiltinRecord = getSpecificBuiltinRecord(b2, i2);
        if (specificBuiltinRecord != null) {
            this._definedNames.remove(specificBuiltinRecord);
        }
    }

    public void removeName(int i2) {
        this._definedNames.remove(i2);
    }

    public void removeSheet(int i2) {
        this._externSheetRecord.removeSheet(i2);
    }

    public int resolveNameXIx(int i2, int i3) {
        return this._externalBookBlocks[this._externSheetRecord.getExtbookIndexFromRefIndex(i2)].getNameIx(i3);
    }

    public String resolveNameXText(int i2, int i3, InternalWorkbook internalWorkbook) {
        int extbookIndexFromRefIndex = this._externSheetRecord.getExtbookIndexFromRefIndex(i2);
        int firstSheetIndexFromRefIndex = this._externSheetRecord.getFirstSheetIndexFromRefIndex(i2);
        if (firstSheetIndexFromRefIndex == -1) {
            throw new RuntimeException("Referenced sheet could not be found");
        } else if (this._externalBookBlocks[extbookIndexFromRefIndex]._externalNameRecords.length > i3) {
            return this._externalBookBlocks[extbookIndexFromRefIndex].getNameText(i3);
        } else {
            if (firstSheetIndexFromRefIndex == -2) {
                NameRecord nameRecord = getNameRecord(i3);
                int sheetNumber = nameRecord.getSheetNumber();
                StringBuffer stringBuffer = new StringBuffer();
                if (sheetNumber > 0) {
                    SheetNameFormatter.appendFormat(stringBuffer, internalWorkbook.getSheetName(sheetNumber - 1));
                    stringBuffer.append("!");
                }
                stringBuffer.append(nameRecord.getNameText());
                return stringBuffer.toString();
            }
            StringBuilder a = a.a("Ext Book Index relative but beyond the supported length, was ", extbookIndexFromRefIndex, " but maximum is ");
            a.append(this._externalBookBlocks.length);
            throw new ArrayIndexOutOfBoundsException(a.toString());
        }
    }

    public int checkExternSheet(int i2, int i3) {
        int i4 = 0;
        while (true) {
            ExternalBookBlock[] externalBookBlockArr = this._externalBookBlocks;
            if (i4 >= externalBookBlockArr.length) {
                i4 = -1;
                break;
            } else if (externalBookBlockArr[i4].getExternalBookRecord().isInternalReferences()) {
                break;
            } else {
                i4++;
            }
        }
        if (i4 >= 0) {
            int refIxForSheet = this._externSheetRecord.getRefIxForSheet(i4, i2, i3);
            if (refIxForSheet >= 0) {
                return refIxForSheet;
            }
            return this._externSheetRecord.addRef(i4, i2, i3);
        }
        throw new RuntimeException("Could not find 'internal references' EXTERNALBOOK");
    }

    public static final class ExternalBookBlock {
        public final CRNBlock[] _crnBlocks;
        public final SupBookRecord _externalBookRecord;
        public ExternalNameRecord[] _externalNameRecords;

        public ExternalBookBlock(RecordStream recordStream) {
            this._externalBookRecord = (SupBookRecord) recordStream.getNext();
            ArrayList arrayList = new ArrayList();
            while (recordStream.peekNextClass() == ExternalNameRecord.class) {
                arrayList.add(recordStream.getNext());
            }
            ExternalNameRecord[] externalNameRecordArr = new ExternalNameRecord[arrayList.size()];
            this._externalNameRecords = externalNameRecordArr;
            arrayList.toArray(externalNameRecordArr);
            arrayList.clear();
            while (recordStream.peekNextClass() == CRNCountRecord.class) {
                arrayList.add(new CRNBlock(recordStream));
            }
            CRNBlock[] cRNBlockArr = new CRNBlock[arrayList.size()];
            this._crnBlocks = cRNBlockArr;
            arrayList.toArray(cRNBlockArr);
        }

        public int addExternalName(ExternalNameRecord externalNameRecord) {
            ExternalNameRecord[] externalNameRecordArr = this._externalNameRecords;
            int length = externalNameRecordArr.length + 1;
            ExternalNameRecord[] externalNameRecordArr2 = new ExternalNameRecord[length];
            System.arraycopy(externalNameRecordArr, 0, externalNameRecordArr2, 0, externalNameRecordArr.length);
            externalNameRecordArr2[length - 1] = externalNameRecord;
            this._externalNameRecords = externalNameRecordArr2;
            return externalNameRecordArr2.length - 1;
        }

        public SupBookRecord getExternalBookRecord() {
            return this._externalBookRecord;
        }

        public int getIndexOfName(String str) {
            int i2 = 0;
            while (true) {
                ExternalNameRecord[] externalNameRecordArr = this._externalNameRecords;
                if (i2 >= externalNameRecordArr.length) {
                    return -1;
                }
                if (externalNameRecordArr[i2].getText().equalsIgnoreCase(str)) {
                    return i2;
                }
                i2++;
            }
        }

        public int getNameIx(int i2) {
            return this._externalNameRecords[i2].getIx();
        }

        public String getNameText(int i2) {
            return this._externalNameRecords[i2].getText();
        }

        public int getNumberOfNames() {
            return this._externalNameRecords.length;
        }

        public ExternalBookBlock(String str, String[] strArr) {
            this._externalBookRecord = SupBookRecord.createExternalReferences(str, strArr);
            this._crnBlocks = new CRNBlock[0];
        }

        public ExternalBookBlock(int i2) {
            this._externalBookRecord = SupBookRecord.createInternalReferences((short) i2);
            this._externalNameRecords = new ExternalNameRecord[0];
            this._crnBlocks = new CRNBlock[0];
        }

        public ExternalBookBlock() {
            this._externalBookRecord = SupBookRecord.createAddInFunctions();
            this._externalNameRecords = new ExternalNameRecord[0];
            this._crnBlocks = new CRNBlock[0];
        }
    }

    public LinkTable(int i2, WorkbookRecordList workbookRecordList) {
        this._workbookRecordList = workbookRecordList;
        this._definedNames = new ArrayList();
        this._externalBookBlocks = new ExternalBookBlock[]{new ExternalBookBlock(i2)};
        this._externSheetRecord = new ExternSheetRecord();
        this._recordCount = 2;
        SupBookRecord externalBookRecord = this._externalBookBlocks[0].getExternalBookRecord();
        int findFirstRecordLocBySid = findFirstRecordLocBySid(140);
        if (findFirstRecordLocBySid >= 0) {
            int i3 = findFirstRecordLocBySid + 1;
            this._workbookRecordList.add(i3, this._externSheetRecord);
            this._workbookRecordList.add(i3, externalBookRecord);
            return;
        }
        throw new RuntimeException("CountryRecord not found");
    }
}
