package org.apache.poi.hssf.model;

import b.b.a.a.a;
import java.util.List;
import org.apache.poi.hssf.record.DimensionsRecord;
import org.apache.poi.hssf.record.EOFRecord;
import org.apache.poi.hssf.record.GutsRecord;
import org.apache.poi.hssf.record.Record;
import org.apache.poi.hssf.record.RecordBase;
import org.apache.poi.hssf.record.aggregates.ColumnInfoRecordsAggregate;
import org.apache.poi.hssf.record.aggregates.ConditionalFormattingTable;
import org.apache.poi.hssf.record.aggregates.DataValidityTable;
import org.apache.poi.hssf.record.aggregates.MergedCellsTable;
import org.apache.poi.hssf.record.aggregates.PageSettingsBlock;
import org.apache.poi.hssf.record.aggregates.WorksheetProtectionBlock;

public final class RecordOrderer {
    public static void addNewSheetRecord(List<RecordBase> list, RecordBase recordBase) {
        list.add(findSheetInsertPos(list, recordBase.getClass()), recordBase);
    }

    public static int findDataValidationTableInsertPos(List<RecordBase> list) {
        int size = list.size() - 1;
        if (list.get(size) instanceof EOFRecord) {
            while (size > 0) {
                size--;
                RecordBase recordBase = list.get(size);
                if (isDVTPriorRecord(recordBase)) {
                    int i2 = size + 1;
                    Record record = (Record) list.get(i2);
                    if (isDVTSubsequentRecord(record.getSid())) {
                        return i2;
                    }
                    StringBuilder b2 = a.b("Unexpected (");
                    b2.append(record.getClass().getName());
                    b2.append(") found after (");
                    b2.append(recordBase.getClass().getName());
                    b2.append(")");
                    throw new IllegalStateException(b2.toString());
                }
                Record record2 = (Record) recordBase;
                if (!isDVTSubsequentRecord(record2.getSid())) {
                    StringBuilder b3 = a.b("Unexpected (");
                    b3.append(record2.getClass().getName());
                    b3.append(") while looking for DV Table insert pos");
                    throw new IllegalStateException(b3.toString());
                }
            }
            return 0;
        }
        throw new IllegalStateException("Last sheet record should be EOFRecord");
    }

    public static int findInsertPosForNewCondFormatTable(List<RecordBase> list) {
        short sid;
        for (int size = list.size() - 2; size >= 0; size--) {
            RecordBase recordBase = list.get(size);
            if (recordBase instanceof MergedCellsTable) {
                return size + 1;
            }
            if (!(recordBase instanceof DataValidityTable) && ((sid = ((Record) recordBase).getSid()) == 29 || sid == 65 || sid == 153 || sid == 160 || sid == 239 || sid == 351 || sid == 574)) {
                return size + 1;
            }
        }
        throw new RuntimeException("Did not find Window2 record");
    }

    public static int findInsertPosForNewMergedRecordTable(List<RecordBase> list) {
        short sid;
        for (int size = list.size() - 2; size >= 0; size--) {
            RecordBase recordBase = list.get(size);
            if ((recordBase instanceof Record) && ((sid = ((Record) recordBase).getSid()) == 29 || sid == 65 || sid == 153 || sid == 160 || sid == 574)) {
                return size + 1;
            }
        }
        throw new RuntimeException("Did not find Window2 record");
    }

    public static int findSheetInsertPos(List<RecordBase> list, Class<? extends RecordBase> cls) {
        if (cls == DataValidityTable.class) {
            return findDataValidationTableInsertPos(list);
        }
        if (cls == MergedCellsTable.class) {
            return findInsertPosForNewMergedRecordTable(list);
        }
        if (cls == ConditionalFormattingTable.class) {
            return findInsertPosForNewCondFormatTable(list);
        }
        if (cls == GutsRecord.class) {
            return getGutsRecordInsertPos(list);
        }
        if (cls == PageSettingsBlock.class) {
            return getPageBreakRecordInsertPos(list);
        }
        if (cls == WorksheetProtectionBlock.class) {
            return getWorksheetProtectionBlockInsertPos(list);
        }
        StringBuilder b2 = a.b("Unexpected record class (");
        b2.append(cls.getName());
        b2.append(")");
        throw new RuntimeException(b2.toString());
    }

    public static int getDimensionsIndex(List<RecordBase> list) {
        int size = list.size();
        for (int i2 = 0; i2 < size; i2++) {
            if (list.get(i2) instanceof DimensionsRecord) {
                return i2;
            }
        }
        throw new RuntimeException("DimensionsRecord not found");
    }

    public static int getGutsRecordInsertPos(List<RecordBase> list) {
        int dimensionsIndex = getDimensionsIndex(list) - 1;
        while (dimensionsIndex > 0) {
            dimensionsIndex--;
            if (isGutsPriorRecord(list.get(dimensionsIndex))) {
                return dimensionsIndex + 1;
            }
        }
        throw new RuntimeException("Did not find insert point for GUTS");
    }

    public static int getPageBreakRecordInsertPos(List<RecordBase> list) {
        int dimensionsIndex = getDimensionsIndex(list) - 1;
        while (dimensionsIndex > 0) {
            dimensionsIndex--;
            if (isPageBreakPriorRecord(list.get(dimensionsIndex))) {
                return dimensionsIndex + 1;
            }
        }
        throw new RuntimeException("Did not find insert point for GUTS");
    }

    public static int getWorksheetProtectionBlockInsertPos(List<RecordBase> list) {
        int dimensionsIndex = getDimensionsIndex(list);
        while (dimensionsIndex > 0) {
            dimensionsIndex--;
            if (!isProtectionSubsequentRecord(list.get(dimensionsIndex))) {
                return dimensionsIndex + 1;
            }
        }
        throw new IllegalStateException("did not find insert pos for protection block");
    }

    public static boolean isDVTPriorRecord(RecordBase recordBase) {
        short sid;
        if ((recordBase instanceof MergedCellsTable) || (recordBase instanceof ConditionalFormattingTable) || (sid = ((Record) recordBase).getSid()) == 29 || sid == 65 || sid == 153 || sid == 160 || sid == 239 || sid == 351 || sid == 440 || sid == 442 || sid == 574 || sid == 2048) {
            return true;
        }
        return false;
    }

    public static boolean isDVTSubsequentRecord(short s) {
        return s == 10 || s == 2146 || s == 2248 || s == 2151 || s == 2152;
    }

    public static boolean isEndOfRowBlock(int i2) {
        if (i2 == 10) {
            throw new RuntimeException("Found EOFRecord before WindowTwoRecord was encountered");
        } else if (i2 == 61 || i2 == 93 || i2 == 125 || i2 == 128 || i2 == 176 || i2 == 434 || i2 == 438 || i2 == 574 || i2 == 236 || i2 == 237) {
            return true;
        } else {
            return PageSettingsBlock.isComponentRecord(i2);
        }
    }

    public static boolean isGutsPriorRecord(RecordBase recordBase) {
        if (!(recordBase instanceof Record)) {
            return false;
        }
        short sid = ((Record) recordBase).getSid();
        if (sid == 34 || sid == 130 || sid == 523 || sid == 2057 || sid == 42 || sid == 43 || sid == 94 || sid == 95) {
            return true;
        }
        switch (sid) {
            case 12:
            case 13:
            case 14:
            case 15:
            case 16:
            case 17:
                return true;
            default:
                return false;
        }
    }

    public static boolean isPageBreakPriorRecord(Object obj) {
        if (!(obj instanceof Record)) {
            return false;
        }
        short sid = ((Record) obj).getSid();
        if (sid == 34 || sid == 523 || sid == 549 || sid == 2057 || sid == 42 || sid == 43 || sid == 94 || sid == 95 || sid == 129 || sid == 130) {
            return true;
        }
        switch (sid) {
            case 12:
            case 13:
            case 14:
            case 15:
            case 16:
            case 17:
                return true;
            default:
                return false;
        }
    }

    public static boolean isProtectionSubsequentRecord(Object obj) {
        if (obj instanceof ColumnInfoRecordsAggregate) {
            return true;
        }
        if (!(obj instanceof Record)) {
            return false;
        }
        short sid = ((Record) obj).getSid();
        if (sid == 85 || sid == 144) {
            return true;
        }
        return false;
    }

    public static boolean isRowBlockRecord(int i2) {
        if (i2 == 6 || i2 == 253 || i2 == 513 || i2 == 520 || i2 == 545 || i2 == 566 || i2 == 638 || i2 == 1212) {
            return true;
        }
        switch (i2) {
            case 515:
            case 516:
            case 517:
                return true;
            default:
                return false;
        }
    }
}
