package org.apache.poi.hssf.model;

import java.util.ArrayList;
import java.util.List;
import org.apache.poi.hssf.record.Record;

public final class WorkbookRecordList {
    public int backuppos = 0;
    public int bspos = 0;
    public int externsheetPos = 0;
    public int fontpos = 0;
    public int namepos = 0;
    public int palettepos = -1;
    public int protpos = 0;
    public List<Record> records = new ArrayList();
    public int supbookpos = 0;
    public int tabpos = 0;
    public int xfpos = 0;

    private void updateRecordPos(int i2, boolean z) {
        int i3 = z ? 1 : -1;
        int protpos2 = getProtpos();
        if (protpos2 >= i2) {
            setProtpos(protpos2 + i3);
        }
        int bspos2 = getBspos();
        if (bspos2 >= i2) {
            setBspos(bspos2 + i3);
        }
        int tabpos2 = getTabpos();
        if (tabpos2 >= i2) {
            setTabpos(tabpos2 + i3);
        }
        int fontpos2 = getFontpos();
        if (fontpos2 >= i2) {
            setFontpos(fontpos2 + i3);
        }
        int xfpos2 = getXfpos();
        if (xfpos2 >= i2) {
            setXfpos(xfpos2 + i3);
        }
        int backuppos2 = getBackuppos();
        if (backuppos2 >= i2) {
            setBackuppos(backuppos2 + i3);
        }
        int namepos2 = getNamepos();
        if (namepos2 >= i2) {
            setNamepos(namepos2 + i3);
        }
        int supbookpos2 = getSupbookpos();
        if (supbookpos2 >= i2) {
            setSupbookpos(supbookpos2 + i3);
        }
        int palettepos2 = getPalettepos();
        if (palettepos2 != -1 && palettepos2 >= i2) {
            setPalettepos(palettepos2 + i3);
        }
        int externsheetPos2 = getExternsheetPos();
        if (externsheetPos2 >= i2) {
            setExternsheetPos(externsheetPos2 + i3);
        }
    }

    public void add(int i2, Record record) {
        this.records.add(i2, record);
        updateRecordPos(i2, true);
    }

    public Record get(int i2) {
        return this.records.get(i2);
    }

    public int getBackuppos() {
        return this.backuppos;
    }

    public int getBspos() {
        return this.bspos;
    }

    public int getExternsheetPos() {
        return this.externsheetPos;
    }

    public int getFontpos() {
        return this.fontpos;
    }

    public int getNamepos() {
        return this.namepos;
    }

    public int getPalettepos() {
        return this.palettepos;
    }

    public int getProtpos() {
        return this.protpos;
    }

    public List<Record> getRecords() {
        return this.records;
    }

    public int getSupbookpos() {
        return this.supbookpos;
    }

    public int getTabpos() {
        return this.tabpos;
    }

    public int getXfpos() {
        return this.xfpos;
    }

    public void remove(Object obj) {
        int i2 = 0;
        for (Record record : this.records) {
            if (record == obj) {
                remove(i2);
                return;
            }
            i2++;
        }
    }

    public void setBackuppos(int i2) {
        this.backuppos = i2;
    }

    public void setBspos(int i2) {
        this.bspos = i2;
    }

    public void setExternsheetPos(int i2) {
        this.externsheetPos = i2;
    }

    public void setFontpos(int i2) {
        this.fontpos = i2;
    }

    public void setNamepos(int i2) {
        this.namepos = i2;
    }

    public void setPalettepos(int i2) {
        this.palettepos = i2;
    }

    public void setProtpos(int i2) {
        this.protpos = i2;
    }

    public void setRecords(List<Record> list) {
        this.records = list;
    }

    public void setSupbookpos(int i2) {
        this.supbookpos = i2;
    }

    public void setTabpos(int i2) {
        this.tabpos = i2;
    }

    public void setXfpos(int i2) {
        this.xfpos = i2;
    }

    public int size() {
        return this.records.size();
    }

    public void remove(int i2) {
        this.records.remove(i2);
        updateRecordPos(i2, false);
    }
}
