package org.apache.poi.hssf.record;

import b.b.a.a.a;
import java.util.ArrayList;
import java.util.List;
import org.apache.poi.ddf.DefaultEscherRecordFactory;
import org.apache.poi.ddf.EscherContainerRecord;
import org.apache.poi.ddf.EscherRecord;
import org.apache.poi.ddf.EscherRecordFactory;
import org.apache.poi.ddf.NullEscherSerializationListener;
import org.apache.poi.hssf.util.LazilyConcatenatedByteArray;
import org.apache.poi.util.LittleEndian;

public abstract class AbstractEscherHolderRecord extends Record implements Cloneable {
    public static boolean DESERIALISE;
    public final List<EscherRecord> escherRecords = new ArrayList();
    public final LazilyConcatenatedByteArray rawDataContainer = new LazilyConcatenatedByteArray();

    static {
        try {
            DESERIALISE = System.getProperty("poi.deserialize.escher") != null;
        } catch (SecurityException unused) {
            DESERIALISE = false;
        }
    }

    public AbstractEscherHolderRecord() {
    }

    private void convertToEscherRecords(int i2, int i3, byte[] bArr) {
        this.escherRecords.clear();
        EscherRecordFactory defaultEscherRecordFactory = new DefaultEscherRecordFactory();
        int i4 = i2;
        while (i4 < i2 + i3) {
            EscherRecord createRecord = defaultEscherRecordFactory.createRecord(bArr, i4);
            int fillFields = createRecord.fillFields(bArr, i4, defaultEscherRecordFactory);
            this.escherRecords.add(createRecord);
            i4 += fillFields;
        }
    }

    public void addEscherRecord(int i2, EscherRecord escherRecord) {
        this.escherRecords.add(i2, escherRecord);
    }

    public void clearEscherRecords() {
        this.escherRecords.clear();
    }

    public void convertRawBytesToEscherRecords() {
        if (!DESERIALISE) {
            byte[] rawData = getRawData();
            convertToEscherRecords(0, rawData.length, rawData);
        }
    }

    public void decode() {
        List<EscherRecord> list = this.escherRecords;
        if (list == null || list.size() == 0) {
            byte[] rawData = getRawData();
            convertToEscherRecords(0, rawData.length, rawData);
        }
    }

    public EscherRecord findFirstWithId(short s) {
        return findFirstWithId(s, getEscherRecords());
    }

    public EscherContainerRecord getEscherContainer() {
        for (EscherRecord escherRecord : this.escherRecords) {
            if (escherRecord instanceof EscherContainerRecord) {
                return (EscherContainerRecord) escherRecord;
            }
        }
        return null;
    }

    public EscherRecord getEscherRecord(int i2) {
        return this.escherRecords.get(i2);
    }

    public List<EscherRecord> getEscherRecords() {
        return this.escherRecords;
    }

    public byte[] getRawData() {
        return this.rawDataContainer.toArray();
    }

    public abstract String getRecordName();

    @Override // org.apache.poi.hssf.record.RecordBase
    public int getRecordSize() {
        byte[] rawData = getRawData();
        if (this.escherRecords.size() == 0 && rawData != null) {
            return rawData.length;
        }
        int i2 = 0;
        for (EscherRecord escherRecord : this.escherRecords) {
            i2 += escherRecord.getRecordSize();
        }
        return i2;
    }

    @Override // org.apache.poi.hssf.record.Record
    public abstract short getSid();

    public void join(AbstractEscherHolderRecord abstractEscherHolderRecord) {
        this.rawDataContainer.concatenate(abstractEscherHolderRecord.getRawData());
    }

    public void processContinueRecord(byte[] bArr) {
        this.rawDataContainer.concatenate(bArr);
    }

    @Override // org.apache.poi.hssf.record.RecordBase
    public int serialize(int i2, byte[] bArr) {
        int i3 = i2 + 0;
        LittleEndian.putShort(bArr, i3, getSid());
        int i4 = i2 + 2;
        LittleEndian.putShort(bArr, i4, (short) (getRecordSize() - 4));
        byte[] rawData = getRawData();
        if (this.escherRecords.size() != 0 || rawData == null) {
            LittleEndian.putShort(bArr, i3, getSid());
            LittleEndian.putShort(bArr, i4, (short) (getRecordSize() - 4));
            int i5 = i2 + 4;
            for (EscherRecord escherRecord : this.escherRecords) {
                i5 += escherRecord.serialize(i5, bArr, new NullEscherSerializationListener());
            }
            return getRecordSize();
        }
        LittleEndian.putShort(bArr, i3, getSid());
        LittleEndian.putShort(bArr, i4, (short) (getRecordSize() - 4));
        System.arraycopy(rawData, 0, bArr, i2 + 4, rawData.length);
        return rawData.length + 4;
    }

    public void setRawData(byte[] bArr) {
        this.rawDataContainer.clear();
        this.rawDataContainer.concatenate(bArr);
    }

    @Override // org.apache.poi.hssf.record.Record
    public String toString() {
        StringBuffer stringBuffer = new StringBuffer();
        String property = System.getProperty("line.separator");
        stringBuffer.append('[' + getRecordName() + ']' + property);
        if (this.escherRecords.size() == 0) {
            stringBuffer.append("No Escher Records Decoded" + property);
        }
        for (EscherRecord escherRecord : this.escherRecords) {
            stringBuffer.append(escherRecord);
        }
        StringBuilder b2 = a.b("[/");
        b2.append(getRecordName());
        b2.append(']');
        b2.append(property);
        stringBuffer.append(b2.toString());
        return stringBuffer.toString();
    }

    private EscherRecord findFirstWithId(short s, List<EscherRecord> list) {
        EscherRecord findFirstWithId;
        for (EscherRecord escherRecord : list) {
            if (escherRecord.getRecordId() == s) {
                return escherRecord;
            }
        }
        for (EscherRecord escherRecord2 : list) {
            if (escherRecord2.isContainerRecord() && (findFirstWithId = findFirstWithId(s, escherRecord2.getChildRecords())) != null) {
                return findFirstWithId;
            }
        }
        return null;
    }

    public boolean addEscherRecord(EscherRecord escherRecord) {
        return this.escherRecords.add(escherRecord);
    }

    @Override // org.apache.poi.hssf.record.Record, java.lang.Object
    public AbstractEscherHolderRecord clone() {
        return (AbstractEscherHolderRecord) cloneViaReserialise();
    }

    public AbstractEscherHolderRecord(RecordInputStream recordInputStream) {
        if (!DESERIALISE) {
            this.rawDataContainer.concatenate(recordInputStream.readRemainder());
            return;
        }
        byte[] readAllContinuedRemainder = recordInputStream.readAllContinuedRemainder();
        convertToEscherRecords(0, readAllContinuedRemainder.length, readAllContinuedRemainder);
    }
}
