package org.apache.poi.hssf.record;

import b.b.a.a.a;
import org.apache.poi.util.HexDump;
import org.apache.poi.util.LittleEndianOutput;

public final class BOFRecord extends StandardRecord implements Cloneable {
    public static final int BUILD = 4307;
    public static final int BUILD_YEAR = 1996;
    public static final int HISTORY_MASK = 65;
    public static final int TYPE_CHART = 32;
    public static final int TYPE_EXCEL_4_MACRO = 64;
    public static final int TYPE_VB_MODULE = 6;
    public static final int TYPE_WORKBOOK = 5;
    public static final int TYPE_WORKSHEET = 16;
    public static final int TYPE_WORKSPACE_FILE = 256;
    public static final int VERSION = 1536;
    public static final short biff2_sid = 9;
    public static final short biff3_sid = 521;
    public static final short biff4_sid = 1033;
    public static final short biff5_sid = 2057;
    public static final short sid = 2057;
    public int field_1_version;
    public int field_2_type;
    public int field_3_build;
    public int field_4_year;
    public int field_5_history;
    public int field_6_rversion;

    public BOFRecord() {
    }

    public static BOFRecord createSheetBOF() {
        return new BOFRecord(16);
    }

    private String getTypeName() {
        int i2 = this.field_2_type;
        if (i2 == 5) {
            return "workbook";
        }
        if (i2 == 6) {
            return "vb module";
        }
        if (i2 == 16) {
            return "worksheet";
        }
        if (i2 == 32) {
            return "chart";
        }
        if (i2 != 64) {
            return i2 != 256 ? "#error unknown type#" : "workspace file";
        }
        return "excel 4 macro";
    }

    public int getBuild() {
        return this.field_3_build;
    }

    public int getBuildYear() {
        return this.field_4_year;
    }

    @Override // org.apache.poi.hssf.record.StandardRecord
    public int getDataSize() {
        return 16;
    }

    public int getHistoryBitMask() {
        return this.field_5_history;
    }

    public int getRequiredVersion() {
        return this.field_6_rversion;
    }

    @Override // org.apache.poi.hssf.record.Record
    public short getSid() {
        return 2057;
    }

    public int getType() {
        return this.field_2_type;
    }

    public int getVersion() {
        return this.field_1_version;
    }

    @Override // org.apache.poi.hssf.record.StandardRecord
    public void serialize(LittleEndianOutput littleEndianOutput) {
        littleEndianOutput.writeShort(getVersion());
        littleEndianOutput.writeShort(getType());
        littleEndianOutput.writeShort(getBuild());
        littleEndianOutput.writeShort(getBuildYear());
        littleEndianOutput.writeInt(getHistoryBitMask());
        littleEndianOutput.writeInt(getRequiredVersion());
    }

    public void setBuild(int i2) {
        this.field_3_build = i2;
    }

    public void setBuildYear(int i2) {
        this.field_4_year = i2;
    }

    public void setHistoryBitMask(int i2) {
        this.field_5_history = i2;
    }

    public void setRequiredVersion(int i2) {
        this.field_6_rversion = i2;
    }

    public void setType(int i2) {
        this.field_2_type = i2;
    }

    public void setVersion(int i2) {
        this.field_1_version = i2;
    }

    @Override // org.apache.poi.hssf.record.Record
    public String toString() {
        StringBuffer c = a.c("[BOF RECORD]\n", "    .version  = ");
        c.append(HexDump.shortToHex(getVersion()));
        c.append("\n");
        c.append("    .type     = ");
        c.append(HexDump.shortToHex(getType()));
        c.append(" (");
        a.a(c, getTypeName(), ")", "\n", "    .build    = ");
        c.append(HexDump.shortToHex(getBuild()));
        c.append("\n");
        c.append("    .buildyear= ");
        c.append(getBuildYear());
        c.append("\n");
        c.append("    .history  = ");
        c.append(HexDump.intToHex(getHistoryBitMask()));
        c.append("\n");
        c.append("    .reqver   = ");
        c.append(HexDump.intToHex(getRequiredVersion()));
        return a.a(c, "\n", "[/BOF RECORD]\n");
    }

    public BOFRecord(int i2) {
        this.field_1_version = VERSION;
        this.field_2_type = i2;
        this.field_3_build = BUILD;
        this.field_4_year = BUILD_YEAR;
        this.field_5_history = 1;
        this.field_6_rversion = VERSION;
    }

    @Override // org.apache.poi.hssf.record.Record, java.lang.Object
    public BOFRecord clone() {
        BOFRecord bOFRecord = new BOFRecord();
        bOFRecord.field_1_version = this.field_1_version;
        bOFRecord.field_2_type = this.field_2_type;
        bOFRecord.field_3_build = this.field_3_build;
        bOFRecord.field_4_year = this.field_4_year;
        bOFRecord.field_5_history = this.field_5_history;
        bOFRecord.field_6_rversion = this.field_6_rversion;
        return bOFRecord;
    }

    public BOFRecord(RecordInputStream recordInputStream) {
        this.field_1_version = recordInputStream.readShort();
        this.field_2_type = recordInputStream.readShort();
        if (recordInputStream.remaining() >= 2) {
            this.field_3_build = recordInputStream.readShort();
        }
        if (recordInputStream.remaining() >= 2) {
            this.field_4_year = recordInputStream.readShort();
        }
        if (recordInputStream.remaining() >= 4) {
            this.field_5_history = recordInputStream.readInt();
        }
        if (recordInputStream.remaining() >= 4) {
            this.field_6_rversion = recordInputStream.readInt();
        }
    }
}
