package org.apache.poi.hssf.record;

import b.b.a.a.a;
import org.apache.poi.ss.util.CellRangeAddress;
import org.apache.poi.ss.util.CellRangeAddressList;
import org.apache.poi.ss.util.CellRangeUtil;
import org.apache.poi.util.LittleEndianOutput;
import org.apache.poi.xssf.usermodel.XSSFDataValidationConstraint;

public abstract class CFHeaderBase extends StandardRecord implements Cloneable {
    public int field_1_numcf;
    public int field_2_need_recalculation_and_id;
    public CellRangeAddress field_3_enclosing_cell_range;
    public CellRangeAddressList field_4_cell_ranges;

    public CFHeaderBase() {
    }

    @Override // org.apache.poi.hssf.record.Record, java.lang.Object
    public abstract CFHeaderBase clone();

    public void copyTo(CFHeaderBase cFHeaderBase) {
        cFHeaderBase.field_1_numcf = this.field_1_numcf;
        cFHeaderBase.field_2_need_recalculation_and_id = this.field_2_need_recalculation_and_id;
        cFHeaderBase.field_3_enclosing_cell_range = this.field_3_enclosing_cell_range.copy();
        cFHeaderBase.field_4_cell_ranges = this.field_4_cell_ranges.copy();
    }

    public void createEmpty() {
        this.field_3_enclosing_cell_range = new CellRangeAddress(0, 0, 0, 0);
        this.field_4_cell_ranges = new CellRangeAddressList();
    }

    public CellRangeAddress[] getCellRanges() {
        return this.field_4_cell_ranges.getCellRangeAddresses();
    }

    @Override // org.apache.poi.hssf.record.StandardRecord
    public int getDataSize() {
        return this.field_4_cell_ranges.getSize() + 12;
    }

    public CellRangeAddress getEnclosingCellRange() {
        return this.field_3_enclosing_cell_range;
    }

    public int getID() {
        return this.field_2_need_recalculation_and_id >> 1;
    }

    public boolean getNeedRecalculation() {
        return (this.field_2_need_recalculation_and_id & 1) == 1;
    }

    public int getNumberOfConditionalFormats() {
        return this.field_1_numcf;
    }

    public abstract String getRecordName();

    public void read(RecordInputStream recordInputStream) {
        this.field_1_numcf = recordInputStream.readShort();
        this.field_2_need_recalculation_and_id = recordInputStream.readShort();
        this.field_3_enclosing_cell_range = new CellRangeAddress(recordInputStream);
        this.field_4_cell_ranges = new CellRangeAddressList(recordInputStream);
    }

    @Override // org.apache.poi.hssf.record.StandardRecord
    public void serialize(LittleEndianOutput littleEndianOutput) {
        littleEndianOutput.writeShort(this.field_1_numcf);
        littleEndianOutput.writeShort(this.field_2_need_recalculation_and_id);
        this.field_3_enclosing_cell_range.serialize(littleEndianOutput);
        this.field_4_cell_ranges.serialize(littleEndianOutput);
    }

    public void setCellRanges(CellRangeAddress[] cellRangeAddressArr) {
        if (cellRangeAddressArr != null) {
            CellRangeAddressList cellRangeAddressList = new CellRangeAddressList();
            CellRangeAddress cellRangeAddress = null;
            for (CellRangeAddress cellRangeAddress2 : cellRangeAddressArr) {
                cellRangeAddress = CellRangeUtil.createEnclosingCellRange(cellRangeAddress2, cellRangeAddress);
                cellRangeAddressList.addCellRangeAddress(cellRangeAddress2);
            }
            this.field_3_enclosing_cell_range = cellRangeAddress;
            this.field_4_cell_ranges = cellRangeAddressList;
            return;
        }
        throw new IllegalArgumentException("cellRanges must not be null");
    }

    public void setEnclosingCellRange(CellRangeAddress cellRangeAddress) {
        this.field_3_enclosing_cell_range = cellRangeAddress;
    }

    public void setID(int i2) {
        boolean needRecalculation = getNeedRecalculation();
        int i3 = i2 << 1;
        this.field_2_need_recalculation_and_id = i3;
        if (needRecalculation) {
            this.field_2_need_recalculation_and_id = i3 + 1;
        }
    }

    public void setNeedRecalculation(boolean z) {
        if (z != getNeedRecalculation()) {
            if (z) {
                this.field_2_need_recalculation_and_id++;
            } else {
                this.field_2_need_recalculation_and_id--;
            }
        }
    }

    public void setNumberOfConditionalFormats(int i2) {
        this.field_1_numcf = i2;
    }

    @Override // org.apache.poi.hssf.record.Record
    public String toString() {
        StringBuffer a = a.a("[");
        a.append(getRecordName());
        a.append("]\n");
        a.append("\t.numCF             = ");
        a.append(getNumberOfConditionalFormats());
        a.append("\n");
        a.append("\t.needRecalc        = ");
        a.append(getNeedRecalculation());
        a.append("\n");
        a.append("\t.id                = ");
        a.append(getID());
        a.append("\n");
        a.append("\t.enclosingCellRange= ");
        a.append(getEnclosingCellRange());
        a.append("\n");
        a.append("\t.cfranges=[");
        int i2 = 0;
        while (i2 < this.field_4_cell_ranges.countRanges()) {
            a.append(i2 == 0 ? "" : XSSFDataValidationConstraint.LIST_SEPARATOR);
            a.append(this.field_4_cell_ranges.getCellRangeAddress(i2));
            i2++;
        }
        a.append("]\n");
        a.append("[/");
        a.append(getRecordName());
        a.append("]\n");
        return a.toString();
    }

    public CFHeaderBase(CellRangeAddress[] cellRangeAddressArr, int i2) {
        setCellRanges(CellRangeUtil.mergeCellRanges(cellRangeAddressArr));
        this.field_1_numcf = i2;
    }
}
