package org.apache.poi.hssf.record;

import b.b.a.a.a;
import java.util.Arrays;
import org.apache.poi.hssf.record.cf.ColorGradientFormatting;
import org.apache.poi.hssf.record.cf.ColorGradientThreshold;
import org.apache.poi.hssf.record.cf.DataBarFormatting;
import org.apache.poi.hssf.record.cf.DataBarThreshold;
import org.apache.poi.hssf.record.cf.IconMultiStateFormatting;
import org.apache.poi.hssf.record.cf.IconMultiStateThreshold;
import org.apache.poi.hssf.record.cf.Threshold;
import org.apache.poi.hssf.record.common.ExtendedColor;
import org.apache.poi.hssf.record.common.FtrHeader;
import org.apache.poi.hssf.record.common.FutureRecord;
import org.apache.poi.hssf.usermodel.HSSFSheet;
import org.apache.poi.ss.formula.Formula;
import org.apache.poi.ss.formula.ptg.Ptg;
import org.apache.poi.ss.usermodel.ConditionalFormattingThreshold;
import org.apache.poi.ss.usermodel.IconMultiStateFormatting;
import org.apache.poi.ss.util.CellRangeAddress;
import org.apache.poi.util.HexDump;
import org.apache.poi.util.LittleEndianOutput;
import org.apache.poi.util.POILogger;

public final class CFRule12Record extends CFRuleBase implements FutureRecord, Cloneable {
    public static final short sid = 2170;
    public ColorGradientFormatting color_gradient;
    public DataBarFormatting data_bar;
    public byte[] ext_formatting_data;
    public int ext_formatting_length;
    public byte ext_opts;
    public byte[] filter_data;
    public Formula formula_scale;
    public FtrHeader futureHeader;
    public IconMultiStateFormatting multistate;
    public int priority;
    public byte template_param_length;
    public byte[] template_params;
    public int template_type;

    public CFRule12Record(byte b2, byte b3) {
        super(b2, b3);
        setDefaults();
    }

    public static CFRule12Record create(HSSFSheet hSSFSheet, String str) {
        return new CFRule12Record((byte) 2, (byte) 0, CFRuleBase.parseFormula(str, hSSFSheet), null, null);
    }

    public static CFRule12Record createColorScale(HSSFSheet hSSFSheet) {
        ExtendedColor[] extendedColorArr = new ExtendedColor[3];
        ColorGradientThreshold[] colorGradientThresholdArr = new ColorGradientThreshold[3];
        for (int i2 = 0; i2 < 3; i2++) {
            colorGradientThresholdArr[i2] = new ColorGradientThreshold();
            extendedColorArr[i2] = new ExtendedColor();
        }
        CFRule12Record cFRule12Record = new CFRule12Record((byte) 3, (byte) 0);
        ColorGradientFormatting createColorGradientFormatting = cFRule12Record.createColorGradientFormatting();
        createColorGradientFormatting.setNumControlPoints(3);
        createColorGradientFormatting.setThresholds(colorGradientThresholdArr);
        createColorGradientFormatting.setColors(extendedColorArr);
        return cFRule12Record;
    }

    private void setDefaults() {
        FtrHeader ftrHeader = new FtrHeader();
        this.futureHeader = ftrHeader;
        ftrHeader.setRecordType(sid);
        this.ext_formatting_length = 0;
        this.ext_formatting_data = new byte[4];
        this.formula_scale = Formula.create(Ptg.EMPTY_PTG_ARRAY);
        this.ext_opts = 0;
        this.priority = 0;
        this.template_type = getConditionType();
        this.template_param_length = 16;
        this.template_params = new byte[16];
    }

    public boolean containsColorGradientBlock() {
        return this.color_gradient != null;
    }

    public boolean containsDataBarBlock() {
        return this.data_bar != null;
    }

    public boolean containsMultiStateBlock() {
        return this.multistate != null;
    }

    public ColorGradientFormatting createColorGradientFormatting() {
        ColorGradientFormatting colorGradientFormatting = this.color_gradient;
        if (colorGradientFormatting != null) {
            return colorGradientFormatting;
        }
        setConditionType((byte) 3);
        ColorGradientFormatting colorGradientFormatting2 = new ColorGradientFormatting();
        this.color_gradient = colorGradientFormatting2;
        return colorGradientFormatting2;
    }

    public DataBarFormatting createDataBarFormatting() {
        DataBarFormatting dataBarFormatting = this.data_bar;
        if (dataBarFormatting != null) {
            return dataBarFormatting;
        }
        setConditionType((byte) 4);
        DataBarFormatting dataBarFormatting2 = new DataBarFormatting();
        this.data_bar = dataBarFormatting2;
        return dataBarFormatting2;
    }

    public IconMultiStateFormatting createMultiStateFormatting() {
        IconMultiStateFormatting iconMultiStateFormatting = this.multistate;
        if (iconMultiStateFormatting != null) {
            return iconMultiStateFormatting;
        }
        setConditionType((byte) 6);
        IconMultiStateFormatting iconMultiStateFormatting2 = new IconMultiStateFormatting();
        this.multistate = iconMultiStateFormatting2;
        return iconMultiStateFormatting2;
    }

    @Override // org.apache.poi.hssf.record.common.FutureRecord
    public CellRangeAddress getAssociatedRange() {
        return this.futureHeader.getAssociatedRange();
    }

    public ColorGradientFormatting getColorGradientFormatting() {
        return this.color_gradient;
    }

    public DataBarFormatting getDataBarFormatting() {
        return this.data_bar;
    }

    @Override // org.apache.poi.hssf.record.StandardRecord
    public int getDataSize() {
        int i2;
        int dataLength;
        int dataSize = FtrHeader.getDataSize() + 6;
        if (this.ext_formatting_length == 0) {
            i2 = dataSize + 6;
        } else {
            i2 = dataSize + getFormattingBlockSize() + 4 + this.ext_formatting_data.length;
        }
        int length = this.template_params.length + 6 + CFRuleBase.getFormulaSize(this.formula_scale) + 2 + CFRuleBase.getFormulaSize(getFormula2()) + CFRuleBase.getFormulaSize(getFormula1()) + i2;
        byte conditionType = getConditionType();
        if (conditionType == 3) {
            dataLength = this.color_gradient.getDataLength();
        } else if (conditionType == 4) {
            dataLength = this.data_bar.getDataLength();
        } else if (conditionType == 5) {
            return length + this.filter_data.length;
        } else {
            if (conditionType != 6) {
                return length;
            }
            dataLength = this.multistate.getDataLength();
        }
        return length + dataLength;
    }

    @Override // org.apache.poi.hssf.record.common.FutureRecord
    public FtrHeader getFutureHeader() {
        return this.futureHeader;
    }

    @Override // org.apache.poi.hssf.record.common.FutureRecord
    public short getFutureRecordType() {
        return this.futureHeader.getRecordType();
    }

    public IconMultiStateFormatting getMultiStateFormatting() {
        return this.multistate;
    }

    public Ptg[] getParsedExpressionScale() {
        return this.formula_scale.getTokens();
    }

    public int getPriority() {
        return this.priority;
    }

    @Override // org.apache.poi.hssf.record.Record
    public short getSid() {
        return sid;
    }

    @Override // org.apache.poi.hssf.record.StandardRecord
    public void serialize(LittleEndianOutput littleEndianOutput) {
        this.futureHeader.serialize(littleEndianOutput);
        int formulaSize = CFRuleBase.getFormulaSize(getFormula1());
        int formulaSize2 = CFRuleBase.getFormulaSize(getFormula2());
        littleEndianOutput.writeByte(getConditionType());
        littleEndianOutput.writeByte(getComparisonOperation());
        littleEndianOutput.writeShort(formulaSize);
        littleEndianOutput.writeShort(formulaSize2);
        int i2 = this.ext_formatting_length;
        if (i2 == 0) {
            littleEndianOutput.writeInt(0);
            littleEndianOutput.writeShort(0);
        } else {
            littleEndianOutput.writeInt(i2);
            serializeFormattingBlock(littleEndianOutput);
            littleEndianOutput.write(this.ext_formatting_data);
        }
        getFormula1().serializeTokens(littleEndianOutput);
        getFormula2().serializeTokens(littleEndianOutput);
        littleEndianOutput.writeShort(CFRuleBase.getFormulaSize(this.formula_scale));
        this.formula_scale.serializeTokens(littleEndianOutput);
        littleEndianOutput.writeByte(this.ext_opts);
        littleEndianOutput.writeShort(this.priority);
        littleEndianOutput.writeShort(this.template_type);
        littleEndianOutput.writeByte(this.template_param_length);
        littleEndianOutput.write(this.template_params);
        byte conditionType = getConditionType();
        if (conditionType == 3) {
            this.color_gradient.serialize(littleEndianOutput);
        } else if (conditionType == 4) {
            this.data_bar.serialize(littleEndianOutput);
        } else if (conditionType == 5) {
            littleEndianOutput.write(this.filter_data);
        } else if (conditionType == 6) {
            this.multistate.serialize(littleEndianOutput);
        }
    }

    public void setParsedExpressionScale(Ptg[] ptgArr) {
        this.formula_scale = Formula.create(ptgArr);
    }

    public void setPriority(int i2) {
        this.priority = i2;
    }

    @Override // org.apache.poi.hssf.record.Record
    public String toString() {
        StringBuilder d2 = a.d("[CFRULE12]\n", "    .condition_type=");
        d2.append((int) getConditionType());
        d2.append("\n");
        d2.append("    .dxfn12_length =0x");
        d2.append(Integer.toHexString(this.ext_formatting_length));
        d2.append("\n");
        d2.append("    .option_flags  =0x");
        d2.append(Integer.toHexString(getOptions()));
        d2.append("\n");
        if (containsFontFormattingBlock()) {
            d2.append(this._fontFormatting);
            d2.append("\n");
        }
        if (containsBorderFormattingBlock()) {
            d2.append(this._borderFormatting);
            d2.append("\n");
        }
        if (containsPatternFormattingBlock()) {
            d2.append(this._patternFormatting);
            d2.append("\n");
        }
        d2.append("    .dxfn12_ext=");
        d2.append(HexDump.toHex(this.ext_formatting_data));
        d2.append("\n");
        d2.append("    .formula_1 =");
        d2.append(Arrays.toString(getFormula1().getTokens()));
        d2.append("\n");
        d2.append("    .formula_2 =");
        d2.append(Arrays.toString(getFormula2().getTokens()));
        d2.append("\n");
        d2.append("    .formula_S =");
        d2.append(Arrays.toString(this.formula_scale.getTokens()));
        d2.append("\n");
        d2.append("    .ext_opts  =");
        d2.append((int) this.ext_opts);
        d2.append("\n");
        d2.append("    .priority  =");
        d2.append(this.priority);
        d2.append("\n");
        d2.append("    .template_type  =");
        d2.append(this.template_type);
        d2.append("\n");
        d2.append("    .template_params=");
        d2.append(HexDump.toHex(this.template_params));
        d2.append("\n");
        d2.append("    .filter_data    =");
        d2.append(HexDump.toHex(this.filter_data));
        d2.append("\n");
        ColorGradientFormatting colorGradientFormatting = this.color_gradient;
        if (colorGradientFormatting != null) {
            d2.append(colorGradientFormatting);
        }
        IconMultiStateFormatting iconMultiStateFormatting = this.multistate;
        if (iconMultiStateFormatting != null) {
            d2.append(iconMultiStateFormatting);
        }
        DataBarFormatting dataBarFormatting = this.data_bar;
        if (dataBarFormatting != null) {
            d2.append(dataBarFormatting);
        }
        d2.append("[/CFRULE12]\n");
        return d2.toString();
    }

    public CFRule12Record(byte b2, byte b3, Ptg[] ptgArr, Ptg[] ptgArr2, Ptg[] ptgArr3) {
        super(b2, b3, ptgArr, ptgArr2);
        setDefaults();
        this.formula_scale = Formula.create(ptgArr3);
    }

    public static CFRule12Record create(HSSFSheet hSSFSheet, byte b2, String str, String str2) {
        return new CFRule12Record((byte) 1, b2, CFRuleBase.parseFormula(str, hSSFSheet), CFRuleBase.parseFormula(str2, hSSFSheet), null);
    }

    @Override // org.apache.poi.hssf.record.Record, org.apache.poi.hssf.record.CFRuleBase, org.apache.poi.hssf.record.CFRuleBase, java.lang.Object
    public CFRule12Record clone() {
        CFRule12Record cFRule12Record = new CFRule12Record(getConditionType(), getComparisonOperation());
        cFRule12Record.futureHeader.setAssociatedRange(this.futureHeader.getAssociatedRange().copy());
        super.copyTo(cFRule12Record);
        int min = Math.min(this.ext_formatting_length, this.ext_formatting_data.length);
        cFRule12Record.ext_formatting_length = min;
        byte[] bArr = new byte[this.ext_formatting_length];
        cFRule12Record.ext_formatting_data = bArr;
        System.arraycopy(this.ext_formatting_data, 0, bArr, 0, min);
        cFRule12Record.formula_scale = this.formula_scale.copy();
        cFRule12Record.ext_opts = this.ext_opts;
        cFRule12Record.priority = this.priority;
        cFRule12Record.template_type = this.template_type;
        cFRule12Record.template_param_length = this.template_param_length;
        int i2 = this.template_param_length;
        byte[] bArr2 = new byte[i2];
        cFRule12Record.template_params = bArr2;
        System.arraycopy(this.template_params, 0, bArr2, 0, i2);
        ColorGradientFormatting colorGradientFormatting = this.color_gradient;
        if (colorGradientFormatting != null) {
            cFRule12Record.color_gradient = (ColorGradientFormatting) colorGradientFormatting.clone();
        }
        IconMultiStateFormatting iconMultiStateFormatting = this.multistate;
        if (iconMultiStateFormatting != null) {
            cFRule12Record.multistate = (IconMultiStateFormatting) iconMultiStateFormatting.clone();
        }
        DataBarFormatting dataBarFormatting = this.data_bar;
        if (dataBarFormatting != null) {
            cFRule12Record.data_bar = (DataBarFormatting) dataBarFormatting.clone();
        }
        byte[] bArr3 = this.filter_data;
        if (bArr3 != null) {
            byte[] bArr4 = new byte[bArr3.length];
            cFRule12Record.filter_data = bArr4;
            byte[] bArr5 = this.filter_data;
            System.arraycopy(bArr5, 0, bArr4, 0, bArr5.length);
        }
        return cFRule12Record;
    }

    public CFRule12Record(RecordInputStream recordInputStream) {
        this.futureHeader = new FtrHeader(recordInputStream);
        setConditionType(recordInputStream.readByte());
        setComparisonOperation(recordInputStream.readByte());
        int readUShort = recordInputStream.readUShort();
        int readUShort2 = recordInputStream.readUShort();
        int readInt = recordInputStream.readInt();
        this.ext_formatting_length = readInt;
        this.ext_formatting_data = new byte[0];
        if (readInt == 0) {
            recordInputStream.readUShort();
        } else {
            int readFormatOptions = readFormatOptions(recordInputStream);
            int i2 = this.ext_formatting_length;
            if (readFormatOptions < i2) {
                byte[] bArr = new byte[(i2 - readFormatOptions)];
                this.ext_formatting_data = bArr;
                recordInputStream.readFully(bArr);
            }
        }
        setFormula1(Formula.read(readUShort, recordInputStream));
        setFormula2(Formula.read(readUShort2, recordInputStream));
        this.formula_scale = Formula.read(recordInputStream.readUShort(), recordInputStream);
        this.ext_opts = recordInputStream.readByte();
        this.priority = recordInputStream.readUShort();
        this.template_type = recordInputStream.readUShort();
        byte readByte = recordInputStream.readByte();
        this.template_param_length = readByte;
        if (readByte == 0 || readByte == 16) {
            byte[] bArr2 = new byte[this.template_param_length];
            this.template_params = bArr2;
            recordInputStream.readFully(bArr2);
        } else {
            POILogger pOILogger = CFRuleBase.logger;
            StringBuilder b2 = a.b("CF Rule v12 template params length should be 0 or 16, found ");
            b2.append((int) this.template_param_length);
            pOILogger.log(5, b2.toString());
            recordInputStream.readRemainder();
        }
        byte conditionType = getConditionType();
        if (conditionType == 3) {
            this.color_gradient = new ColorGradientFormatting(recordInputStream);
        } else if (conditionType == 4) {
            this.data_bar = new DataBarFormatting(recordInputStream);
        } else if (conditionType == 5) {
            this.filter_data = recordInputStream.readRemainder();
        } else if (conditionType == 6) {
            this.multistate = new IconMultiStateFormatting(recordInputStream);
        }
    }

    public static CFRule12Record create(HSSFSheet hSSFSheet, byte b2, String str, String str2, String str3) {
        return new CFRule12Record((byte) 1, b2, CFRuleBase.parseFormula(str, hSSFSheet), CFRuleBase.parseFormula(str2, hSSFSheet), CFRuleBase.parseFormula(str3, hSSFSheet));
    }

    public static CFRule12Record create(HSSFSheet hSSFSheet, ExtendedColor extendedColor) {
        CFRule12Record cFRule12Record = new CFRule12Record((byte) 4, (byte) 0);
        DataBarFormatting createDataBarFormatting = cFRule12Record.createDataBarFormatting();
        createDataBarFormatting.setColor(extendedColor);
        createDataBarFormatting.setPercentMin((byte) 0);
        createDataBarFormatting.setPercentMax((byte) 100);
        DataBarThreshold dataBarThreshold = new DataBarThreshold();
        dataBarThreshold.setType(ConditionalFormattingThreshold.RangeType.MIN.id);
        createDataBarFormatting.setThresholdMin(dataBarThreshold);
        DataBarThreshold dataBarThreshold2 = new DataBarThreshold();
        dataBarThreshold2.setType(ConditionalFormattingThreshold.RangeType.MAX.id);
        createDataBarFormatting.setThresholdMax(dataBarThreshold2);
        return cFRule12Record;
    }

    public static CFRule12Record create(HSSFSheet hSSFSheet, IconMultiStateFormatting.IconSet iconSet) {
        int i2 = iconSet.num;
        Threshold[] thresholdArr = new Threshold[i2];
        for (int i3 = 0; i3 < i2; i3++) {
            thresholdArr[i3] = new IconMultiStateThreshold();
        }
        CFRule12Record cFRule12Record = new CFRule12Record((byte) 6, (byte) 0);
        org.apache.poi.hssf.record.cf.IconMultiStateFormatting createMultiStateFormatting = cFRule12Record.createMultiStateFormatting();
        createMultiStateFormatting.setIconSet(iconSet);
        createMultiStateFormatting.setThresholds(thresholdArr);
        return cFRule12Record;
    }
}
