package org.apache.poi.hssf.record;

import b.b.a.a.a;
import java.util.Arrays;
import org.apache.poi.hssf.usermodel.HSSFSheet;
import org.apache.poi.ss.formula.Formula;
import org.apache.poi.ss.formula.ptg.Ptg;
import org.apache.poi.util.LittleEndianOutput;

public final class CFRuleRecord extends CFRuleBase implements Cloneable {
    public static final short sid = 433;

    public CFRuleRecord(byte b2, byte b3) {
        super(b2, b3);
        setDefaults();
    }

    public static CFRuleRecord create(HSSFSheet hSSFSheet, String str) {
        return new CFRuleRecord((byte) 2, (byte) 0, CFRuleBase.parseFormula(str, hSSFSheet), null);
    }

    private void setDefaults() {
        int value = CFRuleBase.modificationBits.setValue(this.formatting_options, -1);
        this.formatting_options = value;
        int value2 = CFRuleBase.fmtBlockBits.setValue(value, 0);
        this.formatting_options = value2;
        this.formatting_options = CFRuleBase.undocumented.clear(value2);
        this.formatting_not_used = -32766;
        this._fontFormatting = null;
        this._borderFormatting = null;
        this._patternFormatting = null;
    }

    @Override // org.apache.poi.hssf.record.StandardRecord
    public int getDataSize() {
        return CFRuleBase.getFormulaSize(getFormula2()) + CFRuleBase.getFormulaSize(getFormula1()) + getFormattingBlockSize() + 6;
    }

    @Override // org.apache.poi.hssf.record.Record
    public short getSid() {
        return sid;
    }

    @Override // org.apache.poi.hssf.record.StandardRecord
    public void serialize(LittleEndianOutput littleEndianOutput) {
        int formulaSize = CFRuleBase.getFormulaSize(getFormula1());
        int formulaSize2 = CFRuleBase.getFormulaSize(getFormula2());
        littleEndianOutput.writeByte(getConditionType());
        littleEndianOutput.writeByte(getComparisonOperation());
        littleEndianOutput.writeShort(formulaSize);
        littleEndianOutput.writeShort(formulaSize2);
        serializeFormattingBlock(littleEndianOutput);
        getFormula1().serializeTokens(littleEndianOutput);
        getFormula2().serializeTokens(littleEndianOutput);
    }

    @Override // org.apache.poi.hssf.record.Record
    public String toString() {
        StringBuffer c = a.c("[CFRULE]\n", "    .condition_type   =");
        c.append((int) getConditionType());
        c.append("\n");
        c.append("    OPTION FLAGS=0x");
        c.append(Integer.toHexString(getOptions()));
        c.append("\n");
        if (containsFontFormattingBlock()) {
            c.append(this._fontFormatting);
            c.append("\n");
        }
        if (containsBorderFormattingBlock()) {
            c.append(this._borderFormatting);
            c.append("\n");
        }
        if (containsPatternFormattingBlock()) {
            c.append(this._patternFormatting);
            c.append("\n");
        }
        c.append("    Formula 1 =");
        c.append(Arrays.toString(getFormula1().getTokens()));
        c.append("\n");
        c.append("    Formula 2 =");
        c.append(Arrays.toString(getFormula2().getTokens()));
        return a.a(c, "\n", "[/CFRULE]\n");
    }

    public CFRuleRecord(byte b2, byte b3, Ptg[] ptgArr, Ptg[] ptgArr2) {
        super(b2, b3, ptgArr, ptgArr2);
        setDefaults();
    }

    public static CFRuleRecord create(HSSFSheet hSSFSheet, byte b2, String str, String str2) {
        return new CFRuleRecord((byte) 1, b2, CFRuleBase.parseFormula(str, hSSFSheet), CFRuleBase.parseFormula(str2, hSSFSheet));
    }

    @Override // org.apache.poi.hssf.record.Record, org.apache.poi.hssf.record.CFRuleBase, org.apache.poi.hssf.record.CFRuleBase, java.lang.Object
    public CFRuleRecord clone() {
        CFRuleRecord cFRuleRecord = new CFRuleRecord(getConditionType(), getComparisonOperation());
        super.copyTo(cFRuleRecord);
        return cFRuleRecord;
    }

    public CFRuleRecord(RecordInputStream recordInputStream) {
        setConditionType(recordInputStream.readByte());
        setComparisonOperation(recordInputStream.readByte());
        int readUShort = recordInputStream.readUShort();
        int readUShort2 = recordInputStream.readUShort();
        readFormatOptions(recordInputStream);
        setFormula1(Formula.read(readUShort, recordInputStream));
        setFormula2(Formula.read(readUShort2, recordInputStream));
    }
}
