package org.apache.poi.hssf.record;

import b.b.a.a.a;
import org.apache.poi.util.BitField;
import org.apache.poi.util.BitFieldFactory;
import org.apache.poi.util.HexDump;
import org.apache.poi.util.LittleEndianOutput;

public final class ColumnInfoRecord extends StandardRecord implements Cloneable {
    public static final BitField collapsed = BitFieldFactory.getInstance(4096);
    public static final BitField hidden = BitFieldFactory.getInstance(1);
    public static final BitField outlevel = BitFieldFactory.getInstance(1792);
    public static final short sid = 125;
    public int _colWidth;
    public int _firstCol;
    public int _lastCol;
    public int _options;
    public int _xfIndex;
    public int field_6_reserved;

    public ColumnInfoRecord() {
        setColumnWidth(2275);
        this._options = 2;
        this._xfIndex = 15;
        this.field_6_reserved = 2;
    }

    public boolean containsColumn(int i2) {
        return this._firstCol <= i2 && i2 <= this._lastCol;
    }

    public boolean formatMatches(ColumnInfoRecord columnInfoRecord) {
        if (this._xfIndex == columnInfoRecord._xfIndex && this._options == columnInfoRecord._options && this._colWidth == columnInfoRecord._colWidth) {
            return true;
        }
        return false;
    }

    public boolean getCollapsed() {
        return collapsed.isSet(this._options);
    }

    public int getColumnWidth() {
        return this._colWidth;
    }

    @Override // org.apache.poi.hssf.record.StandardRecord
    public int getDataSize() {
        return 12;
    }

    public int getFirstColumn() {
        return this._firstCol;
    }

    public boolean getHidden() {
        return hidden.isSet(this._options);
    }

    public int getLastColumn() {
        return this._lastCol;
    }

    public int getOutlineLevel() {
        return outlevel.getValue(this._options);
    }

    @Override // org.apache.poi.hssf.record.Record
    public short getSid() {
        return 125;
    }

    public int getXFIndex() {
        return this._xfIndex;
    }

    public boolean isAdjacentBefore(ColumnInfoRecord columnInfoRecord) {
        return this._lastCol == columnInfoRecord._firstCol - 1;
    }

    @Override // org.apache.poi.hssf.record.StandardRecord
    public void serialize(LittleEndianOutput littleEndianOutput) {
        littleEndianOutput.writeShort(getFirstColumn());
        littleEndianOutput.writeShort(getLastColumn());
        littleEndianOutput.writeShort(getColumnWidth());
        littleEndianOutput.writeShort(getXFIndex());
        littleEndianOutput.writeShort(this._options);
        littleEndianOutput.writeShort(this.field_6_reserved);
    }

    public void setCollapsed(boolean z) {
        this._options = collapsed.setBoolean(this._options, z);
    }

    public void setColumnWidth(int i2) {
        this._colWidth = i2;
    }

    public void setFirstColumn(int i2) {
        this._firstCol = i2;
    }

    public void setHidden(boolean z) {
        this._options = hidden.setBoolean(this._options, z);
    }

    public void setLastColumn(int i2) {
        this._lastCol = i2;
    }

    public void setOutlineLevel(int i2) {
        this._options = outlevel.setValue(this._options, i2);
    }

    public void setXFIndex(int i2) {
        this._xfIndex = i2;
    }

    @Override // org.apache.poi.hssf.record.Record
    public String toString() {
        StringBuilder d2 = a.d("[COLINFO]\n", "  colfirst = ");
        d2.append(getFirstColumn());
        d2.append("\n");
        d2.append("  collast  = ");
        d2.append(getLastColumn());
        d2.append("\n");
        d2.append("  colwidth = ");
        d2.append(getColumnWidth());
        d2.append("\n");
        d2.append("  xfindex  = ");
        d2.append(getXFIndex());
        d2.append("\n");
        d2.append("  options  = ");
        d2.append(HexDump.shortToHex(this._options));
        d2.append("\n");
        d2.append("    hidden   = ");
        d2.append(getHidden());
        d2.append("\n");
        d2.append("    olevel   = ");
        d2.append(getOutlineLevel());
        d2.append("\n");
        d2.append("    collapsed= ");
        d2.append(getCollapsed());
        return a.a(d2, "\n", "[/COLINFO]\n");
    }

    @Override // org.apache.poi.hssf.record.Record, java.lang.Object
    public ColumnInfoRecord clone() {
        ColumnInfoRecord columnInfoRecord = new ColumnInfoRecord();
        columnInfoRecord._firstCol = this._firstCol;
        columnInfoRecord._lastCol = this._lastCol;
        columnInfoRecord._colWidth = this._colWidth;
        columnInfoRecord._xfIndex = this._xfIndex;
        columnInfoRecord._options = this._options;
        columnInfoRecord.field_6_reserved = this.field_6_reserved;
        return columnInfoRecord;
    }

    public ColumnInfoRecord(RecordInputStream recordInputStream) {
        this._firstCol = recordInputStream.readUShort();
        this._lastCol = recordInputStream.readUShort();
        this._colWidth = recordInputStream.readUShort();
        this._xfIndex = recordInputStream.readUShort();
        this._options = recordInputStream.readUShort();
        int remaining = recordInputStream.remaining();
        if (remaining == 0) {
            this.field_6_reserved = 0;
        } else if (remaining == 1) {
            this.field_6_reserved = recordInputStream.readByte();
        } else if (remaining == 2) {
            this.field_6_reserved = recordInputStream.readUShort();
        } else {
            StringBuilder b2 = a.b("Unusual record size remaining=(");
            b2.append(recordInputStream.remaining());
            b2.append(")");
            throw new RuntimeException(b2.toString());
        }
    }
}
