package org.apache.poi.hssf.record;

import b.b.a.a.a;
import org.apache.poi.util.BitField;
import org.apache.poi.util.BitFieldFactory;
import org.apache.poi.util.HexDump;
import org.apache.poi.util.LittleEndianInput;
import org.apache.poi.util.LittleEndianOutput;
import org.apache.poi.util.RecordFormatException;

public final class CommonObjectDataSubRecord extends SubRecord implements Cloneable {
    public static final short OBJECT_TYPE_ARC = 4;
    public static final short OBJECT_TYPE_BUTTON = 7;
    public static final short OBJECT_TYPE_CHART = 5;
    public static final short OBJECT_TYPE_CHECKBOX = 11;
    public static final short OBJECT_TYPE_COMBO_BOX = 20;
    public static final short OBJECT_TYPE_COMMENT = 25;
    public static final short OBJECT_TYPE_DIALOG_BOX = 15;
    public static final short OBJECT_TYPE_EDIT_BOX = 13;
    public static final short OBJECT_TYPE_GROUP = 0;
    public static final short OBJECT_TYPE_GROUP_BOX = 19;
    public static final short OBJECT_TYPE_LABEL = 14;
    public static final short OBJECT_TYPE_LINE = 1;
    public static final short OBJECT_TYPE_LIST_BOX = 18;
    public static final short OBJECT_TYPE_MICROSOFT_OFFICE_DRAWING = 30;
    public static final short OBJECT_TYPE_OPTION_BUTTON = 12;
    public static final short OBJECT_TYPE_OVAL = 3;
    public static final short OBJECT_TYPE_PICTURE = 8;
    public static final short OBJECT_TYPE_POLYGON = 9;
    public static final short OBJECT_TYPE_RECTANGLE = 2;
    public static final short OBJECT_TYPE_RESERVED1 = 10;
    public static final short OBJECT_TYPE_RESERVED2 = 21;
    public static final short OBJECT_TYPE_RESERVED3 = 22;
    public static final short OBJECT_TYPE_RESERVED4 = 23;
    public static final short OBJECT_TYPE_RESERVED5 = 24;
    public static final short OBJECT_TYPE_RESERVED6 = 26;
    public static final short OBJECT_TYPE_RESERVED7 = 27;
    public static final short OBJECT_TYPE_RESERVED8 = 28;
    public static final short OBJECT_TYPE_RESERVED9 = 29;
    public static final short OBJECT_TYPE_SCROLL_BAR = 17;
    public static final short OBJECT_TYPE_SPINNER = 16;
    public static final short OBJECT_TYPE_TEXT = 6;
    public static final BitField autofill = BitFieldFactory.getInstance(8192);
    public static final BitField autoline = BitFieldFactory.getInstance(16384);
    public static final BitField locked = BitFieldFactory.getInstance(1);
    public static final BitField printable = BitFieldFactory.getInstance(16);
    public static final short sid = 21;
    public short field_1_objectType;
    public int field_2_objectId;
    public short field_3_option;
    public int field_4_reserved1;
    public int field_5_reserved2;
    public int field_6_reserved3;

    public CommonObjectDataSubRecord() {
    }

    @Override // org.apache.poi.hssf.record.SubRecord
    public int getDataSize() {
        return 18;
    }

    public int getObjectId() {
        return this.field_2_objectId;
    }

    public short getObjectType() {
        return this.field_1_objectType;
    }

    public short getOption() {
        return this.field_3_option;
    }

    public int getReserved1() {
        return this.field_4_reserved1;
    }

    public int getReserved2() {
        return this.field_5_reserved2;
    }

    public int getReserved3() {
        return this.field_6_reserved3;
    }

    public short getSid() {
        return 21;
    }

    public boolean isAutofill() {
        return autofill.isSet(this.field_3_option);
    }

    public boolean isAutoline() {
        return autoline.isSet(this.field_3_option);
    }

    public boolean isLocked() {
        return locked.isSet(this.field_3_option);
    }

    public boolean isPrintable() {
        return printable.isSet(this.field_3_option);
    }

    @Override // org.apache.poi.hssf.record.SubRecord
    public void serialize(LittleEndianOutput littleEndianOutput) {
        littleEndianOutput.writeShort(21);
        littleEndianOutput.writeShort(getDataSize());
        littleEndianOutput.writeShort(this.field_1_objectType);
        littleEndianOutput.writeShort(this.field_2_objectId);
        littleEndianOutput.writeShort(this.field_3_option);
        littleEndianOutput.writeInt(this.field_4_reserved1);
        littleEndianOutput.writeInt(this.field_5_reserved2);
        littleEndianOutput.writeInt(this.field_6_reserved3);
    }

    public void setAutofill(boolean z) {
        this.field_3_option = autofill.setShortBoolean(this.field_3_option, z);
    }

    public void setAutoline(boolean z) {
        this.field_3_option = autoline.setShortBoolean(this.field_3_option, z);
    }

    public void setLocked(boolean z) {
        this.field_3_option = locked.setShortBoolean(this.field_3_option, z);
    }

    public void setObjectId(int i2) {
        this.field_2_objectId = i2;
    }

    public void setObjectType(short s) {
        this.field_1_objectType = s;
    }

    public void setOption(short s) {
        this.field_3_option = s;
    }

    public void setPrintable(boolean z) {
        this.field_3_option = printable.setShortBoolean(this.field_3_option, z);
    }

    public void setReserved1(int i2) {
        this.field_4_reserved1 = i2;
    }

    public void setReserved2(int i2) {
        this.field_5_reserved2 = i2;
    }

    public void setReserved3(int i2) {
        this.field_6_reserved3 = i2;
    }

    public String toString() {
        StringBuffer c = a.c("[ftCmo]\n", "    .objectType           = ", "0x");
        c.append(HexDump.toHex(getObjectType()));
        c.append(" (");
        c.append((int) getObjectType());
        c.append(" )");
        c.append(System.getProperty("line.separator"));
        c.append("    .objectId             = ");
        c.append("0x");
        c.append(HexDump.toHex(getObjectId()));
        c.append(" (");
        c.append(getObjectId());
        c.append(" )");
        c.append(System.getProperty("line.separator"));
        c.append("    .option               = ");
        c.append("0x");
        c.append(HexDump.toHex(getOption()));
        c.append(" (");
        c.append((int) getOption());
        c.append(" )");
        c.append(System.getProperty("line.separator"));
        c.append("         .locked                   = ");
        c.append(isLocked());
        c.append('\n');
        c.append("         .printable                = ");
        c.append(isPrintable());
        c.append('\n');
        c.append("         .autofill                 = ");
        c.append(isAutofill());
        c.append('\n');
        c.append("         .autoline                 = ");
        c.append(isAutoline());
        c.append('\n');
        c.append("    .reserved1            = ");
        c.append("0x");
        c.append(HexDump.toHex(getReserved1()));
        c.append(" (");
        c.append(getReserved1());
        c.append(" )");
        c.append(System.getProperty("line.separator"));
        c.append("    .reserved2            = ");
        c.append("0x");
        c.append(HexDump.toHex(getReserved2()));
        c.append(" (");
        c.append(getReserved2());
        c.append(" )");
        c.append(System.getProperty("line.separator"));
        c.append("    .reserved3            = ");
        c.append("0x");
        c.append(HexDump.toHex(getReserved3()));
        c.append(" (");
        c.append(getReserved3());
        c.append(" )");
        c.append(System.getProperty("line.separator"));
        c.append("[/ftCmo]\n");
        return c.toString();
    }

    public CommonObjectDataSubRecord(LittleEndianInput littleEndianInput, int i2) {
        if (i2 == 18) {
            this.field_1_objectType = littleEndianInput.readShort();
            this.field_2_objectId = littleEndianInput.readUShort();
            this.field_3_option = littleEndianInput.readShort();
            this.field_4_reserved1 = littleEndianInput.readInt();
            this.field_5_reserved2 = littleEndianInput.readInt();
            this.field_6_reserved3 = littleEndianInput.readInt();
            return;
        }
        throw new RecordFormatException(a.b("Expected size 18 but got (", i2, ")"));
    }

    @Override // org.apache.poi.hssf.record.SubRecord, org.apache.poi.hssf.record.SubRecord, java.lang.Object
    public CommonObjectDataSubRecord clone() {
        CommonObjectDataSubRecord commonObjectDataSubRecord = new CommonObjectDataSubRecord();
        commonObjectDataSubRecord.field_1_objectType = this.field_1_objectType;
        commonObjectDataSubRecord.field_2_objectId = this.field_2_objectId;
        commonObjectDataSubRecord.field_3_option = this.field_3_option;
        commonObjectDataSubRecord.field_4_reserved1 = this.field_4_reserved1;
        commonObjectDataSubRecord.field_5_reserved2 = this.field_5_reserved2;
        commonObjectDataSubRecord.field_6_reserved3 = this.field_6_reserved3;
        return commonObjectDataSubRecord;
    }
}
