package org.apache.poi.hssf.record;

import b.b.a.a.a;
import org.apache.poi.util.HexDump;
import org.apache.poi.util.LittleEndianOutput;

public final class DBCellRecord extends StandardRecord implements Cloneable {
    public static final int BLOCK_SIZE = 32;
    public static final short sid = 215;
    public final int field_1_row_offset;
    public final short[] field_2_cell_offsets;

    public static final class Builder {
        public short[] _cellOffsets = new short[4];
        public int _nCellOffsets;

        public void addCellOffset(int i2) {
            short[] sArr = this._cellOffsets;
            int length = sArr.length;
            int i3 = this._nCellOffsets;
            if (length <= i3) {
                short[] sArr2 = new short[(i3 * 2)];
                System.arraycopy(sArr, 0, sArr2, 0, i3);
                this._cellOffsets = sArr2;
            }
            short[] sArr3 = this._cellOffsets;
            int i4 = this._nCellOffsets;
            sArr3[i4] = (short) i2;
            this._nCellOffsets = i4 + 1;
        }

        public DBCellRecord build(int i2) {
            int i3 = this._nCellOffsets;
            short[] sArr = new short[i3];
            System.arraycopy(this._cellOffsets, 0, sArr, 0, i3);
            return new DBCellRecord(i2, sArr);
        }
    }

    public DBCellRecord(int i2, short[] sArr) {
        this.field_1_row_offset = i2;
        this.field_2_cell_offsets = sArr;
    }

    @Override // org.apache.poi.hssf.record.Record, java.lang.Object
    public DBCellRecord clone() {
        return this;
    }

    @Override // org.apache.poi.hssf.record.StandardRecord
    public int getDataSize() {
        return (this.field_2_cell_offsets.length * 2) + 4;
    }

    @Override // org.apache.poi.hssf.record.Record
    public short getSid() {
        return 215;
    }

    @Override // org.apache.poi.hssf.record.StandardRecord
    public void serialize(LittleEndianOutput littleEndianOutput) {
        littleEndianOutput.writeInt(this.field_1_row_offset);
        int i2 = 0;
        while (true) {
            short[] sArr = this.field_2_cell_offsets;
            if (i2 < sArr.length) {
                littleEndianOutput.writeShort(sArr[i2]);
                i2++;
            } else {
                return;
            }
        }
    }

    @Override // org.apache.poi.hssf.record.Record
    public String toString() {
        StringBuffer c = a.c("[DBCELL]\n", "    .rowoffset = ");
        c.append(HexDump.intToHex(this.field_1_row_offset));
        c.append("\n");
        for (int i2 = 0; i2 < this.field_2_cell_offsets.length; i2++) {
            c.append("    .cell_");
            c.append(i2);
            c.append(" = ");
            c.append(HexDump.shortToHex(this.field_2_cell_offsets[i2]));
            c.append("\n");
        }
        c.append("[/DBCELL]\n");
        return c.toString();
    }

    public DBCellRecord(RecordInputStream recordInputStream) {
        this.field_1_row_offset = recordInputStream.readUShort();
        this.field_2_cell_offsets = new short[(recordInputStream.remaining() / 2)];
        int i2 = 0;
        while (true) {
            short[] sArr = this.field_2_cell_offsets;
            if (i2 < sArr.length) {
                sArr[i2] = recordInputStream.readShort();
                i2++;
            } else {
                return;
            }
        }
    }
}
