package org.apache.poi.hssf.record;

import b.b.a.a.a;
import java.util.Arrays;
import org.apache.poi.openxml4j.opc.internal.ZipHelper;
import org.apache.poi.util.LittleEndian;
import org.apache.poi.util.LittleEndianOutput;
import org.apache.poi.util.RecordFormatException;
import org.apache.poi.util.StringUtil;

public class DConRefRecord extends StandardRecord {
    public static final short sid = 81;
    public byte[] _unused;
    public int charCount;
    public int charType;
    public int firstCol;
    public int firstRow;
    public int lastCol;
    public int lastRow;
    public byte[] path;

    public DConRefRecord(byte[] bArr) {
        if (LittleEndian.getShort(bArr, 0) == 81) {
            this.firstRow = LittleEndian.getUShort(bArr, 4);
            this.lastRow = LittleEndian.getUShort(bArr, 6);
            this.firstCol = LittleEndian.getUByte(bArr, 8);
            this.lastCol = LittleEndian.getUByte(bArr, 9);
            int uShort = LittleEndian.getUShort(bArr, 10);
            this.charCount = uShort;
            if (uShort >= 2) {
                short uByte = LittleEndian.getUByte(bArr, 12);
                this.charType = uByte;
                int i2 = ((uByte & 1) + 1) * this.charCount;
                byte[] byteArray = LittleEndian.getByteArray(bArr, 13, i2);
                this.path = byteArray;
                int i3 = 13 + i2;
                if (byteArray[0] == 2) {
                    this._unused = LittleEndian.getByteArray(bArr, i3, this.charType + 1);
                    return;
                }
                return;
            }
            throw new RecordFormatException("Character count must be >= 2");
        }
        throw new RecordFormatException("incompatible sid.");
    }

    @Override // org.apache.poi.hssf.record.StandardRecord
    public int getDataSize() {
        byte[] bArr = this.path;
        int length = bArr.length + 9;
        return bArr[0] == 2 ? length + this._unused.length : length;
    }

    public int getFirstColumn() {
        return this.firstCol;
    }

    public int getFirstRow() {
        return this.firstRow;
    }

    public int getLastColumn() {
        return this.lastCol;
    }

    public int getLastRow() {
        return this.lastRow;
    }

    public byte[] getPath() {
        byte[] bArr = this.path;
        return Arrays.copyOf(bArr, bArr.length);
    }

    public String getReadablePath() {
        if (this.path == null) {
            return null;
        }
        int i2 = 1;
        while (true) {
            byte[] bArr = this.path;
            if (bArr[i2] >= 32 || i2 >= bArr.length) {
                byte[] bArr2 = this.path;
            } else {
                i2++;
            }
        }
        byte[] bArr22 = this.path;
        return new String(Arrays.copyOfRange(bArr22, i2, bArr22.length), StringUtil.UTF8).replaceAll("\u0003", ZipHelper.FORWARD_SLASH);
    }

    @Override // org.apache.poi.hssf.record.Record
    public short getSid() {
        return 81;
    }

    public boolean isExternalRef() {
        return this.path[0] == 1;
    }

    @Override // org.apache.poi.hssf.record.StandardRecord
    public void serialize(LittleEndianOutput littleEndianOutput) {
        littleEndianOutput.writeShort(this.firstRow);
        littleEndianOutput.writeShort(this.lastRow);
        littleEndianOutput.writeByte(this.firstCol);
        littleEndianOutput.writeByte(this.lastCol);
        littleEndianOutput.writeShort(this.charCount);
        littleEndianOutput.writeByte(this.charType);
        littleEndianOutput.write(this.path);
        if (this.path[0] == 2) {
            littleEndianOutput.write(this._unused);
        }
    }

    @Override // org.apache.poi.hssf.record.Record
    public String toString() {
        StringBuilder d2 = a.d("[DCONREF]\n", "    .ref\n", "        .firstrow   = ");
        d2.append(this.firstRow);
        d2.append("\n");
        d2.append("        .lastrow    = ");
        d2.append(this.lastRow);
        d2.append("\n");
        d2.append("        .firstcol   = ");
        d2.append(this.firstCol);
        d2.append("\n");
        d2.append("        .lastcol    = ");
        d2.append(this.lastCol);
        d2.append("\n");
        d2.append("    .cch            = ");
        d2.append(this.charCount);
        d2.append("\n");
        d2.append("    .stFile\n");
        d2.append("        .h          = ");
        d2.append(this.charType);
        d2.append("\n");
        d2.append("        .rgb        = ");
        d2.append(getReadablePath());
        return a.a(d2, "\n", "[/DCONREF]\n");
    }

    public DConRefRecord(RecordInputStream recordInputStream) {
        if (recordInputStream.getSid() == 81) {
            this.firstRow = recordInputStream.readUShort();
            this.lastRow = recordInputStream.readUShort();
            this.firstCol = recordInputStream.readUByte();
            this.lastCol = recordInputStream.readUByte();
            this.charCount = recordInputStream.readUShort();
            int readUByte = recordInputStream.readUByte() & 1;
            this.charType = readUByte;
            byte[] bArr = new byte[((readUByte + 1) * this.charCount)];
            this.path = bArr;
            recordInputStream.readFully(bArr);
            if (this.path[0] == 2) {
                this._unused = recordInputStream.readRemainder();
                return;
            }
            return;
        }
        StringBuilder b2 = a.b("Wrong sid: ");
        b2.append((int) recordInputStream.getSid());
        throw new RecordFormatException(b2.toString());
    }
}
