package org.apache.poi.hssf.record;

import b.b.a.a.a;
import org.apache.poi.util.LittleEndianOutput;

public final class DVALRecord extends StandardRecord implements Cloneable {
    public static final short sid = 434;
    public short field_1_options;
    public int field_2_horiz_pos;
    public int field_3_vert_pos;
    public int field_5_dv_no;
    public int field_cbo_id;

    public DVALRecord() {
        this.field_cbo_id = -1;
        this.field_5_dv_no = 0;
    }

    public int getDVRecNo() {
        return this.field_5_dv_no;
    }

    @Override // org.apache.poi.hssf.record.StandardRecord
    public int getDataSize() {
        return 18;
    }

    public int getHorizontalPos() {
        return this.field_2_horiz_pos;
    }

    public int getObjectID() {
        return this.field_cbo_id;
    }

    public short getOptions() {
        return this.field_1_options;
    }

    @Override // org.apache.poi.hssf.record.Record
    public short getSid() {
        return sid;
    }

    public int getVerticalPos() {
        return this.field_3_vert_pos;
    }

    @Override // org.apache.poi.hssf.record.StandardRecord
    public void serialize(LittleEndianOutput littleEndianOutput) {
        littleEndianOutput.writeShort(getOptions());
        littleEndianOutput.writeInt(getHorizontalPos());
        littleEndianOutput.writeInt(getVerticalPos());
        littleEndianOutput.writeInt(getObjectID());
        littleEndianOutput.writeInt(getDVRecNo());
    }

    public void setDVRecNo(int i2) {
        this.field_5_dv_no = i2;
    }

    public void setHorizontalPos(int i2) {
        this.field_2_horiz_pos = i2;
    }

    public void setObjectID(int i2) {
        this.field_cbo_id = i2;
    }

    public void setOptions(short s) {
        this.field_1_options = s;
    }

    public void setVerticalPos(int i2) {
        this.field_3_vert_pos = i2;
    }

    @Override // org.apache.poi.hssf.record.Record
    public String toString() {
        StringBuffer c = a.c("[DVAL]\n", "    .options      = ");
        c.append((int) getOptions());
        c.append('\n');
        c.append("    .horizPos     = ");
        c.append(getHorizontalPos());
        c.append('\n');
        c.append("    .vertPos      = ");
        c.append(getVerticalPos());
        c.append('\n');
        c.append("    .comboObjectID   = ");
        c.append(Integer.toHexString(getObjectID()));
        c.append("\n");
        c.append("    .DVRecordsNumber = ");
        c.append(Integer.toHexString(getDVRecNo()));
        c.append("\n");
        c.append("[/DVAL]\n");
        return c.toString();
    }

    @Override // org.apache.poi.hssf.record.Record, java.lang.Object
    public DVALRecord clone() {
        DVALRecord dVALRecord = new DVALRecord();
        dVALRecord.field_1_options = this.field_1_options;
        dVALRecord.field_2_horiz_pos = this.field_2_horiz_pos;
        dVALRecord.field_3_vert_pos = this.field_3_vert_pos;
        dVALRecord.field_cbo_id = this.field_cbo_id;
        dVALRecord.field_5_dv_no = this.field_5_dv_no;
        return dVALRecord;
    }

    public DVALRecord(RecordInputStream recordInputStream) {
        this.field_1_options = recordInputStream.readShort();
        this.field_2_horiz_pos = recordInputStream.readInt();
        this.field_3_vert_pos = recordInputStream.readInt();
        this.field_cbo_id = recordInputStream.readInt();
        this.field_5_dv_no = recordInputStream.readInt();
    }
}
