package org.apache.poi.hssf.record;

import b.b.a.a.a;
import org.apache.poi.hssf.record.common.UnicodeString;
import org.apache.poi.ss.formula.Formula;
import org.apache.poi.ss.formula.ptg.Ptg;
import org.apache.poi.ss.util.CellRangeAddress;
import org.apache.poi.ss.util.CellRangeAddressList;
import org.apache.poi.util.BitField;
import org.apache.poi.util.LittleEndianOutput;
import org.apache.poi.util.StringUtil;

public final class DVRecord extends StandardRecord implements Cloneable {
    public static final UnicodeString NULL_TEXT_STRING = new UnicodeString("\u0000");
    public static final BitField opt_condition_operator = new BitField(7340032);
    public static final BitField opt_data_type = new BitField(15);
    public static final BitField opt_empty_cell_allowed = new BitField(256);
    public static final BitField opt_error_style = new BitField(112);
    public static final BitField opt_show_error_on_invalid_value = new BitField(524288);
    public static final BitField opt_show_prompt_on_cell_selected = new BitField(262144);
    public static final BitField opt_string_list_formula = new BitField(128);
    public static final BitField opt_suppress_dropdown_arrow = new BitField(512);
    public static final short sid = 446;
    public UnicodeString _errorText;
    public UnicodeString _errorTitle;
    public Formula _formula1;
    public Formula _formula2;
    public short _not_used_1 = 16352;
    public short _not_used_2 = 0;
    public int _option_flags;
    public UnicodeString _promptText;
    public UnicodeString _promptTitle;
    public CellRangeAddressList _regions;

    public DVRecord(int i2, int i3, int i4, boolean z, boolean z2, boolean z3, boolean z4, String str, String str2, boolean z5, String str3, String str4, Ptg[] ptgArr, Ptg[] ptgArr2, CellRangeAddressList cellRangeAddressList) {
        if (str != null && str.length() > 32) {
            throw new IllegalStateException(a.b("Prompt-title cannot be longer than 32 characters, but had: ", str));
        } else if (str2 != null && str2.length() > 255) {
            throw new IllegalStateException(a.b("Prompt-text cannot be longer than 255 characters, but had: ", str2));
        } else if (str3 != null && str3.length() > 32) {
            throw new IllegalStateException(a.b("Error-title cannot be longer than 32 characters, but had: ", str3));
        } else if (str4 == null || str4.length() <= 255) {
            this._option_flags = opt_show_error_on_invalid_value.setBoolean(opt_show_prompt_on_cell_selected.setBoolean(opt_string_list_formula.setBoolean(opt_suppress_dropdown_arrow.setBoolean(opt_empty_cell_allowed.setBoolean(opt_error_style.setValue(opt_condition_operator.setValue(opt_data_type.setValue(0, i2), i3), i4), z), z2), z3), z4), z5);
            this._promptTitle = resolveTitleText(str);
            this._promptText = resolveTitleText(str2);
            this._errorTitle = resolveTitleText(str3);
            this._errorText = resolveTitleText(str4);
            this._formula1 = Formula.create(ptgArr);
            this._formula2 = Formula.create(ptgArr2);
            this._regions = cellRangeAddressList;
        } else {
            throw new IllegalStateException(a.b("Error-text cannot be longer than 255 characters, but had: ", str4));
        }
    }

    public static void appendFormula(StringBuffer stringBuffer, String str, Formula formula) {
        stringBuffer.append(str);
        if (formula == null) {
            stringBuffer.append("<empty>\n");
            return;
        }
        Ptg[] tokens = formula.getTokens();
        stringBuffer.append('\n');
        for (Ptg ptg : tokens) {
            stringBuffer.append('\t');
            stringBuffer.append(ptg);
            stringBuffer.append('\n');
        }
    }

    public static String formatTextTitle(UnicodeString unicodeString) {
        String string = unicodeString.getString();
        return (string.length() == 1 && string.charAt(0) == 0) ? "'\\0'" : string;
    }

    public static int getUnicodeStringSize(UnicodeString unicodeString) {
        String string = unicodeString.getString();
        return (string.length() * (StringUtil.hasMultibyte(string) ? 2 : 1)) + 3;
    }

    public static UnicodeString readUnicodeString(RecordInputStream recordInputStream) {
        return new UnicodeString(recordInputStream);
    }

    public static String resolveTitleString(UnicodeString unicodeString) {
        if (unicodeString == null || unicodeString.equals(NULL_TEXT_STRING)) {
            return null;
        }
        return unicodeString.getString();
    }

    public static UnicodeString resolveTitleText(String str) {
        if (str == null || str.length() < 1) {
            return NULL_TEXT_STRING;
        }
        return new UnicodeString(str);
    }

    public static void serializeUnicodeString(UnicodeString unicodeString, LittleEndianOutput littleEndianOutput) {
        StringUtil.writeUnicodeString(littleEndianOutput, unicodeString.getString());
    }

    public CellRangeAddressList getCellRangeAddress() {
        return this._regions;
    }

    public int getConditionOperator() {
        return opt_condition_operator.getValue(this._option_flags);
    }

    @Override // org.apache.poi.hssf.record.StandardRecord
    public int getDataSize() {
        return this._regions.getSize() + this._formula2.getEncodedTokenSize() + this._formula1.getEncodedTokenSize() + getUnicodeStringSize(this._errorText) + getUnicodeStringSize(this._promptText) + getUnicodeStringSize(this._errorTitle) + getUnicodeStringSize(this._promptTitle) + 12;
    }

    public int getDataType() {
        return opt_data_type.getValue(this._option_flags);
    }

    public boolean getEmptyCellAllowed() {
        return opt_empty_cell_allowed.isSet(this._option_flags);
    }

    public int getErrorStyle() {
        return opt_error_style.getValue(this._option_flags);
    }

    public String getErrorText() {
        return resolveTitleString(this._errorText);
    }

    public String getErrorTitle() {
        return resolveTitleString(this._errorTitle);
    }

    public Ptg[] getFormula1() {
        return Formula.getTokens(this._formula1);
    }

    public Ptg[] getFormula2() {
        return Formula.getTokens(this._formula2);
    }

    public boolean getListExplicitFormula() {
        return opt_string_list_formula.isSet(this._option_flags);
    }

    public String getPromptText() {
        return resolveTitleString(this._promptText);
    }

    public String getPromptTitle() {
        return resolveTitleString(this._promptTitle);
    }

    public boolean getShowErrorOnInvalidValue() {
        return opt_show_error_on_invalid_value.isSet(this._option_flags);
    }

    public boolean getShowPromptOnCellSelected() {
        return opt_show_prompt_on_cell_selected.isSet(this._option_flags);
    }

    @Override // org.apache.poi.hssf.record.Record
    public short getSid() {
        return 446;
    }

    public boolean getSuppressDropdownArrow() {
        return opt_suppress_dropdown_arrow.isSet(this._option_flags);
    }

    @Override // org.apache.poi.hssf.record.StandardRecord
    public void serialize(LittleEndianOutput littleEndianOutput) {
        littleEndianOutput.writeInt(this._option_flags);
        serializeUnicodeString(this._promptTitle, littleEndianOutput);
        serializeUnicodeString(this._errorTitle, littleEndianOutput);
        serializeUnicodeString(this._promptText, littleEndianOutput);
        serializeUnicodeString(this._errorText, littleEndianOutput);
        littleEndianOutput.writeShort(this._formula1.getEncodedTokenSize());
        littleEndianOutput.writeShort(this._not_used_1);
        this._formula1.serializeTokens(littleEndianOutput);
        littleEndianOutput.writeShort(this._formula2.getEncodedTokenSize());
        littleEndianOutput.writeShort(this._not_used_2);
        this._formula2.serializeTokens(littleEndianOutput);
        this._regions.serialize(littleEndianOutput);
    }

    @Override // org.apache.poi.hssf.record.Record
    public String toString() {
        StringBuffer c = a.c("[DV]\n", " options=");
        c.append(Integer.toHexString(this._option_flags));
        c.append(" title-prompt=");
        c.append(formatTextTitle(this._promptTitle));
        c.append(" title-error=");
        c.append(formatTextTitle(this._errorTitle));
        c.append(" text-prompt=");
        c.append(formatTextTitle(this._promptText));
        c.append(" text-error=");
        c.append(formatTextTitle(this._errorText));
        c.append("\n");
        appendFormula(c, "Formula 1:", this._formula1);
        appendFormula(c, "Formula 2:", this._formula2);
        c.append("Regions: ");
        int countRanges = this._regions.countRanges();
        for (int i2 = 0; i2 < countRanges; i2++) {
            if (i2 > 0) {
                c.append(", ");
            }
            CellRangeAddress cellRangeAddress = this._regions.getCellRangeAddress(i2);
            c.append('(');
            c.append(cellRangeAddress.getFirstRow());
            c.append(',');
            c.append(cellRangeAddress.getLastRow());
            c.append(',');
            c.append(cellRangeAddress.getFirstColumn());
            c.append(',');
            c.append(cellRangeAddress.getLastColumn());
            c.append(')');
        }
        return a.a(c, "\n", "[/DV]");
    }

    @Override // org.apache.poi.hssf.record.Record, java.lang.Object
    public DVRecord clone() {
        return (DVRecord) cloneViaReserialise();
    }

    public DVRecord(RecordInputStream recordInputStream) {
        this._option_flags = recordInputStream.readInt();
        this._promptTitle = readUnicodeString(recordInputStream);
        this._errorTitle = readUnicodeString(recordInputStream);
        this._promptText = readUnicodeString(recordInputStream);
        this._errorText = readUnicodeString(recordInputStream);
        int readUShort = recordInputStream.readUShort();
        this._not_used_1 = recordInputStream.readShort();
        this._formula1 = Formula.read(readUShort, recordInputStream);
        int readUShort2 = recordInputStream.readUShort();
        this._not_used_2 = recordInputStream.readShort();
        this._formula2 = Formula.read(readUShort2, recordInputStream);
        this._regions = new CellRangeAddressList(recordInputStream);
    }
}
