package org.apache.poi.hssf.record;

import java.util.List;
import org.apache.poi.ddf.EscherRecord;
import org.apache.poi.ddf.NullEscherSerializationListener;
import org.apache.poi.util.LittleEndian;

public final class DrawingGroupRecord extends AbstractEscherHolderRecord {
    public static final int MAX_DATA_SIZE = 8224;
    public static final int MAX_RECORD_SIZE = 8228;
    public static final short sid = 235;

    public DrawingGroupRecord() {
    }

    private int getRawDataSize() {
        List<EscherRecord> escherRecords = getEscherRecords();
        byte[] rawData = getRawData();
        if (escherRecords.size() == 0 && rawData != null) {
            return rawData.length;
        }
        int i2 = 0;
        for (EscherRecord escherRecord : escherRecords) {
            i2 += escherRecord.getRecordSize();
        }
        return i2;
    }

    public static int grossSizeFromDataSize(int i2) {
        return ((((i2 - 1) / 8224) + 1) * 4) + i2;
    }

    private void writeContinueHeader(byte[] bArr, int i2, int i3) {
        LittleEndian.putShort(bArr, i2 + 0, 60);
        LittleEndian.putShort(bArr, i2 + 2, (short) i3);
    }

    private int writeData(int i2, byte[] bArr, byte[] bArr2) {
        int i3 = 0;
        int i4 = 0;
        while (i3 < bArr2.length) {
            int min = Math.min(bArr2.length - i3, 8224);
            if (i3 / 8224 >= 2) {
                writeContinueHeader(bArr, i2, min);
            } else {
                writeHeader(bArr, i2, min);
            }
            int i5 = i2 + 4;
            System.arraycopy(bArr2, i3, bArr, i5, min);
            i2 = i5 + min;
            i3 += min;
            i4 = i4 + 4 + min;
        }
        return i4;
    }

    private void writeHeader(byte[] bArr, int i2, int i3) {
        LittleEndian.putShort(bArr, i2 + 0, getSid());
        LittleEndian.putShort(bArr, i2 + 2, (short) i3);
    }

    @Override // org.apache.poi.hssf.record.AbstractEscherHolderRecord
    public String getRecordName() {
        return "MSODRAWINGGROUP";
    }

    @Override // org.apache.poi.hssf.record.AbstractEscherHolderRecord, org.apache.poi.hssf.record.RecordBase
    public int getRecordSize() {
        return grossSizeFromDataSize(getRawDataSize());
    }

    @Override // org.apache.poi.hssf.record.Record, org.apache.poi.hssf.record.AbstractEscherHolderRecord
    public short getSid() {
        return sid;
    }

    public void processChildRecords() {
        convertRawBytesToEscherRecords();
    }

    @Override // org.apache.poi.hssf.record.AbstractEscherHolderRecord, org.apache.poi.hssf.record.RecordBase
    public int serialize(int i2, byte[] bArr) {
        byte[] rawData = getRawData();
        if (getEscherRecords().size() == 0 && rawData != null) {
            return writeData(i2, bArr, rawData);
        }
        byte[] bArr2 = new byte[getRawDataSize()];
        int i3 = 0;
        for (EscherRecord escherRecord : getEscherRecords()) {
            i3 += escherRecord.serialize(i3, bArr2, new NullEscherSerializationListener());
        }
        return writeData(i2, bArr, bArr2);
    }

    public DrawingGroupRecord(RecordInputStream recordInputStream) {
        super(recordInputStream);
    }
}
