package org.apache.poi.hssf.record;

import b.b.a.a.a;
import org.apache.poi.util.HexDump;
import org.apache.poi.util.LittleEndianInput;
import org.apache.poi.util.LittleEndianOutput;

public final class DrawingSelectionRecord extends StandardRecord implements Cloneable {
    public static final short sid = 237;
    public int _cpsp;
    public int _dgslk;
    public OfficeArtRecordHeader _header;
    public int[] _shapeIds;
    public int _spidFocus;

    public static final class OfficeArtRecordHeader {
        public static final int ENCODED_SIZE = 8;
        public final int _length;
        public final int _type;
        public final int _verAndInstance;

        public OfficeArtRecordHeader(LittleEndianInput littleEndianInput) {
            this._verAndInstance = littleEndianInput.readUShort();
            this._type = littleEndianInput.readUShort();
            this._length = littleEndianInput.readInt();
        }

        public String debugFormatAsString() {
            StringBuffer stringBuffer = new StringBuffer(32);
            stringBuffer.append("ver+inst=");
            stringBuffer.append(HexDump.shortToHex(this._verAndInstance));
            stringBuffer.append(" type=");
            stringBuffer.append(HexDump.shortToHex(this._type));
            stringBuffer.append(" len=");
            stringBuffer.append(HexDump.intToHex(this._length));
            return stringBuffer.toString();
        }

        public void serialize(LittleEndianOutput littleEndianOutput) {
            littleEndianOutput.writeShort(this._verAndInstance);
            littleEndianOutput.writeShort(this._type);
            littleEndianOutput.writeInt(this._length);
        }
    }

    public DrawingSelectionRecord(RecordInputStream recordInputStream) {
        this._header = new OfficeArtRecordHeader(recordInputStream);
        this._cpsp = recordInputStream.readInt();
        this._dgslk = recordInputStream.readInt();
        this._spidFocus = recordInputStream.readInt();
        int available = recordInputStream.available() / 4;
        int[] iArr = new int[available];
        for (int i2 = 0; i2 < available; i2++) {
            iArr[i2] = recordInputStream.readInt();
        }
        this._shapeIds = iArr;
    }

    @Override // org.apache.poi.hssf.record.Record, java.lang.Object
    public DrawingSelectionRecord clone() {
        return this;
    }

    @Override // org.apache.poi.hssf.record.StandardRecord
    public int getDataSize() {
        return (this._shapeIds.length * 4) + 20;
    }

    @Override // org.apache.poi.hssf.record.Record
    public short getSid() {
        return sid;
    }

    @Override // org.apache.poi.hssf.record.StandardRecord
    public void serialize(LittleEndianOutput littleEndianOutput) {
        this._header.serialize(littleEndianOutput);
        littleEndianOutput.writeInt(this._cpsp);
        littleEndianOutput.writeInt(this._dgslk);
        littleEndianOutput.writeInt(this._spidFocus);
        int i2 = 0;
        while (true) {
            int[] iArr = this._shapeIds;
            if (i2 < iArr.length) {
                littleEndianOutput.writeInt(iArr[i2]);
                i2++;
            } else {
                return;
            }
        }
    }

    @Override // org.apache.poi.hssf.record.Record
    public String toString() {
        StringBuffer c = a.c("[MSODRAWINGSELECTION]\n", "    .rh       =(");
        c.append(this._header.debugFormatAsString());
        c.append(")\n");
        c.append("    .cpsp     =");
        c.append(HexDump.intToHex(this._cpsp));
        c.append('\n');
        c.append("    .dgslk    =");
        c.append(HexDump.intToHex(this._dgslk));
        c.append('\n');
        c.append("    .spidFocus=");
        c.append(HexDump.intToHex(this._spidFocus));
        c.append('\n');
        c.append("    .shapeIds =(");
        for (int i2 = 0; i2 < this._shapeIds.length; i2++) {
            if (i2 > 0) {
                c.append(", ");
            }
            c.append(HexDump.intToHex(this._shapeIds[i2]));
        }
        return a.a(c, ")\n", "[/MSODRAWINGSELECTION]\n");
    }
}
