package org.apache.poi.hssf.record;

import b.b.a.a.a;
import java.io.ByteArrayInputStream;
import org.apache.poi.ss.formula.ptg.Area3DPtg;
import org.apache.poi.ss.formula.ptg.AreaPtg;
import org.apache.poi.ss.formula.ptg.Ptg;
import org.apache.poi.ss.formula.ptg.Ref3DPtg;
import org.apache.poi.ss.formula.ptg.RefPtg;
import org.apache.poi.util.HexDump;
import org.apache.poi.util.LittleEndianInput;
import org.apache.poi.util.LittleEndianInputStream;
import org.apache.poi.util.LittleEndianOutput;
import org.apache.poi.util.POILogFactory;
import org.apache.poi.util.POILogger;
import org.apache.poi.util.RecordFormatException;
import org.apache.poi.util.StringUtil;

public final class EmbeddedObjectRefSubRecord extends SubRecord implements Cloneable {
    public static final byte[] EMPTY_BYTE_ARRAY = new byte[0];
    public static POILogger logger = POILogFactory.getLogger(EmbeddedObjectRefSubRecord.class);
    public static final short sid = 9;
    public int field_1_unknown_int;
    public Ptg field_2_refPtg;
    public byte[] field_2_unknownFormulaData;
    public boolean field_3_unicode_flag;
    public String field_4_ole_classname;
    public Byte field_4_unknownByte;
    public Integer field_5_stream_id;
    public byte[] field_6_unknown;

    public EmbeddedObjectRefSubRecord() {
        this.field_2_unknownFormulaData = new byte[]{2, 108, 106, 22, 1};
        this.field_6_unknown = EMPTY_BYTE_ARRAY;
        this.field_4_ole_classname = null;
    }

    private int getDataSize(int i2) {
        int i3 = i2 + 2;
        if (this.field_5_stream_id != null) {
            i3 += 4;
        }
        return i3 + this.field_6_unknown.length;
    }

    private int getStreamIDOffset(int i2) {
        int i3 = i2 + 6;
        String str = this.field_4_ole_classname;
        if (str != null) {
            i3 += 3;
            int length = str.length();
            if (length > 0) {
                int i4 = i3 + 1;
                i3 = this.field_3_unicode_flag ? i4 + (length * 2) : i4 + length;
            }
        }
        return i3 % 2 != 0 ? i3 + 1 : i3;
    }

    public static byte[] readRawData(LittleEndianInput littleEndianInput, int i2) {
        if (i2 < 0) {
            throw new IllegalArgumentException(a.b("Negative size (", i2, ")"));
        } else if (i2 == 0) {
            return EMPTY_BYTE_ARRAY;
        } else {
            byte[] bArr = new byte[i2];
            littleEndianInput.readFully(bArr);
            return bArr;
        }
    }

    public static Ptg readRefPtg(byte[] bArr) {
        LittleEndianInputStream littleEndianInputStream = new LittleEndianInputStream(new ByteArrayInputStream(bArr));
        byte readByte = littleEndianInputStream.readByte();
        if (readByte == 36) {
            return new RefPtg(littleEndianInputStream);
        }
        if (readByte == 37) {
            return new AreaPtg(littleEndianInputStream);
        }
        if (readByte == 58) {
            return new Ref3DPtg(littleEndianInputStream);
        }
        if (readByte != 59) {
            return null;
        }
        return new Area3DPtg(littleEndianInputStream);
    }

    @Override // org.apache.poi.hssf.record.SubRecord, org.apache.poi.hssf.record.SubRecord, java.lang.Object
    public EmbeddedObjectRefSubRecord clone() {
        return this;
    }

    public String getOLEClassName() {
        return this.field_4_ole_classname;
    }

    public byte[] getObjectData() {
        return this.field_6_unknown;
    }

    public short getSid() {
        return 9;
    }

    public Integer getStreamId() {
        return this.field_5_stream_id;
    }

    @Override // org.apache.poi.hssf.record.SubRecord
    public void serialize(LittleEndianOutput littleEndianOutput) {
        Ptg ptg = this.field_2_refPtg;
        int length = ptg == null ? this.field_2_unknownFormulaData.length : ptg.getSize();
        int streamIDOffset = getStreamIDOffset(length);
        int dataSize = getDataSize(streamIDOffset);
        littleEndianOutput.writeShort(9);
        littleEndianOutput.writeShort(dataSize);
        littleEndianOutput.writeShort(streamIDOffset);
        littleEndianOutput.writeShort(length);
        littleEndianOutput.writeInt(this.field_1_unknown_int);
        Ptg ptg2 = this.field_2_refPtg;
        if (ptg2 == null) {
            littleEndianOutput.write(this.field_2_unknownFormulaData);
        } else {
            ptg2.write(littleEndianOutput);
        }
        int i2 = length + 12;
        if (this.field_4_ole_classname != null) {
            littleEndianOutput.writeByte(3);
            int length2 = this.field_4_ole_classname.length();
            littleEndianOutput.writeShort(length2);
            i2 = i2 + 1 + 2;
            if (length2 > 0) {
                littleEndianOutput.writeByte(this.field_3_unicode_flag ? 1 : 0);
                int i3 = i2 + 1;
                if (this.field_3_unicode_flag) {
                    StringUtil.putUnicodeLE(this.field_4_ole_classname, littleEndianOutput);
                    i2 = i3 + (length2 * 2);
                } else {
                    StringUtil.putCompressedUnicode(this.field_4_ole_classname, littleEndianOutput);
                    i2 = i3 + length2;
                }
            }
        }
        int i4 = streamIDOffset - (i2 - 6);
        if (i4 != 0) {
            if (i4 == 1) {
                Byte b2 = this.field_4_unknownByte;
                littleEndianOutput.writeByte(b2 == null ? 0 : b2.intValue());
            } else {
                throw new IllegalStateException(a.b("Bad padding calculation (", streamIDOffset, ", ", i2, ")"));
            }
        }
        Integer num = this.field_5_stream_id;
        if (num != null) {
            littleEndianOutput.writeInt(num.intValue());
        }
        littleEndianOutput.write(this.field_6_unknown);
    }

    public void setOleClassname(String str) {
        this.field_4_ole_classname = str;
    }

    public void setStorageId(int i2) {
        this.field_5_stream_id = Integer.valueOf(i2);
    }

    public void setUnknownFormulaData(byte[] bArr) {
        this.field_2_unknownFormulaData = bArr;
    }

    public String toString() {
        StringBuffer c = a.c("[ftPictFmla]\n", "    .f2unknown     = ");
        c.append(HexDump.intToHex(this.field_1_unknown_int));
        c.append("\n");
        if (this.field_2_refPtg == null) {
            c.append("    .f3unknown     = ");
            c.append(HexDump.toHex(this.field_2_unknownFormulaData));
            c.append("\n");
        } else {
            c.append("    .formula       = ");
            c.append(this.field_2_refPtg);
            c.append("\n");
        }
        if (this.field_4_ole_classname != null) {
            c.append("    .unicodeFlag   = ");
            c.append(this.field_3_unicode_flag);
            c.append("\n");
            c.append("    .oleClassname  = ");
            c.append(this.field_4_ole_classname);
            c.append("\n");
        }
        if (this.field_4_unknownByte != null) {
            c.append("    .f4unknown   = ");
            c.append(HexDump.byteToHex(this.field_4_unknownByte.intValue()));
            c.append("\n");
        }
        if (this.field_5_stream_id != null) {
            c.append("    .streamId      = ");
            c.append(HexDump.intToHex(this.field_5_stream_id.intValue()));
            c.append("\n");
        }
        if (this.field_6_unknown.length > 0) {
            c.append("    .f7unknown     = ");
            c.append(HexDump.toHex(this.field_6_unknown));
            c.append("\n");
        }
        c.append("[/ftPictFmla]");
        return c.toString();
    }

    @Override // org.apache.poi.hssf.record.SubRecord
    public int getDataSize() {
        Ptg ptg = this.field_2_refPtg;
        return getDataSize(getStreamIDOffset(ptg == null ? this.field_2_unknownFormulaData.length : ptg.getSize()));
    }

    public EmbeddedObjectRefSubRecord(LittleEndianInput littleEndianInput, int i2) {
        int i3;
        int i4 = i2 - 2;
        int readShort = i4 - littleEndianInput.readShort();
        int readUShort = littleEndianInput.readUShort();
        this.field_1_unknown_int = littleEndianInput.readInt();
        byte[] readRawData = readRawData(littleEndianInput, readUShort);
        int i5 = ((i4 - 2) - 4) - readUShort;
        Ptg readRefPtg = readRefPtg(readRawData);
        this.field_2_refPtg = readRefPtg;
        if (readRefPtg == null) {
            this.field_2_unknownFormulaData = readRawData;
        } else {
            this.field_2_unknownFormulaData = null;
        }
        if (i5 >= readShort + 3) {
            i3 = 3;
            if (littleEndianInput.readByte() == 3) {
                int readUShort2 = littleEndianInput.readUShort();
                if (readUShort2 > 0) {
                    boolean z = (littleEndianInput.readByte() & 1) != 0;
                    this.field_3_unicode_flag = z;
                    if (z) {
                        this.field_4_ole_classname = StringUtil.readUnicodeLE(littleEndianInput, readUShort2);
                        i3 = (readUShort2 * 2) + 4;
                    } else {
                        this.field_4_ole_classname = StringUtil.readCompressedUnicode(littleEndianInput, readUShort2);
                        i3 = readUShort2 + 4;
                    }
                } else {
                    this.field_4_ole_classname = "";
                }
            } else {
                throw new RecordFormatException("Expected byte 0x03 here");
            }
        } else {
            this.field_4_ole_classname = null;
            i3 = 0;
        }
        int i6 = i5 - i3;
        if ((i3 + readUShort) % 2 != 0) {
            byte readByte = littleEndianInput.readByte();
            i6--;
            if (this.field_2_refPtg != null && this.field_4_ole_classname == null) {
                this.field_4_unknownByte = Byte.valueOf((byte) readByte);
            }
        }
        int i7 = i6 - readShort;
        if (i7 > 0) {
            logger.log(7, a.b("Discarding ", i7, " unexpected padding bytes "));
            readRawData(littleEndianInput, i7);
            i6 -= i7;
        }
        if (readShort >= 4) {
            this.field_5_stream_id = Integer.valueOf(littleEndianInput.readInt());
            i6 -= 4;
        } else {
            this.field_5_stream_id = null;
        }
        this.field_6_unknown = readRawData(littleEndianInput, i6);
    }
}
