package org.apache.poi.hssf.record;

import b.b.a.a.a;
import java.util.ArrayList;
import org.apache.poi.hssf.record.cont.ContinuableRecord;
import org.apache.poi.hssf.record.cont.ContinuableRecordOutput;
import org.apache.poi.util.LittleEndianOutput;

public final class ExtSSTRecord extends ContinuableRecord {
    public static final int DEFAULT_BUCKET_SIZE = 8;
    public static final int MAX_BUCKETS = 128;
    public static final short sid = 255;
    public InfoSubRecord[] _sstInfos;
    public short _stringsPerBucket;

    public ExtSSTRecord() {
        this._stringsPerBucket = 8;
        this._sstInfos = new InfoSubRecord[0];
    }

    public static final int getNumberOfInfoRecsForStrings(int i2) {
        int i3 = i2 / 8;
        if (i2 % 8 != 0) {
            i3++;
        }
        if (i3 > 128) {
            return 128;
        }
        return i3;
    }

    public static final int getRecordSizeForStrings(int i2) {
        return (getNumberOfInfoRecsForStrings(i2) * 8) + 6;
    }

    public int getDataSize() {
        return (this._sstInfos.length * 8) + 2;
    }

    public InfoSubRecord[] getInfoSubRecords() {
        return this._sstInfos;
    }

    @Override // org.apache.poi.hssf.record.Record
    public short getSid() {
        return 255;
    }

    @Override // org.apache.poi.hssf.record.cont.ContinuableRecord
    public void serialize(ContinuableRecordOutput continuableRecordOutput) {
        continuableRecordOutput.writeShort(this._stringsPerBucket);
        int i2 = 0;
        while (true) {
            InfoSubRecord[] infoSubRecordArr = this._sstInfos;
            if (i2 < infoSubRecordArr.length) {
                infoSubRecordArr[i2].serialize(continuableRecordOutput);
                i2++;
            } else {
                return;
            }
        }
    }

    public void setBucketOffsets(int[] iArr, int[] iArr2) {
        this._sstInfos = new InfoSubRecord[iArr.length];
        for (int i2 = 0; i2 < iArr.length; i2++) {
            this._sstInfos[i2] = new InfoSubRecord(iArr[i2], iArr2[i2]);
        }
    }

    public void setNumStringsPerBucket(short s) {
        this._stringsPerBucket = s;
    }

    @Override // org.apache.poi.hssf.record.Record
    public String toString() {
        StringBuffer c = a.c("[EXTSST]\n", "    .dsst           = ");
        c.append(Integer.toHexString(this._stringsPerBucket));
        c.append("\n");
        c.append("    .numInfoRecords = ");
        c.append(this._sstInfos.length);
        c.append("\n");
        for (int i2 = 0; i2 < this._sstInfos.length; i2++) {
            c.append("    .inforecord     = ");
            c.append(i2);
            c.append("\n");
            c.append("    .streampos      = ");
            c.append(Integer.toHexString(this._sstInfos[i2].getStreamPos()));
            c.append("\n");
            c.append("    .sstoffset      = ");
            c.append(Integer.toHexString(this._sstInfos[i2].getBucketSSTOffset()));
            c.append("\n");
        }
        c.append("[/EXTSST]\n");
        return c.toString();
    }

    public static final class InfoSubRecord {
        public static final int ENCODED_SIZE = 8;
        public int field_1_stream_pos;
        public int field_2_bucket_sst_offset;
        public short field_3_zero;

        public InfoSubRecord(int i2, int i3) {
            this.field_1_stream_pos = i2;
            this.field_2_bucket_sst_offset = i3;
        }

        public int getBucketSSTOffset() {
            return this.field_2_bucket_sst_offset;
        }

        public int getStreamPos() {
            return this.field_1_stream_pos;
        }

        public void serialize(LittleEndianOutput littleEndianOutput) {
            littleEndianOutput.writeInt(this.field_1_stream_pos);
            littleEndianOutput.writeShort(this.field_2_bucket_sst_offset);
            littleEndianOutput.writeShort(this.field_3_zero);
        }

        public InfoSubRecord(RecordInputStream recordInputStream) {
            this.field_1_stream_pos = recordInputStream.readInt();
            this.field_2_bucket_sst_offset = recordInputStream.readShort();
            this.field_3_zero = recordInputStream.readShort();
        }
    }

    public ExtSSTRecord(RecordInputStream recordInputStream) {
        this._stringsPerBucket = recordInputStream.readShort();
        ArrayList arrayList = new ArrayList(recordInputStream.remaining() / 8);
        while (recordInputStream.available() > 0) {
            arrayList.add(new InfoSubRecord(recordInputStream));
            if (recordInputStream.available() == 0 && recordInputStream.hasNextRecord() && recordInputStream.getNextSid() == 60) {
                recordInputStream.nextRecord();
            }
        }
        this._sstInfos = (InfoSubRecord[]) arrayList.toArray(new InfoSubRecord[arrayList.size()]);
    }
}
