package org.apache.poi.hssf.record;

import b.b.a.a.a;
import org.apache.poi.ss.formula.Formula;
import org.apache.poi.ss.formula.constant.ConstantValueParser;
import org.apache.poi.ss.formula.ptg.Ptg;
import org.apache.poi.util.LittleEndianOutput;
import org.apache.poi.util.StringUtil;

public final class ExternalNameRecord extends StandardRecord {
    public static final int OPT_AUTOMATIC_LINK = 2;
    public static final int OPT_BUILTIN_NAME = 1;
    public static final int OPT_ICONIFIED_PICTURE_LINK = 32768;
    public static final int OPT_OLE_LINK = 16;
    public static final int OPT_PICTURE_LINK = 4;
    public static final int OPT_STD_DOCUMENT_NAME = 8;
    public static final short sid = 35;
    public Object[] _ddeValues;
    public int _nColumns;
    public int _nRows;
    public short field_1_option_flag;
    public short field_2_ixals;
    public short field_3_not_used;
    public String field_4_name;
    public Formula field_5_name_definition;

    public ExternalNameRecord() {
        this.field_2_ixals = 0;
    }

    @Override // org.apache.poi.hssf.record.StandardRecord
    public int getDataSize() {
        int i2;
        int encodedSize = (StringUtil.getEncodedSize(this.field_4_name) - 1) + 6;
        if (isOLELink() || isStdDocumentNameIdentifier()) {
            return encodedSize;
        }
        if (isAutomaticLink()) {
            Object[] objArr = this._ddeValues;
            if (objArr == null) {
                return encodedSize;
            }
            encodedSize += 3;
            i2 = ConstantValueParser.getEncodedSize(objArr);
        } else {
            i2 = this.field_5_name_definition.getEncodedSize();
        }
        return encodedSize + i2;
    }

    public short getIx() {
        return this.field_2_ixals;
    }

    public Ptg[] getParsedExpression() {
        return Formula.getTokens(this.field_5_name_definition);
    }

    @Override // org.apache.poi.hssf.record.Record
    public short getSid() {
        return 35;
    }

    public String getText() {
        return this.field_4_name;
    }

    public boolean isAutomaticLink() {
        return (this.field_1_option_flag & 2) != 0;
    }

    public boolean isBuiltInName() {
        return (this.field_1_option_flag & 1) != 0;
    }

    public boolean isIconifiedPictureLink() {
        return (this.field_1_option_flag & 32768) != 0;
    }

    public boolean isOLELink() {
        return (this.field_1_option_flag & 16) != 0;
    }

    public boolean isPicureLink() {
        return (this.field_1_option_flag & 4) != 0;
    }

    public boolean isStdDocumentNameIdentifier() {
        return (this.field_1_option_flag & 8) != 0;
    }

    @Override // org.apache.poi.hssf.record.StandardRecord
    public void serialize(LittleEndianOutput littleEndianOutput) {
        littleEndianOutput.writeShort(this.field_1_option_flag);
        littleEndianOutput.writeShort(this.field_2_ixals);
        littleEndianOutput.writeShort(this.field_3_not_used);
        littleEndianOutput.writeByte(this.field_4_name.length());
        StringUtil.writeUnicodeStringFlagAndData(littleEndianOutput, this.field_4_name);
        if (!isOLELink() && !isStdDocumentNameIdentifier()) {
            if (!isAutomaticLink()) {
                this.field_5_name_definition.serialize(littleEndianOutput);
            } else if (this._ddeValues != null) {
                littleEndianOutput.writeByte(this._nColumns - 1);
                littleEndianOutput.writeShort(this._nRows - 1);
                ConstantValueParser.encode(littleEndianOutput, this._ddeValues);
            }
        }
    }

    public void setIx(short s) {
        this.field_2_ixals = s;
    }

    public void setParsedExpression(Ptg[] ptgArr) {
        this.field_5_name_definition = Formula.create(ptgArr);
    }

    public void setText(String str) {
        this.field_4_name = str;
    }

    @Override // org.apache.poi.hssf.record.Record
    public String toString() {
        StringBuilder d2 = a.d("[EXTERNALNAME]\n", "    .options = ");
        d2.append((int) this.field_1_option_flag);
        d2.append("\n");
        d2.append("    .ix      = ");
        d2.append((int) this.field_2_ixals);
        d2.append("\n");
        d2.append("    .name    = ");
        d2.append(this.field_4_name);
        d2.append("\n");
        Formula formula = this.field_5_name_definition;
        if (formula != null) {
            Ptg[] tokens = formula.getTokens();
            for (Ptg ptg : tokens) {
                d2.append("    .namedef = ");
                d2.append(ptg);
                d2.append(ptg.getRVAType());
                d2.append("\n");
            }
        }
        d2.append("[/EXTERNALNAME]\n");
        return d2.toString();
    }

    public ExternalNameRecord(RecordInputStream recordInputStream) {
        this.field_1_option_flag = recordInputStream.readShort();
        this.field_2_ixals = recordInputStream.readShort();
        this.field_3_not_used = recordInputStream.readShort();
        this.field_4_name = StringUtil.readUnicodeString(recordInputStream, recordInputStream.readUByte());
        if (!isOLELink() && !isStdDocumentNameIdentifier()) {
            if (!isAutomaticLink()) {
                this.field_5_name_definition = Formula.read(recordInputStream.readUShort(), recordInputStream);
            } else if (recordInputStream.available() > 0) {
                int readUByte = recordInputStream.readUByte() + 1;
                int readShort = recordInputStream.readShort() + 1;
                this._ddeValues = ConstantValueParser.parse(recordInputStream, readShort * readUByte);
                this._nColumns = readUByte;
                this._nRows = readShort;
            }
        }
    }
}
