package org.apache.poi.hssf.record;

import b.b.a.a.a;
import org.apache.poi.hssf.record.common.FeatFormulaErr2;
import org.apache.poi.hssf.record.common.FeatProtection;
import org.apache.poi.hssf.record.common.FeatSmartTag;
import org.apache.poi.hssf.record.common.FtrHeader;
import org.apache.poi.hssf.record.common.SharedFeature;
import org.apache.poi.ss.util.CellRangeAddress;
import org.apache.poi.util.LittleEndianOutput;
import org.apache.poi.util.POILogFactory;
import org.apache.poi.util.POILogger;

public final class FeatRecord extends StandardRecord implements Cloneable {
    public static POILogger logger = POILogFactory.getLogger(FeatRecord.class);
    public static final short sid = 2152;
    public static final short v11_sid = 2162;
    public static final short v12_sid = 2168;
    public long cbFeatData;
    public CellRangeAddress[] cellRefs;
    public FtrHeader futureHeader;
    public int isf_sharedFeatureType;
    public byte reserved1;
    public long reserved2;
    public int reserved3;
    public SharedFeature sharedFeature;

    public FeatRecord() {
        FtrHeader ftrHeader = new FtrHeader();
        this.futureHeader = ftrHeader;
        ftrHeader.setRecordType(sid);
    }

    public long getCbFeatData() {
        return this.cbFeatData;
    }

    public CellRangeAddress[] getCellRefs() {
        return this.cellRefs;
    }

    @Override // org.apache.poi.hssf.record.StandardRecord
    public int getDataSize() {
        return this.sharedFeature.getDataSize() + (this.cellRefs.length * 8) + 27;
    }

    public int getIsf_sharedFeatureType() {
        return this.isf_sharedFeatureType;
    }

    public SharedFeature getSharedFeature() {
        return this.sharedFeature;
    }

    @Override // org.apache.poi.hssf.record.Record
    public short getSid() {
        return sid;
    }

    @Override // org.apache.poi.hssf.record.StandardRecord
    public void serialize(LittleEndianOutput littleEndianOutput) {
        this.futureHeader.serialize(littleEndianOutput);
        littleEndianOutput.writeShort(this.isf_sharedFeatureType);
        littleEndianOutput.writeByte(this.reserved1);
        littleEndianOutput.writeInt((int) this.reserved2);
        littleEndianOutput.writeShort(this.cellRefs.length);
        littleEndianOutput.writeInt((int) this.cbFeatData);
        littleEndianOutput.writeShort(this.reserved3);
        int i2 = 0;
        while (true) {
            CellRangeAddress[] cellRangeAddressArr = this.cellRefs;
            if (i2 < cellRangeAddressArr.length) {
                cellRangeAddressArr[i2].serialize(littleEndianOutput);
                i2++;
            } else {
                this.sharedFeature.serialize(littleEndianOutput);
                return;
            }
        }
    }

    public void setCbFeatData(long j) {
        this.cbFeatData = j;
    }

    public void setCellRefs(CellRangeAddress[] cellRangeAddressArr) {
        this.cellRefs = cellRangeAddressArr;
    }

    public void setSharedFeature(SharedFeature sharedFeature2) {
        this.sharedFeature = sharedFeature2;
        if (sharedFeature2 instanceof FeatProtection) {
            this.isf_sharedFeatureType = 2;
        }
        if (sharedFeature2 instanceof FeatFormulaErr2) {
            this.isf_sharedFeatureType = 3;
        }
        if (sharedFeature2 instanceof FeatSmartTag) {
            this.isf_sharedFeatureType = 4;
        }
        if (this.isf_sharedFeatureType == 3) {
            this.cbFeatData = (long) this.sharedFeature.getDataSize();
        } else {
            this.cbFeatData = 0;
        }
    }

    @Override // org.apache.poi.hssf.record.Record
    public String toString() {
        return "[SHARED FEATURE]\n[/SHARED FEATURE]\n";
    }

    @Override // org.apache.poi.hssf.record.Record, java.lang.Object
    public FeatRecord clone() {
        return (FeatRecord) cloneViaReserialise();
    }

    public FeatRecord(RecordInputStream recordInputStream) {
        this.futureHeader = new FtrHeader(recordInputStream);
        this.isf_sharedFeatureType = recordInputStream.readShort();
        this.reserved1 = recordInputStream.readByte();
        this.reserved2 = (long) recordInputStream.readInt();
        int readUShort = recordInputStream.readUShort();
        this.cbFeatData = (long) recordInputStream.readInt();
        this.reserved3 = recordInputStream.readShort();
        this.cellRefs = new CellRangeAddress[readUShort];
        int i2 = 0;
        while (true) {
            CellRangeAddress[] cellRangeAddressArr = this.cellRefs;
            if (i2 >= cellRangeAddressArr.length) {
                break;
            }
            cellRangeAddressArr[i2] = new CellRangeAddress(recordInputStream);
            i2++;
        }
        int i3 = this.isf_sharedFeatureType;
        if (i3 == 2) {
            this.sharedFeature = new FeatProtection(recordInputStream);
        } else if (i3 == 3) {
            this.sharedFeature = new FeatFormulaErr2(recordInputStream);
        } else if (i3 != 4) {
            logger.log(7, a.a(a.b("Unknown Shared Feature "), this.isf_sharedFeatureType, " found!"));
        } else {
            this.sharedFeature = new FeatSmartTag(recordInputStream);
        }
    }
}
