package org.apache.poi.hssf.record;

import b.b.a.a.a;
import org.apache.poi.util.LittleEndianOutput;
import org.apache.poi.util.StringUtil;
import org.apache.xerces.impl.xs.SchemaSymbols;

public final class FileSharingRecord extends StandardRecord implements Cloneable {
    public static final short sid = 91;
    public short field_1_readonly;
    public short field_2_password;
    public byte field_3_username_unicode_options;
    public String field_3_username_value;

    public FileSharingRecord() {
    }

    @Override // org.apache.poi.hssf.record.StandardRecord
    public int getDataSize() {
        int length = this.field_3_username_value.length();
        if (length < 1) {
            return 6;
        }
        return length + 7;
    }

    public short getPassword() {
        return this.field_2_password;
    }

    public short getReadOnly() {
        return this.field_1_readonly;
    }

    @Override // org.apache.poi.hssf.record.Record
    public short getSid() {
        return 91;
    }

    public String getUsername() {
        return this.field_3_username_value;
    }

    @Override // org.apache.poi.hssf.record.StandardRecord
    public void serialize(LittleEndianOutput littleEndianOutput) {
        littleEndianOutput.writeShort(getReadOnly());
        littleEndianOutput.writeShort(getPassword());
        littleEndianOutput.writeShort(this.field_3_username_value.length());
        if (this.field_3_username_value.length() > 0) {
            littleEndianOutput.writeByte(this.field_3_username_unicode_options);
            StringUtil.putCompressedUnicode(getUsername(), littleEndianOutput);
        }
    }

    public void setPassword(short s) {
        this.field_2_password = s;
    }

    public void setReadOnly(short s) {
        this.field_1_readonly = s;
    }

    public void setUsername(String str) {
        this.field_3_username_value = str;
    }

    @Override // org.apache.poi.hssf.record.Record
    public String toString() {
        StringBuffer c = a.c("[FILESHARING]\n", "    .readonly       = ");
        c.append(getReadOnly() == 1 ? SchemaSymbols.ATTVAL_TRUE : SchemaSymbols.ATTVAL_FALSE);
        c.append("\n");
        c.append("    .password       = ");
        c.append(Integer.toHexString(getPassword()));
        c.append("\n");
        c.append("    .username       = ");
        c.append(getUsername());
        c.append("\n");
        c.append("[/FILESHARING]\n");
        return c.toString();
    }

    public FileSharingRecord(RecordInputStream recordInputStream) {
        this.field_1_readonly = recordInputStream.readShort();
        this.field_2_password = recordInputStream.readShort();
        short readShort = recordInputStream.readShort();
        if (readShort > 0) {
            this.field_3_username_unicode_options = recordInputStream.readByte();
            this.field_3_username_value = recordInputStream.readCompressedUnicode(readShort);
            return;
        }
        this.field_3_username_value = "";
    }

    @Override // org.apache.poi.hssf.record.Record, java.lang.Object
    public FileSharingRecord clone() {
        FileSharingRecord fileSharingRecord = new FileSharingRecord();
        fileSharingRecord.setReadOnly(this.field_1_readonly);
        fileSharingRecord.setPassword(this.field_2_password);
        fileSharingRecord.setUsername(this.field_3_username_value);
        return fileSharingRecord;
    }
}
