package org.apache.poi.hssf.record;

import b.b.a.a.a;
import org.apache.poi.util.BitField;
import org.apache.poi.util.BitFieldFactory;
import org.apache.poi.util.HexDump;
import org.apache.poi.util.LittleEndianOutput;
import org.apache.poi.util.StringUtil;

public final class FontRecord extends StandardRecord {
    public static final short SS_NONE = 0;
    public static final short SS_SUB = 2;
    public static final short SS_SUPER = 1;
    public static final byte U_DOUBLE = 2;
    public static final byte U_DOUBLE_ACCOUNTING = 34;
    public static final byte U_NONE = 0;
    public static final byte U_SINGLE = 1;
    public static final byte U_SINGLE_ACCOUNTING = 33;
    public static final BitField italic = BitFieldFactory.getInstance(2);
    public static final BitField macoutline = BitFieldFactory.getInstance(16);
    public static final BitField macshadow = BitFieldFactory.getInstance(32);
    public static final short sid = 49;
    public static final BitField strikeout = BitFieldFactory.getInstance(8);
    public String field_11_font_name;
    public short field_1_font_height;
    public short field_2_attributes;
    public short field_3_color_palette_index;
    public short field_4_bold_weight;
    public short field_5_super_sub_script;
    public byte field_6_underline;
    public byte field_7_family;
    public byte field_8_charset;
    public byte field_9_zero = 0;

    public FontRecord() {
    }

    public static boolean stringEquals(String str, String str2) {
        return str == str2 || (str != null && str.equals(str2));
    }

    public void cloneStyleFrom(FontRecord fontRecord) {
        this.field_1_font_height = fontRecord.field_1_font_height;
        this.field_2_attributes = fontRecord.field_2_attributes;
        this.field_3_color_palette_index = fontRecord.field_3_color_palette_index;
        this.field_4_bold_weight = fontRecord.field_4_bold_weight;
        this.field_5_super_sub_script = fontRecord.field_5_super_sub_script;
        this.field_6_underline = fontRecord.field_6_underline;
        this.field_7_family = fontRecord.field_7_family;
        this.field_8_charset = fontRecord.field_8_charset;
        this.field_9_zero = fontRecord.field_9_zero;
        this.field_11_font_name = fontRecord.field_11_font_name;
    }

    public boolean equals(Object obj) {
        if (obj instanceof FontRecord) {
            return sameProperties((FontRecord) obj);
        }
        return false;
    }

    public short getAttributes() {
        return this.field_2_attributes;
    }

    public short getBoldWeight() {
        return this.field_4_bold_weight;
    }

    public byte getCharset() {
        return this.field_8_charset;
    }

    public short getColorPaletteIndex() {
        return this.field_3_color_palette_index;
    }

    @Override // org.apache.poi.hssf.record.StandardRecord
    public int getDataSize() {
        int length = this.field_11_font_name.length();
        int i2 = 1;
        if (length < 1) {
            return 16;
        }
        if (StringUtil.hasMultibyte(this.field_11_font_name)) {
            i2 = 2;
        }
        return (length * i2) + 16;
    }

    public byte getFamily() {
        return this.field_7_family;
    }

    public short getFontHeight() {
        return this.field_1_font_height;
    }

    public String getFontName() {
        return this.field_11_font_name;
    }

    @Override // org.apache.poi.hssf.record.Record
    public short getSid() {
        return 49;
    }

    public short getSuperSubScript() {
        return this.field_5_super_sub_script;
    }

    public byte getUnderline() {
        return this.field_6_underline;
    }

    public int hashCode() {
        String str = this.field_11_font_name;
        return (((((((((((((((((((str == null ? 0 : str.hashCode()) + 31) * 31) + this.field_1_font_height) * 31) + this.field_2_attributes) * 31) + this.field_3_color_palette_index) * 31) + this.field_4_bold_weight) * 31) + this.field_5_super_sub_script) * 31) + this.field_6_underline) * 31) + this.field_7_family) * 31) + this.field_8_charset) * 31) + this.field_9_zero;
    }

    public boolean isItalic() {
        return italic.isSet(this.field_2_attributes);
    }

    public boolean isMacoutlined() {
        return macoutline.isSet(this.field_2_attributes);
    }

    public boolean isMacshadowed() {
        return macshadow.isSet(this.field_2_attributes);
    }

    public boolean isStruckout() {
        return strikeout.isSet(this.field_2_attributes);
    }

    public boolean sameProperties(FontRecord fontRecord) {
        return this.field_1_font_height == fontRecord.field_1_font_height && this.field_2_attributes == fontRecord.field_2_attributes && this.field_3_color_palette_index == fontRecord.field_3_color_palette_index && this.field_4_bold_weight == fontRecord.field_4_bold_weight && this.field_5_super_sub_script == fontRecord.field_5_super_sub_script && this.field_6_underline == fontRecord.field_6_underline && this.field_7_family == fontRecord.field_7_family && this.field_8_charset == fontRecord.field_8_charset && this.field_9_zero == fontRecord.field_9_zero && stringEquals(this.field_11_font_name, fontRecord.field_11_font_name);
    }

    @Override // org.apache.poi.hssf.record.StandardRecord
    public void serialize(LittleEndianOutput littleEndianOutput) {
        littleEndianOutput.writeShort(getFontHeight());
        littleEndianOutput.writeShort(getAttributes());
        littleEndianOutput.writeShort(getColorPaletteIndex());
        littleEndianOutput.writeShort(getBoldWeight());
        littleEndianOutput.writeShort(getSuperSubScript());
        littleEndianOutput.writeByte(getUnderline());
        littleEndianOutput.writeByte(getFamily());
        littleEndianOutput.writeByte(getCharset());
        littleEndianOutput.writeByte(this.field_9_zero);
        int length = this.field_11_font_name.length();
        littleEndianOutput.writeByte(length);
        boolean hasMultibyte = StringUtil.hasMultibyte(this.field_11_font_name);
        littleEndianOutput.writeByte(hasMultibyte ? 1 : 0);
        if (length <= 0) {
            return;
        }
        if (hasMultibyte) {
            StringUtil.putUnicodeLE(this.field_11_font_name, littleEndianOutput);
        } else {
            StringUtil.putCompressedUnicode(this.field_11_font_name, littleEndianOutput);
        }
    }

    public void setAttributes(short s) {
        this.field_2_attributes = s;
    }

    public void setBoldWeight(short s) {
        this.field_4_bold_weight = s;
    }

    public void setCharset(byte b2) {
        this.field_8_charset = b2;
    }

    public void setColorPaletteIndex(short s) {
        this.field_3_color_palette_index = s;
    }

    public void setFamily(byte b2) {
        this.field_7_family = b2;
    }

    public void setFontHeight(short s) {
        this.field_1_font_height = s;
    }

    public void setFontName(String str) {
        this.field_11_font_name = str;
    }

    public void setItalic(boolean z) {
        this.field_2_attributes = italic.setShortBoolean(this.field_2_attributes, z);
    }

    public void setMacoutline(boolean z) {
        this.field_2_attributes = macoutline.setShortBoolean(this.field_2_attributes, z);
    }

    public void setMacshadow(boolean z) {
        this.field_2_attributes = macshadow.setShortBoolean(this.field_2_attributes, z);
    }

    public void setStrikeout(boolean z) {
        this.field_2_attributes = strikeout.setShortBoolean(this.field_2_attributes, z);
    }

    public void setSuperSubScript(short s) {
        this.field_5_super_sub_script = s;
    }

    public void setUnderline(byte b2) {
        this.field_6_underline = b2;
    }

    @Override // org.apache.poi.hssf.record.Record
    public String toString() {
        StringBuffer c = a.c("[FONT]\n", "    .fontheight    = ");
        c.append(HexDump.shortToHex(getFontHeight()));
        c.append("\n");
        c.append("    .attributes    = ");
        c.append(HexDump.shortToHex(getAttributes()));
        c.append("\n");
        c.append("       .italic     = ");
        c.append(isItalic());
        c.append("\n");
        c.append("       .strikout   = ");
        c.append(isStruckout());
        c.append("\n");
        c.append("       .macoutlined= ");
        c.append(isMacoutlined());
        c.append("\n");
        c.append("       .macshadowed= ");
        c.append(isMacshadowed());
        c.append("\n");
        c.append("    .colorpalette  = ");
        c.append(HexDump.shortToHex(getColorPaletteIndex()));
        c.append("\n");
        c.append("    .boldweight    = ");
        c.append(HexDump.shortToHex(getBoldWeight()));
        c.append("\n");
        c.append("    .supersubscript= ");
        c.append(HexDump.shortToHex(getSuperSubScript()));
        c.append("\n");
        c.append("    .underline     = ");
        c.append(HexDump.byteToHex(getUnderline()));
        c.append("\n");
        c.append("    .family        = ");
        c.append(HexDump.byteToHex(getFamily()));
        c.append("\n");
        c.append("    .charset       = ");
        c.append(HexDump.byteToHex(getCharset()));
        c.append("\n");
        c.append("    .fontname      = ");
        c.append(getFontName());
        return a.a(c, "\n", "[/FONT]\n");
    }

    public FontRecord(RecordInputStream recordInputStream) {
        this.field_1_font_height = recordInputStream.readShort();
        this.field_2_attributes = recordInputStream.readShort();
        this.field_3_color_palette_index = recordInputStream.readShort();
        this.field_4_bold_weight = recordInputStream.readShort();
        this.field_5_super_sub_script = recordInputStream.readShort();
        this.field_6_underline = recordInputStream.readByte();
        this.field_7_family = recordInputStream.readByte();
        this.field_8_charset = recordInputStream.readByte();
        this.field_9_zero = recordInputStream.readByte();
        int readUByte = recordInputStream.readUByte();
        int readUByte2 = recordInputStream.readUByte();
        if (readUByte <= 0) {
            this.field_11_font_name = "";
        } else if (readUByte2 == 0) {
            this.field_11_font_name = recordInputStream.readCompressedUnicode(readUByte);
        } else {
            this.field_11_font_name = recordInputStream.readUnicodeLEString(readUByte);
        }
    }
}
