package org.apache.poi.hssf.record;

import b.b.a.a.a;
import org.apache.poi.util.HexDump;
import org.apache.poi.util.LittleEndianOutput;
import org.apache.poi.util.POILogFactory;
import org.apache.poi.util.POILogger;
import org.apache.poi.util.StringUtil;

public final class FormatRecord extends StandardRecord implements Cloneable {
    public static final POILogger logger = POILogFactory.getLogger(FormatRecord.class);
    public static final short sid = 1054;
    public final int field_1_index_code;
    public final boolean field_3_hasMultibyte;
    public final String field_4_formatstring;

    public FormatRecord(FormatRecord formatRecord) {
        this.field_1_index_code = formatRecord.field_1_index_code;
        this.field_3_hasMultibyte = formatRecord.field_3_hasMultibyte;
        this.field_4_formatstring = formatRecord.field_4_formatstring;
    }

    public static String readStringCommon(RecordInputStream recordInputStream, int i2, boolean z) {
        char[] cArr;
        int i3;
        if (i2 < 0 || i2 > 1048576) {
            throw new IllegalArgumentException(a.b("Bad requested string length (", i2, ")"));
        }
        int remaining = recordInputStream.remaining();
        if (!z) {
            remaining /= 2;
        }
        recordInputStream.remaining();
        if (i2 == remaining) {
            cArr = new char[i2];
        } else {
            cArr = new char[remaining];
        }
        for (int i4 = 0; i4 < cArr.length; i4++) {
            if (z) {
                i3 = recordInputStream.readUByte();
            } else {
                i3 = recordInputStream.readShort();
            }
            cArr[i4] = (char) i3;
        }
        if (recordInputStream.available() == 1) {
            char[] cArr2 = new char[(cArr.length + 1)];
            System.arraycopy(cArr, 0, cArr2, 0, cArr.length);
            cArr2[cArr.length] = (char) recordInputStream.readUByte();
            cArr = cArr2;
        }
        if (recordInputStream.available() > 0) {
            POILogger pOILogger = logger;
            StringBuilder b2 = a.b("FormatRecord has ");
            b2.append(recordInputStream.available());
            b2.append(" unexplained bytes. Silently skipping");
            pOILogger.log(3, b2.toString());
            while (recordInputStream.available() > 0) {
                recordInputStream.readByte();
            }
        }
        return new String(cArr);
    }

    @Override // org.apache.poi.hssf.record.StandardRecord
    public int getDataSize() {
        return (getFormatString().length() * (this.field_3_hasMultibyte ? 2 : 1)) + 5;
    }

    public String getFormatString() {
        return this.field_4_formatstring;
    }

    public int getIndexCode() {
        return this.field_1_index_code;
    }

    @Override // org.apache.poi.hssf.record.Record
    public short getSid() {
        return sid;
    }

    @Override // org.apache.poi.hssf.record.StandardRecord
    public void serialize(LittleEndianOutput littleEndianOutput) {
        String formatString = getFormatString();
        littleEndianOutput.writeShort(getIndexCode());
        littleEndianOutput.writeShort(formatString.length());
        littleEndianOutput.writeByte(this.field_3_hasMultibyte ? 1 : 0);
        if (this.field_3_hasMultibyte) {
            StringUtil.putUnicodeLE(formatString, littleEndianOutput);
        } else {
            StringUtil.putCompressedUnicode(formatString, littleEndianOutput);
        }
    }

    @Override // org.apache.poi.hssf.record.Record
    public String toString() {
        StringBuffer c = a.c("[FORMAT]\n", "    .indexcode       = ");
        c.append(HexDump.shortToHex(getIndexCode()));
        c.append("\n");
        c.append("    .isUnicode       = ");
        c.append(this.field_3_hasMultibyte);
        c.append("\n");
        c.append("    .formatstring    = ");
        c.append(getFormatString());
        return a.a(c, "\n", "[/FORMAT]\n");
    }

    @Override // org.apache.poi.hssf.record.Record, java.lang.Object
    public FormatRecord clone() {
        return new FormatRecord(this);
    }

    public FormatRecord(int i2, String str) {
        this.field_1_index_code = i2;
        this.field_4_formatstring = str;
        this.field_3_hasMultibyte = StringUtil.hasMultibyte(str);
    }

    public FormatRecord(RecordInputStream recordInputStream) {
        this.field_1_index_code = recordInputStream.readShort();
        int readUShort = recordInputStream.readUShort();
        boolean z = (recordInputStream.readByte() & 1) != 0;
        this.field_3_hasMultibyte = z;
        if (z) {
            this.field_4_formatstring = readStringCommon(recordInputStream, readUShort, false);
        } else {
            this.field_4_formatstring = readStringCommon(recordInputStream, readUShort, true);
        }
    }
}
