package org.apache.poi.hssf.record;

import b.b.a.a.a;
import org.apache.poi.ss.formula.Formula;
import org.apache.poi.ss.formula.eval.ErrorEval;
import org.apache.poi.ss.formula.ptg.Ptg;
import org.apache.poi.ss.usermodel.CellType;
import org.apache.poi.util.BitField;
import org.apache.poi.util.BitFieldFactory;
import org.apache.poi.util.HexDump;
import org.apache.poi.util.LittleEndianOutput;
import org.apache.poi.util.RecordFormatException;
import org.apache.poi.xssf.usermodel.XSSFCell;

public final class FormulaRecord extends CellRecord implements Cloneable {
    public static int FIXED_SIZE = 14;
    public static final BitField alwaysCalc = BitFieldFactory.getInstance(1);
    public static final BitField calcOnLoad = BitFieldFactory.getInstance(2);
    public static final BitField sharedFormula = BitFieldFactory.getInstance(8);
    public static final short sid = 6;
    public double field_4_value;
    public short field_5_options;
    public int field_6_zero;
    public Formula field_8_parsed_expr;
    public SpecialCachedValue specialCachedValue;

    public FormulaRecord() {
        this.field_8_parsed_expr = Formula.create(Ptg.EMPTY_PTG_ARRAY);
    }

    @Override // org.apache.poi.hssf.record.CellRecord
    public void appendValueText(StringBuilder sb) {
        sb.append("  .value\t = ");
        SpecialCachedValue specialCachedValue2 = this.specialCachedValue;
        if (specialCachedValue2 == null) {
            sb.append(this.field_4_value);
            sb.append("\n");
        } else {
            sb.append(specialCachedValue2.formatDebugString());
            sb.append("\n");
        }
        sb.append("  .options   = ");
        sb.append(HexDump.shortToHex(getOptions()));
        sb.append("\n");
        sb.append("    .alwaysCalc= ");
        sb.append(isAlwaysCalc());
        sb.append("\n");
        sb.append("    .calcOnLoad= ");
        sb.append(isCalcOnLoad());
        sb.append("\n");
        sb.append("    .shared    = ");
        sb.append(isSharedFormula());
        sb.append("\n");
        sb.append("  .zero      = ");
        sb.append(HexDump.intToHex(this.field_6_zero));
        sb.append("\n");
        Ptg[] tokens = this.field_8_parsed_expr.getTokens();
        for (int i2 = 0; i2 < tokens.length; i2++) {
            if (i2 > 0) {
                sb.append("\n");
            }
            sb.append("    Ptg[");
            sb.append(i2);
            sb.append("]=");
            Ptg ptg = tokens[i2];
            sb.append(ptg);
            sb.append(ptg.getRVAType());
        }
    }

    public boolean getCachedBooleanValue() {
        return this.specialCachedValue.getBooleanValue();
    }

    public int getCachedErrorValue() {
        return this.specialCachedValue.getErrorValue();
    }

    public int getCachedResultType() {
        SpecialCachedValue specialCachedValue2 = this.specialCachedValue;
        if (specialCachedValue2 == null) {
            return CellType.NUMERIC.getCode();
        }
        return specialCachedValue2.getValueType();
    }

    public Formula getFormula() {
        return this.field_8_parsed_expr;
    }

    public short getOptions() {
        return this.field_5_options;
    }

    public Ptg[] getParsedExpression() {
        return this.field_8_parsed_expr.getTokens();
    }

    @Override // org.apache.poi.hssf.record.CellRecord
    public String getRecordName() {
        return "FORMULA";
    }

    @Override // org.apache.poi.hssf.record.Record
    public short getSid() {
        return 6;
    }

    public double getValue() {
        return this.field_4_value;
    }

    @Override // org.apache.poi.hssf.record.CellRecord
    public int getValueDataSize() {
        return this.field_8_parsed_expr.getEncodedSize() + FIXED_SIZE;
    }

    public boolean hasCachedResultString() {
        SpecialCachedValue specialCachedValue2 = this.specialCachedValue;
        return specialCachedValue2 != null && specialCachedValue2.getTypeCode() == 0;
    }

    public boolean isAlwaysCalc() {
        return alwaysCalc.isSet(this.field_5_options);
    }

    public boolean isCalcOnLoad() {
        return calcOnLoad.isSet(this.field_5_options);
    }

    public boolean isSharedFormula() {
        return sharedFormula.isSet(this.field_5_options);
    }

    @Override // org.apache.poi.hssf.record.CellRecord
    public void serializeValue(LittleEndianOutput littleEndianOutput) {
        SpecialCachedValue specialCachedValue2 = this.specialCachedValue;
        if (specialCachedValue2 == null) {
            littleEndianOutput.writeDouble(this.field_4_value);
        } else {
            specialCachedValue2.serialize(littleEndianOutput);
        }
        littleEndianOutput.writeShort(getOptions());
        littleEndianOutput.writeInt(this.field_6_zero);
        this.field_8_parsed_expr.serialize(littleEndianOutput);
    }

    public void setAlwaysCalc(boolean z) {
        this.field_5_options = alwaysCalc.setShortBoolean(this.field_5_options, z);
    }

    public void setCachedResultBoolean(boolean z) {
        this.specialCachedValue = SpecialCachedValue.createCachedBoolean(z);
    }

    public void setCachedResultErrorCode(int i2) {
        this.specialCachedValue = SpecialCachedValue.createCachedErrorCode(i2);
    }

    public void setCachedResultTypeEmptyString() {
        this.specialCachedValue = SpecialCachedValue.createCachedEmptyValue();
    }

    public void setCachedResultTypeString() {
        this.specialCachedValue = SpecialCachedValue.createForString();
    }

    public void setCalcOnLoad(boolean z) {
        this.field_5_options = calcOnLoad.setShortBoolean(this.field_5_options, z);
    }

    public void setOptions(short s) {
        this.field_5_options = s;
    }

    public void setParsedExpression(Ptg[] ptgArr) {
        this.field_8_parsed_expr = Formula.create(ptgArr);
    }

    public void setSharedFormula(boolean z) {
        this.field_5_options = sharedFormula.setShortBoolean(this.field_5_options, z);
    }

    public void setValue(double d2) {
        this.field_4_value = d2;
        this.specialCachedValue = null;
    }

    @Override // org.apache.poi.hssf.record.Record, java.lang.Object
    public FormulaRecord clone() {
        FormulaRecord formulaRecord = new FormulaRecord();
        copyBaseFields(formulaRecord);
        formulaRecord.field_4_value = this.field_4_value;
        formulaRecord.field_5_options = this.field_5_options;
        formulaRecord.field_6_zero = this.field_6_zero;
        formulaRecord.field_8_parsed_expr = this.field_8_parsed_expr;
        formulaRecord.specialCachedValue = this.specialCachedValue;
        return formulaRecord;
    }

    public FormulaRecord(RecordInputStream recordInputStream) {
        super(recordInputStream);
        long readLong = recordInputStream.readLong();
        this.field_5_options = recordInputStream.readShort();
        SpecialCachedValue create = SpecialCachedValue.create(readLong);
        this.specialCachedValue = create;
        if (create == null) {
            this.field_4_value = Double.longBitsToDouble(readLong);
        }
        this.field_6_zero = recordInputStream.readInt();
        this.field_8_parsed_expr = Formula.read(recordInputStream.readShort(), recordInputStream, recordInputStream.available());
    }

    public static final class SpecialCachedValue {
        public static final long BIT_MARKER = -281474976710656L;
        public static final int BOOLEAN = 1;
        public static final int DATA_INDEX = 2;
        public static final int EMPTY = 3;
        public static final int ERROR_CODE = 2;
        public static final int STRING = 0;
        public static final int VARIABLE_DATA_LENGTH = 6;
        public final byte[] _variableData;

        public SpecialCachedValue(byte[] bArr) {
            this._variableData = bArr;
        }

        public static SpecialCachedValue create(long j) {
            if ((j & BIT_MARKER) != BIT_MARKER) {
                return null;
            }
            byte[] bArr = new byte[6];
            for (int i2 = 0; i2 < 6; i2++) {
                bArr[i2] = (byte) ((int) j);
                j >>= 8;
            }
            byte b2 = bArr[0];
            if (b2 == 0 || b2 == 1 || b2 == 2 || b2 == 3) {
                return new SpecialCachedValue(bArr);
            }
            throw new RecordFormatException(a.a(a.b("Bad special value code ("), bArr[0], ")"));
        }

        public static SpecialCachedValue createCachedBoolean(boolean z) {
            return create(1, z ? 1 : 0);
        }

        public static SpecialCachedValue createCachedEmptyValue() {
            return create(3, 0);
        }

        public static SpecialCachedValue createCachedErrorCode(int i2) {
            return create(2, i2);
        }

        public static SpecialCachedValue createForString() {
            return create(0, 0);
        }

        private String formatValue() {
            int typeCode = getTypeCode();
            if (typeCode == 0) {
                return "<string>";
            }
            if (typeCode == 1) {
                return getDataValue() == 0 ? XSSFCell.FALSE : XSSFCell.TRUE;
            }
            if (typeCode != 2) {
                return typeCode != 3 ? a.b("#error(type=", typeCode, ")#") : "<empty>";
            }
            return ErrorEval.getText(getDataValue());
        }

        private int getDataValue() {
            return this._variableData[2];
        }

        public String formatDebugString() {
            return formatValue() + ' ' + HexDump.toHex(this._variableData);
        }

        public boolean getBooleanValue() {
            if (getTypeCode() != 1) {
                StringBuilder b2 = a.b("Not a boolean cached value - ");
                b2.append(formatValue());
                throw new IllegalStateException(b2.toString());
            } else if (getDataValue() != 0) {
                return true;
            } else {
                return false;
            }
        }

        public int getErrorValue() {
            if (getTypeCode() == 2) {
                return getDataValue();
            }
            StringBuilder b2 = a.b("Not an error cached value - ");
            b2.append(formatValue());
            throw new IllegalStateException(b2.toString());
        }

        public int getTypeCode() {
            return this._variableData[0];
        }

        public int getValueType() {
            int typeCode = getTypeCode();
            if (typeCode == 0) {
                return CellType.STRING.getCode();
            }
            if (typeCode == 1) {
                return CellType.BOOLEAN.getCode();
            }
            if (typeCode == 2) {
                return CellType.ERROR.getCode();
            }
            if (typeCode == 3) {
                return CellType.STRING.getCode();
            }
            throw new IllegalStateException(a.b("Unexpected type id (", typeCode, ")"));
        }

        public void serialize(LittleEndianOutput littleEndianOutput) {
            littleEndianOutput.write(this._variableData);
            littleEndianOutput.writeShort(65535);
        }

        public String toString() {
            return SpecialCachedValue.class.getName() + '[' + formatValue() + ']';
        }

        public static SpecialCachedValue create(int i2, int i3) {
            return new SpecialCachedValue(new byte[]{(byte) i2, 0, (byte) i3, 0, 0, 0});
        }
    }
}
