package org.apache.poi.hssf.record;

import b.b.a.a.a;
import org.apache.poi.util.HexDump;
import org.apache.poi.util.LittleEndianInput;
import org.apache.poi.util.LittleEndianOutput;
import org.apache.poi.util.RecordFormatException;

public final class FtPioGrbitSubRecord extends SubRecord implements Cloneable {
    public static final int AUTO_LOAD_BIT = 512;
    public static final int AUTO_PICT_BIT = 1;
    public static final int CAMERA_BIT = 128;
    public static final int CTL_BIT = 16;
    public static final int DDE_BIT = 2;
    public static final int DEFAULT_SIZE_BIT = 256;
    public static final int ICON_BIT = 8;
    public static final int PRINT_CALC_BIT = 4;
    public static final int PRSTM_BIT = 32;
    public static final short length = 2;
    public static final short sid = 8;
    public short flags = 0;

    public FtPioGrbitSubRecord() {
    }

    @Override // org.apache.poi.hssf.record.SubRecord
    public int getDataSize() {
        return 2;
    }

    public boolean getFlagByBit(int i2) {
        return (i2 & this.flags) != 0;
    }

    public short getFlags() {
        return this.flags;
    }

    public short getSid() {
        return 8;
    }

    @Override // org.apache.poi.hssf.record.SubRecord
    public void serialize(LittleEndianOutput littleEndianOutput) {
        littleEndianOutput.writeShort(8);
        littleEndianOutput.writeShort(2);
        littleEndianOutput.writeShort(this.flags);
    }

    public void setFlagByBit(int i2, boolean z) {
        if (z) {
            this.flags = (short) (i2 | this.flags);
            return;
        }
        this.flags = (short) ((i2 ^ 65535) & this.flags);
    }

    public void setFlags(short s) {
        this.flags = s;
    }

    public String toString() {
        StringBuffer stringBuffer = new StringBuffer();
        stringBuffer.append("[FtPioGrbit ]\n");
        stringBuffer.append("  size     = ");
        stringBuffer.append(2);
        stringBuffer.append("\n");
        stringBuffer.append("  flags    = ");
        stringBuffer.append(HexDump.toHex(this.flags));
        stringBuffer.append("\n");
        stringBuffer.append("[/FtPioGrbit ]\n");
        return stringBuffer.toString();
    }

    public FtPioGrbitSubRecord(LittleEndianInput littleEndianInput, int i2) {
        if (i2 == 2) {
            this.flags = littleEndianInput.readShort();
            return;
        }
        throw new RecordFormatException(a.b("Unexpected size (", i2, ")"));
    }

    @Override // org.apache.poi.hssf.record.SubRecord, org.apache.poi.hssf.record.SubRecord, java.lang.Object
    public FtPioGrbitSubRecord clone() {
        FtPioGrbitSubRecord ftPioGrbitSubRecord = new FtPioGrbitSubRecord();
        ftPioGrbitSubRecord.flags = this.flags;
        return ftPioGrbitSubRecord;
    }
}
