package org.apache.poi.hssf.record;

import b.b.a.a.a;
import org.apache.poi.util.LittleEndianOutput;

public final class GutsRecord extends StandardRecord implements Cloneable {
    public static final short sid = 128;
    public short field_1_left_row_gutter;
    public short field_2_top_col_gutter;
    public short field_3_row_level_max;
    public short field_4_col_level_max;

    public GutsRecord() {
    }

    public short getColLevelMax() {
        return this.field_4_col_level_max;
    }

    @Override // org.apache.poi.hssf.record.StandardRecord
    public int getDataSize() {
        return 8;
    }

    public short getLeftRowGutter() {
        return this.field_1_left_row_gutter;
    }

    public short getRowLevelMax() {
        return this.field_3_row_level_max;
    }

    @Override // org.apache.poi.hssf.record.Record
    public short getSid() {
        return 128;
    }

    public short getTopColGutter() {
        return this.field_2_top_col_gutter;
    }

    @Override // org.apache.poi.hssf.record.StandardRecord
    public void serialize(LittleEndianOutput littleEndianOutput) {
        littleEndianOutput.writeShort(getLeftRowGutter());
        littleEndianOutput.writeShort(getTopColGutter());
        littleEndianOutput.writeShort(getRowLevelMax());
        littleEndianOutput.writeShort(getColLevelMax());
    }

    public void setColLevelMax(short s) {
        this.field_4_col_level_max = s;
    }

    public void setLeftRowGutter(short s) {
        this.field_1_left_row_gutter = s;
    }

    public void setRowLevelMax(short s) {
        this.field_3_row_level_max = s;
    }

    public void setTopColGutter(short s) {
        this.field_2_top_col_gutter = s;
    }

    @Override // org.apache.poi.hssf.record.Record
    public String toString() {
        StringBuffer c = a.c("[GUTS]\n", "    .leftgutter     = ");
        c.append(Integer.toHexString(getLeftRowGutter()));
        c.append("\n");
        c.append("    .topgutter      = ");
        c.append(Integer.toHexString(getTopColGutter()));
        c.append("\n");
        c.append("    .rowlevelmax    = ");
        c.append(Integer.toHexString(getRowLevelMax()));
        c.append("\n");
        c.append("    .collevelmax    = ");
        c.append(Integer.toHexString(getColLevelMax()));
        return a.a(c, "\n", "[/GUTS]\n");
    }

    public GutsRecord(RecordInputStream recordInputStream) {
        this.field_1_left_row_gutter = recordInputStream.readShort();
        this.field_2_top_col_gutter = recordInputStream.readShort();
        this.field_3_row_level_max = recordInputStream.readShort();
        this.field_4_col_level_max = recordInputStream.readShort();
    }

    @Override // org.apache.poi.hssf.record.Record, java.lang.Object
    public GutsRecord clone() {
        GutsRecord gutsRecord = new GutsRecord();
        gutsRecord.field_1_left_row_gutter = this.field_1_left_row_gutter;
        gutsRecord.field_2_top_col_gutter = this.field_2_top_col_gutter;
        gutsRecord.field_3_row_level_max = this.field_3_row_level_max;
        gutsRecord.field_4_col_level_max = this.field_4_col_level_max;
        return gutsRecord;
    }
}
