package org.apache.poi.hssf.record;

import b.b.a.a.a;
import org.apache.poi.ss.formula.ptg.UnaryMinusPtg;
import org.apache.poi.ss.util.CellRangeAddress;
import org.apache.poi.ss.util.SheetUtil;
import org.apache.poi.util.HexDump;
import org.apache.poi.util.HexRead;
import org.apache.poi.util.LittleEndian;
import org.apache.poi.util.LittleEndianInput;
import org.apache.poi.util.LittleEndianOutput;
import org.apache.poi.util.POILogFactory;
import org.apache.poi.util.POILogger;
import org.apache.poi.util.RecordFormatException;
import org.apache.poi.util.StringUtil;

public final class HyperlinkRecord extends StandardRecord implements Cloneable {
    public static final GUID FILE_MONIKER = GUID.parse("00000303-0000-0000-C000-000000000046");
    public static final byte[] FILE_TAIL;
    public static final int HLINK_ABS = 2;
    public static final int HLINK_LABEL = 20;
    public static final int HLINK_PLACE = 8;
    public static final int HLINK_TARGET_FRAME = 128;
    public static final int HLINK_UNC_PATH = 256;
    public static final int HLINK_URL = 1;
    public static final GUID STD_MONIKER = GUID.parse("79EAC9D0-BAF9-11CE-8C82-00AA004BA90B");
    public static final int TAIL_SIZE;
    public static final GUID URL_MONIKER = GUID.parse("79EAC9E0-BAF9-11CE-8C82-00AA004BA90B");
    public static final byte[] URL_TAIL = HexRead.readFromString("79 58 81 F4  3B 1D 7F 48   AF 2C 82 5D  C4 85 27 63   00 00 00 00  A5 AB 00 00");
    public static POILogger logger = POILogFactory.getLogger(HyperlinkRecord.class);
    public static final short sid = 440;
    public String _address;
    public int _fileOpts;
    public GUID _guid;
    public String _label;
    public int _linkOpts;
    public GUID _moniker;
    public CellRangeAddress _range;
    public String _shortFilename;
    public String _targetFrame;
    public String _textMark;
    public byte[] _uninterpretedTail;

    public static final class GUID {
        public static final /* synthetic */ boolean $assertionsDisabled = false;
        public static final int ENCODED_SIZE = 16;
        public static final int TEXT_FORMAT_LENGTH = 36;
        public final int _d1;
        public final int _d2;
        public final int _d3;
        public final long _d4;

        public GUID(LittleEndianInput littleEndianInput) {
            this(littleEndianInput.readInt(), littleEndianInput.readUShort(), littleEndianInput.readUShort(), littleEndianInput.readLong());
        }

        public static GUID parse(String str) {
            char[] charArray = str.toCharArray();
            if (charArray.length == 36) {
                int parseShort = (parseShort(charArray, 0) << 16) + (parseShort(charArray, 4) << 0);
                int parseShort2 = parseShort(charArray, 9);
                int parseShort3 = parseShort(charArray, 14);
                for (int i2 = 23; i2 > 19; i2--) {
                    charArray[i2] = charArray[i2 - 1];
                }
                return new GUID(parseShort, parseShort2, parseShort3, parseLELong(charArray, 20));
            }
            throw new RecordFormatException("supplied text is the wrong length for a GUID");
        }

        public static int parseHexChar(char c) {
            if (c >= '0' && c <= '9') {
                return c - SheetUtil.defaultChar;
            }
            char c2 = 'A';
            if (c < 'A' || c > 'F') {
                c2 = 'a';
                if (c < 'a' || c > 'f') {
                    throw new RecordFormatException("Bad hex char '" + c + "'");
                }
            }
            return (c - c2) + 10;
        }

        public static long parseLELong(char[] cArr, int i2) {
            long j = 0;
            for (int i3 = i2 + 14; i3 >= i2; i3 -= 2) {
                j = (((j << 4) + ((long) parseHexChar(cArr[i3 + 0]))) << 4) + ((long) parseHexChar(cArr[i3 + 1]));
            }
            return j;
        }

        public static int parseShort(char[] cArr, int i2) {
            int i3 = 0;
            for (int i4 = 0; i4 < 4; i4++) {
                i3 = (i3 << 4) + parseHexChar(cArr[i2 + i4]);
            }
            return i3;
        }

        public boolean equals(Object obj) {
            if (!(obj instanceof GUID)) {
                return false;
            }
            GUID guid = (GUID) obj;
            if (this._d1 == guid._d1 && this._d2 == guid._d2 && this._d3 == guid._d3 && this._d4 == guid._d4) {
                return true;
            }
            return false;
        }

        public String formatAsString() {
            StringBuilder sb = new StringBuilder(36);
            sb.append(HexDump.intToHex(this._d1).substring(2));
            sb.append(UnaryMinusPtg.MINUS);
            sb.append(HexDump.shortToHex(this._d2).substring(2));
            sb.append(UnaryMinusPtg.MINUS);
            sb.append(HexDump.shortToHex(this._d3).substring(2));
            sb.append(UnaryMinusPtg.MINUS);
            String longToHex = HexDump.longToHex(getD4());
            sb.append(longToHex.substring(2, 6));
            sb.append(UnaryMinusPtg.MINUS);
            sb.append(longToHex.substring(6));
            return sb.toString();
        }

        public int getD1() {
            return this._d1;
        }

        public int getD2() {
            return this._d2;
        }

        public int getD3() {
            return this._d3;
        }

        public long getD4() {
            byte[] bArr = new byte[8];
            long j = this._d4;
            for (int i2 = 7; i2 >= 0; i2--) {
                bArr[i2] = (byte) ((int) (255 & j));
                j >>= 8;
            }
            return LittleEndian.getLong(bArr, 0);
        }

        public int hashCode() {
            return 42;
        }

        public void serialize(LittleEndianOutput littleEndianOutput) {
            littleEndianOutput.writeInt(this._d1);
            littleEndianOutput.writeShort(this._d2);
            littleEndianOutput.writeShort(this._d3);
            littleEndianOutput.writeLong(this._d4);
        }

        public String toString() {
            StringBuilder sb = new StringBuilder(64);
            sb.append(GUID.class.getName());
            sb.append(" [");
            sb.append(formatAsString());
            sb.append("]");
            return sb.toString();
        }

        public GUID(int i2, int i3, int i4, long j) {
            this._d1 = i2;
            this._d2 = i3;
            this._d3 = i4;
            this._d4 = j;
        }
    }

    static {
        byte[] readFromString = HexRead.readFromString("FF FF AD DE  00 00 00 00   00 00 00 00  00 00 00 00   00 00 00 00  00 00 00 00");
        FILE_TAIL = readFromString;
        TAIL_SIZE = readFromString.length;
    }

    public HyperlinkRecord() {
    }

    public static String appendNullTerm(String str) {
        if (str == null) {
            return null;
        }
        return str + (char) 0;
    }

    public static String cleanString(String str) {
        if (str == null) {
            return null;
        }
        int indexOf = str.indexOf(0);
        if (indexOf < 0) {
            return str;
        }
        return str.substring(0, indexOf);
    }

    public static byte[] readTail(byte[] bArr, LittleEndianInput littleEndianInput) {
        byte[] bArr2 = new byte[TAIL_SIZE];
        littleEndianInput.readFully(bArr2);
        return bArr2;
    }

    public static void writeTail(byte[] bArr, LittleEndianOutput littleEndianOutput) {
        littleEndianOutput.write(bArr);
    }

    public String getAddress() {
        if ((this._linkOpts & 1) != 0 && FILE_MONIKER.equals(this._moniker)) {
            String str = this._address;
            if (str == null) {
                str = this._shortFilename;
            }
            return cleanString(str);
        } else if ((this._linkOpts & 8) != 0) {
            return cleanString(this._textMark);
        } else {
            return cleanString(this._address);
        }
    }

    @Override // org.apache.poi.hssf.record.StandardRecord
    public int getDataSize() {
        int length = (this._linkOpts & 20) != 0 ? (this._label.length() * 2) + 36 : 32;
        if ((this._linkOpts & 128) != 0) {
            length = length + 4 + (this._targetFrame.length() * 2);
        }
        int i2 = this._linkOpts;
        if (!((i2 & 1) == 0 || (i2 & 256) == 0)) {
            length = length + 4 + (this._address.length() * 2);
        }
        int i3 = this._linkOpts;
        if ((i3 & 1) != 0 && (i3 & 256) == 0) {
            length += 16;
            if (URL_MONIKER.equals(this._moniker)) {
                length = length + 4 + (this._address.length() * 2);
                if (this._uninterpretedTail != null) {
                    length += TAIL_SIZE;
                }
            } else if (FILE_MONIKER.equals(this._moniker)) {
                length = this._shortFilename.length() + length + 2 + 4 + TAIL_SIZE + 4;
                String str = this._address;
                if (str != null) {
                    length = length + 6 + (str.length() * 2);
                }
            }
        }
        return (this._linkOpts & 8) != 0 ? length + 4 + (this._textMark.length() * 2) : length;
    }

    public int getFileOptions() {
        return this._fileOpts;
    }

    public int getFirstColumn() {
        return this._range.getFirstColumn();
    }

    public int getFirstRow() {
        return this._range.getFirstRow();
    }

    public GUID getGuid() {
        return this._guid;
    }

    public String getLabel() {
        return cleanString(this._label);
    }

    public int getLabelOptions() {
        return 2;
    }

    public int getLastColumn() {
        return this._range.getLastColumn();
    }

    public int getLastRow() {
        return this._range.getLastRow();
    }

    public int getLinkOptions() {
        return this._linkOpts;
    }

    public GUID getMoniker() {
        return this._moniker;
    }

    public String getShortFilename() {
        return cleanString(this._shortFilename);
    }

    @Override // org.apache.poi.hssf.record.Record
    public short getSid() {
        return sid;
    }

    public String getTargetFrame() {
        return cleanString(this._targetFrame);
    }

    public String getTextMark() {
        return cleanString(this._textMark);
    }

    public boolean isDocumentLink() {
        return (this._linkOpts & 8) > 0;
    }

    public boolean isFileLink() {
        int i2 = this._linkOpts;
        return (i2 & 1) > 0 && (i2 & 2) == 0;
    }

    public boolean isUrlLink() {
        int i2 = this._linkOpts;
        return (i2 & 1) > 0 && (i2 & 2) > 0;
    }

    public void newDocumentLink() {
        this._range = new CellRangeAddress(0, 0, 0, 0);
        this._guid = STD_MONIKER;
        this._linkOpts = 28;
        setLabel("");
        this._moniker = FILE_MONIKER;
        setAddress("");
        setTextMark("");
    }

    public void newFileLink() {
        this._range = new CellRangeAddress(0, 0, 0, 0);
        this._guid = STD_MONIKER;
        this._linkOpts = 21;
        this._fileOpts = 0;
        setLabel("");
        this._moniker = FILE_MONIKER;
        setAddress(null);
        setShortFilename("");
        this._uninterpretedTail = FILE_TAIL;
    }

    public void newUrlLink() {
        this._range = new CellRangeAddress(0, 0, 0, 0);
        this._guid = STD_MONIKER;
        this._linkOpts = 23;
        setLabel("");
        this._moniker = URL_MONIKER;
        setAddress("");
        this._uninterpretedTail = URL_TAIL;
    }

    @Override // org.apache.poi.hssf.record.StandardRecord
    public void serialize(LittleEndianOutput littleEndianOutput) {
        this._range.serialize(littleEndianOutput);
        this._guid.serialize(littleEndianOutput);
        littleEndianOutput.writeInt(2);
        littleEndianOutput.writeInt(this._linkOpts);
        if ((this._linkOpts & 20) != 0) {
            littleEndianOutput.writeInt(this._label.length());
            StringUtil.putUnicodeLE(this._label, littleEndianOutput);
        }
        if ((this._linkOpts & 128) != 0) {
            littleEndianOutput.writeInt(this._targetFrame.length());
            StringUtil.putUnicodeLE(this._targetFrame, littleEndianOutput);
        }
        int i2 = this._linkOpts;
        if (!((i2 & 1) == 0 || (i2 & 256) == 0)) {
            littleEndianOutput.writeInt(this._address.length());
            StringUtil.putUnicodeLE(this._address, littleEndianOutput);
        }
        int i3 = this._linkOpts;
        if ((i3 & 1) != 0 && (i3 & 256) == 0) {
            this._moniker.serialize(littleEndianOutput);
            if (URL_MONIKER.equals(this._moniker)) {
                if (this._uninterpretedTail == null) {
                    littleEndianOutput.writeInt(this._address.length() * 2);
                    StringUtil.putUnicodeLE(this._address, littleEndianOutput);
                } else {
                    littleEndianOutput.writeInt((this._address.length() * 2) + TAIL_SIZE);
                    StringUtil.putUnicodeLE(this._address, littleEndianOutput);
                    writeTail(this._uninterpretedTail, littleEndianOutput);
                }
            } else if (FILE_MONIKER.equals(this._moniker)) {
                littleEndianOutput.writeShort(this._fileOpts);
                littleEndianOutput.writeInt(this._shortFilename.length());
                StringUtil.putCompressedUnicode(this._shortFilename, littleEndianOutput);
                writeTail(this._uninterpretedTail, littleEndianOutput);
                String str = this._address;
                if (str == null) {
                    littleEndianOutput.writeInt(0);
                } else {
                    int length = str.length() * 2;
                    littleEndianOutput.writeInt(length + 6);
                    littleEndianOutput.writeInt(length);
                    littleEndianOutput.writeShort(3);
                    StringUtil.putUnicodeLE(this._address, littleEndianOutput);
                }
            }
        }
        if ((this._linkOpts & 8) != 0) {
            littleEndianOutput.writeInt(this._textMark.length());
            StringUtil.putUnicodeLE(this._textMark, littleEndianOutput);
        }
    }

    public void setAddress(String str) {
        if ((this._linkOpts & 1) != 0 && FILE_MONIKER.equals(this._moniker)) {
            this._shortFilename = appendNullTerm(str);
        } else if ((this._linkOpts & 8) != 0) {
            this._textMark = appendNullTerm(str);
        } else {
            this._address = appendNullTerm(str);
        }
    }

    public void setFirstColumn(int i2) {
        this._range.setFirstColumn(i2);
    }

    public void setFirstRow(int i2) {
        this._range.setFirstRow(i2);
    }

    public void setLabel(String str) {
        this._label = appendNullTerm(str);
    }

    public void setLastColumn(int i2) {
        this._range.setLastColumn(i2);
    }

    public void setLastRow(int i2) {
        this._range.setLastRow(i2);
    }

    public void setShortFilename(String str) {
        this._shortFilename = appendNullTerm(str);
    }

    public void setTextMark(String str) {
        this._textMark = appendNullTerm(str);
    }

    @Override // org.apache.poi.hssf.record.Record
    public String toString() {
        StringBuffer c = a.c("[HYPERLINK RECORD]\n", "    .range   = ");
        c.append(this._range.formatAsString());
        c.append("\n");
        c.append("    .guid    = ");
        c.append(this._guid.formatAsString());
        c.append("\n");
        c.append("    .linkOpts= ");
        c.append(HexDump.intToHex(this._linkOpts));
        c.append("\n");
        c.append("    .label   = ");
        c.append(getLabel());
        c.append("\n");
        if ((this._linkOpts & 128) != 0) {
            c.append("    .targetFrame= ");
            c.append(getTargetFrame());
            c.append("\n");
        }
        if (!((this._linkOpts & 1) == 0 || this._moniker == null)) {
            c.append("    .moniker   = ");
            c.append(this._moniker.formatAsString());
            c.append("\n");
        }
        if ((this._linkOpts & 8) != 0) {
            c.append("    .textMark= ");
            c.append(getTextMark());
            c.append("\n");
        }
        c.append("    .address   = ");
        c.append(getAddress());
        c.append("\n");
        c.append("[/HYPERLINK RECORD]\n");
        return c.toString();
    }

    public HyperlinkRecord(RecordInputStream recordInputStream) {
        this._range = new CellRangeAddress(recordInputStream);
        this._guid = new GUID(recordInputStream);
        int readInt = recordInputStream.readInt();
        if (readInt == 2) {
            int readInt2 = recordInputStream.readInt();
            this._linkOpts = readInt2;
            if ((readInt2 & 20) != 0) {
                this._label = recordInputStream.readUnicodeLEString(recordInputStream.readInt());
            }
            if ((this._linkOpts & 128) != 0) {
                this._targetFrame = recordInputStream.readUnicodeLEString(recordInputStream.readInt());
            }
            int i2 = this._linkOpts;
            if (!((i2 & 1) == 0 || (i2 & 256) == 0)) {
                this._moniker = null;
                this._address = recordInputStream.readUnicodeLEString(recordInputStream.readInt());
            }
            int i3 = this._linkOpts;
            if ((i3 & 1) != 0 && (i3 & 256) == 0) {
                GUID guid = new GUID(recordInputStream);
                this._moniker = guid;
                if (URL_MONIKER.equals(guid)) {
                    int readInt3 = recordInputStream.readInt();
                    if (readInt3 == recordInputStream.remaining()) {
                        this._address = recordInputStream.readUnicodeLEString(readInt3 / 2);
                    } else {
                        this._address = recordInputStream.readUnicodeLEString((readInt3 - TAIL_SIZE) / 2);
                        this._uninterpretedTail = readTail(URL_TAIL, recordInputStream);
                    }
                } else if (FILE_MONIKER.equals(this._moniker)) {
                    this._fileOpts = recordInputStream.readShort();
                    this._shortFilename = StringUtil.readCompressedUnicode(recordInputStream, recordInputStream.readInt());
                    this._uninterpretedTail = readTail(FILE_TAIL, recordInputStream);
                    if (recordInputStream.readInt() > 0) {
                        int readInt4 = recordInputStream.readInt();
                        recordInputStream.readUShort();
                        this._address = StringUtil.readUnicodeLE(recordInputStream, readInt4 / 2);
                    } else {
                        this._address = null;
                    }
                } else if (STD_MONIKER.equals(this._moniker)) {
                    this._fileOpts = recordInputStream.readShort();
                    byte[] bArr = new byte[recordInputStream.readInt()];
                    recordInputStream.readFully(bArr);
                    this._address = new String(bArr, StringUtil.UTF8);
                }
            }
            if ((this._linkOpts & 8) != 0) {
                this._textMark = recordInputStream.readUnicodeLEString(recordInputStream.readInt());
            }
            if (recordInputStream.remaining() > 0) {
                POILogger pOILogger = logger;
                StringBuilder b2 = a.b("Hyperlink data remains: ");
                b2.append(recordInputStream.remaining());
                b2.append(" : ");
                b2.append(HexDump.toHex(recordInputStream.readRemainder()));
                pOILogger.log(5, b2.toString());
                return;
            }
            return;
        }
        throw new RecordFormatException(a.c("Stream Version must be 0x2 but found ", readInt));
    }

    @Override // org.apache.poi.hssf.record.Record, java.lang.Object
    public HyperlinkRecord clone() {
        HyperlinkRecord hyperlinkRecord = new HyperlinkRecord();
        hyperlinkRecord._range = this._range.copy();
        hyperlinkRecord._guid = this._guid;
        hyperlinkRecord._linkOpts = this._linkOpts;
        hyperlinkRecord._fileOpts = this._fileOpts;
        hyperlinkRecord._label = this._label;
        hyperlinkRecord._address = this._address;
        hyperlinkRecord._moniker = this._moniker;
        hyperlinkRecord._shortFilename = this._shortFilename;
        hyperlinkRecord._targetFrame = this._targetFrame;
        hyperlinkRecord._textMark = this._textMark;
        hyperlinkRecord._uninterpretedTail = this._uninterpretedTail;
        return hyperlinkRecord;
    }
}
