package org.apache.poi.hssf.record;

import b.b.a.a.a;
import org.apache.poi.util.IntList;
import org.apache.poi.util.LittleEndianOutput;
import org.apache.poi.util.RecordFormatException;

public final class IndexRecord extends StandardRecord implements Cloneable {
    public static final short sid = 523;
    public int field_2_first_row;
    public int field_3_last_row_add1;
    public int field_4_zero;
    public IntList field_5_dbcells;

    public IndexRecord() {
    }

    public static int getRecordSizeForBlockCount(int i2) {
        return (i2 * 4) + 20;
    }

    public void addDbcell(int i2) {
        if (this.field_5_dbcells == null) {
            this.field_5_dbcells = new IntList();
        }
        this.field_5_dbcells.add(i2);
    }

    @Override // org.apache.poi.hssf.record.StandardRecord
    public int getDataSize() {
        return (getNumDbcells() * 4) + 16;
    }

    public int getDbcellAt(int i2) {
        return this.field_5_dbcells.get(i2);
    }

    public int getFirstRow() {
        return this.field_2_first_row;
    }

    public int getLastRowAdd1() {
        return this.field_3_last_row_add1;
    }

    public int getNumDbcells() {
        IntList intList = this.field_5_dbcells;
        if (intList == null) {
            return 0;
        }
        return intList.size();
    }

    @Override // org.apache.poi.hssf.record.Record
    public short getSid() {
        return 523;
    }

    @Override // org.apache.poi.hssf.record.StandardRecord
    public void serialize(LittleEndianOutput littleEndianOutput) {
        littleEndianOutput.writeInt(0);
        littleEndianOutput.writeInt(getFirstRow());
        littleEndianOutput.writeInt(getLastRowAdd1());
        littleEndianOutput.writeInt(this.field_4_zero);
        for (int i2 = 0; i2 < getNumDbcells(); i2++) {
            littleEndianOutput.writeInt(getDbcellAt(i2));
        }
    }

    public void setDbcell(int i2, int i3) {
        this.field_5_dbcells.set(i2, i3);
    }

    public void setFirstRow(int i2) {
        this.field_2_first_row = i2;
    }

    public void setLastRowAdd1(int i2) {
        this.field_3_last_row_add1 = i2;
    }

    @Override // org.apache.poi.hssf.record.Record
    public String toString() {
        StringBuffer c = a.c("[INDEX]\n", "    .firstrow       = ");
        c.append(Integer.toHexString(getFirstRow()));
        c.append("\n");
        c.append("    .lastrowadd1    = ");
        c.append(Integer.toHexString(getLastRowAdd1()));
        c.append("\n");
        for (int i2 = 0; i2 < getNumDbcells(); i2++) {
            c.append("    .dbcell_");
            c.append(i2);
            c.append(" = ");
            c.append(Integer.toHexString(getDbcellAt(i2)));
            c.append("\n");
        }
        c.append("[/INDEX]\n");
        return c.toString();
    }

    public IndexRecord(RecordInputStream recordInputStream) {
        int readInt = recordInputStream.readInt();
        if (readInt == 0) {
            this.field_2_first_row = recordInputStream.readInt();
            this.field_3_last_row_add1 = recordInputStream.readInt();
            this.field_4_zero = recordInputStream.readInt();
            int remaining = recordInputStream.remaining() / 4;
            this.field_5_dbcells = new IntList(remaining);
            for (int i2 = 0; i2 < remaining; i2++) {
                this.field_5_dbcells.add(recordInputStream.readInt());
            }
            return;
        }
        throw new RecordFormatException(a.c("Expected zero for field 1 but got ", readInt));
    }

    @Override // org.apache.poi.hssf.record.Record, java.lang.Object
    public IndexRecord clone() {
        IndexRecord indexRecord = new IndexRecord();
        indexRecord.field_2_first_row = this.field_2_first_row;
        indexRecord.field_3_last_row_add1 = this.field_3_last_row_add1;
        indexRecord.field_4_zero = this.field_4_zero;
        IntList intList = new IntList();
        indexRecord.field_5_dbcells = intList;
        intList.addAll(this.field_5_dbcells);
        return indexRecord;
    }
}
