package org.apache.poi.hssf.record;

import b.b.a.a.a;
import org.apache.poi.util.HexDump;
import org.apache.poi.util.POILogFactory;
import org.apache.poi.util.POILogger;
import org.apache.poi.util.RecordFormatException;

public final class LabelRecord extends Record implements CellValueRecordInterface, Cloneable {
    public static final POILogger logger = POILogFactory.getLogger(LabelRecord.class);
    public static final short sid = 516;
    public int field_1_row;
    public short field_2_column;
    public short field_3_xf_index;
    public short field_4_string_len;
    public byte field_5_unicode_flag;
    public String field_6_value;

    public LabelRecord() {
    }

    @Override // org.apache.poi.hssf.record.CellValueRecordInterface
    public short getColumn() {
        return this.field_2_column;
    }

    @Override // org.apache.poi.hssf.record.RecordBase
    public int getRecordSize() {
        throw new RecordFormatException("Label Records are supported READ ONLY...convert to LabelSST");
    }

    @Override // org.apache.poi.hssf.record.CellValueRecordInterface
    public int getRow() {
        return this.field_1_row;
    }

    @Override // org.apache.poi.hssf.record.Record
    public short getSid() {
        return 516;
    }

    public short getStringLength() {
        return this.field_4_string_len;
    }

    public String getValue() {
        return this.field_6_value;
    }

    @Override // org.apache.poi.hssf.record.CellValueRecordInterface
    public short getXFIndex() {
        return this.field_3_xf_index;
    }

    public boolean isUnCompressedUnicode() {
        return (this.field_5_unicode_flag & 1) != 0;
    }

    @Override // org.apache.poi.hssf.record.RecordBase
    public int serialize(int i2, byte[] bArr) {
        throw new RecordFormatException("Label Records are supported READ ONLY...convert to LabelSST");
    }

    @Override // org.apache.poi.hssf.record.CellValueRecordInterface
    public void setColumn(short s) {
    }

    @Override // org.apache.poi.hssf.record.CellValueRecordInterface
    public void setRow(int i2) {
    }

    @Override // org.apache.poi.hssf.record.CellValueRecordInterface
    public void setXFIndex(short s) {
    }

    @Override // org.apache.poi.hssf.record.Record
    public String toString() {
        StringBuffer c = a.c("[LABEL]\n", "    .row       = ");
        c.append(HexDump.shortToHex(getRow()));
        c.append("\n");
        c.append("    .column    = ");
        c.append(HexDump.shortToHex(getColumn()));
        c.append("\n");
        c.append("    .xfindex   = ");
        c.append(HexDump.shortToHex(getXFIndex()));
        c.append("\n");
        c.append("    .string_len= ");
        a.a(this.field_4_string_len, c, "\n", "    .unicode_flag= ");
        c.append(HexDump.byteToHex(this.field_5_unicode_flag));
        c.append("\n");
        c.append("    .value       = ");
        c.append(getValue());
        c.append("\n");
        c.append("[/LABEL]\n");
        return c.toString();
    }

    public LabelRecord(RecordInputStream recordInputStream) {
        this.field_1_row = recordInputStream.readUShort();
        this.field_2_column = recordInputStream.readShort();
        this.field_3_xf_index = recordInputStream.readShort();
        this.field_4_string_len = recordInputStream.readShort();
        this.field_5_unicode_flag = recordInputStream.readByte();
        if (this.field_4_string_len <= 0) {
            this.field_6_value = "";
        } else if (isUnCompressedUnicode()) {
            this.field_6_value = recordInputStream.readUnicodeLEString(this.field_4_string_len);
        } else {
            this.field_6_value = recordInputStream.readCompressedUnicode(this.field_4_string_len);
        }
        if (recordInputStream.remaining() > 0) {
            POILogger pOILogger = logger;
            StringBuilder b2 = a.b("LabelRecord data remains: ");
            b2.append(recordInputStream.remaining());
            b2.append(" : ");
            b2.append(HexDump.toHex(recordInputStream.readRemainder()));
            pOILogger.log(3, b2.toString());
        }
    }

    @Override // org.apache.poi.hssf.record.Record, java.lang.Object
    public LabelRecord clone() {
        LabelRecord labelRecord = new LabelRecord();
        labelRecord.field_1_row = this.field_1_row;
        labelRecord.field_2_column = this.field_2_column;
        labelRecord.field_3_xf_index = this.field_3_xf_index;
        labelRecord.field_4_string_len = this.field_4_string_len;
        labelRecord.field_5_unicode_flag = this.field_5_unicode_flag;
        labelRecord.field_6_value = this.field_6_value;
        return labelRecord;
    }
}
