package org.apache.poi.hssf.record;

import b.b.a.a.a;
import org.apache.poi.ss.util.CellRangeAddress;
import org.apache.poi.ss.util.CellRangeAddressList;
import org.apache.poi.util.LittleEndianOutput;

public final class MergeCellsRecord extends StandardRecord implements Cloneable {
    public static final short sid = 229;
    public final int _numberOfRegions;
    public final CellRangeAddress[] _regions;
    public final int _startIndex;

    public MergeCellsRecord(CellRangeAddress[] cellRangeAddressArr, int i2, int i3) {
        this._regions = cellRangeAddressArr;
        this._startIndex = i2;
        this._numberOfRegions = i3;
    }

    public CellRangeAddress getAreaAt(int i2) {
        return this._regions[this._startIndex + i2];
    }

    @Override // org.apache.poi.hssf.record.StandardRecord
    public int getDataSize() {
        return CellRangeAddressList.getEncodedSize(this._numberOfRegions);
    }

    public short getNumAreas() {
        return (short) this._numberOfRegions;
    }

    @Override // org.apache.poi.hssf.record.Record
    public short getSid() {
        return sid;
    }

    @Override // org.apache.poi.hssf.record.StandardRecord
    public void serialize(LittleEndianOutput littleEndianOutput) {
        littleEndianOutput.writeShort(this._numberOfRegions);
        for (int i2 = 0; i2 < this._numberOfRegions; i2++) {
            this._regions[this._startIndex + i2].serialize(littleEndianOutput);
        }
    }

    @Override // org.apache.poi.hssf.record.Record
    public String toString() {
        StringBuffer c = a.c("[MERGEDCELLS]", "\n", "     .numregions =");
        c.append((int) getNumAreas());
        c.append("\n");
        for (int i2 = 0; i2 < this._numberOfRegions; i2++) {
            CellRangeAddress cellRangeAddress = this._regions[this._startIndex + i2];
            c.append("     .rowfrom =");
            c.append(cellRangeAddress.getFirstRow());
            c.append("\n");
            c.append("     .rowto   =");
            c.append(cellRangeAddress.getLastRow());
            c.append("\n");
            c.append("     .colfrom =");
            c.append(cellRangeAddress.getFirstColumn());
            c.append("\n");
            c.append("     .colto   =");
            c.append(cellRangeAddress.getLastColumn());
            c.append("\n");
        }
        return a.a(c, "[MERGEDCELLS]", "\n");
    }

    @Override // org.apache.poi.hssf.record.Record, java.lang.Object
    public MergeCellsRecord clone() {
        int i2 = this._numberOfRegions;
        CellRangeAddress[] cellRangeAddressArr = new CellRangeAddress[i2];
        for (int i3 = 0; i3 < i2; i3++) {
            cellRangeAddressArr[i3] = this._regions[this._startIndex + i3].copy();
        }
        return new MergeCellsRecord(cellRangeAddressArr, 0, i2);
    }

    public MergeCellsRecord(RecordInputStream recordInputStream) {
        int readUShort = recordInputStream.readUShort();
        CellRangeAddress[] cellRangeAddressArr = new CellRangeAddress[readUShort];
        for (int i2 = 0; i2 < readUShort; i2++) {
            cellRangeAddressArr[i2] = new CellRangeAddress(recordInputStream);
        }
        this._numberOfRegions = readUShort;
        this._startIndex = 0;
        this._regions = cellRangeAddressArr;
    }
}
