package org.apache.poi.hssf.record;

import b.b.a.a.a;
import org.apache.poi.util.LittleEndianOutput;

public final class MulBlankRecord extends StandardRecord {
    public static final short sid = 190;
    public final int _firstCol;
    public final int _lastCol;
    public final int _row;
    public final short[] _xfs;

    public MulBlankRecord(int i2, int i3, short[] sArr) {
        this._row = i2;
        this._firstCol = i3;
        this._xfs = sArr;
        this._lastCol = (i3 + sArr.length) - 1;
    }

    public static short[] parseXFs(RecordInputStream recordInputStream) {
        int remaining = (recordInputStream.remaining() - 2) / 2;
        short[] sArr = new short[remaining];
        for (int i2 = 0; i2 < remaining; i2++) {
            sArr[i2] = recordInputStream.readShort();
        }
        return sArr;
    }

    @Override // org.apache.poi.hssf.record.Record
    public MulBlankRecord clone() {
        return this;
    }

    @Override // org.apache.poi.hssf.record.StandardRecord
    public int getDataSize() {
        return (this._xfs.length * 2) + 6;
    }

    public int getFirstColumn() {
        return this._firstCol;
    }

    public int getLastColumn() {
        return this._lastCol;
    }

    public int getNumColumns() {
        return (this._lastCol - this._firstCol) + 1;
    }

    public int getRow() {
        return this._row;
    }

    @Override // org.apache.poi.hssf.record.Record
    public short getSid() {
        return 190;
    }

    public short getXFAt(int i2) {
        return this._xfs[i2];
    }

    @Override // org.apache.poi.hssf.record.StandardRecord
    public void serialize(LittleEndianOutput littleEndianOutput) {
        littleEndianOutput.writeShort(this._row);
        littleEndianOutput.writeShort(this._firstCol);
        int length = this._xfs.length;
        for (int i2 = 0; i2 < length; i2++) {
            littleEndianOutput.writeShort(this._xfs[i2]);
        }
        littleEndianOutput.writeShort(this._lastCol);
    }

    @Override // org.apache.poi.hssf.record.Record
    public String toString() {
        StringBuffer c = a.c("[MULBLANK]\n", "row  = ");
        c.append(Integer.toHexString(getRow()));
        c.append("\n");
        c.append("firstcol  = ");
        c.append(Integer.toHexString(getFirstColumn()));
        c.append("\n");
        c.append(" lastcol  = ");
        c.append(Integer.toHexString(this._lastCol));
        c.append("\n");
        for (int i2 = 0; i2 < getNumColumns(); i2++) {
            c.append("xf");
            c.append(i2);
            c.append("\t\t= ");
            c.append(Integer.toHexString(getXFAt(i2)));
            c.append("\n");
        }
        c.append("[/MULBLANK]\n");
        return c.toString();
    }

    public MulBlankRecord(RecordInputStream recordInputStream) {
        this._row = recordInputStream.readUShort();
        this._firstCol = recordInputStream.readShort();
        this._xfs = parseXFs(recordInputStream);
        this._lastCol = recordInputStream.readShort();
    }
}
