package org.apache.poi.hssf.record;

import b.b.a.a.a;
import org.apache.poi.hssf.util.RKUtil;
import org.apache.poi.util.HexDump;
import org.apache.poi.util.LittleEndianOutput;
import org.apache.poi.util.RecordFormatException;

public final class MulRKRecord extends StandardRecord {
    public static final short sid = 189;
    public final int field_1_row;
    public final short field_2_first_col;
    public final RkRec[] field_3_rks;
    public final short field_4_last_col;

    public static final class RkRec {
        public static final int ENCODED_SIZE = 6;
        public final int rk;
        public final short xf;

        public RkRec(RecordInputStream recordInputStream) {
            this.xf = recordInputStream.readShort();
            this.rk = recordInputStream.readInt();
        }

        public static RkRec[] parseRKs(RecordInputStream recordInputStream) {
            int remaining = (recordInputStream.remaining() - 2) / 6;
            RkRec[] rkRecArr = new RkRec[remaining];
            for (int i2 = 0; i2 < remaining; i2++) {
                rkRecArr[i2] = new RkRec(recordInputStream);
            }
            return rkRecArr;
        }
    }

    public MulRKRecord(RecordInputStream recordInputStream) {
        this.field_1_row = recordInputStream.readUShort();
        this.field_2_first_col = recordInputStream.readShort();
        this.field_3_rks = RkRec.parseRKs(recordInputStream);
        this.field_4_last_col = recordInputStream.readShort();
    }

    @Override // org.apache.poi.hssf.record.StandardRecord
    public int getDataSize() {
        throw new RecordFormatException("Sorry, you can't serialize MulRK in this release");
    }

    public short getFirstColumn() {
        return this.field_2_first_col;
    }

    public short getLastColumn() {
        return this.field_4_last_col;
    }

    public int getNumColumns() {
        return (this.field_4_last_col - this.field_2_first_col) + 1;
    }

    public double getRKNumberAt(int i2) {
        return RKUtil.decodeNumber(this.field_3_rks[i2].rk);
    }

    public int getRow() {
        return this.field_1_row;
    }

    @Override // org.apache.poi.hssf.record.Record
    public short getSid() {
        return 189;
    }

    public short getXFAt(int i2) {
        return this.field_3_rks[i2].xf;
    }

    @Override // org.apache.poi.hssf.record.StandardRecord
    public void serialize(LittleEndianOutput littleEndianOutput) {
        throw new RecordFormatException("Sorry, you can't serialize MulRK in this release");
    }

    @Override // org.apache.poi.hssf.record.Record
    public String toString() {
        StringBuffer c = a.c("[MULRK]\n", "\t.row\t = ");
        c.append(HexDump.shortToHex(getRow()));
        c.append("\n");
        c.append("\t.firstcol= ");
        c.append(HexDump.shortToHex(getFirstColumn()));
        c.append("\n");
        c.append("\t.lastcol = ");
        c.append(HexDump.shortToHex(getLastColumn()));
        c.append("\n");
        for (int i2 = 0; i2 < getNumColumns(); i2++) {
            c.append("\txf[");
            c.append(i2);
            c.append("] = ");
            c.append(HexDump.shortToHex(getXFAt(i2)));
            c.append("\n");
            c.append("\trk[");
            c.append(i2);
            c.append("] = ");
            c.append(getRKNumberAt(i2));
            c.append("\n");
        }
        c.append("[/MULRK]\n");
        return c.toString();
    }
}
