package org.apache.poi.hssf.record;

import b.b.a.a.a;
import org.apache.poi.util.LittleEndianOutput;
import org.apache.poi.util.StringUtil;

public final class NoteRecord extends StandardRecord implements Cloneable {
    public static final Byte DEFAULT_PADDING = (byte) 0;
    public static final NoteRecord[] EMPTY_ARRAY = new NoteRecord[0];
    public static final short NOTE_HIDDEN = 0;
    public static final short NOTE_VISIBLE = 2;
    public static final short sid = 28;
    public int field_1_row;
    public int field_2_col;
    public short field_3_flags;
    public int field_4_shapeid;
    public boolean field_5_hasMultibyte;
    public String field_6_author;
    public Byte field_7_padding;

    public NoteRecord() {
        this.field_6_author = "";
        this.field_3_flags = 0;
        this.field_7_padding = DEFAULT_PADDING;
    }

    public boolean authorIsMultibyte() {
        return this.field_5_hasMultibyte;
    }

    public String getAuthor() {
        return this.field_6_author;
    }

    public int getColumn() {
        return this.field_2_col;
    }

    @Override // org.apache.poi.hssf.record.StandardRecord
    public int getDataSize() {
        int i2 = 1;
        int length = (this.field_6_author.length() * (this.field_5_hasMultibyte ? 2 : 1)) + 11;
        if (this.field_7_padding == null) {
            i2 = 0;
        }
        return length + i2;
    }

    public short getFlags() {
        return this.field_3_flags;
    }

    public int getRow() {
        return this.field_1_row;
    }

    public int getShapeId() {
        return this.field_4_shapeid;
    }

    @Override // org.apache.poi.hssf.record.Record
    public short getSid() {
        return 28;
    }

    @Override // org.apache.poi.hssf.record.StandardRecord
    public void serialize(LittleEndianOutput littleEndianOutput) {
        littleEndianOutput.writeShort(this.field_1_row);
        littleEndianOutput.writeShort(this.field_2_col);
        littleEndianOutput.writeShort(this.field_3_flags);
        littleEndianOutput.writeShort(this.field_4_shapeid);
        littleEndianOutput.writeShort(this.field_6_author.length());
        littleEndianOutput.writeByte(this.field_5_hasMultibyte ? 1 : 0);
        if (this.field_5_hasMultibyte) {
            StringUtil.putUnicodeLE(this.field_6_author, littleEndianOutput);
        } else {
            StringUtil.putCompressedUnicode(this.field_6_author, littleEndianOutput);
        }
        Byte b2 = this.field_7_padding;
        if (b2 != null) {
            littleEndianOutput.writeByte(b2.intValue());
        }
    }

    public void setAuthor(String str) {
        this.field_6_author = str;
        this.field_5_hasMultibyte = StringUtil.hasMultibyte(str);
    }

    public void setColumn(int i2) {
        this.field_2_col = i2;
    }

    public void setFlags(short s) {
        this.field_3_flags = s;
    }

    public void setRow(int i2) {
        this.field_1_row = i2;
    }

    public void setShapeId(int i2) {
        this.field_4_shapeid = i2;
    }

    @Override // org.apache.poi.hssf.record.Record
    public String toString() {
        StringBuffer c = a.c("[NOTE]\n", "    .row    = ");
        c.append(this.field_1_row);
        c.append("\n");
        c.append("    .col    = ");
        c.append(this.field_2_col);
        c.append("\n");
        c.append("    .flags  = ");
        c.append((int) this.field_3_flags);
        c.append("\n");
        c.append("    .shapeid= ");
        c.append(this.field_4_shapeid);
        c.append("\n");
        c.append("    .author = ");
        c.append(this.field_6_author);
        c.append("\n");
        c.append("[/NOTE]\n");
        return c.toString();
    }

    @Override // org.apache.poi.hssf.record.Record, java.lang.Object
    public NoteRecord clone() {
        NoteRecord noteRecord = new NoteRecord();
        noteRecord.field_1_row = this.field_1_row;
        noteRecord.field_2_col = this.field_2_col;
        noteRecord.field_3_flags = this.field_3_flags;
        noteRecord.field_4_shapeid = this.field_4_shapeid;
        noteRecord.field_6_author = this.field_6_author;
        return noteRecord;
    }

    public NoteRecord(RecordInputStream recordInputStream) {
        this.field_1_row = recordInputStream.readUShort();
        this.field_2_col = recordInputStream.readShort();
        this.field_3_flags = recordInputStream.readShort();
        this.field_4_shapeid = recordInputStream.readUShort();
        short readShort = recordInputStream.readShort();
        boolean z = recordInputStream.readByte() != 0;
        this.field_5_hasMultibyte = z;
        if (z) {
            this.field_6_author = StringUtil.readUnicodeLE(recordInputStream, readShort);
        } else {
            this.field_6_author = StringUtil.readCompressedUnicode(recordInputStream, readShort);
        }
        if (recordInputStream.available() == 1) {
            this.field_7_padding = Byte.valueOf(recordInputStream.readByte());
        } else if (recordInputStream.available() == 2 && readShort == 0) {
            this.field_7_padding = Byte.valueOf(recordInputStream.readByte());
            recordInputStream.readByte();
        }
    }
}
