package org.apache.poi.hssf.record;

import b.b.a.a.a;
import org.apache.poi.util.HexDump;
import org.apache.poi.util.LittleEndianInput;
import org.apache.poi.util.LittleEndianOutput;
import org.apache.poi.util.RecordFormatException;

public final class NoteStructureSubRecord extends SubRecord implements Cloneable {
    public static final int ENCODED_SIZE = 22;
    public static final short sid = 13;
    public byte[] reserved;

    public NoteStructureSubRecord() {
        this.reserved = new byte[22];
    }

    @Override // org.apache.poi.hssf.record.SubRecord
    public int getDataSize() {
        return this.reserved.length;
    }

    public short getSid() {
        return 13;
    }

    @Override // org.apache.poi.hssf.record.SubRecord
    public void serialize(LittleEndianOutput littleEndianOutput) {
        littleEndianOutput.writeShort(13);
        littleEndianOutput.writeShort(this.reserved.length);
        littleEndianOutput.write(this.reserved);
    }

    public String toString() {
        StringBuffer c = a.c("[ftNts ]", "\n", "  size     = ");
        c.append(getDataSize());
        c.append("\n");
        c.append("  reserved = ");
        c.append(HexDump.toHex(this.reserved));
        c.append("\n");
        c.append("[/ftNts ]");
        c.append("\n");
        return c.toString();
    }

    public NoteStructureSubRecord(LittleEndianInput littleEndianInput, int i2) {
        if (i2 == 22) {
            byte[] bArr = new byte[i2];
            littleEndianInput.readFully(bArr);
            this.reserved = bArr;
            return;
        }
        throw new RecordFormatException(a.b("Unexpected size (", i2, ")"));
    }

    @Override // org.apache.poi.hssf.record.SubRecord, org.apache.poi.hssf.record.SubRecord, java.lang.Object
    public NoteStructureSubRecord clone() {
        NoteStructureSubRecord noteStructureSubRecord = new NoteStructureSubRecord();
        byte[] bArr = this.reserved;
        int length = bArr.length;
        byte[] bArr2 = new byte[length];
        System.arraycopy(bArr, 0, bArr2, 0, length);
        noteStructureSubRecord.reserved = bArr2;
        return noteStructureSubRecord;
    }
}
