package org.apache.poi.hssf.record;

import b.b.a.a.a;
import java.io.ByteArrayInputStream;
import java.util.ArrayList;
import java.util.List;
import org.apache.poi.util.HexDump;
import org.apache.poi.util.LittleEndian;
import org.apache.poi.util.LittleEndianByteArrayOutputStream;
import org.apache.poi.util.LittleEndianInputStream;
import org.apache.poi.util.RecordFormatException;

public final class ObjRecord extends Record implements Cloneable {
    public static int MAX_PAD_ALIGNMENT = 4;
    public static final int NORMAL_PAD_ALIGNMENT = 2;
    public static final short sid = 93;
    public boolean _isPaddedToQuadByteMultiple;
    public final byte[] _uninterpretedData;
    public List<SubRecord> subrecords;

    public ObjRecord() {
        this.subrecords = new ArrayList(2);
        this._uninterpretedData = null;
    }

    public static boolean canPaddingBeDiscarded(byte[] bArr, int i2) {
        for (int length = bArr.length - i2; length < bArr.length; length++) {
            if (bArr[length] != 0) {
                return false;
            }
        }
        return true;
    }

    public void addSubRecord(int i2, SubRecord subRecord) {
        this.subrecords.add(i2, subRecord);
    }

    public void clearSubRecords() {
        this.subrecords.clear();
    }

    @Override // org.apache.poi.hssf.record.RecordBase
    public int getRecordSize() {
        byte[] bArr = this._uninterpretedData;
        if (bArr != null) {
            return bArr.length + 4;
        }
        int i2 = 0;
        for (SubRecord subRecord : this.subrecords) {
            i2 += subRecord.getDataSize() + 4;
        }
        if (this._isPaddedToQuadByteMultiple) {
            while (i2 % MAX_PAD_ALIGNMENT != 0) {
                i2++;
            }
        } else {
            while (i2 % 2 != 0) {
                i2++;
            }
        }
        return i2 + 4;
    }

    @Override // org.apache.poi.hssf.record.Record
    public short getSid() {
        return 93;
    }

    public List<SubRecord> getSubRecords() {
        return this.subrecords;
    }

    @Override // org.apache.poi.hssf.record.RecordBase
    public int serialize(int i2, byte[] bArr) {
        int recordSize = getRecordSize();
        int i3 = recordSize - 4;
        LittleEndianByteArrayOutputStream littleEndianByteArrayOutputStream = new LittleEndianByteArrayOutputStream(bArr, i2, recordSize);
        littleEndianByteArrayOutputStream.writeShort(93);
        littleEndianByteArrayOutputStream.writeShort(i3);
        byte[] bArr2 = this._uninterpretedData;
        if (bArr2 == null) {
            for (int i4 = 0; i4 < this.subrecords.size(); i4++) {
                this.subrecords.get(i4).serialize(littleEndianByteArrayOutputStream);
            }
            int i5 = i2 + i3;
            while (littleEndianByteArrayOutputStream.getWriteIndex() < i5) {
                littleEndianByteArrayOutputStream.writeByte(0);
            }
        } else {
            littleEndianByteArrayOutputStream.write(bArr2);
        }
        return recordSize;
    }

    @Override // org.apache.poi.hssf.record.Record
    public String toString() {
        StringBuffer a = a.a("[OBJ]\n");
        List<SubRecord> list = this.subrecords;
        if (list != null) {
            for (SubRecord subRecord : list) {
                a.append("SUBRECORD: ");
                a.append(subRecord);
            }
        }
        a.append("[/OBJ]\n");
        return a.toString();
    }

    public boolean addSubRecord(SubRecord subRecord) {
        return this.subrecords.add(subRecord);
    }

    @Override // org.apache.poi.hssf.record.Record, java.lang.Object
    public ObjRecord clone() {
        ObjRecord objRecord = new ObjRecord();
        for (SubRecord subRecord : this.subrecords) {
            objRecord.addSubRecord(subRecord.clone());
        }
        return objRecord;
    }

    public ObjRecord(RecordInputStream recordInputStream) {
        SubRecord createSubRecord;
        byte[] readRemainder = recordInputStream.readRemainder();
        if (LittleEndian.getUShort(readRemainder, 0) != 21) {
            this._uninterpretedData = readRemainder;
            this.subrecords = null;
            return;
        }
        this.subrecords = new ArrayList();
        ByteArrayInputStream byteArrayInputStream = new ByteArrayInputStream(readRemainder);
        LittleEndianInputStream littleEndianInputStream = new LittleEndianInputStream(byteArrayInputStream);
        CommonObjectDataSubRecord commonObjectDataSubRecord = (CommonObjectDataSubRecord) SubRecord.createSubRecord(littleEndianInputStream, 0);
        this.subrecords.add(commonObjectDataSubRecord);
        do {
            createSubRecord = SubRecord.createSubRecord(littleEndianInputStream, commonObjectDataSubRecord.getObjectType());
            this.subrecords.add(createSubRecord);
        } while (!createSubRecord.isTerminating());
        int available = byteArrayInputStream.available();
        if (available > 0) {
            boolean z = readRemainder.length % MAX_PAD_ALIGNMENT == 0;
            this._isPaddedToQuadByteMultiple = z;
            if (available >= (z ? MAX_PAD_ALIGNMENT : 2)) {
                if (canPaddingBeDiscarded(readRemainder, available)) {
                    this._isPaddedToQuadByteMultiple = false;
                } else {
                    StringBuilder a = a.a("Leftover ", available, " bytes in subrecord data ");
                    a.append(HexDump.toHex(readRemainder));
                    throw new RecordFormatException(a.toString());
                }
            }
        } else {
            this._isPaddedToQuadByteMultiple = false;
        }
        this._uninterpretedData = null;
    }
}
