package org.apache.poi.hssf.record;

import java.util.ArrayList;
import java.util.HashMap;
import java.util.Iterator;
import java.util.List;
import java.util.Map;
import org.apache.poi.util.LittleEndianOutput;
import org.apache.xmlbeans.impl.jam.xml.JamXmlElements;

public abstract class PageBreakRecord extends StandardRecord {
    public static final int[] EMPTY_INT_ARRAY = new int[0];
    public Map<Integer, Break> _breakMap;
    public List<Break> _breaks;

    public PageBreakRecord() {
        this._breaks = new ArrayList();
        this._breakMap = new HashMap();
    }

    public void addBreak(int i2, int i3, int i4) {
        Integer valueOf = Integer.valueOf(i2);
        Break r1 = this._breakMap.get(valueOf);
        if (r1 == null) {
            Break r12 = new Break(i2, i3, i4);
            this._breakMap.put(valueOf, r12);
            this._breaks.add(r12);
            return;
        }
        r1.main = i2;
        r1.subFrom = i3;
        r1.subTo = i4;
    }

    public final Break getBreak(int i2) {
        return this._breakMap.get(Integer.valueOf(i2));
    }

    public final int[] getBreaks() {
        int numBreaks = getNumBreaks();
        if (numBreaks < 1) {
            return EMPTY_INT_ARRAY;
        }
        int[] iArr = new int[numBreaks];
        for (int i2 = 0; i2 < numBreaks; i2++) {
            iArr[i2] = this._breaks.get(i2).main;
        }
        return iArr;
    }

    public final Iterator<Break> getBreaksIterator() {
        return this._breaks.iterator();
    }

    @Override // org.apache.poi.hssf.record.StandardRecord
    public int getDataSize() {
        return (this._breaks.size() * 6) + 2;
    }

    public int getNumBreaks() {
        return this._breaks.size();
    }

    public boolean isEmpty() {
        return this._breaks.isEmpty();
    }

    public final void removeBreak(int i2) {
        Integer valueOf = Integer.valueOf(i2);
        this._breaks.remove(this._breakMap.get(valueOf));
        this._breakMap.remove(valueOf);
    }

    @Override // org.apache.poi.hssf.record.StandardRecord
    public final void serialize(LittleEndianOutput littleEndianOutput) {
        int size = this._breaks.size();
        littleEndianOutput.writeShort(size);
        for (int i2 = 0; i2 < size; i2++) {
            this._breaks.get(i2).serialize(littleEndianOutput);
        }
    }

    @Override // org.apache.poi.hssf.record.Record
    public String toString() {
        String str;
        String str2;
        StringBuffer stringBuffer = new StringBuffer();
        String str3 = "row";
        if (getSid() == 27) {
            str2 = "HORIZONTALPAGEBREAK";
            str = "col";
        } else {
            str2 = "VERTICALPAGEBREAK";
            str = str3;
            str3 = JamXmlElements.COLUMN;
        }
        stringBuffer.append("[" + str2 + "]");
        stringBuffer.append("\n");
        stringBuffer.append("     .sid        =");
        stringBuffer.append((int) getSid());
        stringBuffer.append("\n");
        stringBuffer.append("     .numbreaks =");
        stringBuffer.append(getNumBreaks());
        stringBuffer.append("\n");
        Iterator<Break> breaksIterator = getBreaksIterator();
        for (int i2 = 0; i2 < getNumBreaks(); i2++) {
            Break next = breaksIterator.next();
            stringBuffer.append("     .");
            stringBuffer.append(str3);
            stringBuffer.append(" (zero-based) =");
            stringBuffer.append(next.main);
            stringBuffer.append("\n");
            stringBuffer.append("     .");
            stringBuffer.append(str);
            stringBuffer.append("From    =");
            stringBuffer.append(next.subFrom);
            stringBuffer.append("\n");
            stringBuffer.append("     .");
            stringBuffer.append(str);
            stringBuffer.append("To      =");
            stringBuffer.append(next.subTo);
            stringBuffer.append("\n");
        }
        stringBuffer.append("[" + str2 + "]");
        stringBuffer.append("\n");
        return stringBuffer.toString();
    }

    public static final class Break {
        public static final int ENCODED_SIZE = 6;
        public int main;
        public int subFrom;
        public int subTo;

        public Break(int i2, int i3, int i4) {
            this.main = i2;
            this.subFrom = i3;
            this.subTo = i4;
        }

        public void serialize(LittleEndianOutput littleEndianOutput) {
            littleEndianOutput.writeShort(this.main + 1);
            littleEndianOutput.writeShort(this.subFrom);
            littleEndianOutput.writeShort(this.subTo);
        }

        public Break(RecordInputStream recordInputStream) {
            this.main = recordInputStream.readUShort() - 1;
            this.subFrom = recordInputStream.readUShort();
            this.subTo = recordInputStream.readUShort();
        }
    }

    public PageBreakRecord(RecordInputStream recordInputStream) {
        short readShort = recordInputStream.readShort();
        this._breaks = new ArrayList(readShort + 2);
        this._breakMap = new HashMap();
        for (int i2 = 0; i2 < readShort; i2++) {
            Break r2 = new Break(recordInputStream);
            this._breaks.add(r2);
            this._breakMap.put(Integer.valueOf(r2.main), r2);
        }
    }
}
