package org.apache.poi.hssf.record;

import b.b.a.a.a;
import java.util.ArrayList;
import java.util.List;
import org.apache.poi.hssf.usermodel.HSSFShapeTypes;
import org.apache.poi.util.LittleEndianOutput;

public final class PaletteRecord extends StandardRecord {
    public static final short FIRST_COLOR_INDEX = 8;
    public static final byte STANDARD_PALETTE_SIZE = 56;
    public static final short sid = 146;
    public final List<PColor> _colors;

    public PaletteRecord() {
        PColor[] createDefaultPalette = createDefaultPalette();
        this._colors = new ArrayList(createDefaultPalette.length);
        for (PColor pColor : createDefaultPalette) {
            this._colors.add(pColor);
        }
    }

    public static PColor[] createDefaultPalette() {
        return new PColor[]{pc(0, 0, 0), pc(255, 255, 255), pc(255, 0, 0), pc(0, 255, 0), pc(0, 0, 255), pc(255, 255, 0), pc(255, 0, 255), pc(0, 255, 255), pc(128, 0, 0), pc(0, 128, 0), pc(0, 0, 128), pc(128, 128, 0), pc(128, 0, 128), pc(0, 128, 128), pc(HSSFShapeTypes.ActionButtonInformation, HSSFShapeTypes.ActionButtonInformation, HSSFShapeTypes.ActionButtonInformation), pc(128, 128, 128), pc(153, 153, 255), pc(153, 51, 102), pc(255, 255, 204), pc(204, 255, 255), pc(102, 0, 102), pc(255, 128, 128), pc(0, 102, 204), pc(204, 204, 255), pc(0, 0, 128), pc(255, 0, 255), pc(255, 255, 0), pc(0, 255, 255), pc(128, 0, 128), pc(128, 0, 0), pc(0, 128, 128), pc(0, 0, 255), pc(0, 204, 255), pc(204, 255, 255), pc(204, 255, 204), pc(255, 255, 153), pc(153, 204, 255), pc(255, 153, 204), pc(204, 153, 255), pc(255, 204, 153), pc(51, 102, 255), pc(51, 204, 204), pc(153, 204, 0), pc(255, 204, 0), pc(255, 153, 0), pc(255, 102, 0), pc(102, 102, 153), pc(150, 150, 150), pc(0, 51, 102), pc(51, 153, 102), pc(0, 51, 0), pc(51, 51, 0), pc(153, 51, 0), pc(153, 51, 102), pc(51, 51, 153), pc(51, 51, 51)};
    }

    public static PColor pc(int i2, int i3, int i4) {
        return new PColor(i2, i3, i4);
    }

    public byte[] getColor(int i2) {
        int i3 = i2 - 8;
        if (i3 < 0 || i3 >= this._colors.size()) {
            return null;
        }
        return this._colors.get(i3).getTriplet();
    }

    @Override // org.apache.poi.hssf.record.StandardRecord
    public int getDataSize() {
        return (this._colors.size() * 4) + 2;
    }

    @Override // org.apache.poi.hssf.record.Record
    public short getSid() {
        return 146;
    }

    @Override // org.apache.poi.hssf.record.StandardRecord
    public void serialize(LittleEndianOutput littleEndianOutput) {
        littleEndianOutput.writeShort(this._colors.size());
        for (int i2 = 0; i2 < this._colors.size(); i2++) {
            this._colors.get(i2).serialize(littleEndianOutput);
        }
    }

    public void setColor(short s, byte b2, byte b3, byte b4) {
        int i2 = s - 8;
        if (i2 >= 0 && i2 < 56) {
            while (this._colors.size() <= i2) {
                this._colors.add(new PColor(0, 0, 0));
            }
            this._colors.set(i2, new PColor(b2, b3, b4));
        }
    }

    @Override // org.apache.poi.hssf.record.Record
    public String toString() {
        StringBuffer c = a.c("[PALETTE]\n", "  numcolors     = ");
        c.append(this._colors.size());
        c.append('\n');
        for (int i2 = 0; i2 < this._colors.size(); i2++) {
            c.append("* colornum      = ");
            c.append(i2);
            c.append('\n');
            c.append(this._colors.get(i2));
            c.append("/*colornum      = ");
            c.append(i2);
            c.append('\n');
        }
        c.append("[/PALETTE]\n");
        return c.toString();
    }

    public static final class PColor {
        public static final short ENCODED_SIZE = 4;
        public final int _blue;
        public final int _green;
        public final int _red;

        public PColor(int i2, int i3, int i4) {
            this._red = i2;
            this._green = i3;
            this._blue = i4;
        }

        public byte[] getTriplet() {
            return new byte[]{(byte) this._red, (byte) this._green, (byte) this._blue};
        }

        public void serialize(LittleEndianOutput littleEndianOutput) {
            littleEndianOutput.writeByte(this._red);
            littleEndianOutput.writeByte(this._green);
            littleEndianOutput.writeByte(this._blue);
            littleEndianOutput.writeByte(0);
        }

        public String toString() {
            StringBuffer a = a.a("  red   = ");
            a.append(this._red & 255);
            a.append('\n');
            a.append("  green = ");
            a.append(this._green & 255);
            a.append('\n');
            a.append("  blue  = ");
            a.append(this._blue & 255);
            a.append('\n');
            return a.toString();
        }

        public PColor(RecordInputStream recordInputStream) {
            this._red = recordInputStream.readByte();
            this._green = recordInputStream.readByte();
            this._blue = recordInputStream.readByte();
            recordInputStream.readByte();
        }
    }

    public PaletteRecord(RecordInputStream recordInputStream) {
        short readShort = recordInputStream.readShort();
        this._colors = new ArrayList(readShort);
        for (int i2 = 0; i2 < readShort; i2++) {
            this._colors.add(new PColor(recordInputStream));
        }
    }
}
