package org.apache.poi.hssf.record;

import b.b.a.a.a;
import org.apache.poi.util.HexDump;
import org.apache.poi.util.LittleEndianOutput;

public final class PaneRecord extends StandardRecord {
    public static final short ACTIVE_PANE_LOWER_LEFT = 2;
    public static final short ACTIVE_PANE_LOWER_RIGHT = 0;
    public static final short ACTIVE_PANE_UPPER_LEFT = 3;
    public static final short ACTIVE_PANE_UPPER_RIGHT = 1;
    public static final short sid = 65;
    public short field_1_x;
    public short field_2_y;
    public short field_3_topRow;
    public short field_4_leftColumn;
    public short field_5_activePane;

    public PaneRecord() {
    }

    @Override // org.apache.poi.hssf.record.Record
    public Object clone() {
        PaneRecord paneRecord = new PaneRecord();
        paneRecord.field_1_x = this.field_1_x;
        paneRecord.field_2_y = this.field_2_y;
        paneRecord.field_3_topRow = this.field_3_topRow;
        paneRecord.field_4_leftColumn = this.field_4_leftColumn;
        paneRecord.field_5_activePane = this.field_5_activePane;
        return paneRecord;
    }

    public short getActivePane() {
        return this.field_5_activePane;
    }

    @Override // org.apache.poi.hssf.record.StandardRecord
    public int getDataSize() {
        return 10;
    }

    public short getLeftColumn() {
        return this.field_4_leftColumn;
    }

    @Override // org.apache.poi.hssf.record.Record
    public short getSid() {
        return 65;
    }

    public short getTopRow() {
        return this.field_3_topRow;
    }

    public short getX() {
        return this.field_1_x;
    }

    public short getY() {
        return this.field_2_y;
    }

    @Override // org.apache.poi.hssf.record.StandardRecord
    public void serialize(LittleEndianOutput littleEndianOutput) {
        littleEndianOutput.writeShort(this.field_1_x);
        littleEndianOutput.writeShort(this.field_2_y);
        littleEndianOutput.writeShort(this.field_3_topRow);
        littleEndianOutput.writeShort(this.field_4_leftColumn);
        littleEndianOutput.writeShort(this.field_5_activePane);
    }

    public void setActivePane(short s) {
        this.field_5_activePane = s;
    }

    public void setLeftColumn(short s) {
        this.field_4_leftColumn = s;
    }

    public void setTopRow(short s) {
        this.field_3_topRow = s;
    }

    public void setX(short s) {
        this.field_1_x = s;
    }

    public void setY(short s) {
        this.field_2_y = s;
    }

    @Override // org.apache.poi.hssf.record.Record
    public String toString() {
        StringBuffer c = a.c("[PANE]\n", "    .x                    = ", "0x");
        c.append(HexDump.toHex(getX()));
        c.append(" (");
        c.append((int) getX());
        c.append(" )");
        c.append(System.getProperty("line.separator"));
        c.append("    .y                    = ");
        c.append("0x");
        c.append(HexDump.toHex(getY()));
        c.append(" (");
        c.append((int) getY());
        c.append(" )");
        c.append(System.getProperty("line.separator"));
        c.append("    .topRow               = ");
        c.append("0x");
        c.append(HexDump.toHex(getTopRow()));
        c.append(" (");
        c.append((int) getTopRow());
        c.append(" )");
        c.append(System.getProperty("line.separator"));
        c.append("    .leftColumn           = ");
        c.append("0x");
        c.append(HexDump.toHex(getLeftColumn()));
        c.append(" (");
        c.append((int) getLeftColumn());
        c.append(" )");
        c.append(System.getProperty("line.separator"));
        c.append("    .activePane           = ");
        c.append("0x");
        c.append(HexDump.toHex(getActivePane()));
        c.append(" (");
        c.append((int) getActivePane());
        c.append(" )");
        c.append(System.getProperty("line.separator"));
        c.append("[/PANE]\n");
        return c.toString();
    }

    public PaneRecord(RecordInputStream recordInputStream) {
        this.field_1_x = recordInputStream.readShort();
        this.field_2_y = recordInputStream.readShort();
        this.field_3_topRow = recordInputStream.readShort();
        this.field_4_leftColumn = recordInputStream.readShort();
        this.field_5_activePane = recordInputStream.readShort();
    }
}
