package org.apache.poi.hssf.record;

import b.b.a.a.a;
import org.apache.poi.util.BitField;
import org.apache.poi.util.BitFieldFactory;
import org.apache.poi.util.LittleEndianOutput;

public final class PrintSetupRecord extends StandardRecord {
    public static final BitField draft = BitFieldFactory.getInstance(16);
    public static final BitField landscape = BitFieldFactory.getInstance(2);
    public static final BitField lefttoright = BitFieldFactory.getInstance(1);
    public static final BitField noOrientation = BitFieldFactory.getInstance(64);
    public static final BitField nocolor = BitFieldFactory.getInstance(8);
    public static final BitField notes = BitFieldFactory.getInstance(32);
    public static final short sid = 161;
    public static final BitField usepage = BitFieldFactory.getInstance(128);
    public static final BitField validsettings = BitFieldFactory.getInstance(4);
    public double field_10_footermargin;
    public short field_11_copies;
    public short field_1_paper_size;
    public short field_2_scale;
    public short field_3_page_start;
    public short field_4_fit_width;
    public short field_5_fit_height;
    public short field_6_options;
    public short field_7_hresolution;
    public short field_8_vresolution;
    public double field_9_headermargin;

    public PrintSetupRecord() {
    }

    @Override // org.apache.poi.hssf.record.Record
    public Object clone() {
        PrintSetupRecord printSetupRecord = new PrintSetupRecord();
        printSetupRecord.field_1_paper_size = this.field_1_paper_size;
        printSetupRecord.field_2_scale = this.field_2_scale;
        printSetupRecord.field_3_page_start = this.field_3_page_start;
        printSetupRecord.field_4_fit_width = this.field_4_fit_width;
        printSetupRecord.field_5_fit_height = this.field_5_fit_height;
        printSetupRecord.field_6_options = this.field_6_options;
        printSetupRecord.field_7_hresolution = this.field_7_hresolution;
        printSetupRecord.field_8_vresolution = this.field_8_vresolution;
        printSetupRecord.field_9_headermargin = this.field_9_headermargin;
        printSetupRecord.field_10_footermargin = this.field_10_footermargin;
        printSetupRecord.field_11_copies = this.field_11_copies;
        return printSetupRecord;
    }

    public short getCopies() {
        return this.field_11_copies;
    }

    @Override // org.apache.poi.hssf.record.StandardRecord
    public int getDataSize() {
        return 34;
    }

    public boolean getDraft() {
        return draft.isSet(this.field_6_options);
    }

    public short getFitHeight() {
        return this.field_5_fit_height;
    }

    public short getFitWidth() {
        return this.field_4_fit_width;
    }

    public double getFooterMargin() {
        return this.field_10_footermargin;
    }

    public short getHResolution() {
        return this.field_7_hresolution;
    }

    public double getHeaderMargin() {
        return this.field_9_headermargin;
    }

    public boolean getLandscape() {
        return landscape.isSet(this.field_6_options);
    }

    public boolean getLeftToRight() {
        return lefttoright.isSet(this.field_6_options);
    }

    public boolean getNoColor() {
        return nocolor.isSet(this.field_6_options);
    }

    public boolean getNoOrientation() {
        return noOrientation.isSet(this.field_6_options);
    }

    public boolean getNotes() {
        return notes.isSet(this.field_6_options);
    }

    public short getOptions() {
        return this.field_6_options;
    }

    public short getPageStart() {
        return this.field_3_page_start;
    }

    public short getPaperSize() {
        return this.field_1_paper_size;
    }

    public short getScale() {
        return this.field_2_scale;
    }

    @Override // org.apache.poi.hssf.record.Record
    public short getSid() {
        return 161;
    }

    public boolean getUsePage() {
        return usepage.isSet(this.field_6_options);
    }

    public short getVResolution() {
        return this.field_8_vresolution;
    }

    public boolean getValidSettings() {
        return validsettings.isSet(this.field_6_options);
    }

    @Override // org.apache.poi.hssf.record.StandardRecord
    public void serialize(LittleEndianOutput littleEndianOutput) {
        littleEndianOutput.writeShort(getPaperSize());
        littleEndianOutput.writeShort(getScale());
        littleEndianOutput.writeShort(getPageStart());
        littleEndianOutput.writeShort(getFitWidth());
        littleEndianOutput.writeShort(getFitHeight());
        littleEndianOutput.writeShort(getOptions());
        littleEndianOutput.writeShort(getHResolution());
        littleEndianOutput.writeShort(getVResolution());
        littleEndianOutput.writeDouble(getHeaderMargin());
        littleEndianOutput.writeDouble(getFooterMargin());
        littleEndianOutput.writeShort(getCopies());
    }

    public void setCopies(short s) {
        this.field_11_copies = s;
    }

    public void setDraft(boolean z) {
        this.field_6_options = draft.setShortBoolean(this.field_6_options, z);
    }

    public void setFitHeight(short s) {
        this.field_5_fit_height = s;
    }

    public void setFitWidth(short s) {
        this.field_4_fit_width = s;
    }

    public void setFooterMargin(double d2) {
        this.field_10_footermargin = d2;
    }

    public void setHResolution(short s) {
        this.field_7_hresolution = s;
    }

    public void setHeaderMargin(double d2) {
        this.field_9_headermargin = d2;
    }

    public void setLandscape(boolean z) {
        this.field_6_options = landscape.setShortBoolean(this.field_6_options, z);
    }

    public void setLeftToRight(boolean z) {
        this.field_6_options = lefttoright.setShortBoolean(this.field_6_options, z);
    }

    public void setNoColor(boolean z) {
        this.field_6_options = nocolor.setShortBoolean(this.field_6_options, z);
    }

    public void setNoOrientation(boolean z) {
        this.field_6_options = noOrientation.setShortBoolean(this.field_6_options, z);
    }

    public void setNotes(boolean z) {
        this.field_6_options = notes.setShortBoolean(this.field_6_options, z);
    }

    public void setOptions(short s) {
        this.field_6_options = s;
    }

    public void setPageStart(short s) {
        this.field_3_page_start = s;
    }

    public void setPaperSize(short s) {
        this.field_1_paper_size = s;
    }

    public void setScale(short s) {
        this.field_2_scale = s;
    }

    public void setUsePage(boolean z) {
        this.field_6_options = usepage.setShortBoolean(this.field_6_options, z);
    }

    public void setVResolution(short s) {
        this.field_8_vresolution = s;
    }

    public void setValidSettings(boolean z) {
        this.field_6_options = validsettings.setShortBoolean(this.field_6_options, z);
    }

    @Override // org.apache.poi.hssf.record.Record
    public String toString() {
        StringBuffer c = a.c("[PRINTSETUP]\n", "    .papersize      = ");
        c.append((int) getPaperSize());
        c.append("\n");
        c.append("    .scale          = ");
        c.append((int) getScale());
        c.append("\n");
        c.append("    .pagestart      = ");
        c.append((int) getPageStart());
        c.append("\n");
        c.append("    .fitwidth       = ");
        c.append((int) getFitWidth());
        c.append("\n");
        c.append("    .fitheight      = ");
        c.append((int) getFitHeight());
        c.append("\n");
        c.append("    .options        = ");
        c.append((int) getOptions());
        c.append("\n");
        c.append("        .ltor       = ");
        c.append(getLeftToRight());
        c.append("\n");
        c.append("        .landscape  = ");
        c.append(getLandscape());
        c.append("\n");
        c.append("        .valid      = ");
        c.append(getValidSettings());
        c.append("\n");
        c.append("        .mono       = ");
        c.append(getNoColor());
        c.append("\n");
        c.append("        .draft      = ");
        c.append(getDraft());
        c.append("\n");
        c.append("        .notes      = ");
        c.append(getNotes());
        c.append("\n");
        c.append("        .noOrientat = ");
        c.append(getNoOrientation());
        c.append("\n");
        c.append("        .usepage    = ");
        c.append(getUsePage());
        c.append("\n");
        c.append("    .hresolution    = ");
        c.append((int) getHResolution());
        c.append("\n");
        c.append("    .vresolution    = ");
        c.append((int) getVResolution());
        c.append("\n");
        c.append("    .headermargin   = ");
        c.append(getHeaderMargin());
        c.append("\n");
        c.append("    .footermargin   = ");
        c.append(getFooterMargin());
        c.append("\n");
        c.append("    .copies         = ");
        c.append((int) getCopies());
        return a.a(c, "\n", "[/PRINTSETUP]\n");
    }

    public PrintSetupRecord(RecordInputStream recordInputStream) {
        this.field_1_paper_size = recordInputStream.readShort();
        this.field_2_scale = recordInputStream.readShort();
        this.field_3_page_start = recordInputStream.readShort();
        this.field_4_fit_width = recordInputStream.readShort();
        this.field_5_fit_height = recordInputStream.readShort();
        this.field_6_options = recordInputStream.readShort();
        this.field_7_hresolution = recordInputStream.readShort();
        this.field_8_vresolution = recordInputStream.readShort();
        this.field_9_headermargin = recordInputStream.readDouble();
        this.field_10_footermargin = recordInputStream.readDouble();
        this.field_11_copies = recordInputStream.readShort();
    }
}
