package org.apache.poi.hssf.record;

import b.b.a.a.a;
import java.io.InputStream;
import java.security.GeneralSecurityException;
import java.util.ArrayList;
import java.util.List;
import org.apache.poi.EncryptedDocumentException;
import org.apache.poi.hssf.record.crypto.Biff8EncryptionKey;
import org.apache.poi.openxml4j.opc.internal.ContentTypeManager;
import org.apache.poi.poifs.crypt.Decryptor;
import org.apache.poi.poifs.crypt.EncryptionInfo;
import org.apache.poi.util.RecordFormatException;

public final class RecordFactoryInputStream {
    public int _bofDepth;
    public DrawingRecord _lastDrawingRecord = new DrawingRecord();
    public Record _lastRecord = null;
    public boolean _lastRecordWasEOFLevelZero;
    public final RecordInputStream _recStream;
    public final boolean _shouldIncludeContinueRecords;
    public Record[] _unreadRecordBuffer;
    public int _unreadRecordIndex = -1;

    public static final class StreamEncryptionInfo {
        public final FilePassRecord _filePassRec;
        public final boolean _hasBOFRecord;
        public final int _initialRecordsSize;
        public final Record _lastRecord;

        public StreamEncryptionInfo(RecordInputStream recordInputStream, List<Record> list) {
            recordInputStream.nextRecord();
            int remaining = recordInputStream.remaining() + 4;
            Record createSingleRecord = RecordFactory.createSingleRecord(recordInputStream);
            list.add(createSingleRecord);
            FilePassRecord filePassRecord = null;
            if (createSingleRecord instanceof BOFRecord) {
                this._hasBOFRecord = true;
                if (recordInputStream.hasNextRecord()) {
                    recordInputStream.nextRecord();
                    createSingleRecord = RecordFactory.createSingleRecord(recordInputStream);
                    int recordSize = createSingleRecord.getRecordSize() + remaining;
                    list.add(createSingleRecord);
                    if (!(createSingleRecord instanceof WriteProtectRecord) || !recordInputStream.hasNextRecord()) {
                        remaining = recordSize;
                    } else {
                        recordInputStream.nextRecord();
                        Record createSingleRecord2 = RecordFactory.createSingleRecord(recordInputStream);
                        remaining = createSingleRecord2.getRecordSize() + recordSize;
                        list.add(createSingleRecord2);
                        createSingleRecord = createSingleRecord2;
                    }
                    filePassRecord = createSingleRecord instanceof FilePassRecord ? (FilePassRecord) createSingleRecord : filePassRecord;
                    if (createSingleRecord instanceof EOFRecord) {
                        throw new IllegalStateException("Nothing between BOF and EOF");
                    }
                }
            } else {
                this._hasBOFRecord = false;
            }
            this._initialRecordsSize = remaining;
            this._filePassRec = filePassRecord;
            this._lastRecord = createSingleRecord;
        }

        public RecordInputStream createDecryptingStream(InputStream inputStream) {
            FilePassRecord filePassRecord = this._filePassRec;
            String currentUserPassword = Biff8EncryptionKey.getCurrentUserPassword();
            if (currentUserPassword == null) {
                currentUserPassword = Decryptor.DEFAULT_PASSWORD;
            }
            EncryptionInfo encryptionInfo = filePassRecord.getEncryptionInfo();
            try {
                if (encryptionInfo.getDecryptor().verifyPassword(currentUserPassword)) {
                    return new RecordInputStream(inputStream, encryptionInfo, this._initialRecordsSize);
                }
                StringBuilder sb = new StringBuilder();
                sb.append(Decryptor.DEFAULT_PASSWORD.equals(currentUserPassword) ? ContentTypeManager.DEFAULT_TAG_NAME : "Supplied");
                sb.append(" password is invalid for salt/verifier/verifierHash");
                throw new EncryptedDocumentException(sb.toString());
            } catch (GeneralSecurityException e2) {
                throw new EncryptedDocumentException(e2);
            }
        }

        public Record getLastRecord() {
            return this._lastRecord;
        }

        public boolean hasBOFRecord() {
            return this._hasBOFRecord;
        }

        public boolean hasEncryption() {
            return this._filePassRec != null;
        }
    }

    public RecordFactoryInputStream(InputStream inputStream, boolean z) {
        RecordInputStream recordInputStream = new RecordInputStream(inputStream);
        ArrayList arrayList = new ArrayList();
        StreamEncryptionInfo streamEncryptionInfo = new StreamEncryptionInfo(recordInputStream, arrayList);
        recordInputStream = streamEncryptionInfo.hasEncryption() ? streamEncryptionInfo.createDecryptingStream(inputStream) : recordInputStream;
        if (!arrayList.isEmpty()) {
            Record[] recordArr = new Record[arrayList.size()];
            this._unreadRecordBuffer = recordArr;
            arrayList.toArray(recordArr);
            this._unreadRecordIndex = 0;
        }
        this._recStream = recordInputStream;
        this._shouldIncludeContinueRecords = z;
        this._lastRecord = streamEncryptionInfo.getLastRecord();
        this._bofDepth = streamEncryptionInfo.hasBOFRecord() ? 1 : 0;
        this._lastRecordWasEOFLevelZero = false;
    }

    private Record getNextUnreadRecord() {
        Record[] recordArr = this._unreadRecordBuffer;
        if (recordArr != null) {
            int i2 = this._unreadRecordIndex;
            if (i2 < recordArr.length) {
                Record record = recordArr[i2];
                this._unreadRecordIndex = i2 + 1;
                return record;
            }
            this._unreadRecordIndex = -1;
            this._unreadRecordBuffer = null;
        }
        return null;
    }

    private Record readNextRecord() {
        Record createSingleRecord = RecordFactory.createSingleRecord(this._recStream);
        this._lastRecordWasEOFLevelZero = false;
        if (createSingleRecord instanceof BOFRecord) {
            this._bofDepth++;
            return createSingleRecord;
        } else if (createSingleRecord instanceof EOFRecord) {
            int i2 = this._bofDepth - 1;
            this._bofDepth = i2;
            if (i2 < 1) {
                this._lastRecordWasEOFLevelZero = true;
            }
            return createSingleRecord;
        } else if (createSingleRecord instanceof DBCellRecord) {
            return null;
        } else {
            if (createSingleRecord instanceof RKRecord) {
                return RecordFactory.convertToNumberRecord((RKRecord) createSingleRecord);
            }
            if (createSingleRecord instanceof MulRKRecord) {
                NumberRecord[] convertRKRecords = RecordFactory.convertRKRecords((MulRKRecord) createSingleRecord);
                this._unreadRecordBuffer = convertRKRecords;
                this._unreadRecordIndex = 1;
                return convertRKRecords[0];
            }
            if (createSingleRecord.getSid() == 235) {
                Record record = this._lastRecord;
                if (record instanceof DrawingGroupRecord) {
                    ((DrawingGroupRecord) record).join((AbstractEscherHolderRecord) createSingleRecord);
                    return null;
                }
            }
            if (createSingleRecord.getSid() == 60) {
                ContinueRecord continueRecord = (ContinueRecord) createSingleRecord;
                Record record2 = this._lastRecord;
                if ((record2 instanceof ObjRecord) || (record2 instanceof TextObjectRecord)) {
                    this._lastDrawingRecord.processContinueRecord(continueRecord.getData());
                    if (this._shouldIncludeContinueRecords) {
                        return createSingleRecord;
                    }
                    return null;
                } else if (record2 instanceof DrawingGroupRecord) {
                    ((DrawingGroupRecord) record2).processContinueRecord(continueRecord.getData());
                    return null;
                } else if (record2 instanceof DrawingRecord) {
                    return continueRecord;
                } else {
                    if ((record2 instanceof UnknownRecord) || (record2 instanceof EOFRecord)) {
                        return createSingleRecord;
                    }
                    StringBuilder b2 = a.b("Unhandled Continue Record followining ");
                    b2.append(this._lastRecord.getClass());
                    throw new RecordFormatException(b2.toString());
                }
            } else {
                this._lastRecord = createSingleRecord;
                if (createSingleRecord instanceof DrawingRecord) {
                    this._lastDrawingRecord = (DrawingRecord) createSingleRecord;
                }
                return createSingleRecord;
            }
        }
    }

    public Record nextRecord() {
        Record nextUnreadRecord = getNextUnreadRecord();
        if (nextUnreadRecord != null) {
            return nextUnreadRecord;
        }
        while (this._recStream.hasNextRecord()) {
            if (this._lastRecordWasEOFLevelZero && this._recStream.getNextSid() != 2057) {
                return null;
            }
            this._recStream.nextRecord();
            Record readNextRecord = readNextRecord();
            if (readNextRecord != null) {
                return readNextRecord;
            }
        }
        return null;
    }
}
