package org.apache.poi.hssf.record;

import b.b.a.a.a;
import org.apache.poi.util.BitField;
import org.apache.poi.util.BitFieldFactory;
import org.apache.poi.util.HexDump;
import org.apache.poi.util.LittleEndianOutput;

public final class RowRecord extends StandardRecord {
    public static final int ENCODED_SIZE = 20;
    public static final int OPTION_BITS_ALWAYS_SET = 256;
    public static final BitField badFontHeight = BitFieldFactory.getInstance(64);
    public static final BitField bottomBorder = BitFieldFactory.getInstance(8192);
    public static final BitField colapsed = BitFieldFactory.getInstance(16);
    public static final BitField formatted = BitFieldFactory.getInstance(128);
    public static final BitField outlineLevel = BitFieldFactory.getInstance(7);
    public static final BitField phoeneticGuide = BitFieldFactory.getInstance(16384);
    public static final short sid = 520;
    public static final BitField topBorder = BitFieldFactory.getInstance(4096);
    public static final BitField xfIndex = BitFieldFactory.getInstance(4095);
    public static final BitField zeroHeight = BitFieldFactory.getInstance(32);
    public int field_1_row_number;
    public int field_2_first_col;
    public int field_3_last_col;
    public short field_4_height;
    public short field_5_optimize;
    public short field_6_reserved;
    public int field_7_option_flags;
    public int field_8_option_flags;

    public RowRecord(int i2) {
        if (i2 >= 0) {
            this.field_1_row_number = i2;
            this.field_4_height = 255;
            this.field_5_optimize = 0;
            this.field_6_reserved = 0;
            this.field_7_option_flags = 256;
            this.field_8_option_flags = 15;
            setEmpty();
            return;
        }
        throw new IllegalArgumentException(a.b("Invalid row number (", i2, ")"));
    }

    @Override // org.apache.poi.hssf.record.Record
    public Object clone() {
        RowRecord rowRecord = new RowRecord(this.field_1_row_number);
        rowRecord.field_2_first_col = this.field_2_first_col;
        rowRecord.field_3_last_col = this.field_3_last_col;
        rowRecord.field_4_height = this.field_4_height;
        rowRecord.field_5_optimize = this.field_5_optimize;
        rowRecord.field_6_reserved = this.field_6_reserved;
        rowRecord.field_7_option_flags = this.field_7_option_flags;
        rowRecord.field_8_option_flags = this.field_8_option_flags;
        return rowRecord;
    }

    public boolean getBadFontHeight() {
        return badFontHeight.isSet(this.field_7_option_flags);
    }

    public boolean getBottomBorder() {
        return bottomBorder.isSet(this.field_8_option_flags);
    }

    public boolean getColapsed() {
        return colapsed.isSet(this.field_7_option_flags);
    }

    @Override // org.apache.poi.hssf.record.StandardRecord
    public int getDataSize() {
        return 16;
    }

    public int getFirstCol() {
        return this.field_2_first_col;
    }

    public boolean getFormatted() {
        return formatted.isSet(this.field_7_option_flags);
    }

    public short getHeight() {
        return this.field_4_height;
    }

    public int getLastCol() {
        return this.field_3_last_col;
    }

    public short getOptimize() {
        return this.field_5_optimize;
    }

    public short getOptionFlags() {
        return (short) this.field_7_option_flags;
    }

    public short getOptionFlags2() {
        return (short) this.field_8_option_flags;
    }

    public short getOutlineLevel() {
        return (short) outlineLevel.getValue(this.field_7_option_flags);
    }

    public boolean getPhoeneticGuide() {
        return phoeneticGuide.isSet(this.field_8_option_flags);
    }

    public int getRowNumber() {
        return this.field_1_row_number;
    }

    @Override // org.apache.poi.hssf.record.Record
    public short getSid() {
        return 520;
    }

    public boolean getTopBorder() {
        return topBorder.isSet(this.field_8_option_flags);
    }

    public short getXFIndex() {
        return xfIndex.getShortValue((short) this.field_8_option_flags);
    }

    public boolean getZeroHeight() {
        return zeroHeight.isSet(this.field_7_option_flags);
    }

    public boolean isEmpty() {
        return (this.field_2_first_col | this.field_3_last_col) == 0;
    }

    @Override // org.apache.poi.hssf.record.StandardRecord
    public void serialize(LittleEndianOutput littleEndianOutput) {
        littleEndianOutput.writeShort(getRowNumber());
        int i2 = 0;
        littleEndianOutput.writeShort(getFirstCol() == -1 ? 0 : getFirstCol());
        if (getLastCol() != -1) {
            i2 = getLastCol();
        }
        littleEndianOutput.writeShort(i2);
        littleEndianOutput.writeShort(getHeight());
        littleEndianOutput.writeShort(getOptimize());
        littleEndianOutput.writeShort(this.field_6_reserved);
        littleEndianOutput.writeShort(getOptionFlags());
        littleEndianOutput.writeShort(getOptionFlags2());
    }

    public void setBadFontHeight(boolean z) {
        this.field_7_option_flags = badFontHeight.setBoolean(this.field_7_option_flags, z);
    }

    public void setBottomBorder(boolean z) {
        this.field_8_option_flags = bottomBorder.setBoolean(this.field_8_option_flags, z);
    }

    public void setColapsed(boolean z) {
        this.field_7_option_flags = colapsed.setBoolean(this.field_7_option_flags, z);
    }

    public void setEmpty() {
        this.field_2_first_col = 0;
        this.field_3_last_col = 0;
    }

    public void setFirstCol(int i2) {
        this.field_2_first_col = i2;
    }

    public void setFormatted(boolean z) {
        this.field_7_option_flags = formatted.setBoolean(this.field_7_option_flags, z);
    }

    public void setHeight(short s) {
        this.field_4_height = s;
    }

    public void setLastCol(int i2) {
        this.field_3_last_col = i2;
    }

    public void setOptimize(short s) {
        this.field_5_optimize = s;
    }

    public void setOutlineLevel(short s) {
        this.field_7_option_flags = outlineLevel.setValue(this.field_7_option_flags, s);
    }

    public void setPhoeneticGuide(boolean z) {
        this.field_8_option_flags = phoeneticGuide.setBoolean(this.field_8_option_flags, z);
    }

    public void setRowNumber(int i2) {
        this.field_1_row_number = i2;
    }

    public void setTopBorder(boolean z) {
        this.field_8_option_flags = topBorder.setBoolean(this.field_8_option_flags, z);
    }

    public void setXFIndex(short s) {
        this.field_8_option_flags = xfIndex.setValue(this.field_8_option_flags, s);
    }

    public void setZeroHeight(boolean z) {
        this.field_7_option_flags = zeroHeight.setBoolean(this.field_7_option_flags, z);
    }

    @Override // org.apache.poi.hssf.record.Record
    public String toString() {
        StringBuffer c = a.c("[ROW]\n", "    .rownumber      = ");
        c.append(Integer.toHexString(getRowNumber()));
        c.append("\n");
        c.append("    .firstcol       = ");
        c.append(HexDump.shortToHex(getFirstCol()));
        c.append("\n");
        c.append("    .lastcol        = ");
        c.append(HexDump.shortToHex(getLastCol()));
        c.append("\n");
        c.append("    .height         = ");
        c.append(HexDump.shortToHex(getHeight()));
        c.append("\n");
        c.append("    .optimize       = ");
        c.append(HexDump.shortToHex(getOptimize()));
        c.append("\n");
        c.append("    .reserved       = ");
        c.append(HexDump.shortToHex(this.field_6_reserved));
        c.append("\n");
        c.append("    .optionflags    = ");
        c.append(HexDump.shortToHex(getOptionFlags()));
        c.append("\n");
        c.append("        .outlinelvl = ");
        c.append(Integer.toHexString(getOutlineLevel()));
        c.append("\n");
        c.append("        .colapsed   = ");
        c.append(getColapsed());
        c.append("\n");
        c.append("        .zeroheight = ");
        c.append(getZeroHeight());
        c.append("\n");
        c.append("        .badfontheig= ");
        c.append(getBadFontHeight());
        c.append("\n");
        c.append("        .formatted  = ");
        c.append(getFormatted());
        c.append("\n");
        c.append("    .optionsflags2  = ");
        c.append(HexDump.shortToHex(getOptionFlags2()));
        c.append("\n");
        c.append("        .xfindex       = ");
        c.append(Integer.toHexString(getXFIndex()));
        c.append("\n");
        c.append("        .topBorder     = ");
        c.append(getTopBorder());
        c.append("\n");
        c.append("        .bottomBorder  = ");
        c.append(getBottomBorder());
        c.append("\n");
        c.append("        .phoeneticGuide= ");
        c.append(getPhoeneticGuide());
        c.append("\n");
        c.append("[/ROW]\n");
        return c.toString();
    }

    public RowRecord(RecordInputStream recordInputStream) {
        int readUShort = recordInputStream.readUShort();
        this.field_1_row_number = readUShort;
        if (readUShort >= 0) {
            this.field_2_first_col = recordInputStream.readShort();
            this.field_3_last_col = recordInputStream.readShort();
            this.field_4_height = recordInputStream.readShort();
            this.field_5_optimize = recordInputStream.readShort();
            this.field_6_reserved = recordInputStream.readShort();
            this.field_7_option_flags = recordInputStream.readShort();
            this.field_8_option_flags = recordInputStream.readShort();
            return;
        }
        throw new IllegalArgumentException(a.a(a.b("Invalid row number "), this.field_1_row_number, " found in InputStream"));
    }
}
