package org.apache.poi.hssf.record;

import org.apache.poi.hssf.record.common.UnicodeString;
import org.apache.poi.hssf.record.cont.ContinuableRecordOutput;
import org.apache.poi.util.IntMapper;

public final class SSTSerializer {
    public final int _numStrings;
    public final int _numUniqueStrings;
    public final int[] bucketAbsoluteOffsets;
    public final int[] bucketRelativeOffsets;
    public final IntMapper<UnicodeString> strings;

    public SSTSerializer(IntMapper<UnicodeString> intMapper, int i2, int i3) {
        this.strings = intMapper;
        this._numStrings = i2;
        this._numUniqueStrings = i3;
        int numberOfInfoRecsForStrings = ExtSSTRecord.getNumberOfInfoRecsForStrings(intMapper.size());
        this.bucketAbsoluteOffsets = new int[numberOfInfoRecsForStrings];
        this.bucketRelativeOffsets = new int[numberOfInfoRecsForStrings];
    }

    private UnicodeString getUnicodeString(int i2) {
        return getUnicodeString(this.strings, i2);
    }

    public int[] getBucketAbsoluteOffsets() {
        return this.bucketAbsoluteOffsets;
    }

    public int[] getBucketRelativeOffsets() {
        return this.bucketRelativeOffsets;
    }

    public void serialize(ContinuableRecordOutput continuableRecordOutput) {
        continuableRecordOutput.writeInt(this._numStrings);
        continuableRecordOutput.writeInt(this._numUniqueStrings);
        for (int i2 = 0; i2 < this.strings.size(); i2++) {
            if (i2 % 8 == 0) {
                int totalSize = continuableRecordOutput.getTotalSize();
                int i3 = i2 / 8;
                if (i3 < 128) {
                    this.bucketAbsoluteOffsets[i3] = totalSize;
                    this.bucketRelativeOffsets[i3] = totalSize;
                }
            }
            getUnicodeString(i2).serialize(continuableRecordOutput);
        }
    }

    public static UnicodeString getUnicodeString(IntMapper<UnicodeString> intMapper, int i2) {
        return intMapper.get(i2);
    }
}
