package org.apache.poi.hssf.record;

import b.b.a.a.a;
import org.apache.poi.hssf.util.CellRangeAddress8Bit;
import org.apache.poi.util.HexDump;
import org.apache.poi.util.LittleEndianOutput;

public final class SelectionRecord extends StandardRecord {
    public static final short sid = 29;
    public byte field_1_pane;
    public int field_2_row_active_cell;
    public int field_3_col_active_cell;
    public int field_4_active_cell_ref_index;
    public CellRangeAddress8Bit[] field_6_refs;

    public SelectionRecord(int i2, int i3) {
        this.field_1_pane = 3;
        this.field_2_row_active_cell = i2;
        this.field_3_col_active_cell = i3;
        this.field_4_active_cell_ref_index = 0;
        this.field_6_refs = new CellRangeAddress8Bit[]{new CellRangeAddress8Bit(i2, i2, i3, i3)};
    }

    @Override // org.apache.poi.hssf.record.Record
    public Object clone() {
        SelectionRecord selectionRecord = new SelectionRecord(this.field_2_row_active_cell, this.field_3_col_active_cell);
        selectionRecord.field_1_pane = this.field_1_pane;
        selectionRecord.field_4_active_cell_ref_index = this.field_4_active_cell_ref_index;
        selectionRecord.field_6_refs = this.field_6_refs;
        return selectionRecord;
    }

    public int getActiveCellCol() {
        return this.field_3_col_active_cell;
    }

    public int getActiveCellRef() {
        return this.field_4_active_cell_ref_index;
    }

    public int getActiveCellRow() {
        return this.field_2_row_active_cell;
    }

    @Override // org.apache.poi.hssf.record.StandardRecord
    public int getDataSize() {
        return CellRangeAddress8Bit.getEncodedSize(this.field_6_refs.length) + 9;
    }

    public byte getPane() {
        return this.field_1_pane;
    }

    @Override // org.apache.poi.hssf.record.Record
    public short getSid() {
        return 29;
    }

    @Override // org.apache.poi.hssf.record.StandardRecord
    public void serialize(LittleEndianOutput littleEndianOutput) {
        littleEndianOutput.writeByte(getPane());
        littleEndianOutput.writeShort(getActiveCellRow());
        littleEndianOutput.writeShort(getActiveCellCol());
        littleEndianOutput.writeShort(getActiveCellRef());
        littleEndianOutput.writeShort(this.field_6_refs.length);
        for (CellRangeAddress8Bit cellRangeAddress8Bit : this.field_6_refs) {
            cellRangeAddress8Bit.serialize(littleEndianOutput);
        }
    }

    public void setActiveCellCol(short s) {
        this.field_3_col_active_cell = s;
    }

    public void setActiveCellRef(short s) {
        this.field_4_active_cell_ref_index = s;
    }

    public void setActiveCellRow(int i2) {
        this.field_2_row_active_cell = i2;
    }

    public void setPane(byte b2) {
        this.field_1_pane = b2;
    }

    @Override // org.apache.poi.hssf.record.Record
    public String toString() {
        StringBuffer c = a.c("[SELECTION]\n", "    .pane            = ");
        c.append(HexDump.byteToHex(getPane()));
        c.append("\n");
        c.append("    .activecellrow   = ");
        c.append(HexDump.shortToHex(getActiveCellRow()));
        c.append("\n");
        c.append("    .activecellcol   = ");
        c.append(HexDump.shortToHex(getActiveCellCol()));
        c.append("\n");
        c.append("    .activecellref   = ");
        c.append(HexDump.shortToHex(getActiveCellRef()));
        c.append("\n");
        c.append("    .numrefs         = ");
        c.append(HexDump.shortToHex(this.field_6_refs.length));
        c.append("\n");
        c.append("[/SELECTION]\n");
        return c.toString();
    }

    public SelectionRecord(RecordInputStream recordInputStream) {
        this.field_1_pane = recordInputStream.readByte();
        this.field_2_row_active_cell = recordInputStream.readUShort();
        this.field_3_col_active_cell = recordInputStream.readShort();
        this.field_4_active_cell_ref_index = recordInputStream.readShort();
        this.field_6_refs = new CellRangeAddress8Bit[recordInputStream.readUShort()];
        int i2 = 0;
        while (true) {
            CellRangeAddress8Bit[] cellRangeAddress8BitArr = this.field_6_refs;
            if (i2 < cellRangeAddress8BitArr.length) {
                cellRangeAddress8BitArr[i2] = new CellRangeAddress8Bit(recordInputStream);
                i2++;
            } else {
                return;
            }
        }
    }
}
