package org.apache.poi.hssf.record;

import b.b.a.a.a;
import org.apache.poi.util.BitField;
import org.apache.poi.util.BitFieldFactory;
import org.apache.poi.util.HexDump;
import org.apache.poi.util.LittleEndianOutput;
import org.apache.poi.util.RecordFormatException;
import org.apache.poi.util.StringUtil;

public final class StyleRecord extends StandardRecord {
    public static final BitField isBuiltinFlag = BitFieldFactory.getInstance(32768);
    public static final short sid = 659;
    public static final BitField styleIndexMask = BitFieldFactory.getInstance(4095);
    public int field_1_xf_index;
    public int field_2_builtin_style;
    public int field_3_outline_style_level;
    public boolean field_3_stringHasMultibyte;
    public String field_4_name;

    public StyleRecord() {
        this.field_1_xf_index = isBuiltinFlag.set(0);
    }

    @Override // org.apache.poi.hssf.record.StandardRecord
    public int getDataSize() {
        if (isBuiltin()) {
            return 4;
        }
        return (this.field_4_name.length() * (this.field_3_stringHasMultibyte ? 2 : 1)) + 5;
    }

    public String getName() {
        return this.field_4_name;
    }

    @Override // org.apache.poi.hssf.record.Record
    public short getSid() {
        return sid;
    }

    public int getXFIndex() {
        return styleIndexMask.getValue(this.field_1_xf_index);
    }

    public boolean isBuiltin() {
        return isBuiltinFlag.isSet(this.field_1_xf_index);
    }

    @Override // org.apache.poi.hssf.record.StandardRecord
    public void serialize(LittleEndianOutput littleEndianOutput) {
        littleEndianOutput.writeShort(this.field_1_xf_index);
        if (isBuiltin()) {
            littleEndianOutput.writeByte(this.field_2_builtin_style);
            littleEndianOutput.writeByte(this.field_3_outline_style_level);
            return;
        }
        littleEndianOutput.writeShort(this.field_4_name.length());
        littleEndianOutput.writeByte(this.field_3_stringHasMultibyte ? 1 : 0);
        if (this.field_3_stringHasMultibyte) {
            StringUtil.putUnicodeLE(getName(), littleEndianOutput);
        } else {
            StringUtil.putCompressedUnicode(getName(), littleEndianOutput);
        }
    }

    public void setBuiltinStyle(int i2) {
        this.field_1_xf_index = isBuiltinFlag.set(this.field_1_xf_index);
        this.field_2_builtin_style = i2;
    }

    public void setName(String str) {
        this.field_4_name = str;
        this.field_3_stringHasMultibyte = StringUtil.hasMultibyte(str);
        this.field_1_xf_index = isBuiltinFlag.clear(this.field_1_xf_index);
    }

    public void setOutlineStyleLevel(int i2) {
        this.field_3_outline_style_level = i2 & 255;
    }

    public void setXFIndex(int i2) {
        this.field_1_xf_index = styleIndexMask.setValue(this.field_1_xf_index, i2);
    }

    @Override // org.apache.poi.hssf.record.Record
    public String toString() {
        StringBuilder d2 = a.d("[STYLE]\n", "    .xf_index_raw =");
        d2.append(HexDump.shortToHex(this.field_1_xf_index));
        d2.append("\n");
        d2.append("        .type     =");
        d2.append(isBuiltin() ? "built-in" : "user-defined");
        d2.append("\n");
        d2.append("        .xf_index =");
        d2.append(HexDump.shortToHex(getXFIndex()));
        d2.append("\n");
        if (isBuiltin()) {
            d2.append("    .builtin_style=");
            d2.append(HexDump.byteToHex(this.field_2_builtin_style));
            d2.append("\n");
            d2.append("    .outline_level=");
            d2.append(HexDump.byteToHex(this.field_3_outline_style_level));
            d2.append("\n");
        } else {
            d2.append("    .name        =");
            d2.append(getName());
            d2.append("\n");
        }
        d2.append("[/STYLE]\n");
        return d2.toString();
    }

    public StyleRecord(RecordInputStream recordInputStream) {
        this.field_1_xf_index = recordInputStream.readShort();
        if (isBuiltin()) {
            this.field_2_builtin_style = recordInputStream.readByte();
            this.field_3_outline_style_level = recordInputStream.readByte();
            return;
        }
        short readShort = recordInputStream.readShort();
        boolean z = true;
        if (recordInputStream.remaining() >= 1) {
            z = recordInputStream.readByte() == 0 ? false : z;
            this.field_3_stringHasMultibyte = z;
            if (z) {
                this.field_4_name = StringUtil.readUnicodeLE(recordInputStream, readShort);
            } else {
                this.field_4_name = StringUtil.readCompressedUnicode(recordInputStream, readShort);
            }
        } else if (readShort == 0) {
            this.field_4_name = "";
        } else {
            throw new RecordFormatException("Ran out of data reading style record");
        }
    }
}
