package org.apache.poi.hssf.record;

import b.b.a.a.a;
import org.apache.poi.util.LittleEndianOutput;
import org.apache.poi.util.POILogFactory;
import org.apache.poi.util.POILogger;
import org.apache.poi.util.StringUtil;

public final class SupBookRecord extends StandardRecord {
    public static final char CH_ALT_STARTUP_DIR = 7;
    public static final char CH_DOWN_DIR = 3;
    public static final char CH_LIB_DIR = '\b';
    public static final char CH_LONG_VOLUME = 5;
    public static final char CH_SAME_VOLUME = 2;
    public static final char CH_STARTUP_DIR = 6;
    public static final char CH_UP_DIR = 4;
    public static final char CH_VOLUME = 1;
    public static final String PATH_SEPERATOR = System.getProperty("file.separator");
    public static final short SMALL_RECORD_SIZE = 4;
    public static final short TAG_ADD_IN_FUNCTIONS = 14849;
    public static final short TAG_INTERNAL_REFERENCES = 1025;
    public static final POILogger logger = POILogFactory.getLogger(SupBookRecord.class);
    public static final short sid = 430;
    public boolean _isAddInFunctions;
    public short field_1_number_of_sheets;
    public String field_2_encoded_url;
    public String[] field_3_sheet_names;

    public SupBookRecord(boolean z, short s) {
        this.field_1_number_of_sheets = s;
        this.field_2_encoded_url = null;
        this.field_3_sheet_names = null;
        this._isAddInFunctions = z;
    }

    public static SupBookRecord createAddInFunctions() {
        return new SupBookRecord(true, (short) 1);
    }

    public static SupBookRecord createExternalReferences(String str, String[] strArr) {
        return new SupBookRecord(str, strArr);
    }

    public static SupBookRecord createInternalReferences(short s) {
        return new SupBookRecord(false, s);
    }

    public static String decodeFileName(String str) {
        StringBuilder sb = new StringBuilder();
        int i2 = 1;
        while (i2 < str.length()) {
            char charAt = str.charAt(i2);
            switch (charAt) {
                case 1:
                    i2++;
                    char charAt2 = str.charAt(i2);
                    if (charAt2 != '@') {
                        sb.append(charAt2);
                        sb.append(":");
                        break;
                    } else {
                        sb.append("\\\\");
                        break;
                    }
                case 2:
                    sb.append(PATH_SEPERATOR);
                    break;
                case 3:
                    sb.append(PATH_SEPERATOR);
                    break;
                case 4:
                    sb.append("..");
                    sb.append(PATH_SEPERATOR);
                    break;
                case 5:
                    logger.log(5, "Found unexpected key: ChLongVolume - IGNORING");
                    break;
                case 6:
                case 7:
                case '\b':
                    logger.log(5, "EXCEL.EXE path unkown - using this directoy instead: .");
                    sb.append(".");
                    sb.append(PATH_SEPERATOR);
                    break;
                default:
                    sb.append(charAt);
                    break;
            }
            i2++;
        }
        return sb.toString();
    }

    @Override // org.apache.poi.hssf.record.StandardRecord
    public int getDataSize() {
        if (!isExternalReferences()) {
            return 4;
        }
        int encodedSize = StringUtil.getEncodedSize(this.field_2_encoded_url) + 2;
        int i2 = 0;
        while (true) {
            String[] strArr = this.field_3_sheet_names;
            if (i2 >= strArr.length) {
                return encodedSize;
            }
            encodedSize += StringUtil.getEncodedSize(strArr[i2]);
            i2++;
        }
    }

    public short getNumberOfSheets() {
        return this.field_1_number_of_sheets;
    }

    public String[] getSheetNames() {
        return (String[]) this.field_3_sheet_names.clone();
    }

    @Override // org.apache.poi.hssf.record.Record
    public short getSid() {
        return sid;
    }

    public String getURL() {
        String str = this.field_2_encoded_url;
        char charAt = str.charAt(0);
        if (charAt == 0) {
            return str.substring(1);
        }
        if (charAt == 1) {
            return decodeFileName(str);
        }
        if (charAt != 2) {
            return str;
        }
        return str.substring(1);
    }

    public boolean isAddInFunctions() {
        return this.field_3_sheet_names == null && this._isAddInFunctions;
    }

    public boolean isExternalReferences() {
        return this.field_3_sheet_names != null;
    }

    public boolean isInternalReferences() {
        return this.field_3_sheet_names == null && !this._isAddInFunctions;
    }

    @Override // org.apache.poi.hssf.record.StandardRecord
    public void serialize(LittleEndianOutput littleEndianOutput) {
        littleEndianOutput.writeShort(this.field_1_number_of_sheets);
        if (isExternalReferences()) {
            StringUtil.writeUnicodeString(littleEndianOutput, this.field_2_encoded_url);
            int i2 = 0;
            while (true) {
                String[] strArr = this.field_3_sheet_names;
                if (i2 < strArr.length) {
                    StringUtil.writeUnicodeString(littleEndianOutput, strArr[i2]);
                    i2++;
                } else {
                    return;
                }
            }
        } else {
            littleEndianOutput.writeShort(this._isAddInFunctions ? 14849 : 1025);
        }
    }

    public void setNumberOfSheets(short s) {
        this.field_1_number_of_sheets = s;
    }

    public void setURL(String str) {
        this.field_2_encoded_url = this.field_2_encoded_url.substring(0, 1) + str;
    }

    @Override // org.apache.poi.hssf.record.Record
    public String toString() {
        StringBuffer a = a.a("[SUPBOOK ");
        if (isExternalReferences()) {
            a.append("External References]\n");
            a.append(" .url     = ");
            a.append(this.field_2_encoded_url);
            a.append("\n");
            a.append(" .nSheets = ");
            a.append((int) this.field_1_number_of_sheets);
            a.append("\n");
            String[] strArr = this.field_3_sheet_names;
            for (String str : strArr) {
                a.append("    .name = ");
                a.append(str);
                a.append("\n");
            }
            a.append("[/SUPBOOK");
        } else if (this._isAddInFunctions) {
            a.append("Add-In Functions");
        } else {
            a.append("Internal References");
            a.append(" nSheets=");
            a.append((int) this.field_1_number_of_sheets);
        }
        a.append("]");
        return a.toString();
    }

    public SupBookRecord(String str, String[] strArr) {
        this.field_1_number_of_sheets = (short) strArr.length;
        this.field_2_encoded_url = str;
        this.field_3_sheet_names = strArr;
        this._isAddInFunctions = false;
    }

    public SupBookRecord(RecordInputStream recordInputStream) {
        int remaining = recordInputStream.remaining();
        this.field_1_number_of_sheets = recordInputStream.readShort();
        if (remaining > 4) {
            this._isAddInFunctions = false;
            this.field_2_encoded_url = recordInputStream.readString();
            int i2 = this.field_1_number_of_sheets;
            String[] strArr = new String[i2];
            for (int i3 = 0; i3 < i2; i3++) {
                strArr[i3] = recordInputStream.readString();
            }
            this.field_3_sheet_names = strArr;
            return;
        }
        this.field_2_encoded_url = null;
        this.field_3_sheet_names = null;
        short readShort = recordInputStream.readShort();
        if (readShort == 1025) {
            this._isAddInFunctions = false;
        } else if (readShort == 14849) {
            this._isAddInFunctions = true;
            if (this.field_1_number_of_sheets != 1) {
                throw new RuntimeException(a.a(a.b("Expected 0x0001 for number of sheets field in 'Add-In Functions' but got ("), this.field_1_number_of_sheets, ")"));
            }
        } else {
            throw new RuntimeException(a.a(readShort, a.b("invalid EXTERNALBOOK code ("), ")"));
        }
    }
}
