package org.apache.poi.hssf.record;

import b.b.a.a.a;
import org.apache.poi.hssf.util.CellRangeAddress8Bit;
import org.apache.poi.hssf.util.CellReference;
import org.apache.poi.util.BitField;
import org.apache.poi.util.BitFieldFactory;
import org.apache.poi.util.HexDump;
import org.apache.poi.util.LittleEndianOutput;

public final class TableRecord extends SharedValueRecordBase {
    public static final BitField alwaysCalc = BitFieldFactory.getInstance(1);
    public static final BitField calcOnOpen = BitFieldFactory.getInstance(2);
    public static final BitField colDeleted = BitFieldFactory.getInstance(32);
    public static final BitField oneOrTwoVar = BitFieldFactory.getInstance(8);
    public static final BitField rowDeleted = BitFieldFactory.getInstance(16);
    public static final BitField rowOrColInpCell = BitFieldFactory.getInstance(4);
    public static final short sid = 566;
    public int field_10_colInputCol;
    public int field_5_flags;
    public int field_6_res;
    public int field_7_rowInputRow;
    public int field_8_colInputRow;
    public int field_9_rowInputCol;

    public TableRecord(RecordInputStream recordInputStream) {
        super(recordInputStream);
        this.field_5_flags = recordInputStream.readByte();
        this.field_6_res = recordInputStream.readByte();
        this.field_7_rowInputRow = recordInputStream.readShort();
        this.field_8_colInputRow = recordInputStream.readShort();
        this.field_9_rowInputCol = recordInputStream.readShort();
        this.field_10_colInputCol = recordInputStream.readShort();
    }

    public static CellReference cr(int i2, int i3) {
        int i4 = i3 & 255;
        boolean z = true;
        boolean z2 = (32768 & i3) == 0;
        if ((i3 & 16384) != 0) {
            z = false;
        }
        return new CellReference(i2, i4, z2, z);
    }

    public int getColInputCol() {
        return this.field_10_colInputCol;
    }

    public int getColInputRow() {
        return this.field_8_colInputRow;
    }

    @Override // org.apache.poi.hssf.record.SharedValueRecordBase
    public int getExtraDataSize() {
        return 10;
    }

    public int getFlags() {
        return this.field_5_flags;
    }

    public int getRowInputCol() {
        return this.field_9_rowInputCol;
    }

    public int getRowInputRow() {
        return this.field_7_rowInputRow;
    }

    @Override // org.apache.poi.hssf.record.Record
    public short getSid() {
        return sid;
    }

    public boolean isAlwaysCalc() {
        return alwaysCalc.isSet(this.field_5_flags);
    }

    public boolean isColDeleted() {
        return colDeleted.isSet(this.field_5_flags);
    }

    public boolean isOneNotTwoVar() {
        return oneOrTwoVar.isSet(this.field_5_flags);
    }

    public boolean isRowDeleted() {
        return rowDeleted.isSet(this.field_5_flags);
    }

    public boolean isRowOrColInpCell() {
        return rowOrColInpCell.isSet(this.field_5_flags);
    }

    @Override // org.apache.poi.hssf.record.SharedValueRecordBase
    public void serializeExtraData(LittleEndianOutput littleEndianOutput) {
        littleEndianOutput.writeByte(this.field_5_flags);
        littleEndianOutput.writeByte(this.field_6_res);
        littleEndianOutput.writeShort(this.field_7_rowInputRow);
        littleEndianOutput.writeShort(this.field_8_colInputRow);
        littleEndianOutput.writeShort(this.field_9_rowInputCol);
        littleEndianOutput.writeShort(this.field_10_colInputCol);
    }

    public void setAlwaysCalc(boolean z) {
        this.field_5_flags = alwaysCalc.setBoolean(this.field_5_flags, z);
    }

    public void setColDeleted(boolean z) {
        this.field_5_flags = colDeleted.setBoolean(this.field_5_flags, z);
    }

    public void setColInputCol(int i2) {
        this.field_10_colInputCol = i2;
    }

    public void setColInputRow(int i2) {
        this.field_8_colInputRow = i2;
    }

    public void setFlags(int i2) {
        this.field_5_flags = i2;
    }

    public void setOneNotTwoVar(boolean z) {
        this.field_5_flags = oneOrTwoVar.setBoolean(this.field_5_flags, z);
    }

    public void setRowDeleted(boolean z) {
        this.field_5_flags = rowDeleted.setBoolean(this.field_5_flags, z);
    }

    public void setRowInputCol(int i2) {
        this.field_9_rowInputCol = i2;
    }

    public void setRowInputRow(int i2) {
        this.field_7_rowInputRow = i2;
    }

    public void setRowOrColInpCell(boolean z) {
        this.field_5_flags = rowOrColInpCell.setBoolean(this.field_5_flags, z);
    }

    @Override // org.apache.poi.hssf.record.Record
    public String toString() {
        StringBuffer c = a.c("[TABLE]\n", "    .range    = ");
        c.append(getRange());
        c.append("\n");
        c.append("    .flags    = ");
        c.append(HexDump.byteToHex(this.field_5_flags));
        c.append("\n");
        c.append("    .alwaysClc= ");
        c.append(isAlwaysCalc());
        c.append("\n");
        c.append("    .reserved = ");
        c.append(HexDump.intToHex(this.field_6_res));
        c.append("\n");
        CellReference cr = cr(this.field_7_rowInputRow, this.field_8_colInputRow);
        CellReference cr2 = cr(this.field_9_rowInputCol, this.field_10_colInputCol);
        c.append("    .rowInput = ");
        c.append(cr.formatAsString());
        c.append("\n");
        c.append("    .colInput = ");
        c.append(cr2.formatAsString());
        c.append("\n");
        c.append("[/TABLE]\n");
        return c.toString();
    }

    public TableRecord(CellRangeAddress8Bit cellRangeAddress8Bit) {
        super(cellRangeAddress8Bit);
        this.field_6_res = 0;
    }
}
