package org.apache.poi.hssf.record;

import b.b.a.a.a;
import org.apache.poi.hssf.record.cont.ContinuableRecord;
import org.apache.poi.hssf.record.cont.ContinuableRecordOutput;
import org.apache.poi.hssf.usermodel.HSSFRichTextString;
import org.apache.poi.ss.formula.ptg.OperandPtg;
import org.apache.poi.ss.formula.ptg.Ptg;
import org.apache.poi.util.BitField;
import org.apache.poi.util.BitFieldFactory;
import org.apache.poi.util.HexDump;
import org.apache.poi.util.RecordFormatException;

public final class TextObjectRecord extends ContinuableRecord {
    public static final int FORMAT_RUN_ENCODED_SIZE = 8;
    public static final short HORIZONTAL_TEXT_ALIGNMENT_CENTERED = 2;
    public static final short HORIZONTAL_TEXT_ALIGNMENT_JUSTIFIED = 4;
    public static final short HORIZONTAL_TEXT_ALIGNMENT_LEFT_ALIGNED = 1;
    public static final short HORIZONTAL_TEXT_ALIGNMENT_RIGHT_ALIGNED = 3;
    public static final BitField HorizontalTextAlignment = BitFieldFactory.getInstance(14);
    public static final short TEXT_ORIENTATION_NONE = 0;
    public static final short TEXT_ORIENTATION_ROT_LEFT = 3;
    public static final short TEXT_ORIENTATION_ROT_RIGHT = 2;
    public static final short TEXT_ORIENTATION_TOP_TO_BOTTOM = 1;
    public static final short VERTICAL_TEXT_ALIGNMENT_BOTTOM = 3;
    public static final short VERTICAL_TEXT_ALIGNMENT_CENTER = 2;
    public static final short VERTICAL_TEXT_ALIGNMENT_JUSTIFY = 4;
    public static final short VERTICAL_TEXT_ALIGNMENT_TOP = 1;
    public static final BitField VerticalTextAlignment = BitFieldFactory.getInstance(112);
    public static final short sid = 438;
    public static final BitField textLocked = BitFieldFactory.getInstance(512);
    public OperandPtg _linkRefPtg;
    public HSSFRichTextString _text;
    public Byte _unknownPostFormulaByte;
    public int _unknownPreFormulaInt;
    public int field_1_options;
    public int field_2_textOrientation;
    public int field_3_reserved4;
    public int field_4_reserved5;
    public int field_5_reserved6;
    public int field_8_reserved7;

    public TextObjectRecord() {
    }

    private int getFormattingDataLength() {
        if (this._text.length() < 1) {
            return 0;
        }
        return (this._text.numFormattingRuns() + 1) * 8;
    }

    public static void processFontRuns(RecordInputStream recordInputStream, HSSFRichTextString hSSFRichTextString, int i2) {
        if (i2 % 8 == 0) {
            int i3 = i2 / 8;
            for (int i4 = 0; i4 < i3; i4++) {
                short readShort = recordInputStream.readShort();
                short readShort2 = recordInputStream.readShort();
                recordInputStream.readInt();
                hSSFRichTextString.applyFont(readShort, hSSFRichTextString.length(), readShort2);
            }
            return;
        }
        throw new RecordFormatException(a.b("Bad format run data length ", i2, ")"));
    }

    public static String readRawString(RecordInputStream recordInputStream, int i2) {
        boolean z = true;
        if ((recordInputStream.readByte() & 1) != 0) {
            z = false;
        }
        if (z) {
            return recordInputStream.readCompressedUnicode(i2);
        }
        return recordInputStream.readUnicodeLEString(i2);
    }

    private void serializeTXORecord(ContinuableRecordOutput continuableRecordOutput) {
        continuableRecordOutput.writeShort(this.field_1_options);
        continuableRecordOutput.writeShort(this.field_2_textOrientation);
        continuableRecordOutput.writeShort(this.field_3_reserved4);
        continuableRecordOutput.writeShort(this.field_4_reserved5);
        continuableRecordOutput.writeShort(this.field_5_reserved6);
        continuableRecordOutput.writeShort(this._text.length());
        continuableRecordOutput.writeShort(getFormattingDataLength());
        continuableRecordOutput.writeInt(this.field_8_reserved7);
        OperandPtg operandPtg = this._linkRefPtg;
        if (operandPtg != null) {
            continuableRecordOutput.writeShort(operandPtg.getSize());
            continuableRecordOutput.writeInt(this._unknownPreFormulaInt);
            this._linkRefPtg.write(continuableRecordOutput);
            Byte b2 = this._unknownPostFormulaByte;
            if (b2 != null) {
                continuableRecordOutput.writeByte(b2.byteValue());
            }
        }
    }

    private void serializeTrailingRecords(ContinuableRecordOutput continuableRecordOutput) {
        continuableRecordOutput.writeContinue();
        continuableRecordOutput.writeStringData(this._text.getString());
        continuableRecordOutput.writeContinue();
        writeFormatData(continuableRecordOutput, this._text);
    }

    public static void writeFormatData(ContinuableRecordOutput continuableRecordOutput, HSSFRichTextString hSSFRichTextString) {
        int numFormattingRuns = hSSFRichTextString.numFormattingRuns();
        for (int i2 = 0; i2 < numFormattingRuns; i2++) {
            continuableRecordOutput.writeShort(hSSFRichTextString.getIndexOfFormattingRun(i2));
            short fontOfFormattingRun = hSSFRichTextString.getFontOfFormattingRun(i2);
            if (fontOfFormattingRun == 0) {
                fontOfFormattingRun = 0;
            }
            continuableRecordOutput.writeShort(fontOfFormattingRun);
            continuableRecordOutput.writeInt(0);
        }
        continuableRecordOutput.writeShort(hSSFRichTextString.length());
        continuableRecordOutput.writeShort(0);
        continuableRecordOutput.writeInt(0);
    }

    @Override // org.apache.poi.hssf.record.Record
    public Object clone() {
        TextObjectRecord textObjectRecord = new TextObjectRecord();
        textObjectRecord._text = this._text;
        textObjectRecord.field_1_options = this.field_1_options;
        textObjectRecord.field_2_textOrientation = this.field_2_textOrientation;
        textObjectRecord.field_3_reserved4 = this.field_3_reserved4;
        textObjectRecord.field_4_reserved5 = this.field_4_reserved5;
        textObjectRecord.field_5_reserved6 = this.field_5_reserved6;
        textObjectRecord.field_8_reserved7 = this.field_8_reserved7;
        textObjectRecord._text = this._text;
        OperandPtg operandPtg = this._linkRefPtg;
        if (operandPtg != null) {
            textObjectRecord._unknownPreFormulaInt = this._unknownPreFormulaInt;
            textObjectRecord._linkRefPtg = operandPtg.copy();
            textObjectRecord._unknownPostFormulaByte = this._unknownPostFormulaByte;
        }
        return textObjectRecord;
    }

    public int getHorizontalTextAlignment() {
        return HorizontalTextAlignment.getValue(this.field_1_options);
    }

    public Ptg getLinkRefPtg() {
        return this._linkRefPtg;
    }

    @Override // org.apache.poi.hssf.record.Record
    public short getSid() {
        return sid;
    }

    public HSSFRichTextString getStr() {
        return this._text;
    }

    public int getTextOrientation() {
        return this.field_2_textOrientation;
    }

    public int getVerticalTextAlignment() {
        return VerticalTextAlignment.getValue(this.field_1_options);
    }

    public boolean isTextLocked() {
        return textLocked.isSet(this.field_1_options);
    }

    @Override // org.apache.poi.hssf.record.cont.ContinuableRecord
    public void serialize(ContinuableRecordOutput continuableRecordOutput) {
        serializeTXORecord(continuableRecordOutput);
        if (this._text.getString().length() > 0) {
            serializeTrailingRecords(continuableRecordOutput);
        }
    }

    public void setHorizontalTextAlignment(int i2) {
        this.field_1_options = HorizontalTextAlignment.setValue(this.field_1_options, i2);
    }

    public void setStr(HSSFRichTextString hSSFRichTextString) {
        this._text = hSSFRichTextString;
    }

    public void setTextLocked(boolean z) {
        this.field_1_options = textLocked.setBoolean(this.field_1_options, z);
    }

    public void setTextOrientation(int i2) {
        this.field_2_textOrientation = i2;
    }

    public void setVerticalTextAlignment(int i2) {
        this.field_1_options = VerticalTextAlignment.setValue(this.field_1_options, i2);
    }

    @Override // org.apache.poi.hssf.record.Record
    public String toString() {
        StringBuffer c = a.c("[TXO]\n", "    .options        = ");
        c.append(HexDump.shortToHex(this.field_1_options));
        c.append("\n");
        c.append("         .isHorizontal = ");
        c.append(getHorizontalTextAlignment());
        c.append('\n');
        c.append("         .isVertical   = ");
        c.append(getVerticalTextAlignment());
        c.append('\n');
        c.append("         .textLocked   = ");
        c.append(isTextLocked());
        c.append('\n');
        c.append("    .textOrientation= ");
        c.append(HexDump.shortToHex(getTextOrientation()));
        c.append("\n");
        c.append("    .reserved4      = ");
        a.a(this.field_3_reserved4, c, "\n", "    .reserved5      = ");
        a.a(this.field_4_reserved5, c, "\n", "    .reserved6      = ");
        a.a(this.field_5_reserved6, c, "\n", "    .textLength     = ");
        c.append(HexDump.shortToHex(this._text.length()));
        c.append("\n");
        c.append("    .reserved7      = ");
        c.append(HexDump.intToHex(this.field_8_reserved7));
        c.append("\n");
        c.append("    .string = ");
        c.append(this._text);
        c.append('\n');
        for (int i2 = 0; i2 < this._text.numFormattingRuns(); i2++) {
            c.append("    .textrun = ");
            c.append((int) this._text.getFontOfFormattingRun(i2));
            c.append('\n');
        }
        c.append("[/TXO]\n");
        return c.toString();
    }

    public TextObjectRecord(RecordInputStream recordInputStream) {
        this.field_1_options = recordInputStream.readUShort();
        this.field_2_textOrientation = recordInputStream.readUShort();
        this.field_3_reserved4 = recordInputStream.readUShort();
        this.field_4_reserved5 = recordInputStream.readUShort();
        this.field_5_reserved6 = recordInputStream.readUShort();
        int readUShort = recordInputStream.readUShort();
        int readUShort2 = recordInputStream.readUShort();
        this.field_8_reserved7 = recordInputStream.readInt();
        if (recordInputStream.remaining() <= 0) {
            this._linkRefPtg = null;
        } else if (recordInputStream.remaining() >= 11) {
            int readUShort3 = recordInputStream.readUShort();
            this._unknownPreFormulaInt = recordInputStream.readInt();
            Ptg[] readTokens = Ptg.readTokens(readUShort3, recordInputStream);
            if (readTokens.length == 1) {
                this._linkRefPtg = (OperandPtg) readTokens[0];
                if (recordInputStream.remaining() > 0) {
                    this._unknownPostFormulaByte = Byte.valueOf(recordInputStream.readByte());
                } else {
                    this._unknownPostFormulaByte = null;
                }
            } else {
                throw new RecordFormatException(a.a(a.b("Read "), readTokens.length, " tokens but expected exactly 1"));
            }
        } else {
            throw new RecordFormatException("Not enough remaining data for a link formula");
        }
        if (recordInputStream.remaining() <= 0) {
            HSSFRichTextString hSSFRichTextString = new HSSFRichTextString(readUShort > 0 ? readRawString(recordInputStream, readUShort) : "");
            this._text = hSSFRichTextString;
            if (readUShort2 > 0) {
                processFontRuns(recordInputStream, hSSFRichTextString, readUShort2);
                return;
            }
            return;
        }
        StringBuilder b2 = a.b("Unused ");
        b2.append(recordInputStream.remaining());
        b2.append(" bytes at end of record");
        throw new RecordFormatException(b2.toString());
    }
}
