package org.apache.poi.hssf.record;

import b.b.a.a.a;
import org.apache.poi.util.BitField;
import org.apache.poi.util.BitFieldFactory;
import org.apache.poi.util.LittleEndianOutput;

public final class WSBoolRecord extends StandardRecord {
    public static final BitField alternateexpression = BitFieldFactory.getInstance(64);
    public static final BitField alternateformula = BitFieldFactory.getInstance(128);
    public static final BitField applystyles = BitFieldFactory.getInstance(32);
    public static final BitField autobreaks = BitFieldFactory.getInstance(1);
    public static final BitField dialog = BitFieldFactory.getInstance(16);
    public static final BitField displayguts = BitFieldFactory.getInstance(6);
    public static final BitField fittopage = BitFieldFactory.getInstance(1);
    public static final BitField rowsumsbelow = BitFieldFactory.getInstance(64);
    public static final BitField rowsumsright = BitFieldFactory.getInstance(128);
    public static final short sid = 129;
    public byte field_1_wsbool;
    public byte field_2_wsbool;

    public WSBoolRecord() {
    }

    @Override // org.apache.poi.hssf.record.Record
    public Object clone() {
        WSBoolRecord wSBoolRecord = new WSBoolRecord();
        wSBoolRecord.field_1_wsbool = this.field_1_wsbool;
        wSBoolRecord.field_2_wsbool = this.field_2_wsbool;
        return wSBoolRecord;
    }

    public boolean getAlternateExpression() {
        return alternateexpression.isSet(this.field_2_wsbool);
    }

    public boolean getAlternateFormula() {
        return alternateformula.isSet(this.field_2_wsbool);
    }

    public boolean getAutobreaks() {
        return autobreaks.isSet(this.field_1_wsbool);
    }

    @Override // org.apache.poi.hssf.record.StandardRecord
    public int getDataSize() {
        return 2;
    }

    public boolean getDialog() {
        return dialog.isSet(this.field_1_wsbool);
    }

    public boolean getDisplayGuts() {
        return displayguts.isSet(this.field_2_wsbool);
    }

    public boolean getFitToPage() {
        return fittopage.isSet(this.field_2_wsbool);
    }

    public boolean getRowSumsBelow() {
        return rowsumsbelow.isSet(this.field_1_wsbool);
    }

    public boolean getRowSumsRight() {
        return rowsumsright.isSet(this.field_1_wsbool);
    }

    @Override // org.apache.poi.hssf.record.Record
    public short getSid() {
        return 129;
    }

    public byte getWSBool1() {
        return this.field_1_wsbool;
    }

    public byte getWSBool2() {
        return this.field_2_wsbool;
    }

    @Override // org.apache.poi.hssf.record.StandardRecord
    public void serialize(LittleEndianOutput littleEndianOutput) {
        littleEndianOutput.writeByte(getWSBool2());
        littleEndianOutput.writeByte(getWSBool1());
    }

    public void setAlternateExpression(boolean z) {
        this.field_2_wsbool = alternateexpression.setByteBoolean(this.field_2_wsbool, z);
    }

    public void setAlternateFormula(boolean z) {
        this.field_2_wsbool = alternateformula.setByteBoolean(this.field_2_wsbool, z);
    }

    public void setAutobreaks(boolean z) {
        this.field_1_wsbool = autobreaks.setByteBoolean(this.field_1_wsbool, z);
    }

    public void setDialog(boolean z) {
        this.field_1_wsbool = dialog.setByteBoolean(this.field_1_wsbool, z);
    }

    public void setDisplayGuts(boolean z) {
        this.field_2_wsbool = displayguts.setByteBoolean(this.field_2_wsbool, z);
    }

    public void setFitToPage(boolean z) {
        this.field_2_wsbool = fittopage.setByteBoolean(this.field_2_wsbool, z);
    }

    public void setRowSumsBelow(boolean z) {
        this.field_1_wsbool = rowsumsbelow.setByteBoolean(this.field_1_wsbool, z);
    }

    public void setRowSumsRight(boolean z) {
        this.field_1_wsbool = rowsumsright.setByteBoolean(this.field_1_wsbool, z);
    }

    public void setWSBool1(byte b2) {
        this.field_1_wsbool = b2;
    }

    public void setWSBool2(byte b2) {
        this.field_2_wsbool = b2;
    }

    @Override // org.apache.poi.hssf.record.Record
    public String toString() {
        StringBuilder b2 = a.b("[WSBOOL]\n    .wsbool1        = ");
        b2.append(Integer.toHexString(getWSBool1()));
        b2.append("\n");
        b2.append("        .autobreaks = ");
        b2.append(getAutobreaks());
        b2.append("\n");
        b2.append("        .dialog     = ");
        b2.append(getDialog());
        b2.append("\n");
        b2.append("        .rowsumsbelw= ");
        b2.append(getRowSumsBelow());
        b2.append("\n");
        b2.append("        .rowsumsrigt= ");
        b2.append(getRowSumsRight());
        b2.append("\n");
        b2.append("    .wsbool2        = ");
        b2.append(Integer.toHexString(getWSBool2()));
        b2.append("\n");
        b2.append("        .fittopage  = ");
        b2.append(getFitToPage());
        b2.append("\n");
        b2.append("        .displayguts= ");
        b2.append(getDisplayGuts());
        b2.append("\n");
        b2.append("        .alternateex= ");
        b2.append(getAlternateExpression());
        b2.append("\n");
        b2.append("        .alternatefo= ");
        b2.append(getAlternateFormula());
        return a.a(b2, "\n", "[/WSBOOL]\n");
    }

    public WSBoolRecord(RecordInputStream recordInputStream) {
        byte[] readRemainder = recordInputStream.readRemainder();
        this.field_1_wsbool = readRemainder[1];
        this.field_2_wsbool = readRemainder[0];
    }
}
