package org.apache.poi.hssf.record;

import b.b.a.a.a;
import org.apache.poi.util.BitField;
import org.apache.poi.util.BitFieldFactory;
import org.apache.poi.util.LittleEndianOutput;

public final class WindowOneRecord extends StandardRecord {
    public static final BitField hidden = BitFieldFactory.getInstance(1);
    public static final BitField hscroll = BitFieldFactory.getInstance(8);
    public static final BitField iconic = BitFieldFactory.getInstance(2);
    public static final BitField reserved = BitFieldFactory.getInstance(4);
    public static final short sid = 61;
    public static final BitField tabs = BitFieldFactory.getInstance(32);
    public static final BitField vscroll = BitFieldFactory.getInstance(16);
    public short field_1_h_hold;
    public short field_2_v_hold;
    public short field_3_width;
    public short field_4_height;
    public short field_5_options;
    public int field_6_active_sheet;
    public int field_7_first_visible_tab;
    public short field_8_num_selected_tabs;
    public short field_9_tab_width_ratio;

    public WindowOneRecord() {
    }

    public int getActiveSheetIndex() {
        return this.field_6_active_sheet;
    }

    @Override // org.apache.poi.hssf.record.StandardRecord
    public int getDataSize() {
        return 18;
    }

    public boolean getDisplayHorizontalScrollbar() {
        return hscroll.isSet(this.field_5_options);
    }

    public boolean getDisplayTabs() {
        return tabs.isSet(this.field_5_options);
    }

    public boolean getDisplayVerticalScrollbar() {
        return vscroll.isSet(this.field_5_options);
    }

    public int getFirstVisibleTab() {
        return this.field_7_first_visible_tab;
    }

    public short getHeight() {
        return this.field_4_height;
    }

    public boolean getHidden() {
        return hidden.isSet(this.field_5_options);
    }

    public short getHorizontalHold() {
        return this.field_1_h_hold;
    }

    public boolean getIconic() {
        return iconic.isSet(this.field_5_options);
    }

    public short getNumSelectedTabs() {
        return this.field_8_num_selected_tabs;
    }

    public short getOptions() {
        return this.field_5_options;
    }

    @Override // org.apache.poi.hssf.record.Record
    public short getSid() {
        return 61;
    }

    public short getTabWidthRatio() {
        return this.field_9_tab_width_ratio;
    }

    public short getVerticalHold() {
        return this.field_2_v_hold;
    }

    public short getWidth() {
        return this.field_3_width;
    }

    @Override // org.apache.poi.hssf.record.StandardRecord
    public void serialize(LittleEndianOutput littleEndianOutput) {
        littleEndianOutput.writeShort(getHorizontalHold());
        littleEndianOutput.writeShort(getVerticalHold());
        littleEndianOutput.writeShort(getWidth());
        littleEndianOutput.writeShort(getHeight());
        littleEndianOutput.writeShort(getOptions());
        littleEndianOutput.writeShort(getActiveSheetIndex());
        littleEndianOutput.writeShort(getFirstVisibleTab());
        littleEndianOutput.writeShort(getNumSelectedTabs());
        littleEndianOutput.writeShort(getTabWidthRatio());
    }

    public void setActiveSheetIndex(int i2) {
        this.field_6_active_sheet = i2;
    }

    public void setDisplayHorizonalScrollbar(boolean z) {
        this.field_5_options = hscroll.setShortBoolean(this.field_5_options, z);
    }

    public void setDisplayTabs(boolean z) {
        this.field_5_options = tabs.setShortBoolean(this.field_5_options, z);
    }

    public void setDisplayVerticalScrollbar(boolean z) {
        this.field_5_options = vscroll.setShortBoolean(this.field_5_options, z);
    }

    public void setFirstVisibleTab(int i2) {
        this.field_7_first_visible_tab = i2;
    }

    public void setHeight(short s) {
        this.field_4_height = s;
    }

    public void setHidden(boolean z) {
        this.field_5_options = hidden.setShortBoolean(this.field_5_options, z);
    }

    public void setHorizontalHold(short s) {
        this.field_1_h_hold = s;
    }

    public void setIconic(boolean z) {
        this.field_5_options = iconic.setShortBoolean(this.field_5_options, z);
    }

    public void setNumSelectedTabs(short s) {
        this.field_8_num_selected_tabs = s;
    }

    public void setOptions(short s) {
        this.field_5_options = s;
    }

    public void setTabWidthRatio(short s) {
        this.field_9_tab_width_ratio = s;
    }

    public void setVerticalHold(short s) {
        this.field_2_v_hold = s;
    }

    public void setWidth(short s) {
        this.field_3_width = s;
    }

    @Override // org.apache.poi.hssf.record.Record
    public String toString() {
        StringBuilder b2 = a.b("[WINDOW1]\n    .h_hold          = ");
        b2.append(Integer.toHexString(getHorizontalHold()));
        b2.append("\n");
        b2.append("    .v_hold          = ");
        b2.append(Integer.toHexString(getVerticalHold()));
        b2.append("\n");
        b2.append("    .width           = ");
        b2.append(Integer.toHexString(getWidth()));
        b2.append("\n");
        b2.append("    .height          = ");
        b2.append(Integer.toHexString(getHeight()));
        b2.append("\n");
        b2.append("    .options         = ");
        b2.append(Integer.toHexString(getOptions()));
        b2.append("\n");
        b2.append("        .hidden      = ");
        b2.append(getHidden());
        b2.append("\n");
        b2.append("        .iconic      = ");
        b2.append(getIconic());
        b2.append("\n");
        b2.append("        .hscroll     = ");
        b2.append(getDisplayHorizontalScrollbar());
        b2.append("\n");
        b2.append("        .vscroll     = ");
        b2.append(getDisplayVerticalScrollbar());
        b2.append("\n");
        b2.append("        .tabs        = ");
        b2.append(getDisplayTabs());
        b2.append("\n");
        b2.append("    .activeSheet     = ");
        b2.append(Integer.toHexString(getActiveSheetIndex()));
        b2.append("\n");
        b2.append("    .firstVisibleTab    = ");
        b2.append(Integer.toHexString(getFirstVisibleTab()));
        b2.append("\n");
        b2.append("    .numselectedtabs = ");
        b2.append(Integer.toHexString(getNumSelectedTabs()));
        b2.append("\n");
        b2.append("    .tabwidthratio   = ");
        b2.append(Integer.toHexString(getTabWidthRatio()));
        b2.append("\n");
        b2.append("[/WINDOW1]\n");
        return b2.toString();
    }

    public WindowOneRecord(RecordInputStream recordInputStream) {
        this.field_1_h_hold = recordInputStream.readShort();
        this.field_2_v_hold = recordInputStream.readShort();
        this.field_3_width = recordInputStream.readShort();
        this.field_4_height = recordInputStream.readShort();
        this.field_5_options = recordInputStream.readShort();
        this.field_6_active_sheet = recordInputStream.readShort();
        this.field_7_first_visible_tab = recordInputStream.readShort();
        this.field_8_num_selected_tabs = recordInputStream.readShort();
        this.field_9_tab_width_ratio = recordInputStream.readShort();
    }
}
