package org.apache.poi.hssf.record;

import b.b.a.a.a;
import org.apache.poi.util.BitField;
import org.apache.poi.util.BitFieldFactory;
import org.apache.poi.util.LittleEndianOutput;

public final class WindowTwoRecord extends StandardRecord {
    public static final BitField active = BitFieldFactory.getInstance(1024);
    public static final BitField arabic = BitFieldFactory.getInstance(64);
    public static final BitField defaultHeader = BitFieldFactory.getInstance(32);
    public static final BitField displayFormulas = BitFieldFactory.getInstance(1);
    public static final BitField displayGridlines = BitFieldFactory.getInstance(2);
    public static final BitField displayGuts = BitFieldFactory.getInstance(128);
    public static final BitField displayRowColHeadings = BitFieldFactory.getInstance(4);
    public static final BitField displayZeros = BitFieldFactory.getInstance(16);
    public static final BitField freezePanes = BitFieldFactory.getInstance(8);
    public static final BitField freezePanesNoSplit = BitFieldFactory.getInstance(256);
    public static final BitField savedInPageBreakPreview = BitFieldFactory.getInstance(2048);
    public static final BitField selected = BitFieldFactory.getInstance(512);
    public static final short sid = 574;
    public short field_1_options;
    public short field_2_top_row;
    public short field_3_left_col;
    public int field_4_header_color;
    public short field_5_page_break_zoom;
    public short field_6_normal_zoom;
    public int field_7_reserved;

    public WindowTwoRecord() {
    }

    @Override // org.apache.poi.hssf.record.Record
    public Object clone() {
        WindowTwoRecord windowTwoRecord = new WindowTwoRecord();
        windowTwoRecord.field_1_options = this.field_1_options;
        windowTwoRecord.field_2_top_row = this.field_2_top_row;
        windowTwoRecord.field_3_left_col = this.field_3_left_col;
        windowTwoRecord.field_4_header_color = this.field_4_header_color;
        windowTwoRecord.field_5_page_break_zoom = this.field_5_page_break_zoom;
        windowTwoRecord.field_6_normal_zoom = this.field_6_normal_zoom;
        windowTwoRecord.field_7_reserved = this.field_7_reserved;
        return windowTwoRecord;
    }

    public boolean getArabic() {
        return arabic.isSet(this.field_1_options);
    }

    @Override // org.apache.poi.hssf.record.StandardRecord
    public int getDataSize() {
        return 18;
    }

    public boolean getDefaultHeader() {
        return defaultHeader.isSet(this.field_1_options);
    }

    public boolean getDisplayFormulas() {
        return displayFormulas.isSet(this.field_1_options);
    }

    public boolean getDisplayGridlines() {
        return displayGridlines.isSet(this.field_1_options);
    }

    public boolean getDisplayGuts() {
        return displayGuts.isSet(this.field_1_options);
    }

    public boolean getDisplayRowColHeadings() {
        return displayRowColHeadings.isSet(this.field_1_options);
    }

    public boolean getDisplayZeros() {
        return displayZeros.isSet(this.field_1_options);
    }

    public boolean getFreezePanes() {
        return freezePanes.isSet(this.field_1_options);
    }

    public boolean getFreezePanesNoSplit() {
        return freezePanesNoSplit.isSet(this.field_1_options);
    }

    public int getHeaderColor() {
        return this.field_4_header_color;
    }

    public short getLeftCol() {
        return this.field_3_left_col;
    }

    public short getNormalZoom() {
        return this.field_6_normal_zoom;
    }

    public short getOptions() {
        return this.field_1_options;
    }

    public short getPageBreakZoom() {
        return this.field_5_page_break_zoom;
    }

    public int getReserved() {
        return this.field_7_reserved;
    }

    public boolean getSavedInPageBreakPreview() {
        return savedInPageBreakPreview.isSet(this.field_1_options);
    }

    public boolean getSelected() {
        return selected.isSet(this.field_1_options);
    }

    @Override // org.apache.poi.hssf.record.Record
    public short getSid() {
        return 574;
    }

    public short getTopRow() {
        return this.field_2_top_row;
    }

    public boolean isActive() {
        return active.isSet(this.field_1_options);
    }

    @Override // org.apache.poi.hssf.record.StandardRecord
    public void serialize(LittleEndianOutput littleEndianOutput) {
        littleEndianOutput.writeShort(getOptions());
        littleEndianOutput.writeShort(getTopRow());
        littleEndianOutput.writeShort(getLeftCol());
        littleEndianOutput.writeInt(getHeaderColor());
        littleEndianOutput.writeShort(getPageBreakZoom());
        littleEndianOutput.writeShort(getNormalZoom());
        littleEndianOutput.writeInt(getReserved());
    }

    public void setActive(boolean z) {
        this.field_1_options = active.setShortBoolean(this.field_1_options, z);
    }

    public void setArabic(boolean z) {
        this.field_1_options = arabic.setShortBoolean(this.field_1_options, z);
    }

    public void setDefaultHeader(boolean z) {
        this.field_1_options = defaultHeader.setShortBoolean(this.field_1_options, z);
    }

    public void setDisplayFormulas(boolean z) {
        this.field_1_options = displayFormulas.setShortBoolean(this.field_1_options, z);
    }

    public void setDisplayGridlines(boolean z) {
        this.field_1_options = displayGridlines.setShortBoolean(this.field_1_options, z);
    }

    public void setDisplayGuts(boolean z) {
        this.field_1_options = displayGuts.setShortBoolean(this.field_1_options, z);
    }

    public void setDisplayRowColHeadings(boolean z) {
        this.field_1_options = displayRowColHeadings.setShortBoolean(this.field_1_options, z);
    }

    public void setDisplayZeros(boolean z) {
        this.field_1_options = displayZeros.setShortBoolean(this.field_1_options, z);
    }

    public void setFreezePanes(boolean z) {
        this.field_1_options = freezePanes.setShortBoolean(this.field_1_options, z);
    }

    public void setFreezePanesNoSplit(boolean z) {
        this.field_1_options = freezePanesNoSplit.setShortBoolean(this.field_1_options, z);
    }

    public void setHeaderColor(int i2) {
        this.field_4_header_color = i2;
    }

    public void setLeftCol(short s) {
        this.field_3_left_col = s;
    }

    public void setNormalZoom(short s) {
        this.field_6_normal_zoom = s;
    }

    public void setOptions(short s) {
        this.field_1_options = s;
    }

    public void setPageBreakZoom(short s) {
        this.field_5_page_break_zoom = s;
    }

    public void setReserved(int i2) {
        this.field_7_reserved = i2;
    }

    public void setSavedInPageBreakPreview(boolean z) {
        this.field_1_options = savedInPageBreakPreview.setShortBoolean(this.field_1_options, z);
    }

    public void setSelected(boolean z) {
        this.field_1_options = selected.setShortBoolean(this.field_1_options, z);
    }

    public void setTopRow(short s) {
        this.field_2_top_row = s;
    }

    @Override // org.apache.poi.hssf.record.Record
    public String toString() {
        StringBuffer c = a.c("[WINDOW2]\n", "    .options        = ");
        c.append(Integer.toHexString(getOptions()));
        c.append("\n");
        c.append("       .dispformulas= ");
        c.append(getDisplayFormulas());
        c.append("\n");
        c.append("       .dispgridlins= ");
        c.append(getDisplayGridlines());
        c.append("\n");
        c.append("       .disprcheadin= ");
        c.append(getDisplayRowColHeadings());
        c.append("\n");
        c.append("       .freezepanes = ");
        c.append(getFreezePanes());
        c.append("\n");
        c.append("       .displayzeros= ");
        c.append(getDisplayZeros());
        c.append("\n");
        c.append("       .defaultheadr= ");
        c.append(getDefaultHeader());
        c.append("\n");
        c.append("       .arabic      = ");
        c.append(getArabic());
        c.append("\n");
        c.append("       .displayguts = ");
        c.append(getDisplayGuts());
        c.append("\n");
        c.append("       .frzpnsnosplt= ");
        c.append(getFreezePanesNoSplit());
        c.append("\n");
        c.append("       .selected    = ");
        c.append(getSelected());
        c.append("\n");
        c.append("       .active       = ");
        c.append(isActive());
        c.append("\n");
        c.append("       .svdinpgbrkpv= ");
        c.append(getSavedInPageBreakPreview());
        c.append("\n");
        c.append("    .toprow         = ");
        c.append(Integer.toHexString(getTopRow()));
        c.append("\n");
        c.append("    .leftcol        = ");
        c.append(Integer.toHexString(getLeftCol()));
        c.append("\n");
        c.append("    .headercolor    = ");
        c.append(Integer.toHexString(getHeaderColor()));
        c.append("\n");
        c.append("    .pagebreakzoom  = ");
        c.append(Integer.toHexString(getPageBreakZoom()));
        c.append("\n");
        c.append("    .normalzoom     = ");
        c.append(Integer.toHexString(getNormalZoom()));
        c.append("\n");
        c.append("    .reserved       = ");
        c.append(Integer.toHexString(getReserved()));
        return a.a(c, "\n", "[/WINDOW2]\n");
    }

    public WindowTwoRecord(RecordInputStream recordInputStream) {
        int remaining = recordInputStream.remaining();
        this.field_1_options = recordInputStream.readShort();
        this.field_2_top_row = recordInputStream.readShort();
        this.field_3_left_col = recordInputStream.readShort();
        this.field_4_header_color = recordInputStream.readInt();
        if (remaining > 10) {
            this.field_5_page_break_zoom = recordInputStream.readShort();
            this.field_6_normal_zoom = recordInputStream.readShort();
        }
        if (remaining > 14) {
            this.field_7_reserved = recordInputStream.readInt();
        }
    }
}
