package org.apache.poi.hssf.record;

import b.b.a.a.a;
import java.util.Arrays;
import org.apache.poi.util.LittleEndian;
import org.apache.poi.util.LittleEndianOutput;
import org.apache.poi.util.RecordFormatException;
import org.apache.poi.util.StringUtil;

public final class WriteAccessRecord extends StandardRecord {
    public static final int DATA_SIZE = 112;
    public static final byte[] PADDING;
    public static final byte PAD_CHAR = 32;
    public static final short sid = 92;
    public String field_1_username;

    static {
        byte[] bArr = new byte[112];
        PADDING = bArr;
        Arrays.fill(bArr, (byte) 32);
    }

    public WriteAccessRecord() {
        setUsername("");
    }

    @Override // org.apache.poi.hssf.record.StandardRecord
    public int getDataSize() {
        return 112;
    }

    @Override // org.apache.poi.hssf.record.Record
    public short getSid() {
        return 92;
    }

    public String getUsername() {
        return this.field_1_username;
    }

    @Override // org.apache.poi.hssf.record.StandardRecord
    public void serialize(LittleEndianOutput littleEndianOutput) {
        String username = getUsername();
        boolean hasMultibyte = StringUtil.hasMultibyte(username);
        littleEndianOutput.writeShort(username.length());
        littleEndianOutput.writeByte(hasMultibyte ? 1 : 0);
        if (hasMultibyte) {
            StringUtil.putUnicodeLE(username, littleEndianOutput);
        } else {
            StringUtil.putCompressedUnicode(username, littleEndianOutput);
        }
        littleEndianOutput.write(PADDING, 0, 112 - ((username.length() * (hasMultibyte ? 2 : 1)) + 3));
    }

    public void setUsername(String str) {
        if (112 - ((str.length() * (StringUtil.hasMultibyte(str) ? 2 : 1)) + 3) >= 0) {
            this.field_1_username = str;
            return;
        }
        throw new IllegalArgumentException(a.b("Name is too long: ", str));
    }

    @Override // org.apache.poi.hssf.record.Record
    public String toString() {
        StringBuffer c = a.c("[WRITEACCESS]\n", "    .name = ");
        c.append(this.field_1_username);
        c.append("\n");
        c.append("[/WRITEACCESS]\n");
        return c.toString();
    }

    public WriteAccessRecord(RecordInputStream recordInputStream) {
        String str;
        if (recordInputStream.remaining() <= 112) {
            int readUShort = recordInputStream.readUShort();
            int readUByte = recordInputStream.readUByte();
            if (readUShort > 112 || (readUByte & 254) != 0) {
                int remaining = recordInputStream.remaining() + 3;
                byte[] bArr = new byte[remaining];
                LittleEndian.putUShort(bArr, 0, readUShort);
                LittleEndian.putByte(bArr, 2, readUByte);
                recordInputStream.readFully(bArr, 3, remaining - 3);
                setUsername(new String(bArr, StringUtil.UTF8).trim());
                return;
            }
            if ((readUByte & 1) == 0) {
                str = StringUtil.readCompressedUnicode(recordInputStream, readUShort);
            } else {
                str = StringUtil.readUnicodeLE(recordInputStream, readUShort);
            }
            this.field_1_username = str.trim();
            for (int remaining2 = recordInputStream.remaining(); remaining2 > 0; remaining2--) {
                recordInputStream.readUByte();
            }
            return;
        }
        StringBuilder b2 = a.b("Expected data size (112) but got (");
        b2.append(recordInputStream.remaining());
        b2.append(")");
        throw new RecordFormatException(b2.toString());
    }
}
