package org.apache.poi.hssf.record.aggregates;

import b.b.a.a.a;
import java.util.ArrayList;
import java.util.Collections;
import java.util.Comparator;
import java.util.List;
import org.apache.poi.hssf.model.RecordStream;
import org.apache.poi.hssf.record.ColumnInfoRecord;
import org.apache.poi.hssf.record.aggregates.RecordAggregate;

public final class ColumnInfoRecordsAggregate extends RecordAggregate implements Cloneable {
    public final List<ColumnInfoRecord> records;

    public static final class CIRComparator implements Comparator<ColumnInfoRecord> {
        public static final Comparator<ColumnInfoRecord> instance = new CIRComparator();

        public static int compareColInfos(ColumnInfoRecord columnInfoRecord, ColumnInfoRecord columnInfoRecord2) {
            return columnInfoRecord.getFirstColumn() - columnInfoRecord2.getFirstColumn();
        }

        public int compare(ColumnInfoRecord columnInfoRecord, ColumnInfoRecord columnInfoRecord2) {
            return compareColInfos(columnInfoRecord, columnInfoRecord2);
        }
    }

    public ColumnInfoRecordsAggregate() {
        this.records = new ArrayList();
    }

    private void attemptMergeColInfoRecords(int i2) {
        int size = this.records.size();
        if (i2 < 0 || i2 >= size) {
            StringBuilder a = a.a("colInfoIx ", i2, " is out of range (0..");
            a.append(size - 1);
            a.append(")");
            throw new IllegalArgumentException(a.toString());
        }
        ColumnInfoRecord colInfo = getColInfo(i2);
        int i3 = i2 + 1;
        if (i3 < size && mergeColInfoRecords(colInfo, getColInfo(i3))) {
            this.records.remove(i3);
        }
        if (i2 > 0 && mergeColInfoRecords(getColInfo(i2 - 1), colInfo)) {
            this.records.remove(i2);
        }
    }

    public static ColumnInfoRecord copyColInfo(ColumnInfoRecord columnInfoRecord) {
        return columnInfoRecord.clone();
    }

    private int findColInfoIdx(int i2, int i3) {
        if (i2 < 0) {
            throw new IllegalArgumentException(a.c("column parameter out of range: ", i2));
        } else if (i3 >= 0) {
            while (i3 < this.records.size()) {
                ColumnInfoRecord colInfo = getColInfo(i3);
                if (colInfo.containsColumn(i2)) {
                    return i3;
                }
                if (colInfo.getFirstColumn() > i2) {
                    return -1;
                }
                i3++;
            }
            return -1;
        } else {
            throw new IllegalArgumentException(a.c("fromIdx parameter out of range: ", i3));
        }
    }

    private int findEndOfColumnOutlineGroup(int i2) {
        ColumnInfoRecord columnInfoRecord = this.records.get(i2);
        int outlineLevel = columnInfoRecord.getOutlineLevel();
        while (i2 < this.records.size() - 1) {
            int i3 = i2 + 1;
            ColumnInfoRecord columnInfoRecord2 = this.records.get(i3);
            if (!columnInfoRecord.isAdjacentBefore(columnInfoRecord2) || columnInfoRecord2.getOutlineLevel() < outlineLevel) {
                break;
            }
            columnInfoRecord = columnInfoRecord2;
            i2 = i3;
        }
        return i2;
    }

    private int findStartOfColumnOutlineGroup(int i2) {
        ColumnInfoRecord columnInfoRecord = this.records.get(i2);
        int outlineLevel = columnInfoRecord.getOutlineLevel();
        while (i2 != 0) {
            ColumnInfoRecord columnInfoRecord2 = this.records.get(i2 - 1);
            if (!columnInfoRecord2.isAdjacentBefore(columnInfoRecord) || columnInfoRecord2.getOutlineLevel() < outlineLevel) {
                break;
            }
            i2--;
            columnInfoRecord = columnInfoRecord2;
        }
        return i2;
    }

    private ColumnInfoRecord getColInfo(int i2) {
        return this.records.get(i2);
    }

    private boolean isColumnGroupCollapsed(int i2) {
        int findEndOfColumnOutlineGroup = findEndOfColumnOutlineGroup(i2);
        int i3 = findEndOfColumnOutlineGroup + 1;
        if (i3 >= this.records.size()) {
            return false;
        }
        ColumnInfoRecord colInfo = getColInfo(i3);
        if (!getColInfo(findEndOfColumnOutlineGroup).isAdjacentBefore(colInfo)) {
            return false;
        }
        return colInfo.getCollapsed();
    }

    /* JADX WARNING: Removed duplicated region for block: B:13:0x004a A[RETURN] */
    /* JADX WARNING: Removed duplicated region for block: B:14:0x004b A[RETURN] */
    /* JADX WARNING: Removed duplicated region for block: B:8:0x002e  */
    private boolean isColumnGroupHiddenByParent(int i2) {
        boolean z;
        int i3;
        int findStartOfColumnOutlineGroup;
        boolean z2;
        int findEndOfColumnOutlineGroup = findEndOfColumnOutlineGroup(i2);
        int i4 = 0;
        if (findEndOfColumnOutlineGroup < this.records.size()) {
            ColumnInfoRecord colInfo = getColInfo(findEndOfColumnOutlineGroup + 1);
            if (getColInfo(findEndOfColumnOutlineGroup).isAdjacentBefore(colInfo)) {
                i3 = colInfo.getOutlineLevel();
                z = colInfo.getHidden();
                findStartOfColumnOutlineGroup = findStartOfColumnOutlineGroup(i2);
                if (findStartOfColumnOutlineGroup > 0) {
                    ColumnInfoRecord colInfo2 = getColInfo(findStartOfColumnOutlineGroup - 1);
                    if (colInfo2.isAdjacentBefore(getColInfo(findStartOfColumnOutlineGroup))) {
                        i4 = colInfo2.getOutlineLevel();
                        z2 = colInfo2.getHidden();
                        return i3 > i4 ? z : z2;
                    }
                }
                z2 = false;
                if (i3 > i4) {
                }
            }
        }
        i3 = 0;
        z = false;
        findStartOfColumnOutlineGroup = findStartOfColumnOutlineGroup(i2);
        if (findStartOfColumnOutlineGroup > 0) {
        }
        z2 = false;
        if (i3 > i4) {
        }
    }

    public static boolean mergeColInfoRecords(ColumnInfoRecord columnInfoRecord, ColumnInfoRecord columnInfoRecord2) {
        if (!columnInfoRecord.isAdjacentBefore(columnInfoRecord2) || !columnInfoRecord.formatMatches(columnInfoRecord2)) {
            return false;
        }
        columnInfoRecord.setLastColumn(columnInfoRecord2.getLastColumn());
        return true;
    }

    public static void setColumnInfoFields(ColumnInfoRecord columnInfoRecord, Short sh, Integer num, Integer num2, Boolean bool, Boolean bool2) {
        if (sh != null) {
            columnInfoRecord.setXFIndex(sh.shortValue());
        }
        if (num != null) {
            columnInfoRecord.setColumnWidth(num.intValue());
        }
        if (num2 != null) {
            columnInfoRecord.setOutlineLevel(num2.shortValue());
        }
        if (bool != null) {
            columnInfoRecord.setHidden(bool.booleanValue());
        }
        if (bool2 != null) {
            columnInfoRecord.setCollapsed(bool2.booleanValue());
        }
    }

    private int setGroupHidden(int i2, int i3, boolean z) {
        ColumnInfoRecord colInfo = getColInfo(i2);
        while (i2 < this.records.size()) {
            colInfo.setHidden(z);
            i2++;
            if (i2 < this.records.size()) {
                ColumnInfoRecord colInfo2 = getColInfo(i2);
                if (!colInfo.isAdjacentBefore(colInfo2) || colInfo2.getOutlineLevel() < i3) {
                    break;
                }
                colInfo = colInfo2;
            }
        }
        return colInfo.getLastColumn();
    }

    public void collapseColumn(int i2) {
        int findColInfoIdx = findColInfoIdx(i2, 0);
        if (findColInfoIdx != -1) {
            int findStartOfColumnOutlineGroup = findStartOfColumnOutlineGroup(findColInfoIdx);
            setColumn(setGroupHidden(findStartOfColumnOutlineGroup, getColInfo(findStartOfColumnOutlineGroup).getOutlineLevel(), true) + 1, null, null, null, null, Boolean.TRUE);
        }
    }

    public void expandColumn(int i2) {
        int findColInfoIdx = findColInfoIdx(i2, 0);
        if (findColInfoIdx != -1 && isColumnGroupCollapsed(findColInfoIdx)) {
            int findEndOfColumnOutlineGroup = findEndOfColumnOutlineGroup(findColInfoIdx);
            ColumnInfoRecord colInfo = getColInfo(findEndOfColumnOutlineGroup);
            if (!isColumnGroupHiddenByParent(findColInfoIdx)) {
                int outlineLevel = colInfo.getOutlineLevel();
                for (int findStartOfColumnOutlineGroup = findStartOfColumnOutlineGroup(findColInfoIdx); findStartOfColumnOutlineGroup <= findEndOfColumnOutlineGroup; findStartOfColumnOutlineGroup++) {
                    ColumnInfoRecord colInfo2 = getColInfo(findStartOfColumnOutlineGroup);
                    if (outlineLevel == colInfo2.getOutlineLevel()) {
                        colInfo2.setHidden(false);
                    }
                }
            }
            setColumn(colInfo.getLastColumn() + 1, null, null, null, null, Boolean.FALSE);
        }
    }

    public ColumnInfoRecord findColumnInfo(int i2) {
        int size = this.records.size();
        for (int i3 = 0; i3 < size; i3++) {
            ColumnInfoRecord colInfo = getColInfo(i3);
            if (colInfo.containsColumn(i2)) {
                return colInfo;
            }
        }
        return null;
    }

    public int getMaxOutlineLevel() {
        int size = this.records.size();
        int i2 = 0;
        for (int i3 = 0; i3 < size; i3++) {
            i2 = Math.max(getColInfo(i3).getOutlineLevel(), i2);
        }
        return i2;
    }

    public int getNumColumns() {
        return this.records.size();
    }

    public int getOutlineLevel(int i2) {
        ColumnInfoRecord findColumnInfo = findColumnInfo(i2);
        if (findColumnInfo != null) {
            return findColumnInfo.getOutlineLevel();
        }
        return 0;
    }

    public void groupColumnRange(int i2, int i3, boolean z) {
        int i4;
        int i5;
        int i6 = 0;
        while (i2 <= i3) {
            int findColInfoIdx = findColInfoIdx(i2, i6);
            if (findColInfoIdx != -1) {
                int outlineLevel = getColInfo(findColInfoIdx).getOutlineLevel();
                i5 = Math.min(7, Math.max(0, z ? outlineLevel + 1 : outlineLevel - 1));
                i4 = Math.max(0, findColInfoIdx - 1);
            } else {
                i4 = i6;
                i5 = 1;
            }
            setColumn(i2, null, null, Integer.valueOf(i5), null, null);
            i2++;
            i6 = i4;
        }
    }

    public void insertColumn(ColumnInfoRecord columnInfoRecord) {
        this.records.add(columnInfoRecord);
        Collections.sort(this.records, CIRComparator.instance);
    }

    public void setColumn(int i2, Short sh, Integer num, Integer num2, Boolean bool, Boolean bool2) {
        ColumnInfoRecord columnInfoRecord;
        boolean z = false;
        int i3 = 0;
        while (true) {
            if (i3 >= this.records.size()) {
                break;
            }
            columnInfoRecord = this.records.get(i3);
            if (columnInfoRecord.containsColumn(i2)) {
                break;
            } else if (columnInfoRecord.getFirstColumn() > i2) {
                break;
            } else {
                i3++;
            }
        }
        columnInfoRecord = null;
        if (columnInfoRecord == null) {
            ColumnInfoRecord columnInfoRecord2 = new ColumnInfoRecord();
            columnInfoRecord2.setFirstColumn(i2);
            columnInfoRecord2.setLastColumn(i2);
            setColumnInfoFields(columnInfoRecord2, sh, num, num2, bool, bool2);
            insertColumn(i3, columnInfoRecord2);
            attemptMergeColInfoRecords(i3);
            return;
        }
        boolean z2 = (sh == null || columnInfoRecord.getXFIndex() == sh.shortValue()) ? false : true;
        boolean z3 = (num == null || columnInfoRecord.getColumnWidth() == num.shortValue()) ? false : true;
        boolean z4 = (num2 == null || columnInfoRecord.getOutlineLevel() == num2.intValue()) ? false : true;
        boolean z5 = (bool == null || columnInfoRecord.getHidden() == bool.booleanValue()) ? false : true;
        boolean z6 = (bool2 == null || columnInfoRecord.getCollapsed() == bool2.booleanValue()) ? false : true;
        if (z2 || z3 || z4 || z5 || z6) {
            z = true;
        }
        if (z) {
            if (columnInfoRecord.getFirstColumn() == i2 && columnInfoRecord.getLastColumn() == i2) {
                setColumnInfoFields(columnInfoRecord, sh, num, num2, bool, bool2);
                attemptMergeColInfoRecords(i3);
            } else if (columnInfoRecord.getFirstColumn() == i2 || columnInfoRecord.getLastColumn() == i2) {
                if (columnInfoRecord.getFirstColumn() == i2) {
                    columnInfoRecord.setFirstColumn(i2 + 1);
                } else {
                    columnInfoRecord.setLastColumn(i2 - 1);
                    i3++;
                }
                ColumnInfoRecord copyColInfo = copyColInfo(columnInfoRecord);
                copyColInfo.setFirstColumn(i2);
                copyColInfo.setLastColumn(i2);
                setColumnInfoFields(copyColInfo, sh, num, num2, bool, bool2);
                insertColumn(i3, copyColInfo);
                attemptMergeColInfoRecords(i3);
            } else {
                ColumnInfoRecord copyColInfo2 = copyColInfo(columnInfoRecord);
                ColumnInfoRecord copyColInfo3 = copyColInfo(columnInfoRecord);
                int lastColumn = columnInfoRecord.getLastColumn();
                columnInfoRecord.setLastColumn(i2 - 1);
                copyColInfo2.setFirstColumn(i2);
                copyColInfo2.setLastColumn(i2);
                setColumnInfoFields(copyColInfo2, sh, num, num2, bool, bool2);
                int i4 = i3 + 1;
                insertColumn(i4, copyColInfo2);
                copyColInfo3.setFirstColumn(i2 + 1);
                copyColInfo3.setLastColumn(lastColumn);
                insertColumn(i4 + 1, copyColInfo3);
            }
        }
    }

    @Override // org.apache.poi.hssf.record.aggregates.RecordAggregate
    public void visitContainedRecords(RecordAggregate.RecordVisitor recordVisitor) {
        int size = this.records.size();
        if (size >= 1) {
            ColumnInfoRecord columnInfoRecord = null;
            int i2 = 0;
            while (i2 < size) {
                ColumnInfoRecord columnInfoRecord2 = this.records.get(i2);
                recordVisitor.visitRecord(columnInfoRecord2);
                if (columnInfoRecord == null || CIRComparator.compareColInfos(columnInfoRecord, columnInfoRecord2) <= 0) {
                    i2++;
                    columnInfoRecord = columnInfoRecord2;
                } else {
                    throw new RuntimeException("Column info records are out of order");
                }
            }
        }
    }

    @Override // java.lang.Object
    public ColumnInfoRecordsAggregate clone() {
        ColumnInfoRecordsAggregate columnInfoRecordsAggregate = new ColumnInfoRecordsAggregate();
        for (ColumnInfoRecord columnInfoRecord : this.records) {
            columnInfoRecordsAggregate.records.add(columnInfoRecord.clone());
        }
        return columnInfoRecordsAggregate;
    }

    public ColumnInfoRecordsAggregate(RecordStream recordStream) {
        this();
        ColumnInfoRecord columnInfoRecord = null;
        boolean z = true;
        while (recordStream.peekNextClass() == ColumnInfoRecord.class) {
            ColumnInfoRecord columnInfoRecord2 = (ColumnInfoRecord) recordStream.getNext();
            this.records.add(columnInfoRecord2);
            if (columnInfoRecord != null && CIRComparator.compareColInfos(columnInfoRecord, columnInfoRecord2) > 0) {
                z = false;
            }
            columnInfoRecord = columnInfoRecord2;
        }
        if (this.records.size() < 1) {
            throw new RuntimeException("No column info records found");
        } else if (!z) {
            Collections.sort(this.records, CIRComparator.instance);
        }
    }

    private void insertColumn(int i2, ColumnInfoRecord columnInfoRecord) {
        this.records.add(i2, columnInfoRecord);
    }
}
