package org.apache.poi.hssf.record.aggregates;

import b.b.a.a.a;
import java.util.ArrayList;
import java.util.List;
import org.apache.poi.hssf.model.RecordStream;
import org.apache.poi.hssf.record.CFHeader12Record;
import org.apache.poi.hssf.record.CFHeaderRecord;
import org.apache.poi.hssf.record.aggregates.RecordAggregate;
import org.apache.poi.ss.formula.FormulaShifter;

public final class ConditionalFormattingTable extends RecordAggregate {
    public final List<CFRecordsAggregate> _cfHeaders;

    public ConditionalFormattingTable() {
        this._cfHeaders = new ArrayList();
    }

    private void checkIndex(int i2) {
        if (i2 < 0 || i2 >= this._cfHeaders.size()) {
            StringBuilder a = a.a("Specified CF index ", i2, " is outside the allowable range (0..");
            a.append(this._cfHeaders.size() - 1);
            a.append(")");
            throw new IllegalArgumentException(a.toString());
        }
    }

    public int add(CFRecordsAggregate cFRecordsAggregate) {
        cFRecordsAggregate.getHeader().setID(this._cfHeaders.size());
        this._cfHeaders.add(cFRecordsAggregate);
        return this._cfHeaders.size() - 1;
    }

    public CFRecordsAggregate get(int i2) {
        checkIndex(i2);
        return this._cfHeaders.get(i2);
    }

    public void remove(int i2) {
        checkIndex(i2);
        this._cfHeaders.remove(i2);
    }

    public int size() {
        return this._cfHeaders.size();
    }

    public void updateFormulasAfterCellShift(FormulaShifter formulaShifter, int i2) {
        int i3 = 0;
        while (i3 < this._cfHeaders.size()) {
            if (!this._cfHeaders.get(i3).updateFormulasAfterCellShift(formulaShifter, i2)) {
                this._cfHeaders.remove(i3);
                i3--;
            }
            i3++;
        }
    }

    @Override // org.apache.poi.hssf.record.aggregates.RecordAggregate
    public void visitContainedRecords(RecordAggregate.RecordVisitor recordVisitor) {
        for (CFRecordsAggregate cFRecordsAggregate : this._cfHeaders) {
            cFRecordsAggregate.visitContainedRecords(recordVisitor);
        }
    }

    public ConditionalFormattingTable(RecordStream recordStream) {
        ArrayList arrayList = new ArrayList();
        while (true) {
            if (recordStream.peekNextClass() == CFHeaderRecord.class || recordStream.peekNextClass() == CFHeader12Record.class) {
                arrayList.add(CFRecordsAggregate.createCFAggregate(recordStream));
            } else {
                this._cfHeaders = arrayList;
                return;
            }
        }
    }
}
