package org.apache.poi.hssf.record.aggregates;

import b.b.a.a.a;
import java.util.ArrayList;
import java.util.List;
import org.apache.poi.hssf.model.RecordStream;
import org.apache.poi.hssf.record.MergeCellsRecord;
import org.apache.poi.hssf.record.aggregates.RecordAggregate;
import org.apache.poi.ss.util.CellRangeAddress;
import org.apache.poi.ss.util.CellRangeAddressList;

public final class MergedCellsTable extends RecordAggregate {
    public static int MAX_MERGED_REGIONS = 1027;
    public final List<CellRangeAddress> _mergedRegions = new ArrayList();

    private void addMergeCellsRecord(MergeCellsRecord mergeCellsRecord) {
        short numAreas = mergeCellsRecord.getNumAreas();
        for (int i2 = 0; i2 < numAreas; i2++) {
            this._mergedRegions.add(mergeCellsRecord.getAreaAt(i2));
        }
    }

    private void checkIndex(int i2) {
        if (i2 < 0 || i2 >= this._mergedRegions.size()) {
            StringBuilder a = a.a("Specified CF index ", i2, " is outside the allowable range (0..");
            a.append(this._mergedRegions.size() - 1);
            a.append(")");
            throw new IllegalArgumentException(a.toString());
        }
    }

    public void addArea(int i2, int i3, int i4, int i5) {
        this._mergedRegions.add(new CellRangeAddress(i2, i4, i3, i5));
    }

    public void addRecords(MergeCellsRecord[] mergeCellsRecordArr) {
        for (MergeCellsRecord mergeCellsRecord : mergeCellsRecordArr) {
            addMergeCellsRecord(mergeCellsRecord);
        }
    }

    public CellRangeAddress get(int i2) {
        checkIndex(i2);
        return this._mergedRegions.get(i2);
    }

    public int getNumberOfMergedRegions() {
        return this._mergedRegions.size();
    }

    @Override // org.apache.poi.hssf.record.aggregates.RecordAggregate, org.apache.poi.hssf.record.RecordBase
    public int getRecordSize() {
        int size = this._mergedRegions.size();
        if (size < 1) {
            return 0;
        }
        int i2 = MAX_MERGED_REGIONS;
        int i3 = size / i2;
        return CellRangeAddressList.getEncodedSize(size % i2) + ((CellRangeAddressList.getEncodedSize(i2) + 4) * i3) + 4;
    }

    public void read(RecordStream recordStream) {
        List<CellRangeAddress> list = this._mergedRegions;
        while (recordStream.peekNextClass() == MergeCellsRecord.class) {
            MergeCellsRecord mergeCellsRecord = (MergeCellsRecord) recordStream.getNext();
            short numAreas = mergeCellsRecord.getNumAreas();
            for (int i2 = 0; i2 < numAreas; i2++) {
                list.add(mergeCellsRecord.getAreaAt(i2));
            }
        }
    }

    public void remove(int i2) {
        checkIndex(i2);
        this._mergedRegions.remove(i2);
    }

    @Override // org.apache.poi.hssf.record.aggregates.RecordAggregate
    public void visitContainedRecords(RecordAggregate.RecordVisitor recordVisitor) {
        int size = this._mergedRegions.size();
        if (size >= 1) {
            int i2 = MAX_MERGED_REGIONS;
            int i3 = size / i2;
            int i4 = size % i2;
            CellRangeAddress[] cellRangeAddressArr = new CellRangeAddress[size];
            this._mergedRegions.toArray(cellRangeAddressArr);
            for (int i5 = 0; i5 < i3; i5++) {
                int i6 = MAX_MERGED_REGIONS;
                recordVisitor.visitRecord(new MergeCellsRecord(cellRangeAddressArr, i5 * i6, i6));
            }
            if (i4 > 0) {
                recordVisitor.visitRecord(new MergeCellsRecord(cellRangeAddressArr, i3 * MAX_MERGED_REGIONS, i4));
            }
        }
    }
}
