package org.apache.poi.hssf.record.aggregates;

import org.apache.poi.hssf.record.Record;
import org.apache.poi.hssf.record.RecordBase;

public abstract class RecordAggregate extends RecordBase {

    public static final class PositionTrackingVisitor implements RecordVisitor {
        public int _position;
        public final RecordVisitor _rv;

        public PositionTrackingVisitor(RecordVisitor recordVisitor, int i2) {
            this._rv = recordVisitor;
            this._position = i2;
        }

        public int getPosition() {
            return this._position;
        }

        public void setPosition(int i2) {
            this._position = i2;
        }

        @Override // org.apache.poi.hssf.record.aggregates.RecordAggregate.RecordVisitor
        public void visitRecord(Record record) {
            this._position = record.getRecordSize() + this._position;
            this._rv.visitRecord(record);
        }
    }

    public static final class RecordSizingVisitor implements RecordVisitor {
        public int _totalSize = 0;

        public int getTotalSize() {
            return this._totalSize;
        }

        @Override // org.apache.poi.hssf.record.aggregates.RecordAggregate.RecordVisitor
        public void visitRecord(Record record) {
            this._totalSize = record.getRecordSize() + this._totalSize;
        }
    }

    public interface RecordVisitor {
        void visitRecord(Record record);
    }

    public static final class SerializingRecordVisitor implements RecordVisitor {
        public int _countBytesWritten = 0;
        public final byte[] _data;
        public final int _startOffset;

        public SerializingRecordVisitor(byte[] bArr, int i2) {
            this._data = bArr;
            this._startOffset = i2;
        }

        public int countBytesWritten() {
            return this._countBytesWritten;
        }

        @Override // org.apache.poi.hssf.record.aggregates.RecordAggregate.RecordVisitor
        public void visitRecord(Record record) {
            int i2 = this._startOffset;
            int i3 = this._countBytesWritten;
            this._countBytesWritten = record.serialize(i2 + i3, this._data) + i3;
        }
    }

    @Override // org.apache.poi.hssf.record.RecordBase
    public int getRecordSize() {
        RecordSizingVisitor recordSizingVisitor = new RecordSizingVisitor();
        visitContainedRecords(recordSizingVisitor);
        return recordSizingVisitor.getTotalSize();
    }

    @Override // org.apache.poi.hssf.record.RecordBase
    public final int serialize(int i2, byte[] bArr) {
        SerializingRecordVisitor serializingRecordVisitor = new SerializingRecordVisitor(bArr, i2);
        visitContainedRecords(serializingRecordVisitor);
        return serializingRecordVisitor.countBytesWritten();
    }

    public abstract void visitContainedRecords(RecordVisitor recordVisitor);
}
