package org.apache.poi.hssf.record.aggregates;

import b.b.a.a.a;
import java.util.ArrayList;
import java.util.Iterator;
import java.util.List;
import java.util.Map;
import java.util.TreeMap;
import org.apache.poi.hssf.model.RecordStream;
import org.apache.poi.hssf.record.CellValueRecordInterface;
import org.apache.poi.hssf.record.DBCellRecord;
import org.apache.poi.hssf.record.DimensionsRecord;
import org.apache.poi.hssf.record.FormulaRecord;
import org.apache.poi.hssf.record.IndexRecord;
import org.apache.poi.hssf.record.MulBlankRecord;
import org.apache.poi.hssf.record.Record;
import org.apache.poi.hssf.record.RowRecord;
import org.apache.poi.hssf.record.UnknownRecord;
import org.apache.poi.hssf.record.aggregates.RecordAggregate;
import org.apache.poi.ss.SpreadsheetVersion;
import org.apache.poi.ss.formula.FormulaShifter;

public final class RowRecordsAggregate extends RecordAggregate {
    public int _firstrow;
    public int _lastrow;
    public RowRecord[] _rowRecordValues;
    public final Map<Integer, RowRecord> _rowRecords;
    public final SharedValueManager _sharedValueManager;
    public final List<Record> _unknownRecords;
    public final ValueRecordsAggregate _valuesAgg;

    public RowRecordsAggregate() {
        this(SharedValueManager.createEmpty());
    }

    private void addUnknownRecord(Record record) {
        this._unknownRecords.add(record);
    }

    public static RowRecord createRow(int i2) {
        return new RowRecord(i2);
    }

    private int getEndRowNumberForBlock(int i2) {
        int i3 = ((i2 + 1) * 32) - 1;
        if (i3 >= this._rowRecords.size()) {
            i3 = this._rowRecords.size() - 1;
        }
        if (this._rowRecordValues == null) {
            this._rowRecordValues = (RowRecord[]) this._rowRecords.values().toArray(new RowRecord[this._rowRecords.size()]);
        }
        try {
            return this._rowRecordValues[i3].getRowNumber();
        } catch (ArrayIndexOutOfBoundsException unused) {
            throw new RuntimeException(a.c("Did not find end row for block ", i2));
        }
    }

    private int getRowBlockSize(int i2) {
        return getRowCountForBlock(i2) * 20;
    }

    private int getStartRowNumberForBlock(int i2) {
        int i3 = i2 * 32;
        if (this._rowRecordValues == null) {
            this._rowRecordValues = (RowRecord[]) this._rowRecords.values().toArray(new RowRecord[this._rowRecords.size()]);
        }
        try {
            return this._rowRecordValues[i3].getRowNumber();
        } catch (ArrayIndexOutOfBoundsException unused) {
            throw new RuntimeException(a.c("Did not find start row for block ", i2));
        }
    }

    private int visitRowRecordsForBlock(int i2, RecordAggregate.RecordVisitor recordVisitor) {
        int i3 = i2 * 32;
        int i4 = i3 + 32;
        Iterator<RowRecord> it = this._rowRecords.values().iterator();
        int i5 = 0;
        int i6 = 0;
        while (i6 < i3) {
            it.next();
            i6++;
        }
        while (it.hasNext()) {
            int i7 = i6 + 1;
            if (i6 >= i4) {
                break;
            }
            RowRecord next = it.next();
            i5 += next.getRecordSize();
            recordVisitor.visitRecord(next);
            i6 = i7;
        }
        return i5;
    }

    private int writeHidden(RowRecord rowRecord, int i2) {
        short outlineLevel = rowRecord.getOutlineLevel();
        while (rowRecord != null && getRow(i2).getOutlineLevel() >= outlineLevel) {
            rowRecord.setZeroHeight(true);
            i2++;
            rowRecord = getRow(i2);
        }
        return i2;
    }

    public void collapseRow(int i2) {
        int findStartOfRowOutlineGroup = findStartOfRowOutlineGroup(i2);
        int writeHidden = writeHidden(getRow(findStartOfRowOutlineGroup), findStartOfRowOutlineGroup);
        RowRecord row = getRow(writeHidden);
        if (row == null) {
            row = createRow(writeHidden);
            insertRow(row);
        }
        row.setColapsed(true);
    }

    public DimensionsRecord createDimensions() {
        DimensionsRecord dimensionsRecord = new DimensionsRecord();
        dimensionsRecord.setFirstRow(this._firstrow);
        dimensionsRecord.setLastRow(this._lastrow);
        dimensionsRecord.setFirstCol((short) this._valuesAgg.getFirstCellNum());
        dimensionsRecord.setLastCol((short) this._valuesAgg.getLastCellNum());
        return dimensionsRecord;
    }

    public FormulaRecordAggregate createFormula(int i2, int i3) {
        FormulaRecord formulaRecord = new FormulaRecord();
        formulaRecord.setRow(i2);
        formulaRecord.setColumn((short) i3);
        return new FormulaRecordAggregate(formulaRecord, null, this._sharedValueManager);
    }

    public IndexRecord createIndexRecord(int i2, int i3) {
        IndexRecord indexRecord = new IndexRecord();
        indexRecord.setFirstRow(this._firstrow);
        indexRecord.setLastRowAdd1(this._lastrow + 1);
        int rowBlockCount = getRowBlockCount();
        int recordSizeForBlockCount = IndexRecord.getRecordSizeForBlockCount(rowBlockCount) + i2 + i3;
        for (int i4 = 0; i4 < rowBlockCount; i4++) {
            int rowCellBlockSize = this._valuesAgg.getRowCellBlockSize(getStartRowNumberForBlock(i4), getEndRowNumberForBlock(i4)) + recordSizeForBlockCount + getRowBlockSize(i4);
            indexRecord.addDbcell(rowCellBlockSize);
            recordSizeForBlockCount = (getRowCountForBlock(i4) * 2) + 8 + rowCellBlockSize;
        }
        return indexRecord;
    }

    public void expandRow(int i2) {
        if (i2 != -1 && isRowGroupCollapsed(i2)) {
            int findStartOfRowOutlineGroup = findStartOfRowOutlineGroup(i2);
            RowRecord row = getRow(findStartOfRowOutlineGroup);
            int findEndOfRowOutlineGroup = findEndOfRowOutlineGroup(i2);
            if (!isRowGroupHiddenByParent(i2)) {
                while (findStartOfRowOutlineGroup <= findEndOfRowOutlineGroup) {
                    RowRecord row2 = getRow(findStartOfRowOutlineGroup);
                    if (row.getOutlineLevel() == row2.getOutlineLevel() || !isRowGroupCollapsed(findStartOfRowOutlineGroup)) {
                        row2.setZeroHeight(false);
                    }
                    findStartOfRowOutlineGroup++;
                }
            }
            getRow(findEndOfRowOutlineGroup + 1).setColapsed(false);
        }
    }

    public int findEndOfRowOutlineGroup(int i2) {
        short outlineLevel = getRow(i2).getOutlineLevel();
        while (i2 < getLastRowNum() && getRow(i2) != null && getRow(i2).getOutlineLevel() >= outlineLevel) {
            i2++;
        }
        return i2 - 1;
    }

    public int findStartOfRowOutlineGroup(int i2) {
        short outlineLevel = getRow(i2).getOutlineLevel();
        while (i2 >= 0 && getRow(i2) != null) {
            if (getRow(i2).getOutlineLevel() < outlineLevel) {
                return i2 + 1;
            }
            i2--;
        }
        return i2 + 1;
    }

    public Iterator<CellValueRecordInterface> getCellValueIterator() {
        return this._valuesAgg.iterator();
    }

    public int getFirstRowNum() {
        return this._firstrow;
    }

    public Iterator<RowRecord> getIterator() {
        return this._rowRecords.values().iterator();
    }

    public int getLastRowNum() {
        return this._lastrow;
    }

    public int getPhysicalNumberOfRows() {
        return this._rowRecords.size();
    }

    public RowRecord getRow(int i2) {
        int lastRowIndex = SpreadsheetVersion.EXCEL97.getLastRowIndex();
        if (i2 >= 0 && i2 <= lastRowIndex) {
            return this._rowRecords.get(Integer.valueOf(i2));
        }
        throw new IllegalArgumentException(a.a("The row number must be between 0 and ", lastRowIndex, ", but had: ", i2));
    }

    public int getRowBlockCount() {
        int size = this._rowRecords.size() / 32;
        return this._rowRecords.size() % 32 != 0 ? size + 1 : size;
    }

    public int getRowCountForBlock(int i2) {
        int i3 = i2 * 32;
        int i4 = (i3 + 32) - 1;
        if (i4 >= this._rowRecords.size()) {
            i4 = this._rowRecords.size() - 1;
        }
        return (i4 - i3) + 1;
    }

    public void insertCell(CellValueRecordInterface cellValueRecordInterface) {
        this._valuesAgg.insertCell(cellValueRecordInterface);
    }

    public void insertRow(RowRecord rowRecord) {
        this._rowRecords.put(Integer.valueOf(rowRecord.getRowNumber()), rowRecord);
        this._rowRecordValues = null;
        int rowNumber = rowRecord.getRowNumber();
        int i2 = this._firstrow;
        if (rowNumber < i2 || i2 == -1) {
            this._firstrow = rowRecord.getRowNumber();
        }
        int rowNumber2 = rowRecord.getRowNumber();
        int i3 = this._lastrow;
        if (rowNumber2 > i3 || i3 == -1) {
            this._lastrow = rowRecord.getRowNumber();
        }
    }

    public boolean isRowGroupCollapsed(int i2) {
        int findEndOfRowOutlineGroup = findEndOfRowOutlineGroup(i2) + 1;
        if (getRow(findEndOfRowOutlineGroup) == null || !getRow(findEndOfRowOutlineGroup).getColapsed()) {
            return false;
        }
        return true;
    }

    public boolean isRowGroupHiddenByParent(int i2) {
        short s;
        boolean z;
        boolean z2;
        int findEndOfRowOutlineGroup = findEndOfRowOutlineGroup(i2) + 1;
        short s2 = 0;
        if (getRow(findEndOfRowOutlineGroup) == null) {
            z = false;
            s = 0;
        } else {
            s = getRow(findEndOfRowOutlineGroup).getOutlineLevel();
            z = getRow(findEndOfRowOutlineGroup).getZeroHeight();
        }
        int findStartOfRowOutlineGroup = findStartOfRowOutlineGroup(i2) - 1;
        if (findStartOfRowOutlineGroup < 0 || getRow(findStartOfRowOutlineGroup) == null) {
            z2 = false;
        } else {
            s2 = getRow(findStartOfRowOutlineGroup).getOutlineLevel();
            z2 = getRow(findStartOfRowOutlineGroup).getZeroHeight();
        }
        return s > s2 ? z : z2;
    }

    public void removeCell(CellValueRecordInterface cellValueRecordInterface) {
        if (cellValueRecordInterface instanceof FormulaRecordAggregate) {
            ((FormulaRecordAggregate) cellValueRecordInterface).notifyFormulaChanging();
        }
        this._valuesAgg.removeCell(cellValueRecordInterface);
    }

    public void removeRow(RowRecord rowRecord) {
        int rowNumber = rowRecord.getRowNumber();
        this._valuesAgg.removeAllCellsValuesForRow(rowNumber);
        Integer valueOf = Integer.valueOf(rowNumber);
        RowRecord remove = this._rowRecords.remove(valueOf);
        if (remove == null) {
            StringBuilder b2 = a.b("Invalid row index (");
            b2.append(valueOf.intValue());
            b2.append(")");
            throw new RuntimeException(b2.toString());
        } else if (rowRecord == remove) {
            this._rowRecordValues = null;
        } else {
            this._rowRecords.put(valueOf, remove);
            throw new RuntimeException("Attempt to remove row that does not belong to this sheet");
        }
    }

    public void updateFormulasAfterRowShift(FormulaShifter formulaShifter, int i2) {
        this._valuesAgg.updateFormulasAfterRowShift(formulaShifter, i2);
    }

    @Override // org.apache.poi.hssf.record.aggregates.RecordAggregate
    public void visitContainedRecords(RecordAggregate.RecordVisitor recordVisitor) {
        RecordAggregate.PositionTrackingVisitor positionTrackingVisitor = new RecordAggregate.PositionTrackingVisitor(recordVisitor, 0);
        int rowBlockCount = getRowBlockCount();
        for (int i2 = 0; i2 < rowBlockCount; i2++) {
            int visitRowRecordsForBlock = visitRowRecordsForBlock(i2, recordVisitor);
            int i3 = visitRowRecordsForBlock + 0;
            int endRowNumberForBlock = getEndRowNumberForBlock(i2);
            DBCellRecord.Builder builder = new DBCellRecord.Builder();
            int i4 = visitRowRecordsForBlock - 20;
            for (int startRowNumberForBlock = getStartRowNumberForBlock(i2); startRowNumberForBlock <= endRowNumberForBlock; startRowNumberForBlock++) {
                if (this._valuesAgg.rowHasCells(startRowNumberForBlock)) {
                    positionTrackingVisitor.setPosition(0);
                    this._valuesAgg.visitCellsForRow(startRowNumberForBlock, positionTrackingVisitor);
                    int position = positionTrackingVisitor.getPosition();
                    i3 += position;
                    builder.addCellOffset(i4);
                    i4 = position;
                }
            }
            recordVisitor.visitRecord(builder.build(i3));
        }
        for (Record record : this._unknownRecords) {
            recordVisitor.visitRecord(record);
        }
    }

    public RowRecordsAggregate(SharedValueManager sharedValueManager) {
        this._firstrow = -1;
        this._lastrow = -1;
        this._rowRecordValues = null;
        if (sharedValueManager != null) {
            this._rowRecords = new TreeMap();
            this._valuesAgg = new ValueRecordsAggregate();
            this._unknownRecords = new ArrayList();
            this._sharedValueManager = sharedValueManager;
            return;
        }
        throw new IllegalArgumentException("SharedValueManager must be provided.");
    }

    public RowRecordsAggregate(RecordStream recordStream, SharedValueManager sharedValueManager) {
        this(sharedValueManager);
        while (recordStream.hasNext()) {
            Record next = recordStream.getNext();
            short sid = next.getSid();
            if (sid == 81) {
                addUnknownRecord(next);
            } else if (sid == 215) {
                continue;
            } else if (sid == 520) {
                insertRow((RowRecord) next);
            } else if (next instanceof UnknownRecord) {
                addUnknownRecord(next);
                while (recordStream.peekNextSid() == 60) {
                    addUnknownRecord(recordStream.getNext());
                }
            } else if (next instanceof MulBlankRecord) {
                this._valuesAgg.addMultipleBlanks((MulBlankRecord) next);
            } else if (next instanceof CellValueRecordInterface) {
                this._valuesAgg.construct((CellValueRecordInterface) next, recordStream, sharedValueManager);
            } else {
                StringBuilder b2 = a.b("Unexpected record type (");
                b2.append(next.getClass().getName());
                b2.append(")");
                throw new RuntimeException(b2.toString());
            }
        }
    }
}
