package org.apache.poi.hssf.record.aggregates;

import b.b.a.a.a;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import org.apache.poi.hssf.record.ArrayRecord;
import org.apache.poi.hssf.record.SharedFormulaRecord;
import org.apache.poi.hssf.record.SharedValueRecordBase;
import org.apache.poi.hssf.record.TableRecord;
import org.apache.poi.hssf.util.CellRangeAddress8Bit;
import org.apache.poi.ss.util.CellReference;
import org.apache.xmlbeans.impl.common.JarHelper;

public final class SharedValueManager {
    public final List<ArrayRecord> _arrayRecords;
    public final Map<SharedFormulaRecord, SharedFormulaGroup> _groupsBySharedFormulaRecord;
    public Map<Integer, SharedFormulaGroup> _groupsCache;
    public final TableRecord[] _tableRecords;

    public static final class SharedFormulaGroup {
        public final CellReference _firstCell;
        public final FormulaRecordAggregate[] _frAggs;
        public int _numberOfFormulas;
        public final SharedFormulaRecord _sfr;

        public SharedFormulaGroup(SharedFormulaRecord sharedFormulaRecord, CellReference cellReference) {
            if (sharedFormulaRecord.isInRange(cellReference.getRow(), cellReference.getCol())) {
                this._sfr = sharedFormulaRecord;
                this._firstCell = cellReference;
                this._frAggs = new FormulaRecordAggregate[(((sharedFormulaRecord.getLastRow() - sharedFormulaRecord.getFirstRow()) + 1) * ((sharedFormulaRecord.getLastColumn() - sharedFormulaRecord.getFirstColumn()) + 1))];
                this._numberOfFormulas = 0;
                return;
            }
            StringBuilder b2 = a.b("First formula cell ");
            b2.append(cellReference.formatAsString());
            b2.append(" is not shared formula range ");
            b2.append(sharedFormulaRecord.getRange());
            b2.append(".");
            throw new IllegalArgumentException(b2.toString());
        }

        public void add(FormulaRecordAggregate formulaRecordAggregate) {
            if (this._numberOfFormulas != 0 || (this._firstCell.getRow() == formulaRecordAggregate.getRow() && this._firstCell.getCol() == formulaRecordAggregate.getColumn())) {
                int i2 = this._numberOfFormulas;
                FormulaRecordAggregate[] formulaRecordAggregateArr = this._frAggs;
                if (i2 < formulaRecordAggregateArr.length) {
                    this._numberOfFormulas = i2 + 1;
                    formulaRecordAggregateArr[i2] = formulaRecordAggregate;
                    return;
                }
                throw new RuntimeException("Too many formula records for shared formula group");
            }
            StringBuilder b2 = a.b("shared formula coding error: ");
            b2.append((int) this._firstCell.getCol());
            b2.append(JarHelper.SEP);
            b2.append(this._firstCell.getRow());
            b2.append(" != ");
            b2.append((int) formulaRecordAggregate.getColumn());
            b2.append(JarHelper.SEP);
            b2.append(formulaRecordAggregate.getRow());
            throw new IllegalStateException(b2.toString());
        }

        public SharedFormulaRecord getSFR() {
            return this._sfr;
        }

        public final String toString() {
            StringBuffer stringBuffer = new StringBuffer(64);
            a.a(SharedFormulaGroup.class, stringBuffer, " [");
            stringBuffer.append(this._sfr.getRange());
            stringBuffer.append("]");
            return stringBuffer.toString();
        }

        public void unlinkSharedFormulas() {
            for (int i2 = 0; i2 < this._numberOfFormulas; i2++) {
                this._frAggs[i2].unlinkSharedFormula();
            }
        }
    }

    public SharedValueManager(SharedFormulaRecord[] sharedFormulaRecordArr, CellReference[] cellReferenceArr, ArrayRecord[] arrayRecordArr, TableRecord[] tableRecordArr) {
        int length = sharedFormulaRecordArr.length;
        if (length == cellReferenceArr.length) {
            this._arrayRecords = toList(arrayRecordArr);
            this._tableRecords = tableRecordArr;
            HashMap hashMap = new HashMap((length * 3) / 2);
            for (int i2 = 0; i2 < length; i2++) {
                SharedFormulaRecord sharedFormulaRecord = sharedFormulaRecordArr[i2];
                hashMap.put(sharedFormulaRecord, new SharedFormulaGroup(sharedFormulaRecord, cellReferenceArr[i2]));
            }
            this._groupsBySharedFormulaRecord = hashMap;
            return;
        }
        throw new IllegalArgumentException(a.a(a.a("array sizes don't match: ", length, "!="), cellReferenceArr.length, "."));
    }

    public static SharedValueManager create(SharedFormulaRecord[] sharedFormulaRecordArr, CellReference[] cellReferenceArr, ArrayRecord[] arrayRecordArr, TableRecord[] tableRecordArr) {
        if (sharedFormulaRecordArr.length + cellReferenceArr.length + arrayRecordArr.length + tableRecordArr.length < 1) {
            return createEmpty();
        }
        return new SharedValueManager(sharedFormulaRecordArr, cellReferenceArr, arrayRecordArr, tableRecordArr);
    }

    public static SharedValueManager createEmpty() {
        return new SharedValueManager(new SharedFormulaRecord[0], new CellReference[0], new ArrayRecord[0], new TableRecord[0]);
    }

    private SharedFormulaGroup findFormulaGroupForCell(CellReference cellReference) {
        if (this._groupsCache == null) {
            this._groupsCache = new HashMap(this._groupsBySharedFormulaRecord.size());
            for (SharedFormulaGroup sharedFormulaGroup : this._groupsBySharedFormulaRecord.values()) {
                this._groupsCache.put(getKeyForCache(sharedFormulaGroup._firstCell), sharedFormulaGroup);
            }
        }
        return this._groupsCache.get(getKeyForCache(cellReference));
    }

    private Integer getKeyForCache(CellReference cellReference) {
        return Integer.valueOf(cellReference.getRow() | ((cellReference.getCol() + 1) << 16));
    }

    public static <Z> List<Z> toList(Z[] zArr) {
        ArrayList arrayList = new ArrayList(zArr.length);
        for (Z z : zArr) {
            arrayList.add(z);
        }
        return arrayList;
    }

    public void addArrayRecord(ArrayRecord arrayRecord) {
        this._arrayRecords.add(arrayRecord);
    }

    public ArrayRecord getArrayRecord(int i2, int i3) {
        for (ArrayRecord arrayRecord : this._arrayRecords) {
            if (arrayRecord.isFirstCell(i2, i3)) {
                return arrayRecord;
            }
        }
        return null;
    }

    public SharedValueRecordBase getRecordForFirstCell(FormulaRecordAggregate formulaRecordAggregate) {
        SharedFormulaGroup findFormulaGroupForCell;
        CellReference expReference = formulaRecordAggregate.getFormulaRecord().getFormula().getExpReference();
        if (expReference == null) {
            return null;
        }
        int row = expReference.getRow();
        short col = expReference.getCol();
        if (formulaRecordAggregate.getRow() == row && formulaRecordAggregate.getColumn() == col) {
            if (!(this._groupsBySharedFormulaRecord.isEmpty() || (findFormulaGroupForCell = findFormulaGroupForCell(expReference)) == null)) {
                return findFormulaGroupForCell.getSFR();
            }
            TableRecord[] tableRecordArr = this._tableRecords;
            for (TableRecord tableRecord : tableRecordArr) {
                if (tableRecord.isFirstCell(row, col)) {
                    return tableRecord;
                }
            }
            for (ArrayRecord arrayRecord : this._arrayRecords) {
                if (arrayRecord.isFirstCell(row, col)) {
                    return arrayRecord;
                }
            }
        }
        return null;
    }

    public SharedFormulaRecord linkSharedFormulaRecord(CellReference cellReference, FormulaRecordAggregate formulaRecordAggregate) {
        SharedFormulaGroup findFormulaGroupForCell = findFormulaGroupForCell(cellReference);
        if (findFormulaGroupForCell != null) {
            findFormulaGroupForCell.add(formulaRecordAggregate);
            return findFormulaGroupForCell.getSFR();
        }
        throw new RuntimeException("Failed to find a matching shared formula record");
    }

    public CellRangeAddress8Bit removeArrayFormula(int i2, int i3) {
        for (ArrayRecord arrayRecord : this._arrayRecords) {
            if (arrayRecord.isInRange(i2, i3)) {
                this._arrayRecords.remove(arrayRecord);
                return arrayRecord.getRange();
            }
        }
        throw new IllegalArgumentException(a.b("Specified cell ", new CellReference(i2, i3, false, false).formatAsString(), " is not part of an array formula."));
    }

    public void unlink(SharedFormulaRecord sharedFormulaRecord) {
        SharedFormulaGroup remove = this._groupsBySharedFormulaRecord.remove(sharedFormulaRecord);
        if (remove != null) {
            this._groupsCache = null;
            remove.unlinkSharedFormulas();
            return;
        }
        throw new IllegalStateException("Failed to find formulas for shared formula");
    }
}
