package org.apache.poi.hssf.record.aggregates;

import b.b.a.a.a;
import java.util.Iterator;
import org.apache.poi.hssf.model.RecordStream;
import org.apache.poi.hssf.record.BlankRecord;
import org.apache.poi.hssf.record.CellValueRecordInterface;
import org.apache.poi.hssf.record.FormulaRecord;
import org.apache.poi.hssf.record.MulBlankRecord;
import org.apache.poi.hssf.record.Record;
import org.apache.poi.hssf.record.RecordBase;
import org.apache.poi.hssf.record.StringRecord;
import org.apache.poi.hssf.record.aggregates.RecordAggregate;
import org.apache.poi.ss.formula.FormulaShifter;
import org.apache.poi.ss.formula.ptg.Ptg;

public final class ValueRecordsAggregate implements Iterable<CellValueRecordInterface> {
    public static final int INDEX_NOT_SET = -1;
    public static final int MAX_ROW_INDEX = 65535;
    public int firstcell;
    public int lastcell;
    public CellValueRecordInterface[][] records;

    public class ValueIterator implements Iterator<CellValueRecordInterface> {
        public int curColIndex = -1;
        public int curRowIndex = 0;
        public int nextColIndex = -1;
        public int nextRowIndex = 0;

        public ValueIterator() {
            getNextPos();
        }

        public void getNextPos() {
            if (this.nextRowIndex < ValueRecordsAggregate.this.records.length) {
                while (this.nextRowIndex < ValueRecordsAggregate.this.records.length) {
                    this.nextColIndex++;
                    if (ValueRecordsAggregate.this.records[this.nextRowIndex] == null || this.nextColIndex >= ValueRecordsAggregate.this.records[this.nextRowIndex].length) {
                        this.nextRowIndex++;
                        this.nextColIndex = -1;
                    } else if (ValueRecordsAggregate.this.records[this.nextRowIndex][this.nextColIndex] != null) {
                        return;
                    }
                }
            }
        }

        public boolean hasNext() {
            return this.nextRowIndex < ValueRecordsAggregate.this.records.length;
        }

        public void remove() {
            ValueRecordsAggregate.this.records[this.curRowIndex][this.curColIndex] = null;
        }

        @Override // java.util.Iterator
        public CellValueRecordInterface next() {
            if (hasNext()) {
                this.curRowIndex = this.nextRowIndex;
                this.curColIndex = this.nextColIndex;
                CellValueRecordInterface cellValueRecordInterface = ValueRecordsAggregate.this.records[this.curRowIndex][this.curColIndex];
                getNextPos();
                return cellValueRecordInterface;
            }
            throw new IndexOutOfBoundsException("iterator has no next");
        }
    }

    public ValueRecordsAggregate() {
        this(-1, -1, new CellValueRecordInterface[30][]);
    }

    public static int countBlanks(CellValueRecordInterface[] cellValueRecordInterfaceArr, int i2) {
        int i3 = i2;
        while (i3 < cellValueRecordInterfaceArr.length && (cellValueRecordInterfaceArr[i3] instanceof BlankRecord)) {
            i3++;
        }
        return i3 - i2;
    }

    private MulBlankRecord createMBR(CellValueRecordInterface[] cellValueRecordInterfaceArr, int i2, int i3) {
        short[] sArr = new short[i3];
        for (int i4 = 0; i4 < i3; i4++) {
            sArr[i4] = ((BlankRecord) cellValueRecordInterfaceArr[i2 + i4]).getXFIndex();
        }
        return new MulBlankRecord(cellValueRecordInterfaceArr[i2].getRow(), i2, sArr);
    }

    public static int getRowSerializedSize(CellValueRecordInterface[] cellValueRecordInterfaceArr) {
        int i2;
        int i3 = 0;
        if (cellValueRecordInterfaceArr == null) {
            return 0;
        }
        int i4 = 0;
        while (i3 < cellValueRecordInterfaceArr.length) {
            RecordBase recordBase = (RecordBase) cellValueRecordInterfaceArr[i3];
            if (recordBase != null) {
                int countBlanks = countBlanks(cellValueRecordInterfaceArr, i3);
                if (countBlanks > 1) {
                    i2 = (countBlanks * 2) + 10 + i4;
                    i3 += countBlanks - 1;
                } else {
                    i2 = recordBase.getRecordSize() + i4;
                }
                i4 = i2;
            }
            i3++;
        }
        return i4;
    }

    public void addMultipleBlanks(MulBlankRecord mulBlankRecord) {
        for (int i2 = 0; i2 < mulBlankRecord.getNumColumns(); i2++) {
            BlankRecord blankRecord = new BlankRecord();
            blankRecord.setColumn((short) (mulBlankRecord.getFirstColumn() + i2));
            blankRecord.setRow(mulBlankRecord.getRow());
            blankRecord.setXFIndex(mulBlankRecord.getXFAt(i2));
            insertCell(blankRecord);
        }
    }

    @Override // java.lang.Object
    public Object clone() {
        throw new RuntimeException("clone() should not be called.  ValueRecordsAggregate should be copied via Sheet.cloneSheet()");
    }

    public void construct(CellValueRecordInterface cellValueRecordInterface, RecordStream recordStream, SharedValueManager sharedValueManager) {
        if (cellValueRecordInterface instanceof FormulaRecord) {
            insertCell(new FormulaRecordAggregate((FormulaRecord) cellValueRecordInterface, recordStream.peekNextClass() == StringRecord.class ? (StringRecord) recordStream.getNext() : null, sharedValueManager));
        } else {
            insertCell(cellValueRecordInterface);
        }
    }

    public int getFirstCellNum() {
        return this.firstcell;
    }

    public int getLastCellNum() {
        return this.lastcell;
    }

    public int getPhysicalNumberOfCells() {
        int i2 = 0;
        int i3 = 0;
        while (true) {
            CellValueRecordInterface[][] cellValueRecordInterfaceArr = this.records;
            if (i2 >= cellValueRecordInterfaceArr.length) {
                return i3;
            }
            CellValueRecordInterface[] cellValueRecordInterfaceArr2 = cellValueRecordInterfaceArr[i2];
            if (cellValueRecordInterfaceArr2 != null) {
                for (CellValueRecordInterface cellValueRecordInterface : cellValueRecordInterfaceArr2) {
                    if (cellValueRecordInterface != null) {
                        i3++;
                    }
                }
            }
            i2++;
        }
    }

    public int getRowCellBlockSize(int i2, int i3) {
        int i4 = 0;
        while (i2 <= i3) {
            CellValueRecordInterface[][] cellValueRecordInterfaceArr = this.records;
            if (i2 >= cellValueRecordInterfaceArr.length) {
                break;
            }
            i4 += getRowSerializedSize(cellValueRecordInterfaceArr[i2]);
            i2++;
        }
        return i4;
    }

    public void insertCell(CellValueRecordInterface cellValueRecordInterface) {
        short column = cellValueRecordInterface.getColumn();
        int row = cellValueRecordInterface.getRow();
        CellValueRecordInterface[][] cellValueRecordInterfaceArr = this.records;
        if (row >= cellValueRecordInterfaceArr.length) {
            int length = cellValueRecordInterfaceArr.length * 2;
            int i2 = row + 1;
            if (length < i2) {
                length = i2;
            }
            CellValueRecordInterface[][] cellValueRecordInterfaceArr2 = new CellValueRecordInterface[length][];
            this.records = cellValueRecordInterfaceArr2;
            System.arraycopy(cellValueRecordInterfaceArr, 0, cellValueRecordInterfaceArr2, 0, cellValueRecordInterfaceArr.length);
        }
        CellValueRecordInterface[] cellValueRecordInterfaceArr3 = this.records[row];
        if (cellValueRecordInterfaceArr3 == null) {
            int i3 = column + 1;
            if (i3 < 10) {
                i3 = 10;
            }
            cellValueRecordInterfaceArr3 = new CellValueRecordInterface[i3];
            this.records[row] = cellValueRecordInterfaceArr3;
        }
        if (column >= cellValueRecordInterfaceArr3.length) {
            int length2 = cellValueRecordInterfaceArr3.length * 2;
            int i4 = column + 1;
            if (length2 < i4) {
                length2 = i4;
            }
            CellValueRecordInterface[] cellValueRecordInterfaceArr4 = new CellValueRecordInterface[length2];
            System.arraycopy(cellValueRecordInterfaceArr3, 0, cellValueRecordInterfaceArr4, 0, cellValueRecordInterfaceArr3.length);
            this.records[row] = cellValueRecordInterfaceArr4;
            cellValueRecordInterfaceArr3 = cellValueRecordInterfaceArr4;
        }
        cellValueRecordInterfaceArr3[column] = cellValueRecordInterface;
        int i5 = this.firstcell;
        if (column < i5 || i5 == -1) {
            this.firstcell = column;
        }
        int i6 = this.lastcell;
        if (column > i6 || i6 == -1) {
            this.lastcell = column;
        }
    }

    @Override // java.lang.Iterable
    public Iterator<CellValueRecordInterface> iterator() {
        return new ValueIterator();
    }

    public void removeAllCellsValuesForRow(int i2) {
        if (i2 < 0 || i2 > 65535) {
            throw new IllegalArgumentException(a.b("Specified rowIndex ", i2, " is outside the allowable range (0..", 65535, ")"));
        }
        CellValueRecordInterface[][] cellValueRecordInterfaceArr = this.records;
        if (i2 < cellValueRecordInterfaceArr.length) {
            cellValueRecordInterfaceArr[i2] = null;
        }
    }

    public void removeCell(CellValueRecordInterface cellValueRecordInterface) {
        if (cellValueRecordInterface != null) {
            int row = cellValueRecordInterface.getRow();
            CellValueRecordInterface[][] cellValueRecordInterfaceArr = this.records;
            if (row < cellValueRecordInterfaceArr.length) {
                CellValueRecordInterface[] cellValueRecordInterfaceArr2 = cellValueRecordInterfaceArr[row];
                if (cellValueRecordInterfaceArr2 != null) {
                    short column = cellValueRecordInterface.getColumn();
                    if (column < cellValueRecordInterfaceArr2.length) {
                        cellValueRecordInterfaceArr2[column] = null;
                        return;
                    }
                    throw new RuntimeException("cell column is out of range");
                }
                throw new RuntimeException("cell row is already empty");
            }
            throw new RuntimeException("cell row is out of range");
        }
        throw new IllegalArgumentException("cell must not be null");
    }

    public boolean rowHasCells(int i2) {
        CellValueRecordInterface[] cellValueRecordInterfaceArr;
        CellValueRecordInterface[][] cellValueRecordInterfaceArr2 = this.records;
        if (i2 >= cellValueRecordInterfaceArr2.length || (cellValueRecordInterfaceArr = cellValueRecordInterfaceArr2[i2]) == null) {
            return false;
        }
        for (CellValueRecordInterface cellValueRecordInterface : cellValueRecordInterfaceArr) {
            if (cellValueRecordInterface != null) {
                return true;
            }
        }
        return false;
    }

    public void updateFormulasAfterRowShift(FormulaShifter formulaShifter, int i2) {
        int i3 = 0;
        while (true) {
            CellValueRecordInterface[][] cellValueRecordInterfaceArr = this.records;
            if (i3 < cellValueRecordInterfaceArr.length) {
                CellValueRecordInterface[] cellValueRecordInterfaceArr2 = cellValueRecordInterfaceArr[i3];
                if (cellValueRecordInterfaceArr2 != null) {
                    for (CellValueRecordInterface cellValueRecordInterface : cellValueRecordInterfaceArr2) {
                        if (cellValueRecordInterface instanceof FormulaRecordAggregate) {
                            FormulaRecordAggregate formulaRecordAggregate = (FormulaRecordAggregate) cellValueRecordInterface;
                            Ptg[] formulaTokens = formulaRecordAggregate.getFormulaTokens();
                            formulaRecordAggregate.getFormulaRecord().getParsedExpression();
                            if (formulaShifter.adjustFormula(formulaTokens, i2)) {
                                formulaRecordAggregate.setParsedExpression(formulaTokens);
                            }
                        }
                    }
                }
                i3++;
            } else {
                return;
            }
        }
    }

    public void visitCellsForRow(int i2, RecordAggregate.RecordVisitor recordVisitor) {
        CellValueRecordInterface[] cellValueRecordInterfaceArr = this.records[i2];
        if (cellValueRecordInterfaceArr != null) {
            int i3 = 0;
            while (i3 < cellValueRecordInterfaceArr.length) {
                RecordBase recordBase = (RecordBase) cellValueRecordInterfaceArr[i3];
                if (recordBase != null) {
                    int countBlanks = countBlanks(cellValueRecordInterfaceArr, i3);
                    if (countBlanks > 1) {
                        recordVisitor.visitRecord(createMBR(cellValueRecordInterfaceArr, i3, countBlanks));
                        i3 += countBlanks - 1;
                    } else if (recordBase instanceof RecordAggregate) {
                        ((RecordAggregate) recordBase).visitContainedRecords(recordVisitor);
                    } else {
                        recordVisitor.visitRecord((Record) recordBase);
                    }
                }
                i3++;
            }
            return;
        }
        throw new IllegalArgumentException(a.b("Row [", i2, "] is empty"));
    }

    public ValueRecordsAggregate(int i2, int i3, CellValueRecordInterface[][] cellValueRecordInterfaceArr) {
        this.firstcell = -1;
        this.lastcell = -1;
        this.firstcell = i2;
        this.lastcell = i3;
        this.records = cellValueRecordInterfaceArr;
    }
}
