package org.apache.poi.hssf.record.cf;

import b.b.a.a.a;
import org.apache.poi.util.BitField;
import org.apache.poi.util.BitFieldFactory;
import org.apache.poi.util.LittleEndian;
import org.apache.poi.util.LittleEndianInput;
import org.apache.poi.util.LittleEndianOutput;
import org.apache.xmlbeans.impl.common.ConcurrentReaderHashMap;

public final class BorderFormatting implements Cloneable {
    public static final short BORDER_DASHED = 3;
    public static final short BORDER_DASH_DOT = 9;
    public static final short BORDER_DASH_DOT_DOT = 11;
    public static final short BORDER_DOTTED = 7;
    public static final short BORDER_DOUBLE = 6;
    public static final short BORDER_HAIR = 4;
    public static final short BORDER_MEDIUM = 2;
    public static final short BORDER_MEDIUM_DASHED = 8;
    public static final short BORDER_MEDIUM_DASH_DOT = 10;
    public static final short BORDER_MEDIUM_DASH_DOT_DOT = 12;
    public static final short BORDER_NONE = 0;
    public static final short BORDER_SLANTED_DASH_DOT = 13;
    public static final short BORDER_THICK = 5;
    public static final short BORDER_THIN = 1;
    public static final BitField bordBlTrtLineOnOff = BitFieldFactory.getInstance(Integer.MIN_VALUE);
    public static final BitField bordBottomLineColor = BitFieldFactory.getInstance(16256);
    public static final BitField bordBottomLineStyle = BitFieldFactory.getInstance(61440);
    public static final BitField bordDiagLineColor = BitFieldFactory.getInstance(2080768);
    public static final BitField bordDiagLineStyle = BitFieldFactory.getInstance(31457280);
    public static final BitField bordLeftLineColor = BitFieldFactory.getInstance(8323072);
    public static final BitField bordLeftLineStyle = BitFieldFactory.getInstance(15);
    public static final BitField bordRightLineColor = BitFieldFactory.getInstance(1065353216);
    public static final BitField bordRightLineStyle = BitFieldFactory.getInstance(240);
    public static final BitField bordTlBrLineOnOff = BitFieldFactory.getInstance(ConcurrentReaderHashMap.MAXIMUM_CAPACITY);
    public static final BitField bordTopLineColor = BitFieldFactory.getInstance(127);
    public static final BitField bordTopLineStyle = BitFieldFactory.getInstance(3840);
    public int field_13_border_styles1;
    public int field_14_border_styles2;

    public BorderFormatting() {
        this.field_13_border_styles1 = 0;
        this.field_14_border_styles2 = 0;
    }

    public int getBorderBottom() {
        return bordBottomLineStyle.getValue(this.field_13_border_styles1);
    }

    public int getBorderDiagonal() {
        return bordDiagLineStyle.getValue(this.field_14_border_styles2);
    }

    public int getBorderLeft() {
        return bordLeftLineStyle.getValue(this.field_13_border_styles1);
    }

    public int getBorderRight() {
        return bordRightLineStyle.getValue(this.field_13_border_styles1);
    }

    public int getBorderTop() {
        return bordTopLineStyle.getValue(this.field_13_border_styles1);
    }

    public int getBottomBorderColor() {
        return bordBottomLineColor.getValue(this.field_14_border_styles2);
    }

    public int getDataLength() {
        return 8;
    }

    public int getDiagonalBorderColor() {
        return bordDiagLineColor.getValue(this.field_14_border_styles2);
    }

    public int getLeftBorderColor() {
        return bordLeftLineColor.getValue(this.field_13_border_styles1);
    }

    public int getRightBorderColor() {
        return bordRightLineColor.getValue(this.field_13_border_styles1);
    }

    public int getTopBorderColor() {
        return bordTopLineColor.getValue(this.field_14_border_styles2);
    }

    public boolean isBackwardDiagonalOn() {
        return bordTlBrLineOnOff.isSet(this.field_13_border_styles1);
    }

    public boolean isForwardDiagonalOn() {
        return bordBlTrtLineOnOff.isSet(this.field_13_border_styles1);
    }

    public int serialize(int i2, byte[] bArr) {
        LittleEndian.putInt(bArr, i2 + 0, this.field_13_border_styles1);
        LittleEndian.putInt(bArr, i2 + 4, this.field_14_border_styles2);
        return 8;
    }

    public void setBackwardDiagonalOn(boolean z) {
        this.field_13_border_styles1 = bordTlBrLineOnOff.setBoolean(this.field_13_border_styles1, z);
    }

    public void setBorderBottom(int i2) {
        this.field_13_border_styles1 = bordBottomLineStyle.setValue(this.field_13_border_styles1, i2);
    }

    public void setBorderDiagonal(int i2) {
        this.field_14_border_styles2 = bordDiagLineStyle.setValue(this.field_14_border_styles2, i2);
    }

    public void setBorderLeft(int i2) {
        this.field_13_border_styles1 = bordLeftLineStyle.setValue(this.field_13_border_styles1, i2);
    }

    public void setBorderRight(int i2) {
        this.field_13_border_styles1 = bordRightLineStyle.setValue(this.field_13_border_styles1, i2);
    }

    public void setBorderTop(int i2) {
        this.field_13_border_styles1 = bordTopLineStyle.setValue(this.field_13_border_styles1, i2);
    }

    public void setBottomBorderColor(int i2) {
        this.field_14_border_styles2 = bordBottomLineColor.setValue(this.field_14_border_styles2, i2);
    }

    public void setDiagonalBorderColor(int i2) {
        this.field_14_border_styles2 = bordDiagLineColor.setValue(this.field_14_border_styles2, i2);
    }

    public void setForwardDiagonalOn(boolean z) {
        this.field_13_border_styles1 = bordBlTrtLineOnOff.setBoolean(this.field_13_border_styles1, z);
    }

    public void setLeftBorderColor(int i2) {
        this.field_13_border_styles1 = bordLeftLineColor.setValue(this.field_13_border_styles1, i2);
    }

    public void setRightBorderColor(int i2) {
        this.field_13_border_styles1 = bordRightLineColor.setValue(this.field_13_border_styles1, i2);
    }

    public void setTopBorderColor(int i2) {
        this.field_14_border_styles2 = bordTopLineColor.setValue(this.field_14_border_styles2, i2);
    }

    public String toString() {
        StringBuffer c = a.c("    [Border Formatting]\n", "          .lftln     = ");
        c.append(Integer.toHexString(getBorderLeft()));
        c.append("\n");
        c.append("          .rgtln     = ");
        c.append(Integer.toHexString(getBorderRight()));
        c.append("\n");
        c.append("          .topln     = ");
        c.append(Integer.toHexString(getBorderTop()));
        c.append("\n");
        c.append("          .btmln     = ");
        c.append(Integer.toHexString(getBorderBottom()));
        c.append("\n");
        c.append("          .leftborder= ");
        c.append(Integer.toHexString(getLeftBorderColor()));
        c.append("\n");
        c.append("          .rghtborder= ");
        c.append(Integer.toHexString(getRightBorderColor()));
        c.append("\n");
        c.append("          .topborder= ");
        c.append(Integer.toHexString(getTopBorderColor()));
        c.append("\n");
        c.append("          .bottomborder= ");
        c.append(Integer.toHexString(getBottomBorderColor()));
        c.append("\n");
        c.append("          .fwdiag= ");
        c.append(isForwardDiagonalOn());
        c.append("\n");
        c.append("          .bwdiag= ");
        c.append(isBackwardDiagonalOn());
        return a.a(c, "\n", "    [/Border Formatting]\n");
    }

    @Override // java.lang.Object
    public BorderFormatting clone() {
        BorderFormatting borderFormatting = new BorderFormatting();
        borderFormatting.field_13_border_styles1 = this.field_13_border_styles1;
        borderFormatting.field_14_border_styles2 = this.field_14_border_styles2;
        return borderFormatting;
    }

    public void serialize(LittleEndianOutput littleEndianOutput) {
        littleEndianOutput.writeInt(this.field_13_border_styles1);
        littleEndianOutput.writeInt(this.field_14_border_styles2);
    }

    public BorderFormatting(LittleEndianInput littleEndianInput) {
        this.field_13_border_styles1 = littleEndianInput.readInt();
        this.field_14_border_styles2 = littleEndianInput.readInt();
    }
}
