package org.apache.poi.hssf.record.cf;

import b.b.a.a.a;
import org.apache.poi.hssf.record.common.ExtendedColor;
import org.apache.poi.util.BitField;
import org.apache.poi.util.BitFieldFactory;
import org.apache.poi.util.LittleEndianInput;
import org.apache.poi.util.LittleEndianOutput;
import org.apache.poi.util.POILogFactory;
import org.apache.poi.util.POILogger;

public final class DataBarFormatting implements Cloneable {
    public static BitField iconOnly = BitFieldFactory.getInstance(1);
    public static POILogger log = POILogFactory.getLogger(DataBarFormatting.class);
    public static BitField reversed = BitFieldFactory.getInstance(4);
    public ExtendedColor color;
    public byte options;
    public byte percentMax;
    public byte percentMin;
    public DataBarThreshold thresholdMax;
    public DataBarThreshold thresholdMin;

    public DataBarFormatting() {
        this.options = 0;
        this.percentMin = 0;
        this.percentMax = 0;
        this.options = 2;
    }

    private boolean getOptionFlag(BitField bitField) {
        return bitField.getValue(this.options) != 0;
    }

    private void setOptionFlag(boolean z, BitField bitField) {
        this.options = bitField.setByteBoolean(this.options, z);
    }

    @Override // java.lang.Object
    public Object clone() {
        DataBarFormatting dataBarFormatting = new DataBarFormatting();
        dataBarFormatting.options = this.options;
        dataBarFormatting.percentMin = this.percentMin;
        dataBarFormatting.percentMax = this.percentMax;
        dataBarFormatting.color = this.color.clone();
        dataBarFormatting.thresholdMin = this.thresholdMin.clone();
        dataBarFormatting.thresholdMax = this.thresholdMax.clone();
        return dataBarFormatting;
    }

    public ExtendedColor getColor() {
        return this.color;
    }

    public int getDataLength() {
        return this.thresholdMax.getDataLength() + this.thresholdMin.getDataLength() + this.color.getDataLength() + 6;
    }

    public byte getPercentMax() {
        return this.percentMax;
    }

    public byte getPercentMin() {
        return this.percentMin;
    }

    public DataBarThreshold getThresholdMax() {
        return this.thresholdMax;
    }

    public DataBarThreshold getThresholdMin() {
        return this.thresholdMin;
    }

    public boolean isIconOnly() {
        return getOptionFlag(iconOnly);
    }

    public boolean isReversed() {
        return getOptionFlag(reversed);
    }

    public void serialize(LittleEndianOutput littleEndianOutput) {
        littleEndianOutput.writeShort(0);
        littleEndianOutput.writeByte(0);
        littleEndianOutput.writeByte(this.options);
        littleEndianOutput.writeByte(this.percentMin);
        littleEndianOutput.writeByte(this.percentMax);
        this.color.serialize(littleEndianOutput);
        this.thresholdMin.serialize(littleEndianOutput);
        this.thresholdMax.serialize(littleEndianOutput);
    }

    public void setColor(ExtendedColor extendedColor) {
        this.color = extendedColor;
    }

    public void setIconOnly(boolean z) {
        setOptionFlag(z, iconOnly);
    }

    public void setPercentMax(byte b2) {
        this.percentMax = b2;
    }

    public void setPercentMin(byte b2) {
        this.percentMin = b2;
    }

    public void setReversed(boolean z) {
        setOptionFlag(z, reversed);
    }

    public void setThresholdMax(DataBarThreshold dataBarThreshold) {
        this.thresholdMax = dataBarThreshold;
    }

    public void setThresholdMin(DataBarThreshold dataBarThreshold) {
        this.thresholdMin = dataBarThreshold;
    }

    public String toString() {
        StringBuffer c = a.c("    [Data Bar Formatting]\n", "          .icon_only= ");
        c.append(isIconOnly());
        c.append("\n");
        c.append("          .reversed = ");
        c.append(isReversed());
        c.append("\n");
        c.append(this.color);
        c.append(this.thresholdMin);
        c.append(this.thresholdMax);
        c.append("    [/Data Bar Formatting]\n");
        return c.toString();
    }

    public DataBarFormatting(LittleEndianInput littleEndianInput) {
        this.options = 0;
        this.percentMin = 0;
        this.percentMax = 0;
        littleEndianInput.readShort();
        littleEndianInput.readByte();
        this.options = littleEndianInput.readByte();
        this.percentMin = littleEndianInput.readByte();
        this.percentMax = littleEndianInput.readByte();
        byte b2 = this.percentMin;
        if (b2 < 0 || b2 > 100) {
            POILogger pOILogger = log;
            StringBuilder b3 = a.b("Inconsistent Minimum Percentage found ");
            b3.append((int) this.percentMin);
            pOILogger.log(5, b3.toString());
        }
        byte b4 = this.percentMax;
        if (b4 < 0 || b4 > 100) {
            POILogger pOILogger2 = log;
            StringBuilder b5 = a.b("Inconsistent Minimum Percentage found ");
            b5.append((int) this.percentMin);
            pOILogger2.log(5, b5.toString());
        }
        this.color = new ExtendedColor(littleEndianInput);
        this.thresholdMin = new DataBarThreshold(littleEndianInput);
        this.thresholdMax = new DataBarThreshold(littleEndianInput);
    }
}
