package org.apache.poi.hssf.record.cf;

import b.b.a.a.a;
import java.util.Locale;
import org.apache.poi.hssf.record.RecordInputStream;
import org.apache.poi.util.BitField;
import org.apache.poi.util.BitFieldFactory;
import org.apache.poi.util.LittleEndian;
import org.apache.xerces.dom3.as.ASDataType;

public final class FontFormatting implements Cloneable {
    public static final int FONT_CELL_HEIGHT_PRESERVED = -1;
    public static final short FONT_WEIGHT_BOLD = 700;
    public static final short FONT_WEIGHT_NORMAL = 400;
    public static final int OFFSET_ESCAPEMENT_TYPE = 74;
    public static final int OFFSET_ESCAPEMENT_TYPE_MODIFIED = 92;
    public static final int OFFSET_FONT_COLOR_INDEX = 80;
    public static final int OFFSET_FONT_FORMATING_END = 116;
    public static final int OFFSET_FONT_HEIGHT = 64;
    public static final int OFFSET_FONT_NAME = 0;
    public static final int OFFSET_FONT_OPTIONS = 68;
    public static final int OFFSET_FONT_WEIGHT = 72;
    public static final int OFFSET_FONT_WEIGHT_MODIFIED = 100;
    public static final int OFFSET_NOT_USED1 = 104;
    public static final int OFFSET_NOT_USED2 = 108;
    public static final int OFFSET_NOT_USED3 = 112;
    public static final int OFFSET_OPTION_FLAGS = 88;
    public static final int OFFSET_UNDERLINE_TYPE = 76;
    public static final int OFFSET_UNDERLINE_TYPE_MODIFIED = 96;
    public static final int RAW_DATA_SIZE = 118;
    public static final short SS_NONE = 0;
    public static final short SS_SUB = 2;
    public static final short SS_SUPER = 1;
    public static final byte U_DOUBLE = 2;
    public static final byte U_DOUBLE_ACCOUNTING = 34;
    public static final byte U_NONE = 0;
    public static final byte U_SINGLE = 1;
    public static final byte U_SINGLE_ACCOUNTING = 33;
    public static final BitField cancellation = BitFieldFactory.getInstance(128);
    public static final BitField cancellationModified = BitFieldFactory.getInstance(128);
    public static final BitField outline = BitFieldFactory.getInstance(8);
    public static final BitField outlineModified = BitFieldFactory.getInstance(8);
    public static final BitField posture = BitFieldFactory.getInstance(2);
    public static final BitField shadow = BitFieldFactory.getInstance(16);
    public static final BitField shadowModified = BitFieldFactory.getInstance(16);
    public static final BitField styleModified = BitFieldFactory.getInstance(2);
    public final byte[] _rawData;

    public FontFormatting() {
        this._rawData = new byte[118];
        setFontHeight(-1);
        setItalic(false);
        setFontWieghtModified(false);
        setOutline(false);
        setShadow(false);
        setStrikeout(false);
        setEscapementType(0);
        setUnderlineType(0);
        setFontColorIndex(-1);
        setFontStyleModified(false);
        setFontOutlineModified(false);
        setFontShadowModified(false);
        setFontCancellationModified(false);
        setEscapementTypeModified(false);
        setUnderlineTypeModified(false);
        setShort(0, 0);
        setInt(104, 1);
        setInt(108, 0);
        setInt(112, Integer.MAX_VALUE);
        setShort(116, 1);
    }

    private boolean getFontOption(BitField bitField) {
        return bitField.isSet(getInt(68));
    }

    private int getInt(int i2) {
        return LittleEndian.getInt(this._rawData, i2);
    }

    private boolean getOptionFlag(BitField bitField) {
        return bitField.getValue(getInt(88)) == 0;
    }

    private short getShort(int i2) {
        return LittleEndian.getShort(this._rawData, i2);
    }

    private void setFontOption(boolean z, BitField bitField) {
        setInt(68, bitField.setBoolean(getInt(68), z));
    }

    private void setFontWeight(short s) {
        if (s < 100) {
            s = 100;
        }
        if (s > 1000) {
            s = ASDataType.OTHER_SIMPLE_DATATYPE;
        }
        setShort(72, s);
    }

    private void setInt(int i2, int i3) {
        LittleEndian.putInt(this._rawData, i2, i3);
    }

    private void setOptionFlag(boolean z, BitField bitField) {
        setInt(88, bitField.setValue(getInt(88), !z ? 1 : 0));
    }

    private void setShort(int i2, int i3) {
        LittleEndian.putShort(this._rawData, i2, (short) i3);
    }

    public int getDataLength() {
        return 118;
    }

    public short getEscapementType() {
        return getShort(74);
    }

    public short getFontColorIndex() {
        return (short) getInt(80);
    }

    public int getFontHeight() {
        return getInt(64);
    }

    public short getFontWeight() {
        return getShort(72);
    }

    public byte[] getRawRecord() {
        return this._rawData;
    }

    public short getUnderlineType() {
        return getShort(76);
    }

    public boolean isBold() {
        return getFontWeight() == 700;
    }

    public boolean isEscapementTypeModified() {
        return getInt(92) == 0;
    }

    public boolean isFontCancellationModified() {
        return getOptionFlag(cancellationModified);
    }

    public boolean isFontOutlineModified() {
        return getOptionFlag(outlineModified);
    }

    public boolean isFontShadowModified() {
        return getOptionFlag(shadowModified);
    }

    public boolean isFontStyleModified() {
        return getOptionFlag(styleModified);
    }

    public boolean isFontWeightModified() {
        return getInt(100) == 0;
    }

    public boolean isItalic() {
        return getFontOption(posture);
    }

    public boolean isOutlineOn() {
        return getFontOption(outline);
    }

    public boolean isShadowOn() {
        return getFontOption(shadow);
    }

    public boolean isStruckout() {
        return getFontOption(cancellation);
    }

    public boolean isUnderlineTypeModified() {
        return getInt(96) == 0;
    }

    public void setBold(boolean z) {
        setFontWeight(z ? (short) 700 : 400);
    }

    public void setEscapementType(short s) {
        setShort(74, s);
    }

    public void setEscapementTypeModified(boolean z) {
        setInt(92, !z ? 1 : 0);
    }

    public void setFontCancellationModified(boolean z) {
        setOptionFlag(z, cancellationModified);
    }

    public void setFontColorIndex(short s) {
        setInt(80, s);
    }

    public void setFontHeight(int i2) {
        setInt(64, i2);
    }

    public void setFontOutlineModified(boolean z) {
        setOptionFlag(z, outlineModified);
    }

    public void setFontShadowModified(boolean z) {
        setOptionFlag(z, shadowModified);
    }

    public void setFontStyleModified(boolean z) {
        setOptionFlag(z, styleModified);
    }

    public void setFontWieghtModified(boolean z) {
        setInt(100, !z ? 1 : 0);
    }

    public void setItalic(boolean z) {
        setFontOption(z, posture);
    }

    public void setOutline(boolean z) {
        setFontOption(z, outline);
    }

    public void setShadow(boolean z) {
        setFontOption(z, shadow);
    }

    public void setStrikeout(boolean z) {
        setFontOption(z, cancellation);
    }

    public void setUnderlineType(short s) {
        setShort(76, s);
    }

    public void setUnderlineTypeModified(boolean z) {
        setInt(96, !z ? 1 : 0);
    }

    public String toString() {
        String str;
        StringBuffer c = a.c("    [Font Formatting]\n", "\t.font height = ");
        c.append(getFontHeight());
        c.append(" twips\n");
        if (isFontStyleModified()) {
            c.append("\t.font posture = ");
            c.append(isItalic() ? "Italic" : "Normal");
            c.append("\n");
        } else {
            c.append("\t.font posture = ]not modified]");
            c.append("\n");
        }
        if (isFontOutlineModified()) {
            c.append("\t.font outline = ");
            c.append(isOutlineOn());
            c.append("\n");
        } else {
            c.append("\t.font outline is not modified\n");
        }
        if (isFontShadowModified()) {
            c.append("\t.font shadow = ");
            c.append(isShadowOn());
            c.append("\n");
        } else {
            c.append("\t.font shadow is not modified\n");
        }
        if (isFontCancellationModified()) {
            c.append("\t.font strikeout = ");
            c.append(isStruckout());
            c.append("\n");
        } else {
            c.append("\t.font strikeout is not modified\n");
        }
        if (isFontStyleModified()) {
            c.append("\t.font weight = ");
            c.append((int) getFontWeight());
            if (getFontWeight() == 400) {
                str = "(Normal)";
            } else if (getFontWeight() == 700) {
                str = "(Bold)";
            } else {
                StringBuilder b2 = a.b("0x");
                b2.append(Integer.toHexString(getFontWeight()));
                str = b2.toString();
            }
            c.append(str);
            c.append("\n");
        } else {
            c.append("\t.font weight = ]not modified]");
            c.append("\n");
        }
        if (isEscapementTypeModified()) {
            c.append("\t.escapement type = ");
            c.append((int) getEscapementType());
            c.append("\n");
        } else {
            c.append("\t.escapement type is not modified\n");
        }
        if (isUnderlineTypeModified()) {
            c.append("\t.underline type = ");
            c.append((int) getUnderlineType());
            c.append("\n");
        } else {
            c.append("\t.underline type is not modified\n");
        }
        c.append("\t.color index = ");
        c.append("0x" + Integer.toHexString(getFontColorIndex()).toUpperCase(Locale.ROOT));
        c.append("\n");
        c.append("    [/Font Formatting]\n");
        return c.toString();
    }

    @Override // java.lang.Object
    public FontFormatting clone() {
        FontFormatting fontFormatting = new FontFormatting();
        byte[] bArr = this._rawData;
        System.arraycopy(bArr, 0, fontFormatting._rawData, 0, bArr.length);
        return fontFormatting;
    }

    public FontFormatting(RecordInputStream recordInputStream) {
        this._rawData = new byte[118];
        int i2 = 0;
        while (true) {
            byte[] bArr = this._rawData;
            if (i2 < bArr.length) {
                bArr[i2] = recordInputStream.readByte();
                i2++;
            } else {
                return;
            }
        }
    }
}
