package org.apache.poi.hssf.record.cf;

import b.b.a.a.a;
import org.apache.poi.ss.usermodel.IconMultiStateFormatting;
import org.apache.poi.util.BitField;
import org.apache.poi.util.BitFieldFactory;
import org.apache.poi.util.LittleEndianInput;
import org.apache.poi.util.LittleEndianOutput;
import org.apache.poi.util.POILogFactory;
import org.apache.poi.util.POILogger;

public final class IconMultiStateFormatting implements Cloneable {
    public static BitField iconOnly = BitFieldFactory.getInstance(1);
    public static POILogger log = POILogFactory.getLogger(IconMultiStateFormatting.class);
    public static BitField reversed = BitFieldFactory.getInstance(4);
    public IconMultiStateFormatting.IconSet iconSet;
    public byte options;
    public Threshold[] thresholds;

    public IconMultiStateFormatting() {
        IconMultiStateFormatting.IconSet iconSet2 = IconMultiStateFormatting.IconSet.GYR_3_TRAFFIC_LIGHTS;
        this.iconSet = iconSet2;
        this.options = 0;
        this.thresholds = new Threshold[iconSet2.num];
    }

    private boolean getOptionFlag(BitField bitField) {
        return bitField.getValue(this.options) != 0;
    }

    private void setOptionFlag(boolean z, BitField bitField) {
        this.options = bitField.setByteBoolean(this.options, z);
    }

    @Override // java.lang.Object
    public Object clone() {
        IconMultiStateFormatting iconMultiStateFormatting = new IconMultiStateFormatting();
        iconMultiStateFormatting.iconSet = this.iconSet;
        iconMultiStateFormatting.options = this.options;
        Threshold[] thresholdArr = new Threshold[this.thresholds.length];
        iconMultiStateFormatting.thresholds = thresholdArr;
        Threshold[] thresholdArr2 = this.thresholds;
        System.arraycopy(thresholdArr2, 0, thresholdArr, 0, thresholdArr2.length);
        return iconMultiStateFormatting;
    }

    public int getDataLength() {
        int i2 = 6;
        for (Threshold threshold : this.thresholds) {
            i2 += threshold.getDataLength();
        }
        return i2;
    }

    public IconMultiStateFormatting.IconSet getIconSet() {
        return this.iconSet;
    }

    public Threshold[] getThresholds() {
        return this.thresholds;
    }

    public boolean isIconOnly() {
        return getOptionFlag(iconOnly);
    }

    public boolean isReversed() {
        return getOptionFlag(reversed);
    }

    public void serialize(LittleEndianOutput littleEndianOutput) {
        littleEndianOutput.writeShort(0);
        littleEndianOutput.writeByte(0);
        littleEndianOutput.writeByte(this.iconSet.num);
        littleEndianOutput.writeByte(this.iconSet.id);
        littleEndianOutput.writeByte(this.options);
        for (Threshold threshold : this.thresholds) {
            threshold.serialize(littleEndianOutput);
        }
    }

    public void setIconOnly(boolean z) {
        setOptionFlag(z, iconOnly);
    }

    public void setIconSet(IconMultiStateFormatting.IconSet iconSet2) {
        this.iconSet = iconSet2;
    }

    public void setReversed(boolean z) {
        setOptionFlag(z, reversed);
    }

    public void setThresholds(Threshold[] thresholdArr) {
        this.thresholds = thresholdArr == null ? null : (Threshold[]) thresholdArr.clone();
    }

    public String toString() {
        StringBuffer c = a.c("    [Icon Formatting]\n", "          .icon_set = ");
        c.append(this.iconSet);
        c.append("\n");
        c.append("          .icon_only= ");
        c.append(isIconOnly());
        c.append("\n");
        c.append("          .reversed = ");
        c.append(isReversed());
        c.append("\n");
        for (Threshold threshold : this.thresholds) {
            c.append(threshold);
        }
        c.append("    [/Icon Formatting]\n");
        return c.toString();
    }

    public IconMultiStateFormatting(LittleEndianInput littleEndianInput) {
        littleEndianInput.readShort();
        littleEndianInput.readByte();
        byte readByte = littleEndianInput.readByte();
        IconMultiStateFormatting.IconSet byId = IconMultiStateFormatting.IconSet.byId(littleEndianInput.readByte());
        this.iconSet = byId;
        int i2 = 0;
        if (byId.num != readByte) {
            POILogger pOILogger = log;
            StringBuilder b2 = a.b("Inconsistent Icon Set defintion, found ");
            b2.append(this.iconSet);
            b2.append(" but defined as ");
            b2.append((int) readByte);
            b2.append(" entries");
            pOILogger.log(5, b2.toString());
        }
        this.options = littleEndianInput.readByte();
        this.thresholds = new Threshold[this.iconSet.num];
        while (true) {
            Threshold[] thresholdArr = this.thresholds;
            if (i2 < thresholdArr.length) {
                thresholdArr[i2] = new IconMultiStateThreshold(littleEndianInput);
                i2++;
            } else {
                return;
            }
        }
    }
}
