package org.apache.poi.hssf.record.cf;

import b.b.a.a.a;
import org.apache.poi.util.BitField;
import org.apache.poi.util.BitFieldFactory;
import org.apache.poi.util.LittleEndianInput;
import org.apache.poi.util.LittleEndianOutput;

public final class PatternFormatting implements Cloneable {
    public static final short ALT_BARS = 3;
    public static final short BIG_SPOTS = 9;
    public static final short BRICKS = 10;
    public static final short DIAMONDS = 16;
    public static final short FINE_DOTS = 2;
    public static final short LEAST_DOTS = 18;
    public static final short LESS_DOTS = 17;
    public static final short NO_FILL = 0;
    public static final short SOLID_FOREGROUND = 1;
    public static final short SPARSE_DOTS = 4;
    public static final short SQUARES = 15;
    public static final short THICK_BACKWARD_DIAG = 7;
    public static final short THICK_FORWARD_DIAG = 8;
    public static final short THICK_HORZ_BANDS = 5;
    public static final short THICK_VERT_BANDS = 6;
    public static final short THIN_BACKWARD_DIAG = 13;
    public static final short THIN_FORWARD_DIAG = 14;
    public static final short THIN_HORZ_BANDS = 11;
    public static final short THIN_VERT_BANDS = 12;
    public static final BitField fillPatternStyle = BitFieldFactory.getInstance(64512);
    public static final BitField patternBackgroundColorIndex = BitFieldFactory.getInstance(16256);
    public static final BitField patternColorIndex = BitFieldFactory.getInstance(127);
    public int field_15_pattern_style;
    public int field_16_pattern_color_indexes;

    public PatternFormatting() {
        this.field_15_pattern_style = 0;
        this.field_16_pattern_color_indexes = 0;
    }

    @Override // java.lang.Object
    public Object clone() {
        PatternFormatting patternFormatting = new PatternFormatting();
        patternFormatting.field_15_pattern_style = this.field_15_pattern_style;
        patternFormatting.field_16_pattern_color_indexes = this.field_16_pattern_color_indexes;
        return patternFormatting;
    }

    public int getDataLength() {
        return 4;
    }

    public int getFillBackgroundColor() {
        return patternBackgroundColorIndex.getValue(this.field_16_pattern_color_indexes);
    }

    public int getFillForegroundColor() {
        return patternColorIndex.getValue(this.field_16_pattern_color_indexes);
    }

    public int getFillPattern() {
        return fillPatternStyle.getValue(this.field_15_pattern_style);
    }

    public void serialize(LittleEndianOutput littleEndianOutput) {
        littleEndianOutput.writeShort(this.field_15_pattern_style);
        littleEndianOutput.writeShort(this.field_16_pattern_color_indexes);
    }

    public void setFillBackgroundColor(int i2) {
        this.field_16_pattern_color_indexes = patternBackgroundColorIndex.setValue(this.field_16_pattern_color_indexes, i2);
    }

    public void setFillForegroundColor(int i2) {
        this.field_16_pattern_color_indexes = patternColorIndex.setValue(this.field_16_pattern_color_indexes, i2);
    }

    public void setFillPattern(int i2) {
        this.field_15_pattern_style = fillPatternStyle.setValue(this.field_15_pattern_style, i2);
    }

    public String toString() {
        StringBuffer c = a.c("    [Pattern Formatting]\n", "          .fillpattern= ");
        c.append(Integer.toHexString(getFillPattern()));
        c.append("\n");
        c.append("          .fgcoloridx= ");
        c.append(Integer.toHexString(getFillForegroundColor()));
        c.append("\n");
        c.append("          .bgcoloridx= ");
        c.append(Integer.toHexString(getFillBackgroundColor()));
        c.append("\n");
        c.append("    [/Pattern Formatting]\n");
        return c.toString();
    }

    public PatternFormatting(LittleEndianInput littleEndianInput) {
        this.field_15_pattern_style = littleEndianInput.readUShort();
        this.field_16_pattern_color_indexes = littleEndianInput.readUShort();
    }
}
