package org.apache.poi.hssf.record.cf;

import b.b.a.a.a;
import java.util.Arrays;
import org.apache.poi.ss.formula.Formula;
import org.apache.poi.ss.formula.functions.NumericFunction;
import org.apache.poi.ss.formula.ptg.Ptg;
import org.apache.poi.ss.usermodel.ConditionalFormattingThreshold;
import org.apache.poi.util.LittleEndianInput;
import org.apache.poi.util.LittleEndianOutput;

public abstract class Threshold {
    public Formula formula;
    public byte type;
    public Double value;

    public Threshold() {
        this.type = (byte) ConditionalFormattingThreshold.RangeType.NUMBER.id;
        this.formula = Formula.create(null);
        this.value = Double.valueOf((double) NumericFunction.LOG_10_TO_BASE_e);
    }

    public void copyTo(Threshold threshold) {
        threshold.type = this.type;
        threshold.formula = this.formula;
        threshold.value = this.value;
    }

    public int getDataLength() {
        int encodedSize = this.formula.getEncodedSize() + 1;
        return this.value != null ? encodedSize + 8 : encodedSize;
    }

    public Formula getFormula() {
        return this.formula;
    }

    public Ptg[] getParsedExpression() {
        return this.formula.getTokens();
    }

    public byte getType() {
        return this.type;
    }

    public Double getValue() {
        return this.value;
    }

    public void serialize(LittleEndianOutput littleEndianOutput) {
        littleEndianOutput.writeByte(this.type);
        if (this.formula.getTokens().length == 0) {
            littleEndianOutput.writeShort(0);
        } else {
            this.formula.serialize(littleEndianOutput);
        }
        Double d2 = this.value;
        if (d2 != null) {
            littleEndianOutput.writeDouble(d2.doubleValue());
        }
    }

    public void setParsedExpression(Ptg[] ptgArr) {
        this.formula = Formula.create(ptgArr);
        if (ptgArr.length > 0) {
            this.value = null;
        }
    }

    public void setType(byte b2) {
        this.type = b2;
        if (b2 == ConditionalFormattingThreshold.RangeType.MIN.id || b2 == ConditionalFormattingThreshold.RangeType.MAX.id || b2 == ConditionalFormattingThreshold.RangeType.FORMULA.id) {
            this.value = null;
        } else if (this.value == null) {
            this.value = Double.valueOf((double) NumericFunction.LOG_10_TO_BASE_e);
        }
    }

    public void setValue(Double d2) {
        this.value = d2;
    }

    public String toString() {
        StringBuffer c = a.c("    [CF Threshold]\n", "          .type    = ");
        c.append(Integer.toHexString(this.type));
        c.append("\n");
        c.append("          .formula = ");
        c.append(Arrays.toString(this.formula.getTokens()));
        c.append("\n");
        c.append("          .value   = ");
        c.append(this.value);
        c.append("\n");
        c.append("    [/CF Threshold]\n");
        return c.toString();
    }

    public Threshold(LittleEndianInput littleEndianInput) {
        byte b2;
        this.type = littleEndianInput.readByte();
        short readShort = littleEndianInput.readShort();
        if (readShort > 0) {
            this.formula = Formula.read(readShort, littleEndianInput);
        } else {
            this.formula = Formula.create(null);
        }
        if (readShort == 0 && (b2 = this.type) != ConditionalFormattingThreshold.RangeType.MIN.id && b2 != ConditionalFormattingThreshold.RangeType.MAX.id) {
            this.value = Double.valueOf(littleEndianInput.readDouble());
        }
    }

    public void setType(int i2) {
        this.type = (byte) i2;
    }
}
