package org.apache.poi.hssf.record.chart;

import b.b.a.a.a;
import org.apache.poi.hssf.record.RecordInputStream;
import org.apache.poi.hssf.record.StandardRecord;
import org.apache.poi.util.BitField;
import org.apache.poi.util.BitFieldFactory;
import org.apache.poi.util.HexDump;
import org.apache.poi.util.LittleEndianOutput;

public final class AreaFormatRecord extends StandardRecord implements Cloneable {
    public static final BitField automatic = BitFieldFactory.getInstance(1);
    public static final BitField invert = BitFieldFactory.getInstance(2);
    public static final short sid = 4106;
    public int field_1_foregroundColor;
    public int field_2_backgroundColor;
    public short field_3_pattern;
    public short field_4_formatFlags;
    public short field_5_forecolorIndex;
    public short field_6_backcolorIndex;

    public AreaFormatRecord() {
    }

    public short getBackcolorIndex() {
        return this.field_6_backcolorIndex;
    }

    public int getBackgroundColor() {
        return this.field_2_backgroundColor;
    }

    @Override // org.apache.poi.hssf.record.StandardRecord
    public int getDataSize() {
        return 16;
    }

    public short getForecolorIndex() {
        return this.field_5_forecolorIndex;
    }

    public int getForegroundColor() {
        return this.field_1_foregroundColor;
    }

    public short getFormatFlags() {
        return this.field_4_formatFlags;
    }

    public short getPattern() {
        return this.field_3_pattern;
    }

    @Override // org.apache.poi.hssf.record.Record
    public short getSid() {
        return sid;
    }

    public boolean isAutomatic() {
        return automatic.isSet(this.field_4_formatFlags);
    }

    public boolean isInvert() {
        return invert.isSet(this.field_4_formatFlags);
    }

    @Override // org.apache.poi.hssf.record.StandardRecord
    public void serialize(LittleEndianOutput littleEndianOutput) {
        littleEndianOutput.writeInt(this.field_1_foregroundColor);
        littleEndianOutput.writeInt(this.field_2_backgroundColor);
        littleEndianOutput.writeShort(this.field_3_pattern);
        littleEndianOutput.writeShort(this.field_4_formatFlags);
        littleEndianOutput.writeShort(this.field_5_forecolorIndex);
        littleEndianOutput.writeShort(this.field_6_backcolorIndex);
    }

    public void setAutomatic(boolean z) {
        this.field_4_formatFlags = automatic.setShortBoolean(this.field_4_formatFlags, z);
    }

    public void setBackcolorIndex(short s) {
        this.field_6_backcolorIndex = s;
    }

    public void setBackgroundColor(int i2) {
        this.field_2_backgroundColor = i2;
    }

    public void setForecolorIndex(short s) {
        this.field_5_forecolorIndex = s;
    }

    public void setForegroundColor(int i2) {
        this.field_1_foregroundColor = i2;
    }

    public void setFormatFlags(short s) {
        this.field_4_formatFlags = s;
    }

    public void setInvert(boolean z) {
        this.field_4_formatFlags = invert.setShortBoolean(this.field_4_formatFlags, z);
    }

    public void setPattern(short s) {
        this.field_3_pattern = s;
    }

    @Override // org.apache.poi.hssf.record.Record
    public String toString() {
        StringBuffer c = a.c("[AREAFORMAT]\n", "    .foregroundColor      = ", "0x");
        c.append(HexDump.toHex(getForegroundColor()));
        c.append(" (");
        c.append(getForegroundColor());
        c.append(" )");
        c.append(System.getProperty("line.separator"));
        c.append("    .backgroundColor      = ");
        c.append("0x");
        c.append(HexDump.toHex(getBackgroundColor()));
        c.append(" (");
        c.append(getBackgroundColor());
        c.append(" )");
        c.append(System.getProperty("line.separator"));
        c.append("    .pattern              = ");
        c.append("0x");
        c.append(HexDump.toHex(getPattern()));
        c.append(" (");
        c.append((int) getPattern());
        c.append(" )");
        c.append(System.getProperty("line.separator"));
        c.append("    .formatFlags          = ");
        c.append("0x");
        c.append(HexDump.toHex(getFormatFlags()));
        c.append(" (");
        c.append((int) getFormatFlags());
        c.append(" )");
        c.append(System.getProperty("line.separator"));
        c.append("         .automatic                = ");
        c.append(isAutomatic());
        c.append('\n');
        c.append("         .invert                   = ");
        c.append(isInvert());
        c.append('\n');
        c.append("    .forecolorIndex       = ");
        c.append("0x");
        c.append(HexDump.toHex(getForecolorIndex()));
        c.append(" (");
        c.append((int) getForecolorIndex());
        c.append(" )");
        c.append(System.getProperty("line.separator"));
        c.append("    .backcolorIndex       = ");
        c.append("0x");
        c.append(HexDump.toHex(getBackcolorIndex()));
        c.append(" (");
        c.append((int) getBackcolorIndex());
        c.append(" )");
        c.append(System.getProperty("line.separator"));
        c.append("[/AREAFORMAT]\n");
        return c.toString();
    }

    public AreaFormatRecord(RecordInputStream recordInputStream) {
        this.field_1_foregroundColor = recordInputStream.readInt();
        this.field_2_backgroundColor = recordInputStream.readInt();
        this.field_3_pattern = recordInputStream.readShort();
        this.field_4_formatFlags = recordInputStream.readShort();
        this.field_5_forecolorIndex = recordInputStream.readShort();
        this.field_6_backcolorIndex = recordInputStream.readShort();
    }

    @Override // org.apache.poi.hssf.record.Record, java.lang.Object
    public AreaFormatRecord clone() {
        AreaFormatRecord areaFormatRecord = new AreaFormatRecord();
        areaFormatRecord.field_1_foregroundColor = this.field_1_foregroundColor;
        areaFormatRecord.field_2_backgroundColor = this.field_2_backgroundColor;
        areaFormatRecord.field_3_pattern = this.field_3_pattern;
        areaFormatRecord.field_4_formatFlags = this.field_4_formatFlags;
        areaFormatRecord.field_5_forecolorIndex = this.field_5_forecolorIndex;
        areaFormatRecord.field_6_backcolorIndex = this.field_6_backcolorIndex;
        return areaFormatRecord;
    }
}
