package org.apache.poi.hssf.record.chart;

import b.b.a.a.a;
import org.apache.poi.hssf.record.RecordInputStream;
import org.apache.poi.hssf.record.StandardRecord;
import org.apache.poi.util.BitField;
import org.apache.poi.util.BitFieldFactory;
import org.apache.poi.util.HexDump;
import org.apache.poi.util.LittleEndianOutput;

public final class AxisOptionsRecord extends StandardRecord implements Cloneable {
    public static final BitField defaultBase = BitFieldFactory.getInstance(32);
    public static final BitField defaultCross = BitFieldFactory.getInstance(64);
    public static final BitField defaultDateSettings = BitFieldFactory.getInstance(128);
    public static final BitField defaultMajor = BitFieldFactory.getInstance(4);
    public static final BitField defaultMaximum = BitFieldFactory.getInstance(2);
    public static final BitField defaultMinimum = BitFieldFactory.getInstance(1);
    public static final BitField defaultMinorUnit = BitFieldFactory.getInstance(8);
    public static final BitField isDate = BitFieldFactory.getInstance(16);
    public static final short sid = 4194;
    public short field_1_minimumCategory;
    public short field_2_maximumCategory;
    public short field_3_majorUnitValue;
    public short field_4_majorUnit;
    public short field_5_minorUnitValue;
    public short field_6_minorUnit;
    public short field_7_baseUnit;
    public short field_8_crossingPoint;
    public short field_9_options;

    public AxisOptionsRecord() {
    }

    public short getBaseUnit() {
        return this.field_7_baseUnit;
    }

    public short getCrossingPoint() {
        return this.field_8_crossingPoint;
    }

    @Override // org.apache.poi.hssf.record.StandardRecord
    public int getDataSize() {
        return 18;
    }

    public short getMajorUnit() {
        return this.field_4_majorUnit;
    }

    public short getMajorUnitValue() {
        return this.field_3_majorUnitValue;
    }

    public short getMaximumCategory() {
        return this.field_2_maximumCategory;
    }

    public short getMinimumCategory() {
        return this.field_1_minimumCategory;
    }

    public short getMinorUnit() {
        return this.field_6_minorUnit;
    }

    public short getMinorUnitValue() {
        return this.field_5_minorUnitValue;
    }

    public short getOptions() {
        return this.field_9_options;
    }

    @Override // org.apache.poi.hssf.record.Record
    public short getSid() {
        return sid;
    }

    public boolean isDefaultBase() {
        return defaultBase.isSet(this.field_9_options);
    }

    public boolean isDefaultCross() {
        return defaultCross.isSet(this.field_9_options);
    }

    public boolean isDefaultDateSettings() {
        return defaultDateSettings.isSet(this.field_9_options);
    }

    public boolean isDefaultMajor() {
        return defaultMajor.isSet(this.field_9_options);
    }

    public boolean isDefaultMaximum() {
        return defaultMaximum.isSet(this.field_9_options);
    }

    public boolean isDefaultMinimum() {
        return defaultMinimum.isSet(this.field_9_options);
    }

    public boolean isDefaultMinorUnit() {
        return defaultMinorUnit.isSet(this.field_9_options);
    }

    public boolean isIsDate() {
        return isDate.isSet(this.field_9_options);
    }

    @Override // org.apache.poi.hssf.record.StandardRecord
    public void serialize(LittleEndianOutput littleEndianOutput) {
        littleEndianOutput.writeShort(this.field_1_minimumCategory);
        littleEndianOutput.writeShort(this.field_2_maximumCategory);
        littleEndianOutput.writeShort(this.field_3_majorUnitValue);
        littleEndianOutput.writeShort(this.field_4_majorUnit);
        littleEndianOutput.writeShort(this.field_5_minorUnitValue);
        littleEndianOutput.writeShort(this.field_6_minorUnit);
        littleEndianOutput.writeShort(this.field_7_baseUnit);
        littleEndianOutput.writeShort(this.field_8_crossingPoint);
        littleEndianOutput.writeShort(this.field_9_options);
    }

    public void setBaseUnit(short s) {
        this.field_7_baseUnit = s;
    }

    public void setCrossingPoint(short s) {
        this.field_8_crossingPoint = s;
    }

    public void setDefaultBase(boolean z) {
        this.field_9_options = defaultBase.setShortBoolean(this.field_9_options, z);
    }

    public void setDefaultCross(boolean z) {
        this.field_9_options = defaultCross.setShortBoolean(this.field_9_options, z);
    }

    public void setDefaultDateSettings(boolean z) {
        this.field_9_options = defaultDateSettings.setShortBoolean(this.field_9_options, z);
    }

    public void setDefaultMajor(boolean z) {
        this.field_9_options = defaultMajor.setShortBoolean(this.field_9_options, z);
    }

    public void setDefaultMaximum(boolean z) {
        this.field_9_options = defaultMaximum.setShortBoolean(this.field_9_options, z);
    }

    public void setDefaultMinimum(boolean z) {
        this.field_9_options = defaultMinimum.setShortBoolean(this.field_9_options, z);
    }

    public void setDefaultMinorUnit(boolean z) {
        this.field_9_options = defaultMinorUnit.setShortBoolean(this.field_9_options, z);
    }

    public void setIsDate(boolean z) {
        this.field_9_options = isDate.setShortBoolean(this.field_9_options, z);
    }

    public void setMajorUnit(short s) {
        this.field_4_majorUnit = s;
    }

    public void setMajorUnitValue(short s) {
        this.field_3_majorUnitValue = s;
    }

    public void setMaximumCategory(short s) {
        this.field_2_maximumCategory = s;
    }

    public void setMinimumCategory(short s) {
        this.field_1_minimumCategory = s;
    }

    public void setMinorUnit(short s) {
        this.field_6_minorUnit = s;
    }

    public void setMinorUnitValue(short s) {
        this.field_5_minorUnitValue = s;
    }

    public void setOptions(short s) {
        this.field_9_options = s;
    }

    @Override // org.apache.poi.hssf.record.Record
    public String toString() {
        StringBuffer c = a.c("[AXCEXT]\n", "    .minimumCategory      = ", "0x");
        c.append(HexDump.toHex(getMinimumCategory()));
        c.append(" (");
        c.append((int) getMinimumCategory());
        c.append(" )");
        c.append(System.getProperty("line.separator"));
        c.append("    .maximumCategory      = ");
        c.append("0x");
        c.append(HexDump.toHex(getMaximumCategory()));
        c.append(" (");
        c.append((int) getMaximumCategory());
        c.append(" )");
        c.append(System.getProperty("line.separator"));
        c.append("    .majorUnitValue       = ");
        c.append("0x");
        c.append(HexDump.toHex(getMajorUnitValue()));
        c.append(" (");
        c.append((int) getMajorUnitValue());
        c.append(" )");
        c.append(System.getProperty("line.separator"));
        c.append("    .majorUnit            = ");
        c.append("0x");
        c.append(HexDump.toHex(getMajorUnit()));
        c.append(" (");
        c.append((int) getMajorUnit());
        c.append(" )");
        c.append(System.getProperty("line.separator"));
        c.append("    .minorUnitValue       = ");
        c.append("0x");
        c.append(HexDump.toHex(getMinorUnitValue()));
        c.append(" (");
        c.append((int) getMinorUnitValue());
        c.append(" )");
        c.append(System.getProperty("line.separator"));
        c.append("    .minorUnit            = ");
        c.append("0x");
        c.append(HexDump.toHex(getMinorUnit()));
        c.append(" (");
        c.append((int) getMinorUnit());
        c.append(" )");
        c.append(System.getProperty("line.separator"));
        c.append("    .baseUnit             = ");
        c.append("0x");
        c.append(HexDump.toHex(getBaseUnit()));
        c.append(" (");
        c.append((int) getBaseUnit());
        c.append(" )");
        c.append(System.getProperty("line.separator"));
        c.append("    .crossingPoint        = ");
        c.append("0x");
        c.append(HexDump.toHex(getCrossingPoint()));
        c.append(" (");
        c.append((int) getCrossingPoint());
        c.append(" )");
        c.append(System.getProperty("line.separator"));
        c.append("    .options              = ");
        c.append("0x");
        c.append(HexDump.toHex(getOptions()));
        c.append(" (");
        c.append((int) getOptions());
        c.append(" )");
        c.append(System.getProperty("line.separator"));
        c.append("         .defaultMinimum           = ");
        c.append(isDefaultMinimum());
        c.append('\n');
        c.append("         .defaultMaximum           = ");
        c.append(isDefaultMaximum());
        c.append('\n');
        c.append("         .defaultMajor             = ");
        c.append(isDefaultMajor());
        c.append('\n');
        c.append("         .defaultMinorUnit         = ");
        c.append(isDefaultMinorUnit());
        c.append('\n');
        c.append("         .isDate                   = ");
        c.append(isIsDate());
        c.append('\n');
        c.append("         .defaultBase              = ");
        c.append(isDefaultBase());
        c.append('\n');
        c.append("         .defaultCross             = ");
        c.append(isDefaultCross());
        c.append('\n');
        c.append("         .defaultDateSettings      = ");
        c.append(isDefaultDateSettings());
        c.append('\n');
        c.append("[/AXCEXT]\n");
        return c.toString();
    }

    public AxisOptionsRecord(RecordInputStream recordInputStream) {
        this.field_1_minimumCategory = recordInputStream.readShort();
        this.field_2_maximumCategory = recordInputStream.readShort();
        this.field_3_majorUnitValue = recordInputStream.readShort();
        this.field_4_majorUnit = recordInputStream.readShort();
        this.field_5_minorUnitValue = recordInputStream.readShort();
        this.field_6_minorUnit = recordInputStream.readShort();
        this.field_7_baseUnit = recordInputStream.readShort();
        this.field_8_crossingPoint = recordInputStream.readShort();
        this.field_9_options = recordInputStream.readShort();
    }

    @Override // org.apache.poi.hssf.record.Record, java.lang.Object
    public AxisOptionsRecord clone() {
        AxisOptionsRecord axisOptionsRecord = new AxisOptionsRecord();
        axisOptionsRecord.field_1_minimumCategory = this.field_1_minimumCategory;
        axisOptionsRecord.field_2_maximumCategory = this.field_2_maximumCategory;
        axisOptionsRecord.field_3_majorUnitValue = this.field_3_majorUnitValue;
        axisOptionsRecord.field_4_majorUnit = this.field_4_majorUnit;
        axisOptionsRecord.field_5_minorUnitValue = this.field_5_minorUnitValue;
        axisOptionsRecord.field_6_minorUnit = this.field_6_minorUnit;
        axisOptionsRecord.field_7_baseUnit = this.field_7_baseUnit;
        axisOptionsRecord.field_8_crossingPoint = this.field_8_crossingPoint;
        axisOptionsRecord.field_9_options = this.field_9_options;
        return axisOptionsRecord;
    }
}
