package org.apache.poi.hssf.record.chart;

import b.b.a.a.a;
import org.apache.poi.hssf.record.RecordInputStream;
import org.apache.poi.hssf.record.StandardRecord;
import org.apache.poi.util.HexDump;
import org.apache.poi.util.LittleEndianOutput;

public final class AxisParentRecord extends StandardRecord implements Cloneable {
    public static final short AXIS_TYPE_MAIN = 0;
    public static final short AXIS_TYPE_SECONDARY = 1;
    public static final short sid = 4161;
    public short field_1_axisType;
    public int field_2_x;
    public int field_3_y;
    public int field_4_width;
    public int field_5_height;

    public AxisParentRecord() {
    }

    public short getAxisType() {
        return this.field_1_axisType;
    }

    @Override // org.apache.poi.hssf.record.StandardRecord
    public int getDataSize() {
        return 18;
    }

    public int getHeight() {
        return this.field_5_height;
    }

    @Override // org.apache.poi.hssf.record.Record
    public short getSid() {
        return sid;
    }

    public int getWidth() {
        return this.field_4_width;
    }

    public int getX() {
        return this.field_2_x;
    }

    public int getY() {
        return this.field_3_y;
    }

    @Override // org.apache.poi.hssf.record.StandardRecord
    public void serialize(LittleEndianOutput littleEndianOutput) {
        littleEndianOutput.writeShort(this.field_1_axisType);
        littleEndianOutput.writeInt(this.field_2_x);
        littleEndianOutput.writeInt(this.field_3_y);
        littleEndianOutput.writeInt(this.field_4_width);
        littleEndianOutput.writeInt(this.field_5_height);
    }

    public void setAxisType(short s) {
        this.field_1_axisType = s;
    }

    public void setHeight(int i2) {
        this.field_5_height = i2;
    }

    public void setWidth(int i2) {
        this.field_4_width = i2;
    }

    public void setX(int i2) {
        this.field_2_x = i2;
    }

    public void setY(int i2) {
        this.field_3_y = i2;
    }

    @Override // org.apache.poi.hssf.record.Record
    public String toString() {
        StringBuffer c = a.c("[AXISPARENT]\n", "    .axisType             = ", "0x");
        c.append(HexDump.toHex(getAxisType()));
        c.append(" (");
        c.append((int) getAxisType());
        c.append(" )");
        c.append(System.getProperty("line.separator"));
        c.append("    .x                    = ");
        c.append("0x");
        c.append(HexDump.toHex(getX()));
        c.append(" (");
        c.append(getX());
        c.append(" )");
        c.append(System.getProperty("line.separator"));
        c.append("    .y                    = ");
        c.append("0x");
        c.append(HexDump.toHex(getY()));
        c.append(" (");
        c.append(getY());
        c.append(" )");
        c.append(System.getProperty("line.separator"));
        c.append("    .width                = ");
        c.append("0x");
        c.append(HexDump.toHex(getWidth()));
        c.append(" (");
        c.append(getWidth());
        c.append(" )");
        c.append(System.getProperty("line.separator"));
        c.append("    .height               = ");
        c.append("0x");
        c.append(HexDump.toHex(getHeight()));
        c.append(" (");
        c.append(getHeight());
        c.append(" )");
        c.append(System.getProperty("line.separator"));
        c.append("[/AXISPARENT]\n");
        return c.toString();
    }

    public AxisParentRecord(RecordInputStream recordInputStream) {
        this.field_1_axisType = recordInputStream.readShort();
        this.field_2_x = recordInputStream.readInt();
        this.field_3_y = recordInputStream.readInt();
        this.field_4_width = recordInputStream.readInt();
        this.field_5_height = recordInputStream.readInt();
    }

    @Override // org.apache.poi.hssf.record.Record, java.lang.Object
    public AxisParentRecord clone() {
        AxisParentRecord axisParentRecord = new AxisParentRecord();
        axisParentRecord.field_1_axisType = this.field_1_axisType;
        axisParentRecord.field_2_x = this.field_2_x;
        axisParentRecord.field_3_y = this.field_3_y;
        axisParentRecord.field_4_width = this.field_4_width;
        axisParentRecord.field_5_height = this.field_5_height;
        return axisParentRecord;
    }
}
