package org.apache.poi.hssf.record.chart;

import b.b.a.a.a;
import org.apache.poi.hssf.record.RecordInputStream;
import org.apache.poi.hssf.record.StandardRecord;
import org.apache.poi.util.HexDump;
import org.apache.poi.util.LittleEndianOutput;

public final class AxisRecord extends StandardRecord implements Cloneable {
    public static final short AXIS_TYPE_CATEGORY_OR_X_AXIS = 0;
    public static final short AXIS_TYPE_SERIES_AXIS = 2;
    public static final short AXIS_TYPE_VALUE_AXIS = 1;
    public static final short sid = 4125;
    public short field_1_axisType;
    public int field_2_reserved1;
    public int field_3_reserved2;
    public int field_4_reserved3;
    public int field_5_reserved4;

    public AxisRecord() {
    }

    public short getAxisType() {
        return this.field_1_axisType;
    }

    @Override // org.apache.poi.hssf.record.StandardRecord
    public int getDataSize() {
        return 18;
    }

    public int getReserved1() {
        return this.field_2_reserved1;
    }

    public int getReserved2() {
        return this.field_3_reserved2;
    }

    public int getReserved3() {
        return this.field_4_reserved3;
    }

    public int getReserved4() {
        return this.field_5_reserved4;
    }

    @Override // org.apache.poi.hssf.record.Record
    public short getSid() {
        return sid;
    }

    @Override // org.apache.poi.hssf.record.StandardRecord
    public void serialize(LittleEndianOutput littleEndianOutput) {
        littleEndianOutput.writeShort(this.field_1_axisType);
        littleEndianOutput.writeInt(this.field_2_reserved1);
        littleEndianOutput.writeInt(this.field_3_reserved2);
        littleEndianOutput.writeInt(this.field_4_reserved3);
        littleEndianOutput.writeInt(this.field_5_reserved4);
    }

    public void setAxisType(short s) {
        this.field_1_axisType = s;
    }

    public void setReserved1(int i2) {
        this.field_2_reserved1 = i2;
    }

    public void setReserved2(int i2) {
        this.field_3_reserved2 = i2;
    }

    public void setReserved3(int i2) {
        this.field_4_reserved3 = i2;
    }

    public void setReserved4(int i2) {
        this.field_5_reserved4 = i2;
    }

    @Override // org.apache.poi.hssf.record.Record
    public String toString() {
        StringBuffer c = a.c("[AXIS]\n", "    .axisType             = ", "0x");
        c.append(HexDump.toHex(getAxisType()));
        c.append(" (");
        c.append((int) getAxisType());
        c.append(" )");
        c.append(System.getProperty("line.separator"));
        c.append("    .reserved1            = ");
        c.append("0x");
        c.append(HexDump.toHex(getReserved1()));
        c.append(" (");
        c.append(getReserved1());
        c.append(" )");
        c.append(System.getProperty("line.separator"));
        c.append("    .reserved2            = ");
        c.append("0x");
        c.append(HexDump.toHex(getReserved2()));
        c.append(" (");
        c.append(getReserved2());
        c.append(" )");
        c.append(System.getProperty("line.separator"));
        c.append("    .reserved3            = ");
        c.append("0x");
        c.append(HexDump.toHex(getReserved3()));
        c.append(" (");
        c.append(getReserved3());
        c.append(" )");
        c.append(System.getProperty("line.separator"));
        c.append("    .reserved4            = ");
        c.append("0x");
        c.append(HexDump.toHex(getReserved4()));
        c.append(" (");
        c.append(getReserved4());
        c.append(" )");
        c.append(System.getProperty("line.separator"));
        c.append("[/AXIS]\n");
        return c.toString();
    }

    public AxisRecord(RecordInputStream recordInputStream) {
        this.field_1_axisType = recordInputStream.readShort();
        this.field_2_reserved1 = recordInputStream.readInt();
        this.field_3_reserved2 = recordInputStream.readInt();
        this.field_4_reserved3 = recordInputStream.readInt();
        this.field_5_reserved4 = recordInputStream.readInt();
    }

    @Override // org.apache.poi.hssf.record.Record, java.lang.Object
    public AxisRecord clone() {
        AxisRecord axisRecord = new AxisRecord();
        axisRecord.field_1_axisType = this.field_1_axisType;
        axisRecord.field_2_reserved1 = this.field_2_reserved1;
        axisRecord.field_3_reserved2 = this.field_3_reserved2;
        axisRecord.field_4_reserved3 = this.field_4_reserved3;
        axisRecord.field_5_reserved4 = this.field_5_reserved4;
        return axisRecord;
    }
}
