package org.apache.poi.hssf.record.chart;

import b.b.a.a.a;
import org.apache.poi.hssf.record.RecordInputStream;
import org.apache.poi.hssf.record.StandardRecord;
import org.apache.poi.util.BitField;
import org.apache.poi.util.BitFieldFactory;
import org.apache.poi.util.HexDump;
import org.apache.poi.util.LittleEndianOutput;

public final class BarRecord extends StandardRecord implements Cloneable {
    public static final BitField displayAsPercentage = BitFieldFactory.getInstance(4);
    public static final BitField horizontal = BitFieldFactory.getInstance(1);
    public static final BitField shadow = BitFieldFactory.getInstance(8);
    public static final short sid = 4119;
    public static final BitField stacked = BitFieldFactory.getInstance(2);
    public short field_1_barSpace;
    public short field_2_categorySpace;
    public short field_3_formatFlags;

    public BarRecord() {
    }

    public short getBarSpace() {
        return this.field_1_barSpace;
    }

    public short getCategorySpace() {
        return this.field_2_categorySpace;
    }

    @Override // org.apache.poi.hssf.record.StandardRecord
    public int getDataSize() {
        return 6;
    }

    public short getFormatFlags() {
        return this.field_3_formatFlags;
    }

    @Override // org.apache.poi.hssf.record.Record
    public short getSid() {
        return sid;
    }

    public boolean isDisplayAsPercentage() {
        return displayAsPercentage.isSet(this.field_3_formatFlags);
    }

    public boolean isHorizontal() {
        return horizontal.isSet(this.field_3_formatFlags);
    }

    public boolean isShadow() {
        return shadow.isSet(this.field_3_formatFlags);
    }

    public boolean isStacked() {
        return stacked.isSet(this.field_3_formatFlags);
    }

    @Override // org.apache.poi.hssf.record.StandardRecord
    public void serialize(LittleEndianOutput littleEndianOutput) {
        littleEndianOutput.writeShort(this.field_1_barSpace);
        littleEndianOutput.writeShort(this.field_2_categorySpace);
        littleEndianOutput.writeShort(this.field_3_formatFlags);
    }

    public void setBarSpace(short s) {
        this.field_1_barSpace = s;
    }

    public void setCategorySpace(short s) {
        this.field_2_categorySpace = s;
    }

    public void setDisplayAsPercentage(boolean z) {
        this.field_3_formatFlags = displayAsPercentage.setShortBoolean(this.field_3_formatFlags, z);
    }

    public void setFormatFlags(short s) {
        this.field_3_formatFlags = s;
    }

    public void setHorizontal(boolean z) {
        this.field_3_formatFlags = horizontal.setShortBoolean(this.field_3_formatFlags, z);
    }

    public void setShadow(boolean z) {
        this.field_3_formatFlags = shadow.setShortBoolean(this.field_3_formatFlags, z);
    }

    public void setStacked(boolean z) {
        this.field_3_formatFlags = stacked.setShortBoolean(this.field_3_formatFlags, z);
    }

    @Override // org.apache.poi.hssf.record.Record
    public String toString() {
        StringBuffer c = a.c("[BAR]\n", "    .barSpace             = ", "0x");
        c.append(HexDump.toHex(getBarSpace()));
        c.append(" (");
        c.append((int) getBarSpace());
        c.append(" )");
        c.append(System.getProperty("line.separator"));
        c.append("    .categorySpace        = ");
        c.append("0x");
        c.append(HexDump.toHex(getCategorySpace()));
        c.append(" (");
        c.append((int) getCategorySpace());
        c.append(" )");
        c.append(System.getProperty("line.separator"));
        c.append("    .formatFlags          = ");
        c.append("0x");
        c.append(HexDump.toHex(getFormatFlags()));
        c.append(" (");
        c.append((int) getFormatFlags());
        c.append(" )");
        c.append(System.getProperty("line.separator"));
        c.append("         .horizontal               = ");
        c.append(isHorizontal());
        c.append('\n');
        c.append("         .stacked                  = ");
        c.append(isStacked());
        c.append('\n');
        c.append("         .displayAsPercentage      = ");
        c.append(isDisplayAsPercentage());
        c.append('\n');
        c.append("         .shadow                   = ");
        c.append(isShadow());
        c.append('\n');
        c.append("[/BAR]\n");
        return c.toString();
    }

    public BarRecord(RecordInputStream recordInputStream) {
        this.field_1_barSpace = recordInputStream.readShort();
        this.field_2_categorySpace = recordInputStream.readShort();
        this.field_3_formatFlags = recordInputStream.readShort();
    }

    @Override // org.apache.poi.hssf.record.Record, java.lang.Object
    public BarRecord clone() {
        BarRecord barRecord = new BarRecord();
        barRecord.field_1_barSpace = this.field_1_barSpace;
        barRecord.field_2_categorySpace = this.field_2_categorySpace;
        barRecord.field_3_formatFlags = this.field_3_formatFlags;
        return barRecord;
    }
}
