package org.apache.poi.hssf.record.chart;

import b.b.a.a.a;
import org.apache.poi.hssf.record.RecordInputStream;
import org.apache.poi.hssf.record.StandardRecord;
import org.apache.poi.util.BitField;
import org.apache.poi.util.BitFieldFactory;
import org.apache.poi.util.HexDump;
import org.apache.poi.util.LittleEndianOutput;

public final class CategorySeriesAxisRecord extends StandardRecord implements Cloneable {
    public static final BitField crossesFarRight = BitFieldFactory.getInstance(2);
    public static final BitField reversed = BitFieldFactory.getInstance(4);
    public static final short sid = 4128;
    public static final BitField valueAxisCrossing = BitFieldFactory.getInstance(1);
    public short field_1_crossingPoint;
    public short field_2_labelFrequency;
    public short field_3_tickMarkFrequency;
    public short field_4_options;

    public CategorySeriesAxisRecord() {
    }

    public short getCrossingPoint() {
        return this.field_1_crossingPoint;
    }

    @Override // org.apache.poi.hssf.record.StandardRecord
    public int getDataSize() {
        return 8;
    }

    public short getLabelFrequency() {
        return this.field_2_labelFrequency;
    }

    public short getOptions() {
        return this.field_4_options;
    }

    @Override // org.apache.poi.hssf.record.Record
    public short getSid() {
        return sid;
    }

    public short getTickMarkFrequency() {
        return this.field_3_tickMarkFrequency;
    }

    public boolean isCrossesFarRight() {
        return crossesFarRight.isSet(this.field_4_options);
    }

    public boolean isReversed() {
        return reversed.isSet(this.field_4_options);
    }

    public boolean isValueAxisCrossing() {
        return valueAxisCrossing.isSet(this.field_4_options);
    }

    @Override // org.apache.poi.hssf.record.StandardRecord
    public void serialize(LittleEndianOutput littleEndianOutput) {
        littleEndianOutput.writeShort(this.field_1_crossingPoint);
        littleEndianOutput.writeShort(this.field_2_labelFrequency);
        littleEndianOutput.writeShort(this.field_3_tickMarkFrequency);
        littleEndianOutput.writeShort(this.field_4_options);
    }

    public void setCrossesFarRight(boolean z) {
        this.field_4_options = crossesFarRight.setShortBoolean(this.field_4_options, z);
    }

    public void setCrossingPoint(short s) {
        this.field_1_crossingPoint = s;
    }

    public void setLabelFrequency(short s) {
        this.field_2_labelFrequency = s;
    }

    public void setOptions(short s) {
        this.field_4_options = s;
    }

    public void setReversed(boolean z) {
        this.field_4_options = reversed.setShortBoolean(this.field_4_options, z);
    }

    public void setTickMarkFrequency(short s) {
        this.field_3_tickMarkFrequency = s;
    }

    public void setValueAxisCrossing(boolean z) {
        this.field_4_options = valueAxisCrossing.setShortBoolean(this.field_4_options, z);
    }

    @Override // org.apache.poi.hssf.record.Record
    public String toString() {
        StringBuffer c = a.c("[CATSERRANGE]\n", "    .crossingPoint        = ", "0x");
        c.append(HexDump.toHex(getCrossingPoint()));
        c.append(" (");
        c.append((int) getCrossingPoint());
        c.append(" )");
        c.append(System.getProperty("line.separator"));
        c.append("    .labelFrequency       = ");
        c.append("0x");
        c.append(HexDump.toHex(getLabelFrequency()));
        c.append(" (");
        c.append((int) getLabelFrequency());
        c.append(" )");
        c.append(System.getProperty("line.separator"));
        c.append("    .tickMarkFrequency    = ");
        c.append("0x");
        c.append(HexDump.toHex(getTickMarkFrequency()));
        c.append(" (");
        c.append((int) getTickMarkFrequency());
        c.append(" )");
        c.append(System.getProperty("line.separator"));
        c.append("    .options              = ");
        c.append("0x");
        c.append(HexDump.toHex(getOptions()));
        c.append(" (");
        c.append((int) getOptions());
        c.append(" )");
        c.append(System.getProperty("line.separator"));
        c.append("         .valueAxisCrossing        = ");
        c.append(isValueAxisCrossing());
        c.append('\n');
        c.append("         .crossesFarRight          = ");
        c.append(isCrossesFarRight());
        c.append('\n');
        c.append("         .reversed                 = ");
        c.append(isReversed());
        c.append('\n');
        c.append("[/CATSERRANGE]\n");
        return c.toString();
    }

    public CategorySeriesAxisRecord(RecordInputStream recordInputStream) {
        this.field_1_crossingPoint = recordInputStream.readShort();
        this.field_2_labelFrequency = recordInputStream.readShort();
        this.field_3_tickMarkFrequency = recordInputStream.readShort();
        this.field_4_options = recordInputStream.readShort();
    }

    @Override // org.apache.poi.hssf.record.Record, java.lang.Object
    public CategorySeriesAxisRecord clone() {
        CategorySeriesAxisRecord categorySeriesAxisRecord = new CategorySeriesAxisRecord();
        categorySeriesAxisRecord.field_1_crossingPoint = this.field_1_crossingPoint;
        categorySeriesAxisRecord.field_2_labelFrequency = this.field_2_labelFrequency;
        categorySeriesAxisRecord.field_3_tickMarkFrequency = this.field_3_tickMarkFrequency;
        categorySeriesAxisRecord.field_4_options = this.field_4_options;
        return categorySeriesAxisRecord;
    }
}
