package org.apache.poi.hssf.record.chart;

import b.b.a.a.a;
import org.apache.poi.hssf.record.RecordInputStream;
import org.apache.poi.hssf.record.StandardRecord;
import org.apache.poi.util.HexDump;
import org.apache.poi.util.LittleEndianInput;
import org.apache.poi.util.LittleEndianOutput;

public final class ChartFRTInfoRecord extends StandardRecord {
    public static final short sid = 2128;
    public short grbitFrt;
    public CFRTID[] rgCFRTID;
    public short rt;
    public byte verOriginator;
    public byte verWriter;

    public static final class CFRTID {
        public static final int ENCODED_SIZE = 4;
        public int rtFirst;
        public int rtLast;

        public CFRTID(LittleEndianInput littleEndianInput) {
            this.rtFirst = littleEndianInput.readShort();
            this.rtLast = littleEndianInput.readShort();
        }

        public void serialize(LittleEndianOutput littleEndianOutput) {
            littleEndianOutput.writeShort(this.rtFirst);
            littleEndianOutput.writeShort(this.rtLast);
        }
    }

    public ChartFRTInfoRecord(RecordInputStream recordInputStream) {
        this.rt = recordInputStream.readShort();
        this.grbitFrt = recordInputStream.readShort();
        this.verOriginator = recordInputStream.readByte();
        this.verWriter = recordInputStream.readByte();
        int readShort = recordInputStream.readShort();
        this.rgCFRTID = new CFRTID[readShort];
        for (int i2 = 0; i2 < readShort; i2++) {
            this.rgCFRTID[i2] = new CFRTID(recordInputStream);
        }
    }

    @Override // org.apache.poi.hssf.record.StandardRecord
    public int getDataSize() {
        return (this.rgCFRTID.length * 4) + 8;
    }

    @Override // org.apache.poi.hssf.record.Record
    public short getSid() {
        return sid;
    }

    @Override // org.apache.poi.hssf.record.StandardRecord
    public void serialize(LittleEndianOutput littleEndianOutput) {
        littleEndianOutput.writeShort(this.rt);
        littleEndianOutput.writeShort(this.grbitFrt);
        littleEndianOutput.writeByte(this.verOriginator);
        littleEndianOutput.writeByte(this.verWriter);
        int length = this.rgCFRTID.length;
        littleEndianOutput.writeShort(length);
        for (int i2 = 0; i2 < length; i2++) {
            this.rgCFRTID[i2].serialize(littleEndianOutput);
        }
    }

    @Override // org.apache.poi.hssf.record.Record
    public String toString() {
        StringBuffer c = a.c("[CHARTFRTINFO]\n", "    .rt           =");
        a.a((int) this.rt, c, '\n', "    .grbitFrt     =");
        a.a((int) this.grbitFrt, c, '\n', "    .verOriginator=");
        c.append(HexDump.byteToHex(this.verOriginator));
        c.append('\n');
        c.append("    .verWriter    =");
        c.append(HexDump.byteToHex(this.verOriginator));
        c.append('\n');
        c.append("    .nCFRTIDs     =");
        c.append(HexDump.shortToHex(this.rgCFRTID.length));
        c.append('\n');
        c.append("[/CHARTFRTINFO]\n");
        return c.toString();
    }
}
