package org.apache.poi.hssf.record.chart;

import b.b.a.a.a;
import org.apache.poi.hssf.record.RecordInputStream;
import org.apache.poi.hssf.record.StandardRecord;
import org.apache.poi.util.BitField;
import org.apache.poi.util.BitFieldFactory;
import org.apache.poi.util.HexDump;
import org.apache.poi.util.LittleEndianOutput;

public final class ChartFormatRecord extends StandardRecord {
    public static final short sid = 4116;
    public static final BitField varyDisplayPattern = BitFieldFactory.getInstance(1);
    public int field1_x_position;
    public int field2_y_position;
    public int field3_width;
    public int field4_height;
    public int field5_grbit;
    public int field6_unknown;

    public ChartFormatRecord() {
    }

    @Override // org.apache.poi.hssf.record.StandardRecord
    public int getDataSize() {
        return 20;
    }

    public int getHeight() {
        return this.field4_height;
    }

    @Override // org.apache.poi.hssf.record.Record
    public short getSid() {
        return sid;
    }

    public boolean getVaryDisplayPattern() {
        return varyDisplayPattern.isSet(this.field5_grbit);
    }

    public int getWidth() {
        return this.field3_width;
    }

    public int getXPosition() {
        return this.field1_x_position;
    }

    public int getYPosition() {
        return this.field2_y_position;
    }

    @Override // org.apache.poi.hssf.record.StandardRecord
    public void serialize(LittleEndianOutput littleEndianOutput) {
        littleEndianOutput.writeInt(getXPosition());
        littleEndianOutput.writeInt(getYPosition());
        littleEndianOutput.writeInt(getWidth());
        littleEndianOutput.writeInt(getHeight());
        littleEndianOutput.writeShort(this.field5_grbit);
        littleEndianOutput.writeShort(this.field6_unknown);
    }

    public void setHeight(int i2) {
        this.field4_height = i2;
    }

    public void setVaryDisplayPattern(boolean z) {
        this.field5_grbit = varyDisplayPattern.setBoolean(this.field5_grbit, z);
    }

    public void setWidth(int i2) {
        this.field3_width = i2;
    }

    public void setXPosition(int i2) {
        this.field1_x_position = i2;
    }

    public void setYPosition(int i2) {
        this.field2_y_position = i2;
    }

    @Override // org.apache.poi.hssf.record.Record
    public String toString() {
        StringBuffer c = a.c("[CHARTFORMAT]\n", "    .xPosition       = ");
        c.append(getXPosition());
        c.append("\n");
        c.append("    .yPosition       = ");
        c.append(getYPosition());
        c.append("\n");
        c.append("    .width           = ");
        c.append(getWidth());
        c.append("\n");
        c.append("    .height          = ");
        c.append(getHeight());
        c.append("\n");
        c.append("    .grBit           = ");
        c.append(HexDump.intToHex(this.field5_grbit));
        c.append("\n");
        c.append("[/CHARTFORMAT]\n");
        return c.toString();
    }

    public ChartFormatRecord(RecordInputStream recordInputStream) {
        this.field1_x_position = recordInputStream.readInt();
        this.field2_y_position = recordInputStream.readInt();
        this.field3_width = recordInputStream.readInt();
        this.field4_height = recordInputStream.readInt();
        this.field5_grbit = recordInputStream.readUShort();
        this.field6_unknown = recordInputStream.readUShort();
    }
}
