package org.apache.poi.hssf.record.chart;

import b.b.a.a.a;
import org.apache.poi.hssf.record.RecordInputStream;
import org.apache.poi.hssf.record.StandardRecord;
import org.apache.poi.util.LittleEndianOutput;

public final class ChartRecord extends StandardRecord implements Cloneable {
    public static final short sid = 4098;
    public int field_1_x;
    public int field_2_y;
    public int field_3_width;
    public int field_4_height;

    public ChartRecord() {
    }

    @Override // org.apache.poi.hssf.record.StandardRecord
    public int getDataSize() {
        return 16;
    }

    public int getHeight() {
        return this.field_4_height;
    }

    @Override // org.apache.poi.hssf.record.Record
    public short getSid() {
        return sid;
    }

    public int getWidth() {
        return this.field_3_width;
    }

    public int getX() {
        return this.field_1_x;
    }

    public int getY() {
        return this.field_2_y;
    }

    @Override // org.apache.poi.hssf.record.StandardRecord
    public void serialize(LittleEndianOutput littleEndianOutput) {
        littleEndianOutput.writeInt(this.field_1_x);
        littleEndianOutput.writeInt(this.field_2_y);
        littleEndianOutput.writeInt(this.field_3_width);
        littleEndianOutput.writeInt(this.field_4_height);
    }

    public void setHeight(int i2) {
        this.field_4_height = i2;
    }

    public void setWidth(int i2) {
        this.field_3_width = i2;
    }

    public void setX(int i2) {
        this.field_1_x = i2;
    }

    public void setY(int i2) {
        this.field_2_y = i2;
    }

    @Override // org.apache.poi.hssf.record.Record
    public String toString() {
        StringBuffer c = a.c("[CHART]\n", "    .x     = ");
        c.append(getX());
        c.append('\n');
        c.append("    .y     = ");
        c.append(getY());
        c.append('\n');
        c.append("    .width = ");
        c.append(getWidth());
        c.append('\n');
        c.append("    .height= ");
        c.append(getHeight());
        c.append('\n');
        c.append("[/CHART]\n");
        return c.toString();
    }

    public ChartRecord(RecordInputStream recordInputStream) {
        this.field_1_x = recordInputStream.readInt();
        this.field_2_y = recordInputStream.readInt();
        this.field_3_width = recordInputStream.readInt();
        this.field_4_height = recordInputStream.readInt();
    }

    @Override // org.apache.poi.hssf.record.Record, java.lang.Object
    public ChartRecord clone() {
        ChartRecord chartRecord = new ChartRecord();
        chartRecord.field_1_x = this.field_1_x;
        chartRecord.field_2_y = this.field_2_y;
        chartRecord.field_3_width = this.field_3_width;
        chartRecord.field_4_height = this.field_4_height;
        return chartRecord;
    }
}
