package org.apache.poi.hssf.record.chart;

import b.b.a.a.a;
import org.apache.poi.hssf.record.RecordInputStream;
import org.apache.poi.hssf.record.StandardRecord;
import org.apache.poi.util.BitField;
import org.apache.poi.util.BitFieldFactory;
import org.apache.poi.util.HexDump;
import org.apache.poi.util.LittleEndianOutput;

public final class DatRecord extends StandardRecord implements Cloneable {
    public static final BitField border = BitFieldFactory.getInstance(4);
    public static final BitField horizontalBorder = BitFieldFactory.getInstance(1);
    public static final BitField showSeriesKey = BitFieldFactory.getInstance(8);
    public static final short sid = 4195;
    public static final BitField verticalBorder = BitFieldFactory.getInstance(2);
    public short field_1_options;

    public DatRecord() {
    }

    @Override // org.apache.poi.hssf.record.StandardRecord
    public int getDataSize() {
        return 2;
    }

    public short getOptions() {
        return this.field_1_options;
    }

    @Override // org.apache.poi.hssf.record.Record
    public short getSid() {
        return sid;
    }

    public boolean isBorder() {
        return border.isSet(this.field_1_options);
    }

    public boolean isHorizontalBorder() {
        return horizontalBorder.isSet(this.field_1_options);
    }

    public boolean isShowSeriesKey() {
        return showSeriesKey.isSet(this.field_1_options);
    }

    public boolean isVerticalBorder() {
        return verticalBorder.isSet(this.field_1_options);
    }

    @Override // org.apache.poi.hssf.record.StandardRecord
    public void serialize(LittleEndianOutput littleEndianOutput) {
        littleEndianOutput.writeShort(this.field_1_options);
    }

    public void setBorder(boolean z) {
        this.field_1_options = border.setShortBoolean(this.field_1_options, z);
    }

    public void setHorizontalBorder(boolean z) {
        this.field_1_options = horizontalBorder.setShortBoolean(this.field_1_options, z);
    }

    public void setOptions(short s) {
        this.field_1_options = s;
    }

    public void setShowSeriesKey(boolean z) {
        this.field_1_options = showSeriesKey.setShortBoolean(this.field_1_options, z);
    }

    public void setVerticalBorder(boolean z) {
        this.field_1_options = verticalBorder.setShortBoolean(this.field_1_options, z);
    }

    @Override // org.apache.poi.hssf.record.Record
    public String toString() {
        StringBuffer c = a.c("[DAT]\n", "    .options              = ", "0x");
        c.append(HexDump.toHex(getOptions()));
        c.append(" (");
        c.append((int) getOptions());
        c.append(" )");
        c.append(System.getProperty("line.separator"));
        c.append("         .horizontalBorder         = ");
        c.append(isHorizontalBorder());
        c.append('\n');
        c.append("         .verticalBorder           = ");
        c.append(isVerticalBorder());
        c.append('\n');
        c.append("         .border                   = ");
        c.append(isBorder());
        c.append('\n');
        c.append("         .showSeriesKey            = ");
        c.append(isShowSeriesKey());
        c.append('\n');
        c.append("[/DAT]\n");
        return c.toString();
    }

    public DatRecord(RecordInputStream recordInputStream) {
        this.field_1_options = recordInputStream.readShort();
    }

    @Override // org.apache.poi.hssf.record.Record, java.lang.Object
    public DatRecord clone() {
        DatRecord datRecord = new DatRecord();
        datRecord.field_1_options = this.field_1_options;
        return datRecord;
    }
}
