package org.apache.poi.hssf.record.chart;

import b.b.a.a.a;
import org.apache.poi.hssf.record.RecordInputStream;
import org.apache.poi.hssf.record.StandardRecord;
import org.apache.poi.util.BitField;
import org.apache.poi.util.BitFieldFactory;
import org.apache.poi.util.HexDump;
import org.apache.poi.util.LittleEndianOutput;

public final class DataFormatRecord extends StandardRecord implements Cloneable {
    public static final short sid = 4102;
    public static final BitField useExcel4Colors = BitFieldFactory.getInstance(1);
    public short field_1_pointNumber;
    public short field_2_seriesIndex;
    public short field_3_seriesNumber;
    public short field_4_formatFlags;

    public DataFormatRecord() {
    }

    @Override // org.apache.poi.hssf.record.StandardRecord
    public int getDataSize() {
        return 8;
    }

    public short getFormatFlags() {
        return this.field_4_formatFlags;
    }

    public short getPointNumber() {
        return this.field_1_pointNumber;
    }

    public short getSeriesIndex() {
        return this.field_2_seriesIndex;
    }

    public short getSeriesNumber() {
        return this.field_3_seriesNumber;
    }

    @Override // org.apache.poi.hssf.record.Record
    public short getSid() {
        return sid;
    }

    public boolean isUseExcel4Colors() {
        return useExcel4Colors.isSet(this.field_4_formatFlags);
    }

    @Override // org.apache.poi.hssf.record.StandardRecord
    public void serialize(LittleEndianOutput littleEndianOutput) {
        littleEndianOutput.writeShort(this.field_1_pointNumber);
        littleEndianOutput.writeShort(this.field_2_seriesIndex);
        littleEndianOutput.writeShort(this.field_3_seriesNumber);
        littleEndianOutput.writeShort(this.field_4_formatFlags);
    }

    public void setFormatFlags(short s) {
        this.field_4_formatFlags = s;
    }

    public void setPointNumber(short s) {
        this.field_1_pointNumber = s;
    }

    public void setSeriesIndex(short s) {
        this.field_2_seriesIndex = s;
    }

    public void setSeriesNumber(short s) {
        this.field_3_seriesNumber = s;
    }

    public void setUseExcel4Colors(boolean z) {
        this.field_4_formatFlags = useExcel4Colors.setShortBoolean(this.field_4_formatFlags, z);
    }

    @Override // org.apache.poi.hssf.record.Record
    public String toString() {
        StringBuffer c = a.c("[DATAFORMAT]\n", "    .pointNumber          = ", "0x");
        c.append(HexDump.toHex(getPointNumber()));
        c.append(" (");
        c.append((int) getPointNumber());
        c.append(" )");
        c.append(System.getProperty("line.separator"));
        c.append("    .seriesIndex          = ");
        c.append("0x");
        c.append(HexDump.toHex(getSeriesIndex()));
        c.append(" (");
        c.append((int) getSeriesIndex());
        c.append(" )");
        c.append(System.getProperty("line.separator"));
        c.append("    .seriesNumber         = ");
        c.append("0x");
        c.append(HexDump.toHex(getSeriesNumber()));
        c.append(" (");
        c.append((int) getSeriesNumber());
        c.append(" )");
        c.append(System.getProperty("line.separator"));
        c.append("    .formatFlags          = ");
        c.append("0x");
        c.append(HexDump.toHex(getFormatFlags()));
        c.append(" (");
        c.append((int) getFormatFlags());
        c.append(" )");
        c.append(System.getProperty("line.separator"));
        c.append("         .useExcel4Colors          = ");
        c.append(isUseExcel4Colors());
        c.append('\n');
        c.append("[/DATAFORMAT]\n");
        return c.toString();
    }

    public DataFormatRecord(RecordInputStream recordInputStream) {
        this.field_1_pointNumber = recordInputStream.readShort();
        this.field_2_seriesIndex = recordInputStream.readShort();
        this.field_3_seriesNumber = recordInputStream.readShort();
        this.field_4_formatFlags = recordInputStream.readShort();
    }

    @Override // org.apache.poi.hssf.record.Record, java.lang.Object
    public DataFormatRecord clone() {
        DataFormatRecord dataFormatRecord = new DataFormatRecord();
        dataFormatRecord.field_1_pointNumber = this.field_1_pointNumber;
        dataFormatRecord.field_2_seriesIndex = this.field_2_seriesIndex;
        dataFormatRecord.field_3_seriesNumber = this.field_3_seriesNumber;
        dataFormatRecord.field_4_formatFlags = this.field_4_formatFlags;
        return dataFormatRecord;
    }
}
