package org.apache.poi.hssf.record.chart;

import b.b.a.a.a;
import org.apache.poi.hssf.record.RecordInputStream;
import org.apache.poi.hssf.record.StandardRecord;
import org.apache.poi.util.HexDump;
import org.apache.poi.util.LittleEndianOutput;

public final class FontBasisRecord extends StandardRecord implements Cloneable {
    public static final short sid = 4192;
    public short field_1_xBasis;
    public short field_2_yBasis;
    public short field_3_heightBasis;
    public short field_4_scale;
    public short field_5_indexToFontTable;

    public FontBasisRecord() {
    }

    @Override // org.apache.poi.hssf.record.StandardRecord
    public int getDataSize() {
        return 10;
    }

    public short getHeightBasis() {
        return this.field_3_heightBasis;
    }

    public short getIndexToFontTable() {
        return this.field_5_indexToFontTable;
    }

    public short getScale() {
        return this.field_4_scale;
    }

    @Override // org.apache.poi.hssf.record.Record
    public short getSid() {
        return sid;
    }

    public short getXBasis() {
        return this.field_1_xBasis;
    }

    public short getYBasis() {
        return this.field_2_yBasis;
    }

    @Override // org.apache.poi.hssf.record.StandardRecord
    public void serialize(LittleEndianOutput littleEndianOutput) {
        littleEndianOutput.writeShort(this.field_1_xBasis);
        littleEndianOutput.writeShort(this.field_2_yBasis);
        littleEndianOutput.writeShort(this.field_3_heightBasis);
        littleEndianOutput.writeShort(this.field_4_scale);
        littleEndianOutput.writeShort(this.field_5_indexToFontTable);
    }

    public void setHeightBasis(short s) {
        this.field_3_heightBasis = s;
    }

    public void setIndexToFontTable(short s) {
        this.field_5_indexToFontTable = s;
    }

    public void setScale(short s) {
        this.field_4_scale = s;
    }

    public void setXBasis(short s) {
        this.field_1_xBasis = s;
    }

    public void setYBasis(short s) {
        this.field_2_yBasis = s;
    }

    @Override // org.apache.poi.hssf.record.Record
    public String toString() {
        StringBuffer c = a.c("[FBI]\n", "    .xBasis               = ", "0x");
        c.append(HexDump.toHex(getXBasis()));
        c.append(" (");
        c.append((int) getXBasis());
        c.append(" )");
        c.append(System.getProperty("line.separator"));
        c.append("    .yBasis               = ");
        c.append("0x");
        c.append(HexDump.toHex(getYBasis()));
        c.append(" (");
        c.append((int) getYBasis());
        c.append(" )");
        c.append(System.getProperty("line.separator"));
        c.append("    .heightBasis          = ");
        c.append("0x");
        c.append(HexDump.toHex(getHeightBasis()));
        c.append(" (");
        c.append((int) getHeightBasis());
        c.append(" )");
        c.append(System.getProperty("line.separator"));
        c.append("    .scale                = ");
        c.append("0x");
        c.append(HexDump.toHex(getScale()));
        c.append(" (");
        c.append((int) getScale());
        c.append(" )");
        c.append(System.getProperty("line.separator"));
        c.append("    .indexToFontTable     = ");
        c.append("0x");
        c.append(HexDump.toHex(getIndexToFontTable()));
        c.append(" (");
        c.append((int) getIndexToFontTable());
        c.append(" )");
        c.append(System.getProperty("line.separator"));
        c.append("[/FBI]\n");
        return c.toString();
    }

    public FontBasisRecord(RecordInputStream recordInputStream) {
        this.field_1_xBasis = recordInputStream.readShort();
        this.field_2_yBasis = recordInputStream.readShort();
        this.field_3_heightBasis = recordInputStream.readShort();
        this.field_4_scale = recordInputStream.readShort();
        this.field_5_indexToFontTable = recordInputStream.readShort();
    }

    @Override // org.apache.poi.hssf.record.Record, java.lang.Object
    public FontBasisRecord clone() {
        FontBasisRecord fontBasisRecord = new FontBasisRecord();
        fontBasisRecord.field_1_xBasis = this.field_1_xBasis;
        fontBasisRecord.field_2_yBasis = this.field_2_yBasis;
        fontBasisRecord.field_3_heightBasis = this.field_3_heightBasis;
        fontBasisRecord.field_4_scale = this.field_4_scale;
        fontBasisRecord.field_5_indexToFontTable = this.field_5_indexToFontTable;
        return fontBasisRecord;
    }
}
