package org.apache.poi.hssf.record.chart;

import b.b.a.a.a;
import org.apache.poi.hssf.record.RecordInputStream;
import org.apache.poi.hssf.record.StandardRecord;
import org.apache.poi.util.BitField;
import org.apache.poi.util.BitFieldFactory;
import org.apache.poi.util.HexDump;
import org.apache.poi.util.LittleEndianOutput;

public final class LegendRecord extends StandardRecord implements Cloneable {
    public static final byte SPACING_CLOSE = 0;
    public static final byte SPACING_MEDIUM = 1;
    public static final byte SPACING_OPEN = 2;
    public static final byte TYPE_BOTTOM = 0;
    public static final byte TYPE_CORNER = 1;
    public static final byte TYPE_LEFT = 4;
    public static final byte TYPE_RIGHT = 3;
    public static final byte TYPE_TOP = 2;
    public static final byte TYPE_UNDOCKED = 7;
    public static final BitField autoPosition = BitFieldFactory.getInstance(1);
    public static final BitField autoSeries = BitFieldFactory.getInstance(2);
    public static final BitField autoXPositioning = BitFieldFactory.getInstance(4);
    public static final BitField autoYPositioning = BitFieldFactory.getInstance(8);
    public static final BitField dataTable = BitFieldFactory.getInstance(32);
    public static final short sid = 4117;
    public static final BitField vertical = BitFieldFactory.getInstance(16);
    public int field_1_xAxisUpperLeft;
    public int field_2_yAxisUpperLeft;
    public int field_3_xSize;
    public int field_4_ySize;
    public byte field_5_type;
    public byte field_6_spacing;
    public short field_7_options;

    public LegendRecord() {
    }

    @Override // org.apache.poi.hssf.record.StandardRecord
    public int getDataSize() {
        return 20;
    }

    public short getOptions() {
        return this.field_7_options;
    }

    @Override // org.apache.poi.hssf.record.Record
    public short getSid() {
        return sid;
    }

    public byte getSpacing() {
        return this.field_6_spacing;
    }

    public byte getType() {
        return this.field_5_type;
    }

    public int getXAxisUpperLeft() {
        return this.field_1_xAxisUpperLeft;
    }

    public int getXSize() {
        return this.field_3_xSize;
    }

    public int getYAxisUpperLeft() {
        return this.field_2_yAxisUpperLeft;
    }

    public int getYSize() {
        return this.field_4_ySize;
    }

    public boolean isAutoPosition() {
        return autoPosition.isSet(this.field_7_options);
    }

    public boolean isAutoSeries() {
        return autoSeries.isSet(this.field_7_options);
    }

    public boolean isAutoXPositioning() {
        return autoXPositioning.isSet(this.field_7_options);
    }

    public boolean isAutoYPositioning() {
        return autoYPositioning.isSet(this.field_7_options);
    }

    public boolean isDataTable() {
        return dataTable.isSet(this.field_7_options);
    }

    public boolean isVertical() {
        return vertical.isSet(this.field_7_options);
    }

    @Override // org.apache.poi.hssf.record.StandardRecord
    public void serialize(LittleEndianOutput littleEndianOutput) {
        littleEndianOutput.writeInt(this.field_1_xAxisUpperLeft);
        littleEndianOutput.writeInt(this.field_2_yAxisUpperLeft);
        littleEndianOutput.writeInt(this.field_3_xSize);
        littleEndianOutput.writeInt(this.field_4_ySize);
        littleEndianOutput.writeByte(this.field_5_type);
        littleEndianOutput.writeByte(this.field_6_spacing);
        littleEndianOutput.writeShort(this.field_7_options);
    }

    public void setAutoPosition(boolean z) {
        this.field_7_options = autoPosition.setShortBoolean(this.field_7_options, z);
    }

    public void setAutoSeries(boolean z) {
        this.field_7_options = autoSeries.setShortBoolean(this.field_7_options, z);
    }

    public void setAutoXPositioning(boolean z) {
        this.field_7_options = autoXPositioning.setShortBoolean(this.field_7_options, z);
    }

    public void setAutoYPositioning(boolean z) {
        this.field_7_options = autoYPositioning.setShortBoolean(this.field_7_options, z);
    }

    public void setDataTable(boolean z) {
        this.field_7_options = dataTable.setShortBoolean(this.field_7_options, z);
    }

    public void setOptions(short s) {
        this.field_7_options = s;
    }

    public void setSpacing(byte b2) {
        this.field_6_spacing = b2;
    }

    public void setType(byte b2) {
        this.field_5_type = b2;
    }

    public void setVertical(boolean z) {
        this.field_7_options = vertical.setShortBoolean(this.field_7_options, z);
    }

    public void setXAxisUpperLeft(int i2) {
        this.field_1_xAxisUpperLeft = i2;
    }

    public void setXSize(int i2) {
        this.field_3_xSize = i2;
    }

    public void setYAxisUpperLeft(int i2) {
        this.field_2_yAxisUpperLeft = i2;
    }

    public void setYSize(int i2) {
        this.field_4_ySize = i2;
    }

    @Override // org.apache.poi.hssf.record.Record
    public String toString() {
        StringBuffer c = a.c("[LEGEND]\n", "    .xAxisUpperLeft       = ", "0x");
        c.append(HexDump.toHex(getXAxisUpperLeft()));
        c.append(" (");
        c.append(getXAxisUpperLeft());
        c.append(" )");
        c.append(System.getProperty("line.separator"));
        c.append("    .yAxisUpperLeft       = ");
        c.append("0x");
        c.append(HexDump.toHex(getYAxisUpperLeft()));
        c.append(" (");
        c.append(getYAxisUpperLeft());
        c.append(" )");
        c.append(System.getProperty("line.separator"));
        c.append("    .xSize                = ");
        c.append("0x");
        c.append(HexDump.toHex(getXSize()));
        c.append(" (");
        c.append(getXSize());
        c.append(" )");
        c.append(System.getProperty("line.separator"));
        c.append("    .ySize                = ");
        c.append("0x");
        c.append(HexDump.toHex(getYSize()));
        c.append(" (");
        c.append(getYSize());
        c.append(" )");
        c.append(System.getProperty("line.separator"));
        c.append("    .type                 = ");
        c.append("0x");
        c.append(HexDump.toHex(getType()));
        c.append(" (");
        c.append((int) getType());
        c.append(" )");
        c.append(System.getProperty("line.separator"));
        c.append("    .spacing              = ");
        c.append("0x");
        c.append(HexDump.toHex(getSpacing()));
        c.append(" (");
        c.append((int) getSpacing());
        c.append(" )");
        c.append(System.getProperty("line.separator"));
        c.append("    .options              = ");
        c.append("0x");
        c.append(HexDump.toHex(getOptions()));
        c.append(" (");
        c.append((int) getOptions());
        c.append(" )");
        c.append(System.getProperty("line.separator"));
        c.append("         .autoPosition             = ");
        c.append(isAutoPosition());
        c.append('\n');
        c.append("         .autoSeries               = ");
        c.append(isAutoSeries());
        c.append('\n');
        c.append("         .autoXPositioning         = ");
        c.append(isAutoXPositioning());
        c.append('\n');
        c.append("         .autoYPositioning         = ");
        c.append(isAutoYPositioning());
        c.append('\n');
        c.append("         .vertical                 = ");
        c.append(isVertical());
        c.append('\n');
        c.append("         .dataTable                = ");
        c.append(isDataTable());
        c.append('\n');
        c.append("[/LEGEND]\n");
        return c.toString();
    }

    public LegendRecord(RecordInputStream recordInputStream) {
        this.field_1_xAxisUpperLeft = recordInputStream.readInt();
        this.field_2_yAxisUpperLeft = recordInputStream.readInt();
        this.field_3_xSize = recordInputStream.readInt();
        this.field_4_ySize = recordInputStream.readInt();
        this.field_5_type = recordInputStream.readByte();
        this.field_6_spacing = recordInputStream.readByte();
        this.field_7_options = recordInputStream.readShort();
    }

    @Override // org.apache.poi.hssf.record.Record, java.lang.Object
    public LegendRecord clone() {
        LegendRecord legendRecord = new LegendRecord();
        legendRecord.field_1_xAxisUpperLeft = this.field_1_xAxisUpperLeft;
        legendRecord.field_2_yAxisUpperLeft = this.field_2_yAxisUpperLeft;
        legendRecord.field_3_xSize = this.field_3_xSize;
        legendRecord.field_4_ySize = this.field_4_ySize;
        legendRecord.field_5_type = this.field_5_type;
        legendRecord.field_6_spacing = this.field_6_spacing;
        legendRecord.field_7_options = this.field_7_options;
        return legendRecord;
    }
}
