package org.apache.poi.hssf.record.chart;

import b.b.a.a.a;
import org.apache.poi.hssf.record.RecordInputStream;
import org.apache.poi.hssf.record.StandardRecord;
import org.apache.poi.util.BitField;
import org.apache.poi.util.BitFieldFactory;
import org.apache.poi.util.HexDump;
import org.apache.poi.util.LittleEndianOutput;

public final class LineFormatRecord extends StandardRecord implements Cloneable {
    public static final short LINE_PATTERN_DARK_GRAY_PATTERN = 6;
    public static final short LINE_PATTERN_DASH = 1;
    public static final short LINE_PATTERN_DASH_DOT = 3;
    public static final short LINE_PATTERN_DASH_DOT_DOT = 4;
    public static final short LINE_PATTERN_DOT = 2;
    public static final short LINE_PATTERN_LIGHT_GRAY_PATTERN = 8;
    public static final short LINE_PATTERN_MEDIUM_GRAY_PATTERN = 7;
    public static final short LINE_PATTERN_NONE = 5;
    public static final short LINE_PATTERN_SOLID = 0;
    public static final short WEIGHT_HAIRLINE = -1;
    public static final short WEIGHT_MEDIUM = 1;
    public static final short WEIGHT_NARROW = 0;
    public static final short WEIGHT_WIDE = 2;
    public static final BitField auto = BitFieldFactory.getInstance(1);
    public static final BitField drawTicks = BitFieldFactory.getInstance(4);
    public static final short sid = 4103;
    public static final BitField unknown = BitFieldFactory.getInstance(4);
    public int field_1_lineColor;
    public short field_2_linePattern;
    public short field_3_weight;
    public short field_4_format;
    public short field_5_colourPaletteIndex;

    public LineFormatRecord() {
    }

    public short getColourPaletteIndex() {
        return this.field_5_colourPaletteIndex;
    }

    @Override // org.apache.poi.hssf.record.StandardRecord
    public int getDataSize() {
        return 12;
    }

    public short getFormat() {
        return this.field_4_format;
    }

    public int getLineColor() {
        return this.field_1_lineColor;
    }

    public short getLinePattern() {
        return this.field_2_linePattern;
    }

    @Override // org.apache.poi.hssf.record.Record
    public short getSid() {
        return sid;
    }

    public short getWeight() {
        return this.field_3_weight;
    }

    public boolean isAuto() {
        return auto.isSet(this.field_4_format);
    }

    public boolean isDrawTicks() {
        return drawTicks.isSet(this.field_4_format);
    }

    public boolean isUnknown() {
        return unknown.isSet(this.field_4_format);
    }

    @Override // org.apache.poi.hssf.record.StandardRecord
    public void serialize(LittleEndianOutput littleEndianOutput) {
        littleEndianOutput.writeInt(this.field_1_lineColor);
        littleEndianOutput.writeShort(this.field_2_linePattern);
        littleEndianOutput.writeShort(this.field_3_weight);
        littleEndianOutput.writeShort(this.field_4_format);
        littleEndianOutput.writeShort(this.field_5_colourPaletteIndex);
    }

    public void setAuto(boolean z) {
        this.field_4_format = auto.setShortBoolean(this.field_4_format, z);
    }

    public void setColourPaletteIndex(short s) {
        this.field_5_colourPaletteIndex = s;
    }

    public void setDrawTicks(boolean z) {
        this.field_4_format = drawTicks.setShortBoolean(this.field_4_format, z);
    }

    public void setFormat(short s) {
        this.field_4_format = s;
    }

    public void setLineColor(int i2) {
        this.field_1_lineColor = i2;
    }

    public void setLinePattern(short s) {
        this.field_2_linePattern = s;
    }

    public void setUnknown(boolean z) {
        this.field_4_format = unknown.setShortBoolean(this.field_4_format, z);
    }

    public void setWeight(short s) {
        this.field_3_weight = s;
    }

    @Override // org.apache.poi.hssf.record.Record
    public String toString() {
        StringBuffer c = a.c("[LINEFORMAT]\n", "    .lineColor            = ", "0x");
        c.append(HexDump.toHex(getLineColor()));
        c.append(" (");
        c.append(getLineColor());
        c.append(" )");
        c.append(System.getProperty("line.separator"));
        c.append("    .linePattern          = ");
        c.append("0x");
        c.append(HexDump.toHex(getLinePattern()));
        c.append(" (");
        c.append((int) getLinePattern());
        c.append(" )");
        c.append(System.getProperty("line.separator"));
        c.append("    .weight               = ");
        c.append("0x");
        c.append(HexDump.toHex(getWeight()));
        c.append(" (");
        c.append((int) getWeight());
        c.append(" )");
        c.append(System.getProperty("line.separator"));
        c.append("    .format               = ");
        c.append("0x");
        c.append(HexDump.toHex(getFormat()));
        c.append(" (");
        c.append((int) getFormat());
        c.append(" )");
        c.append(System.getProperty("line.separator"));
        c.append("         .auto                     = ");
        c.append(isAuto());
        c.append('\n');
        c.append("         .drawTicks                = ");
        c.append(isDrawTicks());
        c.append('\n');
        c.append("         .unknown                  = ");
        c.append(isUnknown());
        c.append('\n');
        c.append("    .colourPaletteIndex   = ");
        c.append("0x");
        c.append(HexDump.toHex(getColourPaletteIndex()));
        c.append(" (");
        c.append((int) getColourPaletteIndex());
        c.append(" )");
        c.append(System.getProperty("line.separator"));
        c.append("[/LINEFORMAT]\n");
        return c.toString();
    }

    public LineFormatRecord(RecordInputStream recordInputStream) {
        this.field_1_lineColor = recordInputStream.readInt();
        this.field_2_linePattern = recordInputStream.readShort();
        this.field_3_weight = recordInputStream.readShort();
        this.field_4_format = recordInputStream.readShort();
        this.field_5_colourPaletteIndex = recordInputStream.readShort();
    }

    @Override // org.apache.poi.hssf.record.Record, java.lang.Object
    public LineFormatRecord clone() {
        LineFormatRecord lineFormatRecord = new LineFormatRecord();
        lineFormatRecord.field_1_lineColor = this.field_1_lineColor;
        lineFormatRecord.field_2_linePattern = this.field_2_linePattern;
        lineFormatRecord.field_3_weight = this.field_3_weight;
        lineFormatRecord.field_4_format = this.field_4_format;
        lineFormatRecord.field_5_colourPaletteIndex = this.field_5_colourPaletteIndex;
        return lineFormatRecord;
    }
}
