package org.apache.poi.hssf.record.chart;

import b.b.a.a.a;
import org.apache.poi.hssf.record.RecordInputStream;
import org.apache.poi.hssf.record.StandardRecord;
import org.apache.poi.util.HexDump;
import org.apache.poi.util.LittleEndianOutput;

public final class ObjectLinkRecord extends StandardRecord implements Cloneable {
    public static final short ANCHOR_ID_CHART_TITLE = 1;
    public static final short ANCHOR_ID_SERIES_OR_POINT = 4;
    public static final short ANCHOR_ID_X_AXIS = 3;
    public static final short ANCHOR_ID_Y_AXIS = 2;
    public static final short ANCHOR_ID_Z_AXIS = 7;
    public static final short sid = 4135;
    public short field_1_anchorId;
    public short field_2_link1;
    public short field_3_link2;

    public ObjectLinkRecord() {
    }

    public short getAnchorId() {
        return this.field_1_anchorId;
    }

    @Override // org.apache.poi.hssf.record.StandardRecord
    public int getDataSize() {
        return 6;
    }

    public short getLink1() {
        return this.field_2_link1;
    }

    public short getLink2() {
        return this.field_3_link2;
    }

    @Override // org.apache.poi.hssf.record.Record
    public short getSid() {
        return sid;
    }

    @Override // org.apache.poi.hssf.record.StandardRecord
    public void serialize(LittleEndianOutput littleEndianOutput) {
        littleEndianOutput.writeShort(this.field_1_anchorId);
        littleEndianOutput.writeShort(this.field_2_link1);
        littleEndianOutput.writeShort(this.field_3_link2);
    }

    public void setAnchorId(short s) {
        this.field_1_anchorId = s;
    }

    public void setLink1(short s) {
        this.field_2_link1 = s;
    }

    public void setLink2(short s) {
        this.field_3_link2 = s;
    }

    @Override // org.apache.poi.hssf.record.Record
    public String toString() {
        StringBuffer c = a.c("[OBJECTLINK]\n", "    .anchorId             = ", "0x");
        c.append(HexDump.toHex(getAnchorId()));
        c.append(" (");
        c.append((int) getAnchorId());
        c.append(" )");
        c.append(System.getProperty("line.separator"));
        c.append("    .link1                = ");
        c.append("0x");
        c.append(HexDump.toHex(getLink1()));
        c.append(" (");
        c.append((int) getLink1());
        c.append(" )");
        c.append(System.getProperty("line.separator"));
        c.append("    .link2                = ");
        c.append("0x");
        c.append(HexDump.toHex(getLink2()));
        c.append(" (");
        c.append((int) getLink2());
        c.append(" )");
        c.append(System.getProperty("line.separator"));
        c.append("[/OBJECTLINK]\n");
        return c.toString();
    }

    public ObjectLinkRecord(RecordInputStream recordInputStream) {
        this.field_1_anchorId = recordInputStream.readShort();
        this.field_2_link1 = recordInputStream.readShort();
        this.field_3_link2 = recordInputStream.readShort();
    }

    @Override // org.apache.poi.hssf.record.Record, java.lang.Object
    public ObjectLinkRecord clone() {
        ObjectLinkRecord objectLinkRecord = new ObjectLinkRecord();
        objectLinkRecord.field_1_anchorId = this.field_1_anchorId;
        objectLinkRecord.field_2_link1 = this.field_2_link1;
        objectLinkRecord.field_3_link2 = this.field_3_link2;
        return objectLinkRecord;
    }
}
