package org.apache.poi.hssf.record.chart;

import b.b.a.a.a;
import org.apache.poi.hssf.record.RecordInputStream;
import org.apache.poi.hssf.record.StandardRecord;
import org.apache.poi.util.BitField;
import org.apache.poi.util.BitFieldFactory;
import org.apache.poi.util.HexDump;
import org.apache.poi.util.LittleEndianOutput;

public final class SeriesLabelsRecord extends StandardRecord {
    public static final BitField labelAsPercentage = BitFieldFactory.getInstance(4);
    public static final BitField showActual = BitFieldFactory.getInstance(1);
    public static final BitField showBubbleSizes = BitFieldFactory.getInstance(32);
    public static final BitField showLabel = BitFieldFactory.getInstance(16);
    public static final BitField showPercent = BitFieldFactory.getInstance(2);
    public static final short sid = 4108;
    public static final BitField smoothedLine = BitFieldFactory.getInstance(8);
    public short field_1_formatFlags;

    public SeriesLabelsRecord() {
    }

    @Override // org.apache.poi.hssf.record.Record
    public Object clone() {
        SeriesLabelsRecord seriesLabelsRecord = new SeriesLabelsRecord();
        seriesLabelsRecord.field_1_formatFlags = this.field_1_formatFlags;
        return seriesLabelsRecord;
    }

    @Override // org.apache.poi.hssf.record.StandardRecord
    public int getDataSize() {
        return 2;
    }

    public short getFormatFlags() {
        return this.field_1_formatFlags;
    }

    @Override // org.apache.poi.hssf.record.Record
    public short getSid() {
        return sid;
    }

    public boolean isLabelAsPercentage() {
        return labelAsPercentage.isSet(this.field_1_formatFlags);
    }

    public boolean isShowActual() {
        return showActual.isSet(this.field_1_formatFlags);
    }

    public boolean isShowBubbleSizes() {
        return showBubbleSizes.isSet(this.field_1_formatFlags);
    }

    public boolean isShowLabel() {
        return showLabel.isSet(this.field_1_formatFlags);
    }

    public boolean isShowPercent() {
        return showPercent.isSet(this.field_1_formatFlags);
    }

    public boolean isSmoothedLine() {
        return smoothedLine.isSet(this.field_1_formatFlags);
    }

    @Override // org.apache.poi.hssf.record.StandardRecord
    public void serialize(LittleEndianOutput littleEndianOutput) {
        littleEndianOutput.writeShort(this.field_1_formatFlags);
    }

    public void setFormatFlags(short s) {
        this.field_1_formatFlags = s;
    }

    public void setLabelAsPercentage(boolean z) {
        this.field_1_formatFlags = labelAsPercentage.setShortBoolean(this.field_1_formatFlags, z);
    }

    public void setShowActual(boolean z) {
        this.field_1_formatFlags = showActual.setShortBoolean(this.field_1_formatFlags, z);
    }

    public void setShowBubbleSizes(boolean z) {
        this.field_1_formatFlags = showBubbleSizes.setShortBoolean(this.field_1_formatFlags, z);
    }

    public void setShowLabel(boolean z) {
        this.field_1_formatFlags = showLabel.setShortBoolean(this.field_1_formatFlags, z);
    }

    public void setShowPercent(boolean z) {
        this.field_1_formatFlags = showPercent.setShortBoolean(this.field_1_formatFlags, z);
    }

    public void setSmoothedLine(boolean z) {
        this.field_1_formatFlags = smoothedLine.setShortBoolean(this.field_1_formatFlags, z);
    }

    @Override // org.apache.poi.hssf.record.Record
    public String toString() {
        StringBuffer c = a.c("[ATTACHEDLABEL]\n", "    .formatFlags          = ", "0x");
        c.append(HexDump.toHex(getFormatFlags()));
        c.append(" (");
        c.append((int) getFormatFlags());
        c.append(" )");
        c.append(System.getProperty("line.separator"));
        c.append("         .showActual               = ");
        c.append(isShowActual());
        c.append('\n');
        c.append("         .showPercent              = ");
        c.append(isShowPercent());
        c.append('\n');
        c.append("         .labelAsPercentage        = ");
        c.append(isLabelAsPercentage());
        c.append('\n');
        c.append("         .smoothedLine             = ");
        c.append(isSmoothedLine());
        c.append('\n');
        c.append("         .showLabel                = ");
        c.append(isShowLabel());
        c.append('\n');
        c.append("         .showBubbleSizes          = ");
        c.append(isShowBubbleSizes());
        c.append('\n');
        c.append("[/ATTACHEDLABEL]\n");
        return c.toString();
    }

    public SeriesLabelsRecord(RecordInputStream recordInputStream) {
        this.field_1_formatFlags = recordInputStream.readShort();
    }
}
