package org.apache.poi.hssf.record.chart;

import b.b.a.a.a;
import org.apache.poi.hssf.record.RecordInputStream;
import org.apache.poi.hssf.record.StandardRecord;
import org.apache.poi.util.HexDump;
import org.apache.poi.util.LittleEndianOutput;

public final class SeriesRecord extends StandardRecord {
    public static final short BUBBLE_SERIES_TYPE_DATES = 0;
    public static final short BUBBLE_SERIES_TYPE_NUMERIC = 1;
    public static final short BUBBLE_SERIES_TYPE_SEQUENCE = 2;
    public static final short BUBBLE_SERIES_TYPE_TEXT = 3;
    public static final short CATEGORY_DATA_TYPE_DATES = 0;
    public static final short CATEGORY_DATA_TYPE_NUMERIC = 1;
    public static final short CATEGORY_DATA_TYPE_SEQUENCE = 2;
    public static final short CATEGORY_DATA_TYPE_TEXT = 3;
    public static final short VALUES_DATA_TYPE_DATES = 0;
    public static final short VALUES_DATA_TYPE_NUMERIC = 1;
    public static final short VALUES_DATA_TYPE_SEQUENCE = 2;
    public static final short VALUES_DATA_TYPE_TEXT = 3;
    public static final short sid = 4099;
    public short field_1_categoryDataType;
    public short field_2_valuesDataType;
    public short field_3_numCategories;
    public short field_4_numValues;
    public short field_5_bubbleSeriesType;
    public short field_6_numBubbleValues;

    public SeriesRecord() {
    }

    @Override // org.apache.poi.hssf.record.Record
    public Object clone() {
        SeriesRecord seriesRecord = new SeriesRecord();
        seriesRecord.field_1_categoryDataType = this.field_1_categoryDataType;
        seriesRecord.field_2_valuesDataType = this.field_2_valuesDataType;
        seriesRecord.field_3_numCategories = this.field_3_numCategories;
        seriesRecord.field_4_numValues = this.field_4_numValues;
        seriesRecord.field_5_bubbleSeriesType = this.field_5_bubbleSeriesType;
        seriesRecord.field_6_numBubbleValues = this.field_6_numBubbleValues;
        return seriesRecord;
    }

    public short getBubbleSeriesType() {
        return this.field_5_bubbleSeriesType;
    }

    public short getCategoryDataType() {
        return this.field_1_categoryDataType;
    }

    @Override // org.apache.poi.hssf.record.StandardRecord
    public int getDataSize() {
        return 12;
    }

    public short getNumBubbleValues() {
        return this.field_6_numBubbleValues;
    }

    public short getNumCategories() {
        return this.field_3_numCategories;
    }

    public short getNumValues() {
        return this.field_4_numValues;
    }

    @Override // org.apache.poi.hssf.record.Record
    public short getSid() {
        return sid;
    }

    public short getValuesDataType() {
        return this.field_2_valuesDataType;
    }

    @Override // org.apache.poi.hssf.record.StandardRecord
    public void serialize(LittleEndianOutput littleEndianOutput) {
        littleEndianOutput.writeShort(this.field_1_categoryDataType);
        littleEndianOutput.writeShort(this.field_2_valuesDataType);
        littleEndianOutput.writeShort(this.field_3_numCategories);
        littleEndianOutput.writeShort(this.field_4_numValues);
        littleEndianOutput.writeShort(this.field_5_bubbleSeriesType);
        littleEndianOutput.writeShort(this.field_6_numBubbleValues);
    }

    public void setBubbleSeriesType(short s) {
        this.field_5_bubbleSeriesType = s;
    }

    public void setCategoryDataType(short s) {
        this.field_1_categoryDataType = s;
    }

    public void setNumBubbleValues(short s) {
        this.field_6_numBubbleValues = s;
    }

    public void setNumCategories(short s) {
        this.field_3_numCategories = s;
    }

    public void setNumValues(short s) {
        this.field_4_numValues = s;
    }

    public void setValuesDataType(short s) {
        this.field_2_valuesDataType = s;
    }

    @Override // org.apache.poi.hssf.record.Record
    public String toString() {
        StringBuffer c = a.c("[SERIES]\n", "    .categoryDataType     = ", "0x");
        c.append(HexDump.toHex(getCategoryDataType()));
        c.append(" (");
        c.append((int) getCategoryDataType());
        c.append(" )");
        c.append(System.getProperty("line.separator"));
        c.append("    .valuesDataType       = ");
        c.append("0x");
        c.append(HexDump.toHex(getValuesDataType()));
        c.append(" (");
        c.append((int) getValuesDataType());
        c.append(" )");
        c.append(System.getProperty("line.separator"));
        c.append("    .numCategories        = ");
        c.append("0x");
        c.append(HexDump.toHex(getNumCategories()));
        c.append(" (");
        c.append((int) getNumCategories());
        c.append(" )");
        c.append(System.getProperty("line.separator"));
        c.append("    .numValues            = ");
        c.append("0x");
        c.append(HexDump.toHex(getNumValues()));
        c.append(" (");
        c.append((int) getNumValues());
        c.append(" )");
        c.append(System.getProperty("line.separator"));
        c.append("    .bubbleSeriesType     = ");
        c.append("0x");
        c.append(HexDump.toHex(getBubbleSeriesType()));
        c.append(" (");
        c.append((int) getBubbleSeriesType());
        c.append(" )");
        c.append(System.getProperty("line.separator"));
        c.append("    .numBubbleValues      = ");
        c.append("0x");
        c.append(HexDump.toHex(getNumBubbleValues()));
        c.append(" (");
        c.append((int) getNumBubbleValues());
        c.append(" )");
        c.append(System.getProperty("line.separator"));
        c.append("[/SERIES]\n");
        return c.toString();
    }

    public SeriesRecord(RecordInputStream recordInputStream) {
        this.field_1_categoryDataType = recordInputStream.readShort();
        this.field_2_valuesDataType = recordInputStream.readShort();
        this.field_3_numCategories = recordInputStream.readShort();
        this.field_4_numValues = recordInputStream.readShort();
        this.field_5_bubbleSeriesType = recordInputStream.readShort();
        this.field_6_numBubbleValues = recordInputStream.readShort();
    }
}
