package org.apache.poi.hssf.record.chart;

import b.b.a.a.a;
import org.apache.poi.hssf.record.RecordInputStream;
import org.apache.poi.hssf.record.StandardRecord;
import org.apache.poi.ss.formula.ptg.GreaterThanPtg;
import org.apache.poi.util.HexDump;
import org.apache.poi.util.LittleEndianOutput;
import org.apache.poi.util.StringUtil;

public final class SeriesTextRecord extends StandardRecord {
    public static final int MAX_LEN = 255;
    public static final short sid = 4109;
    public int field_1_id;
    public String field_4_text;
    public boolean is16bit;

    public SeriesTextRecord() {
        this.field_4_text = "";
        this.is16bit = false;
    }

    @Override // org.apache.poi.hssf.record.Record
    public Object clone() {
        SeriesTextRecord seriesTextRecord = new SeriesTextRecord();
        seriesTextRecord.field_1_id = this.field_1_id;
        seriesTextRecord.is16bit = this.is16bit;
        seriesTextRecord.field_4_text = this.field_4_text;
        return seriesTextRecord;
    }

    @Override // org.apache.poi.hssf.record.StandardRecord
    public int getDataSize() {
        return (this.field_4_text.length() * (this.is16bit ? 2 : 1)) + 4;
    }

    public int getId() {
        return this.field_1_id;
    }

    @Override // org.apache.poi.hssf.record.Record
    public short getSid() {
        return sid;
    }

    public String getText() {
        return this.field_4_text;
    }

    @Override // org.apache.poi.hssf.record.StandardRecord
    public void serialize(LittleEndianOutput littleEndianOutput) {
        littleEndianOutput.writeShort(this.field_1_id);
        littleEndianOutput.writeByte(this.field_4_text.length());
        if (this.is16bit) {
            littleEndianOutput.writeByte(1);
            StringUtil.putUnicodeLE(this.field_4_text, littleEndianOutput);
            return;
        }
        littleEndianOutput.writeByte(0);
        StringUtil.putCompressedUnicode(this.field_4_text, littleEndianOutput);
    }

    public void setId(int i2) {
        this.field_1_id = i2;
    }

    public void setText(String str) {
        if (str.length() <= 255) {
            this.field_4_text = str;
            this.is16bit = StringUtil.hasMultibyte(str);
            return;
        }
        StringBuilder b2 = a.b("Text is too long (");
        b2.append(str.length());
        b2.append(GreaterThanPtg.GREATERTHAN);
        b2.append(255);
        b2.append(")");
        throw new IllegalArgumentException(b2.toString());
    }

    @Override // org.apache.poi.hssf.record.Record
    public String toString() {
        StringBuffer c = a.c("[SERIESTEXT]\n", "  .id     =");
        c.append(HexDump.shortToHex(getId()));
        c.append('\n');
        c.append("  .textLen=");
        c.append(this.field_4_text.length());
        c.append('\n');
        c.append("  .is16bit=");
        c.append(this.is16bit);
        c.append('\n');
        c.append("  .text   =");
        c.append(" (");
        c.append(getText());
        c.append(" )");
        c.append('\n');
        c.append("[/SERIESTEXT]\n");
        return c.toString();
    }

    public SeriesTextRecord(RecordInputStream recordInputStream) {
        this.field_1_id = recordInputStream.readUShort();
        int readUByte = recordInputStream.readUByte();
        boolean z = (recordInputStream.readUByte() & 1) == 0 ? false : true;
        this.is16bit = z;
        if (z) {
            this.field_4_text = recordInputStream.readUnicodeLEString(readUByte);
        } else {
            this.field_4_text = recordInputStream.readCompressedUnicode(readUByte);
        }
    }
}
