package org.apache.poi.hssf.record.chart;

import b.b.a.a.a;
import org.apache.poi.hssf.record.RecordInputStream;
import org.apache.poi.hssf.record.StandardRecord;
import org.apache.poi.util.BitField;
import org.apache.poi.util.BitFieldFactory;
import org.apache.poi.util.HexDump;
import org.apache.poi.util.LittleEndianOutput;

public final class SheetPropertiesRecord extends StandardRecord {
    public static final byte EMPTY_INTERPOLATED = 2;
    public static final byte EMPTY_NOT_PLOTTED = 0;
    public static final byte EMPTY_ZERO = 1;
    public static final BitField autoPlotArea = BitFieldFactory.getInstance(16);
    public static final BitField chartTypeManuallyFormatted = BitFieldFactory.getInstance(1);
    public static final BitField defaultPlotDimensions = BitFieldFactory.getInstance(8);
    public static final BitField doNotSizeWithWindow = BitFieldFactory.getInstance(4);
    public static final BitField plotVisibleOnly = BitFieldFactory.getInstance(2);
    public static final short sid = 4164;
    public int field_1_flags;
    public int field_2_empty;

    public SheetPropertiesRecord() {
    }

    @Override // org.apache.poi.hssf.record.Record
    public Object clone() {
        SheetPropertiesRecord sheetPropertiesRecord = new SheetPropertiesRecord();
        sheetPropertiesRecord.field_1_flags = this.field_1_flags;
        sheetPropertiesRecord.field_2_empty = this.field_2_empty;
        return sheetPropertiesRecord;
    }

    @Override // org.apache.poi.hssf.record.StandardRecord
    public int getDataSize() {
        return 4;
    }

    public int getEmpty() {
        return this.field_2_empty;
    }

    public int getFlags() {
        return this.field_1_flags;
    }

    @Override // org.apache.poi.hssf.record.Record
    public short getSid() {
        return sid;
    }

    public boolean isAutoPlotArea() {
        return autoPlotArea.isSet(this.field_1_flags);
    }

    public boolean isChartTypeManuallyFormatted() {
        return chartTypeManuallyFormatted.isSet(this.field_1_flags);
    }

    public boolean isDefaultPlotDimensions() {
        return defaultPlotDimensions.isSet(this.field_1_flags);
    }

    public boolean isDoNotSizeWithWindow() {
        return doNotSizeWithWindow.isSet(this.field_1_flags);
    }

    public boolean isPlotVisibleOnly() {
        return plotVisibleOnly.isSet(this.field_1_flags);
    }

    @Override // org.apache.poi.hssf.record.StandardRecord
    public void serialize(LittleEndianOutput littleEndianOutput) {
        littleEndianOutput.writeShort(this.field_1_flags);
        littleEndianOutput.writeShort(this.field_2_empty);
    }

    public void setAutoPlotArea(boolean z) {
        this.field_1_flags = autoPlotArea.setBoolean(this.field_1_flags, z);
    }

    public void setChartTypeManuallyFormatted(boolean z) {
        this.field_1_flags = chartTypeManuallyFormatted.setBoolean(this.field_1_flags, z);
    }

    public void setDefaultPlotDimensions(boolean z) {
        this.field_1_flags = defaultPlotDimensions.setBoolean(this.field_1_flags, z);
    }

    public void setDoNotSizeWithWindow(boolean z) {
        this.field_1_flags = doNotSizeWithWindow.setBoolean(this.field_1_flags, z);
    }

    public void setEmpty(byte b2) {
        this.field_2_empty = b2;
    }

    public void setPlotVisibleOnly(boolean z) {
        this.field_1_flags = plotVisibleOnly.setBoolean(this.field_1_flags, z);
    }

    @Override // org.apache.poi.hssf.record.Record
    public String toString() {
        StringBuffer c = a.c("[SHTPROPS]\n", "    .flags                = ");
        c.append(HexDump.shortToHex(this.field_1_flags));
        c.append('\n');
        c.append("         .chartTypeManuallyFormatted= ");
        c.append(isChartTypeManuallyFormatted());
        c.append('\n');
        c.append("         .plotVisibleOnly           = ");
        c.append(isPlotVisibleOnly());
        c.append('\n');
        c.append("         .doNotSizeWithWindow       = ");
        c.append(isDoNotSizeWithWindow());
        c.append('\n');
        c.append("         .defaultPlotDimensions     = ");
        c.append(isDefaultPlotDimensions());
        c.append('\n');
        c.append("         .autoPlotArea              = ");
        c.append(isAutoPlotArea());
        c.append('\n');
        c.append("    .empty                = ");
        c.append(HexDump.shortToHex(this.field_2_empty));
        c.append('\n');
        c.append("[/SHTPROPS]\n");
        return c.toString();
    }

    public SheetPropertiesRecord(RecordInputStream recordInputStream) {
        this.field_1_flags = recordInputStream.readUShort();
        this.field_2_empty = recordInputStream.readUShort();
    }
}
