package org.apache.poi.hssf.record.chart;

import b.b.a.a.a;
import org.apache.poi.hssf.record.RecordInputStream;
import org.apache.poi.hssf.record.StandardRecord;
import org.apache.poi.util.BitField;
import org.apache.poi.util.BitFieldFactory;
import org.apache.poi.util.HexDump;
import org.apache.poi.util.LittleEndianOutput;

public final class TextRecord extends StandardRecord {
    public static final short DATA_LABEL_PLACEMENT_ABOVE = 5;
    public static final short DATA_LABEL_PLACEMENT_AUTO = 9;
    public static final short DATA_LABEL_PLACEMENT_AXIS = 4;
    public static final short DATA_LABEL_PLACEMENT_BELOW = 6;
    public static final short DATA_LABEL_PLACEMENT_CENTER = 3;
    public static final short DATA_LABEL_PLACEMENT_CHART_DEPENDENT = 0;
    public static final short DATA_LABEL_PLACEMENT_INSIDE = 2;
    public static final short DATA_LABEL_PLACEMENT_LEFT = 7;
    public static final short DATA_LABEL_PLACEMENT_OUTSIDE = 1;
    public static final short DATA_LABEL_PLACEMENT_RIGHT = 8;
    public static final short DATA_LABEL_PLACEMENT_USER_MOVED = 10;
    public static final short DISPLAY_MODE_OPAQUE = 2;
    public static final short DISPLAY_MODE_TRANSPARENT = 1;
    public static final byte HORIZONTAL_ALIGNMENT_BOTTOM = 3;
    public static final byte HORIZONTAL_ALIGNMENT_CENTER = 2;
    public static final byte HORIZONTAL_ALIGNMENT_JUSTIFY = 4;
    public static final byte HORIZONTAL_ALIGNMENT_LEFT = 1;
    public static final short ROTATION_NONE = 0;
    public static final short ROTATION_ROTATED_90_DEGREES = 2;
    public static final short ROTATION_ROTATED_90_DEGREES_CLOCKWISE = 3;
    public static final short ROTATION_TOP_TO_BOTTOM = 1;
    public static final byte VERTICAL_ALIGNMENT_BOTTOM = 3;
    public static final byte VERTICAL_ALIGNMENT_CENTER = 2;
    public static final byte VERTICAL_ALIGNMENT_JUSTIFY = 4;
    public static final byte VERTICAL_ALIGNMENT_TOP = 1;
    public static final BitField autoBackground = BitFieldFactory.getInstance(128);
    public static final BitField autoColor = BitFieldFactory.getInstance(1);
    public static final BitField autoGeneratedText = BitFieldFactory.getInstance(16);
    public static final BitField autoLabelDeleted = BitFieldFactory.getInstance(64);
    public static final BitField dataLabelPlacement = BitFieldFactory.getInstance(15);
    public static final BitField generated = BitFieldFactory.getInstance(32);
    public static final BitField rotation = BitFieldFactory.getInstance(1792);
    public static final BitField showBubbleSizes = BitFieldFactory.getInstance(8192);
    public static final BitField showCategoryLabelAsPercentage = BitFieldFactory.getInstance(2048);
    public static final BitField showKey = BitFieldFactory.getInstance(2);
    public static final BitField showLabel = BitFieldFactory.getInstance(16384);
    public static final BitField showValue = BitFieldFactory.getInstance(4);
    public static final BitField showValueAsPercentage = BitFieldFactory.getInstance(4096);
    public static final short sid = 4133;
    public static final BitField vertical = BitFieldFactory.getInstance(8);
    public short field_10_indexOfColorValue;
    public short field_11_options2;
    public short field_12_textRotation;
    public byte field_1_horizontalAlignment;
    public byte field_2_verticalAlignment;
    public short field_3_displayMode;
    public int field_4_rgbColor;
    public int field_5_x;
    public int field_6_y;
    public int field_7_width;
    public int field_8_height;
    public short field_9_options1;

    public TextRecord() {
    }

    @Override // org.apache.poi.hssf.record.Record
    public Object clone() {
        TextRecord textRecord = new TextRecord();
        textRecord.field_1_horizontalAlignment = this.field_1_horizontalAlignment;
        textRecord.field_2_verticalAlignment = this.field_2_verticalAlignment;
        textRecord.field_3_displayMode = this.field_3_displayMode;
        textRecord.field_4_rgbColor = this.field_4_rgbColor;
        textRecord.field_5_x = this.field_5_x;
        textRecord.field_6_y = this.field_6_y;
        textRecord.field_7_width = this.field_7_width;
        textRecord.field_8_height = this.field_8_height;
        textRecord.field_9_options1 = this.field_9_options1;
        textRecord.field_10_indexOfColorValue = this.field_10_indexOfColorValue;
        textRecord.field_11_options2 = this.field_11_options2;
        textRecord.field_12_textRotation = this.field_12_textRotation;
        return textRecord;
    }

    public short getDataLabelPlacement() {
        return dataLabelPlacement.getShortValue(this.field_11_options2);
    }

    @Override // org.apache.poi.hssf.record.StandardRecord
    public int getDataSize() {
        return 32;
    }

    public short getDisplayMode() {
        return this.field_3_displayMode;
    }

    public int getHeight() {
        return this.field_8_height;
    }

    public byte getHorizontalAlignment() {
        return this.field_1_horizontalAlignment;
    }

    public short getIndexOfColorValue() {
        return this.field_10_indexOfColorValue;
    }

    public short getOptions1() {
        return this.field_9_options1;
    }

    public short getOptions2() {
        return this.field_11_options2;
    }

    public int getRgbColor() {
        return this.field_4_rgbColor;
    }

    public short getRotation() {
        return rotation.getShortValue(this.field_9_options1);
    }

    @Override // org.apache.poi.hssf.record.Record
    public short getSid() {
        return sid;
    }

    public short getTextRotation() {
        return this.field_12_textRotation;
    }

    public byte getVerticalAlignment() {
        return this.field_2_verticalAlignment;
    }

    public int getWidth() {
        return this.field_7_width;
    }

    public int getX() {
        return this.field_5_x;
    }

    public int getY() {
        return this.field_6_y;
    }

    public boolean isAutoBackground() {
        return autoBackground.isSet(this.field_9_options1);
    }

    public boolean isAutoColor() {
        return autoColor.isSet(this.field_9_options1);
    }

    public boolean isAutoGeneratedText() {
        return autoGeneratedText.isSet(this.field_9_options1);
    }

    public boolean isAutoLabelDeleted() {
        return autoLabelDeleted.isSet(this.field_9_options1);
    }

    public boolean isGenerated() {
        return generated.isSet(this.field_9_options1);
    }

    public boolean isShowBubbleSizes() {
        return showBubbleSizes.isSet(this.field_9_options1);
    }

    public boolean isShowCategoryLabelAsPercentage() {
        return showCategoryLabelAsPercentage.isSet(this.field_9_options1);
    }

    public boolean isShowKey() {
        return showKey.isSet(this.field_9_options1);
    }

    public boolean isShowLabel() {
        return showLabel.isSet(this.field_9_options1);
    }

    public boolean isShowValue() {
        return showValue.isSet(this.field_9_options1);
    }

    public boolean isShowValueAsPercentage() {
        return showValueAsPercentage.isSet(this.field_9_options1);
    }

    public boolean isVertical() {
        return vertical.isSet(this.field_9_options1);
    }

    @Override // org.apache.poi.hssf.record.StandardRecord
    public void serialize(LittleEndianOutput littleEndianOutput) {
        littleEndianOutput.writeByte(this.field_1_horizontalAlignment);
        littleEndianOutput.writeByte(this.field_2_verticalAlignment);
        littleEndianOutput.writeShort(this.field_3_displayMode);
        littleEndianOutput.writeInt(this.field_4_rgbColor);
        littleEndianOutput.writeInt(this.field_5_x);
        littleEndianOutput.writeInt(this.field_6_y);
        littleEndianOutput.writeInt(this.field_7_width);
        littleEndianOutput.writeInt(this.field_8_height);
        littleEndianOutput.writeShort(this.field_9_options1);
        littleEndianOutput.writeShort(this.field_10_indexOfColorValue);
        littleEndianOutput.writeShort(this.field_11_options2);
        littleEndianOutput.writeShort(this.field_12_textRotation);
    }

    public void setAutoBackground(boolean z) {
        this.field_9_options1 = autoBackground.setShortBoolean(this.field_9_options1, z);
    }

    public void setAutoColor(boolean z) {
        this.field_9_options1 = autoColor.setShortBoolean(this.field_9_options1, z);
    }

    public void setAutoGeneratedText(boolean z) {
        this.field_9_options1 = autoGeneratedText.setShortBoolean(this.field_9_options1, z);
    }

    public void setAutoLabelDeleted(boolean z) {
        this.field_9_options1 = autoLabelDeleted.setShortBoolean(this.field_9_options1, z);
    }

    public void setDataLabelPlacement(short s) {
        this.field_11_options2 = dataLabelPlacement.setShortValue(this.field_11_options2, s);
    }

    public void setDisplayMode(short s) {
        this.field_3_displayMode = s;
    }

    public void setGenerated(boolean z) {
        this.field_9_options1 = generated.setShortBoolean(this.field_9_options1, z);
    }

    public void setHeight(int i2) {
        this.field_8_height = i2;
    }

    public void setHorizontalAlignment(byte b2) {
        this.field_1_horizontalAlignment = b2;
    }

    public void setIndexOfColorValue(short s) {
        this.field_10_indexOfColorValue = s;
    }

    public void setOptions1(short s) {
        this.field_9_options1 = s;
    }

    public void setOptions2(short s) {
        this.field_11_options2 = s;
    }

    public void setRgbColor(int i2) {
        this.field_4_rgbColor = i2;
    }

    public void setRotation(short s) {
        this.field_9_options1 = rotation.setShortValue(this.field_9_options1, s);
    }

    public void setShowBubbleSizes(boolean z) {
        this.field_9_options1 = showBubbleSizes.setShortBoolean(this.field_9_options1, z);
    }

    public void setShowCategoryLabelAsPercentage(boolean z) {
        this.field_9_options1 = showCategoryLabelAsPercentage.setShortBoolean(this.field_9_options1, z);
    }

    public void setShowKey(boolean z) {
        this.field_9_options1 = showKey.setShortBoolean(this.field_9_options1, z);
    }

    public void setShowLabel(boolean z) {
        this.field_9_options1 = showLabel.setShortBoolean(this.field_9_options1, z);
    }

    public void setShowValue(boolean z) {
        this.field_9_options1 = showValue.setShortBoolean(this.field_9_options1, z);
    }

    public void setShowValueAsPercentage(boolean z) {
        this.field_9_options1 = showValueAsPercentage.setShortBoolean(this.field_9_options1, z);
    }

    public void setTextRotation(short s) {
        this.field_12_textRotation = s;
    }

    public void setVertical(boolean z) {
        this.field_9_options1 = vertical.setShortBoolean(this.field_9_options1, z);
    }

    public void setVerticalAlignment(byte b2) {
        this.field_2_verticalAlignment = b2;
    }

    public void setWidth(int i2) {
        this.field_7_width = i2;
    }

    public void setX(int i2) {
        this.field_5_x = i2;
    }

    public void setY(int i2) {
        this.field_6_y = i2;
    }

    @Override // org.apache.poi.hssf.record.Record
    public String toString() {
        StringBuffer c = a.c("[TEXT]\n", "    .horizontalAlignment  = ", "0x");
        c.append(HexDump.toHex(getHorizontalAlignment()));
        c.append(" (");
        c.append((int) getHorizontalAlignment());
        c.append(" )");
        c.append(System.getProperty("line.separator"));
        c.append("    .verticalAlignment    = ");
        c.append("0x");
        c.append(HexDump.toHex(getVerticalAlignment()));
        c.append(" (");
        c.append((int) getVerticalAlignment());
        c.append(" )");
        c.append(System.getProperty("line.separator"));
        c.append("    .displayMode          = ");
        c.append("0x");
        c.append(HexDump.toHex(getDisplayMode()));
        c.append(" (");
        c.append((int) getDisplayMode());
        c.append(" )");
        c.append(System.getProperty("line.separator"));
        c.append("    .rgbColor             = ");
        c.append("0x");
        c.append(HexDump.toHex(getRgbColor()));
        c.append(" (");
        c.append(getRgbColor());
        c.append(" )");
        c.append(System.getProperty("line.separator"));
        c.append("    .x                    = ");
        c.append("0x");
        c.append(HexDump.toHex(getX()));
        c.append(" (");
        c.append(getX());
        c.append(" )");
        c.append(System.getProperty("line.separator"));
        c.append("    .y                    = ");
        c.append("0x");
        c.append(HexDump.toHex(getY()));
        c.append(" (");
        c.append(getY());
        c.append(" )");
        c.append(System.getProperty("line.separator"));
        c.append("    .width                = ");
        c.append("0x");
        c.append(HexDump.toHex(getWidth()));
        c.append(" (");
        c.append(getWidth());
        c.append(" )");
        c.append(System.getProperty("line.separator"));
        c.append("    .height               = ");
        c.append("0x");
        c.append(HexDump.toHex(getHeight()));
        c.append(" (");
        c.append(getHeight());
        c.append(" )");
        c.append(System.getProperty("line.separator"));
        c.append("    .options1             = ");
        c.append("0x");
        c.append(HexDump.toHex(getOptions1()));
        c.append(" (");
        c.append((int) getOptions1());
        c.append(" )");
        c.append(System.getProperty("line.separator"));
        c.append("         .autoColor                = ");
        c.append(isAutoColor());
        c.append('\n');
        c.append("         .showKey                  = ");
        c.append(isShowKey());
        c.append('\n');
        c.append("         .showValue                = ");
        c.append(isShowValue());
        c.append('\n');
        c.append("         .vertical                 = ");
        c.append(isVertical());
        c.append('\n');
        c.append("         .autoGeneratedText        = ");
        c.append(isAutoGeneratedText());
        c.append('\n');
        c.append("         .generated                = ");
        c.append(isGenerated());
        c.append('\n');
        c.append("         .autoLabelDeleted         = ");
        c.append(isAutoLabelDeleted());
        c.append('\n');
        c.append("         .autoBackground           = ");
        c.append(isAutoBackground());
        c.append('\n');
        c.append("         .rotation                 = ");
        c.append((int) getRotation());
        c.append('\n');
        c.append("         .showCategoryLabelAsPercentage     = ");
        c.append(isShowCategoryLabelAsPercentage());
        c.append('\n');
        c.append("         .showValueAsPercentage     = ");
        c.append(isShowValueAsPercentage());
        c.append('\n');
        c.append("         .showBubbleSizes          = ");
        c.append(isShowBubbleSizes());
        c.append('\n');
        c.append("         .showLabel                = ");
        c.append(isShowLabel());
        c.append('\n');
        c.append("    .indexOfColorValue    = ");
        c.append("0x");
        c.append(HexDump.toHex(getIndexOfColorValue()));
        c.append(" (");
        c.append((int) getIndexOfColorValue());
        c.append(" )");
        c.append(System.getProperty("line.separator"));
        c.append("    .options2             = ");
        c.append("0x");
        c.append(HexDump.toHex(getOptions2()));
        c.append(" (");
        c.append((int) getOptions2());
        c.append(" )");
        c.append(System.getProperty("line.separator"));
        c.append("         .dataLabelPlacement       = ");
        c.append((int) getDataLabelPlacement());
        c.append('\n');
        c.append("    .textRotation         = ");
        c.append("0x");
        c.append(HexDump.toHex(getTextRotation()));
        c.append(" (");
        c.append((int) getTextRotation());
        c.append(" )");
        c.append(System.getProperty("line.separator"));
        c.append("[/TEXT]\n");
        return c.toString();
    }

    public TextRecord(RecordInputStream recordInputStream) {
        this.field_1_horizontalAlignment = recordInputStream.readByte();
        this.field_2_verticalAlignment = recordInputStream.readByte();
        this.field_3_displayMode = recordInputStream.readShort();
        this.field_4_rgbColor = recordInputStream.readInt();
        this.field_5_x = recordInputStream.readInt();
        this.field_6_y = recordInputStream.readInt();
        this.field_7_width = recordInputStream.readInt();
        this.field_8_height = recordInputStream.readInt();
        this.field_9_options1 = recordInputStream.readShort();
        this.field_10_indexOfColorValue = recordInputStream.readShort();
        this.field_11_options2 = recordInputStream.readShort();
        this.field_12_textRotation = recordInputStream.readShort();
    }
}
