package org.apache.poi.hssf.record.chart;

import b.b.a.a.a;
import org.apache.poi.hssf.record.RecordInputStream;
import org.apache.poi.hssf.record.StandardRecord;
import org.apache.poi.util.BitField;
import org.apache.poi.util.BitFieldFactory;
import org.apache.poi.util.HexDump;
import org.apache.poi.util.LittleEndianOutput;

public final class TickRecord extends StandardRecord {
    public static final BitField autoTextBackground = BitFieldFactory.getInstance(2);
    public static final BitField autoTextColor = BitFieldFactory.getInstance(1);
    public static final BitField autorotate = BitFieldFactory.getInstance(32);
    public static final BitField rotation = BitFieldFactory.getInstance(28);
    public static final short sid = 4126;
    public short field_10_options;
    public short field_11_tickColor;
    public short field_12_zero5;
    public byte field_1_majorTickType;
    public byte field_2_minorTickType;
    public byte field_3_labelPosition;
    public byte field_4_background;
    public int field_5_labelColorRgb;
    public int field_6_zero1;
    public int field_7_zero2;
    public int field_8_zero3;
    public int field_9_zero4;

    public TickRecord() {
    }

    @Override // org.apache.poi.hssf.record.Record
    public Object clone() {
        TickRecord tickRecord = new TickRecord();
        tickRecord.field_1_majorTickType = this.field_1_majorTickType;
        tickRecord.field_2_minorTickType = this.field_2_minorTickType;
        tickRecord.field_3_labelPosition = this.field_3_labelPosition;
        tickRecord.field_4_background = this.field_4_background;
        tickRecord.field_5_labelColorRgb = this.field_5_labelColorRgb;
        tickRecord.field_6_zero1 = this.field_6_zero1;
        tickRecord.field_7_zero2 = this.field_7_zero2;
        tickRecord.field_8_zero3 = this.field_8_zero3;
        tickRecord.field_9_zero4 = this.field_9_zero4;
        tickRecord.field_10_options = this.field_10_options;
        tickRecord.field_11_tickColor = this.field_11_tickColor;
        tickRecord.field_12_zero5 = this.field_12_zero5;
        return tickRecord;
    }

    public byte getBackground() {
        return this.field_4_background;
    }

    @Override // org.apache.poi.hssf.record.StandardRecord
    public int getDataSize() {
        return 30;
    }

    public int getLabelColorRgb() {
        return this.field_5_labelColorRgb;
    }

    public byte getLabelPosition() {
        return this.field_3_labelPosition;
    }

    public byte getMajorTickType() {
        return this.field_1_majorTickType;
    }

    public byte getMinorTickType() {
        return this.field_2_minorTickType;
    }

    public short getOptions() {
        return this.field_10_options;
    }

    public short getRotation() {
        return rotation.getShortValue(this.field_10_options);
    }

    @Override // org.apache.poi.hssf.record.Record
    public short getSid() {
        return sid;
    }

    public short getTickColor() {
        return this.field_11_tickColor;
    }

    public int getZero1() {
        return this.field_6_zero1;
    }

    public int getZero2() {
        return this.field_7_zero2;
    }

    public short getZero3() {
        return this.field_12_zero5;
    }

    public boolean isAutoTextBackground() {
        return autoTextBackground.isSet(this.field_10_options);
    }

    public boolean isAutoTextColor() {
        return autoTextColor.isSet(this.field_10_options);
    }

    public boolean isAutorotate() {
        return autorotate.isSet(this.field_10_options);
    }

    @Override // org.apache.poi.hssf.record.StandardRecord
    public void serialize(LittleEndianOutput littleEndianOutput) {
        littleEndianOutput.writeByte(this.field_1_majorTickType);
        littleEndianOutput.writeByte(this.field_2_minorTickType);
        littleEndianOutput.writeByte(this.field_3_labelPosition);
        littleEndianOutput.writeByte(this.field_4_background);
        littleEndianOutput.writeInt(this.field_5_labelColorRgb);
        littleEndianOutput.writeInt(this.field_6_zero1);
        littleEndianOutput.writeInt(this.field_7_zero2);
        littleEndianOutput.writeInt(this.field_8_zero3);
        littleEndianOutput.writeInt(this.field_9_zero4);
        littleEndianOutput.writeShort(this.field_10_options);
        littleEndianOutput.writeShort(this.field_11_tickColor);
        littleEndianOutput.writeShort(this.field_12_zero5);
    }

    public void setAutoTextBackground(boolean z) {
        this.field_10_options = autoTextBackground.setShortBoolean(this.field_10_options, z);
    }

    public void setAutoTextColor(boolean z) {
        this.field_10_options = autoTextColor.setShortBoolean(this.field_10_options, z);
    }

    public void setAutorotate(boolean z) {
        this.field_10_options = autorotate.setShortBoolean(this.field_10_options, z);
    }

    public void setBackground(byte b2) {
        this.field_4_background = b2;
    }

    public void setLabelColorRgb(int i2) {
        this.field_5_labelColorRgb = i2;
    }

    public void setLabelPosition(byte b2) {
        this.field_3_labelPosition = b2;
    }

    public void setMajorTickType(byte b2) {
        this.field_1_majorTickType = b2;
    }

    public void setMinorTickType(byte b2) {
        this.field_2_minorTickType = b2;
    }

    public void setOptions(short s) {
        this.field_10_options = s;
    }

    public void setRotation(short s) {
        this.field_10_options = rotation.setShortValue(this.field_10_options, s);
    }

    public void setTickColor(short s) {
        this.field_11_tickColor = s;
    }

    public void setZero1(int i2) {
        this.field_6_zero1 = i2;
    }

    public void setZero2(int i2) {
        this.field_7_zero2 = i2;
    }

    public void setZero3(short s) {
        this.field_12_zero5 = s;
    }

    @Override // org.apache.poi.hssf.record.Record
    public String toString() {
        StringBuffer c = a.c("[TICK]\n", "    .majorTickType        = ", "0x");
        c.append(HexDump.toHex(getMajorTickType()));
        c.append(" (");
        c.append((int) getMajorTickType());
        c.append(" )");
        c.append(System.getProperty("line.separator"));
        c.append("    .minorTickType        = ");
        c.append("0x");
        c.append(HexDump.toHex(getMinorTickType()));
        c.append(" (");
        c.append((int) getMinorTickType());
        c.append(" )");
        c.append(System.getProperty("line.separator"));
        c.append("    .labelPosition        = ");
        c.append("0x");
        c.append(HexDump.toHex(getLabelPosition()));
        c.append(" (");
        c.append((int) getLabelPosition());
        c.append(" )");
        c.append(System.getProperty("line.separator"));
        c.append("    .background           = ");
        c.append("0x");
        c.append(HexDump.toHex(getBackground()));
        c.append(" (");
        c.append((int) getBackground());
        c.append(" )");
        c.append(System.getProperty("line.separator"));
        c.append("    .labelColorRgb        = ");
        c.append("0x");
        c.append(HexDump.toHex(getLabelColorRgb()));
        c.append(" (");
        c.append(getLabelColorRgb());
        c.append(" )");
        c.append(System.getProperty("line.separator"));
        c.append("    .zero1                = ");
        c.append("0x");
        c.append(HexDump.toHex(getZero1()));
        c.append(" (");
        c.append(getZero1());
        c.append(" )");
        c.append(System.getProperty("line.separator"));
        c.append("    .zero2                = ");
        c.append("0x");
        c.append(HexDump.toHex(getZero2()));
        c.append(" (");
        c.append(getZero2());
        c.append(" )");
        c.append(System.getProperty("line.separator"));
        c.append("    .options              = ");
        c.append("0x");
        c.append(HexDump.toHex(getOptions()));
        c.append(" (");
        c.append((int) getOptions());
        c.append(" )");
        c.append(System.getProperty("line.separator"));
        c.append("         .autoTextColor            = ");
        c.append(isAutoTextColor());
        c.append('\n');
        c.append("         .autoTextBackground       = ");
        c.append(isAutoTextBackground());
        c.append('\n');
        c.append("         .rotation                 = ");
        c.append((int) getRotation());
        c.append('\n');
        c.append("         .autorotate               = ");
        c.append(isAutorotate());
        c.append('\n');
        c.append("    .tickColor            = ");
        c.append("0x");
        c.append(HexDump.toHex(getTickColor()));
        c.append(" (");
        c.append((int) getTickColor());
        c.append(" )");
        c.append(System.getProperty("line.separator"));
        c.append("    .zero3                = ");
        c.append("0x");
        c.append(HexDump.toHex(getZero3()));
        c.append(" (");
        c.append((int) getZero3());
        c.append(" )");
        c.append(System.getProperty("line.separator"));
        c.append("[/TICK]\n");
        return c.toString();
    }

    public TickRecord(RecordInputStream recordInputStream) {
        this.field_1_majorTickType = recordInputStream.readByte();
        this.field_2_minorTickType = recordInputStream.readByte();
        this.field_3_labelPosition = recordInputStream.readByte();
        this.field_4_background = recordInputStream.readByte();
        this.field_5_labelColorRgb = recordInputStream.readInt();
        this.field_6_zero1 = recordInputStream.readInt();
        this.field_7_zero2 = recordInputStream.readInt();
        this.field_8_zero3 = recordInputStream.readInt();
        this.field_9_zero4 = recordInputStream.readInt();
        this.field_10_options = recordInputStream.readShort();
        this.field_11_tickColor = recordInputStream.readShort();
        this.field_12_zero5 = recordInputStream.readShort();
    }
}
