package org.apache.poi.hssf.record.chart;

import b.b.a.a.a;
import org.apache.poi.hssf.record.RecordInputStream;
import org.apache.poi.hssf.record.StandardRecord;
import org.apache.poi.util.BitField;
import org.apache.poi.util.BitFieldFactory;
import org.apache.poi.util.HexDump;
import org.apache.poi.util.LittleEndianOutput;

public final class ValueRangeRecord extends StandardRecord {
    public static final BitField automaticCategoryCrossing = BitFieldFactory.getInstance(16);
    public static final BitField automaticMajor = BitFieldFactory.getInstance(4);
    public static final BitField automaticMaximum = BitFieldFactory.getInstance(2);
    public static final BitField automaticMinimum = BitFieldFactory.getInstance(1);
    public static final BitField automaticMinor = BitFieldFactory.getInstance(8);
    public static final BitField crossCategoryAxisAtMaximum = BitFieldFactory.getInstance(128);
    public static final BitField logarithmicScale = BitFieldFactory.getInstance(32);
    public static final BitField reserved = BitFieldFactory.getInstance(256);
    public static final short sid = 4127;
    public static final BitField valuesInReverse = BitFieldFactory.getInstance(64);
    public double field_1_minimumAxisValue;
    public double field_2_maximumAxisValue;
    public double field_3_majorIncrement;
    public double field_4_minorIncrement;
    public double field_5_categoryAxisCross;
    public short field_6_options;

    public ValueRangeRecord() {
    }

    @Override // org.apache.poi.hssf.record.Record
    public Object clone() {
        ValueRangeRecord valueRangeRecord = new ValueRangeRecord();
        valueRangeRecord.field_1_minimumAxisValue = this.field_1_minimumAxisValue;
        valueRangeRecord.field_2_maximumAxisValue = this.field_2_maximumAxisValue;
        valueRangeRecord.field_3_majorIncrement = this.field_3_majorIncrement;
        valueRangeRecord.field_4_minorIncrement = this.field_4_minorIncrement;
        valueRangeRecord.field_5_categoryAxisCross = this.field_5_categoryAxisCross;
        valueRangeRecord.field_6_options = this.field_6_options;
        return valueRangeRecord;
    }

    public double getCategoryAxisCross() {
        return this.field_5_categoryAxisCross;
    }

    @Override // org.apache.poi.hssf.record.StandardRecord
    public int getDataSize() {
        return 42;
    }

    public double getMajorIncrement() {
        return this.field_3_majorIncrement;
    }

    public double getMaximumAxisValue() {
        return this.field_2_maximumAxisValue;
    }

    public double getMinimumAxisValue() {
        return this.field_1_minimumAxisValue;
    }

    public double getMinorIncrement() {
        return this.field_4_minorIncrement;
    }

    public short getOptions() {
        return this.field_6_options;
    }

    @Override // org.apache.poi.hssf.record.Record
    public short getSid() {
        return sid;
    }

    public boolean isAutomaticCategoryCrossing() {
        return automaticCategoryCrossing.isSet(this.field_6_options);
    }

    public boolean isAutomaticMajor() {
        return automaticMajor.isSet(this.field_6_options);
    }

    public boolean isAutomaticMaximum() {
        return automaticMaximum.isSet(this.field_6_options);
    }

    public boolean isAutomaticMinimum() {
        return automaticMinimum.isSet(this.field_6_options);
    }

    public boolean isAutomaticMinor() {
        return automaticMinor.isSet(this.field_6_options);
    }

    public boolean isCrossCategoryAxisAtMaximum() {
        return crossCategoryAxisAtMaximum.isSet(this.field_6_options);
    }

    public boolean isLogarithmicScale() {
        return logarithmicScale.isSet(this.field_6_options);
    }

    public boolean isReserved() {
        return reserved.isSet(this.field_6_options);
    }

    public boolean isValuesInReverse() {
        return valuesInReverse.isSet(this.field_6_options);
    }

    @Override // org.apache.poi.hssf.record.StandardRecord
    public void serialize(LittleEndianOutput littleEndianOutput) {
        littleEndianOutput.writeDouble(this.field_1_minimumAxisValue);
        littleEndianOutput.writeDouble(this.field_2_maximumAxisValue);
        littleEndianOutput.writeDouble(this.field_3_majorIncrement);
        littleEndianOutput.writeDouble(this.field_4_minorIncrement);
        littleEndianOutput.writeDouble(this.field_5_categoryAxisCross);
        littleEndianOutput.writeShort(this.field_6_options);
    }

    public void setAutomaticCategoryCrossing(boolean z) {
        this.field_6_options = automaticCategoryCrossing.setShortBoolean(this.field_6_options, z);
    }

    public void setAutomaticMajor(boolean z) {
        this.field_6_options = automaticMajor.setShortBoolean(this.field_6_options, z);
    }

    public void setAutomaticMaximum(boolean z) {
        this.field_6_options = automaticMaximum.setShortBoolean(this.field_6_options, z);
    }

    public void setAutomaticMinimum(boolean z) {
        this.field_6_options = automaticMinimum.setShortBoolean(this.field_6_options, z);
    }

    public void setAutomaticMinor(boolean z) {
        this.field_6_options = automaticMinor.setShortBoolean(this.field_6_options, z);
    }

    public void setCategoryAxisCross(double d2) {
        this.field_5_categoryAxisCross = d2;
    }

    public void setCrossCategoryAxisAtMaximum(boolean z) {
        this.field_6_options = crossCategoryAxisAtMaximum.setShortBoolean(this.field_6_options, z);
    }

    public void setLogarithmicScale(boolean z) {
        this.field_6_options = logarithmicScale.setShortBoolean(this.field_6_options, z);
    }

    public void setMajorIncrement(double d2) {
        this.field_3_majorIncrement = d2;
    }

    public void setMaximumAxisValue(double d2) {
        this.field_2_maximumAxisValue = d2;
    }

    public void setMinimumAxisValue(double d2) {
        this.field_1_minimumAxisValue = d2;
    }

    public void setMinorIncrement(double d2) {
        this.field_4_minorIncrement = d2;
    }

    public void setOptions(short s) {
        this.field_6_options = s;
    }

    public void setReserved(boolean z) {
        this.field_6_options = reserved.setShortBoolean(this.field_6_options, z);
    }

    public void setValuesInReverse(boolean z) {
        this.field_6_options = valuesInReverse.setShortBoolean(this.field_6_options, z);
    }

    @Override // org.apache.poi.hssf.record.Record
    public String toString() {
        StringBuffer c = a.c("[VALUERANGE]\n", "    .minimumAxisValue     = ", " (");
        c.append(getMinimumAxisValue());
        c.append(" )");
        c.append(System.getProperty("line.separator"));
        c.append("    .maximumAxisValue     = ");
        c.append(" (");
        c.append(getMaximumAxisValue());
        c.append(" )");
        c.append(System.getProperty("line.separator"));
        c.append("    .majorIncrement       = ");
        c.append(" (");
        c.append(getMajorIncrement());
        c.append(" )");
        c.append(System.getProperty("line.separator"));
        c.append("    .minorIncrement       = ");
        c.append(" (");
        c.append(getMinorIncrement());
        c.append(" )");
        c.append(System.getProperty("line.separator"));
        c.append("    .categoryAxisCross    = ");
        c.append(" (");
        c.append(getCategoryAxisCross());
        c.append(" )");
        c.append(System.getProperty("line.separator"));
        c.append("    .options              = ");
        c.append("0x");
        c.append(HexDump.toHex(getOptions()));
        c.append(" (");
        c.append((int) getOptions());
        c.append(" )");
        c.append(System.getProperty("line.separator"));
        c.append("         .automaticMinimum         = ");
        c.append(isAutomaticMinimum());
        c.append('\n');
        c.append("         .automaticMaximum         = ");
        c.append(isAutomaticMaximum());
        c.append('\n');
        c.append("         .automaticMajor           = ");
        c.append(isAutomaticMajor());
        c.append('\n');
        c.append("         .automaticMinor           = ");
        c.append(isAutomaticMinor());
        c.append('\n');
        c.append("         .automaticCategoryCrossing     = ");
        c.append(isAutomaticCategoryCrossing());
        c.append('\n');
        c.append("         .logarithmicScale         = ");
        c.append(isLogarithmicScale());
        c.append('\n');
        c.append("         .valuesInReverse          = ");
        c.append(isValuesInReverse());
        c.append('\n');
        c.append("         .crossCategoryAxisAtMaximum     = ");
        c.append(isCrossCategoryAxisAtMaximum());
        c.append('\n');
        c.append("         .reserved                 = ");
        c.append(isReserved());
        c.append('\n');
        c.append("[/VALUERANGE]\n");
        return c.toString();
    }

    public ValueRangeRecord(RecordInputStream recordInputStream) {
        this.field_1_minimumAxisValue = recordInputStream.readDouble();
        this.field_2_maximumAxisValue = recordInputStream.readDouble();
        this.field_3_majorIncrement = recordInputStream.readDouble();
        this.field_4_minorIncrement = recordInputStream.readDouble();
        this.field_5_categoryAxisCross = recordInputStream.readDouble();
        this.field_6_options = recordInputStream.readShort();
    }
}
