package org.apache.poi.hssf.record.common;

import b.b.a.a.a;
import org.apache.poi.ss.formula.functions.NumericFunction;
import org.apache.poi.util.HexDump;
import org.apache.poi.util.LittleEndianInput;
import org.apache.poi.util.LittleEndianOutput;

public final class ExtendedColor implements Cloneable {
    public static final int THEME_ACCENT_1 = 4;
    public static final int THEME_ACCENT_2 = 5;
    public static final int THEME_ACCENT_3 = 6;
    public static final int THEME_ACCENT_4 = 7;
    public static final int THEME_ACCENT_5 = 8;
    public static final int THEME_ACCENT_6 = 9;
    public static final int THEME_DARK_1 = 0;
    public static final int THEME_DARK_2 = 2;
    public static final int THEME_FOLLOWED_HYPERLINK = 11;
    public static final int THEME_HYPERLINK = 10;
    public static final int THEME_LIGHT_1 = 1;
    public static final int THEME_LIGHT_2 = 3;
    public static final int TYPE_AUTO = 0;
    public static final int TYPE_INDEXED = 1;
    public static final int TYPE_RGB = 2;
    public static final int TYPE_THEMED = 3;
    public static final int TYPE_UNSET = 4;
    public int colorIndex;
    public byte[] rgba;
    public int themeIndex;
    public double tint;
    public int type;

    public ExtendedColor() {
        this.type = 1;
        this.colorIndex = 0;
        this.tint = NumericFunction.LOG_10_TO_BASE_e;
    }

    public int getColorIndex() {
        return this.colorIndex;
    }

    public int getDataLength() {
        return 16;
    }

    public byte[] getRGBA() {
        return this.rgba;
    }

    public int getThemeIndex() {
        return this.themeIndex;
    }

    public double getTint() {
        return this.tint;
    }

    public int getType() {
        return this.type;
    }

    public void serialize(LittleEndianOutput littleEndianOutput) {
        littleEndianOutput.writeInt(this.type);
        int i2 = this.type;
        if (i2 == 1) {
            littleEndianOutput.writeInt(this.colorIndex);
        } else if (i2 == 2) {
            littleEndianOutput.write(this.rgba);
        } else if (i2 == 3) {
            littleEndianOutput.writeInt(this.themeIndex);
        } else {
            littleEndianOutput.writeInt(0);
        }
        littleEndianOutput.writeDouble(this.tint);
    }

    public void setColorIndex(int i2) {
        this.colorIndex = i2;
    }

    public void setRGBA(byte[] bArr) {
        this.rgba = bArr == null ? null : (byte[]) bArr.clone();
    }

    public void setThemeIndex(int i2) {
        this.themeIndex = i2;
    }

    public void setTint(double d2) {
        if (d2 < -1.0d || d2 > 1.0d) {
            throw new IllegalArgumentException("Tint/Shade must be between -1 and +1");
        }
        this.tint = d2;
    }

    public void setType(int i2) {
        this.type = i2;
    }

    public String toString() {
        StringBuffer c = a.c("    [Extended Color]\n", "          .type  = ");
        c.append(this.type);
        c.append("\n");
        c.append("          .tint  = ");
        c.append(this.tint);
        c.append("\n");
        c.append("          .c_idx = ");
        c.append(this.colorIndex);
        c.append("\n");
        c.append("          .rgba  = ");
        c.append(HexDump.toHex(this.rgba));
        c.append("\n");
        c.append("          .t_idx = ");
        c.append(this.themeIndex);
        c.append("\n");
        c.append("    [/Extended Color]\n");
        return c.toString();
    }

    @Override // java.lang.Object
    public ExtendedColor clone() {
        ExtendedColor extendedColor = new ExtendedColor();
        extendedColor.type = this.type;
        extendedColor.tint = this.tint;
        int i2 = this.type;
        if (i2 == 1) {
            extendedColor.colorIndex = this.colorIndex;
        } else if (i2 == 2) {
            byte[] bArr = new byte[4];
            extendedColor.rgba = bArr;
            System.arraycopy(this.rgba, 0, bArr, 0, 4);
        } else if (i2 == 3) {
            extendedColor.themeIndex = this.themeIndex;
        }
        return extendedColor;
    }

    public ExtendedColor(LittleEndianInput littleEndianInput) {
        int readInt = littleEndianInput.readInt();
        this.type = readInt;
        if (readInt == 1) {
            this.colorIndex = littleEndianInput.readInt();
        } else if (readInt == 2) {
            byte[] bArr = new byte[4];
            this.rgba = bArr;
            littleEndianInput.readFully(bArr);
        } else if (readInt == 3) {
            this.themeIndex = littleEndianInput.readInt();
        } else {
            littleEndianInput.readInt();
        }
        this.tint = littleEndianInput.readDouble();
    }
}
