package org.apache.poi.hssf.record.common;

import b.b.a.a.a;
import org.apache.poi.hssf.record.RecordInputStream;
import org.apache.poi.util.LittleEndianOutput;
import org.apache.poi.util.StringUtil;

public final class FeatProtection implements SharedFeature {
    public static long HAS_SELF_RELATIVE_SECURITY_FEATURE = 1;
    public static long NO_SELF_RELATIVE_SECURITY_FEATURE;
    public int fSD;
    public int passwordVerifier;
    public byte[] securityDescriptor;
    public String title;

    public FeatProtection() {
        this.securityDescriptor = new byte[0];
    }

    @Override // org.apache.poi.hssf.record.common.SharedFeature
    public int getDataSize() {
        return StringUtil.getEncodedSize(this.title) + 8 + this.securityDescriptor.length;
    }

    public int getFSD() {
        return this.fSD;
    }

    public int getPasswordVerifier() {
        return this.passwordVerifier;
    }

    public String getTitle() {
        return this.title;
    }

    @Override // org.apache.poi.hssf.record.common.SharedFeature
    public void serialize(LittleEndianOutput littleEndianOutput) {
        littleEndianOutput.writeInt(this.fSD);
        littleEndianOutput.writeInt(this.passwordVerifier);
        StringUtil.writeUnicodeString(littleEndianOutput, this.title);
        littleEndianOutput.write(this.securityDescriptor);
    }

    public void setPasswordVerifier(int i2) {
        this.passwordVerifier = i2;
    }

    public void setTitle(String str) {
        this.title = str;
    }

    @Override // org.apache.poi.hssf.record.common.SharedFeature
    public String toString() {
        StringBuffer a = a.a(" [FEATURE PROTECTION]\n");
        StringBuilder b2 = a.b("   Self Relative = ");
        b2.append(this.fSD);
        a.append(b2.toString());
        a.append("   Password Verifier = " + this.passwordVerifier);
        a.append("   Title = " + this.title);
        a.append("   Security Descriptor Size = " + this.securityDescriptor.length);
        a.append(" [/FEATURE PROTECTION]\n");
        return a.toString();
    }

    public FeatProtection(RecordInputStream recordInputStream) {
        this.fSD = recordInputStream.readInt();
        this.passwordVerifier = recordInputStream.readInt();
        this.title = StringUtil.readUnicodeString(recordInputStream);
        this.securityDescriptor = recordInputStream.readRemainder();
    }
}
