package org.apache.poi.hssf.record.common;

import b.b.a.a.a;
import org.apache.poi.hssf.record.RecordInputStream;
import org.apache.poi.ss.util.CellRangeAddress;
import org.apache.poi.util.LittleEndianOutput;

public final class FtrHeader implements Cloneable {
    public CellRangeAddress associatedRange;
    public short grbitFrt;
    public short recordType;

    public FtrHeader() {
        this.associatedRange = new CellRangeAddress(0, 0, 0, 0);
    }

    public static int getDataSize() {
        return 12;
    }

    @Override // java.lang.Object
    public Object clone() {
        FtrHeader ftrHeader = new FtrHeader();
        ftrHeader.recordType = this.recordType;
        ftrHeader.grbitFrt = this.grbitFrt;
        ftrHeader.associatedRange = this.associatedRange.copy();
        return ftrHeader;
    }

    public CellRangeAddress getAssociatedRange() {
        return this.associatedRange;
    }

    public short getGrbitFrt() {
        return this.grbitFrt;
    }

    public short getRecordType() {
        return this.recordType;
    }

    public void serialize(LittleEndianOutput littleEndianOutput) {
        littleEndianOutput.writeShort(this.recordType);
        littleEndianOutput.writeShort(this.grbitFrt);
        this.associatedRange.serialize(littleEndianOutput);
    }

    public void setAssociatedRange(CellRangeAddress cellRangeAddress) {
        this.associatedRange = cellRangeAddress;
    }

    public void setGrbitFrt(short s) {
        this.grbitFrt = s;
    }

    public void setRecordType(short s) {
        this.recordType = s;
    }

    public String toString() {
        StringBuffer a = a.a(" [FUTURE HEADER]\n");
        StringBuilder b2 = a.b("   Type ");
        b2.append((int) this.recordType);
        a.append(b2.toString());
        a.append("   Flags " + ((int) this.grbitFrt));
        a.append(" [/FUTURE HEADER]\n");
        return a.toString();
    }

    public FtrHeader(RecordInputStream recordInputStream) {
        this.recordType = recordInputStream.readShort();
        this.grbitFrt = recordInputStream.readShort();
        this.associatedRange = new CellRangeAddress(recordInputStream);
    }
}
