package org.apache.poi.hssf.record.common;

import b.b.a.a.a;
import java.util.ArrayList;
import java.util.Arrays;
import java.util.Collections;
import java.util.Iterator;
import java.util.List;
import org.apache.poi.hssf.record.RecordInputStream;
import org.apache.poi.hssf.record.cont.ContinuableRecordInput;
import org.apache.poi.hssf.record.cont.ContinuableRecordOutput;
import org.apache.poi.util.BitField;
import org.apache.poi.util.BitFieldFactory;
import org.apache.poi.util.LittleEndianInput;
import org.apache.poi.util.LittleEndianOutput;
import org.apache.poi.util.POILogFactory;
import org.apache.poi.util.POILogger;
import org.apache.poi.util.StringUtil;

public class UnicodeString implements Comparable<UnicodeString> {
    public static POILogger _logger = POILogFactory.getLogger(UnicodeString.class);
    public static final BitField extBit = BitFieldFactory.getInstance(4);
    public static final BitField highByte = BitFieldFactory.getInstance(1);
    public static final BitField richText = BitFieldFactory.getInstance(8);
    public short field_1_charCount;
    public byte field_2_optionflags;
    public String field_3_string;
    public List<FormatRun> field_4_format_runs;
    public ExtRst field_5_ext_rst;

    public static class ExtRst implements Comparable<ExtRst> {
        public byte[] extraData;
        public short formattingFontIndex;
        public short formattingOptions;
        public int numberOfRuns;
        public PhRun[] phRuns;
        public String phoneticText;
        public short reserved;

        public ExtRst() {
            populateEmpty();
        }

        private void populateEmpty() {
            this.reserved = 1;
            this.phoneticText = "";
            this.phRuns = new PhRun[0];
            this.extraData = new byte[0];
        }

        public boolean equals(Object obj) {
            if ((obj instanceof ExtRst) && compareTo((ExtRst) obj) == 0) {
                return true;
            }
            return false;
        }

        public int getDataSize() {
            return (this.phRuns.length * 6) + (this.phoneticText.length() * 2) + 10 + this.extraData.length;
        }

        public short getFormattingFontIndex() {
            return this.formattingFontIndex;
        }

        public short getFormattingOptions() {
            return this.formattingOptions;
        }

        public int getNumberOfRuns() {
            return this.numberOfRuns;
        }

        public PhRun[] getPhRuns() {
            return this.phRuns;
        }

        public String getPhoneticText() {
            return this.phoneticText;
        }

        public int hashCode() {
            int hashCode = this.phoneticText.hashCode() + (((((((this.reserved * 31) + this.formattingFontIndex) * 31) + this.formattingOptions) * 31) + this.numberOfRuns) * 31);
            PhRun[] phRunArr = this.phRuns;
            if (phRunArr != null) {
                for (PhRun phRun : phRunArr) {
                    hashCode = ((phRun.realTextFirstCharacterOffset + ((phRun.phoneticTextFirstCharacterOffset + (hashCode * 31)) * 31)) * 31) + phRun.realTextLength;
                }
            }
            return hashCode;
        }

        public void serialize(ContinuableRecordOutput continuableRecordOutput) {
            int dataSize = getDataSize();
            continuableRecordOutput.writeContinueIfRequired(8);
            continuableRecordOutput.writeShort(this.reserved);
            continuableRecordOutput.writeShort(dataSize);
            continuableRecordOutput.writeShort(this.formattingFontIndex);
            continuableRecordOutput.writeShort(this.formattingOptions);
            continuableRecordOutput.writeContinueIfRequired(6);
            continuableRecordOutput.writeShort(this.numberOfRuns);
            continuableRecordOutput.writeShort(this.phoneticText.length());
            continuableRecordOutput.writeShort(this.phoneticText.length());
            continuableRecordOutput.writeContinueIfRequired(this.phoneticText.length() * 2);
            StringUtil.putUnicodeLE(this.phoneticText, continuableRecordOutput);
            int i2 = 0;
            while (true) {
                PhRun[] phRunArr = this.phRuns;
                if (i2 < phRunArr.length) {
                    phRunArr[i2].serialize(continuableRecordOutput);
                    i2++;
                } else {
                    continuableRecordOutput.write(this.extraData);
                    return;
                }
            }
        }

        @Override // java.lang.Object
        public ExtRst clone() {
            ExtRst extRst = new ExtRst();
            extRst.reserved = this.reserved;
            extRst.formattingFontIndex = this.formattingFontIndex;
            extRst.formattingOptions = this.formattingOptions;
            extRst.numberOfRuns = this.numberOfRuns;
            extRst.phoneticText = this.phoneticText;
            extRst.phRuns = new PhRun[this.phRuns.length];
            int i2 = 0;
            while (true) {
                PhRun[] phRunArr = extRst.phRuns;
                if (i2 >= phRunArr.length) {
                    return extRst;
                }
                phRunArr[i2] = new PhRun(this.phRuns[i2].phoneticTextFirstCharacterOffset, this.phRuns[i2].realTextFirstCharacterOffset, this.phRuns[i2].realTextLength);
                i2++;
            }
        }

        public int compareTo(ExtRst extRst) {
            int i2 = this.reserved - extRst.reserved;
            if (i2 != 0) {
                return i2;
            }
            int i3 = this.formattingFontIndex - extRst.formattingFontIndex;
            if (i3 != 0) {
                return i3;
            }
            int i4 = this.formattingOptions - extRst.formattingOptions;
            if (i4 != 0) {
                return i4;
            }
            int i5 = this.numberOfRuns - extRst.numberOfRuns;
            if (i5 != 0) {
                return i5;
            }
            int compareTo = this.phoneticText.compareTo(extRst.phoneticText);
            if (compareTo != 0) {
                return compareTo;
            }
            int length = this.phRuns.length - extRst.phRuns.length;
            if (length != 0) {
                return length;
            }
            int i6 = 0;
            while (true) {
                PhRun[] phRunArr = this.phRuns;
                if (i6 >= phRunArr.length) {
                    return Arrays.hashCode(this.extraData) - Arrays.hashCode(extRst.extraData);
                }
                int i7 = phRunArr[i6].phoneticTextFirstCharacterOffset - extRst.phRuns[i6].phoneticTextFirstCharacterOffset;
                if (i7 != 0) {
                    return i7;
                }
                int i8 = this.phRuns[i6].realTextFirstCharacterOffset - extRst.phRuns[i6].realTextFirstCharacterOffset;
                if (i8 != 0) {
                    return i8;
                }
                int i9 = this.phRuns[i6].realTextLength - extRst.phRuns[i6].realTextLength;
                if (i9 != 0) {
                    return i9;
                }
                i6++;
            }
        }

        public ExtRst(LittleEndianInput littleEndianInput, int i2) {
            short readShort = littleEndianInput.readShort();
            this.reserved = readShort;
            if (readShort == -1) {
                populateEmpty();
                return;
            }
            int i3 = 0;
            if (readShort != 1) {
                UnicodeString._logger.log(5, a.a(a.b("Warning - ExtRst has wrong magic marker, expecting 1 but found "), this.reserved, " - ignoring"));
                while (i3 < i2 - 2) {
                    littleEndianInput.readByte();
                    i3++;
                }
                populateEmpty();
                return;
            }
            short readShort2 = littleEndianInput.readShort();
            this.formattingFontIndex = littleEndianInput.readShort();
            this.formattingOptions = littleEndianInput.readShort();
            this.numberOfRuns = littleEndianInput.readUShort();
            short readShort3 = littleEndianInput.readShort();
            short readShort4 = littleEndianInput.readShort();
            if (readShort3 == 0 && readShort4 > 0) {
                readShort4 = 0;
            }
            if (readShort3 == readShort4) {
                String readUnicodeLE = StringUtil.readUnicodeLE(littleEndianInput, readShort3);
                this.phoneticText = readUnicodeLE;
                int length = ((readShort2 - 4) - 6) - (readUnicodeLE.length() * 2);
                int i4 = length / 6;
                this.phRuns = new PhRun[i4];
                int i5 = 0;
                while (true) {
                    PhRun[] phRunArr = this.phRuns;
                    if (i5 >= phRunArr.length) {
                        break;
                    }
                    phRunArr[i5] = new PhRun(littleEndianInput);
                    i5++;
                }
                int i6 = length - (i4 * 6);
                if (i6 < 0) {
                    POILogger pOILogger = UnicodeString._logger;
                    StringBuilder b2 = a.b("Warning - ExtRst overran by ");
                    b2.append(0 - i6);
                    b2.append(" bytes");
                    pOILogger.log(5, b2.toString());
                    i6 = 0;
                }
                this.extraData = new byte[i6];
                while (true) {
                    byte[] bArr = this.extraData;
                    if (i3 < bArr.length) {
                        bArr[i3] = littleEndianInput.readByte();
                        i3++;
                    } else {
                        return;
                    }
                }
            } else {
                throw new IllegalStateException(a.a("The two length fields of the Phonetic Text don't agree! ", readShort3, " vs ", readShort4));
            }
        }
    }

    public static class FormatRun implements Comparable<FormatRun> {
        public static final /* synthetic */ boolean $assertionsDisabled = false;
        public final short _character;
        public short _fontIndex;

        public FormatRun(short s, short s2) {
            this._character = s;
            this._fontIndex = s2;
        }

        public boolean equals(Object obj) {
            if (!(obj instanceof FormatRun)) {
                return false;
            }
            FormatRun formatRun = (FormatRun) obj;
            if (this._character == formatRun._character && this._fontIndex == formatRun._fontIndex) {
                return true;
            }
            return false;
        }

        public short getCharacterPos() {
            return this._character;
        }

        public short getFontIndex() {
            return this._fontIndex;
        }

        public int hashCode() {
            return 42;
        }

        public void serialize(LittleEndianOutput littleEndianOutput) {
            littleEndianOutput.writeShort(this._character);
            littleEndianOutput.writeShort(this._fontIndex);
        }

        public String toString() {
            StringBuilder b2 = a.b("character=");
            b2.append((int) this._character);
            b2.append(",fontIndex=");
            b2.append((int) this._fontIndex);
            return b2.toString();
        }

        public int compareTo(FormatRun formatRun) {
            if (this._character == formatRun._character && this._fontIndex == formatRun._fontIndex) {
                return 0;
            }
            short s = this._character;
            short s2 = formatRun._character;
            return s == s2 ? this._fontIndex - formatRun._fontIndex : s - s2;
        }

        public FormatRun(LittleEndianInput littleEndianInput) {
            this(littleEndianInput.readShort(), littleEndianInput.readShort());
        }
    }

    public static class PhRun {
        public int phoneticTextFirstCharacterOffset;
        public int realTextFirstCharacterOffset;
        public int realTextLength;

        /* access modifiers changed from: private */
        /* access modifiers changed from: public */
        private void serialize(ContinuableRecordOutput continuableRecordOutput) {
            continuableRecordOutput.writeContinueIfRequired(6);
            continuableRecordOutput.writeShort(this.phoneticTextFirstCharacterOffset);
            continuableRecordOutput.writeShort(this.realTextFirstCharacterOffset);
            continuableRecordOutput.writeShort(this.realTextLength);
        }

        public PhRun(int i2, int i3, int i4) {
            this.phoneticTextFirstCharacterOffset = i2;
            this.realTextFirstCharacterOffset = i3;
            this.realTextLength = i4;
        }

        public PhRun(LittleEndianInput littleEndianInput) {
            this.phoneticTextFirstCharacterOffset = littleEndianInput.readUShort();
            this.realTextFirstCharacterOffset = littleEndianInput.readUShort();
            this.realTextLength = littleEndianInput.readUShort();
        }
    }

    public UnicodeString() {
    }

    private int findFormatRunAt(int i2) {
        int size = this.field_4_format_runs.size();
        for (int i3 = 0; i3 < size; i3++) {
            short s = this.field_4_format_runs.get(i3)._character;
            if (s == i2) {
                return i3;
            }
            if (s > i2) {
                return -1;
            }
        }
        return -1;
    }

    private boolean isExtendedText() {
        return extBit.isSet(getOptionFlags());
    }

    private boolean isRichText() {
        return richText.isSet(getOptionFlags());
    }

    public void addFormatRun(FormatRun formatRun) {
        if (this.field_4_format_runs == null) {
            this.field_4_format_runs = new ArrayList();
        }
        int findFormatRunAt = findFormatRunAt(formatRun._character);
        if (findFormatRunAt != -1) {
            this.field_4_format_runs.remove(findFormatRunAt);
        }
        this.field_4_format_runs.add(formatRun);
        Collections.sort(this.field_4_format_runs);
        this.field_2_optionflags = richText.setByte(this.field_2_optionflags);
    }

    public void clearFormatting() {
        this.field_4_format_runs = null;
        this.field_2_optionflags = richText.clearByte(this.field_2_optionflags);
    }

    @Override // java.lang.Object
    public Object clone() {
        UnicodeString unicodeString = new UnicodeString();
        unicodeString.field_1_charCount = this.field_1_charCount;
        unicodeString.field_2_optionflags = this.field_2_optionflags;
        unicodeString.field_3_string = this.field_3_string;
        if (this.field_4_format_runs != null) {
            unicodeString.field_4_format_runs = new ArrayList();
            for (FormatRun formatRun : this.field_4_format_runs) {
                unicodeString.field_4_format_runs.add(new FormatRun(formatRun._character, formatRun._fontIndex));
            }
        }
        ExtRst extRst = this.field_5_ext_rst;
        if (extRst != null) {
            unicodeString.field_5_ext_rst = extRst.clone();
        }
        return unicodeString;
    }

    public boolean equals(Object obj) {
        int size;
        if (!(obj instanceof UnicodeString)) {
            return false;
        }
        UnicodeString unicodeString = (UnicodeString) obj;
        if (!(this.field_1_charCount == unicodeString.field_1_charCount && this.field_2_optionflags == unicodeString.field_2_optionflags && this.field_3_string.equals(unicodeString.field_3_string))) {
            return false;
        }
        List<FormatRun> list = this.field_4_format_runs;
        if (list == null) {
            if (unicodeString.field_4_format_runs == null) {
                return true;
            }
            return false;
        } else if (unicodeString.field_4_format_runs == null || (size = list.size()) != unicodeString.field_4_format_runs.size()) {
            return false;
        } else {
            for (int i2 = 0; i2 < size; i2++) {
                if (!this.field_4_format_runs.get(i2).equals(unicodeString.field_4_format_runs.get(i2))) {
                    return false;
                }
            }
            ExtRst extRst = this.field_5_ext_rst;
            if (extRst != null) {
                ExtRst extRst2 = unicodeString.field_5_ext_rst;
                if (extRst2 == null) {
                    return false;
                }
                return extRst.equals(extRst2);
            } else if (unicodeString.field_5_ext_rst == null) {
                return true;
            } else {
                return false;
            }
        }
    }

    public Iterator<FormatRun> formatIterator() {
        List<FormatRun> list = this.field_4_format_runs;
        if (list != null) {
            return list.iterator();
        }
        return null;
    }

    public int getCharCount() {
        short s = this.field_1_charCount;
        return s < 0 ? s + 65536 : s;
    }

    public short getCharCountShort() {
        return this.field_1_charCount;
    }

    public String getDebugInfo() {
        StringBuffer c = a.c("[UNICODESTRING]\n", "    .charcount       = ");
        c.append(Integer.toHexString(getCharCount()));
        c.append("\n");
        c.append("    .optionflags     = ");
        c.append(Integer.toHexString(getOptionFlags()));
        c.append("\n");
        c.append("    .string          = ");
        c.append(getString());
        c.append("\n");
        if (this.field_4_format_runs != null) {
            for (int i2 = 0; i2 < this.field_4_format_runs.size(); i2++) {
                c.append("      .format_run" + i2 + "          = ");
                c.append(this.field_4_format_runs.get(i2));
                c.append("\n");
            }
        }
        if (this.field_5_ext_rst != null) {
            c.append("    .field_5_ext_rst          = ");
            c.append("\n");
            c.append(this.field_5_ext_rst);
            c.append("\n");
        }
        c.append("[/UNICODESTRING]\n");
        return c.toString();
    }

    public ExtRst getExtendedRst() {
        return this.field_5_ext_rst;
    }

    public FormatRun getFormatRun(int i2) {
        List<FormatRun> list = this.field_4_format_runs;
        if (list != null && i2 >= 0 && i2 < list.size()) {
            return this.field_4_format_runs.get(i2);
        }
        return null;
    }

    public int getFormatRunCount() {
        List<FormatRun> list = this.field_4_format_runs;
        if (list == null) {
            return 0;
        }
        return list.size();
    }

    public byte getOptionFlags() {
        return this.field_2_optionflags;
    }

    public String getString() {
        return this.field_3_string;
    }

    public int hashCode() {
        String str = this.field_3_string;
        return this.field_1_charCount + (str != null ? str.hashCode() : 0);
    }

    public void removeFormatRun(FormatRun formatRun) {
        this.field_4_format_runs.remove(formatRun);
        if (this.field_4_format_runs.size() == 0) {
            this.field_4_format_runs = null;
            this.field_2_optionflags = richText.clearByte(this.field_2_optionflags);
        }
    }

    public void serialize(ContinuableRecordOutput continuableRecordOutput) {
        ExtRst extRst;
        ExtRst extRst2;
        List<FormatRun> list;
        int size = (!isRichText() || (list = this.field_4_format_runs) == null) ? 0 : list.size();
        int dataSize = (!isExtendedText() || (extRst2 = this.field_5_ext_rst) == null) ? 0 : extRst2.getDataSize() + 4;
        continuableRecordOutput.writeString(this.field_3_string, size, dataSize);
        if (size > 0) {
            for (int i2 = 0; i2 < size; i2++) {
                if (continuableRecordOutput.getAvailableSpace() < 4) {
                    continuableRecordOutput.writeContinue();
                }
                this.field_4_format_runs.get(i2).serialize(continuableRecordOutput);
            }
        }
        if (dataSize > 0 && (extRst = this.field_5_ext_rst) != null) {
            extRst.serialize(continuableRecordOutput);
        }
    }

    public void setCharCount(short s) {
        this.field_1_charCount = s;
    }

    public void setExtendedRst(ExtRst extRst) {
        if (extRst != null) {
            this.field_2_optionflags = extBit.setByte(this.field_2_optionflags);
        } else {
            this.field_2_optionflags = extBit.clearByte(this.field_2_optionflags);
        }
        this.field_5_ext_rst = extRst;
    }

    public void setOptionFlags(byte b2) {
        this.field_2_optionflags = b2;
    }

    public void setString(String str) {
        this.field_3_string = str;
        setCharCount((short) str.length());
        int length = str.length();
        boolean z = false;
        int i2 = 0;
        while (true) {
            if (i2 >= length) {
                break;
            } else if (str.charAt(i2) > 255) {
                z = true;
                break;
            } else {
                i2++;
            }
        }
        if (z) {
            this.field_2_optionflags = highByte.setByte(this.field_2_optionflags);
        } else {
            this.field_2_optionflags = highByte.clearByte(this.field_2_optionflags);
        }
    }

    public void swapFontUse(short s, short s2) {
        for (FormatRun formatRun : this.field_4_format_runs) {
            if (formatRun._fontIndex == s) {
                formatRun._fontIndex = s2;
            }
        }
    }

    public String toString() {
        return getString();
    }

    public UnicodeString(String str) {
        setString(str);
    }

    public int compareTo(UnicodeString unicodeString) {
        int compareTo = getString().compareTo(unicodeString.getString());
        if (compareTo != 0) {
            return compareTo;
        }
        List<FormatRun> list = this.field_4_format_runs;
        if (list == null) {
            if (unicodeString.field_4_format_runs == null) {
                return 0;
            }
            return 1;
        } else if (unicodeString.field_4_format_runs == null) {
            return -1;
        } else {
            int size = list.size();
            if (size != unicodeString.field_4_format_runs.size()) {
                return size - unicodeString.field_4_format_runs.size();
            }
            for (int i2 = 0; i2 < size; i2++) {
                int compareTo2 = this.field_4_format_runs.get(i2).compareTo(unicodeString.field_4_format_runs.get(i2));
                if (compareTo2 != 0) {
                    return compareTo2;
                }
            }
            ExtRst extRst = this.field_5_ext_rst;
            if (extRst != null) {
                ExtRst extRst2 = unicodeString.field_5_ext_rst;
                if (extRst2 == null) {
                    return -1;
                }
                return extRst.compareTo(extRst2);
            } else if (unicodeString.field_5_ext_rst == null) {
                return 0;
            } else {
                return 1;
            }
        }
    }

    public UnicodeString(RecordInputStream recordInputStream) {
        this.field_1_charCount = recordInputStream.readShort();
        this.field_2_optionflags = recordInputStream.readByte();
        short readShort = isRichText() ? recordInputStream.readShort() : 0;
        int readInt = isExtendedText() ? recordInputStream.readInt() : 0;
        boolean z = (this.field_2_optionflags & 1) == 0;
        int charCount = getCharCount();
        this.field_3_string = z ? recordInputStream.readCompressedUnicode(charCount) : recordInputStream.readUnicodeLEString(charCount);
        if (isRichText() && readShort > 0) {
            this.field_4_format_runs = new ArrayList(readShort);
            for (int i2 = 0; i2 < readShort; i2++) {
                this.field_4_format_runs.add(new FormatRun(recordInputStream));
            }
        }
        if (isExtendedText() && readInt > 0) {
            ExtRst extRst = new ExtRst(new ContinuableRecordInput(recordInputStream), readInt);
            this.field_5_ext_rst = extRst;
            if (extRst.getDataSize() + 4 != readInt) {
                POILogger pOILogger = _logger;
                StringBuilder a = a.a("ExtRst was supposed to be ", readInt, " bytes long, but seems to actually be ");
                a.append(this.field_5_ext_rst.getDataSize() + 4);
                pOILogger.log(5, a.toString());
            }
        }
    }
}
