package org.apache.poi.hssf.record.cont;

import org.apache.poi.util.DelayableLittleEndianOutput;
import org.apache.poi.util.LittleEndianByteArrayOutputStream;
import org.apache.poi.util.LittleEndianOutput;

public final class UnknownLengthRecordOutput implements LittleEndianOutput {
    public static final int MAX_DATA_SIZE = 8224;
    public final byte[] _byteBuffer;
    public final LittleEndianOutput _dataSizeOutput;
    public final LittleEndianOutput _originalOut;
    public LittleEndianOutput _out;
    public int _size;

    public UnknownLengthRecordOutput(LittleEndianOutput littleEndianOutput, int i2) {
        this._originalOut = littleEndianOutput;
        littleEndianOutput.writeShort(i2);
        if (littleEndianOutput instanceof DelayableLittleEndianOutput) {
            this._dataSizeOutput = ((DelayableLittleEndianOutput) littleEndianOutput).createDelayedOutput(2);
            this._byteBuffer = null;
            this._out = littleEndianOutput;
            return;
        }
        this._dataSizeOutput = littleEndianOutput;
        this._byteBuffer = new byte[8224];
        this._out = new LittleEndianByteArrayOutputStream(this._byteBuffer, 0);
    }

    public int getAvailableSpace() {
        if (this._out != null) {
            return 8224 - this._size;
        }
        throw new IllegalStateException("Record already terminated");
    }

    public int getTotalSize() {
        return this._size + 4;
    }

    public void terminate() {
        if (this._out != null) {
            this._dataSizeOutput.writeShort(this._size);
            byte[] bArr = this._byteBuffer;
            if (bArr != null) {
                this._originalOut.write(bArr, 0, this._size);
                this._out = null;
                return;
            }
            this._out = null;
            return;
        }
        throw new IllegalStateException("Record already terminated");
    }

    @Override // org.apache.poi.util.LittleEndianOutput
    public void write(byte[] bArr) {
        this._out.write(bArr);
        this._size += bArr.length;
    }

    @Override // org.apache.poi.util.LittleEndianOutput
    public void writeByte(int i2) {
        this._out.writeByte(i2);
        this._size++;
    }

    @Override // org.apache.poi.util.LittleEndianOutput
    public void writeDouble(double d2) {
        this._out.writeDouble(d2);
        this._size += 8;
    }

    @Override // org.apache.poi.util.LittleEndianOutput
    public void writeInt(int i2) {
        this._out.writeInt(i2);
        this._size += 4;
    }

    @Override // org.apache.poi.util.LittleEndianOutput
    public void writeLong(long j) {
        this._out.writeLong(j);
        this._size += 8;
    }

    @Override // org.apache.poi.util.LittleEndianOutput
    public void writeShort(int i2) {
        this._out.writeShort(i2);
        this._size += 2;
    }

    @Override // org.apache.poi.util.LittleEndianOutput
    public void write(byte[] bArr, int i2, int i3) {
        this._out.write(bArr, i2, i3);
        this._size += i3;
    }
}
