package org.apache.poi.hssf.record.pivottable;

import b.b.a.a.a;
import org.apache.poi.hssf.record.RecordInputStream;
import org.apache.poi.hssf.record.StandardRecord;
import org.apache.poi.util.LittleEndianOutput;
import org.apache.poi.util.StringUtil;

public final class ViewDefinitionRecord extends StandardRecord {
    public static final short sid = 176;
    public int cCol;
    public int cDim;
    public int cDimCol;
    public int cDimData;
    public int cDimPg;
    public int cDimRw;
    public int cRw;
    public int colFirst;
    public int colFirstData;
    public int colLast;
    public String dataField;
    public int grbit;
    public int iCache;
    public int ipos4Data;
    public int itblAutoFmt;
    public String name;
    public int reserved;
    public int rwFirst;
    public int rwFirstData;
    public int rwFirstHead;
    public int rwLast;
    public int sxaxis4Data;

    public ViewDefinitionRecord(RecordInputStream recordInputStream) {
        this.rwFirst = recordInputStream.readUShort();
        this.rwLast = recordInputStream.readUShort();
        this.colFirst = recordInputStream.readUShort();
        this.colLast = recordInputStream.readUShort();
        this.rwFirstHead = recordInputStream.readUShort();
        this.rwFirstData = recordInputStream.readUShort();
        this.colFirstData = recordInputStream.readUShort();
        this.iCache = recordInputStream.readUShort();
        this.reserved = recordInputStream.readUShort();
        this.sxaxis4Data = recordInputStream.readUShort();
        this.ipos4Data = recordInputStream.readUShort();
        this.cDim = recordInputStream.readUShort();
        this.cDimRw = recordInputStream.readUShort();
        this.cDimCol = recordInputStream.readUShort();
        this.cDimPg = recordInputStream.readUShort();
        this.cDimData = recordInputStream.readUShort();
        this.cRw = recordInputStream.readUShort();
        this.cCol = recordInputStream.readUShort();
        this.grbit = recordInputStream.readUShort();
        this.itblAutoFmt = recordInputStream.readUShort();
        int readUShort = recordInputStream.readUShort();
        int readUShort2 = recordInputStream.readUShort();
        this.name = StringUtil.readUnicodeString(recordInputStream, readUShort);
        this.dataField = StringUtil.readUnicodeString(recordInputStream, readUShort2);
    }

    @Override // org.apache.poi.hssf.record.StandardRecord
    public int getDataSize() {
        return StringUtil.getEncodedSize(this.dataField) + StringUtil.getEncodedSize(this.name) + 40;
    }

    @Override // org.apache.poi.hssf.record.Record
    public short getSid() {
        return 176;
    }

    @Override // org.apache.poi.hssf.record.StandardRecord
    public void serialize(LittleEndianOutput littleEndianOutput) {
        littleEndianOutput.writeShort(this.rwFirst);
        littleEndianOutput.writeShort(this.rwLast);
        littleEndianOutput.writeShort(this.colFirst);
        littleEndianOutput.writeShort(this.colLast);
        littleEndianOutput.writeShort(this.rwFirstHead);
        littleEndianOutput.writeShort(this.rwFirstData);
        littleEndianOutput.writeShort(this.colFirstData);
        littleEndianOutput.writeShort(this.iCache);
        littleEndianOutput.writeShort(this.reserved);
        littleEndianOutput.writeShort(this.sxaxis4Data);
        littleEndianOutput.writeShort(this.ipos4Data);
        littleEndianOutput.writeShort(this.cDim);
        littleEndianOutput.writeShort(this.cDimRw);
        littleEndianOutput.writeShort(this.cDimCol);
        littleEndianOutput.writeShort(this.cDimPg);
        littleEndianOutput.writeShort(this.cDimData);
        littleEndianOutput.writeShort(this.cRw);
        littleEndianOutput.writeShort(this.cCol);
        littleEndianOutput.writeShort(this.grbit);
        littleEndianOutput.writeShort(this.itblAutoFmt);
        littleEndianOutput.writeShort(this.name.length());
        littleEndianOutput.writeShort(this.dataField.length());
        StringUtil.writeUnicodeStringFlagAndData(littleEndianOutput, this.name);
        StringUtil.writeUnicodeStringFlagAndData(littleEndianOutput, this.dataField);
    }

    @Override // org.apache.poi.hssf.record.Record
    public String toString() {
        StringBuffer c = a.c("[SXVIEW]\n", "    .rwFirst      =");
        a.a(this.rwFirst, c, '\n', "    .rwLast       =");
        a.a(this.rwLast, c, '\n', "    .colFirst     =");
        a.a(this.colFirst, c, '\n', "    .colLast      =");
        a.a(this.colLast, c, '\n', "    .rwFirstHead  =");
        a.a(this.rwFirstHead, c, '\n', "    .rwFirstData  =");
        a.a(this.rwFirstData, c, '\n', "    .colFirstData =");
        a.a(this.colFirstData, c, '\n', "    .iCache       =");
        a.a(this.iCache, c, '\n', "    .reserved     =");
        a.a(this.reserved, c, '\n', "    .sxaxis4Data  =");
        a.a(this.sxaxis4Data, c, '\n', "    .ipos4Data    =");
        a.a(this.ipos4Data, c, '\n', "    .cDim         =");
        a.a(this.cDim, c, '\n', "    .cDimRw       =");
        a.a(this.cDimRw, c, '\n', "    .cDimCol      =");
        a.a(this.cDimCol, c, '\n', "    .cDimPg       =");
        a.a(this.cDimPg, c, '\n', "    .cDimData     =");
        a.a(this.cDimData, c, '\n', "    .cRw          =");
        a.a(this.cRw, c, '\n', "    .cCol         =");
        a.a(this.cCol, c, '\n', "    .grbit        =");
        a.a(this.grbit, c, '\n', "    .itblAutoFmt  =");
        a.a(this.itblAutoFmt, c, '\n', "    .name         =");
        c.append(this.name);
        c.append('\n');
        c.append("    .dataField    =");
        c.append(this.dataField);
        c.append('\n');
        c.append("[/SXVIEW]\n");
        return c.toString();
    }
}
