package org.apache.poi.hssf.usermodel;

import java.awt.Color;
import java.awt.Font;
import java.awt.FontMetrics;
import java.awt.Graphics;
import java.awt.Image;
import java.awt.Rectangle;
import java.awt.Shape;
import java.awt.Toolkit;
import java.awt.image.ImageObserver;
import java.text.AttributedCharacterIterator;
import org.apache.poi.hssf.util.HSSFColor;
import org.apache.poi.util.NotImplemented;
import org.apache.poi.util.POILogFactory;
import org.apache.poi.util.POILogger;
import org.apache.poi.util.SuppressForbidden;

public class EscherGraphics extends Graphics {
    public static final POILogger logger = POILogFactory.getLogger(EscherGraphics.class);
    public Color background = Color.white;
    public final HSSFShapeGroup escherGroup;
    public Font font;
    public Color foreground;
    public final float verticalPixelsPerPoint;
    public float verticalPointsPerPixel = 1.0f;
    public final HSSFWorkbook workbook;

    public EscherGraphics(HSSFShapeGroup hSSFShapeGroup, HSSFWorkbook hSSFWorkbook, Color color, float f2) {
        this.escherGroup = hSSFShapeGroup;
        this.workbook = hSSFWorkbook;
        this.verticalPointsPerPixel = f2;
        this.verticalPixelsPerPoint = 1.0f / f2;
        this.font = new Font(HSSFFont.FONT_ARIAL, 0, 10);
        this.foreground = color;
    }

    private int[] addToAll(int[] iArr, int i2) {
        int[] iArr2 = new int[iArr.length];
        for (int i3 = 0; i3 < iArr.length; i3++) {
            iArr2[i3] = iArr[i3] + i2;
        }
        return iArr2;
    }

    private int findBiggest(int[] iArr) {
        int i2 = Integer.MIN_VALUE;
        for (int i3 = 0; i3 < iArr.length; i3++) {
            if (iArr[i3] > i2) {
                i2 = iArr[i3];
            }
        }
        return i2;
    }

    private int findSmallest(int[] iArr) {
        int i2 = Integer.MAX_VALUE;
        for (int i3 = 0; i3 < iArr.length; i3++) {
            if (iArr[i3] < i2) {
                i2 = iArr[i3];
            }
        }
        return i2;
    }

    private HSSFFont matchFont(Font font2) {
        HSSFColor findColor = this.workbook.getCustomPalette().findColor((byte) this.foreground.getRed(), (byte) this.foreground.getGreen(), (byte) this.foreground.getBlue());
        if (findColor == null) {
            findColor = this.workbook.getCustomPalette().findSimilarColor((byte) this.foreground.getRed(), (byte) this.foreground.getGreen(), (byte) this.foreground.getBlue());
        }
        boolean z = true;
        boolean z2 = (font2.getStyle() & 1) != 0;
        if ((font2.getStyle() & 2) == 0) {
            z = false;
        }
        HSSFFont findFont = this.workbook.findFont(z2, findColor.getIndex(), (short) (font2.getSize() * 20), font2.getName(), z, false, (short) 0, (byte) 0);
        if (findFont != null) {
            return findFont;
        }
        HSSFFont createFont = this.workbook.createFont();
        createFont.setBold(z2);
        createFont.setColor(findColor.getIndex());
        createFont.setFontHeight((short) (font2.getSize() * 20));
        createFont.setFontName(font2.getName());
        createFont.setItalic(z);
        createFont.setStrikeout(false);
        createFont.setTypeOffset(0);
        createFont.setUnderline((byte) 0);
        return createFont;
    }

    @NotImplemented
    public void clearRect(int i2, int i3, int i4, int i5) {
        Color color = this.foreground;
        setColor(this.background);
        fillRect(i2, i3, i4, i5);
        setColor(color);
    }

    @NotImplemented
    public void clipRect(int i2, int i3, int i4, int i5) {
        if (logger.check(5)) {
            logger.log(5, "clipRect not supported");
        }
    }

    @NotImplemented
    public void copyArea(int i2, int i3, int i4, int i5, int i6, int i7) {
        if (logger.check(5)) {
            logger.log(5, "copyArea not supported");
        }
    }

    public Graphics create() {
        return new EscherGraphics(this.escherGroup, this.workbook, this.foreground, this.font, this.verticalPointsPerPixel);
    }

    public void dispose() {
    }

    @NotImplemented
    public void drawArc(int i2, int i3, int i4, int i5, int i6, int i7) {
        if (logger.check(5)) {
            logger.log(5, "drawArc not supported");
        }
    }

    @NotImplemented
    public boolean drawImage(Image image, int i2, int i3, int i4, int i5, int i6, int i7, int i8, int i9, Color color, ImageObserver imageObserver) {
        if (logger.check(5)) {
            logger.log(5, "drawImage not supported");
        }
        return true;
    }

    public void drawLine(int i2, int i3, int i4, int i5) {
        drawLine(i2, i3, i4, i5, 0);
    }

    public void drawOval(int i2, int i3, int i4, int i5) {
        HSSFSimpleShape createShape = this.escherGroup.createShape(new HSSFChildAnchor(i2, i3, i4 + i2, i5 + i3));
        createShape.setShapeType(3);
        createShape.setLineWidth(0);
        createShape.setLineStyleColor(this.foreground.getRed(), this.foreground.getGreen(), this.foreground.getBlue());
        createShape.setNoFill(true);
    }

    public void drawPolygon(int[] iArr, int[] iArr2, int i2) {
        int findBiggest = findBiggest(iArr);
        int findBiggest2 = findBiggest(iArr2);
        int findSmallest = findSmallest(iArr);
        int findSmallest2 = findSmallest(iArr2);
        HSSFPolygon createPolygon = this.escherGroup.createPolygon(new HSSFChildAnchor(findSmallest, findSmallest2, findBiggest, findBiggest2));
        createPolygon.setPolygonDrawArea(findBiggest - findSmallest, findBiggest2 - findSmallest2);
        createPolygon.setPoints(addToAll(iArr, -findSmallest), addToAll(iArr2, -findSmallest2));
        createPolygon.setLineStyleColor(this.foreground.getRed(), this.foreground.getGreen(), this.foreground.getBlue());
        createPolygon.setLineWidth(0);
        createPolygon.setNoFill(true);
    }

    @NotImplemented
    public void drawPolyline(int[] iArr, int[] iArr2, int i2) {
        if (logger.check(5)) {
            logger.log(5, "drawPolyline not supported");
        }
    }

    @NotImplemented
    public void drawRect(int i2, int i3, int i4, int i5) {
        if (logger.check(5)) {
            logger.log(5, "drawRect not supported");
        }
    }

    @NotImplemented
    public void drawRoundRect(int i2, int i3, int i4, int i5, int i6, int i7) {
        if (logger.check(5)) {
            logger.log(5, "drawRoundRect not supported");
        }
    }

    public void drawString(String str, int i2, int i3) {
        Font font2;
        if (str != null && !str.equals("")) {
            if (this.font.getName().equals("SansSerif")) {
                font2 = new Font(HSSFFont.FONT_ARIAL, this.font.getStyle(), (int) (((float) this.font.getSize()) / this.verticalPixelsPerPoint));
            } else {
                font2 = new Font(this.font.getName(), this.font.getStyle(), (int) (((float) this.font.getSize()) / this.verticalPixelsPerPoint));
            }
            float f2 = this.verticalPixelsPerPoint;
            int size = (int) (((float) i3) - ((f2 * 2.0f) + (((float) this.font.getSize()) / f2)));
            HSSFTextbox createTextbox = this.escherGroup.createTextbox(new HSSFChildAnchor(i2, size, (StaticFontMetrics.getFontDetails(font2).getStringWidth(str) * 8) + 12 + i2, (((int) ((((float) this.font.getSize()) / this.verticalPixelsPerPoint) + 6.0f)) * 2) + size));
            createTextbox.setNoFill(true);
            createTextbox.setLineStyle(-1);
            HSSFRichTextString hSSFRichTextString = new HSSFRichTextString(str);
            hSSFRichTextString.applyFont(matchFont(font2));
            createTextbox.setString(hSSFRichTextString);
        }
    }

    public void fillArc(int i2, int i3, int i4, int i5, int i6, int i7) {
        if (logger.check(5)) {
            logger.log(5, "fillArc not supported");
        }
    }

    public void fillOval(int i2, int i3, int i4, int i5) {
        HSSFSimpleShape createShape = this.escherGroup.createShape(new HSSFChildAnchor(i2, i3, i4 + i2, i5 + i3));
        createShape.setShapeType(3);
        createShape.setLineStyle(-1);
        createShape.setFillColor(this.foreground.getRed(), this.foreground.getGreen(), this.foreground.getBlue());
        createShape.setLineStyleColor(this.foreground.getRed(), this.foreground.getGreen(), this.foreground.getBlue());
        createShape.setNoFill(false);
    }

    public void fillPolygon(int[] iArr, int[] iArr2, int i2) {
        int findBiggest = findBiggest(iArr);
        int findBiggest2 = findBiggest(iArr2);
        int findSmallest = findSmallest(iArr);
        int findSmallest2 = findSmallest(iArr2);
        HSSFPolygon createPolygon = this.escherGroup.createPolygon(new HSSFChildAnchor(findSmallest, findSmallest2, findBiggest, findBiggest2));
        createPolygon.setPolygonDrawArea(findBiggest - findSmallest, findBiggest2 - findSmallest2);
        createPolygon.setPoints(addToAll(iArr, -findSmallest), addToAll(iArr2, -findSmallest2));
        createPolygon.setLineStyleColor(this.foreground.getRed(), this.foreground.getGreen(), this.foreground.getBlue());
        createPolygon.setFillColor(this.foreground.getRed(), this.foreground.getGreen(), this.foreground.getBlue());
    }

    public void fillRect(int i2, int i3, int i4, int i5) {
        HSSFSimpleShape createShape = this.escherGroup.createShape(new HSSFChildAnchor(i2, i3, i4 + i2, i5 + i3));
        createShape.setShapeType(1);
        createShape.setLineStyle(-1);
        createShape.setFillColor(this.foreground.getRed(), this.foreground.getGreen(), this.foreground.getBlue());
        createShape.setLineStyleColor(this.foreground.getRed(), this.foreground.getGreen(), this.foreground.getBlue());
    }

    public void fillRoundRect(int i2, int i3, int i4, int i5, int i6, int i7) {
        if (logger.check(5)) {
            logger.log(5, "fillRoundRect not supported");
        }
    }

    public Color getBackground() {
        return this.background;
    }

    public Shape getClip() {
        return getClipBounds();
    }

    public Rectangle getClipBounds() {
        return null;
    }

    public Color getColor() {
        return this.foreground;
    }

    public HSSFShapeGroup getEscherGraphics() {
        return this.escherGroup;
    }

    public Font getFont() {
        return this.font;
    }

    @SuppressForbidden
    public FontMetrics getFontMetrics(Font font2) {
        return Toolkit.getDefaultToolkit().getFontMetrics(font2);
    }

    public void setBackground(Color color) {
        this.background = color;
    }

    public void setClip(int i2, int i3, int i4, int i5) {
        setClip(new Rectangle(i2, i3, i4, i5));
    }

    @NotImplemented
    public void setClip(Shape shape) {
    }

    public void setColor(Color color) {
        this.foreground = color;
    }

    public void setFont(Font font2) {
        this.font = font2;
    }

    @NotImplemented
    public void setPaintMode() {
        if (logger.check(5)) {
            logger.log(5, "setPaintMode not supported");
        }
    }

    @NotImplemented
    public void setXORMode(Color color) {
        if (logger.check(5)) {
            logger.log(5, "setXORMode not supported");
        }
    }

    @NotImplemented
    public void translate(int i2, int i3) {
        if (logger.check(5)) {
            logger.log(5, "translate not supported");
        }
    }

    public void drawLine(int i2, int i3, int i4, int i5, int i6) {
        HSSFSimpleShape createShape = this.escherGroup.createShape(new HSSFChildAnchor(i2, i3, i4, i5));
        createShape.setShapeType(20);
        createShape.setLineWidth(i6);
        createShape.setLineStyleColor(this.foreground.getRed(), this.foreground.getGreen(), this.foreground.getBlue());
    }

    @NotImplemented
    public boolean drawImage(Image image, int i2, int i3, int i4, int i5, int i6, int i7, int i8, int i9, ImageObserver imageObserver) {
        if (logger.check(5)) {
            logger.log(5, "drawImage not supported");
        }
        return true;
    }

    public boolean drawImage(Image image, int i2, int i3, int i4, int i5, Color color, ImageObserver imageObserver) {
        return drawImage(image, i2, i3, i2 + i4, i3 + i5, 0, 0, image.getWidth(imageObserver), image.getHeight(imageObserver), color, imageObserver);
    }

    public boolean drawImage(Image image, int i2, int i3, int i4, int i5, ImageObserver imageObserver) {
        return drawImage(image, i2, i3, i2 + i4, i3 + i5, 0, 0, image.getWidth(imageObserver), image.getHeight(imageObserver), imageObserver);
    }

    public boolean drawImage(Image image, int i2, int i3, Color color, ImageObserver imageObserver) {
        return drawImage(image, i2, i3, image.getWidth(imageObserver), image.getHeight(imageObserver), color, imageObserver);
    }

    public boolean drawImage(Image image, int i2, int i3, ImageObserver imageObserver) {
        return drawImage(image, i2, i3, image.getWidth(imageObserver), image.getHeight(imageObserver), imageObserver);
    }

    public EscherGraphics(HSSFShapeGroup hSSFShapeGroup, HSSFWorkbook hSSFWorkbook, Color color, Font font2, float f2) {
        this.escherGroup = hSSFShapeGroup;
        this.workbook = hSSFWorkbook;
        this.foreground = color;
        this.font = font2;
        this.verticalPointsPerPixel = f2;
        this.verticalPixelsPerPoint = 1.0f / f2;
    }

    public void drawString(AttributedCharacterIterator attributedCharacterIterator, int i2, int i3) {
        if (logger.check(5)) {
            logger.log(5, "drawString not supported");
        }
    }
}
