package org.apache.poi.hssf.usermodel;

import b.b.a.a.a;
import java.util.HashMap;
import java.util.Map;
import java.util.Properties;
import java.util.StringTokenizer;
import org.apache.poi.xssf.usermodel.XSSFDataValidationConstraint;

public class FontDetails {
    public String _fontName;
    public int _height;
    public final Map<Character, Integer> charWidths = new HashMap();

    public FontDetails(String str, int i2) {
        this._fontName = str;
        this._height = i2;
    }

    public static String buildFontCharactersProperty(String str) {
        return a.b("font.", str, ".characters");
    }

    public static String buildFontHeightProperty(String str) {
        return a.b("font.", str, ".height");
    }

    public static String buildFontWidthsProperty(String str) {
        return a.b("font.", str, ".widths");
    }

    public static FontDetails create(String str, Properties properties) {
        String property = properties.getProperty(buildFontHeightProperty(str));
        String property2 = properties.getProperty(buildFontWidthsProperty(str));
        String property3 = properties.getProperty(buildFontCharactersProperty(str));
        if (property == null || property2 == null || property3 == null) {
            throw new IllegalArgumentException(a.b("The supplied FontMetrics doesn't know about the font '", str, "', so we can't use it. Please add it to your font metrics file (see StaticFontMetrics.getFontDetails"));
        }
        FontDetails fontDetails = new FontDetails(str, Integer.parseInt(property));
        String[] split = split(property3, XSSFDataValidationConstraint.LIST_SEPARATOR, -1);
        String[] split2 = split(property2, XSSFDataValidationConstraint.LIST_SEPARATOR, -1);
        if (split.length == split2.length) {
            for (int i2 = 0; i2 < split2.length; i2++) {
                if (split[i2].length() != 0) {
                    fontDetails.addChar(split[i2].charAt(0), Integer.parseInt(split2[i2]));
                }
            }
            return fontDetails;
        }
        throw new RuntimeException(a.b("Number of characters does not number of widths for font ", str));
    }

    public static String[] split(String str, String str2, int i2) {
        StringTokenizer stringTokenizer = new StringTokenizer(str, str2);
        int countTokens = stringTokenizer.countTokens();
        if (i2 != -1 && countTokens > i2) {
            countTokens = i2;
        }
        String[] strArr = new String[countTokens];
        int i3 = 0;
        while (true) {
            if (!stringTokenizer.hasMoreTokens()) {
                break;
            } else if (i2 == -1 || i3 != countTokens - 1) {
                strArr[i3] = stringTokenizer.nextToken().trim();
                i3++;
            } else {
                StringBuffer stringBuffer = new StringBuffer(((countTokens - i3) * str.length()) / countTokens);
                while (stringTokenizer.hasMoreTokens()) {
                    stringBuffer.append(stringTokenizer.nextToken());
                    if (stringTokenizer.hasMoreTokens()) {
                        stringBuffer.append(str2);
                    }
                }
                strArr[i3] = stringBuffer.toString().trim();
            }
        }
        return strArr;
    }

    public void addChar(char c, int i2) {
        this.charWidths.put(Character.valueOf(c), Integer.valueOf(i2));
    }

    public void addChars(char[] cArr, int[] iArr) {
        for (int i2 = 0; i2 < cArr.length; i2++) {
            this.charWidths.put(Character.valueOf(cArr[i2]), Integer.valueOf(iArr[i2]));
        }
    }

    public int getCharWidth(char c) {
        Integer num = this.charWidths.get(Character.valueOf(c));
        if (num != null) {
            return num.intValue();
        }
        if ('W' == c) {
            return 0;
        }
        return getCharWidth('W');
    }

    public String getFontName() {
        return this._fontName;
    }

    public int getHeight() {
        return this._height;
    }

    public int getStringWidth(String str) {
        int i2 = 0;
        for (int i3 = 0; i3 < str.length(); i3++) {
            i2 += getCharWidth(str.charAt(i3));
        }
        return i2;
    }
}
