package org.apache.poi.hssf.usermodel;

import b.b.a.a.a;
import java.util.ArrayList;
import java.util.Iterator;
import java.util.List;
import org.apache.lucene.codecs.lucene3x.Lucene3xFields;
import org.apache.poi.hssf.record.BOFRecord;
import org.apache.poi.hssf.record.DimensionsRecord;
import org.apache.poi.hssf.record.EOFRecord;
import org.apache.poi.hssf.record.EscherAggregate;
import org.apache.poi.hssf.record.FooterRecord;
import org.apache.poi.hssf.record.HCenterRecord;
import org.apache.poi.hssf.record.HeaderRecord;
import org.apache.poi.hssf.record.PrintSetupRecord;
import org.apache.poi.hssf.record.ProtectRecord;
import org.apache.poi.hssf.record.Record;
import org.apache.poi.hssf.record.RecordBase;
import org.apache.poi.hssf.record.SCLRecord;
import org.apache.poi.hssf.record.UnknownRecord;
import org.apache.poi.hssf.record.VCenterRecord;
import org.apache.poi.hssf.record.chart.AreaFormatRecord;
import org.apache.poi.hssf.record.chart.AreaRecord;
import org.apache.poi.hssf.record.chart.AxisLineFormatRecord;
import org.apache.poi.hssf.record.chart.AxisOptionsRecord;
import org.apache.poi.hssf.record.chart.AxisParentRecord;
import org.apache.poi.hssf.record.chart.AxisRecord;
import org.apache.poi.hssf.record.chart.AxisUsedRecord;
import org.apache.poi.hssf.record.chart.BarRecord;
import org.apache.poi.hssf.record.chart.BeginRecord;
import org.apache.poi.hssf.record.chart.CategorySeriesAxisRecord;
import org.apache.poi.hssf.record.chart.ChartFormatRecord;
import org.apache.poi.hssf.record.chart.ChartRecord;
import org.apache.poi.hssf.record.chart.ChartTitleFormatRecord;
import org.apache.poi.hssf.record.chart.DataFormatRecord;
import org.apache.poi.hssf.record.chart.DefaultDataLabelTextPropertiesRecord;
import org.apache.poi.hssf.record.chart.EndRecord;
import org.apache.poi.hssf.record.chart.FontBasisRecord;
import org.apache.poi.hssf.record.chart.FontIndexRecord;
import org.apache.poi.hssf.record.chart.FrameRecord;
import org.apache.poi.hssf.record.chart.LegendRecord;
import org.apache.poi.hssf.record.chart.LineFormatRecord;
import org.apache.poi.hssf.record.chart.LinkedDataRecord;
import org.apache.poi.hssf.record.chart.PlotAreaRecord;
import org.apache.poi.hssf.record.chart.PlotGrowthRecord;
import org.apache.poi.hssf.record.chart.SeriesIndexRecord;
import org.apache.poi.hssf.record.chart.SeriesRecord;
import org.apache.poi.hssf.record.chart.SeriesTextRecord;
import org.apache.poi.hssf.record.chart.SeriesToChartGroupRecord;
import org.apache.poi.hssf.record.chart.SheetPropertiesRecord;
import org.apache.poi.hssf.record.chart.TextRecord;
import org.apache.poi.hssf.record.chart.TickRecord;
import org.apache.poi.hssf.record.chart.UnitsRecord;
import org.apache.poi.hssf.record.chart.ValueRangeRecord;
import org.apache.poi.ss.formula.functions.NumericFunction;
import org.apache.poi.ss.formula.ptg.Area3DPtg;
import org.apache.poi.ss.formula.ptg.AreaPtgBase;
import org.apache.poi.ss.formula.ptg.Ptg;
import org.apache.poi.ss.util.CellRangeAddress;
import org.apache.poi.ss.util.CellRangeAddressBase;

public final class HSSFChart {
    public ChartRecord chartRecord;
    public ChartTitleFormatRecord chartTitleFormat;
    public SeriesTextRecord chartTitleText;
    public LegendRecord legendRecord;
    public List<HSSFSeries> series = new ArrayList();
    public HSSFSheet sheet;
    public HSSFChartType type = HSSFChartType.Unknown;
    public List<ValueRangeRecord> valueRanges = new ArrayList();

    public enum HSSFChartType {
        Area {
            @Override // org.apache.poi.hssf.usermodel.HSSFChart.HSSFChartType
            public short getSid() {
                return AreaRecord.sid;
            }
        },
        Bar {
            @Override // org.apache.poi.hssf.usermodel.HSSFChart.HSSFChartType
            public short getSid() {
                return BarRecord.sid;
            }
        },
        Line {
            @Override // org.apache.poi.hssf.usermodel.HSSFChart.HSSFChartType
            public short getSid() {
                return 4120;
            }
        },
        Pie {
            @Override // org.apache.poi.hssf.usermodel.HSSFChart.HSSFChartType
            public short getSid() {
                return 4121;
            }
        },
        Scatter {
            @Override // org.apache.poi.hssf.usermodel.HSSFChart.HSSFChartType
            public short getSid() {
                return 4123;
            }
        },
        Unknown {
            @Override // org.apache.poi.hssf.usermodel.HSSFChart.HSSFChartType
            public short getSid() {
                return 0;
            }
        };

        public abstract short getSid();
    }

    public static class HSSFSeries {
        public LinkedDataRecord dataCategoryLabels;
        public LinkedDataRecord dataName;
        public LinkedDataRecord dataSecondaryCategoryLabels;
        public LinkedDataRecord dataValues;
        public SeriesRecord series;
        public SeriesTextRecord seriesTitleText;

        public HSSFSeries(SeriesRecord seriesRecord) {
            this.series = seriesRecord;
        }

        private CellRangeAddressBase getCellRange(LinkedDataRecord linkedDataRecord) {
            if (linkedDataRecord == null) {
                return null;
            }
            Ptg[] formulaOfLink = linkedDataRecord.getFormulaOfLink();
            int i2 = 0;
            int i3 = 0;
            int i4 = 0;
            int i5 = 0;
            for (Ptg ptg : formulaOfLink) {
                if (ptg instanceof AreaPtgBase) {
                    AreaPtgBase areaPtgBase = (AreaPtgBase) ptg;
                    i2 = areaPtgBase.getFirstRow();
                    i3 = areaPtgBase.getLastRow();
                    i4 = areaPtgBase.getFirstColumn();
                    i5 = areaPtgBase.getLastColumn();
                }
            }
            return new CellRangeAddress(i2, i3, i4, i5);
        }

        private Integer setVerticalCellRange(LinkedDataRecord linkedDataRecord, CellRangeAddressBase cellRangeAddressBase) {
            if (linkedDataRecord == null) {
                return null;
            }
            ArrayList arrayList = new ArrayList();
            int lastRow = (cellRangeAddressBase.getLastRow() - cellRangeAddressBase.getFirstRow()) + 1;
            int lastColumn = (cellRangeAddressBase.getLastColumn() - cellRangeAddressBase.getFirstColumn()) + 1;
            Ptg[] formulaOfLink = linkedDataRecord.getFormulaOfLink();
            for (Ptg ptg : formulaOfLink) {
                if (ptg instanceof AreaPtgBase) {
                    AreaPtgBase areaPtgBase = (AreaPtgBase) ptg;
                    areaPtgBase.setFirstRow(cellRangeAddressBase.getFirstRow());
                    areaPtgBase.setLastRow(cellRangeAddressBase.getLastRow());
                    areaPtgBase.setFirstColumn(cellRangeAddressBase.getFirstColumn());
                    areaPtgBase.setLastColumn(cellRangeAddressBase.getLastColumn());
                    arrayList.add(areaPtgBase);
                }
            }
            linkedDataRecord.setFormulaOfLink((Ptg[]) arrayList.toArray(new Ptg[arrayList.size()]));
            return Integer.valueOf(lastRow * lastColumn);
        }

        public CellRangeAddressBase getCategoryLabelsCellRange() {
            return getCellRange(this.dataCategoryLabels);
        }

        public LinkedDataRecord getDataCategoryLabels() {
            return this.dataCategoryLabels;
        }

        public LinkedDataRecord getDataName() {
            return this.dataName;
        }

        public LinkedDataRecord getDataSecondaryCategoryLabels() {
            return this.dataSecondaryCategoryLabels;
        }

        public LinkedDataRecord getDataValues() {
            return this.dataValues;
        }

        public short getNumValues() {
            return this.series.getNumValues();
        }

        public SeriesRecord getSeries() {
            return this.series;
        }

        public String getSeriesTitle() {
            SeriesTextRecord seriesTextRecord = this.seriesTitleText;
            if (seriesTextRecord != null) {
                return seriesTextRecord.getText();
            }
            return null;
        }

        public short getValueType() {
            return this.series.getValuesDataType();
        }

        public CellRangeAddressBase getValuesCellRange() {
            return getCellRange(this.dataValues);
        }

        public void insertData(LinkedDataRecord linkedDataRecord) {
            byte linkType = linkedDataRecord.getLinkType();
            if (linkType == 0) {
                this.dataName = linkedDataRecord;
            } else if (linkType == 1) {
                this.dataValues = linkedDataRecord;
            } else if (linkType == 2) {
                this.dataCategoryLabels = linkedDataRecord;
            } else if (linkType == 3) {
                this.dataSecondaryCategoryLabels = linkedDataRecord;
            } else {
                StringBuilder b2 = a.b("Invalid link type: ");
                b2.append((int) linkedDataRecord.getLinkType());
                throw new IllegalStateException(b2.toString());
            }
        }

        public void setCategoryLabelsCellRange(CellRangeAddressBase cellRangeAddressBase) {
            Integer verticalCellRange = setVerticalCellRange(this.dataCategoryLabels, cellRangeAddressBase);
            if (verticalCellRange != null) {
                this.series.setNumCategories((short) verticalCellRange.intValue());
            }
        }

        public void setSeriesTitle(String str) {
            SeriesTextRecord seriesTextRecord = this.seriesTitleText;
            if (seriesTextRecord != null) {
                seriesTextRecord.setText(str);
                return;
            }
            throw new IllegalStateException("No series title found to change");
        }

        public void setSeriesTitleText(SeriesTextRecord seriesTextRecord) {
            this.seriesTitleText = seriesTextRecord;
        }

        public void setValuesCellRange(CellRangeAddressBase cellRangeAddressBase) {
            Integer verticalCellRange = setVerticalCellRange(this.dataValues, cellRangeAddressBase);
            if (verticalCellRange != null) {
                this.series.setNumValues((short) verticalCellRange.intValue());
            }
        }
    }

    public HSSFChart(HSSFSheet hSSFSheet, ChartRecord chartRecord2) {
        this.chartRecord = chartRecord2;
        this.sheet = hSSFSheet;
    }

    private TextRecord createAllTextRecord() {
        TextRecord textRecord = new TextRecord();
        textRecord.setHorizontalAlignment((byte) 2);
        textRecord.setVerticalAlignment((byte) 2);
        textRecord.setDisplayMode(1);
        textRecord.setRgbColor(0);
        textRecord.setX(-37);
        textRecord.setY(-60);
        textRecord.setWidth(0);
        textRecord.setHeight(0);
        textRecord.setAutoColor(true);
        textRecord.setShowKey(false);
        textRecord.setShowValue(true);
        textRecord.setVertical(false);
        textRecord.setAutoGeneratedText(true);
        textRecord.setGenerated(true);
        textRecord.setAutoLabelDeleted(false);
        textRecord.setAutoBackground(true);
        textRecord.setRotation(0);
        textRecord.setShowCategoryLabelAsPercentage(false);
        textRecord.setShowValueAsPercentage(false);
        textRecord.setShowBubbleSizes(false);
        textRecord.setShowLabel(false);
        textRecord.setIndexOfColorValue(77);
        textRecord.setDataLabelPlacement(0);
        textRecord.setTextRotation(0);
        return textRecord;
    }

    private AreaFormatRecord createAreaFormatRecord1() {
        AreaFormatRecord areaFormatRecord = new AreaFormatRecord();
        areaFormatRecord.setForegroundColor(16777215);
        areaFormatRecord.setBackgroundColor(0);
        areaFormatRecord.setPattern(1);
        areaFormatRecord.setAutomatic(true);
        areaFormatRecord.setInvert(false);
        areaFormatRecord.setForecolorIndex(78);
        areaFormatRecord.setBackcolorIndex(77);
        return areaFormatRecord;
    }

    private AreaFormatRecord createAreaFormatRecord2() {
        AreaFormatRecord areaFormatRecord = new AreaFormatRecord();
        areaFormatRecord.setForegroundColor(12632256);
        areaFormatRecord.setBackgroundColor(0);
        areaFormatRecord.setPattern(1);
        areaFormatRecord.setAutomatic(false);
        areaFormatRecord.setInvert(false);
        areaFormatRecord.setForecolorIndex(22);
        areaFormatRecord.setBackcolorIndex(79);
        return areaFormatRecord;
    }

    private AxisLineFormatRecord createAxisLineFormatRecord(short s) {
        AxisLineFormatRecord axisLineFormatRecord = new AxisLineFormatRecord();
        axisLineFormatRecord.setAxisType(s);
        return axisLineFormatRecord;
    }

    private AxisOptionsRecord createAxisOptionsRecord() {
        AxisOptionsRecord axisOptionsRecord = new AxisOptionsRecord();
        axisOptionsRecord.setMinimumCategory(-28644);
        axisOptionsRecord.setMaximumCategory(-28715);
        axisOptionsRecord.setMajorUnitValue(2);
        axisOptionsRecord.setMajorUnit(0);
        axisOptionsRecord.setMinorUnitValue(1);
        axisOptionsRecord.setMinorUnit(0);
        axisOptionsRecord.setBaseUnit(0);
        axisOptionsRecord.setCrossingPoint(-28644);
        axisOptionsRecord.setDefaultMinimum(true);
        axisOptionsRecord.setDefaultMaximum(true);
        axisOptionsRecord.setDefaultMajor(true);
        axisOptionsRecord.setDefaultMinorUnit(true);
        axisOptionsRecord.setIsDate(true);
        axisOptionsRecord.setDefaultBase(true);
        axisOptionsRecord.setDefaultCross(true);
        axisOptionsRecord.setDefaultDateSettings(true);
        return axisOptionsRecord;
    }

    private AxisParentRecord createAxisParentRecord() {
        AxisParentRecord axisParentRecord = new AxisParentRecord();
        axisParentRecord.setAxisType(0);
        axisParentRecord.setX(479);
        axisParentRecord.setY(221);
        axisParentRecord.setWidth(2995);
        axisParentRecord.setHeight(2902);
        return axisParentRecord;
    }

    private AxisRecord createAxisRecord(short s) {
        AxisRecord axisRecord = new AxisRecord();
        axisRecord.setAxisType(s);
        return axisRecord;
    }

    private void createAxisRecords(List<Record> list) {
        list.add(createAxisParentRecord());
        list.add(createBeginRecord());
        list.add(createAxisRecord(0));
        list.add(createBeginRecord());
        list.add(createCategorySeriesAxisRecord());
        list.add(createAxisOptionsRecord());
        list.add(createTickRecord1());
        list.add(createEndRecord());
        list.add(createAxisRecord(1));
        list.add(createBeginRecord());
        list.add(createValueRangeRecord());
        list.add(createTickRecord2());
        list.add(createAxisLineFormatRecord(1));
        list.add(createLineFormatRecord(false));
        list.add(createEndRecord());
        list.add(createPlotAreaRecord());
        list.add(createFrameRecord2());
        list.add(createBeginRecord());
        list.add(createLineFormatRecord2());
        list.add(createAreaFormatRecord2());
        list.add(createEndRecord());
        list.add(createChartFormatRecord());
        list.add(createBeginRecord());
        list.add(createBarRecord());
        list.add(createLegendRecord());
        list.add(createBeginRecord());
        list.add(createTextRecord());
        list.add(createBeginRecord());
        list.add(createLinkedDataRecord());
        list.add(createEndRecord());
        list.add(createEndRecord());
        list.add(createEndRecord());
        list.add(createEndRecord());
    }

    private AxisUsedRecord createAxisUsedRecord(short s) {
        AxisUsedRecord axisUsedRecord = new AxisUsedRecord();
        axisUsedRecord.setNumAxis(s);
        return axisUsedRecord;
    }

    private BOFRecord createBOFRecord() {
        BOFRecord bOFRecord = new BOFRecord();
        bOFRecord.setVersion(600);
        bOFRecord.setType(20);
        bOFRecord.setBuild(7422);
        bOFRecord.setBuildYear(1997);
        bOFRecord.setHistoryBitMask(16585);
        bOFRecord.setRequiredVersion(106);
        return bOFRecord;
    }

    private BarRecord createBarRecord() {
        BarRecord barRecord = new BarRecord();
        barRecord.setBarSpace(0);
        barRecord.setCategorySpace(EscherAggregate.ST_TEXTCIRCLEPOUR);
        barRecord.setHorizontal(false);
        barRecord.setStacked(false);
        barRecord.setDisplayAsPercentage(false);
        barRecord.setShadow(false);
        return barRecord;
    }

    private BeginRecord createBeginRecord() {
        return new BeginRecord();
    }

    private LinkedDataRecord createCategoriesLinkedDataRecord() {
        LinkedDataRecord linkedDataRecord = new LinkedDataRecord();
        linkedDataRecord.setLinkType((byte) 2);
        linkedDataRecord.setReferenceType((byte) 2);
        linkedDataRecord.setCustomNumberFormat(false);
        linkedDataRecord.setIndexNumberFmtRecord(0);
        linkedDataRecord.setFormulaOfLink(new Ptg[]{new Area3DPtg(0, 31, 1, 1, false, false, false, false, 0)});
        return linkedDataRecord;
    }

    private CategorySeriesAxisRecord createCategorySeriesAxisRecord() {
        CategorySeriesAxisRecord categorySeriesAxisRecord = new CategorySeriesAxisRecord();
        categorySeriesAxisRecord.setCrossingPoint(1);
        categorySeriesAxisRecord.setLabelFrequency(1);
        categorySeriesAxisRecord.setTickMarkFrequency(1);
        categorySeriesAxisRecord.setValueAxisCrossing(true);
        categorySeriesAxisRecord.setCrossesFarRight(false);
        categorySeriesAxisRecord.setReversed(false);
        return categorySeriesAxisRecord;
    }

    private ChartFormatRecord createChartFormatRecord() {
        ChartFormatRecord chartFormatRecord = new ChartFormatRecord();
        chartFormatRecord.setXPosition(0);
        chartFormatRecord.setYPosition(0);
        chartFormatRecord.setWidth(0);
        chartFormatRecord.setHeight(0);
        chartFormatRecord.setVaryDisplayPattern(false);
        return chartFormatRecord;
    }

    private ChartRecord createChartRecord(int i2, int i3, int i4, int i5) {
        ChartRecord chartRecord2 = new ChartRecord();
        chartRecord2.setX(i2);
        chartRecord2.setY(i3);
        chartRecord2.setWidth(i4);
        chartRecord2.setHeight(i5);
        return chartRecord2;
    }

    private DataFormatRecord createDataFormatRecord() {
        DataFormatRecord dataFormatRecord = new DataFormatRecord();
        dataFormatRecord.setPointNumber(-1);
        dataFormatRecord.setSeriesIndex(0);
        dataFormatRecord.setSeriesNumber(0);
        dataFormatRecord.setUseExcel4Colors(false);
        return dataFormatRecord;
    }

    private DefaultDataLabelTextPropertiesRecord createDefaultTextRecord(short s) {
        DefaultDataLabelTextPropertiesRecord defaultDataLabelTextPropertiesRecord = new DefaultDataLabelTextPropertiesRecord();
        defaultDataLabelTextPropertiesRecord.setCategoryDataType(s);
        return defaultDataLabelTextPropertiesRecord;
    }

    private DimensionsRecord createDimensionsRecord() {
        DimensionsRecord dimensionsRecord = new DimensionsRecord();
        dimensionsRecord.setFirstRow(0);
        dimensionsRecord.setLastRow(31);
        dimensionsRecord.setFirstCol(0);
        dimensionsRecord.setLastCol(1);
        return dimensionsRecord;
    }

    private LinkedDataRecord createDirectLinkRecord() {
        LinkedDataRecord linkedDataRecord = new LinkedDataRecord();
        linkedDataRecord.setLinkType((byte) 0);
        linkedDataRecord.setReferenceType((byte) 1);
        linkedDataRecord.setCustomNumberFormat(false);
        linkedDataRecord.setIndexNumberFmtRecord(0);
        linkedDataRecord.setFormulaOfLink(null);
        return linkedDataRecord;
    }

    private EndRecord createEndRecord() {
        return new EndRecord();
    }

    private FontBasisRecord createFontBasisRecord1() {
        FontBasisRecord fontBasisRecord = new FontBasisRecord();
        fontBasisRecord.setXBasis(9120);
        fontBasisRecord.setYBasis(5640);
        fontBasisRecord.setHeightBasis(200);
        fontBasisRecord.setScale(0);
        fontBasisRecord.setIndexToFontTable(5);
        return fontBasisRecord;
    }

    private FontBasisRecord createFontBasisRecord2() {
        FontBasisRecord createFontBasisRecord1 = createFontBasisRecord1();
        createFontBasisRecord1.setIndexToFontTable(6);
        return createFontBasisRecord1;
    }

    private FontIndexRecord createFontIndexRecord(int i2) {
        FontIndexRecord fontIndexRecord = new FontIndexRecord();
        fontIndexRecord.setFontIndex((short) i2);
        return fontIndexRecord;
    }

    private FrameRecord createFrameRecord1() {
        FrameRecord frameRecord = new FrameRecord();
        frameRecord.setBorderType(0);
        frameRecord.setAutoSize(false);
        frameRecord.setAutoPosition(true);
        return frameRecord;
    }

    private FrameRecord createFrameRecord2() {
        FrameRecord frameRecord = new FrameRecord();
        frameRecord.setBorderType(0);
        frameRecord.setAutoSize(true);
        frameRecord.setAutoPosition(true);
        return frameRecord;
    }

    private HCenterRecord createHCenterRecord() {
        HCenterRecord hCenterRecord = new HCenterRecord();
        hCenterRecord.setHCenter(false);
        return hCenterRecord;
    }

    private LegendRecord createLegendRecord() {
        LegendRecord legendRecord2 = new LegendRecord();
        legendRecord2.setXAxisUpperLeft(3542);
        legendRecord2.setYAxisUpperLeft(1566);
        legendRecord2.setXSize(437);
        legendRecord2.setYSize(213);
        legendRecord2.setType((byte) 3);
        legendRecord2.setSpacing((byte) 1);
        legendRecord2.setAutoPosition(true);
        legendRecord2.setAutoSeries(true);
        legendRecord2.setAutoXPositioning(true);
        legendRecord2.setAutoYPositioning(true);
        legendRecord2.setVertical(true);
        legendRecord2.setDataTable(false);
        return legendRecord2;
    }

    private LineFormatRecord createLineFormatRecord(boolean z) {
        LineFormatRecord lineFormatRecord = new LineFormatRecord();
        lineFormatRecord.setLineColor(0);
        lineFormatRecord.setLinePattern(0);
        lineFormatRecord.setWeight(-1);
        lineFormatRecord.setAuto(true);
        lineFormatRecord.setDrawTicks(z);
        lineFormatRecord.setColourPaletteIndex(77);
        return lineFormatRecord;
    }

    private LineFormatRecord createLineFormatRecord2() {
        LineFormatRecord lineFormatRecord = new LineFormatRecord();
        lineFormatRecord.setLineColor(8421504);
        lineFormatRecord.setLinePattern(0);
        lineFormatRecord.setWeight(0);
        lineFormatRecord.setAuto(false);
        lineFormatRecord.setDrawTicks(false);
        lineFormatRecord.setUnknown(false);
        lineFormatRecord.setColourPaletteIndex(23);
        return lineFormatRecord;
    }

    private LinkedDataRecord createLinkedDataRecord() {
        LinkedDataRecord linkedDataRecord = new LinkedDataRecord();
        linkedDataRecord.setLinkType((byte) 0);
        linkedDataRecord.setReferenceType((byte) 1);
        linkedDataRecord.setCustomNumberFormat(false);
        linkedDataRecord.setIndexNumberFmtRecord(0);
        linkedDataRecord.setFormulaOfLink(null);
        return linkedDataRecord;
    }

    private UnknownRecord createMSDrawingObjectRecord() {
        return new UnknownRecord(236, new byte[]{15, 0, 2, Lucene3xFields.PreTermsEnum.UTF8_NON_BMP_LEAD, -64, 0, 0, 0, 16, 0, 8, Lucene3xFields.PreTermsEnum.UTF8_NON_BMP_LEAD, 8, 0, 0, 0, 2, 0, 0, 0, 2, 4, 0, 0, 15, 0, 3, Lucene3xFields.PreTermsEnum.UTF8_NON_BMP_LEAD, -88, 0, 0, 0, 15, 0, 4, Lucene3xFields.PreTermsEnum.UTF8_NON_BMP_LEAD, 40, 0, 0, 0, 1, 0, 9, Lucene3xFields.PreTermsEnum.UTF8_NON_BMP_LEAD, 16, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 0, 10, Lucene3xFields.PreTermsEnum.UTF8_NON_BMP_LEAD, 8, 0, 0, 0, 0, 4, 0, 0, 5, 0, 0, 0, 15, 0, 4, Lucene3xFields.PreTermsEnum.UTF8_NON_BMP_LEAD, 112, 0, 0, 0, -110, 12, 10, Lucene3xFields.PreTermsEnum.UTF8_NON_BMP_LEAD, 8, 0, 0, 0, 2, 4, 0, 0, 0, 10, 0, 0, -109, 0, 11, Lucene3xFields.PreTermsEnum.UTF8_NON_BMP_LEAD, 54, 0, 0, 0, Byte.MAX_VALUE, 0, 4, 1, 4, 1, -65, 0, 8, 0, 8, 0, -127, 1, 78, 0, 0, 8, -125, 1, 77, 0, 0, 8, -65, 1, 16, 0, 17, 0, -64, 1, 77, 0, 0, 8, -1, 1, 8, 0, 8, 0, 63, 2, 0, 0, 2, 0, -65, 3, 0, 0, 8, 0, 0, 0, 16, Lucene3xFields.PreTermsEnum.UTF8_NON_BMP_LEAD, 18, 0, 0, 0, 0, 0, 4, 0, -64, 2, 10, 0, -12, 0, 14, 0, 102, 1, 32, 0, -23, 0, 0, 0, 17, Lucene3xFields.PreTermsEnum.UTF8_NON_BMP_LEAD, 0, 0, 0, 0});
    }

    private UnknownRecord createOBJRecord() {
        return new UnknownRecord(93, new byte[]{21, 0, 18, 0, 5, 0, 2, 0, 17, 96, 0, 0, 0, 0, -72, 3, -121, 3, 0, 0, 0, 0, 0, 0, 0, 0});
    }

    private PlotAreaRecord createPlotAreaRecord() {
        return new PlotAreaRecord();
    }

    private PlotGrowthRecord createPlotGrowthRecord(int i2, int i3) {
        PlotGrowthRecord plotGrowthRecord = new PlotGrowthRecord();
        plotGrowthRecord.setHorizontalScale(i2);
        plotGrowthRecord.setVerticalScale(i3);
        return plotGrowthRecord;
    }

    private PrintSetupRecord createPrintSetupRecord() {
        PrintSetupRecord printSetupRecord = new PrintSetupRecord();
        printSetupRecord.setPaperSize(0);
        printSetupRecord.setScale(18);
        printSetupRecord.setPageStart(1);
        printSetupRecord.setFitWidth(1);
        printSetupRecord.setFitHeight(1);
        printSetupRecord.setLeftToRight(false);
        printSetupRecord.setLandscape(false);
        printSetupRecord.setValidSettings(true);
        printSetupRecord.setNoColor(false);
        printSetupRecord.setDraft(false);
        printSetupRecord.setNotes(false);
        printSetupRecord.setNoOrientation(false);
        printSetupRecord.setUsePage(false);
        printSetupRecord.setHResolution(0);
        printSetupRecord.setVResolution(0);
        printSetupRecord.setHeaderMargin(0.5d);
        printSetupRecord.setFooterMargin(0.5d);
        printSetupRecord.setCopies(15);
        return printSetupRecord;
    }

    private SCLRecord createSCLRecord(short s, short s2) {
        SCLRecord sCLRecord = new SCLRecord();
        sCLRecord.setDenominator(s2);
        sCLRecord.setNumerator(s);
        return sCLRecord;
    }

    private SeriesIndexRecord createSeriesIndexRecord(int i2) {
        SeriesIndexRecord seriesIndexRecord = new SeriesIndexRecord();
        seriesIndexRecord.setIndex((short) i2);
        return seriesIndexRecord;
    }

    private SeriesRecord createSeriesRecord() {
        SeriesRecord seriesRecord = new SeriesRecord();
        seriesRecord.setCategoryDataType(1);
        seriesRecord.setValuesDataType(1);
        seriesRecord.setNumCategories(32);
        seriesRecord.setNumValues(31);
        seriesRecord.setBubbleSeriesType(1);
        seriesRecord.setNumBubbleValues(0);
        return seriesRecord;
    }

    private SeriesToChartGroupRecord createSeriesToChartGroupRecord() {
        return new SeriesToChartGroupRecord();
    }

    private SheetPropertiesRecord createSheetPropsRecord() {
        SheetPropertiesRecord sheetPropertiesRecord = new SheetPropertiesRecord();
        sheetPropertiesRecord.setChartTypeManuallyFormatted(false);
        sheetPropertiesRecord.setPlotVisibleOnly(true);
        sheetPropertiesRecord.setDoNotSizeWithWindow(false);
        sheetPropertiesRecord.setDefaultPlotDimensions(true);
        sheetPropertiesRecord.setAutoPlotArea(false);
        return sheetPropertiesRecord;
    }

    private TextRecord createTextRecord() {
        TextRecord textRecord = new TextRecord();
        textRecord.setHorizontalAlignment((byte) 2);
        textRecord.setVerticalAlignment((byte) 2);
        textRecord.setDisplayMode(1);
        textRecord.setRgbColor(0);
        textRecord.setX(-37);
        textRecord.setY(-60);
        textRecord.setWidth(0);
        textRecord.setHeight(0);
        textRecord.setAutoColor(true);
        textRecord.setShowKey(false);
        textRecord.setShowValue(false);
        textRecord.setVertical(false);
        textRecord.setAutoGeneratedText(true);
        textRecord.setGenerated(true);
        textRecord.setAutoLabelDeleted(false);
        textRecord.setAutoBackground(true);
        textRecord.setRotation(0);
        textRecord.setShowCategoryLabelAsPercentage(false);
        textRecord.setShowValueAsPercentage(false);
        textRecord.setShowBubbleSizes(false);
        textRecord.setShowLabel(false);
        textRecord.setIndexOfColorValue(77);
        textRecord.setDataLabelPlacement(0);
        textRecord.setTextRotation(0);
        return textRecord;
    }

    private TickRecord createTickRecord1() {
        TickRecord tickRecord = new TickRecord();
        tickRecord.setMajorTickType((byte) 2);
        tickRecord.setMinorTickType((byte) 0);
        tickRecord.setLabelPosition((byte) 3);
        tickRecord.setBackground((byte) 1);
        tickRecord.setLabelColorRgb(0);
        tickRecord.setZero1(0);
        tickRecord.setZero2(0);
        tickRecord.setZero3(45);
        tickRecord.setAutorotate(true);
        tickRecord.setAutoTextBackground(true);
        tickRecord.setRotation(0);
        tickRecord.setAutorotate(true);
        tickRecord.setTickColor(77);
        return tickRecord;
    }

    private TickRecord createTickRecord2() {
        TickRecord createTickRecord1 = createTickRecord1();
        createTickRecord1.setZero3(0);
        return createTickRecord1;
    }

    private LinkedDataRecord createTitleLinkedDataRecord() {
        LinkedDataRecord linkedDataRecord = new LinkedDataRecord();
        linkedDataRecord.setLinkType((byte) 0);
        linkedDataRecord.setReferenceType((byte) 1);
        linkedDataRecord.setCustomNumberFormat(false);
        linkedDataRecord.setIndexNumberFmtRecord(0);
        linkedDataRecord.setFormulaOfLink(null);
        return linkedDataRecord;
    }

    private UnitsRecord createUnitsRecord() {
        UnitsRecord unitsRecord = new UnitsRecord();
        unitsRecord.setUnits(0);
        return unitsRecord;
    }

    private TextRecord createUnknownTextRecord() {
        TextRecord textRecord = new TextRecord();
        textRecord.setHorizontalAlignment((byte) 2);
        textRecord.setVerticalAlignment((byte) 2);
        textRecord.setDisplayMode(1);
        textRecord.setRgbColor(0);
        textRecord.setX(-37);
        textRecord.setY(-60);
        textRecord.setWidth(0);
        textRecord.setHeight(0);
        textRecord.setAutoColor(true);
        textRecord.setShowKey(false);
        textRecord.setShowValue(false);
        textRecord.setVertical(false);
        textRecord.setAutoGeneratedText(true);
        textRecord.setGenerated(true);
        textRecord.setAutoLabelDeleted(false);
        textRecord.setAutoBackground(true);
        textRecord.setRotation(0);
        textRecord.setShowCategoryLabelAsPercentage(false);
        textRecord.setShowValueAsPercentage(false);
        textRecord.setShowBubbleSizes(false);
        textRecord.setShowLabel(false);
        textRecord.setIndexOfColorValue(77);
        textRecord.setDataLabelPlacement(11088);
        textRecord.setTextRotation(0);
        return textRecord;
    }

    private VCenterRecord createVCenterRecord() {
        VCenterRecord vCenterRecord = new VCenterRecord();
        vCenterRecord.setVCenter(false);
        return vCenterRecord;
    }

    private ValueRangeRecord createValueRangeRecord() {
        ValueRangeRecord valueRangeRecord = new ValueRangeRecord();
        valueRangeRecord.setMinimumAxisValue(NumericFunction.LOG_10_TO_BASE_e);
        valueRangeRecord.setMaximumAxisValue(NumericFunction.LOG_10_TO_BASE_e);
        valueRangeRecord.setMajorIncrement(NumericFunction.LOG_10_TO_BASE_e);
        valueRangeRecord.setMinorIncrement(NumericFunction.LOG_10_TO_BASE_e);
        valueRangeRecord.setCategoryAxisCross(NumericFunction.LOG_10_TO_BASE_e);
        valueRangeRecord.setAutomaticMinimum(true);
        valueRangeRecord.setAutomaticMaximum(true);
        valueRangeRecord.setAutomaticMajor(true);
        valueRangeRecord.setAutomaticMinor(true);
        valueRangeRecord.setAutomaticCategoryCrossing(true);
        valueRangeRecord.setLogarithmicScale(false);
        valueRangeRecord.setValuesInReverse(false);
        valueRangeRecord.setCrossCategoryAxisAtMaximum(false);
        valueRangeRecord.setReserved(true);
        return valueRangeRecord;
    }

    private LinkedDataRecord createValuesLinkedDataRecord() {
        LinkedDataRecord linkedDataRecord = new LinkedDataRecord();
        linkedDataRecord.setLinkType((byte) 1);
        linkedDataRecord.setReferenceType((byte) 2);
        linkedDataRecord.setCustomNumberFormat(false);
        linkedDataRecord.setIndexNumberFmtRecord(0);
        linkedDataRecord.setFormulaOfLink(new Ptg[]{new Area3DPtg(0, 31, 0, 0, false, false, false, false, 0)});
        return linkedDataRecord;
    }

    public static HSSFChart[] getSheetCharts(HSSFSheet hSSFSheet) {
        ArrayList arrayList = new ArrayList();
        HSSFSeries hSSFSeries = null;
        HSSFChart hSSFChart = null;
        for (RecordBase recordBase : hSSFSheet.getSheet().getRecords()) {
            if (recordBase instanceof ChartRecord) {
                hSSFChart = new HSSFChart(hSSFSheet, (ChartRecord) recordBase);
                arrayList.add(hSSFChart);
                hSSFSeries = null;
            } else if (recordBase instanceof LinkedDataRecord) {
                LinkedDataRecord linkedDataRecord = (LinkedDataRecord) recordBase;
                if (hSSFSeries != null) {
                    hSSFSeries.insertData(linkedDataRecord);
                }
            }
            if (hSSFChart != null) {
                if (recordBase instanceof LegendRecord) {
                    hSSFChart.legendRecord = (LegendRecord) recordBase;
                } else if (recordBase instanceof SeriesRecord) {
                    hSSFSeries = new HSSFSeries((SeriesRecord) recordBase);
                    hSSFChart.series.add(hSSFSeries);
                } else if (recordBase instanceof ChartTitleFormatRecord) {
                    hSSFChart.chartTitleFormat = (ChartTitleFormatRecord) recordBase;
                } else if (recordBase instanceof SeriesTextRecord) {
                    SeriesTextRecord seriesTextRecord = (SeriesTextRecord) recordBase;
                    if (hSSFChart.legendRecord != null || hSSFChart.series.size() <= 0) {
                        hSSFChart.chartTitleText = seriesTextRecord;
                    } else {
                        List<HSSFSeries> list = hSSFChart.series;
                        list.get(list.size() - 1).seriesTitleText = seriesTextRecord;
                    }
                } else if (recordBase instanceof ValueRangeRecord) {
                    hSSFChart.valueRanges.add((ValueRangeRecord) recordBase);
                } else if (recordBase instanceof Record) {
                    Record record = (Record) recordBase;
                    HSSFChartType[] values = HSSFChartType.values();
                    int length = values.length;
                    int i2 = 0;
                    while (true) {
                        if (i2 >= length) {
                            break;
                        }
                        HSSFChartType hSSFChartType = values[i2];
                        if (hSSFChartType != HSSFChartType.Unknown && record.getSid() == hSSFChartType.getSid()) {
                            hSSFChart.type = hSSFChartType;
                            break;
                        }
                        i2++;
                    }
                }
            }
        }
        return (HSSFChart[]) arrayList.toArray(new HSSFChart[arrayList.size()]);
    }

    public void createBarChart(HSSFWorkbook hSSFWorkbook, HSSFSheet hSSFSheet) {
        ArrayList arrayList = new ArrayList();
        arrayList.add(createMSDrawingObjectRecord());
        arrayList.add(createOBJRecord());
        arrayList.add(createBOFRecord());
        arrayList.add(new HeaderRecord(""));
        arrayList.add(new FooterRecord(""));
        arrayList.add(createHCenterRecord());
        arrayList.add(createVCenterRecord());
        arrayList.add(createPrintSetupRecord());
        arrayList.add(createFontBasisRecord1());
        arrayList.add(createFontBasisRecord2());
        arrayList.add(new ProtectRecord(false));
        arrayList.add(createUnitsRecord());
        arrayList.add(createChartRecord(0, 0, 30434904, 19031616));
        arrayList.add(createBeginRecord());
        arrayList.add(createSCLRecord(1, 1));
        arrayList.add(createPlotGrowthRecord(65536, 65536));
        arrayList.add(createFrameRecord1());
        arrayList.add(createBeginRecord());
        arrayList.add(createLineFormatRecord(true));
        arrayList.add(createAreaFormatRecord1());
        arrayList.add(createEndRecord());
        arrayList.add(createSeriesRecord());
        arrayList.add(createBeginRecord());
        arrayList.add(createTitleLinkedDataRecord());
        arrayList.add(createValuesLinkedDataRecord());
        arrayList.add(createCategoriesLinkedDataRecord());
        arrayList.add(createDataFormatRecord());
        arrayList.add(createSeriesToChartGroupRecord());
        arrayList.add(createEndRecord());
        arrayList.add(createSheetPropsRecord());
        arrayList.add(createDefaultTextRecord(2));
        arrayList.add(createAllTextRecord());
        arrayList.add(createBeginRecord());
        arrayList.add(createFontIndexRecord(5));
        arrayList.add(createDirectLinkRecord());
        arrayList.add(createEndRecord());
        arrayList.add(createDefaultTextRecord(3));
        arrayList.add(createUnknownTextRecord());
        arrayList.add(createBeginRecord());
        arrayList.add(createFontIndexRecord(6));
        arrayList.add(createDirectLinkRecord());
        arrayList.add(createEndRecord());
        arrayList.add(createAxisUsedRecord(1));
        createAxisRecords(arrayList);
        arrayList.add(createEndRecord());
        arrayList.add(createDimensionsRecord());
        arrayList.add(createSeriesIndexRecord(2));
        arrayList.add(createSeriesIndexRecord(1));
        arrayList.add(createSeriesIndexRecord(3));
        arrayList.add(EOFRecord.instance);
        hSSFSheet.insertChartRecords(arrayList);
        hSSFWorkbook.insertChartRecord();
    }

    /* JADX DEBUG: Failed to insert an additional move for type inference into block B:74:0x0071 */
    public HSSFSeries createSeries() {
        SeriesRecord seriesRecord;
        ArrayList arrayList = new ArrayList();
        List<RecordBase> records = this.sheet.getSheet().getRecords();
        int i2 = 0;
        int i3 = 0;
        boolean z = false;
        int i4 = 0;
        int i5 = -1;
        int i6 = -1;
        int i7 = -1;
        int i8 = -1;
        for (RecordBase recordBase : records) {
            i2++;
            if (!(recordBase instanceof BeginRecord)) {
                if (recordBase instanceof EndRecord) {
                    i3--;
                    if (i5 == i3) {
                        if (!z) {
                            arrayList.add(recordBase);
                            i7 = i2;
                            z = true;
                        } else {
                            i7 = i2;
                        }
                        i5 = -1;
                    }
                    if (i8 == i3) {
                        break;
                    }
                }
            } else {
                i3++;
            }
            if (recordBase instanceof ChartRecord) {
                if (recordBase == this.chartRecord) {
                    i6 = i2;
                    i8 = i3;
                }
            } else if ((recordBase instanceof SeriesRecord) && i6 != -1) {
                i4++;
                i5 = i3;
            }
            if (i5 != -1 && !z) {
                arrayList.add(recordBase);
            }
        }
        if (i7 == -1) {
            return null;
        }
        int i9 = i7 + 1;
        ArrayList arrayList2 = new ArrayList();
        Iterator it = arrayList.iterator();
        HSSFSeries hSSFSeries = null;
        while (it.hasNext()) {
            RecordBase recordBase2 = (RecordBase) it.next();
            if (recordBase2 instanceof BeginRecord) {
                hSSFSeries = hSSFSeries;
                seriesRecord = new BeginRecord();
            } else if (recordBase2 instanceof EndRecord) {
                hSSFSeries = hSSFSeries;
                seriesRecord = new EndRecord();
            } else if (recordBase2 instanceof SeriesRecord) {
                SeriesRecord seriesRecord2 = (SeriesRecord) ((SeriesRecord) recordBase2).clone();
                hSSFSeries = new HSSFSeries(seriesRecord2);
                seriesRecord = seriesRecord2;
            } else if (recordBase2 instanceof LinkedDataRecord) {
                LinkedDataRecord clone = ((LinkedDataRecord) recordBase2).clone();
                hSSFSeries = hSSFSeries;
                seriesRecord = clone;
                if (hSSFSeries != null) {
                    hSSFSeries.insertData(clone);
                    hSSFSeries = hSSFSeries;
                    seriesRecord = clone;
                }
            } else if (recordBase2 instanceof DataFormatRecord) {
                DataFormatRecord clone2 = ((DataFormatRecord) recordBase2).clone();
                short s = (short) i4;
                clone2.setSeriesIndex(s);
                clone2.setSeriesNumber(s);
                hSSFSeries = hSSFSeries;
                seriesRecord = clone2;
            } else if (recordBase2 instanceof SeriesTextRecord) {
                SeriesTextRecord seriesTextRecord = (SeriesTextRecord) ((SeriesTextRecord) recordBase2).clone();
                hSSFSeries = hSSFSeries;
                seriesRecord = seriesTextRecord;
                if (hSSFSeries != null) {
                    hSSFSeries.setSeriesTitleText(seriesTextRecord);
                    hSSFSeries = hSSFSeries;
                    seriesRecord = seriesTextRecord;
                }
            } else if (recordBase2 instanceof Record) {
                hSSFSeries = hSSFSeries;
                seriesRecord = (Record) ((Record) recordBase2).clone();
            } else {
                seriesRecord = null;
                hSSFSeries = hSSFSeries;
            }
            if (seriesRecord != null) {
                arrayList2.add(seriesRecord == 1 ? 1 : 0);
            }
        }
        if (hSSFSeries == null) {
            return null;
        }
        Iterator it2 = arrayList2.iterator();
        while (it2.hasNext()) {
            records.add(i9, (RecordBase) it2.next());
            i9++;
        }
        return hSSFSeries;
    }

    public int getChartHeight() {
        return this.chartRecord.getHeight();
    }

    public String getChartTitle() {
        SeriesTextRecord seriesTextRecord = this.chartTitleText;
        if (seriesTextRecord != null) {
            return seriesTextRecord.getText();
        }
        return null;
    }

    public int getChartWidth() {
        return this.chartRecord.getWidth();
    }

    public int getChartX() {
        return this.chartRecord.getX();
    }

    public int getChartY() {
        return this.chartRecord.getY();
    }

    public HSSFSeries[] getSeries() {
        List<HSSFSeries> list = this.series;
        return (HSSFSeries[]) list.toArray(new HSSFSeries[list.size()]);
    }

    public HSSFChartType getType() {
        return this.type;
    }

    public boolean removeSeries(HSSFSeries hSSFSeries) {
        Iterator<RecordBase> it = this.sheet.getSheet().getRecords().iterator();
        int i2 = 0;
        int i3 = -1;
        boolean z = false;
        boolean z2 = false;
        boolean z3 = false;
        int i4 = -1;
        int i5 = -1;
        while (it.hasNext()) {
            RecordBase next = it.next();
            if (!(next instanceof BeginRecord)) {
                if (next instanceof EndRecord) {
                    i2--;
                    if (i3 == i2) {
                        if (z) {
                            it.remove();
                            i3 = -1;
                            z = false;
                            z3 = true;
                        } else {
                            i3 = -1;
                        }
                    }
                    if (i4 == i2) {
                        break;
                    }
                }
            } else {
                i2++;
            }
            if (next instanceof ChartRecord) {
                if (next == this.chartRecord) {
                    i4 = i2;
                    z2 = true;
                }
            } else if (next instanceof SeriesRecord) {
                if (z2) {
                    if (hSSFSeries.series == next) {
                        i3 = i2;
                        z = true;
                    } else {
                        i5++;
                    }
                }
            } else if ((next instanceof DataFormatRecord) && z2 && !z) {
                DataFormatRecord dataFormatRecord = (DataFormatRecord) next;
                short s = (short) i5;
                dataFormatRecord.setSeriesIndex(s);
                dataFormatRecord.setSeriesNumber(s);
            }
            if (z) {
                it.remove();
            }
        }
        return z3;
    }

    public void setChartHeight(int i2) {
        this.chartRecord.setHeight(i2);
    }

    public void setChartTitle(String str) {
        SeriesTextRecord seriesTextRecord = this.chartTitleText;
        if (seriesTextRecord != null) {
            seriesTextRecord.setText(str);
            return;
        }
        throw new IllegalStateException("No chart title found to change");
    }

    public void setChartWidth(int i2) {
        this.chartRecord.setWidth(i2);
    }

    public void setChartX(int i2) {
        this.chartRecord.setX(i2);
    }

    public void setChartY(int i2) {
        this.chartRecord.setY(i2);
    }

    public void setValueRange(int i2, Double d2, Double d3, Double d4, Double d5) {
        ValueRangeRecord valueRangeRecord = this.valueRanges.get(i2);
        if (valueRangeRecord != null) {
            if (d2 != null) {
                valueRangeRecord.setAutomaticMinimum(d2.isNaN());
                valueRangeRecord.setMinimumAxisValue(d2.doubleValue());
            }
            if (d3 != null) {
                valueRangeRecord.setAutomaticMaximum(d3.isNaN());
                valueRangeRecord.setMaximumAxisValue(d3.doubleValue());
            }
            if (d4 != null) {
                valueRangeRecord.setAutomaticMajor(d4.isNaN());
                valueRangeRecord.setMajorIncrement(d4.doubleValue());
            }
            if (d5 != null) {
                valueRangeRecord.setAutomaticMinor(d5.isNaN());
                valueRangeRecord.setMinorIncrement(d5.doubleValue());
            }
        }
    }
}
