package org.apache.poi.hssf.usermodel;

import org.apache.poi.ddf.EscherClientAnchorRecord;
import org.apache.poi.ddf.EscherRecord;
import org.apache.poi.ss.SpreadsheetVersion;
import org.apache.poi.ss.usermodel.ClientAnchor;

public final class HSSFClientAnchor extends HSSFAnchor implements ClientAnchor {
    public static final /* synthetic */ boolean $assertionsDisabled = false;
    public static final int MAX_COL = SpreadsheetVersion.EXCEL97.getLastColumnIndex();
    public static final int MAX_ROW = SpreadsheetVersion.EXCEL97.getLastRowIndex();
    public EscherClientAnchorRecord _escherClientAnchor;

    public HSSFClientAnchor(EscherClientAnchorRecord escherClientAnchorRecord) {
        this._escherClientAnchor = escherClientAnchorRecord;
    }

    private void checkRange(int i2, int i3, int i4, String str) {
        if (i2 < i3 || i2 > i4) {
            throw new IllegalArgumentException(str + " must be between " + i3 + " and " + i4 + ", but was: " + i2);
        }
    }

    private float getRowHeightInPoints(HSSFSheet hSSFSheet, int i2) {
        HSSFRow row = hSSFSheet.getRow(i2);
        if (row == null) {
            return hSSFSheet.getDefaultRowHeightInPoints();
        }
        return row.getHeightInPoints();
    }

    public static int unsignedValue(short s) {
        return s < 0 ? s + 65536 : s;
    }

    @Override // org.apache.poi.hssf.usermodel.HSSFAnchor
    public void createEscherAnchor() {
        this._escherClientAnchor = new EscherClientAnchorRecord();
    }

    public boolean equals(Object obj) {
        if (obj == null) {
            return false;
        }
        if (obj == this) {
            return true;
        }
        if (obj.getClass() != HSSFClientAnchor.class) {
            return false;
        }
        HSSFClientAnchor hSSFClientAnchor = (HSSFClientAnchor) obj;
        if (hSSFClientAnchor.getCol1() == getCol1() && hSSFClientAnchor.getCol2() == getCol2() && hSSFClientAnchor.getDx1() == getDx1() && hSSFClientAnchor.getDx2() == getDx2() && hSSFClientAnchor.getDy1() == getDy1() && hSSFClientAnchor.getDy2() == getDy2() && hSSFClientAnchor.getRow1() == getRow1() && hSSFClientAnchor.getRow2() == getRow2() && hSSFClientAnchor.getAnchorType() == getAnchorType()) {
            return true;
        }
        return false;
    }

    public float getAnchorHeightInPoints(HSSFSheet hSSFSheet) {
        int dy1 = getDy1();
        int dy2 = getDy2();
        int min = Math.min(getRow1(), getRow2());
        int max = Math.max(getRow1(), getRow2());
        if (min == max) {
            return (((float) (dy2 - dy1)) / 256.0f) * getRowHeightInPoints(hSSFSheet, max);
        }
        float rowHeightInPoints = ((256.0f - ((float) dy1)) / 256.0f) * getRowHeightInPoints(hSSFSheet, min);
        float f2 = 0.0f;
        while (true) {
            rowHeightInPoints += f2;
            min++;
            if (min >= max) {
                return rowHeightInPoints + ((((float) dy2) / 256.0f) * getRowHeightInPoints(hSSFSheet, max));
            }
            f2 = getRowHeightInPoints(hSSFSheet, min);
        }
    }

    @Override // org.apache.poi.ss.usermodel.ClientAnchor
    public ClientAnchor.AnchorType getAnchorType() {
        return ClientAnchor.AnchorType.byId(this._escherClientAnchor.getFlag());
    }

    @Override // org.apache.poi.ss.usermodel.ClientAnchor
    public short getCol1() {
        return this._escherClientAnchor.getCol1();
    }

    @Override // org.apache.poi.ss.usermodel.ClientAnchor
    public short getCol2() {
        return this._escherClientAnchor.getCol2();
    }

    @Override // org.apache.poi.ss.usermodel.ClientAnchor, org.apache.poi.ss.usermodel.ChildAnchor
    public int getDx1() {
        return this._escherClientAnchor.getDx1();
    }

    @Override // org.apache.poi.ss.usermodel.ClientAnchor, org.apache.poi.ss.usermodel.ChildAnchor
    public int getDx2() {
        return this._escherClientAnchor.getDx2();
    }

    @Override // org.apache.poi.ss.usermodel.ClientAnchor, org.apache.poi.ss.usermodel.ChildAnchor
    public int getDy1() {
        return this._escherClientAnchor.getDy1();
    }

    @Override // org.apache.poi.ss.usermodel.ClientAnchor, org.apache.poi.ss.usermodel.ChildAnchor
    public int getDy2() {
        return this._escherClientAnchor.getDy2();
    }

    @Override // org.apache.poi.hssf.usermodel.HSSFAnchor
    public EscherRecord getEscherAnchor() {
        return this._escherClientAnchor;
    }

    @Override // org.apache.poi.ss.usermodel.ClientAnchor
    public int getRow1() {
        return unsignedValue(this._escherClientAnchor.getRow1());
    }

    @Override // org.apache.poi.ss.usermodel.ClientAnchor
    public int getRow2() {
        return unsignedValue(this._escherClientAnchor.getRow2());
    }

    public int hashCode() {
        return 42;
    }

    @Override // org.apache.poi.hssf.usermodel.HSSFAnchor
    public boolean isHorizontallyFlipped() {
        return this._isHorizontallyFlipped;
    }

    @Override // org.apache.poi.hssf.usermodel.HSSFAnchor
    public boolean isVerticallyFlipped() {
        return this._isVerticallyFlipped;
    }

    public void setAnchor(short s, int i2, int i3, int i4, short s2, int i5, int i6, int i7) {
        checkRange(getDx1(), 0, 1023, "dx1");
        checkRange(getDx2(), 0, 1023, "dx2");
        checkRange(getDy1(), 0, 255, "dy1");
        checkRange(getDy2(), 0, 255, "dy2");
        checkRange(getCol1(), 0, MAX_COL, "col1");
        checkRange(getCol2(), 0, MAX_COL, "col2");
        checkRange(getRow1(), 0, MAX_ROW, "row1");
        checkRange(getRow2(), 0, MAX_ROW, "row2");
        setCol1(s);
        setRow1(i2);
        setDx1(i3);
        setDy1(i4);
        setCol2(s2);
        setRow2(i5);
        setDx2(i6);
        setDy2(i7);
    }

    @Override // org.apache.poi.ss.usermodel.ClientAnchor
    public void setAnchorType(ClientAnchor.AnchorType anchorType) {
        this._escherClientAnchor.setFlag(anchorType.value);
    }

    public void setCol1(short s) {
        checkRange(s, 0, MAX_COL, "col1");
        this._escherClientAnchor.setCol1(s);
    }

    public void setCol2(short s) {
        checkRange(s, 0, MAX_COL, "col2");
        this._escherClientAnchor.setCol2(s);
    }

    @Override // org.apache.poi.ss.usermodel.ClientAnchor, org.apache.poi.ss.usermodel.ChildAnchor
    public void setDx1(int i2) {
        this._escherClientAnchor.setDx1(Integer.valueOf(i2).shortValue());
    }

    @Override // org.apache.poi.ss.usermodel.ClientAnchor, org.apache.poi.ss.usermodel.ChildAnchor
    public void setDx2(int i2) {
        this._escherClientAnchor.setDx2(Integer.valueOf(i2).shortValue());
    }

    @Override // org.apache.poi.ss.usermodel.ClientAnchor, org.apache.poi.ss.usermodel.ChildAnchor
    public void setDy1(int i2) {
        this._escherClientAnchor.setDy1(Integer.valueOf(i2).shortValue());
    }

    @Override // org.apache.poi.ss.usermodel.ClientAnchor, org.apache.poi.ss.usermodel.ChildAnchor
    public void setDy2(int i2) {
        this._escherClientAnchor.setDy2(Integer.valueOf(i2).shortValue());
    }

    @Override // org.apache.poi.ss.usermodel.ClientAnchor
    public void setRow1(int i2) {
        checkRange(i2, 0, MAX_ROW, "row1");
        this._escherClientAnchor.setRow1(Integer.valueOf(i2).shortValue());
    }

    @Override // org.apache.poi.ss.usermodel.ClientAnchor
    public void setRow2(int i2) {
        checkRange(i2, 0, MAX_ROW, "row2");
        this._escherClientAnchor.setRow2(Integer.valueOf(i2).shortValue());
    }

    public HSSFClientAnchor() {
    }

    @Override // org.apache.poi.ss.usermodel.ClientAnchor
    public void setCol1(int i2) {
        setCol1((short) i2);
    }

    @Override // org.apache.poi.ss.usermodel.ClientAnchor
    public void setCol2(int i2) {
        setCol2((short) i2);
    }

    public HSSFClientAnchor(int i2, int i3, int i4, int i5, short s, int i6, short s2, int i7) {
        super(i2, i3, i4, i5);
        checkRange(i2, 0, 1023, "dx1");
        checkRange(i4, 0, 1023, "dx2");
        checkRange(i3, 0, 255, "dy1");
        checkRange(i5, 0, 255, "dy2");
        checkRange(s, 0, MAX_COL, "col1");
        checkRange(s2, 0, MAX_COL, "col2");
        checkRange(i6, 0, MAX_ROW, "row1");
        checkRange(i7, 0, MAX_ROW, "row2");
        setCol1((short) Math.min((int) s, (int) s2));
        setCol2((short) Math.max((int) s, (int) s2));
        setRow1(Math.min(i6, i7));
        setRow2(Math.max(i6, i7));
        if (s > s2) {
            this._isHorizontallyFlipped = true;
        }
        if (i6 > i7) {
            this._isVerticallyFlipped = true;
        }
    }
}
