package org.apache.poi.hssf.usermodel;

import org.apache.poi.hssf.record.CFRule12Record;
import org.apache.poi.hssf.record.cf.ColorGradientFormatting;
import org.apache.poi.hssf.record.cf.ColorGradientThreshold;
import org.apache.poi.hssf.record.common.ExtendedColor;
import org.apache.poi.ss.usermodel.Color;
import org.apache.poi.ss.usermodel.ColorScaleFormatting;
import org.apache.poi.ss.usermodel.ConditionalFormattingThreshold;

public final class HSSFColorScaleFormatting implements ColorScaleFormatting {
    public final CFRule12Record cfRule12Record;
    public final ColorGradientFormatting colorFormatting;
    public final HSSFSheet sheet;

    public HSSFColorScaleFormatting(CFRule12Record cFRule12Record, HSSFSheet hSSFSheet) {
        this.sheet = hSSFSheet;
        this.cfRule12Record = cFRule12Record;
        this.colorFormatting = cFRule12Record.getColorGradientFormatting();
    }

    @Override // org.apache.poi.ss.usermodel.ColorScaleFormatting
    public int getNumControlPoints() {
        return this.colorFormatting.getNumControlPoints();
    }

    @Override // org.apache.poi.ss.usermodel.ColorScaleFormatting
    public void setColors(Color[] colorArr) {
        ExtendedColor[] extendedColorArr = new ExtendedColor[colorArr.length];
        for (int i2 = 0; i2 < colorArr.length; i2++) {
            extendedColorArr[i2] = ((HSSFExtendedColor) colorArr[i2]).getExtendedColor();
        }
        this.colorFormatting.setColors(extendedColorArr);
    }

    @Override // org.apache.poi.ss.usermodel.ColorScaleFormatting
    public void setNumControlPoints(int i2) {
        this.colorFormatting.setNumControlPoints(i2);
    }

    @Override // org.apache.poi.ss.usermodel.ColorScaleFormatting
    public void setThresholds(ConditionalFormattingThreshold[] conditionalFormattingThresholdArr) {
        int length = conditionalFormattingThresholdArr.length;
        ColorGradientThreshold[] colorGradientThresholdArr = new ColorGradientThreshold[length];
        for (int i2 = 0; i2 < length; i2++) {
            colorGradientThresholdArr[i2] = (ColorGradientThreshold) ((HSSFConditionalFormattingThreshold) conditionalFormattingThresholdArr[i2]).getThreshold();
        }
        this.colorFormatting.setThresholds(colorGradientThresholdArr);
    }

    @Override // org.apache.poi.ss.usermodel.ColorScaleFormatting
    public HSSFConditionalFormattingThreshold createThreshold() {
        return new HSSFConditionalFormattingThreshold(new ColorGradientThreshold(), this.sheet);
    }

    @Override // org.apache.poi.ss.usermodel.ColorScaleFormatting
    public HSSFExtendedColor[] getColors() {
        ExtendedColor[] colors = this.colorFormatting.getColors();
        HSSFExtendedColor[] hSSFExtendedColorArr = new HSSFExtendedColor[colors.length];
        for (int i2 = 0; i2 < colors.length; i2++) {
            hSSFExtendedColorArr[i2] = new HSSFExtendedColor(colors[i2]);
        }
        return hSSFExtendedColorArr;
    }

    @Override // org.apache.poi.ss.usermodel.ColorScaleFormatting
    public HSSFConditionalFormattingThreshold[] getThresholds() {
        ColorGradientThreshold[] thresholds = this.colorFormatting.getThresholds();
        HSSFConditionalFormattingThreshold[] hSSFConditionalFormattingThresholdArr = new HSSFConditionalFormattingThreshold[thresholds.length];
        for (int i2 = 0; i2 < thresholds.length; i2++) {
            hSSFConditionalFormattingThresholdArr[i2] = new HSSFConditionalFormattingThreshold(thresholds[i2], this.sheet);
        }
        return hSSFConditionalFormattingThresholdArr;
    }
}
