package org.apache.poi.hssf.usermodel;

import java.util.Arrays;
import java.util.List;
import java.util.Vector;
import org.apache.poi.hssf.model.InternalWorkbook;
import org.apache.poi.hssf.record.FormatRecord;
import org.apache.poi.ss.usermodel.BuiltinFormats;
import org.apache.poi.ss.usermodel.DataFormat;

public final class HSSFDataFormat implements DataFormat {
    public static final String[] _builtinFormats = BuiltinFormats.getAll();
    public final Vector<String> _formats = new Vector<>();
    public boolean _movedBuiltins = false;
    public final InternalWorkbook _workbook;

    public HSSFDataFormat(InternalWorkbook internalWorkbook) {
        this._workbook = internalWorkbook;
        for (FormatRecord formatRecord : internalWorkbook.getFormats()) {
            ensureFormatsSize(formatRecord.getIndexCode());
            this._formats.set(formatRecord.getIndexCode(), formatRecord.getFormatString());
        }
    }

    private void ensureFormatsSize(int i2) {
        if (this._formats.size() <= i2) {
            this._formats.setSize(i2 + 1);
        }
    }

    public static short getBuiltinFormat(String str) {
        return (short) BuiltinFormats.getBuiltinFormat(str);
    }

    public static List<String> getBuiltinFormats() {
        return Arrays.asList(_builtinFormats);
    }

    public static int getNumberOfBuiltinBuiltinFormats() {
        return _builtinFormats.length;
    }

    @Override // org.apache.poi.ss.usermodel.DataFormat
    public short getFormat(String str) {
        if (str.equalsIgnoreCase("TEXT")) {
            str = "@";
        }
        if (!this._movedBuiltins) {
            for (int i2 = 0; i2 < _builtinFormats.length; i2++) {
                ensureFormatsSize(i2);
                if (this._formats.get(i2) == null) {
                    this._formats.set(i2, _builtinFormats[i2]);
                }
            }
            this._movedBuiltins = true;
        }
        for (int i3 = 0; i3 < this._formats.size(); i3++) {
            if (str.equals(this._formats.get(i3))) {
                return (short) i3;
            }
        }
        short format = this._workbook.getFormat(str, true);
        ensureFormatsSize(format);
        this._formats.set(format, str);
        return format;
    }

    public static String getBuiltinFormat(short s) {
        return BuiltinFormats.getBuiltinFormat(s);
    }

    @Override // org.apache.poi.ss.usermodel.DataFormat
    public String getFormat(short s) {
        if (this._movedBuiltins) {
            return this._formats.get(s);
        }
        String str = null;
        if (s == -1) {
            return null;
        }
        if (this._formats.size() > s) {
            str = this._formats.get(s);
        }
        String[] strArr = _builtinFormats;
        if (strArr.length <= s || strArr[s] == null || str != null) {
            return str;
        }
        return strArr[s];
    }
}
