package org.apache.poi.hssf.usermodel;

import b.b.a.a.a;
import java.io.FileNotFoundException;
import java.util.ArrayList;
import java.util.Collections;
import java.util.HashSet;
import java.util.Iterator;
import java.util.List;
import java.util.Map;
import org.apache.poi.ddf.EscherComplexProperty;
import org.apache.poi.ddf.EscherContainerRecord;
import org.apache.poi.ddf.EscherDgRecord;
import org.apache.poi.ddf.EscherOptRecord;
import org.apache.poi.ddf.EscherProperty;
import org.apache.poi.ddf.EscherSpRecord;
import org.apache.poi.ddf.EscherSpgrRecord;
import org.apache.poi.hssf.model.DrawingManager2;
import org.apache.poi.hssf.record.CommonObjectDataSubRecord;
import org.apache.poi.hssf.record.EmbeddedObjectRefSubRecord;
import org.apache.poi.hssf.record.EndSubRecord;
import org.apache.poi.hssf.record.EscherAggregate;
import org.apache.poi.hssf.record.FtCfSubRecord;
import org.apache.poi.hssf.record.FtPioGrbitSubRecord;
import org.apache.poi.hssf.record.NoteRecord;
import org.apache.poi.hssf.record.ObjRecord;
import org.apache.poi.hssf.util.CellReference;
import org.apache.poi.poifs.filesystem.DirectoryEntry;
import org.apache.poi.poifs.filesystem.DirectoryNode;
import org.apache.poi.ss.usermodel.Chart;
import org.apache.poi.ss.usermodel.ClientAnchor;
import org.apache.poi.ss.usermodel.Drawing;
import org.apache.poi.util.HexDump;
import org.apache.poi.util.Internal;
import org.apache.poi.util.NotImplemented;
import org.apache.poi.util.StringUtil;

public final class HSSFPatriarch implements HSSFShapeContainer, Drawing<HSSFShape> {
    public EscherAggregate _boundAggregate;
    public final EscherContainerRecord _mainSpgrContainer;
    public final List<HSSFShape> _shapes = new ArrayList();
    public final HSSFSheet _sheet;
    public final EscherSpgrRecord _spgrRecord;

    public HSSFPatriarch(HSSFSheet hSSFSheet, EscherAggregate escherAggregate) {
        this._sheet = hSSFSheet;
        this._boundAggregate = escherAggregate;
        this._mainSpgrContainer = escherAggregate.getEscherContainer().getChildContainers().get(0);
        this._spgrRecord = (EscherSpgrRecord) ((EscherContainerRecord) this._boundAggregate.getEscherContainer().getChildContainers().get(0).getChild(0)).getChildById(EscherSpgrRecord.RECORD_ID);
        buildShapeTree();
    }

    public static HSSFPatriarch createPatriarch(HSSFPatriarch hSSFPatriarch, HSSFSheet hSSFSheet) {
        HSSFShape hSSFShape;
        HSSFPatriarch hSSFPatriarch2 = new HSSFPatriarch(hSSFSheet, new EscherAggregate(true));
        hSSFPatriarch2.afterCreate();
        for (HSSFShape hSSFShape2 : hSSFPatriarch.getChildren()) {
            if (hSSFShape2 instanceof HSSFShapeGroup) {
                hSSFShape = ((HSSFShapeGroup) hSSFShape2).cloneShape(hSSFPatriarch2);
            } else {
                hSSFShape = hSSFShape2.cloneShape();
            }
            hSSFPatriarch2.onCreate(hSSFShape);
            hSSFPatriarch2.addShape(hSSFShape);
        }
        return hSSFPatriarch2;
    }

    private void onCreate(HSSFShape hSSFShape) {
        EscherContainerRecord escherContainer = hSSFShape.getEscherContainer();
        hSSFShape.setShapeId(newShapeId());
        this._boundAggregate.getEscherContainer().getChildContainers().get(0).addChildRecord(escherContainer);
        hSSFShape.afterInsert(this);
        setFlipFlags(hSSFShape);
    }

    private void setFlipFlags(HSSFShape hSSFShape) {
        EscherSpRecord escherSpRecord = (EscherSpRecord) hSSFShape.getEscherContainer().getChildById(EscherSpRecord.RECORD_ID);
        if (hSSFShape.getAnchor().isHorizontallyFlipped()) {
            escherSpRecord.setFlags(escherSpRecord.getFlags() | 64);
        }
        if (hSSFShape.getAnchor().isVerticallyFlipped()) {
            escherSpRecord.setFlags(escherSpRecord.getFlags() | 128);
        }
    }

    @Override // org.apache.poi.hssf.usermodel.HSSFShapeContainer
    @Internal
    public void addShape(HSSFShape hSSFShape) {
        hSSFShape.setPatriarch(this);
        this._shapes.add(hSSFShape);
    }

    public void afterCreate() {
        DrawingManager2 drawingManager = this._sheet.getWorkbook().getWorkbook().getDrawingManager();
        this._boundAggregate.setDgId(drawingManager.findNewDrawingGroupId());
        this._boundAggregate.setMainSpRecordId(newShapeId());
        drawingManager.incrementDrawingsSaved();
    }

    public void buildShapeTree() {
        EscherContainerRecord escherContainer = this._boundAggregate.getEscherContainer();
        if (escherContainer != null) {
            List<EscherContainerRecord> childContainers = escherContainer.getChildContainers().get(0).getChildContainers();
            for (int i2 = 0; i2 < childContainers.size(); i2++) {
                EscherContainerRecord escherContainerRecord = childContainers.get(i2);
                if (i2 != 0) {
                    HSSFShapeFactory.createShapeTree(escherContainerRecord, this._boundAggregate, this, this._sheet.getWorkbook().getDirectory());
                }
            }
        }
    }

    @Override // org.apache.poi.hssf.usermodel.HSSFShapeContainer
    public void clear() {
        Iterator it = new ArrayList(this._shapes).iterator();
        while (it.hasNext()) {
            removeShape((HSSFShape) it.next());
        }
    }

    public boolean containsChart() {
        EscherOptRecord escherOptRecord = (EscherOptRecord) this._boundAggregate.findFirstWithId(EscherOptRecord.RECORD_ID);
        if (escherOptRecord == null) {
            return false;
        }
        for (EscherProperty escherProperty : escherOptRecord.getEscherProperties()) {
            if (escherProperty.getPropertyNumber() == 896 && escherProperty.isComplex() && StringUtil.getFromUnicodeLE(((EscherComplexProperty) escherProperty).getComplexData()).equals("Chart 1\u0000")) {
                return true;
            }
        }
        return false;
    }

    public int countOfAllChildren() {
        int size = this._shapes.size();
        for (HSSFShape hSSFShape : this._shapes) {
            size += hSSFShape.countOfAllChildren();
        }
        return size;
    }

    @Override // org.apache.poi.ss.usermodel.Drawing
    @NotImplemented
    public Chart createChart(ClientAnchor clientAnchor) {
        throw new RuntimeException("NotImplemented");
    }

    public HSSFSimpleShape createComboBox(HSSFAnchor hSSFAnchor) {
        HSSFCombobox hSSFCombobox = new HSSFCombobox((HSSFShape) null, hSSFAnchor);
        addShape(hSSFCombobox);
        onCreate(hSSFCombobox);
        return hSSFCombobox;
    }

    public HSSFComment createComment(HSSFAnchor hSSFAnchor) {
        HSSFComment hSSFComment = new HSSFComment((HSSFShape) null, hSSFAnchor);
        addShape(hSSFComment);
        onCreate(hSSFComment);
        return hSSFComment;
    }

    public HSSFShapeGroup createGroup(HSSFClientAnchor hSSFClientAnchor) {
        HSSFShapeGroup hSSFShapeGroup = new HSSFShapeGroup((HSSFShape) null, hSSFClientAnchor);
        addShape(hSSFShapeGroup);
        onCreate(hSSFShapeGroup);
        return hSSFShapeGroup;
    }

    public HSSFPolygon createPolygon(HSSFClientAnchor hSSFClientAnchor) {
        HSSFPolygon hSSFPolygon = new HSSFPolygon((HSSFShape) null, hSSFClientAnchor);
        addShape(hSSFPolygon);
        onCreate(hSSFPolygon);
        return hSSFPolygon;
    }

    public HSSFSimpleShape createSimpleShape(HSSFClientAnchor hSSFClientAnchor) {
        HSSFSimpleShape hSSFSimpleShape = new HSSFSimpleShape((HSSFShape) null, hSSFClientAnchor);
        addShape(hSSFSimpleShape);
        onCreate(hSSFSimpleShape);
        return hSSFSimpleShape;
    }

    public HSSFTextbox createTextbox(HSSFClientAnchor hSSFClientAnchor) {
        HSSFTextbox hSSFTextbox = new HSSFTextbox(null, hSSFClientAnchor);
        addShape(hSSFTextbox);
        onCreate(hSSFTextbox);
        return hSSFTextbox;
    }

    @Internal
    public EscherAggregate getBoundAggregate() {
        return this._boundAggregate;
    }

    @Override // org.apache.poi.hssf.usermodel.HSSFShapeContainer
    public List<HSSFShape> getChildren() {
        return Collections.unmodifiableList(this._shapes);
    }

    public HSSFSheet getSheet() {
        return this._sheet;
    }

    @Override // org.apache.poi.hssf.usermodel.HSSFShapeContainer
    public int getX1() {
        return this._spgrRecord.getRectX1();
    }

    @Override // org.apache.poi.hssf.usermodel.HSSFShapeContainer
    public int getX2() {
        return this._spgrRecord.getRectX2();
    }

    @Override // org.apache.poi.hssf.usermodel.HSSFShapeContainer
    public int getY1() {
        return this._spgrRecord.getRectY1();
    }

    @Override // org.apache.poi.hssf.usermodel.HSSFShapeContainer
    public int getY2() {
        return this._spgrRecord.getRectY2();
    }

    @Override // java.lang.Iterable
    public Iterator<HSSFShape> iterator() {
        return this._shapes.iterator();
    }

    public int newShapeId() {
        return this._sheet.getWorkbook().getWorkbook().getDrawingManager().allocateShapeId((EscherDgRecord) this._boundAggregate.getEscherContainer().getChildById(EscherDgRecord.RECORD_ID));
    }

    public void preSerialize() {
        Map<Integer, NoteRecord> tailRecords = this._boundAggregate.getTailRecords();
        HashSet hashSet = new HashSet(tailRecords.size());
        for (NoteRecord noteRecord : tailRecords.values()) {
            String formatAsString = new CellReference(noteRecord.getRow(), noteRecord.getColumn()).formatAsString();
            if (!hashSet.contains(formatAsString)) {
                hashSet.add(formatAsString);
            } else {
                throw new IllegalStateException(a.b("found multiple cell comments for cell ", formatAsString));
            }
        }
    }

    @Override // org.apache.poi.hssf.usermodel.HSSFShapeContainer
    public boolean removeShape(HSSFShape hSSFShape) {
        boolean removeChildRecord = this._mainSpgrContainer.removeChildRecord(hSSFShape.getEscherContainer());
        if (removeChildRecord) {
            hSSFShape.afterRemove(this);
            this._shapes.remove(hSSFShape);
        }
        return removeChildRecord;
    }

    @Override // org.apache.poi.hssf.usermodel.HSSFShapeContainer
    public void setCoordinates(int i2, int i3, int i4, int i5) {
        this._spgrRecord.setRectY1(i3);
        this._spgrRecord.setRectY2(i5);
        this._spgrRecord.setRectX1(i2);
        this._spgrRecord.setRectX2(i4);
    }

    @Override // org.apache.poi.ss.usermodel.Drawing
    public HSSFClientAnchor createAnchor(int i2, int i3, int i4, int i5, int i6, int i7, int i8, int i9) {
        return new HSSFClientAnchor(i2, i3, i4, i5, (short) i6, i7, (short) i8, i9);
    }

    @Override // org.apache.poi.ss.usermodel.Drawing
    public HSSFComment createCellComment(ClientAnchor clientAnchor) {
        return createComment((HSSFAnchor) clientAnchor);
    }

    @Override // org.apache.poi.ss.usermodel.Drawing
    public HSSFObjectData createObjectData(ClientAnchor clientAnchor, int i2, int i3) {
        ObjRecord objRecord = new ObjRecord();
        CommonObjectDataSubRecord commonObjectDataSubRecord = new CommonObjectDataSubRecord();
        commonObjectDataSubRecord.setObjectType(8);
        commonObjectDataSubRecord.setLocked(true);
        commonObjectDataSubRecord.setPrintable(true);
        commonObjectDataSubRecord.setAutofill(true);
        commonObjectDataSubRecord.setAutoline(true);
        commonObjectDataSubRecord.setReserved1(0);
        commonObjectDataSubRecord.setReserved2(0);
        commonObjectDataSubRecord.setReserved3(0);
        objRecord.addSubRecord(commonObjectDataSubRecord);
        FtCfSubRecord ftCfSubRecord = new FtCfSubRecord();
        HSSFPictureData hSSFPictureData = getSheet().getWorkbook().getAllPictures().get(i3 - 1);
        switch (hSSFPictureData.getFormat()) {
            case 2:
            case 3:
                ftCfSubRecord.setFlags(2);
                break;
            case 4:
            case 5:
            case 6:
            case 7:
                ftCfSubRecord.setFlags(9);
                break;
            default:
                StringBuilder b2 = a.b("Invalid picture type: ");
                b2.append(hSSFPictureData.getFormat());
                throw new IllegalStateException(b2.toString());
        }
        objRecord.addSubRecord(ftCfSubRecord);
        FtPioGrbitSubRecord ftPioGrbitSubRecord = new FtPioGrbitSubRecord();
        ftPioGrbitSubRecord.setFlagByBit(1, true);
        objRecord.addSubRecord(ftPioGrbitSubRecord);
        EmbeddedObjectRefSubRecord embeddedObjectRefSubRecord = new EmbeddedObjectRefSubRecord();
        embeddedObjectRefSubRecord.setUnknownFormulaData(new byte[]{2, 0, 0, 0, 0});
        embeddedObjectRefSubRecord.setOleClassname("Paket");
        embeddedObjectRefSubRecord.setStorageId(i2);
        objRecord.addSubRecord(embeddedObjectRefSubRecord);
        objRecord.addSubRecord(new EndSubRecord());
        String str = "MBD" + HexDump.toHex(i2);
        try {
            DirectoryNode directory = this._sheet.getWorkbook().getDirectory();
            if (directory != null) {
                DirectoryEntry directoryEntry = (DirectoryEntry) directory.getEntry(str);
                HSSFPicture hSSFPicture = new HSSFPicture((HSSFShape) null, (HSSFClientAnchor) clientAnchor);
                hSSFPicture.setPictureIndex(i3);
                EscherContainerRecord escherContainer = hSSFPicture.getEscherContainer();
                EscherSpRecord escherSpRecord = (EscherSpRecord) escherContainer.getChildById(EscherSpRecord.RECORD_ID);
                escherSpRecord.setFlags(escherSpRecord.getFlags() | 16);
                HSSFObjectData hSSFObjectData = new HSSFObjectData(escherContainer, objRecord, directoryEntry);
                addShape(hSSFObjectData);
                onCreate(hSSFObjectData);
                return hSSFObjectData;
            }
            throw new FileNotFoundException();
        } catch (FileNotFoundException e2) {
            throw new IllegalStateException("trying to add ole shape without actually adding data first - use HSSFWorkbook.addOlePackage first", e2);
        }
    }

    public HSSFPicture createPicture(HSSFClientAnchor hSSFClientAnchor, int i2) {
        HSSFPicture hSSFPicture = new HSSFPicture((HSSFShape) null, hSSFClientAnchor);
        hSSFPicture.setPictureIndex(i2);
        addShape(hSSFPicture);
        onCreate(hSSFPicture);
        return hSSFPicture;
    }

    @Override // org.apache.poi.ss.usermodel.Drawing
    public HSSFPicture createPicture(ClientAnchor clientAnchor, int i2) {
        return createPicture((HSSFClientAnchor) clientAnchor, i2);
    }
}
