package org.apache.poi.hssf.usermodel;

import java.util.Iterator;
import java.util.List;
import java.util.Map;
import org.apache.poi.ddf.EscherClientDataRecord;
import org.apache.poi.ddf.EscherContainerRecord;
import org.apache.poi.ddf.EscherOptRecord;
import org.apache.poi.ddf.EscherRecord;
import org.apache.poi.hssf.record.CommonObjectDataSubRecord;
import org.apache.poi.hssf.record.EmbeddedObjectRefSubRecord;
import org.apache.poi.hssf.record.EscherAggregate;
import org.apache.poi.hssf.record.ObjRecord;
import org.apache.poi.hssf.record.Record;
import org.apache.poi.hssf.record.SubRecord;
import org.apache.poi.hssf.record.TextObjectRecord;
import org.apache.poi.poifs.filesystem.DirectoryNode;
import org.apache.poi.util.RecordFormatException;

public class HSSFShapeFactory {
    public static void createShapeTree(EscherContainerRecord escherContainerRecord, EscherAggregate escherAggregate, HSSFShapeContainer hSSFShapeContainer, DirectoryNode directoryNode) {
        HSSFShape hSSFShape;
        ObjRecord objRecord = null;
        if (escherContainerRecord.getRecordId() == -4093) {
            EscherClientDataRecord escherClientDataRecord = (EscherClientDataRecord) ((EscherContainerRecord) escherContainerRecord.getChild(0)).getChildById(EscherClientDataRecord.RECORD_ID);
            if (escherClientDataRecord != null) {
                objRecord = (ObjRecord) escherAggregate.getShapeToObjMapping().get(escherClientDataRecord);
            }
            HSSFShapeGroup hSSFShapeGroup = new HSSFShapeGroup(escherContainerRecord, objRecord);
            List<EscherContainerRecord> childContainers = escherContainerRecord.getChildContainers();
            for (int i2 = 0; i2 < childContainers.size(); i2++) {
                EscherContainerRecord escherContainerRecord2 = childContainers.get(i2);
                if (i2 != 0) {
                    createShapeTree(escherContainerRecord2, escherAggregate, hSSFShapeGroup, directoryNode);
                }
            }
            hSSFShapeContainer.addShape(hSSFShapeGroup);
        } else if (escherContainerRecord.getRecordId() == -4092) {
            Map<EscherRecord, Record> shapeToObjMapping = escherAggregate.getShapeToObjMapping();
            Iterator<EscherRecord> it = escherContainerRecord.iterator();
            TextObjectRecord textObjectRecord = null;
            while (it.hasNext()) {
                EscherRecord next = it.next();
                short recordId = next.getRecordId();
                if (recordId == -4083) {
                    textObjectRecord = (TextObjectRecord) shapeToObjMapping.get(next);
                } else if (recordId == -4079) {
                    objRecord = (ObjRecord) shapeToObjMapping.get(next);
                }
            }
            if (objRecord == null) {
                throw new RecordFormatException("EscherClientDataRecord can't be found.");
            } else if (isEmbeddedObject(objRecord)) {
                hSSFShapeContainer.addShape(new HSSFObjectData(escherContainerRecord, objRecord, directoryNode));
            } else {
                short objectType = ((CommonObjectDataSubRecord) objRecord.getSubRecords().get(0)).getObjectType();
                if (objectType == 1) {
                    hSSFShape = new HSSFSimpleShape(escherContainerRecord, objRecord);
                } else if (objectType == 2) {
                    hSSFShape = new HSSFSimpleShape(escherContainerRecord, objRecord, textObjectRecord);
                } else if (objectType == 6) {
                    hSSFShape = new HSSFTextbox(escherContainerRecord, objRecord, textObjectRecord);
                } else if (objectType == 8) {
                    hSSFShape = new HSSFPicture(escherContainerRecord, objRecord);
                } else if (objectType == 20) {
                    hSSFShape = new HSSFCombobox(escherContainerRecord, objRecord);
                } else if (objectType == 25) {
                    hSSFShape = new HSSFComment(escherContainerRecord, objRecord, textObjectRecord, escherAggregate.getNoteRecordByObj(objRecord));
                } else if (objectType != 30) {
                    hSSFShape = new HSSFSimpleShape(escherContainerRecord, objRecord, textObjectRecord);
                } else {
                    EscherOptRecord escherOptRecord = (EscherOptRecord) escherContainerRecord.getChildById(EscherOptRecord.RECORD_ID);
                    if (escherOptRecord == null) {
                        hSSFShape = new HSSFSimpleShape(escherContainerRecord, objRecord, textObjectRecord);
                    } else if (escherOptRecord.lookup(325) != null) {
                        hSSFShape = new HSSFPolygon(escherContainerRecord, objRecord, textObjectRecord);
                    } else {
                        hSSFShape = new HSSFSimpleShape(escherContainerRecord, objRecord, textObjectRecord);
                    }
                }
                hSSFShapeContainer.addShape(hSSFShape);
            }
        }
    }

    public static boolean isEmbeddedObject(ObjRecord objRecord) {
        for (SubRecord subRecord : objRecord.getSubRecords()) {
            if (subRecord instanceof EmbeddedObjectRefSubRecord) {
                return true;
            }
        }
        return false;
    }
}
