package org.apache.poi.hwmf.draw;

import java.awt.Color;
import java.awt.Shape;
import java.awt.geom.Area;
import java.awt.geom.Point2D;
import java.awt.geom.Rectangle2D;
import java.awt.image.BufferedImage;
import java.awt.image.ColorModel;
import java.awt.image.WritableRaster;
import java.util.Hashtable;
import java.util.List;
import org.apache.poi.hwmf.record.HwmfBrushStyle;
import org.apache.poi.hwmf.record.HwmfColorRef;
import org.apache.poi.hwmf.record.HwmfFill;
import org.apache.poi.hwmf.record.HwmfFont;
import org.apache.poi.hwmf.record.HwmfHatchStyle;
import org.apache.poi.hwmf.record.HwmfMapMode;
import org.apache.poi.hwmf.record.HwmfMisc;
import org.apache.poi.hwmf.record.HwmfPalette;
import org.apache.poi.hwmf.record.HwmfPenStyle;
import org.apache.poi.hwmf.record.HwmfText;
import org.apache.poi.ss.formula.functions.NumericFunction;

public class HwmfDrawProperties {
    public HwmfColorRef backgroundColor;
    public HwmfMisc.WmfSetBkMode.HwmfBkMode bkMode;
    public BufferedImage brushBitmap;
    public HwmfColorRef brushColor;
    public HwmfHatchStyle brushHatch;
    public HwmfBrushStyle brushStyle;
    public HwmfFont font;
    public final Point2D location;
    public HwmfMapMode mapMode;
    public List<HwmfPalette.PaletteEntry> palette;
    public int paletteOffset;
    public HwmfColorRef penColor;
    public double penMiterLimit;
    public HwmfPenStyle penStyle;
    public double penWidth;
    public HwmfFill.WmfSetPolyfillMode.HwmfPolyfillMode polyfillMode;
    public Shape region;
    public HwmfText.HwmfTextAlignment textAlignAsian;
    public HwmfText.HwmfTextAlignment textAlignLatin;
    public HwmfColorRef textColor;
    public HwmfText.HwmfTextVerticalAlignment textVAlignAsian;
    public HwmfText.HwmfTextVerticalAlignment textVAlignLatin;
    public Rectangle2D viewport;
    public final Rectangle2D window;

    public HwmfDrawProperties() {
        this.viewport = null;
        this.mapMode = HwmfMapMode.MM_ANISOTROPIC;
        this.backgroundColor = new HwmfColorRef(Color.BLACK);
        this.brushStyle = HwmfBrushStyle.BS_SOLID;
        this.brushColor = new HwmfColorRef(Color.BLACK);
        this.brushHatch = HwmfHatchStyle.HS_HORIZONTAL;
        this.brushBitmap = null;
        this.penWidth = 1.0d;
        this.penStyle = HwmfPenStyle.valueOf(0);
        this.penColor = new HwmfColorRef(Color.BLACK);
        this.penMiterLimit = 10.0d;
        this.bkMode = HwmfMisc.WmfSetBkMode.HwmfBkMode.OPAQUE;
        this.polyfillMode = HwmfFill.WmfSetPolyfillMode.HwmfPolyfillMode.WINDING;
        this.region = null;
        this.palette = null;
        this.paletteOffset = 0;
        this.font = null;
        this.textColor = new HwmfColorRef(Color.BLACK);
        this.textAlignLatin = HwmfText.HwmfTextAlignment.LEFT;
        this.textVAlignLatin = HwmfText.HwmfTextVerticalAlignment.TOP;
        this.textAlignAsian = HwmfText.HwmfTextAlignment.RIGHT;
        this.textVAlignAsian = HwmfText.HwmfTextVerticalAlignment.TOP;
        this.window = new Rectangle2D.Double((double) NumericFunction.LOG_10_TO_BASE_e, (double) NumericFunction.LOG_10_TO_BASE_e, 1.0d, 1.0d);
        this.viewport = null;
        this.location = new Point2D.Double((double) NumericFunction.LOG_10_TO_BASE_e, (double) NumericFunction.LOG_10_TO_BASE_e);
    }

    public HwmfColorRef getBackgroundColor() {
        return this.backgroundColor;
    }

    public HwmfMisc.WmfSetBkMode.HwmfBkMode getBkMode() {
        return this.bkMode;
    }

    public BufferedImage getBrushBitmap() {
        return this.brushBitmap;
    }

    public HwmfColorRef getBrushColor() {
        return this.brushColor;
    }

    public HwmfHatchStyle getBrushHatch() {
        return this.brushHatch;
    }

    public HwmfBrushStyle getBrushStyle() {
        return this.brushStyle;
    }

    public HwmfFont getFont() {
        return this.font;
    }

    public Point2D getLocation() {
        return (Point2D) this.location.clone();
    }

    public HwmfMapMode getMapMode() {
        return this.mapMode;
    }

    public List<HwmfPalette.PaletteEntry> getPalette() {
        return this.palette;
    }

    public int getPaletteOffset() {
        return this.paletteOffset;
    }

    public HwmfColorRef getPenColor() {
        return this.penColor;
    }

    public double getPenMiterLimit() {
        return this.penMiterLimit;
    }

    public HwmfPenStyle getPenStyle() {
        return this.penStyle;
    }

    public double getPenWidth() {
        return this.penWidth;
    }

    public HwmfFill.WmfSetPolyfillMode.HwmfPolyfillMode getPolyfillMode() {
        return this.polyfillMode;
    }

    public Shape getRegion() {
        return this.region;
    }

    public HwmfText.HwmfTextAlignment getTextAlignAsian() {
        return this.textAlignAsian;
    }

    public HwmfText.HwmfTextAlignment getTextAlignLatin() {
        return this.textAlignLatin;
    }

    public HwmfColorRef getTextColor() {
        return this.textColor;
    }

    public HwmfText.HwmfTextVerticalAlignment getTextVAlignAsian() {
        return this.textVAlignAsian;
    }

    public HwmfText.HwmfTextVerticalAlignment getTextVAlignLatin() {
        return this.textVAlignLatin;
    }

    public Rectangle2D getViewport() {
        Rectangle2D rectangle2D = this.viewport;
        if (rectangle2D == null) {
            return null;
        }
        return (Rectangle2D) rectangle2D.clone();
    }

    public Rectangle2D getWindow() {
        return (Rectangle2D) this.window.clone();
    }

    public void setBackgroundColor(HwmfColorRef hwmfColorRef) {
        this.backgroundColor = hwmfColorRef;
    }

    public void setBkMode(HwmfMisc.WmfSetBkMode.HwmfBkMode hwmfBkMode) {
        this.bkMode = hwmfBkMode;
    }

    public void setBrushBitmap(BufferedImage bufferedImage) {
        this.brushBitmap = bufferedImage;
    }

    public void setBrushColor(HwmfColorRef hwmfColorRef) {
        this.brushColor = hwmfColorRef;
    }

    public void setBrushHatch(HwmfHatchStyle hwmfHatchStyle) {
        this.brushHatch = hwmfHatchStyle;
    }

    public void setBrushStyle(HwmfBrushStyle hwmfBrushStyle) {
        this.brushStyle = hwmfBrushStyle;
    }

    public void setFont(HwmfFont hwmfFont) {
        this.font = hwmfFont;
    }

    public void setLocation(double d2, double d3) {
        this.location.setLocation(d2, d3);
    }

    public void setMapMode(HwmfMapMode hwmfMapMode) {
        this.mapMode = hwmfMapMode;
    }

    public void setPalette(List<HwmfPalette.PaletteEntry> list) {
        this.palette = list;
    }

    public void setPaletteOffset(int i2) {
        this.paletteOffset = i2;
    }

    public void setPenColor(HwmfColorRef hwmfColorRef) {
        this.penColor = hwmfColorRef;
    }

    public void setPenMiterLimit(double d2) {
        this.penMiterLimit = d2;
    }

    public void setPenStyle(HwmfPenStyle hwmfPenStyle) {
        this.penStyle = hwmfPenStyle;
    }

    public void setPenWidth(double d2) {
        this.penWidth = d2;
    }

    public void setPolyfillMode(HwmfFill.WmfSetPolyfillMode.HwmfPolyfillMode hwmfPolyfillMode) {
        this.polyfillMode = hwmfPolyfillMode;
    }

    public void setRegion(Shape shape) {
        this.region = shape;
    }

    public void setTextAlignAsian(HwmfText.HwmfTextAlignment hwmfTextAlignment) {
        this.textAlignAsian = hwmfTextAlignment;
    }

    public void setTextAlignLatin(HwmfText.HwmfTextAlignment hwmfTextAlignment) {
        this.textAlignLatin = hwmfTextAlignment;
    }

    public void setTextColor(HwmfColorRef hwmfColorRef) {
        this.textColor = hwmfColorRef;
    }

    public void setTextVAlignAsian(HwmfText.HwmfTextVerticalAlignment hwmfTextVerticalAlignment) {
        this.textVAlignAsian = hwmfTextVerticalAlignment;
    }

    public void setTextVAlignLatin(HwmfText.HwmfTextVerticalAlignment hwmfTextVerticalAlignment) {
        this.textVAlignLatin = hwmfTextVerticalAlignment;
    }

    public void setViewportExt(double d2, double d3) {
        if (this.viewport == null) {
            this.viewport = (Rectangle2D) this.window.clone();
        }
        double x = this.viewport.getX();
        double y = this.viewport.getY();
        if (d2 == NumericFunction.LOG_10_TO_BASE_e) {
            d2 = this.viewport.getWidth();
        }
        if (d3 == NumericFunction.LOG_10_TO_BASE_e) {
            d3 = this.viewport.getHeight();
        }
        this.viewport.setRect(x, y, d2, d3);
    }

    public void setViewportOrg(double d2, double d3) {
        if (this.viewport == null) {
            this.viewport = (Rectangle2D) this.window.clone();
        }
        this.viewport.setRect(d2, d3, this.viewport.getWidth(), this.viewport.getHeight());
    }

    public void setWindowExt(double d2, double d3) {
        double x = this.window.getX();
        double y = this.window.getY();
        if (d2 == NumericFunction.LOG_10_TO_BASE_e) {
            d2 = this.window.getWidth();
        }
        if (d3 == NumericFunction.LOG_10_TO_BASE_e) {
            d3 = this.window.getHeight();
        }
        this.window.setRect(x, y, d2, d3);
    }

    public void setWindowOrg(double d2, double d3) {
        this.window.setRect(d2, d3, this.window.getWidth(), this.window.getHeight());
    }

    public HwmfDrawProperties(HwmfDrawProperties hwmfDrawProperties) {
        HwmfColorRef hwmfColorRef = null;
        this.viewport = null;
        this.mapMode = HwmfMapMode.MM_ANISOTROPIC;
        this.backgroundColor = new HwmfColorRef(Color.BLACK);
        this.brushStyle = HwmfBrushStyle.BS_SOLID;
        this.brushColor = new HwmfColorRef(Color.BLACK);
        this.brushHatch = HwmfHatchStyle.HS_HORIZONTAL;
        this.brushBitmap = null;
        this.penWidth = 1.0d;
        this.penStyle = HwmfPenStyle.valueOf(0);
        this.penColor = new HwmfColorRef(Color.BLACK);
        this.penMiterLimit = 10.0d;
        this.bkMode = HwmfMisc.WmfSetBkMode.HwmfBkMode.OPAQUE;
        this.polyfillMode = HwmfFill.WmfSetPolyfillMode.HwmfPolyfillMode.WINDING;
        this.region = null;
        this.palette = null;
        this.paletteOffset = 0;
        this.font = null;
        this.textColor = new HwmfColorRef(Color.BLACK);
        this.textAlignLatin = HwmfText.HwmfTextAlignment.LEFT;
        this.textVAlignLatin = HwmfText.HwmfTextVerticalAlignment.TOP;
        this.textAlignAsian = HwmfText.HwmfTextAlignment.RIGHT;
        this.textVAlignAsian = HwmfText.HwmfTextVerticalAlignment.TOP;
        this.window = (Rectangle2D) hwmfDrawProperties.window.clone();
        Rectangle2D rectangle2D = hwmfDrawProperties.viewport;
        this.viewport = rectangle2D == null ? null : (Rectangle2D) rectangle2D.clone();
        this.location = (Point2D) hwmfDrawProperties.location.clone();
        this.mapMode = hwmfDrawProperties.mapMode;
        HwmfColorRef hwmfColorRef2 = hwmfDrawProperties.backgroundColor;
        this.backgroundColor = hwmfColorRef2 == null ? null : hwmfColorRef2.clone();
        this.brushStyle = hwmfDrawProperties.brushStyle;
        this.brushColor = hwmfDrawProperties.brushColor.clone();
        this.brushHatch = hwmfDrawProperties.brushHatch;
        BufferedImage bufferedImage = hwmfDrawProperties.brushBitmap;
        if (bufferedImage != null) {
            ColorModel colorModel = bufferedImage.getColorModel();
            this.brushBitmap = new BufferedImage(colorModel, hwmfDrawProperties.brushBitmap.copyData((WritableRaster) null), colorModel.isAlphaPremultiplied(), (Hashtable) null);
        }
        this.penWidth = 1.0d;
        HwmfPenStyle hwmfPenStyle = hwmfDrawProperties.penStyle;
        this.penStyle = hwmfPenStyle == null ? null : hwmfPenStyle.clone();
        HwmfColorRef hwmfColorRef3 = hwmfDrawProperties.penColor;
        this.penColor = hwmfColorRef3 == null ? null : hwmfColorRef3.clone();
        this.penMiterLimit = hwmfDrawProperties.penMiterLimit;
        this.bkMode = hwmfDrawProperties.bkMode;
        this.polyfillMode = hwmfDrawProperties.polyfillMode;
        Rectangle2D rectangle2D2 = hwmfDrawProperties.region;
        if (rectangle2D2 instanceof Rectangle2D) {
            this.region = rectangle2D2.getBounds2D();
        } else if (rectangle2D2 instanceof Area) {
            this.region = new Area(hwmfDrawProperties.region);
        }
        this.palette = hwmfDrawProperties.palette;
        this.paletteOffset = hwmfDrawProperties.paletteOffset;
        this.font = hwmfDrawProperties.font;
        HwmfColorRef hwmfColorRef4 = hwmfDrawProperties.textColor;
        this.textColor = hwmfColorRef4 != null ? hwmfColorRef4.clone() : hwmfColorRef;
    }
}
