package org.apache.poi.hwmf.record;

import java.awt.Shape;
import java.awt.image.BufferedImage;
import org.apache.poi.hwmf.draw.HwmfGraphics;
import org.apache.poi.util.LittleEndianInputStream;

public class HwmfFill {

    public enum ColorUsage {
        DIB_RGB_COLORS(0),
        DIB_PAL_COLORS(1),
        DIB_PAL_INDICES(2);
        
        public final int flag;

        /* access modifiers changed from: public */
        ColorUsage(int i2) {
            this.flag = i2;
        }

        public static ColorUsage valueOf(int i2) {
            ColorUsage[] values = values();
            for (ColorUsage colorUsage : values) {
                if (colorUsage.flag == i2) {
                    return colorUsage;
                }
            }
            return null;
        }
    }

    public interface HwmfImageRecord {
        BufferedImage getImage();
    }

    public static class WmfBitBlt implements HwmfRecord {
        public static final /* synthetic */ boolean $assertionsDisabled = false;
        public int height;
        public HwmfTernaryRasterOp rasterOperation;
        public HwmfBitmap16 target;
        public int width;
        public int xDest;
        public int xSrc;
        public int yDest;
        public int ySrc;

        @Override // org.apache.poi.hwmf.record.HwmfRecord
        public void draw(HwmfGraphics hwmfGraphics) {
        }

        @Override // org.apache.poi.hwmf.record.HwmfRecord
        public HwmfRecordType getRecordType() {
            return HwmfRecordType.bitBlt;
        }

        @Override // org.apache.poi.hwmf.record.HwmfRecord
        public int init(LittleEndianInputStream littleEndianInputStream, long j, int i2) {
            int i3;
            boolean z = j / 2 != ((long) ((i2 >> 8) + 3));
            littleEndianInputStream.readUShort();
            this.rasterOperation = HwmfTernaryRasterOp.valueOf(littleEndianInputStream.readUShort());
            this.ySrc = littleEndianInputStream.readShort();
            this.xSrc = littleEndianInputStream.readShort();
            if (!z) {
                littleEndianInputStream.readShort();
                i3 = 10;
            } else {
                i3 = 8;
            }
            this.height = littleEndianInputStream.readShort();
            this.width = littleEndianInputStream.readShort();
            this.yDest = littleEndianInputStream.readShort();
            this.xDest = littleEndianInputStream.readShort();
            int i4 = i3 + 8;
            if (!z) {
                return i4;
            }
            HwmfBitmap16 hwmfBitmap16 = new HwmfBitmap16();
            this.target = hwmfBitmap16;
            return i4 + hwmfBitmap16.init(littleEndianInputStream);
        }
    }

    public static class WmfDibBitBlt implements HwmfRecord, HwmfImageRecord, HwmfObjectTableEntry {
        public static final /* synthetic */ boolean $assertionsDisabled = false;
        public int height;
        public HwmfTernaryRasterOp rasterOperation;
        public HwmfBitmapDib target;
        public int width;
        public int xDest;
        public int xSrc;
        public int yDest;
        public int ySrc;

        @Override // org.apache.poi.hwmf.record.HwmfObjectTableEntry
        public void applyObject(HwmfGraphics hwmfGraphics) {
        }

        @Override // org.apache.poi.hwmf.record.HwmfRecord
        public void draw(HwmfGraphics hwmfGraphics) {
            hwmfGraphics.addObjectTableEntry(this);
        }

        @Override // org.apache.poi.hwmf.record.HwmfFill.HwmfImageRecord
        public BufferedImage getImage() {
            HwmfBitmapDib hwmfBitmapDib = this.target;
            if (hwmfBitmapDib == null) {
                return null;
            }
            return hwmfBitmapDib.getImage();
        }

        @Override // org.apache.poi.hwmf.record.HwmfRecord
        public HwmfRecordType getRecordType() {
            return HwmfRecordType.dibBitBlt;
        }

        @Override // org.apache.poi.hwmf.record.HwmfRecord
        public int init(LittleEndianInputStream littleEndianInputStream, long j, int i2) {
            int i3;
            boolean z = j / 2 != ((long) ((i2 >> 8) + 3));
            littleEndianInputStream.readUShort();
            this.rasterOperation = HwmfTernaryRasterOp.valueOf(littleEndianInputStream.readUShort());
            this.ySrc = littleEndianInputStream.readShort();
            this.xSrc = littleEndianInputStream.readShort();
            if (!z) {
                littleEndianInputStream.readShort();
                i3 = 10;
            } else {
                i3 = 8;
            }
            this.height = littleEndianInputStream.readShort();
            this.width = littleEndianInputStream.readShort();
            this.yDest = littleEndianInputStream.readShort();
            this.xDest = littleEndianInputStream.readShort();
            int i4 = i3 + 8;
            if (!z) {
                return i4;
            }
            HwmfBitmapDib hwmfBitmapDib = new HwmfBitmapDib();
            this.target = hwmfBitmapDib;
            return i4 + hwmfBitmapDib.init(littleEndianInputStream, (int) ((j - 6) - ((long) i4)));
        }
    }

    public static class WmfDibStretchBlt implements HwmfRecord, HwmfImageRecord, HwmfObjectTableEntry {
        public static final /* synthetic */ boolean $assertionsDisabled = false;
        public int destHeight;
        public int destWidth;
        public HwmfTernaryRasterOp rasterOperation;
        public int srcHeight;
        public int srcWidth;
        public HwmfBitmapDib target;
        public int xDest;
        public int xSrc;
        public int yDest;
        public int ySrc;

        @Override // org.apache.poi.hwmf.record.HwmfObjectTableEntry
        public void applyObject(HwmfGraphics hwmfGraphics) {
        }

        @Override // org.apache.poi.hwmf.record.HwmfRecord
        public void draw(HwmfGraphics hwmfGraphics) {
            hwmfGraphics.addObjectTableEntry(this);
        }

        @Override // org.apache.poi.hwmf.record.HwmfFill.HwmfImageRecord
        public BufferedImage getImage() {
            return this.target.getImage();
        }

        @Override // org.apache.poi.hwmf.record.HwmfRecord
        public HwmfRecordType getRecordType() {
            return HwmfRecordType.dibStretchBlt;
        }

        @Override // org.apache.poi.hwmf.record.HwmfRecord
        public int init(LittleEndianInputStream littleEndianInputStream, long j, int i2) {
            boolean z = j > ((long) ((i2 >> 8) + 3));
            littleEndianInputStream.readUShort();
            this.rasterOperation = HwmfTernaryRasterOp.valueOf(littleEndianInputStream.readUShort());
            this.srcHeight = littleEndianInputStream.readShort();
            this.srcWidth = littleEndianInputStream.readShort();
            this.ySrc = littleEndianInputStream.readShort();
            this.xSrc = littleEndianInputStream.readShort();
            int i3 = 12;
            if (!z) {
                littleEndianInputStream.readShort();
                i3 = 14;
            }
            this.destHeight = littleEndianInputStream.readShort();
            this.destWidth = littleEndianInputStream.readShort();
            this.yDest = littleEndianInputStream.readShort();
            this.xDest = littleEndianInputStream.readShort();
            int i4 = i3 + 8;
            if (!z) {
                return i4;
            }
            HwmfBitmapDib hwmfBitmapDib = new HwmfBitmapDib();
            this.target = hwmfBitmapDib;
            return i4 + hwmfBitmapDib.init(littleEndianInputStream, (int) ((j - 6) - ((long) i4)));
        }
    }

    public static class WmfExtFloodFill implements HwmfRecord {
        public HwmfColorRef colorRef;
        public int mode;
        public int x;
        public int y;

        @Override // org.apache.poi.hwmf.record.HwmfRecord
        public void draw(HwmfGraphics hwmfGraphics) {
        }

        @Override // org.apache.poi.hwmf.record.HwmfRecord
        public HwmfRecordType getRecordType() {
            return HwmfRecordType.extFloodFill;
        }

        @Override // org.apache.poi.hwmf.record.HwmfRecord
        public int init(LittleEndianInputStream littleEndianInputStream, long j, int i2) {
            this.mode = littleEndianInputStream.readUShort();
            HwmfColorRef hwmfColorRef = new HwmfColorRef();
            this.colorRef = hwmfColorRef;
            int init = hwmfColorRef.init(littleEndianInputStream);
            this.y = littleEndianInputStream.readShort();
            this.x = littleEndianInputStream.readShort();
            return init + 6;
        }
    }

    public static class WmfFillRegion implements HwmfRecord {
        public int brushIndex;
        public int regionIndex;

        @Override // org.apache.poi.hwmf.record.HwmfRecord
        public void draw(HwmfGraphics hwmfGraphics) {
            hwmfGraphics.applyObjectTableEntry(this.regionIndex);
            hwmfGraphics.applyObjectTableEntry(this.brushIndex);
            Shape region = hwmfGraphics.getProperties().getRegion();
            if (region != null) {
                hwmfGraphics.fill(region);
            }
        }

        @Override // org.apache.poi.hwmf.record.HwmfRecord
        public HwmfRecordType getRecordType() {
            return HwmfRecordType.fillRegion;
        }

        @Override // org.apache.poi.hwmf.record.HwmfRecord
        public int init(LittleEndianInputStream littleEndianInputStream, long j, int i2) {
            this.regionIndex = littleEndianInputStream.readUShort();
            this.brushIndex = littleEndianInputStream.readUShort();
            return 4;
        }
    }

    public static class WmfFloodFill implements HwmfRecord {
        public HwmfColorRef colorRef;
        public int xStart;
        public int yStart;

        @Override // org.apache.poi.hwmf.record.HwmfRecord
        public void draw(HwmfGraphics hwmfGraphics) {
        }

        @Override // org.apache.poi.hwmf.record.HwmfRecord
        public HwmfRecordType getRecordType() {
            return HwmfRecordType.floodFill;
        }

        @Override // org.apache.poi.hwmf.record.HwmfRecord
        public int init(LittleEndianInputStream littleEndianInputStream, long j, int i2) {
            HwmfColorRef hwmfColorRef = new HwmfColorRef();
            this.colorRef = hwmfColorRef;
            int init = hwmfColorRef.init(littleEndianInputStream);
            this.yStart = littleEndianInputStream.readShort();
            this.xStart = littleEndianInputStream.readShort();
            return init + 4;
        }
    }

    public static class WmfInvertRegion implements HwmfRecord {
        public int region;

        @Override // org.apache.poi.hwmf.record.HwmfRecord
        public void draw(HwmfGraphics hwmfGraphics) {
        }

        @Override // org.apache.poi.hwmf.record.HwmfRecord
        public HwmfRecordType getRecordType() {
            return HwmfRecordType.invertRegion;
        }

        @Override // org.apache.poi.hwmf.record.HwmfRecord
        public int init(LittleEndianInputStream littleEndianInputStream, long j, int i2) {
            this.region = littleEndianInputStream.readUShort();
            return 2;
        }
    }

    public static class WmfPaintRegion implements HwmfRecord {
        public int regionIndex;

        @Override // org.apache.poi.hwmf.record.HwmfRecord
        public void draw(HwmfGraphics hwmfGraphics) {
            hwmfGraphics.applyObjectTableEntry(this.regionIndex);
            Shape region = hwmfGraphics.getProperties().getRegion();
            if (region != null) {
                hwmfGraphics.fill(region);
            }
        }

        @Override // org.apache.poi.hwmf.record.HwmfRecord
        public HwmfRecordType getRecordType() {
            return HwmfRecordType.paintRegion;
        }

        @Override // org.apache.poi.hwmf.record.HwmfRecord
        public int init(LittleEndianInputStream littleEndianInputStream, long j, int i2) {
            this.regionIndex = littleEndianInputStream.readUShort();
            return 2;
        }
    }

    public static class WmfPatBlt implements HwmfRecord {
        public static final /* synthetic */ boolean $assertionsDisabled = false;
        public int height;
        public HwmfTernaryRasterOp rasterOperation;
        public int width;
        public int xLeft;
        public int yLeft;

        @Override // org.apache.poi.hwmf.record.HwmfRecord
        public void draw(HwmfGraphics hwmfGraphics) {
        }

        @Override // org.apache.poi.hwmf.record.HwmfRecord
        public HwmfRecordType getRecordType() {
            return HwmfRecordType.patBlt;
        }

        @Override // org.apache.poi.hwmf.record.HwmfRecord
        public int init(LittleEndianInputStream littleEndianInputStream, long j, int i2) {
            littleEndianInputStream.readUShort();
            this.rasterOperation = HwmfTernaryRasterOp.valueOf(littleEndianInputStream.readUShort());
            this.height = littleEndianInputStream.readShort();
            this.width = littleEndianInputStream.readShort();
            this.yLeft = littleEndianInputStream.readShort();
            this.xLeft = littleEndianInputStream.readShort();
            return 12;
        }
    }

    public static class WmfSetDibToDev implements HwmfRecord, HwmfImageRecord, HwmfObjectTableEntry {
        public ColorUsage colorUsage;
        public HwmfBitmapDib dib;
        public int height;
        public int scanCount;
        public int startScan;
        public int width;
        public int xDest;
        public int xDib;
        public int yDest;
        public int yDib;

        @Override // org.apache.poi.hwmf.record.HwmfObjectTableEntry
        public void applyObject(HwmfGraphics hwmfGraphics) {
        }

        @Override // org.apache.poi.hwmf.record.HwmfRecord
        public void draw(HwmfGraphics hwmfGraphics) {
            hwmfGraphics.addObjectTableEntry(this);
        }

        @Override // org.apache.poi.hwmf.record.HwmfFill.HwmfImageRecord
        public BufferedImage getImage() {
            return this.dib.getImage();
        }

        @Override // org.apache.poi.hwmf.record.HwmfRecord
        public HwmfRecordType getRecordType() {
            return HwmfRecordType.setDibToDev;
        }

        @Override // org.apache.poi.hwmf.record.HwmfRecord
        public int init(LittleEndianInputStream littleEndianInputStream, long j, int i2) {
            this.colorUsage = ColorUsage.valueOf(littleEndianInputStream.readUShort());
            this.scanCount = littleEndianInputStream.readUShort();
            this.startScan = littleEndianInputStream.readUShort();
            this.yDib = littleEndianInputStream.readUShort();
            this.xDib = littleEndianInputStream.readUShort();
            this.height = littleEndianInputStream.readUShort();
            this.width = littleEndianInputStream.readUShort();
            this.yDest = littleEndianInputStream.readUShort();
            this.xDest = littleEndianInputStream.readUShort();
            HwmfBitmapDib hwmfBitmapDib = new HwmfBitmapDib();
            this.dib = hwmfBitmapDib;
            return hwmfBitmapDib.init(littleEndianInputStream, (int) ((j - 6) - ((long) 18))) + 18;
        }
    }

    public static class WmfSetPolyfillMode implements HwmfRecord {
        public HwmfPolyfillMode polyfillMode;

        public enum HwmfPolyfillMode {
            ALTERNATE(1, 0),
            WINDING(2, 1);
            
            public final int awtFlag;
            public final int wmfFlag;

            /* access modifiers changed from: public */
            HwmfPolyfillMode(int i2, int i3) {
                this.wmfFlag = i2;
                this.awtFlag = i3;
            }

            public static HwmfPolyfillMode valueOf(int i2) {
                HwmfPolyfillMode[] values = values();
                for (HwmfPolyfillMode hwmfPolyfillMode : values) {
                    if (hwmfPolyfillMode.wmfFlag == i2) {
                        return hwmfPolyfillMode;
                    }
                }
                return null;
            }
        }

        @Override // org.apache.poi.hwmf.record.HwmfRecord
        public void draw(HwmfGraphics hwmfGraphics) {
            hwmfGraphics.getProperties().setPolyfillMode(this.polyfillMode);
        }

        @Override // org.apache.poi.hwmf.record.HwmfRecord
        public HwmfRecordType getRecordType() {
            return HwmfRecordType.setPolyFillMode;
        }

        @Override // org.apache.poi.hwmf.record.HwmfRecord
        public int init(LittleEndianInputStream littleEndianInputStream, long j, int i2) {
            this.polyfillMode = HwmfPolyfillMode.valueOf(littleEndianInputStream.readUShort() & 3);
            return 2;
        }
    }

    public static class WmfStretchBlt implements HwmfRecord {
        public static final /* synthetic */ boolean $assertionsDisabled = false;
        public int destHeight;
        public int destWidth;
        public HwmfTernaryRasterOp rasterOperation;
        public int srcHeight;
        public int srcWidth;
        public HwmfBitmap16 target;
        public int xDest;
        public int xSrc;
        public int yDest;
        public int ySrc;

        @Override // org.apache.poi.hwmf.record.HwmfRecord
        public void draw(HwmfGraphics hwmfGraphics) {
        }

        @Override // org.apache.poi.hwmf.record.HwmfRecord
        public HwmfRecordType getRecordType() {
            return HwmfRecordType.stretchBlt;
        }

        @Override // org.apache.poi.hwmf.record.HwmfRecord
        public int init(LittleEndianInputStream littleEndianInputStream, long j, int i2) {
            boolean z = j > ((long) ((i2 >> 8) + 3));
            littleEndianInputStream.readUShort();
            this.rasterOperation = HwmfTernaryRasterOp.valueOf(littleEndianInputStream.readUShort());
            this.srcHeight = littleEndianInputStream.readShort();
            this.srcWidth = littleEndianInputStream.readShort();
            this.ySrc = littleEndianInputStream.readShort();
            this.xSrc = littleEndianInputStream.readShort();
            int i3 = 12;
            if (!z) {
                littleEndianInputStream.readShort();
                i3 = 14;
            }
            this.destHeight = littleEndianInputStream.readShort();
            this.destWidth = littleEndianInputStream.readShort();
            this.yDest = littleEndianInputStream.readShort();
            this.xDest = littleEndianInputStream.readShort();
            int i4 = i3 + 8;
            if (!z) {
                return i4;
            }
            HwmfBitmap16 hwmfBitmap16 = new HwmfBitmap16();
            this.target = hwmfBitmap16;
            return i4 + hwmfBitmap16.init(littleEndianInputStream);
        }
    }

    public static class WmfStretchDib implements HwmfRecord, HwmfImageRecord, HwmfObjectTableEntry {
        public static final /* synthetic */ boolean $assertionsDisabled = false;
        public ColorUsage colorUsage;
        public int destHeight;
        public int destWidth;
        public HwmfBitmapDib dib;
        public HwmfTernaryRasterOp rasterOperation;
        public int srcHeight;
        public int srcWidth;
        public int xDst;
        public int xSrc;
        public int yDst;
        public int ySrc;

        @Override // org.apache.poi.hwmf.record.HwmfObjectTableEntry
        public void applyObject(HwmfGraphics hwmfGraphics) {
        }

        @Override // org.apache.poi.hwmf.record.HwmfRecord
        public void draw(HwmfGraphics hwmfGraphics) {
            hwmfGraphics.addObjectTableEntry(this);
        }

        @Override // org.apache.poi.hwmf.record.HwmfFill.HwmfImageRecord
        public BufferedImage getImage() {
            return this.dib.getImage();
        }

        @Override // org.apache.poi.hwmf.record.HwmfRecord
        public HwmfRecordType getRecordType() {
            return HwmfRecordType.stretchDib;
        }

        @Override // org.apache.poi.hwmf.record.HwmfRecord
        public int init(LittleEndianInputStream littleEndianInputStream, long j, int i2) {
            littleEndianInputStream.readUShort();
            this.rasterOperation = HwmfTernaryRasterOp.valueOf(littleEndianInputStream.readUShort());
            this.colorUsage = ColorUsage.valueOf(littleEndianInputStream.readUShort());
            this.srcHeight = littleEndianInputStream.readShort();
            this.srcWidth = littleEndianInputStream.readShort();
            this.ySrc = littleEndianInputStream.readShort();
            this.xSrc = littleEndianInputStream.readShort();
            this.destHeight = littleEndianInputStream.readShort();
            this.destWidth = littleEndianInputStream.readShort();
            this.yDst = littleEndianInputStream.readShort();
            this.xDst = littleEndianInputStream.readShort();
            HwmfBitmapDib hwmfBitmapDib = new HwmfBitmapDib();
            this.dib = hwmfBitmapDib;
            return hwmfBitmapDib.init(littleEndianInputStream, (int) ((j - 6) - ((long) 22))) + 22;
        }
    }
}
