package org.apache.poi.hwmf.record;

import org.apache.poi.util.BitField;
import org.apache.poi.util.BitFieldFactory;

public class HwmfPenStyle implements Cloneable {
    public static final BitField SUBSECTION_ALTERNATE = BitFieldFactory.getInstance(8);
    public static final BitField SUBSECTION_DASH = BitFieldFactory.getInstance(7);
    public static final BitField SUBSECTION_ENDCAP = BitFieldFactory.getInstance(768);
    public static final BitField SUBSECTION_JOIN = BitFieldFactory.getInstance(12288);
    public int flag;

    public enum HwmfLineCap {
        ROUND(0, 1),
        SQUARE(1, 2),
        FLAT(2, 0);
        
        public final int awtFlag;
        public final int wmfFlag;

        /* access modifiers changed from: public */
        HwmfLineCap(int i2, int i3) {
            this.wmfFlag = i2;
            this.awtFlag = i3;
        }

        public static HwmfLineCap valueOf(int i2) {
            HwmfLineCap[] values = values();
            for (HwmfLineCap hwmfLineCap : values) {
                if (hwmfLineCap.wmfFlag == i2) {
                    return hwmfLineCap;
                }
            }
            return null;
        }
    }

    public enum HwmfLineDash {
        SOLID(0, null),
        DASH(1, 10.0f, 8.0f),
        DOT(2, 2.0f, 4.0f),
        DASHDOT(3, 10.0f, 8.0f, 2.0f, 8.0f),
        DASHDOTDOT(4, 10.0f, 4.0f, 2.0f, 4.0f, 2.0f, 4.0f),
        NULL(5, null),
        INSIDEFRAME(6, null),
        USERSTYLE(7, null);
        
        public final float[] dashes;
        public final int wmfFlag;

        /* access modifiers changed from: public */
        HwmfLineDash(int i2, float... fArr) {
            this.wmfFlag = i2;
            this.dashes = fArr;
        }

        public static HwmfLineDash valueOf(int i2) {
            HwmfLineDash[] values = values();
            for (HwmfLineDash hwmfLineDash : values) {
                if (hwmfLineDash.wmfFlag == i2) {
                    return hwmfLineDash;
                }
            }
            return null;
        }
    }

    public enum HwmfLineJoin {
        ROUND(0, 1),
        BEVEL(1, 2),
        MITER(2, 0);
        
        public final int awtFlag;
        public final int wmfFlag;

        /* access modifiers changed from: public */
        HwmfLineJoin(int i2, int i3) {
            this.wmfFlag = i2;
            this.awtFlag = i3;
        }

        public static HwmfLineJoin valueOf(int i2) {
            HwmfLineJoin[] values = values();
            for (HwmfLineJoin hwmfLineJoin : values) {
                if (hwmfLineJoin.wmfFlag == i2) {
                    return hwmfLineJoin;
                }
            }
            return null;
        }
    }

    public static HwmfPenStyle valueOf(int i2) {
        HwmfPenStyle hwmfPenStyle = new HwmfPenStyle();
        hwmfPenStyle.flag = i2;
        return hwmfPenStyle;
    }

    public HwmfLineCap getLineCap() {
        return HwmfLineCap.valueOf(SUBSECTION_ENDCAP.getValue(this.flag));
    }

    public HwmfLineDash getLineDash() {
        return HwmfLineDash.valueOf(SUBSECTION_DASH.getValue(this.flag));
    }

    public HwmfLineJoin getLineJoin() {
        return HwmfLineJoin.valueOf(SUBSECTION_JOIN.getValue(this.flag));
    }

    public boolean isAlternateDash() {
        return SUBSECTION_ALTERNATE.isSet(this.flag);
    }

    @Override // java.lang.Object
    public HwmfPenStyle clone() {
        try {
            return (HwmfPenStyle) super.clone();
        } catch (CloneNotSupportedException unused) {
            throw new InternalError();
        }
    }
}
