package org.apache.poi.hwmf.record;

import java.awt.Shape;
import java.awt.geom.Area;
import java.awt.geom.Rectangle2D;
import org.apache.poi.hwmf.draw.HwmfGraphics;
import org.apache.poi.ss.formula.functions.NumericFunction;
import org.apache.poi.util.LittleEndianInputStream;

public class HwmfWindowing {

    public static class WmfCreateRegion implements HwmfRecord, HwmfObjectTableEntry {
        public int bottom;
        public int left;
        public int maxScan;
        public int nextInChain;
        public int objectCount;
        public int objectType;
        public int regionSize;
        public int right;
        public int scanCount;
        public WmfScanObject[] scanObjects;
        public int top;

        @Override // org.apache.poi.hwmf.record.HwmfObjectTableEntry
        public void applyObject(HwmfGraphics hwmfGraphics) {
            Shape shape;
            Shape area = new Area();
            WmfScanObject[] wmfScanObjectArr = this.scanObjects;
            int length = wmfScanObjectArr.length;
            int i2 = 0;
            int i3 = 0;
            Shape shape2 = null;
            while (true) {
                int i4 = 1;
                if (i2 >= length) {
                    break;
                }
                WmfScanObject wmfScanObject = wmfScanObjectArr[i2];
                int min = Math.min(wmfScanObject.top, wmfScanObject.bottom);
                int abs = Math.abs((wmfScanObject.top - wmfScanObject.bottom) - 1);
                int i5 = 0;
                while (i5 < wmfScanObject.count / 2) {
                    shape2 = r15;
                    Shape shape3 = new Rectangle2D.Double((double) Math.min(wmfScanObject.left_scanline[i5], wmfScanObject.right_scanline[i5]), (double) min, (double) Math.abs((wmfScanObject.right_scanline[i5] - wmfScanObject.left_scanline[i5]) - i4), (double) abs);
                    area.add(new Area(shape2));
                    i3++;
                    i5++;
                    wmfScanObject = wmfScanObject;
                    wmfScanObjectArr = wmfScanObjectArr;
                    i4 = 1;
                }
                i2++;
            }
            if (i3 > 0) {
                if (i3 == 1) {
                    area = shape2;
                }
                shape = area;
            } else {
                shape = null;
            }
            hwmfGraphics.getProperties().setRegion(shape);
        }

        @Override // org.apache.poi.hwmf.record.HwmfRecord
        public void draw(HwmfGraphics hwmfGraphics) {
            hwmfGraphics.addObjectTableEntry(this);
        }

        @Override // org.apache.poi.hwmf.record.HwmfRecord
        public HwmfRecordType getRecordType() {
            return HwmfRecordType.createRegion;
        }

        @Override // org.apache.poi.hwmf.record.HwmfRecord
        public int init(LittleEndianInputStream littleEndianInputStream, long j, int i2) {
            this.nextInChain = littleEndianInputStream.readShort();
            this.objectType = littleEndianInputStream.readShort();
            this.objectCount = littleEndianInputStream.readInt();
            this.regionSize = littleEndianInputStream.readShort();
            this.scanCount = littleEndianInputStream.readShort();
            this.maxScan = littleEndianInputStream.readShort();
            this.left = littleEndianInputStream.readShort();
            this.top = littleEndianInputStream.readShort();
            this.right = littleEndianInputStream.readShort();
            this.bottom = littleEndianInputStream.readShort();
            this.scanObjects = new WmfScanObject[this.scanCount];
            int i3 = 22;
            for (int i4 = 0; i4 < this.scanCount; i4++) {
                WmfScanObject[] wmfScanObjectArr = this.scanObjects;
                WmfScanObject wmfScanObject = new WmfScanObject();
                wmfScanObjectArr[i4] = wmfScanObject;
                i3 += wmfScanObject.init(littleEndianInputStream);
            }
            return i3;
        }
    }

    public static class WmfExcludeClipRect implements HwmfRecord, HwmfObjectTableEntry {
        public int bottom;
        public int left;
        public int right;
        public int top;

        @Override // org.apache.poi.hwmf.record.HwmfObjectTableEntry
        public void applyObject(HwmfGraphics hwmfGraphics) {
        }

        @Override // org.apache.poi.hwmf.record.HwmfRecord
        public void draw(HwmfGraphics hwmfGraphics) {
            hwmfGraphics.addObjectTableEntry(this);
        }

        @Override // org.apache.poi.hwmf.record.HwmfRecord
        public HwmfRecordType getRecordType() {
            return HwmfRecordType.excludeClipRect;
        }

        @Override // org.apache.poi.hwmf.record.HwmfRecord
        public int init(LittleEndianInputStream littleEndianInputStream, long j, int i2) {
            this.bottom = littleEndianInputStream.readShort();
            this.right = littleEndianInputStream.readShort();
            this.top = littleEndianInputStream.readShort();
            this.left = littleEndianInputStream.readShort();
            return 8;
        }
    }

    public static class WmfIntersectClipRect implements HwmfRecord, HwmfObjectTableEntry {
        public int bottom;
        public int left;
        public int right;
        public int top;

        @Override // org.apache.poi.hwmf.record.HwmfObjectTableEntry
        public void applyObject(HwmfGraphics hwmfGraphics) {
        }

        @Override // org.apache.poi.hwmf.record.HwmfRecord
        public void draw(HwmfGraphics hwmfGraphics) {
            hwmfGraphics.addObjectTableEntry(this);
        }

        @Override // org.apache.poi.hwmf.record.HwmfRecord
        public HwmfRecordType getRecordType() {
            return HwmfRecordType.intersectClipRect;
        }

        @Override // org.apache.poi.hwmf.record.HwmfRecord
        public int init(LittleEndianInputStream littleEndianInputStream, long j, int i2) {
            this.bottom = littleEndianInputStream.readShort();
            this.right = littleEndianInputStream.readShort();
            this.top = littleEndianInputStream.readShort();
            this.left = littleEndianInputStream.readShort();
            return 8;
        }
    }

    public static class WmfOffsetClipRgn implements HwmfRecord, HwmfObjectTableEntry {
        public int xOffset;
        public int yOffset;

        @Override // org.apache.poi.hwmf.record.HwmfObjectTableEntry
        public void applyObject(HwmfGraphics hwmfGraphics) {
        }

        @Override // org.apache.poi.hwmf.record.HwmfRecord
        public void draw(HwmfGraphics hwmfGraphics) {
            hwmfGraphics.addObjectTableEntry(this);
        }

        @Override // org.apache.poi.hwmf.record.HwmfRecord
        public HwmfRecordType getRecordType() {
            return HwmfRecordType.offsetClipRgn;
        }

        @Override // org.apache.poi.hwmf.record.HwmfRecord
        public int init(LittleEndianInputStream littleEndianInputStream, long j, int i2) {
            this.yOffset = littleEndianInputStream.readShort();
            this.xOffset = littleEndianInputStream.readShort();
            return 4;
        }
    }

    public static class WmfOffsetViewportOrg implements HwmfRecord {
        public int xOffset;
        public int yOffset;

        @Override // org.apache.poi.hwmf.record.HwmfRecord
        public void draw(HwmfGraphics hwmfGraphics) {
            double d2;
            Rectangle2D viewport = hwmfGraphics.getProperties().getViewport();
            double d3 = NumericFunction.LOG_10_TO_BASE_e;
            if (viewport == null) {
                d2 = 0.0d;
            } else {
                d2 = viewport.getX();
            }
            if (viewport != null) {
                d3 = viewport.getY();
            }
            hwmfGraphics.getProperties().setViewportOrg(d2 + ((double) this.xOffset), d3 + ((double) this.yOffset));
        }

        @Override // org.apache.poi.hwmf.record.HwmfRecord
        public HwmfRecordType getRecordType() {
            return HwmfRecordType.offsetViewportOrg;
        }

        @Override // org.apache.poi.hwmf.record.HwmfRecord
        public int init(LittleEndianInputStream littleEndianInputStream, long j, int i2) {
            this.yOffset = littleEndianInputStream.readShort();
            this.xOffset = littleEndianInputStream.readShort();
            return 4;
        }
    }

    public static class WmfOffsetWindowOrg implements HwmfRecord {
        public int xOffset;
        public int yOffset;

        @Override // org.apache.poi.hwmf.record.HwmfRecord
        public void draw(HwmfGraphics hwmfGraphics) {
            Rectangle2D window = hwmfGraphics.getProperties().getWindow();
            hwmfGraphics.getProperties().setWindowOrg(window.getX() + ((double) this.xOffset), window.getY() + ((double) this.yOffset));
            hwmfGraphics.updateWindowMapMode();
        }

        @Override // org.apache.poi.hwmf.record.HwmfRecord
        public HwmfRecordType getRecordType() {
            return HwmfRecordType.offsetWindowOrg;
        }

        @Override // org.apache.poi.hwmf.record.HwmfRecord
        public int init(LittleEndianInputStream littleEndianInputStream, long j, int i2) {
            this.yOffset = littleEndianInputStream.readShort();
            this.xOffset = littleEndianInputStream.readShort();
            return 4;
        }
    }

    public static class WmfScaleViewportExt implements HwmfRecord {
        public int xDenom;
        public int xNum;
        public int yDenom;
        public int yNum;

        @Override // org.apache.poi.hwmf.record.HwmfRecord
        public void draw(HwmfGraphics hwmfGraphics) {
            Rectangle2D viewport = hwmfGraphics.getProperties().getViewport();
            if (viewport == null) {
                viewport = hwmfGraphics.getProperties().getWindow();
            }
            hwmfGraphics.getProperties().setViewportExt((viewport.getWidth() * ((double) this.xNum)) / ((double) this.xDenom), (viewport.getHeight() * ((double) this.yNum)) / ((double) this.yDenom));
        }

        @Override // org.apache.poi.hwmf.record.HwmfRecord
        public HwmfRecordType getRecordType() {
            return HwmfRecordType.scaleViewportExt;
        }

        @Override // org.apache.poi.hwmf.record.HwmfRecord
        public int init(LittleEndianInputStream littleEndianInputStream, long j, int i2) {
            this.yDenom = littleEndianInputStream.readShort();
            this.yNum = littleEndianInputStream.readShort();
            this.xDenom = littleEndianInputStream.readShort();
            this.xNum = littleEndianInputStream.readShort();
            return 8;
        }
    }

    public static class WmfScaleWindowExt implements HwmfRecord {
        public int xDenom;
        public int xNum;
        public int yDenom;
        public int yNum;

        @Override // org.apache.poi.hwmf.record.HwmfRecord
        public void draw(HwmfGraphics hwmfGraphics) {
            Rectangle2D window = hwmfGraphics.getProperties().getWindow();
            hwmfGraphics.getProperties().setWindowExt((window.getWidth() * ((double) this.xNum)) / ((double) this.xDenom), (window.getHeight() * ((double) this.yNum)) / ((double) this.yDenom));
            hwmfGraphics.updateWindowMapMode();
        }

        @Override // org.apache.poi.hwmf.record.HwmfRecord
        public HwmfRecordType getRecordType() {
            return HwmfRecordType.scaleWindowExt;
        }

        @Override // org.apache.poi.hwmf.record.HwmfRecord
        public int init(LittleEndianInputStream littleEndianInputStream, long j, int i2) {
            this.yDenom = littleEndianInputStream.readShort();
            this.yNum = littleEndianInputStream.readShort();
            this.xDenom = littleEndianInputStream.readShort();
            this.xNum = littleEndianInputStream.readShort();
            return 8;
        }
    }

    public static class WmfScanObject {
        public int bottom;
        public int count;
        public int count2;
        public int[] left_scanline;
        public int[] right_scanline;
        public int top;

        public int init(LittleEndianInputStream littleEndianInputStream) {
            this.count = littleEndianInputStream.readUShort();
            this.top = littleEndianInputStream.readUShort();
            this.bottom = littleEndianInputStream.readUShort();
            int i2 = this.count;
            this.left_scanline = new int[(i2 / 2)];
            this.right_scanline = new int[(i2 / 2)];
            int i3 = 6;
            for (int i4 = 0; i4 < this.count / 2; i4++) {
                this.left_scanline[i4] = littleEndianInputStream.readUShort();
                this.right_scanline[i4] = littleEndianInputStream.readUShort();
                i3 += 4;
            }
            this.count2 = littleEndianInputStream.readUShort();
            return i3 + 2;
        }
    }

    public static class WmfSelectClipRegion implements HwmfRecord {
        public int region;

        @Override // org.apache.poi.hwmf.record.HwmfRecord
        public void draw(HwmfGraphics hwmfGraphics) {
        }

        @Override // org.apache.poi.hwmf.record.HwmfRecord
        public HwmfRecordType getRecordType() {
            return HwmfRecordType.selectClipRegion;
        }

        @Override // org.apache.poi.hwmf.record.HwmfRecord
        public int init(LittleEndianInputStream littleEndianInputStream, long j, int i2) {
            this.region = littleEndianInputStream.readShort();
            return 2;
        }
    }

    public static class WmfSetViewportExt implements HwmfRecord {
        public int height;
        public int width;

        @Override // org.apache.poi.hwmf.record.HwmfRecord
        public void draw(HwmfGraphics hwmfGraphics) {
            hwmfGraphics.getProperties().setViewportExt((double) this.width, (double) this.height);
        }

        @Override // org.apache.poi.hwmf.record.HwmfRecord
        public HwmfRecordType getRecordType() {
            return HwmfRecordType.setViewportExt;
        }

        @Override // org.apache.poi.hwmf.record.HwmfRecord
        public int init(LittleEndianInputStream littleEndianInputStream, long j, int i2) {
            this.height = littleEndianInputStream.readShort();
            this.width = littleEndianInputStream.readShort();
            return 4;
        }
    }

    public static class WmfSetViewportOrg implements HwmfRecord {
        public int x;
        public int y;

        @Override // org.apache.poi.hwmf.record.HwmfRecord
        public void draw(HwmfGraphics hwmfGraphics) {
            hwmfGraphics.getProperties().setViewportOrg((double) this.x, (double) this.y);
        }

        @Override // org.apache.poi.hwmf.record.HwmfRecord
        public HwmfRecordType getRecordType() {
            return HwmfRecordType.setViewportOrg;
        }

        @Override // org.apache.poi.hwmf.record.HwmfRecord
        public int init(LittleEndianInputStream littleEndianInputStream, long j, int i2) {
            this.y = littleEndianInputStream.readShort();
            this.x = littleEndianInputStream.readShort();
            return 4;
        }
    }

    public static class WmfSetWindowExt implements HwmfRecord {
        public int height;
        public int width;

        @Override // org.apache.poi.hwmf.record.HwmfRecord
        public void draw(HwmfGraphics hwmfGraphics) {
            hwmfGraphics.getProperties().setWindowExt((double) this.width, (double) this.height);
            hwmfGraphics.updateWindowMapMode();
        }

        public int getHeight() {
            return this.height;
        }

        @Override // org.apache.poi.hwmf.record.HwmfRecord
        public HwmfRecordType getRecordType() {
            return HwmfRecordType.setWindowExt;
        }

        public int getWidth() {
            return this.width;
        }

        @Override // org.apache.poi.hwmf.record.HwmfRecord
        public int init(LittleEndianInputStream littleEndianInputStream, long j, int i2) {
            this.height = littleEndianInputStream.readShort();
            this.width = littleEndianInputStream.readShort();
            return 4;
        }
    }

    public static class WmfSetWindowOrg implements HwmfRecord {
        public int x;
        public int y;

        @Override // org.apache.poi.hwmf.record.HwmfRecord
        public void draw(HwmfGraphics hwmfGraphics) {
            hwmfGraphics.getProperties().setWindowOrg((double) this.x, (double) this.y);
            hwmfGraphics.updateWindowMapMode();
        }

        @Override // org.apache.poi.hwmf.record.HwmfRecord
        public HwmfRecordType getRecordType() {
            return HwmfRecordType.setWindowOrg;
        }

        public int getX() {
            return this.x;
        }

        public int getY() {
            return this.y;
        }

        @Override // org.apache.poi.hwmf.record.HwmfRecord
        public int init(LittleEndianInputStream littleEndianInputStream, long j, int i2) {
            this.y = littleEndianInputStream.readShort();
            this.x = littleEndianInputStream.readShort();
            return 4;
        }
    }
}
