package org.apache.poi.hwpf.converter;

import b.b.a.a.a;
import java.io.File;
import java.io.FileInputStream;
import java.io.InputStream;
import java.util.HashMap;
import java.util.Map;
import java.util.TreeSet;
import org.apache.poi.hwpf.HWPFDocument;
import org.apache.poi.hwpf.HWPFDocumentCore;
import org.apache.poi.hwpf.HWPFOldDocument;
import org.apache.poi.hwpf.OldWordFileFormatException;
import org.apache.poi.hwpf.usermodel.BorderCode;
import org.apache.poi.hwpf.usermodel.HWPFList;
import org.apache.poi.hwpf.usermodel.Table;
import org.apache.poi.hwpf.usermodel.TableCell;
import org.apache.poi.hwpf.usermodel.TableRow;
import org.apache.poi.poifs.filesystem.DirectoryNode;
import org.apache.poi.poifs.filesystem.POIFSFileSystem;
import org.apache.poi.ss.usermodel.DataFormatter;
import org.apache.poi.ss.util.NormalisedDecimal;
import org.apache.poi.ss.util.SheetUtil;
import org.apache.poi.util.POILogFactory;
import org.apache.poi.util.POILogger;
import org.w3c.dom.Attr;
import org.w3c.dom.Element;
import org.w3c.dom.NamedNodeMap;
import org.w3c.dom.Node;
import org.w3c.dom.NodeList;

public class AbstractWordUtils {
    public static final String EMPTY = "";
    public static final float TWIPS_PER_INCH = 1440.0f;
    public static final int TWIPS_PER_PT = 20;
    public static final POILogger logger = POILogFactory.getLogger(AbstractWordUtils.class);

    public static class NumberingState {
        public final Map<String, Integer> levels = new HashMap();
    }

    public static int[] buildTableCellEdgesArray(Table table) {
        TreeSet treeSet = new TreeSet();
        for (int i2 = 0; i2 < table.numRows(); i2++) {
            TableRow row = table.getRow(i2);
            for (int i3 = 0; i3 < row.numCells(); i3++) {
                TableCell cell = row.getCell(i3);
                treeSet.add(Integer.valueOf(cell.getLeftEdge()));
                treeSet.add(Integer.valueOf(cell.getWidth() + cell.getLeftEdge()));
            }
        }
        Integer[] numArr = (Integer[]) treeSet.toArray(new Integer[treeSet.size()]);
        int[] iArr = new int[numArr.length];
        for (int i4 = 0; i4 < numArr.length; i4++) {
            iArr[i4] = numArr[i4].intValue();
        }
        return iArr;
    }

    public static boolean canBeMerged(Node node, Node node2, String str) {
        Attr attr;
        if (node.getNodeType() == 1 && node2.getNodeType() == 1) {
            Element element = (Element) node;
            Element element2 = (Element) node2;
            if (equals(str, element.getTagName()) && equals(str, element2.getTagName())) {
                NamedNodeMap attributes = element.getAttributes();
                NamedNodeMap attributes2 = element2.getAttributes();
                if (attributes.getLength() != attributes2.getLength()) {
                    return false;
                }
                for (int i2 = 0; i2 < attributes.getLength(); i2++) {
                    Attr attr2 = (Attr) attributes.item(i2);
                    if (isNotEmpty(attr2.getNamespaceURI())) {
                        attr = (Attr) attributes2.getNamedItemNS(attr2.getNamespaceURI(), attr2.getLocalName());
                    } else {
                        attr = (Attr) attributes2.getNamedItem(attr2.getName());
                    }
                    if (attr == null || !equals(attr2.getTextContent(), attr.getTextContent())) {
                        return false;
                    }
                }
                return true;
            }
        }
        return false;
    }

    public static void compactChildNodesR(Element element, String str) {
        NodeList childNodes = element.getChildNodes();
        int i2 = 0;
        while (i2 < childNodes.getLength() - 1) {
            Node item = childNodes.item(i2);
            Node item2 = childNodes.item(i2 + 1);
            if (canBeMerged(item, item2, str)) {
                while (item2.getChildNodes().getLength() > 0) {
                    item.appendChild(item2.getFirstChild());
                }
                item2.getParentNode().removeChild(item2);
                i2--;
            }
            i2++;
        }
        NodeList childNodes2 = element.getChildNodes();
        for (int i3 = 0; i3 < childNodes2.getLength() - 1; i3++) {
            Node item3 = childNodes2.item(i3);
            if (item3 instanceof Element) {
                compactChildNodesR((Element) item3, str);
            }
        }
    }

    public static boolean equals(String str, String str2) {
        if (str == null) {
            return str2 == null;
        }
        return str.equals(str2);
    }

    public static String getBorderType(BorderCode borderCode) {
        if (borderCode != null) {
            switch (borderCode.getBorderType()) {
                case 3:
                    return "double";
                case 4:
                case 5:
                case 20:
                default:
                    return "solid";
                case 6:
                    return "dotted";
                case 7:
                case 8:
                    return "dashed";
                case 9:
                    return "dotted";
                case 10:
                case 11:
                case 12:
                case 13:
                case 14:
                case 15:
                case 16:
                case 17:
                case 18:
                case 19:
                case 21:
                    return "double";
                case 22:
                case 23:
                    return "dashed";
                case 24:
                    return "ridge";
                case 25:
                    return "grooved";
            }
        } else {
            throw new IllegalArgumentException("borderCode is null");
        }
    }

    public static String getBorderWidth(BorderCode borderCode) {
        int lineWidth = borderCode.getLineWidth();
        int i2 = lineWidth / 8;
        return i2 + "." + ((lineWidth - (i2 * 8)) * 125) + "pt";
    }

    /* JADX DEBUG: Failed to insert an additional move for type inference into block B:12:0x006c */
    /* JADX DEBUG: Multi-variable search result rejected for r1v1, resolved type: char[] */
    /* JADX DEBUG: Multi-variable search result rejected for r4v0, resolved type: char */
    /* JADX DEBUG: Multi-variable search result rejected for r7v2, resolved type: java.lang.StringBuilder */
    /* JADX WARN: Multi-variable type inference failed */
    /* JADX WARN: Type inference failed for: r4v3 */
    /* JADX WARN: Type inference failed for: r4v4, types: [int] */
    public static String getBulletText(NumberingState numberingState, HWPFList hWPFList, char c) {
        int i2;
        StringBuffer stringBuffer = new StringBuffer();
        char[] charArray = hWPFList.getNumberText(c).toCharArray();
        for (char c2 : charArray) {
            if (c2 < 9) {
                int lsid = hWPFList.getLsid();
                String str = lsid + DataFormatter.defaultFractionWholePartFormat + ((int) c2);
                if (hWPFList.isStartAtOverriden(c2) || !numberingState.levels.containsKey(str)) {
                    i2 = hWPFList.getStartAt(c2);
                    numberingState.levels.put(str, Integer.valueOf(i2));
                } else {
                    i2 = ((Integer) numberingState.levels.get(str)).intValue();
                    if (c == c2) {
                        i2++;
                        numberingState.levels.put(str, Integer.valueOf(i2));
                    }
                }
                if (c == c2) {
                    while (true) {
                        c2 = (c2 == true ? 1 : 0) + 1;
                        if (c2 >= 9) {
                            break;
                        }
                        numberingState.levels.remove(lsid + DataFormatter.defaultFractionWholePartFormat + ((int) c2));
                    }
                }
                stringBuffer.append(NumberFormatter.getNumber(i2, hWPFList.getNumberFormat(c)));
            } else {
                stringBuffer.append(c2);
            }
        }
        byte typeOfCharFollowingTheNumber = hWPFList.getTypeOfCharFollowingTheNumber(c);
        if (typeOfCharFollowingTheNumber == 0) {
            stringBuffer.append("\t");
        } else if (typeOfCharFollowingTheNumber == 1) {
            stringBuffer.append(" ");
        }
        return stringBuffer.toString();
    }

    public static String getColor(int i2) {
        switch (i2) {
            case 2:
                return "blue";
            case 3:
                return "cyan";
            case 4:
                return "green";
            case 5:
                return "magenta";
            case 6:
                return "red";
            case 7:
                return "yellow";
            case 8:
                return "white";
            case 9:
                return "darkblue";
            case 10:
                return "darkcyan";
            case 11:
                return "darkgreen";
            case 12:
                return "darkmagenta";
            case 13:
                return "darkred";
            case 14:
                return "darkyellow";
            case 15:
                return "darkgray";
            case 16:
                return "lightgray";
            default:
                return "black";
        }
    }

    public static String getColor24(int i2) {
        if (i2 != -1) {
            int i3 = i2 & 16777215;
            int i4 = ((i3 & 16711680) >> 16) | ((i3 & 255) << 16) | (65280 & i3);
            switch (i4) {
                case 0:
                    return "black";
                case 128:
                    return "navy";
                case 255:
                    return "blue";
                case 32768:
                    return "green";
                case 32896:
                    return "teal";
                case 65280:
                    return "lime";
                case 65535:
                    return "aqua";
                case NormalisedDecimal.FRAC_HALF /*{ENCODED_INT: 8388608}*/:
                    return "maroon";
                case 8388736:
                    return "purple";
                case 8421376:
                    return "olive";
                case 8421504:
                    return "gray";
                case 12632256:
                    return "silver";
                case 16711680:
                    return "red";
                case 16711935:
                    return "fuchsia";
                case 16776960:
                    return "yellow";
                case 16777215:
                    return "white";
                default:
                    StringBuilder sb = new StringBuilder(DataFormatter.defaultFractionWholePartFormat);
                    String hexString = Integer.toHexString(i4);
                    for (int length = hexString.length(); length < 6; length++) {
                        sb.append(SheetUtil.defaultChar);
                    }
                    sb.append(hexString);
                    return sb.toString();
            }
        } else {
            throw new IllegalArgumentException("This colorref is empty");
        }
    }

    public static String getJustification(int i2) {
        switch (i2) {
            case 0:
                return "start";
            case 1:
                return "center";
            case 2:
                return "end";
            case 3:
            case 4:
                return "justify";
            case 5:
                return "center";
            case 6:
                return "left";
            case 7:
                return "start";
            case 8:
                return "end";
            case 9:
                return "justify";
            default:
                return "";
        }
    }

    public static String getLanguage(int i2) {
        if (i2 == 1024) {
            return "";
        }
        if (i2 == 1033) {
            return "en-us";
        }
        if (i2 == 1049) {
            return "ru-ru";
        }
        if (i2 == 2057) {
            return "en-uk";
        }
        logger.log(5, "Uknown or unmapped language code: ", Integer.valueOf(i2));
        return "";
    }

    public static String getListItemNumberLabel(int i2, int i3) {
        if (i3 != 0) {
            logger.log(3, a.c("NYI: toListItemNumberLabel(): ", i3));
        }
        return String.valueOf(i2);
    }

    public static String getOpacity(int i2) {
        int i3 = (int) ((((long) i2) & 4278190080L) >>> 24);
        if (i3 == 0 || i3 == 255) {
            return ".0";
        }
        StringBuilder b2 = a.b("");
        b2.append(((float) i3) / 255.0f);
        return b2.toString();
    }

    public static boolean isEmpty(String str) {
        return str == null || str.length() == 0;
    }

    public static boolean isNotEmpty(String str) {
        return !isEmpty(str);
    }

    public static HWPFDocumentCore loadDoc(DirectoryNode directoryNode) {
        try {
            return new HWPFDocument(directoryNode);
        } catch (OldWordFileFormatException unused) {
            return new HWPFOldDocument(directoryNode);
        }
    }

    public static String substringBeforeLast(String str, String str2) {
        int lastIndexOf;
        if (isEmpty(str) || isEmpty(str2) || (lastIndexOf = str.lastIndexOf(str2)) == -1) {
            return str;
        }
        return str.substring(0, lastIndexOf);
    }

    public static HWPFDocumentCore loadDoc(File file) {
        FileInputStream fileInputStream = new FileInputStream(file);
        try {
            return loadDoc(fileInputStream);
        } finally {
            fileInputStream.close();
        }
    }

    public static HWPFDocumentCore loadDoc(InputStream inputStream) {
        return loadDoc(HWPFDocumentCore.verifyAndBuildPOIFS(inputStream));
    }

    public static HWPFDocumentCore loadDoc(POIFSFileSystem pOIFSFileSystem) {
        return loadDoc(pOIFSFileSystem.getRoot());
    }
}
