package org.apache.poi.hwpf.converter;

import b.b.a.a.a;
import java.util.LinkedHashMap;
import java.util.Map;
import org.apache.xmlbeans.impl.jam.xml.JamXmlElements;
import org.apache.xmlbeans.impl.schema.SoapEncSchemaTypeSystem;
import org.w3c.dom.Document;
import org.w3c.dom.Element;
import org.w3c.dom.Text;

public class HtmlDocumentFacade {
    public final Element body;
    public final Document document;
    public final Element head;
    public final Element html;
    public Map<String, Map<String, String>> stylesheet = new LinkedHashMap();
    public Element stylesheetElement;
    public Element title;
    public Text titleText;

    public HtmlDocumentFacade(Document document2) {
        this.document = document2;
        Element createElement = document2.createElement("html");
        this.html = createElement;
        document2.appendChild(createElement);
        this.body = document2.createElement("body");
        this.head = document2.createElement("head");
        Element createElement2 = document2.createElement("style");
        this.stylesheetElement = createElement2;
        createElement2.setAttribute(JamXmlElements.TYPE, "text/css");
        this.html.appendChild(this.head);
        this.html.appendChild(this.body);
        this.head.appendChild(this.stylesheetElement);
        addStyleClass(this.body, "b", "white-space-collapsing:preserve;");
    }

    public void addAuthor(String str) {
        addMeta("author", str);
    }

    public void addDescription(String str) {
        addMeta("description", str);
    }

    public void addKeywords(String str) {
        addMeta("keywords", str);
    }

    public void addMeta(String str, String str2) {
        Element createElement = this.document.createElement("meta");
        createElement.setAttribute("name", str);
        createElement.setAttribute("content", str2);
        this.head.appendChild(createElement);
    }

    public void addStyleClass(Element element, String str, String str2) {
        String attribute = element.getAttribute(JamXmlElements.CLASS);
        String orCreateCssClass = getOrCreateCssClass(str, str2);
        if (!AbstractWordUtils.isEmpty(attribute)) {
            orCreateCssClass = a.b(attribute, " ", orCreateCssClass);
        }
        element.setAttribute(JamXmlElements.CLASS, orCreateCssClass);
    }

    public String buildStylesheet(Map<String, Map<String, String>> map) {
        StringBuilder sb = new StringBuilder();
        for (Map<String, String> map2 : map.values()) {
            for (Map.Entry<String, String> entry : map2.entrySet()) {
                sb.append(".");
                sb.append(entry.getValue());
                sb.append("{");
                sb.append(entry.getKey());
                sb.append("}\n");
            }
        }
        return sb.toString();
    }

    public Element createBlock() {
        return this.document.createElement("div");
    }

    public Element createBookmark(String str) {
        Element createElement = this.document.createElement("a");
        createElement.setAttribute("name", str);
        return createElement;
    }

    public Element createHeader1() {
        return this.document.createElement("h1");
    }

    public Element createHeader2() {
        return this.document.createElement("h2");
    }

    public Element createHyperlink(String str) {
        Element createElement = this.document.createElement("a");
        createElement.setAttribute(SoapEncSchemaTypeSystem.ATTR_HREF, str);
        return createElement;
    }

    public Element createImage(String str) {
        Element createElement = this.document.createElement("img");
        createElement.setAttribute("src", str);
        return createElement;
    }

    public Element createLineBreak() {
        return this.document.createElement("br");
    }

    public Element createListItem() {
        return this.document.createElement("li");
    }

    public Element createOption(String str, boolean z) {
        Element createElement = this.document.createElement("option");
        createElement.appendChild(createText(str));
        if (z) {
            createElement.setAttribute("selected", "selected");
        }
        return createElement;
    }

    public Element createParagraph() {
        return this.document.createElement("p");
    }

    public Element createSelect() {
        return this.document.createElement("select");
    }

    public Element createTable() {
        return this.document.createElement("table");
    }

    public Element createTableBody() {
        return this.document.createElement("tbody");
    }

    public Element createTableCell() {
        return this.document.createElement("td");
    }

    public Element createTableColumn() {
        return this.document.createElement("col");
    }

    public Element createTableColumnGroup() {
        return this.document.createElement("colgroup");
    }

    public Element createTableHeader() {
        return this.document.createElement("thead");
    }

    public Element createTableHeaderCell() {
        return this.document.createElement("th");
    }

    public Element createTableRow() {
        return this.document.createElement("tr");
    }

    public Text createText(String str) {
        return this.document.createTextNode(str);
    }

    public Element createUnorderedList() {
        return this.document.createElement("ul");
    }

    public Element getBody() {
        return this.body;
    }

    public Document getDocument() {
        return this.document;
    }

    public Element getHead() {
        return this.head;
    }

    public String getOrCreateCssClass(String str, String str2) {
        if (!this.stylesheet.containsKey(str)) {
            this.stylesheet.put(str, new LinkedHashMap(1));
        }
        Map<String, String> map = this.stylesheet.get(str);
        String str3 = map.get(str2);
        if (str3 != null) {
            return str3;
        }
        StringBuilder b2 = a.b(str);
        b2.append(map.size() + 1);
        String sb = b2.toString();
        map.put(str2, sb);
        return sb;
    }

    public String getTitle() {
        if (this.title == null) {
            return null;
        }
        return this.titleText.getTextContent();
    }

    public void setTitle(String str) {
        Element element;
        if (AbstractWordUtils.isEmpty(str) && (element = this.title) != null) {
            this.head.removeChild(element);
            this.title = null;
            this.titleText = null;
        }
        if (this.title == null) {
            this.title = this.document.createElement("title");
            Text createTextNode = this.document.createTextNode(str);
            this.titleText = createTextNode;
            this.title.appendChild(createTextNode);
            this.head.appendChild(this.title);
        }
        this.titleText.setData(str);
    }

    public void updateStylesheet() {
        this.stylesheetElement.setTextContent(buildStylesheet(this.stylesheet));
    }
}
