package org.apache.poi.hwpf.converter;

import org.w3c.dom.Document;
import org.w3c.dom.Element;
import org.w3c.dom.Text;

public class TextDocumentFacade {
    public final Element body;
    public final Document document;
    public final Element head;
    public final Element root;
    public Element title;
    public Text titleText;

    public TextDocumentFacade(Document document2) {
        this.document = document2;
        Element createElement = document2.createElement("html");
        this.root = createElement;
        document2.appendChild(createElement);
        this.body = document2.createElement("body");
        Element createElement2 = document2.createElement("head");
        this.head = createElement2;
        this.root.appendChild(createElement2);
        this.root.appendChild(this.body);
        this.title = document2.createElement("title");
        this.titleText = document2.createTextNode("");
        this.head.appendChild(this.title);
    }

    public void addAuthor(String str) {
        addMeta("Author", str);
    }

    public void addDescription(String str) {
        addMeta("Description", str);
    }

    public void addKeywords(String str) {
        addMeta("Keywords", str);
    }

    public void addMeta(String str, String str2) {
        Element createElement = this.document.createElement("meta");
        Element createElement2 = this.document.createElement("name");
        Document document2 = this.document;
        createElement2.appendChild(document2.createTextNode(str + ": "));
        createElement.appendChild(createElement2);
        Element createElement3 = this.document.createElement("value");
        Document document3 = this.document;
        createElement3.appendChild(document3.createTextNode(str2 + "\n"));
        createElement.appendChild(createElement3);
        this.head.appendChild(createElement);
    }

    public Element createBlock() {
        return this.document.createElement("div");
    }

    public Element createHeader1() {
        Element createElement = this.document.createElement("h1");
        createElement.appendChild(this.document.createTextNode("        "));
        return createElement;
    }

    public Element createHeader2() {
        Element createElement = this.document.createElement("h2");
        createElement.appendChild(this.document.createTextNode("    "));
        return createElement;
    }

    public Element createParagraph() {
        return this.document.createElement("p");
    }

    public Element createTable() {
        return this.document.createElement("table");
    }

    public Element createTableBody() {
        return this.document.createElement("tbody");
    }

    public Element createTableCell() {
        return this.document.createElement("td");
    }

    public Element createTableRow() {
        return this.document.createElement("tr");
    }

    public Text createText(String str) {
        return this.document.createTextNode(str);
    }

    public Element createUnorderedList() {
        return this.document.createElement("ul");
    }

    public Element getBody() {
        return this.body;
    }

    public Document getDocument() {
        return this.document;
    }

    public Element getHead() {
        return this.head;
    }

    public String getTitle() {
        if (this.title == null) {
            return null;
        }
        return this.titleText.getTextContent();
    }

    public void setTitle(String str) {
        Element element;
        if (AbstractWordUtils.isEmpty(str) && (element = this.title) != null) {
            this.head.removeChild(element);
            this.title = null;
            this.titleText = null;
        }
        if (this.title == null) {
            this.title = this.document.createElement("title");
            Text createTextNode = this.document.createTextNode(str);
            this.titleText = createTextNode;
            this.title.appendChild(createTextNode);
            this.head.appendChild(this.title);
        }
        this.titleText.setData(str);
    }
}
