package org.apache.poi.hwpf.converter;

import b.b.a.a.a;
import java.io.File;
import java.io.PrintStream;
import java.util.ArrayList;
import java.util.LinkedHashSet;
import java.util.List;
import java.util.Set;
import java.util.concurrent.atomic.AtomicInteger;
import javax.xml.transform.OutputKeys;
import javax.xml.transform.Transformer;
import javax.xml.transform.TransformerFactory;
import javax.xml.transform.dom.DOMSource;
import javax.xml.transform.stream.StreamResult;
import org.apache.poi.hpsf.SummaryInformation;
import org.apache.poi.hwpf.HWPFDocument;
import org.apache.poi.hwpf.HWPFDocumentCore;
import org.apache.poi.hwpf.converter.FontReplacer;
import org.apache.poi.hwpf.usermodel.Bookmark;
import org.apache.poi.hwpf.usermodel.CharacterRun;
import org.apache.poi.hwpf.usermodel.OfficeDrawing;
import org.apache.poi.hwpf.usermodel.Paragraph;
import org.apache.poi.hwpf.usermodel.Picture;
import org.apache.poi.hwpf.usermodel.Range;
import org.apache.poi.hwpf.usermodel.Section;
import org.apache.poi.hwpf.usermodel.Table;
import org.apache.poi.hwpf.usermodel.TableCell;
import org.apache.poi.hwpf.usermodel.TableRow;
import org.apache.poi.util.POILogFactory;
import org.apache.poi.util.POILogger;
import org.apache.poi.util.XMLHelper;
import org.w3c.dom.Document;
import org.w3c.dom.Element;
import org.w3c.dom.Node;
import org.w3c.dom.NodeList;

public class WordToFoConverter extends AbstractWordConverter {
    public static final POILogger logger = POILogFactory.getLogger(WordToFoConverter.class);
    public List<Element> endnotes = new ArrayList(0);
    public final FoDocumentFacade foDocumentFacade;
    public AtomicInteger internalLinkCounter = new AtomicInteger(0);
    public boolean outputCharactersLanguage = false;
    public Set<String> usedIds = new LinkedHashSet();

    public WordToFoConverter(Document document) {
        this.foDocumentFacade = new FoDocumentFacade(document);
    }

    public static void main(String[] strArr) {
        if (strArr.length < 2) {
            System.err.println("Usage: WordToFoConverter <inputFile.doc> <saveTo.fo>");
            return;
        }
        PrintStream printStream = System.out;
        StringBuilder b2 = a.b("Converting ");
        b2.append(strArr[0]);
        printStream.println(b2.toString());
        PrintStream printStream2 = System.out;
        StringBuilder b3 = a.b("Saving output to ");
        b3.append(strArr[1]);
        printStream2.println(b3.toString());
        DOMSource dOMSource = new DOMSource(process(new File(strArr[0])));
        StreamResult streamResult = new StreamResult(new File(strArr[1]));
        Transformer newTransformer = TransformerFactory.newInstance().newTransformer();
        newTransformer.setOutputProperty(OutputKeys.ENCODING, "UTF-8");
        newTransformer.setOutputProperty(OutputKeys.INDENT, "yes");
        newTransformer.transform(dOMSource, streamResult);
    }

    public static Document process(File file) {
        HWPFDocumentCore loadDoc = AbstractWordUtils.loadDoc(file);
        WordToFoConverter wordToFoConverter = new WordToFoConverter(XMLHelper.getDocumentBuilderFactory().newDocumentBuilder().newDocument());
        wordToFoConverter.processDocument(loadDoc);
        return wordToFoConverter.getDocument();
    }

    public Element createNoteInline(String str) {
        Element createInline = this.foDocumentFacade.createInline();
        createInline.setTextContent(str);
        createInline.setAttribute("baseline-shift", "super");
        createInline.setAttribute("font-size", "smaller");
        return createInline;
    }

    public String createPageMaster(Section section, String str, int i2) {
        String str2 = str + "-page" + i2;
        Element addSimplePageMaster = this.foDocumentFacade.addSimplePageMaster(str2);
        addSimplePageMaster.setAttribute("page-height", (((float) section.getPageHeight()) / 1440.0f) + "in");
        addSimplePageMaster.setAttribute("page-width", (((float) section.getPageWidth()) / 1440.0f) + "in");
        Element addRegionBody = this.foDocumentFacade.addRegionBody(addSimplePageMaster);
        addRegionBody.setAttribute("margin", (((float) section.getMarginTop()) / 1440.0f) + "in " + (((float) section.getMarginRight()) / 1440.0f) + "in " + (((float) section.getMarginBottom()) / 1440.0f) + "in " + (((float) section.getMarginLeft()) / 1440.0f) + "in");
        if (section.getNumColumns() > 1) {
            StringBuilder b2 = a.b("");
            b2.append(section.getNumColumns());
            addRegionBody.setAttribute("column-count", b2.toString());
            if (section.isColumnsEvenlySpaced()) {
                addRegionBody.setAttribute("column-gap", (((float) section.getDistanceBetweenColumns()) / 1440.0f) + "in");
            } else {
                addRegionBody.setAttribute("column-gap", "0.25in");
            }
        }
        return str2;
    }

    @Override // org.apache.poi.hwpf.converter.AbstractWordConverter
    public Document getDocument() {
        return this.foDocumentFacade.getDocument();
    }

    public boolean isOutputCharactersLanguage() {
        return this.outputCharactersLanguage;
    }

    @Override // org.apache.poi.hwpf.converter.AbstractWordConverter
    public void outputCharacters(Element element, CharacterRun characterRun, String str) {
        Element createInline = this.foDocumentFacade.createInline();
        FontReplacer.Triplet characterRunTriplet = getCharacterRunTriplet(characterRun);
        if (AbstractWordUtils.isNotEmpty(characterRunTriplet.fontName)) {
            WordToFoUtils.setFontFamily(createInline, characterRunTriplet.fontName);
        }
        WordToFoUtils.setBold(createInline, characterRunTriplet.bold);
        WordToFoUtils.setItalic(createInline, characterRunTriplet.italic);
        WordToFoUtils.setFontSize(createInline, characterRun.getFontSize() / 2);
        WordToFoUtils.setCharactersProperties(characterRun, createInline);
        if (isOutputCharactersLanguage()) {
            WordToFoUtils.setLanguage(characterRun, createInline);
        }
        element.appendChild(createInline);
        createInline.appendChild(this.foDocumentFacade.createText(str));
    }

    @Override // org.apache.poi.hwpf.converter.AbstractWordConverter
    public void processBookmarks(HWPFDocumentCore hWPFDocumentCore, Element element, Range range, int i2, List<Bookmark> list) {
        for (Bookmark bookmark : list) {
            Element createInline = this.foDocumentFacade.createInline();
            StringBuilder b2 = a.b("bookmark_");
            b2.append(bookmark.getName());
            if (setId(createInline, b2.toString())) {
                element.appendChild(createInline);
                element = createInline;
            }
        }
        if (range != null) {
            processCharacters(hWPFDocumentCore, i2, range, element);
        }
    }

    @Override // org.apache.poi.hwpf.converter.AbstractWordConverter
    public void processDocumentInformation(SummaryInformation summaryInformation) {
        if (AbstractWordUtils.isNotEmpty(summaryInformation.getTitle())) {
            this.foDocumentFacade.setTitle(summaryInformation.getTitle());
        }
        if (AbstractWordUtils.isNotEmpty(summaryInformation.getAuthor())) {
            this.foDocumentFacade.setCreator(summaryInformation.getAuthor());
        }
        if (AbstractWordUtils.isNotEmpty(summaryInformation.getKeywords())) {
            this.foDocumentFacade.setKeywords(summaryInformation.getKeywords());
        }
        if (AbstractWordUtils.isNotEmpty(summaryInformation.getComments())) {
            this.foDocumentFacade.setDescription(summaryInformation.getComments());
        }
    }

    @Override // org.apache.poi.hwpf.converter.AbstractWordConverter
    public void processDrawnObject(HWPFDocument hWPFDocument, CharacterRun characterRun, OfficeDrawing officeDrawing, String str, Element element) {
        element.appendChild(this.foDocumentFacade.createExternalGraphic(str));
    }

    @Override // org.apache.poi.hwpf.converter.AbstractWordConverter
    public void processEndnoteAutonumbered(HWPFDocument hWPFDocument, int i2, Element element, Range range) {
        String valueOf = String.valueOf(this.internalLinkCounter.incrementAndGet());
        String b2 = a.b("endnote_", valueOf);
        String b3 = a.b("endnote_back_", valueOf);
        Element createBasicLinkInternal = this.foDocumentFacade.createBasicLinkInternal(b2);
        createBasicLinkInternal.appendChild(createNoteInline(valueOf));
        setId(createBasicLinkInternal, b3);
        element.appendChild(createBasicLinkInternal);
        Element createBlock = this.foDocumentFacade.createBlock();
        Element createBasicLinkInternal2 = this.foDocumentFacade.createBasicLinkInternal(b3);
        createBasicLinkInternal2.appendChild(createNoteInline(valueOf + " "));
        setId(createBasicLinkInternal2, b2);
        createBlock.appendChild(createBasicLinkInternal2);
        processCharacters(hWPFDocument, Integer.MIN_VALUE, range, createBlock);
        WordToFoUtils.compactInlines(createBlock);
        this.endnotes.add(createBlock);
    }

    @Override // org.apache.poi.hwpf.converter.AbstractWordConverter
    public void processFootnoteAutonumbered(HWPFDocument hWPFDocument, int i2, Element element, Range range) {
        String valueOf = String.valueOf(this.internalLinkCounter.incrementAndGet());
        String b2 = a.b("footnote_", valueOf);
        String b3 = a.b("footnote_back_", valueOf);
        Node createFootnote = this.foDocumentFacade.createFootnote();
        element.appendChild(createFootnote);
        Node createInline = this.foDocumentFacade.createInline();
        Element createBasicLinkInternal = this.foDocumentFacade.createBasicLinkInternal(b2);
        createBasicLinkInternal.appendChild(createNoteInline(valueOf));
        setId(createBasicLinkInternal, b3);
        createInline.appendChild(createBasicLinkInternal);
        createFootnote.appendChild(createInline);
        Node createFootnoteBody = this.foDocumentFacade.createFootnoteBody();
        Element createBlock = this.foDocumentFacade.createBlock();
        Element createBasicLinkInternal2 = this.foDocumentFacade.createBasicLinkInternal(b3);
        createBasicLinkInternal2.appendChild(createNoteInline(valueOf + " "));
        setId(createBasicLinkInternal2, b2);
        createBlock.appendChild(createBasicLinkInternal2);
        createFootnoteBody.appendChild(createBlock);
        createFootnote.appendChild(createFootnoteBody);
        processCharacters(hWPFDocument, Integer.MIN_VALUE, range, createBlock);
        WordToFoUtils.compactInlines(createBlock);
    }

    @Override // org.apache.poi.hwpf.converter.AbstractWordConverter
    public void processHyperlink(HWPFDocumentCore hWPFDocumentCore, Element element, Range range, int i2, String str) {
        Element createBasicLinkExternal = this.foDocumentFacade.createBasicLinkExternal(str);
        element.appendChild(createBasicLinkExternal);
        if (range != null) {
            processCharacters(hWPFDocumentCore, i2, range, createBasicLinkExternal);
        }
    }

    @Override // org.apache.poi.hwpf.converter.AbstractWordConverter
    public void processImage(Element element, boolean z, Picture picture, String str) {
        Element createExternalGraphic = this.foDocumentFacade.createExternalGraphic(str);
        WordToFoUtils.setPictureProperties(picture, createExternalGraphic);
        element.appendChild(createExternalGraphic);
    }

    @Override // org.apache.poi.hwpf.converter.AbstractWordConverter
    public void processImageWithoutPicturesManager(Element element, boolean z, Picture picture) {
        Document document = this.foDocumentFacade.document;
        StringBuilder b2 = a.b("Image link to '");
        b2.append(picture.suggestFullFileName());
        b2.append("' can be here");
        element.appendChild(document.createComment(b2.toString()));
    }

    @Override // org.apache.poi.hwpf.converter.AbstractWordConverter
    public void processLineBreak(Element element, CharacterRun characterRun) {
        element.appendChild(this.foDocumentFacade.createBlock());
    }

    /* JADX WARNING: Code restructure failed: missing block: B:5:0x0020, code lost:
        if (r3.hasAttribute("break-after") == false) goto L_0x0024;
     */
    @Override // org.apache.poi.hwpf.converter.AbstractWordConverter
    public void processPageBreak(HWPFDocumentCore hWPFDocumentCore, Element element) {
        Element element2;
        NodeList childNodes = element.getChildNodes();
        if (childNodes.getLength() > 0) {
            Node item = childNodes.item(childNodes.getLength() - 1);
            if (item instanceof Element) {
                element2 = (Element) item;
            }
        }
        element2 = null;
        if (element2 == null) {
            element2 = this.foDocumentFacade.createBlock();
            element.appendChild(element2);
        }
        element2.setAttribute("break-after", "page");
    }

    @Override // org.apache.poi.hwpf.converter.AbstractWordConverter
    public void processPageref(HWPFDocumentCore hWPFDocumentCore, Element element, Range range, int i2, String str) {
        FoDocumentFacade foDocumentFacade2 = this.foDocumentFacade;
        Element createBasicLinkInternal = foDocumentFacade2.createBasicLinkInternal("bookmark_" + str);
        element.appendChild(createBasicLinkInternal);
        if (range != null) {
            processCharacters(hWPFDocumentCore, i2, range, createBasicLinkInternal);
        }
    }

    @Override // org.apache.poi.hwpf.converter.AbstractWordConverter
    public void processParagraph(HWPFDocumentCore hWPFDocumentCore, Element element, int i2, Paragraph paragraph, String str) {
        Element createBlock = this.foDocumentFacade.createBlock();
        element.appendChild(createBlock);
        WordToFoUtils.setParagraphProperties(paragraph, createBlock);
        if (paragraph.numCharacterRuns() != 0) {
            if (AbstractWordUtils.isNotEmpty(str)) {
                Element createInline = this.foDocumentFacade.createInline();
                createBlock.appendChild(createInline);
                createInline.appendChild(this.foDocumentFacade.createText(str));
                str.trim().length();
            }
            if (!processCharacters(hWPFDocumentCore, i2, paragraph, createBlock)) {
                createBlock.appendChild(this.foDocumentFacade.createLeader());
            }
            WordToFoUtils.compactInlines(createBlock);
        }
    }

    @Override // org.apache.poi.hwpf.converter.AbstractWordConverter
    public void processSection(HWPFDocumentCore hWPFDocumentCore, Section section, int i2) {
        Element addFlowToPageSequence = this.foDocumentFacade.addFlowToPageSequence(this.foDocumentFacade.addPageSequence(createPageMaster(section, "page", i2)), "xsl-region-body");
        processParagraphes(hWPFDocumentCore, addFlowToPageSequence, section, Integer.MIN_VALUE);
        List<Element> list = this.endnotes;
        if (!(list == null || list.isEmpty())) {
            for (Element element : this.endnotes) {
                addFlowToPageSequence.appendChild(element);
            }
            this.endnotes.clear();
        }
    }

    @Override // org.apache.poi.hwpf.converter.AbstractWordConverter
    public void processTable(HWPFDocumentCore hWPFDocumentCore, Element element, Table table) {
        TableRow tableRow;
        int i2;
        int i3;
        Element element2;
        Element element3;
        Table table2 = table;
        Element createTableHeader = this.foDocumentFacade.createTableHeader();
        Element createTableBody = this.foDocumentFacade.createTableBody();
        int[] buildTableCellEdgesArray = AbstractWordUtils.buildTableCellEdgesArray(table);
        int numRows = table.numRows();
        int i4 = Integer.MIN_VALUE;
        for (int i5 = 0; i5 < numRows; i5++) {
            i4 = Math.max(i4, table2.getRow(i5).numCells());
        }
        int i6 = 0;
        while (true) {
            int i7 = 1;
            if (i6 >= numRows) {
                break;
            }
            TableRow row = table2.getRow(i6);
            Element createTableRow = this.foDocumentFacade.createTableRow();
            WordToFoUtils.setTableRowProperties(row, createTableRow);
            int numCells = row.numCells();
            int i8 = 0;
            int i9 = 0;
            while (i9 < numCells) {
                TableCell cell = row.getCell(i9);
                if (!cell.isVerticallyMerged() || cell.isFirstVerticallyMerged()) {
                    Element createTableCell = this.foDocumentFacade.createTableCell();
                    WordToFoUtils.setTableCellProperties(row, cell, createTableCell, i6 == 0, i6 == numRows + -1, i9 == 0, i9 == numCells + -1);
                    int numberColumnsSpanned = getNumberColumnsSpanned(buildTableCellEdgesArray, i8, cell);
                    int i10 = i8 + numberColumnsSpanned;
                    if (numberColumnsSpanned == 0) {
                        i3 = i9;
                        i2 = numCells;
                        element2 = createTableRow;
                        tableRow = row;
                    } else {
                        if (numberColumnsSpanned != i7) {
                            element3 = createTableCell;
                            element3.setAttribute("number-columns-spanned", String.valueOf(numberColumnsSpanned));
                        } else {
                            element3 = createTableCell;
                        }
                        i3 = i9;
                        i2 = numCells;
                        element2 = createTableRow;
                        tableRow = row;
                        int numberRowsSpanned = getNumberRowsSpanned(table, buildTableCellEdgesArray, i6, i3, cell);
                        if (numberRowsSpanned > 1) {
                            element3.setAttribute("number-rows-spanned", String.valueOf(numberRowsSpanned));
                        }
                        processParagraphes(hWPFDocumentCore, element3, cell, table.getTableLevel());
                        if (!element3.hasChildNodes()) {
                            element3.appendChild(this.foDocumentFacade.createBlock());
                        }
                        element2.appendChild(element3);
                    }
                    i8 = i10;
                } else {
                    i8 = getNumberColumnsSpanned(buildTableCellEdgesArray, i8, cell) + i8;
                    i3 = i9;
                    i2 = numCells;
                    element2 = createTableRow;
                    tableRow = row;
                }
                i9 = i3 + 1;
                createTableRow = element2;
                numCells = i2;
                row = tableRow;
                i7 = 1;
            }
            if (createTableRow.hasChildNodes()) {
                if (row.isTableHeader()) {
                    createTableHeader.appendChild(createTableRow);
                } else {
                    createTableBody.appendChild(createTableRow);
                }
            }
            i6++;
            table2 = table;
        }
        Element createTable = this.foDocumentFacade.createTable();
        createTable.setAttribute("table-layout", "fixed");
        if (createTableHeader.hasChildNodes()) {
            createTable.appendChild(createTableHeader);
        }
        if (createTableBody.hasChildNodes()) {
            createTable.appendChild(createTableBody);
            element.appendChild(createTable);
            return;
        }
        POILogger pOILogger = logger;
        StringBuilder b2 = a.b("Table without body starting on offset ");
        b2.append(table.getStartOffset());
        b2.append(" -- ");
        b2.append(table.getEndOffset());
        pOILogger.log(5, b2.toString());
    }

    public boolean setId(Element element, String str) {
        if (this.usedIds.contains(str)) {
            logger.log(5, "Tried to create element with same ID '", str, "'. Skipped");
            return false;
        }
        element.setAttribute("id", str);
        this.usedIds.add(str);
        return true;
    }

    public void setOutputCharactersLanguage(boolean z) {
        this.outputCharactersLanguage = z;
    }

    public WordToFoConverter(FoDocumentFacade foDocumentFacade2) {
        this.foDocumentFacade = foDocumentFacade2;
    }
}
