package org.apache.poi.hwpf.converter;

import b.b.a.a.a;
import java.io.File;
import java.io.PrintStream;
import java.util.Deque;
import java.util.LinkedList;
import java.util.List;
import javax.xml.transform.OutputKeys;
import javax.xml.transform.Transformer;
import javax.xml.transform.TransformerFactory;
import javax.xml.transform.dom.DOMSource;
import javax.xml.transform.stream.StreamResult;
import org.apache.lucene.codecs.lucene3x.Lucene3xNormsProducer;
import org.apache.poi.hpsf.SummaryInformation;
import org.apache.poi.hwpf.HWPFDocument;
import org.apache.poi.hwpf.HWPFDocumentCore;
import org.apache.poi.hwpf.converter.FontReplacer;
import org.apache.poi.hwpf.usermodel.Bookmark;
import org.apache.poi.hwpf.usermodel.CharacterRun;
import org.apache.poi.hwpf.usermodel.OfficeDrawing;
import org.apache.poi.hwpf.usermodel.Paragraph;
import org.apache.poi.hwpf.usermodel.Picture;
import org.apache.poi.hwpf.usermodel.Range;
import org.apache.poi.hwpf.usermodel.Section;
import org.apache.poi.hwpf.usermodel.Table;
import org.apache.poi.hwpf.usermodel.TableCell;
import org.apache.poi.hwpf.usermodel.TableRow;
import org.apache.poi.ss.formula.functions.Complex;
import org.apache.poi.ss.usermodel.DataFormatter;
import org.apache.poi.util.POILogFactory;
import org.apache.poi.util.POILogger;
import org.apache.poi.util.XMLHelper;
import org.apache.xmlbeans.impl.jam.xml.JamXmlElements;
import org.apache.xmlbeans.impl.schema.SoapEncSchemaTypeSystem;
import org.w3c.dom.Document;
import org.w3c.dom.Element;

public class WordToHtmlConverter extends AbstractWordConverter {
    public static final POILogger logger = POILogFactory.getLogger(WordToHtmlConverter.class);
    public final Deque<BlockProperies> blocksProperies = new LinkedList();
    public final HtmlDocumentFacade htmlDocumentFacade;
    public Element notes;

    public static class BlockProperies {
        public final String pFontName;
        public final int pFontSize;

        public BlockProperies(String str, int i2) {
            this.pFontName = str;
            this.pFontSize = i2;
        }
    }

    public WordToHtmlConverter(Document document) {
        this.htmlDocumentFacade = new HtmlDocumentFacade(document);
    }

    public static String getSectionStyle(Section section) {
        String str = "margin: " + (((float) section.getMarginTop()) / 1440.0f) + "in " + (((float) section.getMarginRight()) / 1440.0f) + "in " + (((float) section.getMarginBottom()) / 1440.0f) + "in " + (((float) section.getMarginLeft()) / 1440.0f) + "in;";
        if (section.getNumColumns() <= 1) {
            return str;
        }
        StringBuilder d2 = a.d(str, "column-count: ");
        d2.append(section.getNumColumns());
        d2.append(";");
        String sb = d2.toString();
        if (!section.isColumnsEvenlySpaced()) {
            return a.b(sb, "column-gap: 0.25in;");
        }
        return sb + "column-gap: " + (((float) section.getDistanceBetweenColumns()) / 1440.0f) + "in;";
    }

    public static void main(String[] strArr) {
        if (strArr.length < 2) {
            System.err.println("Usage: WordToHtmlConverter <inputFile.doc> <saveTo.html>");
            return;
        }
        PrintStream printStream = System.out;
        StringBuilder b2 = a.b("Converting ");
        b2.append(strArr[0]);
        printStream.println(b2.toString());
        PrintStream printStream2 = System.out;
        StringBuilder b3 = a.b("Saving output to ");
        b3.append(strArr[1]);
        printStream2.println(b3.toString());
        DOMSource dOMSource = new DOMSource(process(new File(strArr[0])));
        StreamResult streamResult = new StreamResult(new File(strArr[1]));
        Transformer newTransformer = TransformerFactory.newInstance().newTransformer();
        newTransformer.setOutputProperty(OutputKeys.ENCODING, "UTF-8");
        newTransformer.setOutputProperty(OutputKeys.INDENT, "yes");
        newTransformer.setOutputProperty("method", "html");
        newTransformer.transform(dOMSource, streamResult);
    }

    public static Document process(File file) {
        HWPFDocumentCore loadDoc = AbstractWordUtils.loadDoc(file);
        WordToHtmlConverter wordToHtmlConverter = new WordToHtmlConverter(XMLHelper.getDocumentBuilderFactory().newDocumentBuilder().newDocument());
        wordToHtmlConverter.processDocument(loadDoc);
        return wordToHtmlConverter.getDocument();
    }

    @Override // org.apache.poi.hwpf.converter.AbstractWordConverter
    public void afterProcess() {
        if (this.notes != null) {
            this.htmlDocumentFacade.getBody().appendChild(this.notes);
        }
        this.htmlDocumentFacade.updateStylesheet();
    }

    @Override // org.apache.poi.hwpf.converter.AbstractWordConverter
    public Document getDocument() {
        return this.htmlDocumentFacade.getDocument();
    }

    @Override // org.apache.poi.hwpf.converter.AbstractWordConverter
    public void outputCharacters(Element element, CharacterRun characterRun, String str) {
        Element createElement = this.htmlDocumentFacade.document.createElement("span");
        element.appendChild(createElement);
        StringBuilder sb = new StringBuilder();
        BlockProperies peek = this.blocksProperies.peek();
        FontReplacer.Triplet characterRunTriplet = getCharacterRunTriplet(characterRun);
        if (AbstractWordUtils.isNotEmpty(characterRunTriplet.fontName) && !AbstractWordUtils.equals(characterRunTriplet.fontName, peek.pFontName)) {
            StringBuilder b2 = a.b("font-family:");
            b2.append(characterRunTriplet.fontName);
            b2.append(";");
            sb.append(b2.toString());
        }
        if (characterRun.getFontSize() / 2 != peek.pFontSize) {
            StringBuilder b3 = a.b("font-size:");
            b3.append(characterRun.getFontSize() / 2);
            b3.append("pt;");
            sb.append(b3.toString());
        }
        if (characterRunTriplet.bold) {
            sb.append("font-weight:bold;");
        }
        if (characterRunTriplet.italic) {
            sb.append("font-style:italic;");
        }
        WordToHtmlUtils.addCharactersProperties(characterRun, sb);
        if (sb.length() != 0) {
            this.htmlDocumentFacade.addStyleClass(createElement, Lucene3xNormsProducer.SEPARATE_NORMS_EXTENSION, sb.toString());
        }
        createElement.appendChild(this.htmlDocumentFacade.createText(str));
    }

    @Override // org.apache.poi.hwpf.converter.AbstractWordConverter
    public void processBookmarks(HWPFDocumentCore hWPFDocumentCore, Element element, Range range, int i2, List<Bookmark> list) {
        for (Bookmark bookmark : list) {
            Element createBookmark = this.htmlDocumentFacade.createBookmark(bookmark.getName());
            element.appendChild(createBookmark);
            element = createBookmark;
        }
        if (range != null) {
            processCharacters(hWPFDocumentCore, i2, range, element);
        }
    }

    @Override // org.apache.poi.hwpf.converter.AbstractWordConverter
    public void processDocumentInformation(SummaryInformation summaryInformation) {
        if (AbstractWordUtils.isNotEmpty(summaryInformation.getTitle())) {
            this.htmlDocumentFacade.setTitle(summaryInformation.getTitle());
        }
        if (AbstractWordUtils.isNotEmpty(summaryInformation.getAuthor())) {
            this.htmlDocumentFacade.addAuthor(summaryInformation.getAuthor());
        }
        if (AbstractWordUtils.isNotEmpty(summaryInformation.getKeywords())) {
            this.htmlDocumentFacade.addKeywords(summaryInformation.getKeywords());
        }
        if (AbstractWordUtils.isNotEmpty(summaryInformation.getComments())) {
            this.htmlDocumentFacade.addDescription(summaryInformation.getComments());
        }
    }

    @Override // org.apache.poi.hwpf.converter.AbstractWordConverter
    public void processDocumentPart(HWPFDocumentCore hWPFDocumentCore, Range range) {
        super.processDocumentPart(hWPFDocumentCore, range);
        afterProcess();
    }

    @Override // org.apache.poi.hwpf.converter.AbstractWordConverter
    public void processDrawnObject(HWPFDocument hWPFDocument, CharacterRun characterRun, OfficeDrawing officeDrawing, String str, Element element) {
        element.appendChild(this.htmlDocumentFacade.createImage(str));
    }

    @Override // org.apache.poi.hwpf.converter.AbstractWordConverter
    public void processDropDownList(Element element, CharacterRun characterRun, String[] strArr, int i2) {
        Element createSelect = this.htmlDocumentFacade.createSelect();
        int i3 = 0;
        while (i3 < strArr.length) {
            createSelect.appendChild(this.htmlDocumentFacade.createOption(strArr[i3], i2 == i3));
            i3++;
        }
        element.appendChild(createSelect);
    }

    @Override // org.apache.poi.hwpf.converter.AbstractWordConverter
    public void processEndnoteAutonumbered(HWPFDocument hWPFDocument, int i2, Element element, Range range) {
        processNoteAutonumbered(hWPFDocument, "end", i2, element, range);
    }

    @Override // org.apache.poi.hwpf.converter.AbstractWordConverter
    public void processFootnoteAutonumbered(HWPFDocument hWPFDocument, int i2, Element element, Range range) {
        processNoteAutonumbered(hWPFDocument, "foot", i2, element, range);
    }

    @Override // org.apache.poi.hwpf.converter.AbstractWordConverter
    public void processHyperlink(HWPFDocumentCore hWPFDocumentCore, Element element, Range range, int i2, String str) {
        Element createHyperlink = this.htmlDocumentFacade.createHyperlink(str);
        element.appendChild(createHyperlink);
        if (range != null) {
            processCharacters(hWPFDocumentCore, i2, range, createHyperlink);
        }
    }

    /* JADX WARN: Multi-variable type inference failed */
    /* JADX WARN: Type inference failed for: r17v0, types: [org.w3c.dom.Element, org.w3c.dom.Node] */
    /* JADX WARN: Type inference failed for: r5v5, types: [org.w3c.dom.Node] */
    @Override // org.apache.poi.hwpf.converter.AbstractWordConverter
    public void processImage(Element element, boolean z, Picture picture, String str) {
        float f2;
        float f3;
        float f4;
        float f5;
        float f6;
        float f7;
        Element element2;
        int horizontalScalingFactor = picture.getHorizontalScalingFactor();
        int verticalScalingFactor = picture.getVerticalScalingFactor();
        StringBuilder sb = new StringBuilder();
        if (horizontalScalingFactor > 0) {
            f3 = (((float) (picture.getDxaGoal() * horizontalScalingFactor)) / 1000.0f) / 1440.0f;
            f2 = (((float) (picture.getDxaCropRight() * horizontalScalingFactor)) / 1000.0f) / 1440.0f;
            f4 = ((float) (picture.getDxaCropLeft() * horizontalScalingFactor)) / 1000.0f;
        } else {
            f3 = ((float) picture.getDxaGoal()) / 1440.0f;
            f2 = ((float) picture.getDxaCropRight()) / 1440.0f;
            f4 = (float) picture.getDxaCropLeft();
        }
        float f8 = f4 / 1440.0f;
        if (verticalScalingFactor > 0) {
            f6 = (((float) (picture.getDyaGoal() * verticalScalingFactor)) / 1000.0f) / 1440.0f;
            f5 = (((float) (picture.getDyaCropTop() * verticalScalingFactor)) / 1000.0f) / 1440.0f;
            f7 = ((float) (picture.getDyaCropBottom() * verticalScalingFactor)) / 1000.0f;
        } else {
            f6 = ((float) picture.getDyaGoal()) / 1440.0f;
            f5 = ((float) picture.getDyaCropTop()) / 1440.0f;
            f7 = (float) picture.getDyaCropBottom();
        }
        float f9 = f7 / 1440.0f;
        if (Math.abs(f8) + Math.abs(f9) + Math.abs(f2) + Math.abs(f5) > 0.0f) {
            float max = Math.max(0.0f, (f3 - f8) - f2);
            float max2 = Math.max(0.0f, (f6 - f5) - f9);
            element2 = this.htmlDocumentFacade.createBlock();
            HtmlDocumentFacade htmlDocumentFacade2 = this.htmlDocumentFacade;
            htmlDocumentFacade2.addStyleClass(element2, "d", "vertical-align:text-bottom;width:" + max + "in;height:" + max2 + "in;");
            Element createBlock = this.htmlDocumentFacade.createBlock();
            HtmlDocumentFacade htmlDocumentFacade3 = this.htmlDocumentFacade;
            htmlDocumentFacade3.addStyleClass(createBlock, "d", "position:relative;width:" + max + "in;height:" + max2 + "in;overflow:hidden;");
            element2.appendChild(createBlock);
            Element createImage = this.htmlDocumentFacade.createImage(str);
            HtmlDocumentFacade htmlDocumentFacade4 = this.htmlDocumentFacade;
            htmlDocumentFacade4.addStyleClass(createImage, Complex.DEFAULT_SUFFIX, "position:absolute;left:-" + f8 + ";top:-" + f5 + ";width:" + f3 + "in;height:" + f6 + "in;");
            createBlock.appendChild(createImage);
            sb.append("overflow:hidden;");
        } else {
            element2 = this.htmlDocumentFacade.createImage(str);
            element2.setAttribute("style", "width:" + f3 + "in;height:" + f6 + "in;vertical-align:text-bottom;");
        }
        element.appendChild(element2);
    }

    @Override // org.apache.poi.hwpf.converter.AbstractWordConverter
    public void processImageWithoutPicturesManager(Element element, boolean z, Picture picture) {
        Document document = this.htmlDocumentFacade.document;
        StringBuilder b2 = a.b("Image link to '");
        b2.append(picture.suggestFullFileName());
        b2.append("' can be here");
        element.appendChild(document.createComment(b2.toString()));
    }

    @Override // org.apache.poi.hwpf.converter.AbstractWordConverter
    public void processLineBreak(Element element, CharacterRun characterRun) {
        element.appendChild(this.htmlDocumentFacade.createLineBreak());
    }

    public void processNoteAutonumbered(HWPFDocument hWPFDocument, String str, int i2, Element element, Range range) {
        String valueOf = String.valueOf(i2 + 1);
        String orCreateCssClass = this.htmlDocumentFacade.getOrCreateCssClass("a", "vertical-align:super;font-size:smaller;");
        String b2 = a.b(str, "note_", valueOf);
        String b3 = a.b(str, "note_back_", valueOf);
        HtmlDocumentFacade htmlDocumentFacade2 = this.htmlDocumentFacade;
        Element createHyperlink = htmlDocumentFacade2.createHyperlink(DataFormatter.defaultFractionWholePartFormat + b2);
        createHyperlink.setAttribute("name", b3);
        createHyperlink.setAttribute(JamXmlElements.CLASS, orCreateCssClass + " " + str + "noteanchor");
        createHyperlink.setTextContent(valueOf);
        element.appendChild(createHyperlink);
        if (this.notes == null) {
            Element createBlock = this.htmlDocumentFacade.createBlock();
            this.notes = createBlock;
            createBlock.setAttribute(JamXmlElements.CLASS, "notes");
        }
        Element createBlock2 = this.htmlDocumentFacade.createBlock();
        createBlock2.setAttribute(JamXmlElements.CLASS, str + "note");
        this.notes.appendChild(createBlock2);
        Element createBookmark = this.htmlDocumentFacade.createBookmark(b2);
        createBookmark.setAttribute(SoapEncSchemaTypeSystem.ATTR_HREF, DataFormatter.defaultFractionWholePartFormat + b3);
        createBookmark.setTextContent(valueOf);
        createBookmark.setAttribute(JamXmlElements.CLASS, orCreateCssClass + " " + str + "noteindex");
        createBlock2.appendChild(createBookmark);
        createBlock2.appendChild(this.htmlDocumentFacade.createText(" "));
        Element createElement = this.htmlDocumentFacade.getDocument().createElement("span");
        createElement.setAttribute(JamXmlElements.CLASS, str + "notetext");
        createBlock2.appendChild(createElement);
        this.blocksProperies.add(new BlockProperies("", -1));
        try {
            processCharacters(hWPFDocument, Integer.MIN_VALUE, range, createElement);
        } finally {
            this.blocksProperies.pop();
        }
    }

    @Override // org.apache.poi.hwpf.converter.AbstractWordConverter
    public void processPageBreak(HWPFDocumentCore hWPFDocumentCore, Element element) {
        element.appendChild(this.htmlDocumentFacade.createLineBreak());
    }

    @Override // org.apache.poi.hwpf.converter.AbstractWordConverter
    public void processPageref(HWPFDocumentCore hWPFDocumentCore, Element element, Range range, int i2, String str) {
        HtmlDocumentFacade htmlDocumentFacade2 = this.htmlDocumentFacade;
        Element createHyperlink = htmlDocumentFacade2.createHyperlink(DataFormatter.defaultFractionWholePartFormat + str);
        element.appendChild(createHyperlink);
        if (range != null) {
            processCharacters(hWPFDocumentCore, i2, range, createHyperlink);
        }
    }

    /* JADX INFO: finally extract failed */
    @Override // org.apache.poi.hwpf.converter.AbstractWordConverter
    public void processParagraph(HWPFDocumentCore hWPFDocumentCore, Element element, int i2, Paragraph paragraph, String str) {
        String str2;
        int i3;
        Element createParagraph = this.htmlDocumentFacade.createParagraph();
        element.appendChild(createParagraph);
        StringBuilder sb = new StringBuilder();
        WordToHtmlUtils.addParagraphProperties(paragraph, sb);
        if (paragraph.numCharacterRuns() != 0) {
            CharacterRun characterRun = paragraph.getCharacterRun(0);
            if (characterRun != null) {
                FontReplacer.Triplet characterRunTriplet = getCharacterRunTriplet(characterRun);
                i3 = characterRun.getFontSize() / 2;
                str2 = characterRunTriplet.fontName;
                WordToHtmlUtils.addFontFamily(str2, sb);
                WordToHtmlUtils.addFontSize(i3, sb);
            } else {
                i3 = -1;
                str2 = "";
            }
            this.blocksProperies.push(new BlockProperies(str2, i3));
            try {
                if (AbstractWordUtils.isNotEmpty(str)) {
                    if (str.endsWith("\t")) {
                        float indentFromLeft = ((float) (paragraph.getIndentFromLeft() + paragraph.getFirstLineIndent())) + 20.0f;
                        float ceil = ((float) (Math.ceil((double) (indentFromLeft / 720.0f)) * 720.0d)) - indentFromLeft;
                        Element createElement = this.htmlDocumentFacade.getDocument().createElement("span");
                        HtmlDocumentFacade htmlDocumentFacade2 = this.htmlDocumentFacade;
                        htmlDocumentFacade2.addStyleClass(createElement, Lucene3xNormsProducer.SEPARATE_NORMS_EXTENSION, "display: inline-block; text-indent: 0; min-width: " + (ceil / 1440.0f) + "in;");
                        createParagraph.appendChild(createElement);
                        HtmlDocumentFacade htmlDocumentFacade3 = this.htmlDocumentFacade;
                        createElement.appendChild(htmlDocumentFacade3.createText(str.substring(0, str.length() + -1) + AbstractWordConverter.UNICODECHAR_ZERO_WIDTH_SPACE + AbstractWordConverter.UNICODECHAR_NO_BREAK_SPACE));
                    } else {
                        createParagraph.appendChild(this.htmlDocumentFacade.createText(str.substring(0, str.length() - 1)));
                    }
                }
                processCharacters(hWPFDocumentCore, i2, paragraph, createParagraph);
                this.blocksProperies.pop();
                if (sb.length() > 0) {
                    this.htmlDocumentFacade.addStyleClass(createParagraph, "p", sb.toString());
                }
                WordToHtmlUtils.compactSpans(createParagraph);
            } catch (Throwable th) {
                this.blocksProperies.pop();
                throw th;
            }
        }
    }

    @Override // org.apache.poi.hwpf.converter.AbstractWordConverter
    public void processSection(HWPFDocumentCore hWPFDocumentCore, Section section, int i2) {
        Element createBlock = this.htmlDocumentFacade.createBlock();
        this.htmlDocumentFacade.addStyleClass(createBlock, "d", getSectionStyle(section));
        this.htmlDocumentFacade.body.appendChild(createBlock);
        processParagraphes(hWPFDocumentCore, createBlock, section, Integer.MIN_VALUE);
    }

    @Override // org.apache.poi.hwpf.converter.AbstractWordConverter
    public void processSingleSection(HWPFDocumentCore hWPFDocumentCore, Section section) {
        HtmlDocumentFacade htmlDocumentFacade2 = this.htmlDocumentFacade;
        htmlDocumentFacade2.addStyleClass(htmlDocumentFacade2.body, "b", getSectionStyle(section));
        processParagraphes(hWPFDocumentCore, this.htmlDocumentFacade.body, section, Integer.MIN_VALUE);
    }

    @Override // org.apache.poi.hwpf.converter.AbstractWordConverter
    public void processTable(HWPFDocumentCore hWPFDocumentCore, Element element, Table table) {
        TableRow tableRow;
        StringBuilder sb;
        int i2;
        int i3;
        Element element2;
        Element element3;
        Table table2 = table;
        Element createTableHeader = this.htmlDocumentFacade.createTableHeader();
        Element createTableBody = this.htmlDocumentFacade.createTableBody();
        int[] buildTableCellEdgesArray = AbstractWordUtils.buildTableCellEdgesArray(table);
        int numRows = table.numRows();
        int i4 = Integer.MIN_VALUE;
        for (int i5 = 0; i5 < numRows; i5++) {
            i4 = Math.max(i4, table2.getRow(i5).numCells());
        }
        int i6 = 0;
        while (i6 < numRows) {
            TableRow row = table2.getRow(i6);
            Element createTableRow = this.htmlDocumentFacade.createTableRow();
            StringBuilder sb2 = new StringBuilder();
            WordToHtmlUtils.addTableRowProperties(row, sb2);
            int numCells = row.numCells();
            int i7 = 0;
            int i8 = 0;
            while (i8 < numCells) {
                TableCell cell = row.getCell(i8);
                if (!cell.isVerticallyMerged() || cell.isFirstVerticallyMerged()) {
                    if (row.isTableHeader()) {
                        element3 = this.htmlDocumentFacade.createTableHeaderCell();
                    } else {
                        element3 = this.htmlDocumentFacade.createTableCell();
                    }
                    StringBuilder sb3 = new StringBuilder();
                    WordToHtmlUtils.addTableCellProperties(row, cell, i6 == 0, i6 == numRows + -1, i8 == 0, i8 == numCells + -1, sb3);
                    int numberColumnsSpanned = getNumberColumnsSpanned(buildTableCellEdgesArray, i7, cell);
                    int i9 = i7 + numberColumnsSpanned;
                    if (numberColumnsSpanned == 0) {
                        i3 = i8;
                        i2 = numCells;
                        element2 = createTableRow;
                        tableRow = row;
                        sb = sb2;
                    } else {
                        if (numberColumnsSpanned != 1) {
                            element3.setAttribute("colspan", String.valueOf(numberColumnsSpanned));
                        }
                        i3 = i8;
                        i2 = numCells;
                        sb = sb2;
                        element2 = createTableRow;
                        tableRow = row;
                        int numberRowsSpanned = getNumberRowsSpanned(table, buildTableCellEdgesArray, i6, i3, cell);
                        if (numberRowsSpanned > 1) {
                            element3.setAttribute("rowspan", String.valueOf(numberRowsSpanned));
                        }
                        processParagraphes(hWPFDocumentCore, element3, cell, table.getTableLevel());
                        if (!element3.hasChildNodes()) {
                            element3.appendChild(this.htmlDocumentFacade.createParagraph());
                        }
                        if (sb3.length() > 0) {
                            this.htmlDocumentFacade.addStyleClass(element3, element3.getTagName(), sb3.toString());
                        }
                        element2.appendChild(element3);
                    }
                    i7 = i9;
                } else {
                    i3 = i8;
                    i2 = numCells;
                    sb = sb2;
                    element2 = createTableRow;
                    tableRow = row;
                    i7 = getNumberColumnsSpanned(buildTableCellEdgesArray, i7, cell) + i7;
                }
                i8 = i3 + 1;
                createTableRow = element2;
                numCells = i2;
                sb2 = sb;
                row = tableRow;
            }
            if (sb2.length() > 0) {
                createTableRow.setAttribute(JamXmlElements.CLASS, this.htmlDocumentFacade.getOrCreateCssClass("r", sb2.toString()));
            }
            if (row.isTableHeader()) {
                createTableHeader.appendChild(createTableRow);
            } else {
                createTableBody.appendChild(createTableRow);
            }
            i6++;
            table2 = table;
        }
        Element createTable = this.htmlDocumentFacade.createTable();
        createTable.setAttribute(JamXmlElements.CLASS, this.htmlDocumentFacade.getOrCreateCssClass("t", "table-layout:fixed;border-collapse:collapse;border-spacing:0;"));
        if (createTableHeader.hasChildNodes()) {
            createTable.appendChild(createTableHeader);
        }
        if (createTableBody.hasChildNodes()) {
            createTable.appendChild(createTableBody);
            element.appendChild(createTable);
            return;
        }
        logger.log(5, "Table without body starting at [", Integer.valueOf(table.getStartOffset()), "; ", Integer.valueOf(table.getEndOffset()), ")");
    }

    public WordToHtmlConverter(HtmlDocumentFacade htmlDocumentFacade2) {
        this.htmlDocumentFacade = htmlDocumentFacade2;
    }
}
