package org.apache.poi.hwpf.converter;

import b.b.a.a.a;
import org.apache.poi.hwpf.usermodel.BorderCode;
import org.apache.poi.hwpf.usermodel.CharacterRun;
import org.apache.poi.hwpf.usermodel.Paragraph;
import org.apache.poi.hwpf.usermodel.TableCell;
import org.apache.poi.hwpf.usermodel.TableRow;
import org.w3c.dom.Element;

public class WordToHtmlUtils extends AbstractWordUtils {
    public static void addBold(boolean z, StringBuilder sb) {
        StringBuilder b2 = a.b("font-weight:");
        b2.append(z ? "bold" : "normal");
        b2.append(";");
        sb.append(b2.toString());
    }

    public static void addBorder(BorderCode borderCode, String str, StringBuilder sb) {
        if (borderCode != null && !borderCode.isEmpty()) {
            if (AbstractWordUtils.isEmpty(str)) {
                sb.append("border:");
            } else {
                sb.append("border-");
                sb.append(str);
            }
            sb.append(":");
            if (borderCode.getLineWidth() < 8) {
                sb.append("thin");
            } else {
                sb.append(AbstractWordUtils.getBorderWidth(borderCode));
            }
            sb.append(' ');
            sb.append(AbstractWordUtils.getBorderType(borderCode));
            sb.append(' ');
            sb.append(AbstractWordUtils.getColor(borderCode.getColor()));
            sb.append(';');
        }
    }

    public static void addCharactersProperties(CharacterRun characterRun, StringBuilder sb) {
        addBorder(characterRun.getBorder(), "", sb);
        if (characterRun.isCapitalized()) {
            sb.append("text-transform:uppercase;");
        }
        if (characterRun.getIco24() != -1) {
            StringBuilder b2 = a.b("color:");
            b2.append(AbstractWordUtils.getColor24(characterRun.getIco24()));
            b2.append(";");
            sb.append(b2.toString());
        }
        if (characterRun.isHighlighted()) {
            StringBuilder b3 = a.b("background-color:");
            b3.append(AbstractWordUtils.getColor(characterRun.getHighlightedColor()));
            b3.append(";");
            sb.append(b3.toString());
        }
        if (characterRun.isStrikeThrough()) {
            sb.append("text-decoration:line-through;");
        }
        if (characterRun.isShadowed()) {
            StringBuilder b4 = a.b("text-shadow:");
            b4.append(characterRun.getFontSize() / 24);
            b4.append("pt;");
            sb.append(b4.toString());
        }
        if (characterRun.isSmallCaps()) {
            sb.append("font-variant:small-caps;");
        }
        if (characterRun.getSubSuperScriptIndex() == 1) {
            sb.append("vertical-align:super;");
            sb.append("font-size:smaller;");
        }
        if (characterRun.getSubSuperScriptIndex() == 2) {
            sb.append("vertical-align:sub;");
            sb.append("font-size:smaller;");
        }
        if (characterRun.getUnderlineCode() > 0) {
            sb.append("text-decoration:underline;");
        }
        if (characterRun.isVanished()) {
            sb.append("visibility:hidden;");
        }
    }

    public static void addFontFamily(String str, StringBuilder sb) {
        if (!AbstractWordUtils.isEmpty(str)) {
            sb.append("font-family:" + str + ";");
        }
    }

    public static void addFontSize(int i2, StringBuilder sb) {
        sb.append("font-size:" + i2 + "pt;");
    }

    public static void addIndent(Paragraph paragraph, StringBuilder sb) {
        addIndent(sb, "text-indent", paragraph.getFirstLineIndent());
        addIndent(sb, "margin-left", paragraph.getIndentFromLeft());
        addIndent(sb, "margin-right", paragraph.getIndentFromRight());
        addIndent(sb, "margin-top", paragraph.getSpacingBefore());
        addIndent(sb, "margin-bottom", paragraph.getSpacingAfter());
    }

    public static void addJustification(Paragraph paragraph, StringBuilder sb) {
        String justification = AbstractWordUtils.getJustification(paragraph.getJustification());
        if (AbstractWordUtils.isNotEmpty(justification)) {
            sb.append("text-align:" + justification + ";");
        }
    }

    public static void addParagraphProperties(Paragraph paragraph, StringBuilder sb) {
        addIndent(paragraph, sb);
        addJustification(paragraph, sb);
        addBorder(paragraph.getBottomBorder(), "bottom", sb);
        addBorder(paragraph.getLeftBorder(), "left", sb);
        addBorder(paragraph.getRightBorder(), "right", sb);
        addBorder(paragraph.getTopBorder(), "top", sb);
        if (paragraph.pageBreakBefore()) {
            sb.append("break-before:page;");
        }
        StringBuilder b2 = a.b("hyphenate:");
        b2.append(paragraph.isAutoHyphenated() ? "auto" : "none");
        b2.append(";");
        sb.append(b2.toString());
        if (paragraph.keepOnPage()) {
            sb.append("keep-together.within-page:always;");
        }
        if (paragraph.keepWithNext()) {
            sb.append("keep-with-next.within-page:always;");
        }
    }

    public static void addTableCellProperties(TableRow tableRow, TableCell tableCell, boolean z, boolean z2, boolean z3, boolean z4, StringBuilder sb) {
        StringBuilder b2 = a.b("width:");
        b2.append(((float) tableCell.getWidth()) / 1440.0f);
        b2.append("in;");
        sb.append(b2.toString());
        sb.append("padding-start:" + (((float) tableRow.getGapHalf()) / 1440.0f) + "in;");
        sb.append("padding-end:" + (((float) tableRow.getGapHalf()) / 1440.0f) + "in;");
        BorderCode topBorder = (tableCell.getBrcTop() == null || tableCell.getBrcTop().getBorderType() == 0) ? z ? tableRow.getTopBorder() : tableRow.getHorizontalBorder() : tableCell.getBrcTop();
        BorderCode bottomBorder = (tableCell.getBrcBottom() == null || tableCell.getBrcBottom().getBorderType() == 0) ? z2 ? tableRow.getBottomBorder() : tableRow.getHorizontalBorder() : tableCell.getBrcBottom();
        BorderCode leftBorder = (tableCell.getBrcLeft() == null || tableCell.getBrcLeft().getBorderType() == 0) ? z3 ? tableRow.getLeftBorder() : tableRow.getVerticalBorder() : tableCell.getBrcLeft();
        BorderCode rightBorder = (tableCell.getBrcRight() == null || tableCell.getBrcRight().getBorderType() == 0) ? z4 ? tableRow.getRightBorder() : tableRow.getVerticalBorder() : tableCell.getBrcRight();
        addBorder(bottomBorder, "bottom", sb);
        addBorder(leftBorder, "left", sb);
        addBorder(rightBorder, "right", sb);
        addBorder(topBorder, "top", sb);
    }

    public static void addTableRowProperties(TableRow tableRow, StringBuilder sb) {
        if (tableRow.getRowHeight() > 0) {
            StringBuilder b2 = a.b("height:");
            b2.append(((float) tableRow.getRowHeight()) / 1440.0f);
            b2.append("in;");
            sb.append(b2.toString());
        }
        if (!tableRow.cantSplit()) {
            sb.append("keep-together:always;");
        }
    }

    public static void compactSpans(Element element) {
        AbstractWordUtils.compactChildNodesR(element, "span");
    }

    public static void addIndent(StringBuilder sb, String str, int i2) {
        if (i2 != 0) {
            StringBuilder d2 = a.d(str, ":");
            d2.append(((float) i2) / 1440.0f);
            d2.append("in;");
            sb.append(d2.toString());
        }
    }
}
