package org.apache.poi.hwpf.converter;

import b.b.a.a.a;
import java.io.File;
import java.io.PrintStream;
import java.io.StringWriter;
import java.util.List;
import java.util.concurrent.atomic.AtomicInteger;
import javax.xml.parsers.DocumentBuilderFactory;
import javax.xml.transform.OutputKeys;
import javax.xml.transform.Transformer;
import javax.xml.transform.TransformerFactory;
import javax.xml.transform.dom.DOMSource;
import javax.xml.transform.stream.StreamResult;
import org.apache.poi.hpsf.SummaryInformation;
import org.apache.poi.hwpf.HWPFDocument;
import org.apache.poi.hwpf.HWPFDocumentCore;
import org.apache.poi.hwpf.usermodel.Bookmark;
import org.apache.poi.hwpf.usermodel.CharacterRun;
import org.apache.poi.hwpf.usermodel.OfficeDrawing;
import org.apache.poi.hwpf.usermodel.Paragraph;
import org.apache.poi.hwpf.usermodel.Picture;
import org.apache.poi.hwpf.usermodel.Range;
import org.apache.poi.hwpf.usermodel.Section;
import org.apache.poi.hwpf.usermodel.Table;
import org.apache.poi.hwpf.usermodel.TableCell;
import org.apache.poi.hwpf.usermodel.TableRow;
import org.apache.poi.poifs.filesystem.DirectoryNode;
import org.apache.poi.poifs.filesystem.Entry;
import org.apache.poi.util.POILogFactory;
import org.apache.poi.util.POILogger;
import org.apache.poi.util.XMLHelper;
import org.w3c.dom.Document;
import org.w3c.dom.Element;

public class WordToTextConverter extends AbstractWordConverter {
    public static final POILogger logger = POILogFactory.getLogger(WordToTextConverter.class);
    public AtomicInteger noteCounters;
    public Element notes;
    public boolean outputSummaryInformation;
    public final TextDocumentFacade textDocumentFacade;

    public WordToTextConverter() {
        this.noteCounters = new AtomicInteger(1);
        this.notes = null;
        this.outputSummaryInformation = false;
        this.textDocumentFacade = new TextDocumentFacade(DocumentBuilderFactory.newInstance().newDocumentBuilder().newDocument());
    }

    public static String getText(DirectoryNode directoryNode) {
        return getText(AbstractWordUtils.loadDoc(directoryNode));
    }

    public static void main(String[] strArr) {
        if (strArr.length < 2) {
            System.err.println("Usage: WordToTextConverter <inputFile.doc> <saveTo.txt>");
            return;
        }
        PrintStream printStream = System.out;
        StringBuilder b2 = a.b("Converting ");
        b2.append(strArr[0]);
        printStream.println(b2.toString());
        PrintStream printStream2 = System.out;
        StringBuilder b3 = a.b("Saving output to ");
        b3.append(strArr[1]);
        printStream2.println(b3.toString());
        DOMSource dOMSource = new DOMSource(process(new File(strArr[0])));
        StreamResult streamResult = new StreamResult(new File(strArr[1]));
        Transformer newTransformer = TransformerFactory.newInstance().newTransformer();
        newTransformer.setOutputProperty(OutputKeys.ENCODING, "UTF-8");
        newTransformer.setOutputProperty(OutputKeys.INDENT, "no");
        newTransformer.setOutputProperty("method", "text");
        newTransformer.transform(dOMSource, streamResult);
    }

    public static Document process(File file) {
        HWPFDocumentCore loadDoc = AbstractWordUtils.loadDoc(file);
        WordToTextConverter wordToTextConverter = new WordToTextConverter(XMLHelper.getDocumentBuilderFactory().newDocumentBuilder().newDocument());
        wordToTextConverter.processDocument(loadDoc);
        return wordToTextConverter.getDocument();
    }

    @Override // org.apache.poi.hwpf.converter.AbstractWordConverter
    public void afterProcess() {
        if (this.notes != null) {
            this.textDocumentFacade.getBody().appendChild(this.notes);
        }
    }

    @Override // org.apache.poi.hwpf.converter.AbstractWordConverter
    public Document getDocument() {
        return this.textDocumentFacade.getDocument();
    }

    public boolean isOutputSummaryInformation() {
        return this.outputSummaryInformation;
    }

    @Override // org.apache.poi.hwpf.converter.AbstractWordConverter
    public void outputCharacters(Element element, CharacterRun characterRun, String str) {
        element.appendChild(this.textDocumentFacade.createText(str));
    }

    @Override // org.apache.poi.hwpf.converter.AbstractWordConverter
    public void processBookmarks(HWPFDocumentCore hWPFDocumentCore, Element element, Range range, int i2, List<Bookmark> list) {
        processCharacters(hWPFDocumentCore, i2, range, element);
    }

    @Override // org.apache.poi.hwpf.converter.AbstractWordConverter
    public void processDocumentInformation(SummaryInformation summaryInformation) {
        if (isOutputSummaryInformation()) {
            if (AbstractWordUtils.isNotEmpty(summaryInformation.getTitle())) {
                this.textDocumentFacade.setTitle(summaryInformation.getTitle());
            }
            if (AbstractWordUtils.isNotEmpty(summaryInformation.getAuthor())) {
                this.textDocumentFacade.addAuthor(summaryInformation.getAuthor());
            }
            if (AbstractWordUtils.isNotEmpty(summaryInformation.getComments())) {
                this.textDocumentFacade.addDescription(summaryInformation.getComments());
            }
            if (AbstractWordUtils.isNotEmpty(summaryInformation.getKeywords())) {
                this.textDocumentFacade.addKeywords(summaryInformation.getKeywords());
            }
        }
    }

    @Override // org.apache.poi.hwpf.converter.AbstractWordConverter
    public void processDocumentPart(HWPFDocumentCore hWPFDocumentCore, Range range) {
        super.processDocumentPart(hWPFDocumentCore, range);
        afterProcess();
    }

    @Override // org.apache.poi.hwpf.converter.AbstractWordConverter
    public void processDrawnObject(HWPFDocument hWPFDocument, CharacterRun characterRun, OfficeDrawing officeDrawing, String str, Element element) {
    }

    @Override // org.apache.poi.hwpf.converter.AbstractWordConverter
    public void processEndnoteAutonumbered(HWPFDocument hWPFDocument, int i2, Element element, Range range) {
        processNote(hWPFDocument, element, range);
    }

    @Override // org.apache.poi.hwpf.converter.AbstractWordConverter
    public void processFootnoteAutonumbered(HWPFDocument hWPFDocument, int i2, Element element, Range range) {
        processNote(hWPFDocument, element, range);
    }

    @Override // org.apache.poi.hwpf.converter.AbstractWordConverter
    public void processHyperlink(HWPFDocumentCore hWPFDocumentCore, Element element, Range range, int i2, String str) {
        processCharacters(hWPFDocumentCore, i2, range, element);
        TextDocumentFacade textDocumentFacade2 = this.textDocumentFacade;
        StringBuilder b2 = a.b(" (​");
        b2.append(str.replaceAll("\\/", "​\\/​"));
        b2.append(AbstractWordConverter.UNICODECHAR_ZERO_WIDTH_SPACE);
        b2.append(")");
        element.appendChild(textDocumentFacade2.createText(b2.toString()));
    }

    @Override // org.apache.poi.hwpf.converter.AbstractWordConverter
    public void processImage(Element element, boolean z, Picture picture) {
    }

    @Override // org.apache.poi.hwpf.converter.AbstractWordConverter
    public void processImage(Element element, boolean z, Picture picture, String str) {
    }

    @Override // org.apache.poi.hwpf.converter.AbstractWordConverter
    public void processImageWithoutPicturesManager(Element element, boolean z, Picture picture) {
    }

    @Override // org.apache.poi.hwpf.converter.AbstractWordConverter
    public void processLineBreak(Element element, CharacterRun characterRun) {
        element.appendChild(this.textDocumentFacade.createText("\n"));
    }

    public void processNote(HWPFDocument hWPFDocument, Element element, Range range) {
        int andIncrement = this.noteCounters.getAndIncrement();
        TextDocumentFacade textDocumentFacade2 = this.textDocumentFacade;
        element.appendChild(textDocumentFacade2.createText("​[" + andIncrement + "]" + AbstractWordConverter.UNICODECHAR_ZERO_WIDTH_SPACE));
        if (this.notes == null) {
            this.notes = this.textDocumentFacade.createBlock();
        }
        Element createBlock = this.textDocumentFacade.createBlock();
        this.notes.appendChild(createBlock);
        TextDocumentFacade textDocumentFacade3 = this.textDocumentFacade;
        createBlock.appendChild(textDocumentFacade3.createText("^" + andIncrement + "\t "));
        processCharacters(hWPFDocument, Integer.MIN_VALUE, range, createBlock);
        createBlock.appendChild(this.textDocumentFacade.createText("\n"));
    }

    @Override // org.apache.poi.hwpf.converter.AbstractWordConverter
    public boolean processOle2(HWPFDocument hWPFDocument, Element element, Entry entry) {
        if (!(entry instanceof DirectoryNode)) {
            return false;
        }
        DirectoryNode directoryNode = (DirectoryNode) entry;
        if (directoryNode.hasEntry(HWPFDocumentCore.STREAM_WORD_DOCUMENT)) {
            String text = getText(directoryNode);
            TextDocumentFacade textDocumentFacade2 = this.textDocumentFacade;
            element.appendChild(textDocumentFacade2.createText(AbstractWordConverter.UNICODECHAR_ZERO_WIDTH_SPACE + text + AbstractWordConverter.UNICODECHAR_ZERO_WIDTH_SPACE));
            return true;
        }
        try {
            Object invoke = Class.forName("org.apache.poi.extractor.ExtractorFactory").getMethod("createExtractor", DirectoryNode.class).invoke(null, directoryNode);
            try {
                TextDocumentFacade textDocumentFacade3 = this.textDocumentFacade;
                element.appendChild(textDocumentFacade3.createText(AbstractWordConverter.UNICODECHAR_ZERO_WIDTH_SPACE + ((String) invoke.getClass().getMethod("getText", new Class[0]).invoke(invoke, new Object[0])) + AbstractWordConverter.UNICODECHAR_ZERO_WIDTH_SPACE));
                return true;
            } catch (Exception e2) {
                logger.log(7, "Unable to extract text from OLE entry '", entry.getName(), "': ", e2, e2);
                return false;
            }
        } catch (Exception e3) {
            POILogger pOILogger = logger;
            pOILogger.log(5, "There is an OLE object entry '", entry.getName(), "', but there is no text extractor for this object type ", "or text extractor factory is not available: ", "" + e3);
            return false;
        }
    }

    @Override // org.apache.poi.hwpf.converter.AbstractWordConverter
    public void processPageBreak(HWPFDocumentCore hWPFDocumentCore, Element element) {
        Element createBlock = this.textDocumentFacade.createBlock();
        createBlock.appendChild(this.textDocumentFacade.createText("\n"));
        element.appendChild(createBlock);
    }

    @Override // org.apache.poi.hwpf.converter.AbstractWordConverter
    public void processPageref(HWPFDocumentCore hWPFDocumentCore, Element element, Range range, int i2, String str) {
        processCharacters(hWPFDocumentCore, i2, range, element);
    }

    @Override // org.apache.poi.hwpf.converter.AbstractWordConverter
    public void processParagraph(HWPFDocumentCore hWPFDocumentCore, Element element, int i2, Paragraph paragraph, String str) {
        Element createParagraph = this.textDocumentFacade.createParagraph();
        createParagraph.appendChild(this.textDocumentFacade.createText(str));
        processCharacters(hWPFDocumentCore, i2, paragraph, createParagraph);
        createParagraph.appendChild(this.textDocumentFacade.createText("\n"));
        element.appendChild(createParagraph);
    }

    @Override // org.apache.poi.hwpf.converter.AbstractWordConverter
    public void processSection(HWPFDocumentCore hWPFDocumentCore, Section section, int i2) {
        Element createBlock = this.textDocumentFacade.createBlock();
        processParagraphes(hWPFDocumentCore, createBlock, section, Integer.MIN_VALUE);
        createBlock.appendChild(this.textDocumentFacade.createText("\n"));
        this.textDocumentFacade.body.appendChild(createBlock);
    }

    @Override // org.apache.poi.hwpf.converter.AbstractWordConverter
    public void processTable(HWPFDocumentCore hWPFDocumentCore, Element element, Table table) {
        int numRows = table.numRows();
        for (int i2 = 0; i2 < numRows; i2++) {
            TableRow row = table.getRow(i2);
            Element createTableRow = this.textDocumentFacade.createTableRow();
            int numCells = row.numCells();
            for (int i3 = 0; i3 < numCells; i3++) {
                TableCell cell = row.getCell(i3);
                Element createTableCell = this.textDocumentFacade.createTableCell();
                if (i3 != 0) {
                    createTableCell.appendChild(this.textDocumentFacade.createText("\t"));
                }
                processCharacters(hWPFDocumentCore, table.getTableLevel(), cell, createTableCell);
                createTableRow.appendChild(createTableCell);
            }
            createTableRow.appendChild(this.textDocumentFacade.createText("\n"));
            element.appendChild(createTableRow);
        }
    }

    public void setOutputSummaryInformation(boolean z) {
        this.outputSummaryInformation = z;
    }

    public static String getText(File file) {
        return getText(AbstractWordUtils.loadDoc(file));
    }

    public static String getText(HWPFDocumentCore hWPFDocumentCore) {
        WordToTextConverter wordToTextConverter = new WordToTextConverter(XMLHelper.getDocumentBuilderFactory().newDocumentBuilder().newDocument());
        wordToTextConverter.processDocument(hWPFDocumentCore);
        return wordToTextConverter.getText();
    }

    public WordToTextConverter(Document document) {
        this.noteCounters = new AtomicInteger(1);
        this.notes = null;
        this.outputSummaryInformation = false;
        this.textDocumentFacade = new TextDocumentFacade(document);
    }

    public String getText() {
        StringWriter stringWriter = new StringWriter();
        DOMSource dOMSource = new DOMSource(getDocument());
        StreamResult streamResult = new StreamResult(stringWriter);
        Transformer newTransformer = TransformerFactory.newInstance().newTransformer();
        newTransformer.setOutputProperty(OutputKeys.ENCODING, "UTF-8");
        newTransformer.setOutputProperty(OutputKeys.INDENT, "no");
        newTransformer.setOutputProperty("method", "text");
        newTransformer.transform(dOMSource, streamResult);
        return stringWriter.toString();
    }

    public WordToTextConverter(TextDocumentFacade textDocumentFacade2) {
        this.noteCounters = new AtomicInteger(1);
        this.notes = null;
        this.outputSummaryInformation = false;
        this.textDocumentFacade = textDocumentFacade2;
    }
}
