package org.apache.poi.hwpf.dev;

import b.b.a.a.a;
import java.io.ByteArrayInputStream;
import java.io.ByteArrayOutputStream;
import java.io.File;
import java.io.FileInputStream;
import java.io.IOException;
import java.io.InputStream;
import java.io.PrintStream;
import java.util.ArrayList;
import java.util.Arrays;
import java.util.Collections;
import java.util.Iterator;
import java.util.LinkedHashMap;
import java.util.Map;
import org.apache.poi.hssf.record.EscherAggregate;
import org.apache.poi.hwpf.HWPFDocument;
import org.apache.poi.hwpf.HWPFDocumentCore;
import org.apache.poi.hwpf.HWPFOldDocument;
import org.apache.poi.hwpf.OldWordFileFormatException;
import org.apache.poi.hwpf.model.CHPX;
import org.apache.poi.hwpf.model.FieldsDocumentPart;
import org.apache.poi.hwpf.model.LFO;
import org.apache.poi.hwpf.model.LFOData;
import org.apache.poi.hwpf.model.ListLevel;
import org.apache.poi.hwpf.model.ListTables;
import org.apache.poi.hwpf.model.PAPFormattedDiskPage;
import org.apache.poi.hwpf.model.PAPX;
import org.apache.poi.hwpf.model.PlexOfCps;
import org.apache.poi.hwpf.model.StyleDescription;
import org.apache.poi.hwpf.model.TextPiece;
import org.apache.poi.hwpf.sprm.SprmIterator;
import org.apache.poi.hwpf.sprm.SprmOperation;
import org.apache.poi.hwpf.usermodel.Bookmark;
import org.apache.poi.hwpf.usermodel.Bookmarks;
import org.apache.poi.hwpf.usermodel.Field;
import org.apache.poi.hwpf.usermodel.OfficeDrawing;
import org.apache.poi.hwpf.usermodel.Paragraph;
import org.apache.poi.hwpf.usermodel.ParagraphProperties;
import org.apache.poi.hwpf.usermodel.Picture;
import org.apache.poi.hwpf.usermodel.Range;
import org.apache.poi.poifs.filesystem.DirectoryEntry;
import org.apache.poi.poifs.filesystem.Entry;
import org.apache.poi.poifs.filesystem.POIFSFileSystem;
import org.apache.poi.util.IOUtils;
import org.apache.poi.util.LittleEndian;

public final class HWPFLister {
    public final HWPFDocumentCore _doc;
    public LinkedHashMap<Integer, String> paragraphs;

    public HWPFLister(HWPFDocumentCore hWPFDocumentCore) {
        this._doc = hWPFDocumentCore;
        buildParagraphs();
    }

    private void buildParagraphs() {
        this.paragraphs = new LinkedHashMap<>();
        StringBuilder sb = new StringBuilder();
        String documentText = this._doc.getDocumentText();
        for (int i2 = 0; i2 < documentText.length(); i2++) {
            char charAt = documentText.charAt(i2);
            sb.append(charAt);
            if (charAt == '\r' || charAt == 7 || charAt == '\f') {
                this.paragraphs.put(Integer.valueOf(i2), sb.toString());
                sb.setLength(0);
            }
        }
    }

    private void dumpBookmarks() {
        HWPFDocumentCore hWPFDocumentCore = this._doc;
        if (!(hWPFDocumentCore instanceof HWPFDocument)) {
            System.out.println("Word 95 not supported so far");
            return;
        }
        Bookmarks bookmarks = ((HWPFDocument) hWPFDocumentCore).getBookmarks();
        for (int i2 = 0; i2 < bookmarks.getBookmarksCount(); i2++) {
            Bookmark bookmark = bookmarks.getBookmark(i2);
            PrintStream printStream = System.out;
            StringBuilder b2 = a.b("[");
            b2.append(bookmark.getStart());
            b2.append("; ");
            b2.append(bookmark.getEnd());
            b2.append("): ");
            b2.append(bookmark.getName());
            printStream.println(b2.toString());
        }
    }

    private void dumpDop() {
        HWPFDocumentCore hWPFDocumentCore = this._doc;
        if (!(hWPFDocumentCore instanceof HWPFDocument)) {
            System.out.println("Word 95 not supported so far");
        } else {
            System.out.println(((HWPFDocument) hWPFDocumentCore).getDocProperties());
        }
    }

    private void dumpEscher() {
        HWPFDocumentCore hWPFDocumentCore = this._doc;
        if (hWPFDocumentCore instanceof HWPFOldDocument) {
            System.out.println("Word 95 not supported so far");
        } else {
            System.out.println(((HWPFDocument) hWPFDocumentCore).getEscherRecordHolder());
        }
    }

    private void dumpFields() {
        HWPFDocumentCore hWPFDocumentCore = this._doc;
        if (!(hWPFDocumentCore instanceof HWPFDocument)) {
            System.out.println("Word 95 not supported so far");
            return;
        }
        HWPFDocument hWPFDocument = (HWPFDocument) hWPFDocumentCore;
        FieldsDocumentPart[] values = FieldsDocumentPart.values();
        for (FieldsDocumentPart fieldsDocumentPart : values) {
            System.out.println("=== Document part: " + fieldsDocumentPart + " ===");
            for (Field field : hWPFDocument.getFields().getFields(fieldsDocumentPart)) {
                System.out.println(field);
            }
        }
    }

    private void dumpOfficeDrawings() {
        HWPFDocumentCore hWPFDocumentCore = this._doc;
        if (!(hWPFDocumentCore instanceof HWPFDocument)) {
            System.out.println("Word 95 not supported so far");
            return;
        }
        HWPFDocument hWPFDocument = (HWPFDocument) hWPFDocumentCore;
        if (hWPFDocument.getOfficeDrawingsHeaders() != null) {
            System.out.println("=== Document part: HEADER ===");
            for (OfficeDrawing officeDrawing : hWPFDocument.getOfficeDrawingsHeaders().getOfficeDrawings()) {
                System.out.println(officeDrawing);
            }
        }
        if (hWPFDocument.getOfficeDrawingsHeaders() != null) {
            System.out.println("=== Document part: MAIN ===");
            for (OfficeDrawing officeDrawing2 : hWPFDocument.getOfficeDrawingsMain().getOfficeDrawings()) {
                System.out.println(officeDrawing2);
            }
        }
    }

    private void dumpPictures() {
        HWPFDocumentCore hWPFDocumentCore = this._doc;
        if (hWPFDocumentCore instanceof HWPFOldDocument) {
            System.out.println("Word 95 not supported so far");
            return;
        }
        for (Picture picture : ((HWPFDocument) hWPFDocumentCore).getPicturesTable().getAllPictures()) {
            System.out.println(picture);
        }
    }

    private void dumpStyles() {
        HWPFDocumentCore hWPFDocumentCore = this._doc;
        if (hWPFDocumentCore instanceof HWPFOldDocument) {
            System.out.println("Word 95 not supported so far");
            return;
        }
        HWPFDocument hWPFDocument = (HWPFDocument) hWPFDocumentCore;
        for (int i2 = 0; i2 < hWPFDocument.getStyleSheet().numStyles(); i2++) {
            StyleDescription styleDescription = hWPFDocument.getStyleSheet().getStyleDescription(i2);
            if (styleDescription != null) {
                PrintStream printStream = System.out;
                StringBuilder a = a.a("=== Style #", i2, " '");
                a.append(styleDescription.getName());
                a.append("' ===");
                printStream.println(a.toString());
                System.out.println(styleDescription);
                if (styleDescription.getPAPX() != null) {
                    dumpSprms(new SprmIterator(styleDescription.getPAPX(), 2), "Style's PAP SPRM: ");
                }
                if (styleDescription.getCHPX() != null) {
                    dumpSprms(new SprmIterator(styleDescription.getCHPX(), 0), "Style's CHP SPRM: ");
                }
            }
        }
    }

    public static HWPFDocumentCore loadDoc(File file) {
        FileInputStream fileInputStream = new FileInputStream(file);
        try {
            return loadDoc(fileInputStream);
        } finally {
            IOUtils.closeQuietly(fileInputStream);
        }
    }

    public static void main(String[] strArr) {
        if (strArr.length == 0) {
            System.err.println("Use:");
            System.err.println("\tHWPFLister <filename>\n\t\t[--dop]\n\t\t[--textPieces] [--textPiecesText]\n\t\t[--chpx] [--chpxProperties] [--chpxSprms]\n\t\t[--papx] [--papxProperties] [--papxSprms]\n\t\t[--paragraphs] [--paragraphsText]\n\t\t[--bookmarks]\n\t\t[--escher]\n\t\t[--fields]\n\t\t[--pictures]\n\t\t[--officeDrawings]\n\t\t[--styles]\n\t\t[--writereadback]\n");
            System.exit(1);
        }
        boolean z = false;
        boolean z2 = false;
        boolean z3 = false;
        boolean z4 = false;
        boolean z5 = false;
        boolean z6 = false;
        boolean z7 = false;
        boolean z8 = false;
        boolean z9 = false;
        boolean z10 = false;
        boolean z11 = false;
        boolean z12 = false;
        boolean z13 = false;
        boolean z14 = false;
        boolean z15 = false;
        boolean z16 = false;
        boolean z17 = false;
        boolean z18 = false;
        for (String str : Arrays.asList(strArr).subList(1, strArr.length)) {
            if ("--dop".equals(str)) {
                z2 = true;
            }
            if ("--textPieces".equals(str)) {
                z3 = true;
            }
            if ("--textPiecesText".equals(str)) {
                z4 = true;
            }
            if ("--chpx".equals(str)) {
                z5 = true;
            }
            if ("--chpxProperties".equals(str)) {
                z6 = true;
            }
            if ("--chpxSprms".equals(str)) {
                z7 = true;
            }
            if ("--paragraphs".equals(str)) {
                z11 = true;
            }
            if ("--paragraphsText".equals(str)) {
                z12 = true;
            }
            if ("--papx".equals(str)) {
                z8 = true;
            }
            if ("--papxProperties".equals(str)) {
                z9 = true;
            }
            if ("--papxSprms".equals(str)) {
                z10 = true;
            }
            if ("--bookmarks".equals(str)) {
                z13 = true;
            }
            if ("--escher".equals(str)) {
                z14 = true;
            }
            if ("--fields".equals(str)) {
                z15 = true;
            }
            if ("--pictures".equals(str)) {
                z17 = true;
            }
            if ("--officeDrawings".equals(str)) {
                z16 = true;
            }
            if ("--styles".equals(str)) {
                z18 = true;
            }
            if ("--writereadback".equals(str)) {
                z = true;
            }
        }
        HWPFDocumentCore loadDoc = loadDoc(new File(strArr[0]));
        if (z) {
            loadDoc = writeOutAndReadBack(loadDoc);
        }
        System.setProperty(HWPFDocument.PROPERTY_PRESERVE_BIN_TABLES, Boolean.TRUE.toString());
        System.setProperty(HWPFDocument.PROPERTY_PRESERVE_TEXT_TABLE, Boolean.TRUE.toString());
        HWPFDocumentCore loadDoc2 = loadDoc(new File(strArr[0]));
        if (z) {
            loadDoc2 = writeOutAndReadBack(loadDoc2);
        }
        HWPFLister hWPFLister = new HWPFLister(loadDoc2);
        HWPFLister hWPFLister2 = new HWPFLister(loadDoc);
        System.out.println("== OLE streams ==");
        hWPFLister.dumpFileSystem();
        System.out.println("== FIB (original) ==");
        hWPFLister.dumpFIB();
        if (z2) {
            System.out.println("== Document properties ==");
            hWPFLister.dumpDop();
        }
        if (z3) {
            System.out.println("== Text pieces (original) ==");
            hWPFLister.dumpTextPieces(z4);
        }
        if (z5) {
            System.out.println("== CHPX (original) ==");
            hWPFLister.dumpChpx(z6, z7);
            System.out.println("== CHPX (rebuilded) ==");
            hWPFLister2.dumpChpx(z6, z7);
        }
        if (z8) {
            System.out.println("== PAPX (original) ==");
            hWPFLister.dumpPapx(z9, z10);
            System.out.println("== PAPX (rebuilded) ==");
            hWPFLister2.dumpPapx(z9, z10);
        }
        if (z11) {
            System.out.println("== Text paragraphs (original) ==");
            hWPFLister2.dumpParagraphs(true);
            System.out.println("== DOM paragraphs (rebuilded) ==");
            hWPFLister2.dumpParagraphsDom(z12);
        }
        if (z13) {
            System.out.println("== BOOKMARKS (rebuilded) ==");
            hWPFLister2.dumpBookmarks();
        }
        if (z14) {
            System.out.println("== ESCHER PROPERTIES (rebuilded) ==");
            hWPFLister2.dumpEscher();
        }
        if (z15) {
            System.out.println("== FIELDS (rebuilded) ==");
            hWPFLister2.dumpFields();
        }
        if (z16) {
            System.out.println("== OFFICE DRAWINGS (rebuilded) ==");
            hWPFLister2.dumpOfficeDrawings();
        }
        if (z17) {
            System.out.println("== PICTURES (rebuilded) ==");
            hWPFLister2.dumpPictures();
        }
        if (z18) {
            System.out.println("== STYLES (rebuilded) ==");
            hWPFLister2.dumpStyles();
        }
    }

    public static HWPFDocumentCore writeOutAndReadBack(HWPFDocumentCore hWPFDocumentCore) {
        try {
            ByteArrayOutputStream byteArrayOutputStream = new ByteArrayOutputStream(4096);
            hWPFDocumentCore.write(byteArrayOutputStream);
            return loadDoc(new ByteArrayInputStream(byteArrayOutputStream.toByteArray()));
        } catch (IOException e2) {
            throw new RuntimeException(e2);
        }
    }

    public void dumpChpx(boolean z, boolean z2) {
        for (CHPX chpx : this._doc.getCharacterTable().getTextRuns()) {
            System.out.println(chpx);
            if (z) {
                System.out.println(chpx.getCharacterProperties(this._doc.getStyleSheet(), EscherAggregate.ST_NIL));
            }
            if (z2) {
                SprmIterator sprmIterator = new SprmIterator(chpx.getGrpprl(), 0);
                while (sprmIterator.hasNext()) {
                    SprmOperation next = sprmIterator.next();
                    System.out.println("\t" + next);
                }
            }
            String text = new Range(chpx.getStart(), chpx.getEnd(), this._doc.getOverallRange()) {
                /* class org.apache.poi.hwpf.dev.HWPFLister.AnonymousClass1 */

                @Override // org.apache.poi.hwpf.usermodel.Range
                public String toString() {
                    return a.a(a.b("CHPX range ("), super.toString(), ")");
                }
            }.text();
            StringBuilder sb = new StringBuilder();
            char[] charArray = text.toCharArray();
            for (char c : charArray) {
                if (c < 30) {
                    sb.append("\\0x");
                    sb.append(Integer.toHexString(c));
                } else {
                    sb.append(c);
                }
            }
            System.out.println(sb);
        }
    }

    public void dumpFIB() {
        System.out.println(this._doc.getFileInformationBlock());
    }

    public void dumpFileSystem() {
        System.out.println(dumpFileSystem((DirectoryEntry) this._doc.getDirectory()));
    }

    public void dumpPapx(boolean z, boolean z2) {
        if (this._doc instanceof HWPFDocument) {
            System.out.println("binary PAP pages ");
            HWPFDocumentCore hWPFDocumentCore = this._doc;
            HWPFDocument hWPFDocument = (HWPFDocument) hWPFDocumentCore;
            byte[] mainStream = hWPFDocumentCore.getMainStream();
            PlexOfCps plexOfCps = new PlexOfCps(hWPFDocument.getTableStream(), hWPFDocument.getFileInformationBlock().getFcPlcfbtePapx(), hWPFDocument.getFileInformationBlock().getLcbPlcfbtePapx(), 4);
            ArrayList arrayList = new ArrayList();
            int length = plexOfCps.length();
            for (int i2 = 0; i2 < length; i2++) {
                PAPFormattedDiskPage pAPFormattedDiskPage = new PAPFormattedDiskPage(mainStream, hWPFDocument.getDataStream(), LittleEndian.getInt(plexOfCps.getProperty(i2).getBytes()) * 512, hWPFDocument.getTextTable());
                PrintStream printStream = System.out;
                printStream.println("* PFKP: " + pAPFormattedDiskPage);
                for (PAPX papx : pAPFormattedDiskPage.getPAPXs()) {
                    PrintStream printStream2 = System.out;
                    printStream2.println("** " + papx);
                    arrayList.add(papx);
                    if (papx != null && z2) {
                        dumpSprms(new SprmIterator(papx.getGrpprl(), 2), "*** ");
                    }
                }
            }
            Collections.sort(arrayList);
            System.out.println("* Sorted by END");
            Iterator it = arrayList.iterator();
            while (it.hasNext()) {
                PAPX papx2 = (PAPX) it.next();
                PrintStream printStream3 = System.out;
                printStream3.println("** " + papx2);
                if (papx2 != null && z2) {
                    dumpSprms(new SprmIterator(papx2.getGrpprl(), 2), "*** ");
                }
            }
        }
        Iterator<PAPX> it2 = this._doc.getParagraphTable().getParagraphs().iterator();
        while (it2.hasNext()) {
            PAPX next = it2.next();
            System.out.println(next);
            if (z) {
                System.out.println(Paragraph.newParagraph(this._doc.getOverallRange(), next).getProps());
            }
            dumpSprms(new SprmIterator(next.getGrpprl(), 2), "\t");
        }
    }

    public void dumpParagraphLevels(ListTables listTables, ParagraphProperties paragraphProperties) {
        if (paragraphProperties.getIlfo() != 0) {
            LFO lfo = listTables.getLfo(paragraphProperties.getIlfo());
            PrintStream printStream = System.out;
            printStream.println("PAP's LFO: " + lfo);
            LFOData lfoData = listTables.getLfoData(paragraphProperties.getIlfo());
            PrintStream printStream2 = System.out;
            printStream2.println("PAP's LFOData: " + lfoData);
            if (lfo != null) {
                ListLevel level = listTables.getLevel(lfo.getLsid(), paragraphProperties.getIlvl());
                PrintStream printStream3 = System.out;
                printStream3.println("PAP's ListLevel: " + level);
                if (level.getGrpprlPapx() != null) {
                    System.out.println("PAP's ListLevel PAPX:");
                    dumpSprms(new SprmIterator(level.getGrpprlPapx(), 0), "* ");
                }
                if (level.getGrpprlPapx() != null) {
                    System.out.println("PAP's ListLevel CHPX:");
                    dumpSprms(new SprmIterator(level.getGrpprlChpx(), 0), "* ");
                }
            }
        }
    }

    public void dumpParagraphs(boolean z) {
        for (Map.Entry<Integer, String> entry : this.paragraphs.entrySet()) {
            Integer key = entry.getKey();
            PrintStream printStream = System.out;
            StringBuilder b2 = a.b("[...; ");
            b2.append(key.intValue() + 1);
            b2.append("): ");
            b2.append(entry.getValue());
            printStream.println(b2.toString());
            if (z) {
                boolean z2 = false;
                Iterator<PAPX> it = this._doc.getParagraphTable().getParagraphs().iterator();
                while (it.hasNext()) {
                    PAPX next = it.next();
                    if (next.getStart() <= key.intValue() && key.intValue() < next.getEnd()) {
                        PrintStream printStream2 = System.out;
                        printStream2.println("* " + next);
                        dumpSprms(new SprmIterator(next.getGrpprl(), 2), "** ");
                        z2 = true;
                    }
                }
                if (!z2) {
                    System.out.println("* NO PAPX ASSOTIATED WITH PARAGRAPH!");
                }
            }
        }
    }

    public void dumpParagraphsDom(boolean z) {
        Range overallRange = this._doc.getOverallRange();
        for (int i2 = 0; i2 < overallRange.numParagraphs(); i2++) {
            Paragraph paragraph = overallRange.getParagraph(i2);
            PrintStream printStream = System.out;
            printStream.println(i2 + ":\t" + paragraph);
            if (z) {
                System.out.println(paragraph.text());
            }
        }
    }

    public void dumpSprms(SprmIterator sprmIterator, String str) {
        while (sprmIterator.hasNext()) {
            SprmOperation next = sprmIterator.next();
            PrintStream printStream = System.out;
            printStream.println(str + next);
        }
    }

    public void dumpTextPieces(boolean z) {
        for (TextPiece textPiece : this._doc.getTextTable().getTextPieces()) {
            System.out.println(textPiece);
            if (z) {
                PrintStream printStream = System.out;
                StringBuilder b2 = a.b("\t");
                b2.append((Object) textPiece.getStringBuilder());
                printStream.println(b2.toString());
            }
        }
    }

    private String dumpFileSystem(DirectoryEntry directoryEntry) {
        StringBuilder b2 = a.b("+ ");
        b2.append(directoryEntry.getName());
        Iterator<Entry> entries = directoryEntry.getEntries();
        while (entries.hasNext()) {
            StringBuilder b3 = a.b("\n");
            b3.append(dumpFileSystem(entries.next()));
            b2.append(b3.toString().replaceAll("\n", "\n+---"));
        }
        b2.append("\n");
        return b2.toString();
    }

    public static HWPFDocumentCore loadDoc(InputStream inputStream) {
        POIFSFileSystem verifyAndBuildPOIFS = HWPFDocumentCore.verifyAndBuildPOIFS(inputStream);
        try {
            return new HWPFDocument(verifyAndBuildPOIFS);
        } catch (OldWordFileFormatException unused) {
            return new HWPFOldDocument(verifyAndBuildPOIFS);
        }
    }

    private String dumpFileSystem(Entry entry) {
        if (entry instanceof DirectoryEntry) {
            return dumpFileSystem((DirectoryEntry) entry);
        }
        return entry.getName();
    }
}
