package org.apache.poi.hwpf.extractor;

import b.b.a.a.a;
import java.io.FileInputStream;
import java.io.InputStream;
import org.apache.poi.POIOLE2TextExtractor;
import org.apache.poi.hwpf.HWPFDocument;
import org.apache.poi.hwpf.HWPFDocumentCore;
import org.apache.poi.hwpf.converter.WordToTextConverter;
import org.apache.poi.hwpf.usermodel.HeaderStories;
import org.apache.poi.hwpf.usermodel.Range;
import org.apache.poi.poifs.filesystem.DirectoryNode;
import org.apache.poi.poifs.filesystem.POIFSFileSystem;
import org.apache.poi.ss.formula.FormulaParser;

public final class WordExtractor extends POIOLE2TextExtractor {
    public HWPFDocument doc;

    public WordExtractor(InputStream inputStream) {
        this(HWPFDocumentCore.verifyAndBuildPOIFS(inputStream));
    }

    private void appendHeaderFooter(String str, StringBuffer stringBuffer) {
        if (str != null && str.length() != 0) {
            String replace = str.replace(FormulaParser.CR, '\n');
            if (!replace.endsWith("\n")) {
                stringBuffer.append(replace);
                stringBuffer.append('\n');
            } else if (replace.endsWith("\n\n")) {
                stringBuffer.append(replace.substring(0, replace.length() - 1));
            } else {
                stringBuffer.append(replace);
            }
        }
    }

    public static void main(String[] strArr) {
        if (strArr.length == 0) {
            System.err.println("Use:");
            System.err.println("   java org.apache.poi.hwpf.extractor.WordExtractor <filename>");
            System.exit(1);
        }
        WordExtractor wordExtractor = new WordExtractor(new FileInputStream(strArr[0]));
        try {
            System.out.println(wordExtractor.getText());
        } finally {
            wordExtractor.close();
        }
    }

    public static String stripFields(String str) {
        return Range.stripFields(str);
    }

    public String[] getCommentsText() {
        return getParagraphText(this.doc.getCommentsRange());
    }

    public String[] getEndnoteText() {
        return getParagraphText(this.doc.getEndnoteRange());
    }

    @Deprecated
    public String getFooterText() {
        HeaderStories headerStories = new HeaderStories(this.doc);
        StringBuffer stringBuffer = new StringBuffer();
        if (headerStories.getFirstFooter() != null) {
            appendHeaderFooter(headerStories.getFirstFooter(), stringBuffer);
        }
        if (headerStories.getEvenFooter() != null) {
            appendHeaderFooter(headerStories.getEvenFooter(), stringBuffer);
        }
        if (headerStories.getOddFooter() != null) {
            appendHeaderFooter(headerStories.getOddFooter(), stringBuffer);
        }
        return stringBuffer.toString();
    }

    public String[] getFootnoteText() {
        return getParagraphText(this.doc.getFootnoteRange());
    }

    @Deprecated
    public String getHeaderText() {
        HeaderStories headerStories = new HeaderStories(this.doc);
        StringBuffer stringBuffer = new StringBuffer();
        if (headerStories.getFirstHeader() != null) {
            appendHeaderFooter(headerStories.getFirstHeader(), stringBuffer);
        }
        if (headerStories.getEvenHeader() != null) {
            appendHeaderFooter(headerStories.getEvenHeader(), stringBuffer);
        }
        if (headerStories.getOddHeader() != null) {
            appendHeaderFooter(headerStories.getOddHeader(), stringBuffer);
        }
        return stringBuffer.toString();
    }

    public String[] getMainTextboxText() {
        return getParagraphText(this.doc.getMainTextboxRange());
    }

    public String[] getParagraphText() {
        try {
            return getParagraphText(this.doc.getRange());
        } catch (Exception unused) {
            return new String[]{getTextFromPieces()};
        }
    }

    @Override // org.apache.poi.POITextExtractor
    public String getText() {
        try {
            WordToTextConverter wordToTextConverter = new WordToTextConverter();
            HeaderStories headerStories = new HeaderStories(this.doc);
            if (headerStories.getFirstHeaderSubrange() != null) {
                wordToTextConverter.processDocumentPart(this.doc, headerStories.getFirstHeaderSubrange());
            }
            if (headerStories.getEvenHeaderSubrange() != null) {
                wordToTextConverter.processDocumentPart(this.doc, headerStories.getEvenHeaderSubrange());
            }
            if (headerStories.getOddHeaderSubrange() != null) {
                wordToTextConverter.processDocumentPart(this.doc, headerStories.getOddHeaderSubrange());
            }
            wordToTextConverter.processDocument(this.doc);
            wordToTextConverter.processDocumentPart(this.doc, this.doc.getMainTextboxRange());
            if (headerStories.getFirstFooterSubrange() != null) {
                wordToTextConverter.processDocumentPart(this.doc, headerStories.getFirstFooterSubrange());
            }
            if (headerStories.getEvenFooterSubrange() != null) {
                wordToTextConverter.processDocumentPart(this.doc, headerStories.getEvenFooterSubrange());
            }
            if (headerStories.getOddFooterSubrange() != null) {
                wordToTextConverter.processDocumentPart(this.doc, headerStories.getOddFooterSubrange());
            }
            return wordToTextConverter.getText();
        } catch (RuntimeException e2) {
            throw e2;
        } catch (Exception e3) {
            throw new RuntimeException(e3);
        }
    }

    public String getTextFromPieces() {
        String replaceAll = this.doc.getDocumentText().replaceAll("\r\r\r", "\r\n\r\n\r\n").replaceAll("\r\r", "\r\n\r\n");
        return replaceAll.endsWith("\r") ? a.b(replaceAll, "\n") : replaceAll;
    }

    public WordExtractor(POIFSFileSystem pOIFSFileSystem) {
        this(new HWPFDocument(pOIFSFileSystem));
    }

    public WordExtractor(DirectoryNode directoryNode) {
        this(new HWPFDocument(directoryNode));
    }

    public WordExtractor(HWPFDocument hWPFDocument) {
        super(hWPFDocument);
        this.doc = hWPFDocument;
    }

    public static String[] getParagraphText(Range range) {
        int numParagraphs = range.numParagraphs();
        String[] strArr = new String[numParagraphs];
        for (int i2 = 0; i2 < numParagraphs; i2++) {
            strArr[i2] = range.getParagraph(i2).text();
            if (strArr[i2].endsWith("\r")) {
                strArr[i2] = a.a(new StringBuilder(), strArr[i2], "\n");
            }
        }
        return strArr;
    }
}
