package org.apache.poi.hwpf.model;

import java.io.ByteArrayOutputStream;
import java.util.ArrayList;
import java.util.Arrays;
import java.util.List;
import org.apache.poi.hwpf.model.types.BKFAbstractType;
import org.apache.poi.ss.formula.function.FunctionMetadataReader;
import org.apache.poi.util.Internal;
import org.apache.poi.util.POILogFactory;
import org.apache.poi.util.POILogger;

@Internal
public class BookmarksTables {
    public static final POILogger logger = POILogFactory.getLogger(BookmarksTables.class);
    public PlexOfCps descriptorsFirst = new PlexOfCps(4);
    public PlexOfCps descriptorsLim = new PlexOfCps(0);
    public List<String> names = new ArrayList(0);

    public BookmarksTables(byte[] bArr, FileInformationBlock fileInformationBlock) {
        read(bArr, fileInformationBlock);
    }

    private void read(byte[] bArr, FileInformationBlock fileInformationBlock) {
        int fcSttbfbkmk = fileInformationBlock.getFcSttbfbkmk();
        int lcbSttbfbkmk = fileInformationBlock.getLcbSttbfbkmk();
        if (!(fcSttbfbkmk == 0 || lcbSttbfbkmk == 0)) {
            this.names = new ArrayList(Arrays.asList(SttbUtils.readSttbfBkmk(bArr, fcSttbfbkmk)));
        }
        int fcPlcfbkf = fileInformationBlock.getFcPlcfbkf();
        int lcbPlcfbkf = fileInformationBlock.getLcbPlcfbkf();
        if (!(fcPlcfbkf == 0 || lcbPlcfbkf == 0)) {
            this.descriptorsFirst = new PlexOfCps(bArr, fcPlcfbkf, lcbPlcfbkf, BKFAbstractType.getSize());
        }
        int fcPlcfbkl = fileInformationBlock.getFcPlcfbkl();
        int lcbPlcfbkl = fileInformationBlock.getLcbPlcfbkl();
        if (fcPlcfbkl != 0 && lcbPlcfbkl != 0) {
            this.descriptorsLim = new PlexOfCps(bArr, fcPlcfbkl, lcbPlcfbkl, 0);
        }
    }

    public void afterDelete(int i2, int i3) {
        int i4 = -i3;
        this.descriptorsFirst.adjust(i2, i4);
        this.descriptorsLim.adjust(i2, i4);
        int i5 = 0;
        while (i5 < this.descriptorsFirst.length()) {
            if (this.descriptorsFirst.getProperty(i5).getStart() == this.descriptorsLim.getProperty(i5).getStart()) {
                logger.log(1, "Removing bookmark #", Integer.valueOf(i5), FunctionMetadataReader.ELLIPSIS);
                remove(i5);
                i5--;
            }
            i5++;
        }
    }

    public void afterInsert(int i2, int i3) {
        this.descriptorsFirst.adjust(i2, i3);
        this.descriptorsLim.adjust(i2 - 1, i3);
    }

    public int getBookmarksCount() {
        return this.descriptorsFirst.length();
    }

    public GenericPropertyNode getDescriptorFirst(int i2) {
        return this.descriptorsFirst.getProperty(i2);
    }

    public int getDescriptorFirstIndex(GenericPropertyNode genericPropertyNode) {
        return Arrays.asList(this.descriptorsFirst.toPropertiesArray()).indexOf(genericPropertyNode);
    }

    public GenericPropertyNode getDescriptorLim(int i2) {
        return this.descriptorsLim.getProperty(i2);
    }

    public int getDescriptorsFirstCount() {
        return this.descriptorsFirst.length();
    }

    public int getDescriptorsLimCount() {
        return this.descriptorsLim.length();
    }

    public String getName(int i2) {
        return this.names.get(i2);
    }

    public int getNamesCount() {
        return this.names.size();
    }

    public void remove(int i2) {
        this.descriptorsFirst.remove(i2);
        this.descriptorsLim.remove(i2);
        this.names.remove(i2);
    }

    public void setName(int i2, String str) {
        this.names.set(i2, str);
    }

    public void writePlcfBkmkf(FileInformationBlock fileInformationBlock, ByteArrayOutputStream byteArrayOutputStream) {
        PlexOfCps plexOfCps = this.descriptorsFirst;
        if (plexOfCps == null || plexOfCps.length() == 0) {
            fileInformationBlock.setFcPlcfbkf(0);
            fileInformationBlock.setLcbPlcfbkf(0);
            return;
        }
        int size = byteArrayOutputStream.size();
        byteArrayOutputStream.write(this.descriptorsFirst.toByteArray());
        int size2 = byteArrayOutputStream.size();
        fileInformationBlock.setFcPlcfbkf(size);
        fileInformationBlock.setLcbPlcfbkf(size2 - size);
    }

    public void writePlcfBkmkl(FileInformationBlock fileInformationBlock, ByteArrayOutputStream byteArrayOutputStream) {
        PlexOfCps plexOfCps = this.descriptorsLim;
        if (plexOfCps == null || plexOfCps.length() == 0) {
            fileInformationBlock.setFcPlcfbkl(0);
            fileInformationBlock.setLcbPlcfbkl(0);
            return;
        }
        int size = byteArrayOutputStream.size();
        byteArrayOutputStream.write(this.descriptorsLim.toByteArray());
        int size2 = byteArrayOutputStream.size();
        fileInformationBlock.setFcPlcfbkl(size);
        fileInformationBlock.setLcbPlcfbkl(size2 - size);
    }

    public void writeSttbfBkmk(FileInformationBlock fileInformationBlock, ByteArrayOutputStream byteArrayOutputStream) {
        List<String> list = this.names;
        if (list == null || list.isEmpty()) {
            fileInformationBlock.setFcSttbfbkmk(0);
            fileInformationBlock.setLcbSttbfbkmk(0);
            return;
        }
        int size = byteArrayOutputStream.size();
        List<String> list2 = this.names;
        SttbUtils.writeSttbfBkmk((String[]) list2.toArray(new String[list2.size()]), byteArrayOutputStream);
        int size2 = byteArrayOutputStream.size();
        fileInformationBlock.setFcSttbfbkmk(size);
        fileInformationBlock.setLcbSttbfbkmk(size2 - size);
    }
}
