package org.apache.poi.hwpf.model;

import java.util.ArrayList;
import java.util.Collections;
import java.util.List;
import org.apache.poi.hwpf.sprm.SprmBuffer;
import org.apache.poi.util.Internal;
import org.apache.poi.util.LittleEndian;
import org.apache.poi.util.RecordFormatException;

@Internal
public final class CHPFormattedDiskPage extends FormattedDiskPage {
    public static final int FC_SIZE = 4;
    public ArrayList<CHPX> _chpxList;
    public ArrayList<CHPX> _overFlow;

    public CHPFormattedDiskPage() {
        this._chpxList = new ArrayList<>();
    }

    public void fill(List<CHPX> list) {
        this._chpxList.addAll(list);
    }

    public CHPX getCHPX(int i2) {
        return this._chpxList.get(i2);
    }

    public List<CHPX> getCHPXs() {
        return Collections.unmodifiableList(this._chpxList);
    }

    @Override // org.apache.poi.hwpf.model.FormattedDiskPage
    public byte[] getGrpprl(int i2) {
        int uByte = LittleEndian.getUByte(this._fkp, ((this._crun + 1) * 4) + i2 + this._offset) * 2;
        if (uByte == 0) {
            return new byte[0];
        }
        int uByte2 = LittleEndian.getUByte(this._fkp, this._offset + uByte);
        byte[] bArr = new byte[uByte2];
        System.arraycopy(this._fkp, uByte + 1 + this._offset, bArr, 0, uByte2);
        return bArr;
    }

    public ArrayList<CHPX> getOverflow() {
        return this._overFlow;
    }

    @Deprecated
    public byte[] toByteArray(CharIndexTranslator charIndexTranslator, int i2) {
        return toByteArray(charIndexTranslator);
    }

    public byte[] toByteArray(CharIndexTranslator charIndexTranslator) {
        int i2;
        byte[] bArr = new byte[512];
        int size = this._chpxList.size();
        int i3 = 6;
        int i4 = 0;
        while (true) {
            i2 = 511;
            if (i4 >= size) {
                break;
            }
            int length = this._chpxList.get(i4).getGrpprl().length;
            int i5 = length + 6 + i3;
            if (i5 > (i4 % 2) + 511) {
                break;
            }
            if ((length + 1) % 2 > 0) {
                i5++;
            }
            i3 = i5;
            i4++;
        }
        if (i4 != 0) {
            if (i4 != size) {
                ArrayList<CHPX> arrayList = new ArrayList<>();
                this._overFlow = arrayList;
                arrayList.addAll(this._chpxList.subList(i4, size));
            }
            bArr[511] = (byte) i4;
            int i6 = (i4 * 4) + 4;
            int i7 = 0;
            int i8 = 0;
            for (CHPX chpx : this._chpxList.subList(0, i4)) {
                int byteIndex = charIndexTranslator.getByteIndex(chpx.getStart());
                int byteIndex2 = charIndexTranslator.getByteIndex(chpx.getEnd());
                LittleEndian.putInt(bArr, i7, byteIndex);
                byte[] grpprl = chpx.getGrpprl();
                int length2 = i2 - (grpprl.length + 1);
                i2 = length2 - (length2 % 2);
                bArr[i6] = (byte) (i2 / 2);
                bArr[i2] = (byte) grpprl.length;
                System.arraycopy(grpprl, 0, bArr, i2 + 1, grpprl.length);
                i6++;
                i7 += 4;
                i8 = byteIndex2;
            }
            LittleEndian.putInt(bArr, i7, i8);
            return bArr;
        }
        throw new RecordFormatException("empty grpprl entry.");
    }

    @Deprecated
    public CHPFormattedDiskPage(byte[] bArr, int i2, int i3, TextPieceTable textPieceTable) {
        this(bArr, i2, textPieceTable);
    }

    public CHPFormattedDiskPage(byte[] bArr, int i2, CharIndexTranslator charIndexTranslator) {
        super(bArr, i2);
        this._chpxList = new ArrayList<>();
        for (int i3 = 0; i3 < this._crun; i3++) {
            int[][] charIndexRanges = charIndexTranslator.getCharIndexRanges(getStart(i3), getEnd(i3));
            for (int[] iArr : charIndexRanges) {
                this._chpxList.add(new CHPX(iArr[0], iArr[1], new SprmBuffer(getGrpprl(i3), 0)));
            }
        }
    }
}
