package org.apache.poi.hwpf.model;

import java.io.ByteArrayOutputStream;
import java.io.IOException;
import java.nio.charset.Charset;
import java.util.LinkedList;
import org.apache.poi.hwpf.HWPFDocumentCore;
import org.apache.poi.hwpf.model.io.HWPFFileSystem;
import org.apache.poi.hwpf.sprm.SprmBuffer;
import org.apache.poi.util.Internal;
import org.apache.poi.util.LittleEndian;
import org.apache.poi.util.StringUtil;

@Internal
public class ComplexFileTable {
    public static final byte GRPPRL_TYPE = 1;
    public static final byte TEXT_PIECE_TABLE_TYPE = 2;
    public SprmBuffer[] _grpprls;
    public TextPieceTable _tpt;

    public ComplexFileTable() {
        this._tpt = new TextPieceTable();
    }

    public SprmBuffer[] getGrpprls() {
        return this._grpprls;
    }

    public TextPieceTable getTextPieceTable() {
        return this._tpt;
    }

    public TextPieceTable newTextPieceTable(byte[] bArr, byte[] bArr2, int i2, int i3, int i4, Charset charset) {
        return new TextPieceTable(bArr, bArr2, i2, i3, i4);
    }

    @Deprecated
    public void writeTo(HWPFFileSystem hWPFFileSystem) {
        writeTo(hWPFFileSystem.getStream(HWPFDocumentCore.STREAM_WORD_DOCUMENT), hWPFFileSystem.getStream(HWPFDocumentCore.STREAM_TABLE_1));
    }

    public ComplexFileTable(byte[] bArr, byte[] bArr2, int i2, int i3, Charset charset) {
        LinkedList linkedList = new LinkedList();
        while (bArr2[i2] == 1) {
            int i4 = i2 + 1;
            short s = LittleEndian.getShort(bArr2, i4);
            int i5 = i4 + 2;
            byte[] byteArray = LittleEndian.getByteArray(bArr2, i5, s);
            i2 = i5 + s;
            linkedList.add(new SprmBuffer(byteArray, false, 0));
        }
        this._grpprls = (SprmBuffer[]) linkedList.toArray(new SprmBuffer[linkedList.size()]);
        if (bArr2[i2] == 2) {
            int i6 = i2 + 1;
            this._tpt = newTextPieceTable(bArr, bArr2, i6 + 4, LittleEndian.getInt(bArr2, i6), i3, charset);
            return;
        }
        throw new IOException("The text piece table is corrupted");
    }

    public void writeTo(ByteArrayOutputStream byteArrayOutputStream, ByteArrayOutputStream byteArrayOutputStream2) {
        byteArrayOutputStream2.write(2);
        byte[] writeTo = this._tpt.writeTo(byteArrayOutputStream);
        byte[] bArr = new byte[4];
        LittleEndian.putInt(bArr, 0, writeTo.length);
        byteArrayOutputStream2.write(bArr);
        byteArrayOutputStream2.write(writeTo);
    }

    public ComplexFileTable(byte[] bArr, byte[] bArr2, int i2, int i3) {
        this(bArr, bArr2, i2, i3, StringUtil.WIN_1252);
    }
}
