package org.apache.poi.hwpf.model;

import org.apache.poi.hwpf.model.types.FFDataBaseAbstractType;
import org.apache.poi.util.Internal;
import org.apache.poi.util.LittleEndian;

@Internal
public class FFData {
    public FFDataBase _base;
    public Sttb _hsttbDropList;
    public Integer _wDef;
    public Xstz _xstzEntryMcr;
    public Xstz _xstzExitMcr;
    public Xstz _xstzHelpText;
    public Xstz _xstzName;
    public Xstz _xstzStatText;
    public Xstz _xstzTextDef;
    public Xstz _xstzTextFormat;

    public FFData(byte[] bArr, int i2) {
        fillFields(bArr, i2);
    }

    public void fillFields(byte[] bArr, int i2) {
        this._base = new FFDataBase(bArr, i2);
        int size = FFDataBaseAbstractType.getSize() + i2;
        Xstz xstz = new Xstz(bArr, size);
        this._xstzName = xstz;
        int size2 = xstz.getSize() + size;
        if (this._base.getIType() == 0) {
            Xstz xstz2 = new Xstz(bArr, size2);
            this._xstzTextDef = xstz2;
            size2 += xstz2.getSize();
        } else {
            this._xstzTextDef = null;
        }
        if (this._base.getIType() == 1 || this._base.getIType() == 2) {
            this._wDef = Integer.valueOf(LittleEndian.getUShort(bArr, size2));
            size2 += 2;
        } else {
            this._wDef = null;
        }
        Xstz xstz3 = new Xstz(bArr, size2);
        this._xstzTextFormat = xstz3;
        int size3 = xstz3.getSize() + size2;
        Xstz xstz4 = new Xstz(bArr, size3);
        this._xstzHelpText = xstz4;
        int size4 = xstz4.getSize() + size3;
        Xstz xstz5 = new Xstz(bArr, size4);
        this._xstzStatText = xstz5;
        int size5 = xstz5.getSize() + size4;
        Xstz xstz6 = new Xstz(bArr, size5);
        this._xstzEntryMcr = xstz6;
        int size6 = xstz6.getSize() + size5;
        Xstz xstz7 = new Xstz(bArr, size6);
        this._xstzExitMcr = xstz7;
        int size7 = xstz7.getSize() + size6;
        if (this._base.getIType() == 2) {
            Sttb sttb = new Sttb(bArr, size7);
            this._hsttbDropList = sttb;
            sttb.getSize();
        }
    }

    public int getDefaultDropDownItemIndex() {
        return this._wDef.intValue();
    }

    public String[] getDropList() {
        return this._hsttbDropList.getData();
    }

    public int getSize() {
        int size = this._xstzName.getSize() + FFDataBaseAbstractType.getSize();
        if (this._base.getIType() == 0) {
            size += this._xstzTextDef.getSize();
        }
        if (this._base.getIType() == 1 || this._base.getIType() == 2) {
            size += 2;
        }
        int size2 = this._xstzExitMcr.getSize() + this._xstzEntryMcr.getSize() + this._xstzStatText.getSize() + this._xstzHelpText.getSize() + this._xstzTextFormat.getSize() + size;
        return this._base.getIType() == 2 ? size2 + this._hsttbDropList.getSize() : size2;
    }

    public String getTextDef() {
        return this._xstzTextDef.getAsJavaString();
    }

    public byte[] serialize() {
        byte[] bArr = new byte[getSize()];
        this._base.serialize(bArr, 0);
        int size = FFDataBaseAbstractType.getSize() + 0;
        int serialize = this._xstzName.serialize(bArr, size) + size;
        if (this._base.getIType() == 0) {
            serialize += this._xstzTextDef.serialize(bArr, serialize);
        }
        if (this._base.getIType() == 1 || this._base.getIType() == 2) {
            LittleEndian.putUShort(bArr, serialize, this._wDef.intValue());
            serialize += 2;
        }
        int serialize2 = this._xstzTextFormat.serialize(bArr, serialize) + serialize;
        int serialize3 = this._xstzHelpText.serialize(bArr, serialize2) + serialize2;
        int serialize4 = this._xstzStatText.serialize(bArr, serialize3) + serialize3;
        int serialize5 = this._xstzEntryMcr.serialize(bArr, serialize4) + serialize4;
        int serialize6 = this._xstzExitMcr.serialize(bArr, serialize5) + serialize5;
        if (this._base.getIType() == 2) {
            this._hsttbDropList.serialize(bArr, serialize6);
        }
        return bArr;
    }
}
