package org.apache.poi.hwpf.model;

import b.b.a.a.a;
import java.util.ArrayList;
import java.util.LinkedHashMap;
import java.util.List;
import java.util.Map;
import org.apache.poi.hwpf.model.types.FSPAAbstractType;
import org.apache.poi.util.Internal;
import org.apache.xmlbeans.impl.jam.internal.JamPrinter;

@Internal
public final class FSPATable {
    public final Map<Integer, GenericPropertyNode> _byStart = new LinkedHashMap();

    public FSPATable(byte[] bArr, FileInformationBlock fileInformationBlock, FSPADocumentPart fSPADocumentPart) {
        PlexOfCps plexOfCps = new PlexOfCps(bArr, fileInformationBlock.getFSPAPlcfOffset(fSPADocumentPart), fileInformationBlock.getFSPAPlcfLength(fSPADocumentPart), FSPAAbstractType.getSize());
        for (int i2 = 0; i2 < plexOfCps.length(); i2++) {
            GenericPropertyNode property = plexOfCps.getProperty(i2);
            this._byStart.put(Integer.valueOf(property.getStart()), property);
        }
    }

    public FSPA getFspaFromCp(int i2) {
        GenericPropertyNode genericPropertyNode = this._byStart.get(Integer.valueOf(i2));
        if (genericPropertyNode == null) {
            return null;
        }
        return new FSPA(genericPropertyNode.getBytes(), 0);
    }

    public FSPA[] getShapes() {
        ArrayList arrayList = new ArrayList(this._byStart.size());
        for (GenericPropertyNode genericPropertyNode : this._byStart.values()) {
            arrayList.add(new FSPA(genericPropertyNode.getBytes(), 0));
        }
        return (FSPA[]) arrayList.toArray(new FSPA[arrayList.size()]);
    }

    public String toString() {
        StringBuffer a = a.a("[FPSA PLC size=");
        a.append(this._byStart.size());
        a.append("]\n");
        for (Map.Entry<Integer, GenericPropertyNode> entry : this._byStart.entrySet()) {
            Integer key = entry.getKey();
            a.append(JamPrinter.INDENT);
            a.append(key);
            a.append(" => \t");
            try {
                a.append(getFspaFromCp(key.intValue()));
            } catch (Exception e2) {
                a.append(e2.getMessage());
            }
            a.append("\n");
        }
        a.append("[/FSPA PLC]");
        return a.toString();
    }

    @Deprecated
    public FSPATable(byte[] bArr, int i2, int i3, List<TextPiece> list) {
        if (i2 != 0) {
            PlexOfCps plexOfCps = new PlexOfCps(bArr, i2, i3, FSPA.FSPA_SIZE);
            for (int i4 = 0; i4 < plexOfCps.length(); i4++) {
                GenericPropertyNode property = plexOfCps.getProperty(i4);
                this._byStart.put(Integer.valueOf(property.getStart()), property);
            }
        }
    }
}
