package org.apache.poi.hwpf.model;

import java.util.Arrays;
import org.apache.poi.util.BitField;
import org.apache.poi.util.BitFieldFactory;
import org.apache.poi.util.Internal;
import org.apache.poi.util.LittleEndian;

@Internal
public final class Ffn {
    public static final /* synthetic */ boolean $assertionsDisabled = false;
    public static BitField _fTrueType = BitFieldFactory.getInstance(4);
    public static BitField _ff = BitFieldFactory.getInstance(112);
    public static BitField _prq = BitFieldFactory.getInstance(3);
    public int _cbFfnM1;
    public byte _chs;
    public byte[] _fontSig = new byte[24];
    public byte _info;
    public byte _ixchSzAlt;
    public byte[] _panose = new byte[10];
    public short _wWeight;
    public char[] _xszFfn;
    public int _xszFfnLength;

    public Ffn(byte[] bArr, int i2) {
        this._cbFfnM1 = LittleEndian.getUByte(bArr, i2);
        int i3 = i2 + 1;
        this._info = bArr[i3];
        int i4 = i3 + 1;
        this._wWeight = LittleEndian.getShort(bArr, i4);
        int i5 = i4 + 2;
        this._chs = bArr[i5];
        int i6 = i5 + 1;
        this._ixchSzAlt = bArr[i6];
        int i7 = i6 + 1;
        byte[] bArr2 = this._panose;
        System.arraycopy(bArr, i7, bArr2, 0, bArr2.length);
        int length = i7 + this._panose.length;
        byte[] bArr3 = this._fontSig;
        System.arraycopy(bArr, length, bArr3, 0, bArr3.length);
        int length2 = length + this._fontSig.length;
        int size = (getSize() - (length2 - i2)) / 2;
        this._xszFfnLength = size;
        this._xszFfn = new char[size];
        for (int i8 = 0; i8 < this._xszFfnLength; i8++) {
            this._xszFfn[i8] = (char) LittleEndian.getShort(bArr, length2);
            length2 += 2;
        }
    }

    public boolean equals(Object obj) {
        if (!(obj instanceof Ffn)) {
            return false;
        }
        Ffn ffn = (Ffn) obj;
        if (ffn._cbFfnM1 == this._cbFfnM1 && ffn._info == this._info && ffn._wWeight == this._wWeight && ffn._chs == this._chs && ffn._ixchSzAlt == this._ixchSzAlt && Arrays.equals(ffn._panose, this._panose) && Arrays.equals(ffn._fontSig, this._fontSig) && Arrays.equals(ffn._xszFfn, this._xszFfn)) {
            return true;
        }
        return false;
    }

    public String getAltFontName() {
        int i2 = this._ixchSzAlt;
        while (i2 < this._xszFfnLength && this._xszFfn[i2] != 0) {
            i2++;
        }
        return new String(this._xszFfn, (int) this._ixchSzAlt, i2);
    }

    public byte getChs() {
        return this._chs;
    }

    public byte[] getFontSig() {
        return this._fontSig;
    }

    public String getMainFontName() {
        int i2 = 0;
        while (i2 < this._xszFfnLength && this._xszFfn[i2] != 0) {
            i2++;
        }
        return new String(this._xszFfn, 0, i2);
    }

    public byte[] getPanose() {
        return this._panose;
    }

    public int getSize() {
        return this._cbFfnM1 + 1;
    }

    public short getWeight() {
        return this._wWeight;
    }

    public int get_cbFfnM1() {
        return this._cbFfnM1;
    }

    public int hashCode() {
        return 42;
    }

    public void set_cbFfnM1(int i2) {
        this._cbFfnM1 = i2;
    }

    public byte[] toByteArray() {
        byte[] bArr = new byte[getSize()];
        int i2 = 0;
        bArr[0] = (byte) this._cbFfnM1;
        bArr[1] = this._info;
        LittleEndian.putShort(bArr, 2, this._wWeight);
        bArr[4] = this._chs;
        bArr[5] = this._ixchSzAlt;
        byte[] bArr2 = this._panose;
        System.arraycopy(bArr2, 0, bArr, 6, bArr2.length);
        int length = 6 + this._panose.length;
        byte[] bArr3 = this._fontSig;
        System.arraycopy(bArr3, 0, bArr, length, bArr3.length);
        int length2 = length + this._fontSig.length;
        while (true) {
            char[] cArr = this._xszFfn;
            if (i2 >= cArr.length) {
                return bArr;
            }
            LittleEndian.putShort(bArr, length2, (short) cArr[i2]);
            length2 += 2;
            i2++;
        }
    }
}
