package org.apache.poi.hwpf.model;

import java.io.ByteArrayOutputStream;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.Map;
import org.apache.poi.util.Internal;

@Internal
public class FieldsTables {
    public static final int FLD_SIZE = 2;
    @Deprecated
    public static final int PLCFFLDATN = 0;
    @Deprecated
    public static final int PLCFFLDEDN = 1;
    @Deprecated
    public static final int PLCFFLDFTN = 2;
    @Deprecated
    public static final int PLCFFLDHDR = 3;
    @Deprecated
    public static final int PLCFFLDHDRTXBX = 4;
    @Deprecated
    public static final int PLCFFLDMOM = 5;
    @Deprecated
    public static final int PLCFFLDTXBX = 6;
    public Map<FieldsDocumentPart, PlexOfCps> _tables = new HashMap(FieldsDocumentPart.values().length);

    public FieldsTables(byte[] bArr, FileInformationBlock fileInformationBlock) {
        FieldsDocumentPart[] values = FieldsDocumentPart.values();
        for (FieldsDocumentPart fieldsDocumentPart : values) {
            this._tables.put(fieldsDocumentPart, readPLCF(bArr, fileInformationBlock, fieldsDocumentPart));
        }
    }

    private PlexOfCps readPLCF(byte[] bArr, FileInformationBlock fileInformationBlock, FieldsDocumentPart fieldsDocumentPart) {
        int fieldsPlcfOffset = fileInformationBlock.getFieldsPlcfOffset(fieldsDocumentPart);
        int fieldsPlcfLength = fileInformationBlock.getFieldsPlcfLength(fieldsDocumentPart);
        if (fieldsPlcfOffset <= 0 || fieldsPlcfLength <= 0) {
            return null;
        }
        return new PlexOfCps(bArr, fieldsPlcfOffset, fieldsPlcfLength, 2);
    }

    private int savePlex(FileInformationBlock fileInformationBlock, FieldsDocumentPart fieldsDocumentPart, PlexOfCps plexOfCps, ByteArrayOutputStream byteArrayOutputStream) {
        if (plexOfCps == null || plexOfCps.length() == 0) {
            fileInformationBlock.setFieldsPlcfOffset(fieldsDocumentPart, byteArrayOutputStream.size());
            fileInformationBlock.setFieldsPlcfLength(fieldsDocumentPart, 0);
            return 0;
        }
        byte[] byteArray = plexOfCps.toByteArray();
        int size = byteArrayOutputStream.size();
        int length = byteArray.length;
        byteArrayOutputStream.write(byteArray);
        fileInformationBlock.setFieldsPlcfOffset(fieldsDocumentPart, size);
        fileInformationBlock.setFieldsPlcfLength(fieldsDocumentPart, length);
        return length;
    }

    public static ArrayList<PlexOfField> toArrayList(PlexOfCps plexOfCps) {
        if (plexOfCps == null) {
            return new ArrayList<>();
        }
        ArrayList<PlexOfField> arrayList = new ArrayList<>(plexOfCps.length());
        for (int i2 = 0; i2 < plexOfCps.length(); i2++) {
            arrayList.add(new PlexOfField(plexOfCps.getProperty(i2)));
        }
        return arrayList;
    }

    public ArrayList<PlexOfField> getFieldsPLCF(FieldsDocumentPart fieldsDocumentPart) {
        return toArrayList(this._tables.get(fieldsDocumentPart));
    }

    public void write(FileInformationBlock fileInformationBlock, ByteArrayOutputStream byteArrayOutputStream) {
        FieldsDocumentPart[] values = FieldsDocumentPart.values();
        for (FieldsDocumentPart fieldsDocumentPart : values) {
            savePlex(fileInformationBlock, fieldsDocumentPart, this._tables.get(fieldsDocumentPart), byteArrayOutputStream);
        }
    }

    @Deprecated
    public ArrayList<PlexOfField> getFieldsPLCF(int i2) {
        return getFieldsPLCF(FieldsDocumentPart.values()[i2]);
    }
}
