package org.apache.poi.hwpf.model;

import b.b.a.a.a;
import java.io.ByteArrayOutputStream;
import java.lang.reflect.Method;
import java.lang.reflect.Modifier;
import java.util.HashSet;
import java.util.Locale;
import org.apache.poi.hssf.usermodel.HSSFShapeTypes;
import org.apache.poi.hwpf.model.types.FibBaseAbstractType;
import org.apache.poi.hwpf.model.types.FibRgLw97AbstractType;
import org.apache.poi.hwpf.model.types.FibRgW97AbstractType;
import org.apache.poi.util.Internal;
import org.apache.poi.util.LittleEndian;
import org.apache.poi.util.POILogFactory;
import org.apache.poi.util.POILogger;

@Internal
public final class FileInformationBlock {
    public static final /* synthetic */ boolean $assertionsDisabled = false;
    public static final POILogger logger = POILogFactory.getLogger(FileInformationBlock.class);
    public int _cbRgFcLcb;
    public int _cslw;
    public int _csw;
    public int _cswNew;
    public FibBase _fibBase;
    public byte[] _fibRgCswNew;
    public FibRgLw _fibRgLw;
    public FibRgW97 _fibRgW;
    public FIBFieldHandler _fieldHandler;
    public int _nFibNew;

    public FileInformationBlock(byte[] bArr) {
        this._fibBase = new FibBase(bArr, 0);
        int size = FibBaseAbstractType.getSize();
        this._csw = LittleEndian.getUShort(bArr, size);
        int i2 = size + 2;
        this._fibRgW = new FibRgW97(bArr, i2);
        int size2 = FibRgW97AbstractType.getSize() + i2;
        this._cslw = LittleEndian.getUShort(bArr, size2);
        int i3 = size2 + 2;
        if (this._fibBase.getNFib() < 105) {
            this._fibRgLw = new FibRgLw95(bArr, i3);
            int size3 = FibRgLw97AbstractType.getSize() + i3;
            this._cbRgFcLcb = 74;
            this._cswNew = LittleEndian.getUShort(bArr, (74 * 4 * 2) + size3);
            this._cswNew = 0;
            this._nFibNew = -1;
            this._fibRgCswNew = new byte[0];
            return;
        }
        this._fibRgLw = new FibRgLw97(bArr, i3);
        int size4 = FibRgLw97AbstractType.getSize() + i3;
        int uShort = LittleEndian.getUShort(bArr, size4);
        this._cbRgFcLcb = uShort;
        int i4 = (uShort * 4 * 2) + size4 + 2;
        int uShort2 = LittleEndian.getUShort(bArr, i4);
        this._cswNew = uShort2;
        int i5 = i4 + 2;
        if (uShort2 != 0) {
            this._nFibNew = LittleEndian.getUShort(bArr, i5);
            int i6 = (this._cswNew - 1) * 2;
            this._fibRgCswNew = new byte[i6];
            LittleEndian.getByteArray(bArr, i5 + 2, i6);
        } else {
            this._nFibNew = -1;
            this._fibRgCswNew = new byte[0];
        }
        assertCbRgFcLcb();
        assertCswNew();
    }

    private void assertCbRgFcLcb() {
        int nFib = getNFib();
        String format = String.format(Locale.ROOT, "%04X", Integer.valueOf(nFib));
        if (nFib == 113) {
            return;
        }
        if (nFib == 257) {
            assertCbRgFcLcb("0x0101", 136, "0x0088", this._cbRgFcLcb);
        } else if (nFib == 274) {
            assertCbRgFcLcb("0x0112", 183, "0x00B7", this._cbRgFcLcb);
        } else if (nFib == 216 || nFib == 217) {
            assertCbRgFcLcb(format, 108, "0x006C", this._cbRgFcLcb);
        } else if (nFib == 267 || nFib == 268) {
            assertCbRgFcLcb(format, 164, "0x00A4", this._cbRgFcLcb);
        } else {
            switch (nFib) {
                case 190:
                case 191:
                case HSSFShapeTypes.ActionButtonInformation:
                case HSSFShapeTypes.ActionButtonForwardNext:
                case HSSFShapeTypes.ActionButtonBackPrevious:
                case HSSFShapeTypes.ActionButtonEnd:
                    assertCbRgFcLcb(format, 93, "0x005D", this._cbRgFcLcb);
                    return;
                default:
                    POILogger pOILogger = logger;
                    pOILogger.log(5, "Invalid file format version number: " + nFib + "(" + format + ")");
                    return;
            }
        }
    }

    private void assertCswNew() {
        int nFib = getNFib();
        if (nFib == 193) {
            assertCswNew("0x00C1", 0, "0x0000", this._cswNew);
        } else if (nFib == 217) {
            assertCswNew("0x00D9", 2, "0x0002", this._cswNew);
        } else if (nFib == 257) {
            assertCswNew("0x0101", 2, "0x0002", this._cswNew);
        } else if (nFib == 268) {
            assertCswNew("0x010C", 2, "0x0002", this._cswNew);
        } else if (nFib != 274) {
            POILogger pOILogger = logger;
            StringBuilder b2 = a.b("Invalid file format version number: ");
            b2.append(getNFib());
            pOILogger.log(5, b2.toString());
        } else {
            assertCswNew("0x0112", 5, "0x0005", this._cswNew);
        }
    }

    public void clearOffsetsSizes() {
        this._fieldHandler.clearFields();
    }

    public void fillVariableFields(byte[] bArr, byte[] bArr2) {
        HashSet hashSet = new HashSet();
        hashSet.add(1);
        hashSet.add(33);
        hashSet.add(31);
        hashSet.add(12);
        hashSet.add(13);
        hashSet.add(6);
        hashSet.add(73);
        hashSet.add(74);
        for (FieldsDocumentPart fieldsDocumentPart : FieldsDocumentPart.values()) {
            hashSet.add(Integer.valueOf(fieldsDocumentPart.getFibFieldsField()));
        }
        hashSet.add(22);
        hashSet.add(23);
        hashSet.add(21);
        NoteType[] values = NoteType.values();
        for (NoteType noteType : values) {
            hashSet.add(Integer.valueOf(noteType.getFibDescriptorsFieldIndex()));
            hashSet.add(Integer.valueOf(noteType.getFibTextPositionsFieldIndex()));
        }
        hashSet.add(15);
        hashSet.add(51);
        hashSet.add(71);
        hashSet.add(87);
        this._fieldHandler = new FIBFieldHandler(bArr, 154, this._cbRgFcLcb, bArr2, hashSet, true);
    }

    public int getCbMac() {
        return this._fibRgLw.getCbMac();
    }

    public int getFSPAPlcfLength(FSPADocumentPart fSPADocumentPart) {
        return this._fieldHandler.getFieldSize(fSPADocumentPart.getFibFieldsField());
    }

    public int getFSPAPlcfOffset(FSPADocumentPart fSPADocumentPart) {
        return this._fieldHandler.getFieldOffset(fSPADocumentPart.getFibFieldsField());
    }

    public int getFcClx() {
        return this._fieldHandler.getFieldOffset(33);
    }

    public int getFcDggInfo() {
        return this._fieldHandler.getFieldOffset(50);
    }

    public int getFcDop() {
        return this._fieldHandler.getFieldOffset(31);
    }

    @Deprecated
    public int getFcPlcfLst() {
        return this._fieldHandler.getFieldOffset(73);
    }

    public int getFcPlcfbkf() {
        return this._fieldHandler.getFieldOffset(22);
    }

    public int getFcPlcfbkl() {
        return this._fieldHandler.getFieldOffset(23);
    }

    public int getFcPlcfbteChpx() {
        return this._fieldHandler.getFieldOffset(12);
    }

    public int getFcPlcfbtePapx() {
        return this._fieldHandler.getFieldOffset(13);
    }

    @Deprecated
    public int getFcPlcffldAtn() {
        return this._fieldHandler.getFieldOffset(19);
    }

    @Deprecated
    public int getFcPlcffldEdn() {
        return this._fieldHandler.getFieldOffset(48);
    }

    @Deprecated
    public int getFcPlcffldFtn() {
        return this._fieldHandler.getFieldOffset(18);
    }

    @Deprecated
    public int getFcPlcffldHdr() {
        return this._fieldHandler.getFieldOffset(17);
    }

    @Deprecated
    public int getFcPlcffldHdrtxbx() {
        return this._fieldHandler.getFieldOffset(59);
    }

    @Deprecated
    public int getFcPlcffldMom() {
        return this._fieldHandler.getFieldOffset(16);
    }

    @Deprecated
    public int getFcPlcffldTxbx() {
        return this._fieldHandler.getFieldOffset(57);
    }

    public int getFcPlcfsed() {
        return this._fieldHandler.getFieldOffset(6);
    }

    @Deprecated
    public int getFcPlcspaMom() {
        return this._fieldHandler.getFieldOffset(40);
    }

    public int getFcPlfLfo() {
        return this._fieldHandler.getFieldOffset(74);
    }

    public int getFcPlfLst() {
        return this._fieldHandler.getFieldOffset(73);
    }

    public int getFcStshf() {
        return this._fieldHandler.getFieldOffset(1);
    }

    public int getFcSttbSavedBy() {
        return this._fieldHandler.getFieldOffset(71);
    }

    public int getFcSttbfRMark() {
        return this._fieldHandler.getFieldOffset(51);
    }

    public int getFcSttbfbkmk() {
        return this._fieldHandler.getFieldOffset(21);
    }

    public int getFcSttbfffn() {
        return this._fieldHandler.getFieldOffset(15);
    }

    public FibBase getFibBase() {
        return this._fibBase;
    }

    public int getFieldsPlcfLength(FieldsDocumentPart fieldsDocumentPart) {
        return this._fieldHandler.getFieldSize(fieldsDocumentPart.getFibFieldsField());
    }

    public int getFieldsPlcfOffset(FieldsDocumentPart fieldsDocumentPart) {
        return this._fieldHandler.getFieldOffset(fieldsDocumentPart.getFibFieldsField());
    }

    public int getLcbClx() {
        return this._fieldHandler.getFieldSize(33);
    }

    public int getLcbDggInfo() {
        return this._fieldHandler.getFieldSize(50);
    }

    public int getLcbDop() {
        return this._fieldHandler.getFieldSize(31);
    }

    @Deprecated
    public int getLcbPlcfLst() {
        return this._fieldHandler.getFieldSize(73);
    }

    public int getLcbPlcfbkf() {
        return this._fieldHandler.getFieldSize(22);
    }

    public int getLcbPlcfbkl() {
        return this._fieldHandler.getFieldSize(23);
    }

    public int getLcbPlcfbteChpx() {
        return this._fieldHandler.getFieldSize(12);
    }

    public int getLcbPlcfbtePapx() {
        return this._fieldHandler.getFieldSize(13);
    }

    @Deprecated
    public int getLcbPlcffldAtn() {
        return this._fieldHandler.getFieldSize(19);
    }

    @Deprecated
    public int getLcbPlcffldEdn() {
        return this._fieldHandler.getFieldSize(48);
    }

    @Deprecated
    public int getLcbPlcffldFtn() {
        return this._fieldHandler.getFieldSize(18);
    }

    @Deprecated
    public int getLcbPlcffldHdr() {
        return this._fieldHandler.getFieldSize(17);
    }

    @Deprecated
    public int getLcbPlcffldHdrtxbx() {
        return this._fieldHandler.getFieldSize(59);
    }

    @Deprecated
    public int getLcbPlcffldMom() {
        return this._fieldHandler.getFieldSize(16);
    }

    @Deprecated
    public int getLcbPlcffldTxbx() {
        return this._fieldHandler.getFieldSize(57);
    }

    public int getLcbPlcfsed() {
        return this._fieldHandler.getFieldSize(6);
    }

    @Deprecated
    public int getLcbPlcspaMom() {
        return this._fieldHandler.getFieldSize(40);
    }

    public int getLcbPlfLfo() {
        return this._fieldHandler.getFieldSize(74);
    }

    public int getLcbPlfLst() {
        return this._fieldHandler.getFieldSize(73);
    }

    public int getLcbStshf() {
        return this._fieldHandler.getFieldSize(1);
    }

    public int getLcbSttbSavedBy() {
        return this._fieldHandler.getFieldSize(71);
    }

    public int getLcbSttbfRMark() {
        return this._fieldHandler.getFieldSize(51);
    }

    public int getLcbSttbfbkmk() {
        return this._fieldHandler.getFieldSize(21);
    }

    public int getLcbSttbfffn() {
        return this._fieldHandler.getFieldSize(15);
    }

    public int getModifiedHigh() {
        return this._fieldHandler.getFieldSize(74);
    }

    public int getModifiedLow() {
        return this._fieldHandler.getFieldOffset(74);
    }

    public int getNFib() {
        if (this._cswNew == 0) {
            return this._fibBase.getNFib();
        }
        return this._nFibNew;
    }

    public int getNotesDescriptorsOffset(NoteType noteType) {
        return this._fieldHandler.getFieldOffset(noteType.getFibDescriptorsFieldIndex());
    }

    public int getNotesDescriptorsSize(NoteType noteType) {
        return this._fieldHandler.getFieldSize(noteType.getFibDescriptorsFieldIndex());
    }

    public int getNotesTextPositionsOffset(NoteType noteType) {
        return this._fieldHandler.getFieldOffset(noteType.getFibTextPositionsFieldIndex());
    }

    public int getNotesTextPositionsSize(NoteType noteType) {
        return this._fieldHandler.getFieldSize(noteType.getFibTextPositionsFieldIndex());
    }

    public int getPlcfHddOffset() {
        return this._fieldHandler.getFieldOffset(11);
    }

    public int getPlcfHddSize() {
        return this._fieldHandler.getFieldSize(11);
    }

    public int getSize() {
        int size = FibRgW97AbstractType.getSize();
        int size2 = FibRgLw97AbstractType.getSize();
        return this._fieldHandler.sizeInBytes() + size2 + size + FibBaseAbstractType.getSize() + 2 + 2 + 2;
    }

    public int getSubdocumentTextStreamLength(SubdocumentType subdocumentType) {
        if (subdocumentType != null) {
            return this._fibRgLw.getSubdocumentTextStreamLength(subdocumentType);
        }
        throw new IllegalArgumentException("argument 'type' is null");
    }

    public void setCbMac(int i2) {
        this._fibRgLw.setCbMac(i2);
    }

    public void setFSPAPlcfLength(FSPADocumentPart fSPADocumentPart, int i2) {
        this._fieldHandler.setFieldSize(fSPADocumentPart.getFibFieldsField(), i2);
    }

    public void setFSPAPlcfOffset(FSPADocumentPart fSPADocumentPart, int i2) {
        this._fieldHandler.setFieldOffset(fSPADocumentPart.getFibFieldsField(), i2);
    }

    public void setFcClx(int i2) {
        this._fieldHandler.setFieldOffset(33, i2);
    }

    public void setFcDop(int i2) {
        this._fieldHandler.setFieldOffset(31, i2);
    }

    @Deprecated
    public void setFcPlcfLst(int i2) {
        this._fieldHandler.setFieldOffset(73, i2);
    }

    public void setFcPlcfbkf(int i2) {
        this._fieldHandler.setFieldOffset(22, i2);
    }

    public void setFcPlcfbkl(int i2) {
        this._fieldHandler.setFieldOffset(23, i2);
    }

    public void setFcPlcfbteChpx(int i2) {
        this._fieldHandler.setFieldOffset(12, i2);
    }

    public void setFcPlcfbtePapx(int i2) {
        this._fieldHandler.setFieldOffset(13, i2);
    }

    @Deprecated
    public void setFcPlcffldAtn(int i2) {
        this._fieldHandler.setFieldOffset(19, i2);
    }

    @Deprecated
    public void setFcPlcffldEdn(int i2) {
        this._fieldHandler.setFieldOffset(48, i2);
    }

    @Deprecated
    public void setFcPlcffldFtn(int i2) {
        this._fieldHandler.setFieldOffset(18, i2);
    }

    @Deprecated
    public void setFcPlcffldHdr(int i2) {
        this._fieldHandler.setFieldOffset(17, i2);
    }

    @Deprecated
    public void setFcPlcffldHdrtxbx(int i2) {
        this._fieldHandler.setFieldOffset(59, i2);
    }

    @Deprecated
    public void setFcPlcffldMom(int i2) {
        this._fieldHandler.setFieldOffset(16, i2);
    }

    @Deprecated
    public void setFcPlcffldTxbx(int i2) {
        this._fieldHandler.setFieldOffset(57, i2);
    }

    public void setFcPlcfsed(int i2) {
        this._fieldHandler.setFieldOffset(6, i2);
    }

    public void setFcPlfLfo(int i2) {
        this._fieldHandler.setFieldOffset(74, i2);
    }

    public void setFcPlfLst(int i2) {
        this._fieldHandler.setFieldOffset(73, i2);
    }

    public void setFcStshf(int i2) {
        this._fieldHandler.setFieldOffset(1, i2);
    }

    public void setFcSttbSavedBy(int i2) {
        this._fieldHandler.setFieldOffset(71, i2);
    }

    public void setFcSttbfRMark(int i2) {
        this._fieldHandler.setFieldOffset(51, i2);
    }

    public void setFcSttbfbkmk(int i2) {
        this._fieldHandler.setFieldOffset(21, i2);
    }

    public void setFcSttbfffn(int i2) {
        this._fieldHandler.setFieldOffset(15, i2);
    }

    public void setFieldsPlcfLength(FieldsDocumentPart fieldsDocumentPart, int i2) {
        this._fieldHandler.setFieldSize(fieldsDocumentPart.getFibFieldsField(), i2);
    }

    public void setFieldsPlcfOffset(FieldsDocumentPart fieldsDocumentPart, int i2) {
        this._fieldHandler.setFieldOffset(fieldsDocumentPart.getFibFieldsField(), i2);
    }

    public void setLcbClx(int i2) {
        this._fieldHandler.setFieldSize(33, i2);
    }

    public void setLcbDop(int i2) {
        this._fieldHandler.setFieldSize(31, i2);
    }

    @Deprecated
    public void setLcbPlcfLst(int i2) {
        this._fieldHandler.setFieldSize(73, i2);
    }

    public void setLcbPlcfbkf(int i2) {
        this._fieldHandler.setFieldSize(22, i2);
    }

    public void setLcbPlcfbkl(int i2) {
        this._fieldHandler.setFieldSize(23, i2);
    }

    public void setLcbPlcfbteChpx(int i2) {
        this._fieldHandler.setFieldSize(12, i2);
    }

    public void setLcbPlcfbtePapx(int i2) {
        this._fieldHandler.setFieldSize(13, i2);
    }

    @Deprecated
    public void setLcbPlcffldAtn(int i2) {
        this._fieldHandler.setFieldSize(19, i2);
    }

    @Deprecated
    public void setLcbPlcffldEdn(int i2) {
        this._fieldHandler.setFieldSize(48, i2);
    }

    @Deprecated
    public void setLcbPlcffldFtn(int i2) {
        this._fieldHandler.setFieldSize(18, i2);
    }

    @Deprecated
    public void setLcbPlcffldHdr(int i2) {
        this._fieldHandler.setFieldSize(17, i2);
    }

    @Deprecated
    public void setLcbPlcffldHdrtxbx(int i2) {
        this._fieldHandler.setFieldSize(59, i2);
    }

    @Deprecated
    public void setLcbPlcffldMom(int i2) {
        this._fieldHandler.setFieldSize(16, i2);
    }

    @Deprecated
    public void setLcbPlcffldTxbx(int i2) {
        this._fieldHandler.setFieldSize(57, i2);
    }

    public void setLcbPlcfsed(int i2) {
        this._fieldHandler.setFieldSize(6, i2);
    }

    public void setLcbPlfLfo(int i2) {
        this._fieldHandler.setFieldSize(74, i2);
    }

    public void setLcbPlfLst(int i2) {
        this._fieldHandler.setFieldSize(73, i2);
    }

    public void setLcbStshf(int i2) {
        this._fieldHandler.setFieldSize(1, i2);
    }

    public void setLcbSttbSavedBy(int i2) {
        this._fieldHandler.setFieldSize(71, i2);
    }

    public void setLcbSttbfRMark(int i2) {
        this._fieldHandler.setFieldSize(51, i2);
    }

    public void setLcbSttbfbkmk(int i2) {
        this._fieldHandler.setFieldSize(21, i2);
    }

    public void setLcbSttbfffn(int i2) {
        this._fieldHandler.setFieldSize(15, i2);
    }

    public void setModifiedHigh(int i2) {
        this._fieldHandler.setFieldSize(74, i2);
    }

    public void setModifiedLow(int i2) {
        this._fieldHandler.setFieldOffset(74, i2);
    }

    public void setNotesDescriptorsOffset(NoteType noteType, int i2) {
        this._fieldHandler.setFieldOffset(noteType.getFibDescriptorsFieldIndex(), i2);
    }

    public void setNotesDescriptorsSize(NoteType noteType, int i2) {
        this._fieldHandler.setFieldSize(noteType.getFibDescriptorsFieldIndex(), i2);
    }

    public void setNotesTextPositionsOffset(NoteType noteType, int i2) {
        this._fieldHandler.setFieldOffset(noteType.getFibTextPositionsFieldIndex(), i2);
    }

    public void setNotesTextPositionsSize(NoteType noteType, int i2) {
        this._fieldHandler.setFieldSize(noteType.getFibTextPositionsFieldIndex(), i2);
    }

    public void setPlcfHddOffset(int i2) {
        this._fieldHandler.setFieldOffset(11, i2);
    }

    public void setPlcfHddSize(int i2) {
        this._fieldHandler.setFieldSize(11, i2);
    }

    public void setSubdocumentTextStreamLength(SubdocumentType subdocumentType, int i2) {
        if (subdocumentType == null) {
            throw new IllegalArgumentException("argument 'type' is null");
        } else if (i2 >= 0) {
            this._fibRgLw.setSubdocumentTextStreamLength(subdocumentType, i2);
        } else {
            throw new IllegalArgumentException("Subdocument length can't be less than 0 (passed value is " + i2 + "). " + "If there is no subdocument " + "length must be set to zero.");
        }
    }

    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append(this._fibBase);
        sb.append("[FIB2]\n");
        sb.append("\tSubdocuments info:\n");
        SubdocumentType[] values = SubdocumentType.values();
        for (SubdocumentType subdocumentType : values) {
            sb.append("\t\t");
            sb.append(subdocumentType);
            sb.append(" has length of ");
            sb.append(getSubdocumentTextStreamLength(subdocumentType));
            sb.append(" char(s)\n");
        }
        sb.append("\tFields PLCF info:\n");
        FieldsDocumentPart[] values2 = FieldsDocumentPart.values();
        for (FieldsDocumentPart fieldsDocumentPart : values2) {
            sb.append("\t\t");
            sb.append(fieldsDocumentPart);
            sb.append(": PLCF starts at ");
            sb.append(getFieldsPlcfOffset(fieldsDocumentPart));
            sb.append(" and have length of ");
            sb.append(getFieldsPlcfLength(fieldsDocumentPart));
            sb.append("\n");
        }
        sb.append("\tNotes PLCF info:\n");
        NoteType[] values3 = NoteType.values();
        for (NoteType noteType : values3) {
            sb.append("\t\t");
            sb.append(noteType);
            sb.append(": descriptions starts ");
            sb.append(getNotesDescriptorsOffset(noteType));
            sb.append(" and have length of ");
            sb.append(getNotesDescriptorsSize(noteType));
            sb.append(" bytes\n");
            sb.append("\t\t");
            sb.append(noteType);
            sb.append(": text positions starts ");
            sb.append(getNotesTextPositionsOffset(noteType));
            sb.append(" and have length of ");
            sb.append(getNotesTextPositionsSize(noteType));
            sb.append(" bytes\n");
        }
        sb.append(this._fieldHandler);
        try {
            sb.append("\tJava reflection info:\n");
            Method[] methods = FileInformationBlock.class.getMethods();
            for (Method method : methods) {
                if (method.getName().startsWith("get") && Modifier.isPublic(method.getModifiers()) && !Modifier.isStatic(method.getModifiers())) {
                    if (method.getParameterTypes().length <= 0) {
                        sb.append("\t\t");
                        sb.append(method.getName());
                        sb.append(" => ");
                        sb.append(method.invoke(this, new Object[0]));
                        sb.append("\n");
                    }
                }
            }
        } catch (Exception e2) {
            sb.append("(exc: ");
            sb.append(e2.getMessage());
            sb.append(")");
        }
        sb.append("[/FIB2]\n");
        return sb.toString();
    }

    public void writeTo(byte[] bArr, ByteArrayOutputStream byteArrayOutputStream) {
        this._cbRgFcLcb = this._fieldHandler.getFieldsCount();
        this._fibBase.serialize(bArr, 0);
        int size = FibBaseAbstractType.getSize();
        LittleEndian.putUShort(bArr, size, this._csw);
        int i2 = size + 2;
        this._fibRgW.serialize(bArr, i2);
        int size2 = FibRgW97AbstractType.getSize() + i2;
        LittleEndian.putUShort(bArr, size2, this._cslw);
        int i3 = size2 + 2;
        ((FibRgLw97) this._fibRgLw).serialize(bArr, i3);
        int size3 = FibRgLw97AbstractType.getSize() + i3;
        LittleEndian.putUShort(bArr, size3, this._cbRgFcLcb);
        int i4 = size3 + 2;
        this._fieldHandler.writeTo(bArr, i4, byteArrayOutputStream);
        int i5 = (this._cbRgFcLcb * 4 * 2) + i4;
        LittleEndian.putUShort(bArr, i5, this._cswNew);
        int i6 = i5 + 2;
        if (this._cswNew != 0) {
            LittleEndian.putUShort(bArr, i6, this._nFibNew);
            byte[] bArr2 = this._fibRgCswNew;
            System.arraycopy(bArr2, 0, bArr, i6 + 2, bArr2.length);
            int length = this._fibRgCswNew.length;
        }
    }

    public static void assertCswNew(String str, int i2, String str2, int i3) {
        if (i3 != i2) {
            logger.log(5, "Since FIB.nFib == ", str, " value of FIB.cswNew MUST be ", a.b(str2, ", not 0x"), Integer.toHexString(i3));
        }
    }

    public static void assertCbRgFcLcb(String str, int i2, String str2, int i3) {
        if (i3 != i2) {
            logger.log(5, "Since FIB.nFib == ", str, " value of FIB.cbRgFcLcb MUST be ", a.b(str2, ", not 0x"), Integer.toHexString(i3));
        }
    }
}
