package org.apache.poi.hwpf.model;

import java.io.ByteArrayOutputStream;
import org.apache.poi.hwpf.HWPFDocumentCore;
import org.apache.poi.hwpf.model.io.HWPFFileSystem;
import org.apache.poi.util.Internal;
import org.apache.poi.util.LittleEndian;
import org.apache.poi.util.POILogFactory;
import org.apache.poi.util.POILogger;

@Internal
public final class FontTable {
    public static final /* synthetic */ boolean $assertionsDisabled = false;
    public static final POILogger _logger = POILogFactory.getLogger(FontTable.class);
    public short _extraDataSz;
    public Ffn[] _fontNames = null;
    public short _stringCount;
    public int fcSttbfffn;
    public int lcbSttbfffn;

    public FontTable(byte[] bArr, int i2, int i3) {
        this.lcbSttbfffn = i3;
        this.fcSttbfffn = i2;
        this._stringCount = LittleEndian.getShort(bArr, i2);
        int i4 = i2 + 2;
        this._extraDataSz = LittleEndian.getShort(bArr, i4);
        int i5 = i4 + 2;
        this._fontNames = new Ffn[this._stringCount];
        for (int i6 = 0; i6 < this._stringCount; i6++) {
            this._fontNames[i6] = new Ffn(bArr, i5);
            i5 += this._fontNames[i6].getSize();
        }
    }

    public boolean equals(Object obj) {
        if (!(obj instanceof FontTable)) {
            return false;
        }
        FontTable fontTable = (FontTable) obj;
        if (fontTable._stringCount != this._stringCount || fontTable._extraDataSz != this._extraDataSz || fontTable._fontNames.length != this._fontNames.length) {
            return false;
        }
        int i2 = 0;
        while (true) {
            Ffn[] ffnArr = fontTable._fontNames;
            if (i2 >= ffnArr.length) {
                return true;
            }
            if (!ffnArr[i2].equals(this._fontNames[i2])) {
                return false;
            }
            i2++;
        }
    }

    public String getAltFont(int i2) {
        if (i2 < this._stringCount) {
            return this._fontNames[i2].getAltFontName();
        }
        _logger.log(3, "Mismatch in chpFtc with stringCount");
        return null;
    }

    public short getExtraDataSz() {
        return this._extraDataSz;
    }

    public Ffn[] getFontNames() {
        return this._fontNames;
    }

    public String getMainFont(int i2) {
        if (i2 < this._stringCount) {
            return this._fontNames[i2].getMainFontName();
        }
        _logger.log(3, "Mismatch in chpFtc with stringCount");
        return null;
    }

    public int getSize() {
        return this.lcbSttbfffn;
    }

    public short getStringCount() {
        return this._stringCount;
    }

    public int hashCode() {
        return 42;
    }

    public void setStringCount(short s) {
        this._stringCount = s;
    }

    @Deprecated
    public void writeTo(HWPFFileSystem hWPFFileSystem) {
        writeTo(hWPFFileSystem.getStream(HWPFDocumentCore.STREAM_TABLE_1));
    }

    public void writeTo(ByteArrayOutputStream byteArrayOutputStream) {
        byte[] bArr = new byte[2];
        int i2 = 0;
        LittleEndian.putShort(bArr, 0, this._stringCount);
        byteArrayOutputStream.write(bArr);
        LittleEndian.putShort(bArr, 0, this._extraDataSz);
        byteArrayOutputStream.write(bArr);
        while (true) {
            Ffn[] ffnArr = this._fontNames;
            if (i2 < ffnArr.length) {
                byteArrayOutputStream.write(ffnArr[i2].toByteArray());
                i2++;
            } else {
                return;
            }
        }
    }
}
