package org.apache.poi.hwpf.model;

import org.apache.poi.hwpf.model.types.HRESIAbstractType;
import org.apache.poi.ss.formula.ptg.NumberPtg;
import org.apache.poi.util.Internal;
import org.apache.poi.util.LittleEndian;

@Internal
public final class Hyphenation extends HRESIAbstractType implements Cloneable {
    public Hyphenation() {
    }

    public boolean equals(Object obj) {
        if (this == obj) {
            return true;
        }
        if (obj == null || Hyphenation.class != obj.getClass()) {
            return false;
        }
        Hyphenation hyphenation = (Hyphenation) obj;
        return this.field_1_hres == hyphenation.field_1_hres && this.field_2_chHres == hyphenation.field_2_chHres;
    }

    public short getValue() {
        byte[] bArr = new byte[2];
        serialize(bArr, 0);
        return LittleEndian.getShort(bArr);
    }

    public int hashCode() {
        return ((this.field_1_hres + NumberPtg.sid) * 31) + this.field_2_chHres;
    }

    public boolean isEmpty() {
        return this.field_1_hres == 0 && this.field_2_chHres == 0;
    }

    @Override // org.apache.poi.hwpf.model.types.HRESIAbstractType
    public String toString() {
        if (isEmpty()) {
            return "[HRESI] EMPTY";
        }
        return super.toString();
    }

    public Hyphenation(short s) {
        byte[] bArr = new byte[2];
        LittleEndian.putShort(bArr, 0, s);
        fillFields(bArr, 0);
    }

    @Override // java.lang.Object
    public Hyphenation clone() {
        try {
            return (Hyphenation) super.clone();
        } catch (CloneNotSupportedException e2) {
            throw new RuntimeException(e2);
        }
    }
}
