package org.apache.poi.hwpf.model;

import org.apache.poi.hwpf.model.types.LFOLVLBaseAbstractType;
import org.apache.poi.util.Internal;

@Internal
public final class ListFormatOverrideLevel {
    public LFOLVLBase _base;
    public ListLevel _lvl;

    public ListFormatOverrideLevel(byte[] bArr, int i2) {
        this._base = new LFOLVLBase(bArr, i2);
        int size = LFOLVLBaseAbstractType.getSize() + i2;
        if (this._base.isFFormatting()) {
            this._lvl = new ListLevel(bArr, size);
        }
    }

    public boolean equals(Object obj) {
        boolean z;
        if (!(obj instanceof ListFormatOverrideLevel)) {
            return false;
        }
        ListFormatOverrideLevel listFormatOverrideLevel = (ListFormatOverrideLevel) obj;
        ListLevel listLevel = this._lvl;
        if (listLevel != null) {
            z = listLevel.equals(listFormatOverrideLevel._lvl);
        } else {
            z = listFormatOverrideLevel._lvl == null;
        }
        if (!z || !listFormatOverrideLevel._base.equals(this._base)) {
            return false;
        }
        return true;
    }

    public int getIStartAt() {
        return this._base.getIStartAt();
    }

    public ListLevel getLevel() {
        return this._lvl;
    }

    public int getLevelNum() {
        return this._base.getILvl();
    }

    public int getSizeInBytes() {
        return this._lvl == null ? LFOLVLBaseAbstractType.getSize() : LFOLVLBaseAbstractType.getSize() + this._lvl.getSizeInBytes();
    }

    public int hashCode() {
        int hashCode = (this._base.hashCode() + 31) * 31;
        ListLevel listLevel = this._lvl;
        return hashCode + (listLevel != null ? listLevel.hashCode() : 0);
    }

    public boolean isFormatting() {
        return this._base.isFFormatting();
    }

    public boolean isStartAt() {
        return this._base.isFStartAt();
    }

    public byte[] toByteArray() {
        byte[] bArr = new byte[getSizeInBytes()];
        this._base.serialize(bArr, 0);
        int size = LFOLVLBaseAbstractType.getSize() + 0;
        ListLevel listLevel = this._lvl;
        if (listLevel != null) {
            byte[] byteArray = listLevel.toByteArray();
            System.arraycopy(byteArray, 0, bArr, size, byteArray.length);
        }
        return bArr;
    }
}
