package org.apache.poi.hwpf.model;

import b.b.a.a.a;
import java.util.Arrays;
import org.apache.poi.hwpf.model.types.LVLFAbstractType;
import org.apache.poi.util.Internal;
import org.apache.poi.util.POILogFactory;
import org.apache.poi.util.POILogger;

@Internal
public final class ListLevel {
    public static final /* synthetic */ boolean $assertionsDisabled = false;
    public static final POILogger logger = POILogFactory.getLogger(ListLevel.class);
    public byte[] _grpprlChpx;
    public byte[] _grpprlPapx;
    public LVLF _lvlf;
    public Xst _xst;

    public ListLevel() {
        this._xst = new Xst();
    }

    public boolean equals(Object obj) {
        if (!(obj instanceof ListLevel)) {
            return false;
        }
        ListLevel listLevel = (ListLevel) obj;
        if (!listLevel._lvlf.equals(this._lvlf) || !Arrays.equals(listLevel._grpprlChpx, this._grpprlChpx) || !Arrays.equals(listLevel._grpprlPapx, this._grpprlPapx) || !listLevel._xst.equals(this._xst)) {
            return false;
        }
        return true;
    }

    public int getAlignment() {
        return this._lvlf.getJc();
    }

    public byte[] getGrpprlChpx() {
        return this._grpprlChpx;
    }

    public byte[] getGrpprlPapx() {
        return this._grpprlPapx;
    }

    public byte[] getLevelNumberingPlaceholderOffsets() {
        return this._lvlf.getRgbxchNums();
    }

    public byte[] getLevelProperties() {
        return this._grpprlPapx;
    }

    public int getNumberFormat() {
        return this._lvlf.getNfc();
    }

    public String getNumberText() {
        return this._xst.getAsJavaString();
    }

    public short getRestart() {
        if (this._lvlf.isFNoRestart()) {
            return this._lvlf.getIlvlRestartLim();
        }
        return -1;
    }

    public int getSizeInBytes() {
        return this._xst.getSize() + this._lvlf.getCbGrpprlPapx() + this._lvlf.getCbGrpprlChpx() + LVLFAbstractType.getSize();
    }

    public int getStartAt() {
        return this._lvlf.getIStartAt();
    }

    public byte getTypeOfCharFollowingTheNumber() {
        return this._lvlf.getIxchFollow();
    }

    public int hashCode() {
        return 42;
    }

    public boolean isLegalNumbering() {
        return this._lvlf.isFLegal();
    }

    public int read(byte[] bArr, int i2) {
        this._lvlf = new LVLF(bArr, i2);
        int size = LVLFAbstractType.getSize() + i2;
        byte[] bArr2 = new byte[this._lvlf.getCbGrpprlPapx()];
        this._grpprlPapx = bArr2;
        System.arraycopy(bArr, size, bArr2, 0, this._lvlf.getCbGrpprlPapx());
        int cbGrpprlPapx = this._lvlf.getCbGrpprlPapx() + size;
        byte[] bArr3 = new byte[this._lvlf.getCbGrpprlChpx()];
        this._grpprlChpx = bArr3;
        System.arraycopy(bArr, cbGrpprlPapx, bArr3, 0, this._lvlf.getCbGrpprlChpx());
        int cbGrpprlChpx = this._lvlf.getCbGrpprlChpx() + cbGrpprlPapx;
        Xst xst = new Xst(bArr, cbGrpprlChpx);
        this._xst = xst;
        int size2 = xst.getSize() + cbGrpprlChpx;
        if (this._lvlf.getNfc() == 23 && this._xst.getCch() != 1) {
            logger.log(5, "LVL at offset ", Integer.valueOf(i2), " has nfc == 0x17 (bullets), but cch != 1 (", Integer.valueOf(this._xst.getCch()), ")");
        }
        return size2 - i2;
    }

    public void setAlignment(int i2) {
        this._lvlf.setJc((byte) i2);
    }

    public void setLevelProperties(byte[] bArr) {
        this._grpprlPapx = bArr;
    }

    public void setNumberFormat(int i2) {
        this._lvlf.setNfc((byte) i2);
    }

    public void setNumberProperties(byte[] bArr) {
        this._grpprlChpx = bArr;
    }

    public void setStartAt(int i2) {
        this._lvlf.setIStartAt(i2);
    }

    public void setTypeOfCharFollowingTheNumber(byte b2) {
        this._lvlf.setIxchFollow(b2);
    }

    public byte[] toByteArray() {
        byte[] bArr = new byte[getSizeInBytes()];
        this._lvlf.setCbGrpprlChpx((short) this._grpprlChpx.length);
        this._lvlf.setCbGrpprlPapx((short) this._grpprlPapx.length);
        this._lvlf.serialize(bArr, 0);
        int size = LVLFAbstractType.getSize() + 0;
        byte[] bArr2 = this._grpprlPapx;
        System.arraycopy(bArr2, 0, bArr, size, bArr2.length);
        int length = size + this._grpprlPapx.length;
        byte[] bArr3 = this._grpprlChpx;
        System.arraycopy(bArr3, 0, bArr, length, bArr3.length);
        this._xst.serialize(bArr, length + this._grpprlChpx.length);
        this._xst.getSize();
        return bArr;
    }

    public String toString() {
        StringBuilder b2 = a.b("LVL: ");
        StringBuilder b3 = a.b("\n");
        b3.append(this._lvlf);
        b2.append(b3.toString().replaceAll("\n", "\n    "));
        b2.append("\n");
        b2.append("PAPX's grpprl: ");
        b2.append(Arrays.toString(this._grpprlPapx));
        b2.append("\n");
        b2.append("CHPX's grpprl: ");
        b2.append(Arrays.toString(this._grpprlChpx));
        b2.append("\n");
        b2.append("xst: ");
        b2.append(this._xst);
        b2.append("\n");
        return b2.toString();
    }

    @Deprecated
    public ListLevel(byte[] bArr, int i2) {
        this._xst = new Xst();
        read(bArr, i2);
    }

    public ListLevel(int i2, boolean z) {
        this._xst = new Xst();
        this._lvlf = new LVLF();
        setStartAt(1);
        this._grpprlPapx = new byte[0];
        this._grpprlChpx = new byte[0];
        if (z) {
            this._lvlf.getRgbxchNums()[0] = 1;
            StringBuilder b2 = a.b("");
            b2.append((char) i2);
            b2.append(".");
            this._xst = new Xst(b2.toString());
            return;
        }
        this._xst = new Xst("•");
    }

    public ListLevel(int i2, int i3, int i4, byte[] bArr, byte[] bArr2, String str) {
        this._xst = new Xst();
        this._lvlf = new LVLF();
        setStartAt(i2);
        this._lvlf.setNfc((byte) i3);
        this._lvlf.setJc((byte) i4);
        this._grpprlChpx = (byte[]) bArr.clone();
        this._grpprlPapx = (byte[]) bArr2.clone();
        this._xst = new Xst(str);
    }
}
