package org.apache.poi.hwpf.model;

import b.b.a.a.a;
import java.io.ByteArrayOutputStream;
import java.util.LinkedHashMap;
import org.apache.poi.hwpf.model.types.LSTFAbstractType;
import org.apache.poi.util.Internal;
import org.apache.poi.util.LittleEndian;
import org.apache.poi.util.POILogFactory;
import org.apache.poi.util.POILogger;

@Internal
public final class ListTables {
    public static final POILogger log = POILogFactory.getLogger(ListTables.class);
    public final LinkedHashMap<Integer, ListData> _listMap = new LinkedHashMap<>();
    public PlfLfo _plfLfo;

    public ListTables() {
    }

    public int addList(ListData listData, LFO lfo, LFOData lFOData) {
        int lsid = listData.getLsid();
        while (this._listMap.get(Integer.valueOf(lsid)) != null) {
            lsid = listData.resetListID();
            lfo.setLsid(lsid);
        }
        this._listMap.put(Integer.valueOf(lsid), listData);
        if (lfo != null || lFOData == null) {
            if (lfo != null) {
                this._plfLfo.add(lfo, lFOData);
            }
            return lsid;
        }
        throw new IllegalArgumentException("LFO and LFOData should be specified both or noone");
    }

    public boolean equals(Object obj) {
        if (this == obj) {
            return true;
        }
        if (obj == null || ListTables.class != obj.getClass()) {
            return false;
        }
        ListTables listTables = (ListTables) obj;
        LinkedHashMap<Integer, ListData> linkedHashMap = this._listMap;
        if (linkedHashMap == null) {
            if (listTables._listMap != null) {
                return false;
            }
        } else if (!linkedHashMap.equals(listTables._listMap)) {
            return false;
        }
        PlfLfo plfLfo = this._plfLfo;
        if (plfLfo == null) {
            if (listTables._plfLfo != null) {
                return false;
            }
        } else if (!plfLfo.equals(listTables._plfLfo)) {
            return false;
        }
        return true;
    }

    public ListLevel getLevel(int i2, int i3) {
        ListData listData = this._listMap.get(Integer.valueOf(i2));
        if (listData == null) {
            if (log.check(5)) {
                log.log(5, a.b("ListData for ", i2, " was null."));
            }
            return null;
        } else if (i3 < listData.numLevels()) {
            return listData.getLevels()[i3];
        } else {
            if (log.check(5)) {
                POILogger pOILogger = log;
                StringBuilder a = a.a("Requested level ", i3, " which was greater than the maximum defined (");
                a.append(listData.numLevels());
                a.append(")");
                pOILogger.log(5, a.toString());
            }
            return null;
        }
    }

    public LFO getLfo(int i2) {
        return this._plfLfo.getLfo(i2);
    }

    public LFOData getLfoData(int i2) {
        return this._plfLfo.getLfoData(i2);
    }

    public ListData getListData(int i2) {
        return this._listMap.get(Integer.valueOf(i2));
    }

    public int getOverrideIndexFromListID(int i2) {
        return this._plfLfo.getIlfoByLsid(i2);
    }

    public int hashCode() {
        LinkedHashMap<Integer, ListData> linkedHashMap = this._listMap;
        int i2 = 0;
        int hashCode = ((linkedHashMap == null ? 0 : linkedHashMap.hashCode()) + 31) * 31;
        PlfLfo plfLfo = this._plfLfo;
        if (plfLfo != null) {
            i2 = plfLfo.hashCode();
        }
        return hashCode + i2;
    }

    public void writeListDataTo(FileInformationBlock fileInformationBlock, ByteArrayOutputStream byteArrayOutputStream) {
        ListLevel[] levels;
        int size = byteArrayOutputStream.size();
        fileInformationBlock.setFcPlfLst(size);
        int size2 = this._listMap.size();
        ByteArrayOutputStream byteArrayOutputStream2 = new ByteArrayOutputStream();
        byte[] bArr = new byte[2];
        LittleEndian.putShort(bArr, 0, (short) size2);
        byteArrayOutputStream.write(bArr);
        for (ListData listData : this._listMap.values()) {
            byteArrayOutputStream.write(listData.toByteArray());
            for (ListLevel listLevel : listData.getLevels()) {
                byteArrayOutputStream2.write(listLevel.toByteArray());
            }
        }
        fileInformationBlock.setLcbPlfLst(byteArrayOutputStream.size() - size);
        byteArrayOutputStream.write(byteArrayOutputStream2.toByteArray());
    }

    public void writeListOverridesTo(FileInformationBlock fileInformationBlock, ByteArrayOutputStream byteArrayOutputStream) {
        this._plfLfo.writeTo(fileInformationBlock, byteArrayOutputStream);
    }

    public ListTables(byte[] bArr, int i2, int i3, int i4) {
        short s = LittleEndian.getShort(bArr, i2);
        int i5 = i2 + 2;
        int size = (LSTFAbstractType.getSize() * s) + i5;
        for (int i6 = 0; i6 < s; i6++) {
            ListData listData = new ListData(bArr, i5);
            this._listMap.put(Integer.valueOf(listData.getLsid()), listData);
            i5 += LSTFAbstractType.getSize();
            int numLevels = listData.numLevels();
            for (int i7 = 0; i7 < numLevels; i7++) {
                ListLevel listLevel = new ListLevel();
                size += listLevel.read(bArr, size);
                listData.setLevel(i7, listLevel);
            }
        }
        this._plfLfo = new PlfLfo(bArr, i3, i4);
    }
}
