package org.apache.poi.hwpf.model;

import java.io.ByteArrayOutputStream;
import java.util.ArrayList;
import java.util.Collections;
import java.util.Comparator;
import java.util.IdentityHashMap;
import java.util.Iterator;
import java.util.LinkedList;
import java.util.List;
import org.apache.poi.hwpf.model.PropertyNode;
import org.apache.poi.hwpf.sprm.SprmBuffer;
import org.apache.poi.hwpf.sprm.SprmIterator;
import org.apache.poi.util.Internal;
import org.apache.poi.util.LittleEndian;
import org.apache.poi.util.POILogFactory;
import org.apache.poi.util.POILogger;

@Internal
public class PAPBinTable {
    public static final /* synthetic */ boolean $assertionsDisabled = false;
    public static final POILogger logger = POILogFactory.getLogger(PAPBinTable.class);
    public final ArrayList<PAPX> _paragraphs = new ArrayList<>();

    public PAPBinTable() {
    }

    public void adjustForDelete(int i2, int i3, int i4) {
        int size = this._paragraphs.size();
        int i5 = i3 + i4;
        PAPX papx = this._paragraphs.get(i2);
        int i6 = i2;
        while (papx.getEnd() < i5) {
            i6++;
            papx = this._paragraphs.get(i6);
        }
        if (i2 == i6) {
            PAPX papx2 = this._paragraphs.get(i6);
            papx2.setEnd((papx2.getEnd() - i5) + i3);
        } else {
            this._paragraphs.get(i2).setEnd(i3);
            while (true) {
                i2++;
                if (i2 >= i6) {
                    break;
                }
                PAPX papx3 = this._paragraphs.get(i2);
                papx3.setStart(i3);
                papx3.setEnd(i3);
            }
            PAPX papx4 = this._paragraphs.get(i6);
            papx4.setEnd((papx4.getEnd() - i5) + i3);
        }
        while (true) {
            i6++;
            if (i6 < size) {
                PAPX papx5 = this._paragraphs.get(i6);
                papx5.setStart(papx5.getStart() - i4);
                papx5.setEnd(papx5.getEnd() - i4);
            } else {
                return;
            }
        }
    }

    public void adjustForInsert(int i2, int i3) {
        int size = this._paragraphs.size();
        PAPX papx = this._paragraphs.get(i2);
        papx.setEnd(papx.getEnd() + i3);
        while (true) {
            i2++;
            if (i2 < size) {
                PAPX papx2 = this._paragraphs.get(i2);
                papx2.setStart(papx2.getStart() + i3);
                papx2.setEnd(papx2.getEnd() + i3);
            } else {
                return;
            }
        }
    }

    public ArrayList<PAPX> getParagraphs() {
        return this._paragraphs;
    }

    public void insert(int i2, int i3, SprmBuffer sprmBuffer) {
        PAPX papx = new PAPX(0, 0, sprmBuffer);
        papx.setStart(i3);
        papx.setEnd(i3);
        if (i2 == this._paragraphs.size()) {
            this._paragraphs.add(papx);
            return;
        }
        PAPX papx2 = this._paragraphs.get(i2);
        if (papx2 == null || papx2.getStart() >= i3) {
            this._paragraphs.add(i2, papx);
            return;
        }
        PAPX papx3 = new PAPX(0, 0, papx2.getSprmBuf().clone());
        papx3.setStart(i3);
        papx3.setEnd(papx2.getEnd());
        papx2.setEnd(i3);
        this._paragraphs.add(i2 + 1, papx);
        this._paragraphs.add(i2 + 2, papx3);
    }

    public void rebuild(StringBuilder sb, ComplexFileTable complexFileTable) {
        rebuild(sb, complexFileTable, this._paragraphs);
    }

    public void writeTo(ByteArrayOutputStream byteArrayOutputStream, ByteArrayOutputStream byteArrayOutputStream2, CharIndexTranslator charIndexTranslator) {
        PlexOfCps plexOfCps = new PlexOfCps(4);
        int size = byteArrayOutputStream.size() % 512;
        if (size != 0) {
            byteArrayOutputStream.write(new byte[(512 - size)]);
        }
        int size2 = byteArrayOutputStream.size() / 512;
        ArrayList<PAPX> arrayList = this._paragraphs;
        int byteIndex = charIndexTranslator.getByteIndex(arrayList.get(arrayList.size() - 1).getEnd());
        ArrayList<PAPX> arrayList2 = this._paragraphs;
        while (true) {
            int byteIndex2 = charIndexTranslator.getByteIndex(arrayList2.get(0).getStart());
            PAPFormattedDiskPage pAPFormattedDiskPage = new PAPFormattedDiskPage();
            pAPFormattedDiskPage.fill(arrayList2);
            byteArrayOutputStream.write(pAPFormattedDiskPage.toByteArray(byteArrayOutputStream2, charIndexTranslator));
            arrayList2 = pAPFormattedDiskPage.getOverflow();
            int byteIndex3 = arrayList2 != null ? charIndexTranslator.getByteIndex(arrayList2.get(0).getStart()) : byteIndex;
            byte[] bArr = new byte[4];
            int i2 = size2 + 1;
            LittleEndian.putInt(bArr, 0, size2);
            plexOfCps.addProperty(new GenericPropertyNode(byteIndex2, byteIndex3, bArr));
            if (arrayList2 == null) {
                byteArrayOutputStream2.write(plexOfCps.toByteArray());
                return;
            }
            size2 = i2;
        }
    }

    public static void rebuild(StringBuilder sb, ComplexFileTable complexFileTable, List<PAPX> list) {
        boolean z;
        boolean z2;
        long currentTimeMillis = System.currentTimeMillis();
        int i2 = 1;
        if (complexFileTable != null) {
            SprmBuffer[] grpprls = complexFileTable.getGrpprls();
            for (TextPiece textPiece : complexFileTable.getTextPieceTable().getTextPieces()) {
                PropertyModifier prm = textPiece.getPieceDescriptor().getPrm();
                if (prm.isComplex()) {
                    short igrpprl = prm.getIgrpprl();
                    if (igrpprl < 0 || igrpprl >= grpprls.length) {
                        POILogger pOILogger = logger;
                        pOILogger.log(5, textPiece + "'s PRM references to unknown grpprl");
                    } else {
                        SprmBuffer sprmBuffer = grpprls[igrpprl];
                        SprmIterator it = sprmBuffer.iterator();
                        while (true) {
                            if (it.hasNext()) {
                                if (it.next().getType() == 1) {
                                    z2 = true;
                                    break;
                                }
                            } else {
                                z2 = false;
                                break;
                            }
                        }
                        if (z2) {
                            SprmBuffer sprmBuffer2 = new SprmBuffer(2);
                            sprmBuffer2.append(sprmBuffer.toByteArray());
                            list.add(new PAPX(textPiece.getStart(), textPiece.getEnd(), sprmBuffer2));
                        }
                    }
                }
            }
            logger.log(1, "Merged (?) with PAPX from complex file table in ", Long.valueOf(System.currentTimeMillis() - currentTimeMillis), " ms (", Integer.valueOf(list.size()), " elements in total)");
            currentTimeMillis = System.currentTimeMillis();
        }
        ArrayList arrayList = new ArrayList(list);
        Collections.sort(arrayList, PropertyNode.EndComparator.instance);
        logger.log(1, "PAPX sorted by end position in ", Long.valueOf(System.currentTimeMillis() - currentTimeMillis), " ms");
        long currentTimeMillis2 = System.currentTimeMillis();
        final IdentityHashMap identityHashMap = new IdentityHashMap();
        int i3 = 0;
        for (PAPX papx : list) {
            identityHashMap.put(papx, Integer.valueOf(i3));
            i3++;
        }
        AnonymousClass1 r13 = new Comparator<PAPX>() {
            /* class org.apache.poi.hwpf.model.PAPBinTable.AnonymousClass1 */

            public int compare(PAPX papx, PAPX papx2) {
                return ((Integer) identityHashMap.get(papx)).compareTo((Integer) identityHashMap.get(papx2));
            }
        };
        logger.log(1, "PAPX's order map created in ", Long.valueOf(System.currentTimeMillis() - currentTimeMillis2), " ms");
        long currentTimeMillis3 = System.currentTimeMillis();
        LinkedList linkedList = new LinkedList();
        int i4 = 0;
        int i5 = 0;
        int i6 = 0;
        while (i4 < sb.length()) {
            char charAt = sb.charAt(i4);
            if (charAt == '\r' || charAt == 7 || charAt == '\f') {
                int i7 = i4 + 1;
                LinkedList linkedList2 = new LinkedList();
                int i8 = i6;
                while (true) {
                    if (i8 >= arrayList.size()) {
                        z = false;
                        break;
                    }
                    PAPX papx2 = (PAPX) arrayList.get(i8);
                    if (papx2.getEnd() - 1 > i4) {
                        i6 = i8;
                        z = true;
                        break;
                    }
                    linkedList2.add(papx2);
                    i8++;
                }
                if (!z) {
                    i6 = arrayList.size() - i2;
                }
                if (linkedList2.size() == 0) {
                    POILogger pOILogger2 = logger;
                    Object[] objArr = new Object[5];
                    objArr[0] = "Paragraph [";
                    objArr[i2] = Integer.valueOf(i5);
                    objArr[2] = "; ";
                    objArr[3] = Integer.valueOf(i7);
                    objArr[4] = ") has no PAPX. Creating new one.";
                    pOILogger2.log(5, objArr);
                    linkedList.add(new PAPX(i5, i7, new SprmBuffer(2)));
                } else {
                    if (linkedList2.size() == 1) {
                        PAPX papx3 = (PAPX) linkedList2.get(0);
                        if (papx3.getStart() == i5 && papx3.getEnd() == i7) {
                            linkedList.add(papx3);
                        }
                    }
                    Collections.sort(linkedList2, r13);
                    SprmBuffer sprmBuffer3 = null;
                    Iterator it2 = linkedList2.iterator();
                    while (it2.hasNext()) {
                        PAPX papx4 = (PAPX) it2.next();
                        if (papx4.getGrpprl() != null && papx4.getGrpprl().length > 2) {
                            if (sprmBuffer3 == null) {
                                sprmBuffer3 = papx4.getSprmBuf().clone();
                            } else {
                                sprmBuffer3.append(papx4.getGrpprl(), 2);
                            }
                        }
                    }
                    linkedList.add(new PAPX(i5, i7, sprmBuffer3));
                }
                i5 = i7;
            }
            i4++;
            i2 = 1;
        }
        list.clear();
        list.addAll(linkedList);
        logger.log(1, "PAPX rebuilded from document text in ", Long.valueOf(System.currentTimeMillis() - currentTimeMillis3), " ms (", Integer.valueOf(list.size()), " elements)");
        System.currentTimeMillis();
    }

    public PAPBinTable(byte[] bArr, byte[] bArr2, byte[] bArr3, int i2, int i3, CharIndexTranslator charIndexTranslator) {
        long currentTimeMillis = System.currentTimeMillis();
        PlexOfCps plexOfCps = new PlexOfCps(bArr2, i2, i3, 4);
        int length = plexOfCps.length();
        for (int i4 = 0; i4 < length; i4++) {
            for (PAPX papx : new PAPFormattedDiskPage(bArr, bArr3, LittleEndian.getInt(plexOfCps.getProperty(i4).getBytes()) * 512, charIndexTranslator).getPAPXs()) {
                if (papx != null) {
                    this._paragraphs.add(papx);
                }
            }
        }
        logger.log(1, "PAPX tables loaded in ", Long.valueOf(System.currentTimeMillis() - currentTimeMillis), " ms (", Integer.valueOf(this._paragraphs.size()), " elements)");
        if (this._paragraphs.isEmpty()) {
            logger.log(5, "PAPX FKPs are empty");
            this._paragraphs.add(new PAPX(0, 0, new SprmBuffer(2)));
        }
    }
}
