package org.apache.poi.hwpf.model;

import java.io.ByteArrayOutputStream;
import java.util.ArrayList;
import java.util.Arrays;
import java.util.Collections;
import java.util.List;
import org.apache.poi.util.Internal;
import org.apache.poi.util.LittleEndian;

@Internal
public final class PAPFormattedDiskPage extends FormattedDiskPage {
    public static final int BX_SIZE = 13;
    public static final int FC_SIZE = 4;
    public ArrayList<PAPX> _overFlow;
    public ArrayList<PAPX> _papxList;

    public PAPFormattedDiskPage(byte[] bArr) {
        this();
    }

    private ParagraphHeight getParagraphHeight(int i2) {
        int i3 = (i2 * 13) + ((this._crun + 1) * 4);
        return new ParagraphHeight(this._fkp, i3 + this._offset + 1);
    }

    public void fill(List<PAPX> list) {
        this._papxList.addAll(list);
    }

    @Override // org.apache.poi.hwpf.model.FormattedDiskPage
    public byte[] getGrpprl(int i2) {
        int i3;
        int uByte = LittleEndian.getUByte(this._fkp, (i2 * 13) + ((this._crun + 1) * 4) + this._offset) * 2;
        int uByte2 = LittleEndian.getUByte(this._fkp, this._offset + uByte) * 2;
        if (uByte2 == 0) {
            uByte++;
            i3 = LittleEndian.getUByte(this._fkp, this._offset + uByte) * 2;
        } else {
            i3 = uByte2 - 1;
        }
        byte[] bArr = new byte[i3];
        System.arraycopy(this._fkp, uByte + 1 + this._offset, bArr, 0, i3);
        return bArr;
    }

    public ArrayList<PAPX> getOverflow() {
        return this._overFlow;
    }

    public PAPX getPAPX(int i2) {
        return this._papxList.get(i2);
    }

    public List<PAPX> getPAPXs() {
        return Collections.unmodifiableList(this._papxList);
    }

    public byte[] toByteArray(ByteArrayOutputStream byteArrayOutputStream, CharIndexTranslator charIndexTranslator) {
        int i2;
        int i3;
        int i4;
        byte[] bArr;
        int i5;
        PAPFormattedDiskPage pAPFormattedDiskPage = this;
        byte[] bArr2 = new byte[512];
        int size = pAPFormattedDiskPage._papxList.size();
        byte[] bArr3 = new byte[0];
        int i6 = 0;
        int i7 = 4;
        while (true) {
            i2 = 488;
            i3 = 511;
            if (i6 >= size) {
                break;
            }
            byte[] grpprl = pAPFormattedDiskPage._papxList.get(i6).getGrpprl();
            int length = grpprl.length;
            if (length > 488) {
                length = 8;
            }
            int i8 = i7 + (!Arrays.equals(grpprl, bArr3) ? length + 17 + 1 : 17);
            if (i8 > (i6 % 2) + 511) {
                break;
            }
            i7 = length % 2 > 0 ? i8 + 1 : i8 + 2;
            i6++;
            bArr3 = grpprl;
        }
        if (i6 != size) {
            ArrayList<PAPX> arrayList = new ArrayList<>();
            pAPFormattedDiskPage._overFlow = arrayList;
            arrayList.addAll(pAPFormattedDiskPage._papxList.subList(i6, size));
        }
        bArr2[511] = (byte) i6;
        int i9 = (i6 * 4) + 4;
        PAPX papx = null;
        byte[] bArr4 = new byte[0];
        int i10 = 0;
        int i11 = 0;
        while (i10 < i6) {
            papx = pAPFormattedDiskPage._papxList.get(i10);
            byte[] byteArray = papx.getParagraphHeight().toByteArray();
            byte[] grpprl2 = papx.getGrpprl();
            if (grpprl2.length > i2) {
                byte[] bArr5 = new byte[(grpprl2.length - 2)];
                System.arraycopy(grpprl2, 2, bArr5, 0, grpprl2.length - 2);
                int size2 = byteArrayOutputStream.size();
                byteArrayOutputStream.write(bArr5);
                bArr = new byte[8];
                LittleEndian.putUShort(bArr, 0, LittleEndian.getUShort(grpprl2, 0));
                i4 = 2;
                LittleEndian.putUShort(bArr, 2, 26182);
                LittleEndian.putInt(bArr, 4, size2);
            } else {
                bArr = grpprl2;
                i4 = 2;
            }
            boolean equals = Arrays.equals(bArr4, bArr);
            if (!equals) {
                int length2 = i3 - ((2 - (bArr.length % i4)) + bArr.length);
                i3 = length2 - (length2 % 2);
            }
            LittleEndian.putInt(bArr2, i11, charIndexTranslator.getByteIndex(papx.getStart()));
            bArr2[i9] = (byte) (i3 / 2);
            System.arraycopy(byteArray, 0, bArr2, i9 + 1, byteArray.length);
            if (!equals) {
                if (bArr.length % 2 > 0) {
                    i5 = i3 + 1;
                    bArr2[i3] = (byte) ((bArr.length + 1) / 2);
                } else {
                    int i12 = i3 + 1;
                    bArr2[i12] = (byte) (bArr.length / 2);
                    i5 = i12 + 1;
                }
                System.arraycopy(bArr, 0, bArr2, i5, bArr.length);
                bArr4 = bArr;
            }
            i9 += 13;
            i11 += 4;
            i10++;
            i2 = 488;
            pAPFormattedDiskPage = this;
        }
        LittleEndian.putInt(bArr2, i11, charIndexTranslator.getByteIndex(papx.getEnd()));
        return bArr2;
    }

    public PAPFormattedDiskPage() {
        this._papxList = new ArrayList<>();
    }

    public PAPFormattedDiskPage(byte[] bArr, byte[] bArr2, int i2, int i3, TextPieceTable textPieceTable) {
        this(bArr, bArr2, i2, textPieceTable);
    }

    public PAPFormattedDiskPage(byte[] bArr, byte[] bArr2, int i2, CharIndexTranslator charIndexTranslator) {
        super(bArr, i2);
        this._papxList = new ArrayList<>();
        for (int i3 = 0; i3 < this._crun; i3++) {
            int[][] charIndexRanges = charIndexTranslator.getCharIndexRanges(getStart(i3), getEnd(i3));
            for (int[] iArr : charIndexRanges) {
                this._papxList.add(new PAPX(iArr[0], iArr[1], getGrpprl(i3), getParagraphHeight(i3), bArr2));
            }
        }
        this._fkp = null;
    }
}
