package org.apache.poi.hwpf.model;

import b.b.a.a.a;
import org.apache.poi.hwpf.sprm.ParagraphSprmUncompressor;
import org.apache.poi.hwpf.sprm.SprmBuffer;
import org.apache.poi.hwpf.sprm.SprmOperation;
import org.apache.poi.hwpf.usermodel.ParagraphProperties;
import org.apache.poi.util.Internal;
import org.apache.poi.util.LittleEndian;

@Internal
public final class PAPX extends BytePropertyNode<PAPX> {
    public static final /* synthetic */ boolean $assertionsDisabled = false;
    public ParagraphHeight _phe;

    public PAPX(int i2, int i3, CharIndexTranslator charIndexTranslator, byte[] bArr, ParagraphHeight paragraphHeight, byte[] bArr2) {
        super(i2, i3, charIndexTranslator, new SprmBuffer(bArr, 2));
        this._phe = paragraphHeight;
        SprmBuffer findHuge = findHuge(new SprmBuffer(bArr, 2), bArr2);
        if (findHuge != null) {
            this._buf = findHuge;
        }
    }

    private SprmBuffer findHuge(SprmBuffer sprmBuffer, byte[] bArr) {
        byte[] byteArray = sprmBuffer.toByteArray();
        if (byteArray.length != 8 || bArr == null) {
            return null;
        }
        SprmOperation sprmOperation = new SprmOperation(byteArray, 2);
        if ((sprmOperation.getOperation() != 69 && sprmOperation.getOperation() != 70) || sprmOperation.getSizeCode() != 3) {
            return null;
        }
        int operand = sprmOperation.getOperand();
        if (operand + 1 >= bArr.length) {
            return null;
        }
        short s = LittleEndian.getShort(bArr, operand);
        if (operand + s >= bArr.length) {
            return null;
        }
        byte[] bArr2 = new byte[(s + 2)];
        bArr2[0] = byteArray[0];
        bArr2[1] = byteArray[1];
        System.arraycopy(bArr, operand + 2, bArr2, 2, s);
        return new SprmBuffer(bArr2, 2);
    }

    @Override // org.apache.poi.hwpf.model.PropertyNode
    public boolean equals(Object obj) {
        if (super.equals(obj)) {
            return this._phe.equals(((PAPX) obj)._phe);
        }
        return false;
    }

    public byte[] getGrpprl() {
        Object obj = this._buf;
        if (obj == null) {
            return new byte[0];
        }
        return ((SprmBuffer) obj).toByteArray();
    }

    public short getIstd() {
        if (this._buf == null) {
            return 0;
        }
        byte[] grpprl = getGrpprl();
        if (grpprl.length == 0) {
            return 0;
        }
        if (grpprl.length == 1) {
            return LittleEndian.getUByte(grpprl, 0);
        }
        return LittleEndian.getShort(grpprl);
    }

    public ParagraphHeight getParagraphHeight() {
        return this._phe;
    }

    @Internal
    @Deprecated
    public ParagraphProperties getParagraphProperties(StyleSheet styleSheet) {
        if (styleSheet == null) {
            return new ParagraphProperties();
        }
        return ParagraphSprmUncompressor.uncompressPAP(styleSheet.getParagraphStyle(getIstd()), getGrpprl(), 2);
    }

    public SprmBuffer getSprmBuf() {
        return (SprmBuffer) this._buf;
    }

    @Override // org.apache.poi.hwpf.model.PropertyNode
    public int hashCode() {
        return 42;
    }

    public String toString() {
        StringBuilder b2 = a.b("PAPX from ");
        b2.append(getStart());
        b2.append(" to ");
        b2.append(getEnd());
        b2.append(" (in bytes ");
        b2.append(getStartBytes());
        b2.append(" to ");
        b2.append(getEndBytes());
        b2.append(")");
        return b2.toString();
    }

    public PAPX(int i2, int i3, byte[] bArr, ParagraphHeight paragraphHeight, byte[] bArr2) {
        super(i2, i3, new SprmBuffer(bArr, 2));
        this._phe = paragraphHeight;
        SprmBuffer findHuge = findHuge(new SprmBuffer(bArr, 2), bArr2);
        if (findHuge != null) {
            this._buf = findHuge;
        }
    }

    @Deprecated
    public PAPX(int i2, int i3, CharIndexTranslator charIndexTranslator, SprmBuffer sprmBuffer, byte[] bArr) {
        super(i2, i3, charIndexTranslator, sprmBuffer);
        this._phe = new ParagraphHeight();
        SprmBuffer findHuge = findHuge(sprmBuffer, bArr);
        if (findHuge != null) {
            this._buf = findHuge;
        }
    }

    public PAPX(int i2, int i3, SprmBuffer sprmBuffer) {
        super(i2, i3, sprmBuffer);
        this._phe = new ParagraphHeight();
    }
}
