package org.apache.poi.hwpf.model;

import java.util.LinkedList;
import java.util.List;
import org.apache.poi.ddf.DefaultEscherRecordFactory;
import org.apache.poi.ddf.EscherContainerRecord;
import org.apache.poi.ddf.EscherRecord;
import org.apache.poi.hwpf.model.types.PICFAbstractType;
import org.apache.poi.util.Internal;
import org.apache.poi.util.LittleEndian;

@Internal
public class PICFAndOfficeArtData {
    public List<EscherRecord> _blipRecords;
    public short _cchPicName;
    public PICF _picf;
    public EscherContainerRecord _shape;
    public byte[] _stPicName;

    public PICFAndOfficeArtData(byte[] bArr, int i2) {
        this._picf = new PICF(bArr, i2);
        int size = PICFAbstractType.getSize() + i2;
        if (this._picf.getMm() == 102) {
            short uByte = LittleEndian.getUByte(bArr, size);
            this._cchPicName = uByte;
            int i3 = size + 1;
            this._stPicName = LittleEndian.getByteArray(bArr, i3, uByte);
            size = i3 + this._cchPicName;
        }
        DefaultEscherRecordFactory defaultEscherRecordFactory = new DefaultEscherRecordFactory();
        EscherContainerRecord escherContainerRecord = new EscherContainerRecord();
        this._shape = escherContainerRecord;
        int fillFields = escherContainerRecord.fillFields(bArr, size, defaultEscherRecordFactory) + size;
        this._blipRecords = new LinkedList();
        while (fillFields - i2 < this._picf.getLcb()) {
            EscherRecord createRecord = defaultEscherRecordFactory.createRecord(bArr, fillFields);
            if (createRecord.getRecordId() == -4089 || (createRecord.getRecordId() >= -4072 && createRecord.getRecordId() <= -3817)) {
                fillFields += createRecord.fillFields(bArr, fillFields, defaultEscherRecordFactory);
                this._blipRecords.add(createRecord);
            } else {
                return;
            }
        }
    }

    public List<EscherRecord> getBlipRecords() {
        return this._blipRecords;
    }

    public PICF getPicf() {
        return this._picf;
    }

    public EscherContainerRecord getShape() {
        return this._shape;
    }

    public byte[] getStPicName() {
        return this._stPicName;
    }
}
