package org.apache.poi.hwpf.model;

import b.b.a.a.a;
import java.nio.charset.Charset;
import org.apache.poi.util.Internal;
import org.apache.poi.util.LittleEndian;
import org.apache.poi.util.StringUtil;
import org.apache.xmlbeans.impl.common.ConcurrentReaderHashMap;

@Internal
public final class PieceDescriptor {
    public final Charset charset;
    public final short descriptor;
    public int fc;
    public final PropertyModifier prm;
    public final boolean unicode;

    public PieceDescriptor(byte[] bArr, int i2) {
        this(bArr, i2, null);
    }

    public static int getSizeInBytes() {
        return 8;
    }

    public boolean equals(Object obj) {
        if (this == obj) {
            return true;
        }
        if (obj == null || PieceDescriptor.class != obj.getClass()) {
            return false;
        }
        PieceDescriptor pieceDescriptor = (PieceDescriptor) obj;
        if (this.descriptor != pieceDescriptor.descriptor) {
            return false;
        }
        PropertyModifier propertyModifier = this.prm;
        if (propertyModifier == null) {
            if (pieceDescriptor.prm != null) {
                return false;
            }
        } else if (!propertyModifier.equals(pieceDescriptor.prm)) {
            return false;
        }
        return this.unicode == pieceDescriptor.unicode;
    }

    public Charset getCharset() {
        return this.charset;
    }

    public int getFilePosition() {
        return this.fc;
    }

    public PropertyModifier getPrm() {
        return this.prm;
    }

    public int hashCode() {
        int i2 = (this.descriptor + 31) * 31;
        PropertyModifier propertyModifier = this.prm;
        return ((i2 + (propertyModifier == null ? 0 : propertyModifier.hashCode())) * 31) + (this.unicode ? 1231 : 1237);
    }

    public boolean isUnicode() {
        return this.unicode;
    }

    public void setFilePosition(int i2) {
        this.fc = i2;
    }

    public byte[] toByteArray() {
        int i2 = this.fc;
        if (!this.unicode) {
            i2 = (i2 * 2) | ConcurrentReaderHashMap.MAXIMUM_CAPACITY;
        }
        byte[] bArr = new byte[8];
        LittleEndian.putShort(bArr, 0, this.descriptor);
        LittleEndian.putInt(bArr, 2, i2);
        LittleEndian.putShort(bArr, 6, this.prm.getValue());
        return bArr;
    }

    public String toString() {
        StringBuilder b2 = a.b("PieceDescriptor (pos: ");
        b2.append(getFilePosition());
        b2.append("; ");
        b2.append(isUnicode() ? "unicode" : "non-unicode");
        b2.append("; prm: ");
        b2.append(getPrm());
        b2.append(")");
        return b2.toString();
    }

    public PieceDescriptor(byte[] bArr, int i2, Charset charset2) {
        this.descriptor = LittleEndian.getShort(bArr, i2);
        int i3 = i2 + 2;
        this.fc = LittleEndian.getInt(bArr, i3);
        this.prm = new PropertyModifier(LittleEndian.getShort(bArr, i3 + 4));
        if (charset2 == null) {
            int i4 = this.fc;
            if ((1073741824 & i4) == 0) {
                this.unicode = true;
                this.charset = null;
                return;
            }
            this.unicode = false;
            int i5 = -1073741825 & i4;
            this.fc = i5;
            this.fc = i5 / 2;
            this.charset = StringUtil.WIN_1252;
            return;
        }
        if (charset2 == StringUtil.UTF16LE) {
            this.unicode = true;
        } else {
            this.unicode = false;
        }
        this.charset = charset2;
    }
}
