package org.apache.poi.hwpf.model;

import b.b.a.a.a;
import java.util.ArrayList;
import java.util.List;
import org.apache.poi.util.Internal;
import org.apache.poi.util.LittleEndian;

public final class PlexOfCps {
    public int _cbStruct;
    public int _iMac;
    public List<GenericPropertyNode> _props;

    public PlexOfCps(int i2) {
        this._props = new ArrayList();
        this._cbStruct = i2;
    }

    private int getIntOffset(int i2) {
        return i2 * 4;
    }

    private int getStructOffset(int i2) {
        return (this._cbStruct * i2) + ((this._iMac + 1) * 4);
    }

    public void addProperty(GenericPropertyNode genericPropertyNode) {
        this._props.add(genericPropertyNode);
        this._iMac++;
    }

    @Internal
    public void adjust(int i2, int i3) {
        for (GenericPropertyNode genericPropertyNode : this._props) {
            if (genericPropertyNode.getStart() > i2) {
                if (genericPropertyNode.getStart() + i3 < i2) {
                    genericPropertyNode.setStart(i2);
                } else {
                    genericPropertyNode.setStart(genericPropertyNode.getStart() + i3);
                }
            }
            if (genericPropertyNode.getEnd() >= i2) {
                if (genericPropertyNode.getEnd() + i3 < i2) {
                    genericPropertyNode.setEnd(i2);
                } else {
                    genericPropertyNode.setEnd(genericPropertyNode.getEnd() + i3);
                }
            }
        }
    }

    public GenericPropertyNode getProperty(int i2) {
        return this._props.get(i2);
    }

    public int length() {
        return this._iMac;
    }

    public void remove(int i2) {
        this._props.remove(i2);
        this._iMac--;
    }

    public byte[] toByteArray() {
        int size = this._props.size();
        int i2 = (size + 1) * 4;
        byte[] bArr = new byte[((this._cbStruct * size) + i2)];
        int i3 = 0;
        int i4 = 0;
        while (i3 < size) {
            GenericPropertyNode genericPropertyNode = this._props.get(i3);
            int end = genericPropertyNode.getEnd();
            LittleEndian.putInt(bArr, i3 * 4, genericPropertyNode.getStart());
            byte[] bytes = genericPropertyNode.getBytes();
            int i5 = this._cbStruct;
            System.arraycopy(bytes, 0, bArr, (i3 * i5) + i2, i5);
            i3++;
            i4 = end;
        }
        LittleEndian.putInt(bArr, size * 4, i4);
        return bArr;
    }

    public GenericPropertyNode[] toPropertiesArray() {
        List<GenericPropertyNode> list = this._props;
        if (list == null || list.isEmpty()) {
            return new GenericPropertyNode[0];
        }
        List<GenericPropertyNode> list2 = this._props;
        return (GenericPropertyNode[]) list2.toArray(new GenericPropertyNode[list2.size()]);
    }

    public String toString() {
        StringBuilder b2 = a.b("PLCF (cbStruct: ");
        b2.append(this._cbStruct);
        b2.append("; iMac: ");
        return a.a(b2, this._iMac, ")");
    }

    private GenericPropertyNode getProperty(int i2, byte[] bArr, int i3) {
        int i4 = LittleEndian.getInt(bArr, getIntOffset(i2) + i3);
        int i5 = LittleEndian.getInt(bArr, getIntOffset(i2 + 1) + i3);
        byte[] bArr2 = new byte[this._cbStruct];
        System.arraycopy(bArr, i3 + getStructOffset(i2), bArr2, 0, this._cbStruct);
        return new GenericPropertyNode(i4, i5, bArr2);
    }

    public PlexOfCps(byte[] bArr, int i2, int i3, int i4) {
        this._iMac = (i3 - 4) / (i4 + 4);
        this._cbStruct = i4;
        this._props = new ArrayList(this._iMac);
        for (int i5 = 0; i5 < this._iMac; i5++) {
            this._props.add(getProperty(i5, bArr, i2));
        }
    }
}
