package org.apache.poi.hwpf.model;

import b.b.a.a.a;
import java.io.ByteArrayOutputStream;
import java.util.Arrays;
import java.util.NoSuchElementException;
import org.apache.poi.hwpf.model.types.LFOAbstractType;
import org.apache.poi.util.LittleEndian;
import org.apache.poi.util.POILogFactory;
import org.apache.poi.util.POILogger;

public class PlfLfo {
    public static final POILogger log = POILogFactory.getLogger(PlfLfo.class);
    public int _lfoMac;
    public LFO[] _rgLfo;
    public LFOData[] _rgLfoData;

    public PlfLfo(byte[] bArr, int i2, int i3) {
        long uInt = LittleEndian.getUInt(bArr, i2);
        int i4 = i2 + 4;
        if (uInt <= 2147483647L) {
            int i5 = (int) uInt;
            this._lfoMac = i5;
            this._rgLfo = new LFO[i5];
            this._rgLfoData = new LFOData[i5];
            for (int i6 = 0; i6 < this._lfoMac; i6++) {
                LFO lfo = new LFO(bArr, i4);
                i4 += LFOAbstractType.getSize();
                this._rgLfo[i6] = lfo;
            }
            for (int i7 = 0; i7 < this._lfoMac; i7++) {
                LFOData lFOData = new LFOData(bArr, i4, this._rgLfo[i7].getClfolvl());
                i4 += lFOData.getSizeInBytes();
                this._rgLfoData[i7] = lFOData;
            }
            int i8 = i4 - i2;
            if (i8 != i3 && log.check(5)) {
                log.log(5, a.a("Actual size of PlfLfo is ", i8, " bytes, but expected ", i3));
                return;
            }
            return;
        }
        throw new UnsupportedOperationException("Apache POI doesn't support rgLfo/rgLfoData size large than 2147483647 elements");
    }

    public void add(LFO lfo, LFOData lFOData) {
        LFO[] lfoArr = (LFO[]) Arrays.copyOf(this._rgLfo, this._lfoMac + 1);
        this._rgLfo = lfoArr;
        int i2 = this._lfoMac;
        lfoArr[i2] = lfo;
        LFOData[] lFODataArr = (LFOData[]) Arrays.copyOf(this._rgLfoData, i2 + 1);
        this._rgLfoData = lFODataArr;
        int i3 = this._lfoMac;
        lFODataArr[i3] = lFOData;
        this._lfoMac = i3 + 1;
    }

    public boolean equals(Object obj) {
        if (this == obj) {
            return true;
        }
        if (obj == null || PlfLfo.class != obj.getClass()) {
            return false;
        }
        PlfLfo plfLfo = (PlfLfo) obj;
        if (this._lfoMac != plfLfo._lfoMac || !Arrays.equals(this._rgLfo, plfLfo._rgLfo) || !Arrays.equals(this._rgLfoData, plfLfo._rgLfoData)) {
            return false;
        }
        return true;
    }

    public int getIlfoByLsid(int i2) {
        int i3 = 0;
        while (i3 < this._lfoMac) {
            int lsid = this._rgLfo[i3].getLsid();
            i3++;
            if (lsid == i2) {
                return i3;
            }
        }
        throw new NoSuchElementException(a.b("LFO with lsid ", i2, " not found"));
    }

    public LFO getLfo(int i2) {
        if (i2 > 0 && i2 <= this._lfoMac) {
            return this._rgLfo[i2 - 1];
        }
        StringBuilder a = a.a("LFO with ilfo ", i2, " not found. lfoMac is ");
        a.append(this._lfoMac);
        throw new NoSuchElementException(a.toString());
    }

    public LFOData getLfoData(int i2) {
        if (i2 > 0 && i2 <= this._lfoMac) {
            return this._rgLfoData[i2 - 1];
        }
        StringBuilder a = a.a("LFOData with ilfo ", i2, " not found. lfoMac is ");
        a.append(this._lfoMac);
        throw new NoSuchElementException(a.toString());
    }

    public int getLfoMac() {
        return this._lfoMac;
    }

    public int hashCode() {
        int hashCode = Arrays.hashCode(this._rgLfo);
        return Arrays.hashCode(this._rgLfoData) + ((hashCode + ((this._lfoMac + 31) * 31)) * 31);
    }

    public void writeTo(FileInformationBlock fileInformationBlock, ByteArrayOutputStream byteArrayOutputStream) {
        int size = byteArrayOutputStream.size();
        fileInformationBlock.setFcPlfLfo(size);
        LittleEndian.putUInt((long) this._lfoMac, byteArrayOutputStream);
        byte[] bArr = new byte[(LFOAbstractType.getSize() * this._lfoMac)];
        for (int i2 = 0; i2 < this._lfoMac; i2++) {
            this._rgLfo[i2].serialize(bArr, LFOAbstractType.getSize() * i2);
        }
        byteArrayOutputStream.write(bArr, 0, LFOAbstractType.getSize() * this._lfoMac);
        for (int i3 = 0; i3 < this._lfoMac; i3++) {
            this._rgLfoData[i3].writeTo(byteArrayOutputStream);
        }
        fileInformationBlock.setLcbPlfLfo(byteArrayOutputStream.size() - size);
    }
}
