package org.apache.poi.hwpf.model;

import b.b.a.a.a;
import java.util.Arrays;
import java.util.Comparator;
import org.apache.poi.hwpf.model.PropertyNode;
import org.apache.poi.util.Internal;
import org.apache.poi.util.POILogFactory;
import org.apache.poi.util.POILogger;

@Internal
public abstract class PropertyNode<T extends PropertyNode<T>> implements Comparable<T>, Cloneable {
    public static final POILogger _logger = POILogFactory.getLogger(PropertyNode.class);
    public Object _buf;
    public int _cpEnd;
    public int _cpStart;

    public static final class EndComparator implements Comparator<PropertyNode<?>> {
        public static final EndComparator instance = new EndComparator();

        public int compare(PropertyNode<?> propertyNode, PropertyNode<?> propertyNode2) {
            int end = propertyNode.getEnd();
            int end2 = propertyNode2.getEnd();
            if (end < end2) {
                return -1;
            }
            return end == end2 ? 0 : 1;
        }
    }

    public static final class StartComparator implements Comparator<PropertyNode<?>> {
        public static final StartComparator instance = new StartComparator();

        public int compare(PropertyNode<?> propertyNode, PropertyNode<?> propertyNode2) {
            int start = propertyNode.getStart();
            int start2 = propertyNode2.getStart();
            if (start < start2) {
                return -1;
            }
            return start == start2 ? 0 : 1;
        }
    }

    public PropertyNode(int i2, int i3, Object obj) {
        this._cpStart = i2;
        this._cpEnd = i3;
        this._buf = obj;
        if (i2 < 0) {
            _logger.log(5, a.a(a.b("A property claimed to start before zero, at "), this._cpStart, "! Resetting it to zero, and hoping for the best"));
            this._cpStart = 0;
        }
        if (this._cpEnd < this._cpStart) {
            POILogger pOILogger = _logger;
            StringBuilder b2 = a.b("A property claimed to end (");
            b2.append(this._cpEnd);
            b2.append(") before start! ");
            b2.append("Resetting end to start, and hoping for the best");
            pOILogger.log(5, b2.toString());
            this._cpEnd = this._cpStart;
        }
    }

    public void adjustForDelete(int i2, int i3) {
        int i4 = i2 + i3;
        int i5 = this._cpEnd;
        if (i5 > i2) {
            int i6 = this._cpStart;
            if (i6 < i4) {
                this._cpEnd = i4 >= i5 ? i2 : i5 - i3;
                this._cpStart = Math.min(i2, this._cpStart);
                return;
            }
            this._cpEnd = i5 - i3;
            this._cpStart = i6 - i3;
        }
    }

    public boolean equals(Object obj) {
        if (!(obj instanceof PropertyNode) || !limitsAreEqual(obj)) {
            return false;
        }
        Object obj2 = ((PropertyNode) obj)._buf;
        if (obj2 instanceof byte[]) {
            Object obj3 = this._buf;
            if (obj3 instanceof byte[]) {
                return Arrays.equals((byte[]) obj2, (byte[]) obj3);
            }
        }
        return this._buf.equals(obj2);
    }

    public int getEnd() {
        return this._cpEnd;
    }

    public int getStart() {
        return this._cpStart;
    }

    public int hashCode() {
        return this._buf.hashCode() + (this._cpStart * 31);
    }

    public boolean limitsAreEqual(Object obj) {
        PropertyNode propertyNode = (PropertyNode) obj;
        return propertyNode.getStart() == this._cpStart && propertyNode.getEnd() == this._cpEnd;
    }

    public void setEnd(int i2) {
        this._cpEnd = i2;
    }

    public void setStart(int i2) {
        this._cpStart = i2;
    }

    @Override // java.lang.Object
    public T clone() {
        return (T) ((PropertyNode) super.clone());
    }

    public int compareTo(T t) {
        int end = t.getEnd();
        int i2 = this._cpEnd;
        if (i2 == end) {
            return 0;
        }
        return i2 < end ? -1 : 1;
    }
}
