package org.apache.poi.hwpf.model;

import java.io.ByteArrayOutputStream;
import java.util.ArrayList;
import java.util.Collections;
import java.util.List;
import org.apache.poi.hwpf.HWPFDocumentCore;
import org.apache.poi.hwpf.model.PropertyNode;
import org.apache.poi.hwpf.model.io.HWPFFileSystem;
import org.apache.poi.util.Internal;
import org.apache.poi.util.LittleEndian;
import org.apache.poi.util.POILogFactory;
import org.apache.poi.util.POILogger;

@Internal
public class SectionTable {
    public static final int SED_SIZE = 12;
    public static final POILogger _logger = POILogFactory.getLogger(SectionTable.class);
    public List<SEPX> _sections = new ArrayList();
    public List<TextPiece> _text;

    public SectionTable() {
    }

    public void adjustForInsert(int i2, int i3) {
        int size = this._sections.size();
        SEPX sepx = this._sections.get(i2);
        sepx.setEnd(sepx.getEnd() + i3);
        while (true) {
            i2++;
            if (i2 < size) {
                SEPX sepx2 = this._sections.get(i2);
                sepx2.setStart(sepx2.getStart() + i3);
                sepx2.setEnd(sepx2.getEnd() + i3);
            } else {
                return;
            }
        }
    }

    public List<SEPX> getSections() {
        return this._sections;
    }

    @Deprecated
    public void writeTo(HWPFFileSystem hWPFFileSystem, int i2) {
        writeTo(hWPFFileSystem.getStream(HWPFDocumentCore.STREAM_WORD_DOCUMENT), hWPFFileSystem.getStream(HWPFDocumentCore.STREAM_TABLE_1));
    }

    public SectionTable(byte[] bArr, byte[] bArr2, int i2, int i3, int i4, TextPieceTable textPieceTable, int i5) {
        PlexOfCps plexOfCps = new PlexOfCps(bArr2, i2, i3, 12);
        this._text = textPieceTable.getTextPieces();
        int length = plexOfCps.length();
        for (int i6 = 0; i6 < length; i6++) {
            GenericPropertyNode property = plexOfCps.getProperty(i6);
            SectionDescriptor sectionDescriptor = new SectionDescriptor(property.getBytes(), 0);
            int fc = sectionDescriptor.getFc();
            int start = property.getStart();
            int end = property.getEnd();
            if (fc == -1) {
                this._sections.add(new SEPX(sectionDescriptor, start, end, new byte[0]));
            } else {
                int i7 = LittleEndian.getShort(bArr, fc);
                byte[] bArr3 = new byte[i7];
                System.arraycopy(bArr, fc + 2, bArr3, 0, i7);
                this._sections.add(new SEPX(sectionDescriptor, start, end, bArr3));
            }
        }
        boolean z = false;
        boolean z2 = false;
        for (int i8 = 0; i8 < this._sections.size(); i8++) {
            SEPX sepx = this._sections.get(i8);
            if (sepx.getEnd() == i5) {
                z = true;
            } else if (sepx.getEnd() == i5 || sepx.getEnd() == i5 - 1) {
                z2 = true;
            }
        }
        if (!z && z2) {
            _logger.log(5, "Your document seemed to be mostly unicode, but the section definition was in bytes! Trying anyway, but things may well go wrong!");
            for (int i9 = 0; i9 < this._sections.size(); i9++) {
                SEPX sepx2 = this._sections.get(i9);
                GenericPropertyNode property2 = plexOfCps.getProperty(i9);
                int start2 = property2.getStart();
                int end2 = property2.getEnd();
                sepx2.setStart(start2);
                sepx2.setEnd(end2);
            }
        }
        Collections.sort(this._sections, PropertyNode.StartComparator.instance);
    }

    public void writeTo(ByteArrayOutputStream byteArrayOutputStream, ByteArrayOutputStream byteArrayOutputStream2) {
        int size = byteArrayOutputStream.size();
        int size2 = this._sections.size();
        PlexOfCps plexOfCps = new PlexOfCps(12);
        for (int i2 = 0; i2 < size2; i2++) {
            SEPX sepx = this._sections.get(i2);
            byte[] grpprl = sepx.getGrpprl();
            byte[] bArr = new byte[2];
            LittleEndian.putShort(bArr, 0, (short) grpprl.length);
            byteArrayOutputStream.write(bArr);
            byteArrayOutputStream.write(grpprl);
            SectionDescriptor sectionDescriptor = sepx.getSectionDescriptor();
            sectionDescriptor.setFc(size);
            plexOfCps.addProperty(new GenericPropertyNode(sepx.getStart(), sepx.getEnd(), sectionDescriptor.toByteArray()));
            size = byteArrayOutputStream.size();
        }
        byteArrayOutputStream2.write(plexOfCps.toByteArray());
    }
}
