package org.apache.poi.hwpf.model;

import java.util.Arrays;
import org.apache.poi.util.LittleEndian;
import org.apache.poi.util.POILogFactory;
import org.apache.poi.util.StringUtil;

public class Sttb {
    public final int _cDataLength;
    public int _cbExtra;
    public String[] _data;
    public byte[][] _extraData;
    public final boolean _fExtend;

    public Sttb(byte[] bArr, int i2) {
        this(2, bArr, i2);
    }

    public void fillFields(byte[] bArr, int i2) {
        short s = LittleEndian.getShort(bArr, i2);
        int i3 = i2 + 2;
        if (s != -1) {
            POILogFactory.getLogger(Sttb.class).log(5, "Non-extended character Pascal strings are not supported right now. Creating empty values in the RevisionMarkAuthorTable for now.  Please, contact POI developers for update.");
            this._data = new String[0];
            this._extraData = new byte[0][];
            return;
        }
        int uShort = this._cDataLength == 2 ? LittleEndian.getUShort(bArr, i3) : LittleEndian.getInt(bArr, i3);
        int i4 = i3 + this._cDataLength;
        this._cbExtra = LittleEndian.getUShort(bArr, i4);
        int i5 = i4 + 2;
        this._data = new String[uShort];
        this._extraData = new byte[uShort][];
        for (int i6 = 0; i6 < uShort; i6++) {
            short s2 = LittleEndian.getShort(bArr, i5);
            i5 += 2;
            if (s2 >= 0) {
                this._data[i6] = StringUtil.getFromUnicodeLE(bArr, i5, s2);
                int i7 = (s2 * 2) + i5;
                this._extraData[i6] = LittleEndian.getByteArray(bArr, i7, this._cbExtra);
                i5 = i7 + this._cbExtra;
            }
        }
    }

    public String[] getData() {
        return this._data;
    }

    public int getSize() {
        int i2 = this._cDataLength + 2 + 2;
        getClass();
        for (String str : this._data) {
            i2 = i2 + 2 + (str.length() * 2);
        }
        return this._extraData != null ? i2 + (this._cbExtra * this._data.length) : i2;
    }

    public byte[] serialize() {
        byte[] bArr = new byte[getSize()];
        LittleEndian.putShort(bArr, 0, -1);
        String[] strArr = this._data;
        int i2 = 6;
        if (strArr != null && strArr.length != 0) {
            if (this._cDataLength == 4) {
                LittleEndian.putInt(bArr, 2, strArr.length);
                LittleEndian.putUShort(bArr, 6, this._cbExtra);
                i2 = 8;
            } else {
                LittleEndian.putUShort(bArr, 2, strArr.length);
                LittleEndian.putUShort(bArr, 4, this._cbExtra);
            }
            int i3 = 0;
            while (true) {
                String[] strArr2 = this._data;
                if (i3 >= strArr2.length) {
                    return bArr;
                }
                String str = strArr2[i3];
                if (str == null) {
                    bArr[i2] = -1;
                    bArr[i2 + 1] = 0;
                    i2 += 2;
                } else {
                    LittleEndian.putUShort(bArr, i2, str.length());
                    int i4 = i2 + 2;
                    StringUtil.putUnicodeLE(str, bArr, i4);
                    int length = (str.length() * 2) + i4;
                    int i5 = this._cbExtra;
                    if (i5 != 0) {
                        byte[][] bArr2 = this._extraData;
                        if (!(bArr2[i3] == null || bArr2[i3].length == 0)) {
                            System.arraycopy(bArr2[i3], 0, bArr, length, Math.min(bArr2[i3].length, i5));
                        }
                        length += this._cbExtra;
                    }
                    i2 = length;
                }
                i3++;
            }
        } else if (this._cDataLength == 4) {
            LittleEndian.putInt(bArr, 2, 0);
            LittleEndian.putUShort(bArr, 6, this._cbExtra);
            return bArr;
        } else {
            LittleEndian.putUShort(bArr, 2, 0);
            LittleEndian.putUShort(bArr, 4, this._cbExtra);
            return bArr;
        }
    }

    public Sttb(int i2, byte[] bArr, int i3) {
        this._fExtend = true;
        this._cDataLength = i2;
        fillFields(bArr, i3);
    }

    public Sttb(int i2, String[] strArr) {
        this._fExtend = true;
        this._cDataLength = i2;
        this._data = (String[]) Arrays.copyOf(strArr, strArr.length);
        this._cbExtra = 0;
        this._extraData = null;
    }

    public int serialize(byte[] bArr, int i2) {
        byte[] serialize = serialize();
        System.arraycopy(serialize, 0, bArr, i2, serialize.length);
        return serialize.length;
    }
}
