package org.apache.poi.hwpf.model;

import b.b.a.a.a;
import java.util.Arrays;
import org.apache.poi.hwpf.model.types.StdfBaseAbstractType;
import org.apache.poi.hwpf.usermodel.CharacterProperties;
import org.apache.poi.hwpf.usermodel.ParagraphProperties;
import org.apache.poi.util.Internal;
import org.apache.poi.util.LittleEndian;
import org.apache.poi.util.POILogFactory;
import org.apache.poi.util.POILogger;
import org.apache.poi.util.StringUtil;

@Internal
public final class StyleDescription implements HDFType {
    public static final int CHARACTER_STYLE = 2;
    public static final int PARAGRAPH_STYLE = 1;
    public static final POILogger logger = POILogFactory.getLogger(StyleDescription.class);
    public int _baseLength;
    @Deprecated
    public CharacterProperties _chp;
    public String _name;
    @Deprecated
    public ParagraphProperties _pap;
    public StdfBase _stdfBase;
    public StdfPost2000 _stdfPost2000;
    public UPX[] _upxs;

    public StyleDescription() {
    }

    public boolean equals(Object obj) {
        if (this == obj) {
            return true;
        }
        if (obj == null || StyleDescription.class != obj.getClass()) {
            return false;
        }
        StyleDescription styleDescription = (StyleDescription) obj;
        String str = this._name;
        if (str == null) {
            if (styleDescription._name != null) {
                return false;
            }
        } else if (!str.equals(styleDescription._name)) {
            return false;
        }
        StdfBase stdfBase = this._stdfBase;
        if (stdfBase == null) {
            if (styleDescription._stdfBase != null) {
                return false;
            }
        } else if (!stdfBase.equals(styleDescription._stdfBase)) {
            return false;
        }
        return Arrays.equals(this._upxs, styleDescription._upxs);
    }

    public int getBaseStyle() {
        return this._stdfBase.getIstdBase();
    }

    @Deprecated
    public CharacterProperties getCHP() {
        return this._chp;
    }

    public byte[] getCHPX() {
        byte stk = this._stdfBase.getStk();
        if (stk == 1) {
            UPX[] upxArr = this._upxs;
            if (upxArr.length > 1) {
                return upxArr[1].getUPX();
            }
            return null;
        } else if (stk != 2) {
            return null;
        } else {
            return this._upxs[0].getUPX();
        }
    }

    public String getName() {
        return this._name;
    }

    @Deprecated
    public ParagraphProperties getPAP() {
        return this._pap;
    }

    public byte[] getPAPX() {
        if (this._stdfBase.getStk() != 1) {
            return null;
        }
        return this._upxs[0].getUPX();
    }

    public int hashCode() {
        String str = this._name;
        int i2 = 0;
        int hashCode = ((str == null ? 0 : str.hashCode()) + 31) * 31;
        StdfBase stdfBase = this._stdfBase;
        if (stdfBase != null) {
            i2 = stdfBase.hashCode();
        }
        return Arrays.hashCode(this._upxs) + ((hashCode + i2) * 31);
    }

    @Deprecated
    public void setCHP(CharacterProperties characterProperties) {
        this._chp = characterProperties;
    }

    @Deprecated
    public void setPAP(ParagraphProperties paragraphProperties) {
        this._pap = paragraphProperties;
    }

    public byte[] toByteArray() {
        int i2 = 1;
        int size = this._upxs[0].size() + 2 + ((this._name.length() + 1) * 2) + this._baseLength + 2;
        while (true) {
            UPX[] upxArr = this._upxs;
            if (i2 >= upxArr.length) {
                break;
            }
            size = this._upxs[i2].size() + 2 + (upxArr[i2 - 1].size() % 2) + size;
            i2++;
        }
        byte[] bArr = new byte[size];
        this._stdfBase.serialize(bArr, 0);
        int i3 = this._baseLength;
        char[] charArray = this._name.toCharArray();
        LittleEndian.putShort(bArr, this._baseLength, (short) charArray.length);
        int i4 = i3 + 2;
        for (char c : charArray) {
            LittleEndian.putShort(bArr, i4, (short) c);
            i4 += 2;
        }
        int i5 = i4 + 2;
        int i6 = 0;
        while (true) {
            UPX[] upxArr2 = this._upxs;
            if (i6 >= upxArr2.length) {
                return bArr;
            }
            short size2 = (short) upxArr2[i6].size();
            LittleEndian.putShort(bArr, i5, size2);
            int i7 = i5 + 2;
            System.arraycopy(this._upxs[i6].getUPX(), 0, bArr, i7, size2);
            i5 = i7 + (size2 % 2) + size2;
            i6++;
        }
    }

    public String toString() {
        StringBuilder b2 = a.b("[STD]: '");
        b2.append(this._name);
        b2.append("'");
        b2.append(("\nStdfBase:\t" + this._stdfBase).replaceAll("\n", "\n    "));
        b2.append(("\nStdfPost2000:\t" + this._stdfPost2000).replaceAll("\n", "\n    "));
        UPX[] upxArr = this._upxs;
        for (UPX upx : upxArr) {
            b2.append(("\nUPX:\t" + upx).replaceAll("\n", "\n    "));
        }
        return b2.toString();
    }

    public StyleDescription(byte[] bArr, int i2, int i3, boolean z) {
        boolean z2;
        int i4;
        short s;
        this._baseLength = i2;
        int i5 = i3 + i2;
        if (i2 == 18) {
            z2 = true;
        } else {
            if (i2 != 10) {
                logger.log(5, "Style definition has non-standard size of ", Integer.valueOf(i2));
            }
            z2 = false;
        }
        this._stdfBase = new StdfBase(bArr, i3);
        int size = StdfBaseAbstractType.getSize() + i3;
        if (z2) {
            this._stdfPost2000 = new StdfPost2000(bArr, size);
        }
        if (z) {
            short s2 = LittleEndian.getShort(bArr, i5);
            i5 += 2;
            i4 = 2;
            s = s2;
        } else {
            i4 = 1;
            s = bArr[i5];
        }
        this._name = StringUtil.getFromUnicodeLE(bArr, i5, ((s == 1 ? 1 : 0) * i4) / 2);
        int i6 = ((s + 1) * i4) + i5;
        int cupx = this._stdfBase.getCupx();
        this._upxs = new UPX[cupx];
        for (int i7 = 0; i7 < cupx; i7++) {
            int i8 = LittleEndian.getShort(bArr, i6);
            int i9 = i6 + 2;
            byte[] bArr2 = new byte[i8];
            System.arraycopy(bArr, i9, bArr2, 0, i8);
            this._upxs[i7] = new UPX(bArr2);
            i6 = i9 + i8;
            if ((i8 & 1) == 1) {
                i6++;
            }
        }
    }
}
