package org.apache.poi.hwpf.model;

import b.b.a.a.a;
import java.io.OutputStream;
import org.apache.poi.hwpf.model.types.StshifAbstractType;
import org.apache.poi.hwpf.sprm.CharacterSprmUncompressor;
import org.apache.poi.hwpf.sprm.ParagraphSprmUncompressor;
import org.apache.poi.hwpf.usermodel.CharacterProperties;
import org.apache.poi.hwpf.usermodel.ParagraphProperties;
import org.apache.poi.util.Internal;
import org.apache.poi.util.LittleEndian;

@Internal
public final class StyleSheet implements HDFType {
    public static final /* synthetic */ boolean $assertionsDisabled = false;
    @Deprecated
    public static final CharacterProperties NIL_CHP = new CharacterProperties();
    public static final byte[] NIL_CHPX = new byte[0];
    @Deprecated
    public static final ParagraphProperties NIL_PAP = new ParagraphProperties();
    public static final byte[] NIL_PAPX = {0, 0};
    public static final int NIL_STYLE = 4095;
    public int _cbStshi;
    public Stshif _stshif;
    public StyleDescription[] _styleDescriptions = new StyleDescription[this._stshif.getCstd()];

    public StyleSheet(byte[] bArr, int i2) {
        this._cbStshi = LittleEndian.getShort(bArr, i2);
        int i3 = i2 + 2;
        this._stshif = new Stshif(bArr, i3);
        StshifAbstractType.getSize();
        int i4 = i3 + this._cbStshi;
        int i5 = 0;
        for (int i6 = 0; i6 < this._stshif.getCstd(); i6++) {
            short s = LittleEndian.getShort(bArr, i4);
            int i7 = i4 + 2;
            if (s > 0) {
                this._styleDescriptions[i6] = new StyleDescription(bArr, this._stshif.getCbSTDBaseInFile(), i7, true);
            }
            i4 = i7 + s;
        }
        while (true) {
            StyleDescription[] styleDescriptionArr = this._styleDescriptions;
            if (i5 < styleDescriptionArr.length) {
                if (styleDescriptionArr[i5] != null) {
                    createPap(i5);
                    createChp(i5);
                }
                i5++;
            } else {
                return;
            }
        }
    }

    @Deprecated
    private void createChp(int i2) {
        StyleDescription styleDescription = this._styleDescriptions[i2];
        CharacterProperties chp = styleDescription.getCHP();
        byte[] chpx = styleDescription.getCHPX();
        int baseStyle = styleDescription.getBaseStyle();
        if (baseStyle == i2) {
            baseStyle = 4095;
        }
        if (chp == null && chpx != null) {
            CharacterProperties characterProperties = new CharacterProperties();
            if (baseStyle != 4095) {
                characterProperties = this._styleDescriptions[baseStyle].getCHP();
                if (characterProperties == null) {
                    createChp(baseStyle);
                    characterProperties = this._styleDescriptions[baseStyle].getCHP();
                }
                if (characterProperties == null) {
                    characterProperties = new CharacterProperties();
                }
            }
            styleDescription.setCHP(CharacterSprmUncompressor.uncompressCHP(characterProperties, chpx, 0));
        }
    }

    @Deprecated
    private void createPap(int i2) {
        StyleDescription styleDescription = this._styleDescriptions[i2];
        ParagraphProperties pap = styleDescription.getPAP();
        byte[] papx = styleDescription.getPAPX();
        int baseStyle = styleDescription.getBaseStyle();
        if (pap == null && papx != null) {
            ParagraphProperties paragraphProperties = new ParagraphProperties();
            if (baseStyle != 4095 && (paragraphProperties = this._styleDescriptions[baseStyle].getPAP()) == null) {
                if (baseStyle != i2) {
                    createPap(baseStyle);
                    paragraphProperties = this._styleDescriptions[baseStyle].getPAP();
                } else {
                    throw new IllegalStateException(a.b("Pap style ", i2, " claimed to have itself as its parent, which isn't allowed"));
                }
            }
            if (paragraphProperties == null) {
                paragraphProperties = new ParagraphProperties();
            }
            styleDescription.setPAP(ParagraphSprmUncompressor.uncompressPAP(paragraphProperties, papx, 2));
        }
    }

    public boolean equals(Object obj) {
        if (!(obj instanceof StyleSheet)) {
            return false;
        }
        StyleSheet styleSheet = (StyleSheet) obj;
        if (!styleSheet._stshif.equals(this._stshif) || styleSheet._cbStshi != this._cbStshi || styleSheet._styleDescriptions.length != this._styleDescriptions.length) {
            return false;
        }
        int i2 = 0;
        while (true) {
            StyleDescription[] styleDescriptionArr = this._styleDescriptions;
            if (i2 >= styleDescriptionArr.length) {
                return true;
            }
            StyleDescription styleDescription = styleDescriptionArr[i2];
            StyleDescription styleDescription2 = styleSheet._styleDescriptions[i2];
            if ((styleDescription != null || styleDescription2 != null) && (styleDescription == null || styleDescription2 == null || !styleDescription2.equals(styleDescription))) {
                return false;
            }
            i2++;
        }
        return false;
    }

    public byte[] getCHPX(int i2) {
        if (i2 == 4095) {
            return NIL_CHPX;
        }
        StyleDescription[] styleDescriptionArr = this._styleDescriptions;
        if (i2 >= styleDescriptionArr.length) {
            return NIL_CHPX;
        }
        if (styleDescriptionArr[i2] == null) {
            return NIL_CHPX;
        }
        if (styleDescriptionArr[i2].getCHPX() == null) {
            return NIL_CHPX;
        }
        return this._styleDescriptions[i2].getCHPX();
    }

    @Deprecated
    public CharacterProperties getCharacterStyle(int i2) {
        if (i2 == 4095) {
            return NIL_CHP;
        }
        StyleDescription[] styleDescriptionArr = this._styleDescriptions;
        if (i2 >= styleDescriptionArr.length) {
            return NIL_CHP;
        }
        return styleDescriptionArr[i2] != null ? styleDescriptionArr[i2].getCHP() : NIL_CHP;
    }

    public byte[] getPAPX(int i2) {
        if (i2 == 4095) {
            return NIL_PAPX;
        }
        StyleDescription[] styleDescriptionArr = this._styleDescriptions;
        if (i2 >= styleDescriptionArr.length) {
            return NIL_PAPX;
        }
        if (styleDescriptionArr[i2] == null) {
            return NIL_PAPX;
        }
        if (styleDescriptionArr[i2].getPAPX() == null) {
            return NIL_PAPX;
        }
        return this._styleDescriptions[i2].getPAPX();
    }

    @Deprecated
    public ParagraphProperties getParagraphStyle(int i2) {
        if (i2 == 4095) {
            return NIL_PAP;
        }
        StyleDescription[] styleDescriptionArr = this._styleDescriptions;
        if (i2 >= styleDescriptionArr.length) {
            return NIL_PAP;
        }
        if (styleDescriptionArr[i2] == null) {
            return NIL_PAP;
        }
        if (styleDescriptionArr[i2].getPAP() == null) {
            return NIL_PAP;
        }
        return this._styleDescriptions[i2].getPAP();
    }

    public StyleDescription getStyleDescription(int i2) {
        return this._styleDescriptions[i2];
    }

    public int hashCode() {
        return 42;
    }

    public int numStyles() {
        return this._styleDescriptions.length;
    }

    public void writeTo(OutputStream outputStream) {
        this._cbStshi = 18;
        byte[] bArr = new byte[(18 + 2)];
        LittleEndian.putUShort(bArr, 0, (short) 18);
        this._stshif.setCstd(this._styleDescriptions.length);
        this._stshif.serialize(bArr, 2);
        outputStream.write(bArr);
        byte[] bArr2 = new byte[2];
        int i2 = 0;
        while (true) {
            StyleDescription[] styleDescriptionArr = this._styleDescriptions;
            if (i2 < styleDescriptionArr.length) {
                if (styleDescriptionArr[i2] != null) {
                    byte[] byteArray = styleDescriptionArr[i2].toByteArray();
                    LittleEndian.putShort(bArr2, 0, (short) ((byteArray.length % 2) + byteArray.length));
                    outputStream.write(bArr2);
                    outputStream.write(byteArray);
                    if (byteArray.length % 2 == 1) {
                        outputStream.write(0);
                    }
                } else {
                    bArr2[0] = 0;
                    bArr2[1] = 0;
                    outputStream.write(bArr2);
                }
                i2++;
            } else {
                return;
            }
        }
    }
}
