package org.apache.poi.hwpf.model;

import b.b.a.a.a;
import java.nio.charset.Charset;
import org.apache.poi.util.CodePageUtil;
import org.apache.poi.util.Internal;
import org.apache.poi.util.StringUtil;

@Internal
public class TextPiece extends PropertyNode<TextPiece> {
    public static final /* synthetic */ boolean $assertionsDisabled = false;
    public PieceDescriptor _pd;
    public boolean _usesUnicode;

    public TextPiece(int i2, int i3, byte[] bArr, PieceDescriptor pieceDescriptor, int i4) {
        this(i2, i3, bArr, pieceDescriptor);
    }

    public static StringBuilder buildInitSB(byte[] bArr, PieceDescriptor pieceDescriptor) {
        if (StringUtil.BIG5.equals(pieceDescriptor.getCharset())) {
            return new StringBuilder(CodePageUtil.cp950ToString(bArr, 0, bArr.length));
        }
        return new StringBuilder(new String(bArr, 0, bArr.length, pieceDescriptor.isUnicode() ? StringUtil.UTF16LE : pieceDescriptor.getCharset()));
    }

    @Override // org.apache.poi.hwpf.model.PropertyNode
    @Deprecated
    public void adjustForDelete(int i2, int i3) {
        int start = getStart();
        int end = getEnd();
        int i4 = i2 + i3;
        if (i2 <= end && i4 >= start) {
            ((StringBuilder) this._buf).delete(Math.max(start, i2) - start, Math.min(end, i4) - start);
        }
        super.adjustForDelete(i2, i3);
    }

    public int bytesLength() {
        return (getEnd() - getStart()) * (this._usesUnicode ? 2 : 1);
    }

    @Deprecated
    public int characterLength() {
        return getEnd() - getStart();
    }

    @Override // org.apache.poi.hwpf.model.PropertyNode
    public boolean equals(Object obj) {
        if (!(obj instanceof TextPiece)) {
            return false;
        }
        TextPiece textPiece = (TextPiece) obj;
        if (!limitsAreEqual(obj) || textPiece._usesUnicode != this._usesUnicode || !textPiece._buf.toString().equals(this._buf.toString()) || !textPiece._pd.equals(this._pd)) {
            return false;
        }
        return true;
    }

    public int getCP() {
        return getStart();
    }

    public PieceDescriptor getPieceDescriptor() {
        return this._pd;
    }

    public byte[] getRawBytes() {
        return ((CharSequence) this._buf).toString().getBytes(Charset.forName(this._usesUnicode ? "UTF-16LE" : "Cp1252"));
    }

    @Deprecated
    public StringBuffer getStringBuffer() {
        return new StringBuffer(getStringBuilder());
    }

    public StringBuilder getStringBuilder() {
        return (StringBuilder) this._buf;
    }

    @Override // org.apache.poi.hwpf.model.PropertyNode
    public int hashCode() {
        return 42;
    }

    public boolean isUnicode() {
        return this._usesUnicode;
    }

    @Deprecated
    public String substring(int i2, int i3) {
        StringBuilder sb = (StringBuilder) this._buf;
        if (i2 < 0) {
            throw new StringIndexOutOfBoundsException(a.c("Can't request a substring before 0 - asked for ", i2));
        } else if (i3 > sb.length()) {
            StringBuilder a = a.a("Index ", i3, " out of range 0 -> ");
            a.append(sb.length());
            throw new StringIndexOutOfBoundsException(a.toString());
        } else if (i3 >= i2) {
            return sb.substring(i2, i3);
        } else {
            throw new StringIndexOutOfBoundsException(a.b("Asked for text from ", i2, " to ", i3, ", which has an end before the start!"));
        }
    }

    public String toString() {
        StringBuilder b2 = a.b("TextPiece from ");
        b2.append(getStart());
        b2.append(" to ");
        b2.append(getEnd());
        b2.append(" (");
        b2.append(getPieceDescriptor());
        b2.append(")");
        return b2.toString();
    }

    public TextPiece(int i2, int i3, byte[] bArr, PieceDescriptor pieceDescriptor) {
        super(i2, i3, buildInitSB(bArr, pieceDescriptor));
        this._usesUnicode = pieceDescriptor.isUnicode();
        this._pd = pieceDescriptor;
        int length = ((CharSequence) this._buf).length();
        if (i3 - i2 != length) {
            throw new IllegalStateException(a.a(a.a("Told we're for characters ", i2, " -> ", i3, ", but actually covers "), length, " characters!"));
        } else if (i3 < i2) {
            throw new IllegalStateException(a.a("Told we're of negative size! start=", i2, " end=", i3));
        }
    }
}
