package org.apache.poi.hwpf.model.types;

import b.b.a.a.a;
import org.apache.poi.util.BitField;
import org.apache.poi.util.Internal;
import org.apache.poi.util.LittleEndian;

@Internal
public abstract class BKFAbstractType {
    public static BitField fCol = new BitField(32768);
    public static BitField fPub = new BitField(128);
    public static BitField itcFirst = new BitField(127);
    public static BitField itcLim = new BitField(32512);
    public short field_1_ibkl;
    public short field_2_bkf_flags;

    public static int getSize() {
        return 4;
    }

    public void fillFields(byte[] bArr, int i2) {
        this.field_1_ibkl = LittleEndian.getShort(bArr, i2 + 0);
        this.field_2_bkf_flags = LittleEndian.getShort(bArr, i2 + 2);
    }

    public short getBkf_flags() {
        return this.field_2_bkf_flags;
    }

    public short getIbkl() {
        return this.field_1_ibkl;
    }

    public byte getItcFirst() {
        return (byte) itcFirst.getValue(this.field_2_bkf_flags);
    }

    public byte getItcLim() {
        return (byte) itcLim.getValue(this.field_2_bkf_flags);
    }

    public boolean isFCol() {
        return fCol.isSet(this.field_2_bkf_flags);
    }

    public boolean isFPub() {
        return fPub.isSet(this.field_2_bkf_flags);
    }

    public void serialize(byte[] bArr, int i2) {
        LittleEndian.putShort(bArr, i2 + 0, this.field_1_ibkl);
        LittleEndian.putShort(bArr, i2 + 2, this.field_2_bkf_flags);
    }

    public void setBkf_flags(short s) {
        this.field_2_bkf_flags = s;
    }

    public void setFCol(boolean z) {
        this.field_2_bkf_flags = (short) fCol.setBoolean(this.field_2_bkf_flags, z);
    }

    public void setFPub(boolean z) {
        this.field_2_bkf_flags = (short) fPub.setBoolean(this.field_2_bkf_flags, z);
    }

    public void setIbkl(short s) {
        this.field_1_ibkl = s;
    }

    public void setItcFirst(byte b2) {
        this.field_2_bkf_flags = (short) itcFirst.setValue(this.field_2_bkf_flags, b2);
    }

    public void setItcLim(byte b2) {
        this.field_2_bkf_flags = (short) itcLim.setValue(this.field_2_bkf_flags, b2);
    }

    public String toString() {
        StringBuilder d2 = a.d("[BKF]\n", "    .ibkl                 = ", " (");
        d2.append((int) getIbkl());
        d2.append(" )\n");
        d2.append("    .bkf_flags            = ");
        d2.append(" (");
        d2.append((int) getBkf_flags());
        d2.append(" )\n");
        d2.append("         .itcFirst                 = ");
        d2.append((int) getItcFirst());
        d2.append('\n');
        d2.append("         .fPub                     = ");
        d2.append(isFPub());
        d2.append('\n');
        d2.append("         .itcLim                   = ");
        d2.append((int) getItcLim());
        d2.append('\n');
        d2.append("         .fCol                     = ");
        d2.append(isFCol());
        d2.append('\n');
        d2.append("[/BKF]\n");
        return d2.toString();
    }
}
