package org.apache.poi.hwpf.model.types;

import b.b.a.a.a;
import java.util.Arrays;
import org.apache.poi.hwpf.model.Colorref;
import org.apache.poi.hwpf.model.Hyphenation;
import org.apache.poi.hwpf.usermodel.BorderCode;
import org.apache.poi.hwpf.usermodel.DateAndTime;
import org.apache.poi.hwpf.usermodel.ShadingDescriptor;
import org.apache.poi.ss.util.NormalisedDecimal;
import org.apache.poi.util.BitField;
import org.apache.poi.util.Internal;
import org.apache.xmlbeans.impl.common.ConcurrentReaderHashMap;

@Internal
public abstract class CHPAbstractType {
    public static final byte ISS_NONE = 0;
    public static final byte ISS_SUBSCRIPTED = 2;
    public static final byte ISS_SUPERSCRIPTED = 1;
    public static final byte KCD_CIRCLE = 3;
    public static final byte KCD_COMMA = 2;
    public static final byte KCD_DOT = 1;
    public static final byte KCD_NON = 0;
    public static final byte KCD_UNDER_DOT = 4;
    public static final byte KUL_BY_WORD = 2;
    public static final byte KUL_DASH = 7;
    public static final byte KUL_DASHED_HEAVY = 23;
    public static final byte KUL_DASH_LONG = 39;
    public static final byte KUL_DASH_LONG_HEAVY = 55;
    public static final byte KUL_DOT = 8;
    public static final byte KUL_DOTTED = 4;
    public static final byte KUL_DOTTED_HEAVY = 20;
    public static final byte KUL_DOT_DASH = 9;
    public static final byte KUL_DOT_DASH_HEAVY = 25;
    public static final byte KUL_DOT_DOT_DASH = 10;
    public static final byte KUL_DOT_DOT_DASH_HEAVY = 26;
    public static final byte KUL_DOUBLE = 3;
    public static final byte KUL_HIDDEN = 5;
    public static final byte KUL_NONE = 0;
    public static final byte KUL_SINGLE = 1;
    public static final byte KUL_THICK = 6;
    public static final byte KUL_WAVE = 11;
    public static final byte KUL_WAVE_DOUBLE = 43;
    public static final byte KUL_WAVE_HEAVY = 27;
    public static final byte LBRCRJ_BOTH = 3;
    public static final byte LBRCRJ_LEFT = 1;
    public static final byte LBRCRJ_NONE = 0;
    public static final byte LBRCRJ_RIGHT = 2;
    public static final byte SFXTTEXT_BACKGROUND_BLINK = 2;
    public static final byte SFXTTEXT_LAS_VEGAS_LIGHTS = 1;
    public static final byte SFXTTEXT_MARCHING_ANTS = 4;
    public static final byte SFXTTEXT_MARCHING_RED_ANTS = 5;
    public static final byte SFXTTEXT_NO = 0;
    public static final byte SFXTTEXT_SHIMMER = 6;
    public static final byte SFXTTEXT_SPARKLE_TEXT = 3;
    public static final BitField fBiDi = new BitField(4194304);
    public static final BitField fBold = new BitField(1);
    public static final BitField fBoldBi = new BitField(1048576);
    public static final BitField fBoldOther = new BitField(33554432);
    public static final BitField fCalc = new BitField(ConcurrentReaderHashMap.MAXIMUM_CAPACITY);
    public static final BitField fCaps = new BitField(64);
    public static final BitField fCellFitText = new BitField(64);
    public static final BitField fChsDiff = new BitField(1);
    public static final BitField fComplexScripts = new BitField(1048576);
    public static final BitField fDStrike = new BitField(262144);
    public static final BitField fData = new BitField(16384);
    public static final BitField fEmboss = new BitField(65536);
    public static final BitField fFitText = new BitField(536870912);
    public static final BitField fFldVanish = new BitField(16);
    public static final BitField fFmtLineProp = new BitField(Integer.MIN_VALUE);
    public static final BitField fHighlight = new BitField(32);
    public static final BitField fIcoBi = new BitField(NormalisedDecimal.FRAC_HALF);
    public static final BitField fImprint = new BitField(131072);
    public static final BitField fItalic = new BitField(2);
    public static final BitField fItalicBi = new BitField(2097152);
    public static final BitField fItalicOther = new BitField(67108864);
    public static final BitField fKumimoji = new BitField(1024);
    public static final BitField fLSFitText = new BitField(4096);
    public static final BitField fLowerCase = new BitField(8192);
    public static final BitField fMacChs = new BitField(32);
    public static final BitField fNoProof = new BitField(134217728);
    public static final BitField fNonGlyph = new BitField(16777216);
    public static final BitField fObj = new BitField(2048);
    public static final BitField fOle2 = new BitField(32768);
    public static final BitField fOutline = new BitField(8);
    public static final BitField fRMark = new BitField(256);
    public static final BitField fRMarkDel = new BitField(4);
    public static final BitField fRuby = new BitField(2048);
    public static final BitField fShadow = new BitField(4096);
    public static final BitField fSmallCaps = new BitField(32);
    public static final BitField fSpec = new BitField(512);
    public static final BitField fStrike = new BitField(1024);
    public static final BitField fTNY = new BitField(256);
    public static final BitField fTNYCompress = new BitField(16);
    public static final BitField fTNYFetchTxm = new BitField(32);
    public static final BitField fUsePgsuSettings = new BitField(524288);
    public static final BitField fVanish = new BitField(128);
    public static final BitField fWarichu = new BitField(512);
    public static final BitField fWarichuNoOpenBracket = new BitField(8);
    public static final BitField fWebHidden = new BitField(268435456);
    public static final BitField iWarichuBracket = new BitField(7);
    public static final BitField icoHighlight = new BitField(31);
    public static final BitField itypFELayout = new BitField(255);
    public static final BitField spare = new BitField(57344);
    public static final BitField unused = new BitField(128);
    public int field_10_pctCharWidth;
    public int field_11_lidDefault = 1024;
    public int field_12_lidFE = 1024;
    public byte field_13_kcd;
    public boolean field_14_fUndetermine;
    public byte field_15_iss;
    public boolean field_16_fSpecSymbol;
    public byte field_17_idct;
    public byte field_18_idctHint;
    public byte field_19_kul;
    public int field_1_grpfChp;
    public Hyphenation field_20_hresi = new Hyphenation();
    public int field_21_hpsKern;
    public short field_22_hpsPos;
    public ShadingDescriptor field_23_shd = new ShadingDescriptor();
    public BorderCode field_24_brc = new BorderCode();
    public int field_25_ibstRMark;
    public byte field_26_sfxtText;
    public boolean field_27_fDblBdr;
    public boolean field_28_fBorderWS;
    public short field_29_ufel;
    public int field_2_hps = 20;
    public byte field_30_copt;
    public int field_31_hpsAsci;
    public int field_32_hpsFE;
    public int field_33_hpsBi;
    public int field_34_ftcSym;
    public int field_35_xchSym;
    public int field_36_fcPic = -1;
    public int field_37_fcObj;
    public int field_38_lTagObj;
    public int field_39_fcData;
    public int field_3_ftcAscii;
    public Hyphenation field_40_hresiOld = new Hyphenation();
    public int field_41_ibstRMarkDel;
    public DateAndTime field_42_dttmRMark = new DateAndTime();
    public DateAndTime field_43_dttmRMarkDel = new DateAndTime();
    public int field_44_istd = 10;
    public int field_45_idslRMReason;
    public int field_46_idslReasonDel;
    public int field_47_cpg;
    public short field_48_Highlight;
    public short field_49_CharsetFlags;
    public int field_4_ftcFE;
    public short field_50_chse;
    public boolean field_51_fPropRMark;
    public int field_52_ibstPropRMark;
    public DateAndTime field_53_dttmPropRMark = new DateAndTime();
    public boolean field_54_fConflictOrig;
    public boolean field_55_fConflictOtherDel;
    public int field_56_wConflict;
    public int field_57_IbstConflict;
    public DateAndTime field_58_dttmConflict = new DateAndTime();
    public boolean field_59_fDispFldRMark;
    public int field_5_ftcOther;
    public int field_60_ibstDispFldRMark;
    public DateAndTime field_61_dttmDispFldRMark = new DateAndTime();
    public byte[] field_62_xstDispFldRMark = new byte[32];
    public int field_63_fcObjp;
    public byte field_64_lbrCRJ;
    public boolean field_65_fSpecVanish;
    public boolean field_66_fHasOldProps;
    public boolean field_67_fSdtVanish;
    public int field_68_wCharScale = 100;
    public int field_6_ftcBi;
    public int field_7_dxaSpace;
    public Colorref field_8_cv = new Colorref();
    public byte field_9_ico;

    public boolean equals(Object obj) {
        if (this == obj) {
            return true;
        }
        if (obj == null || getClass() != obj.getClass()) {
            return false;
        }
        CHPAbstractType cHPAbstractType = (CHPAbstractType) obj;
        if (this.field_1_grpfChp != cHPAbstractType.field_1_grpfChp || this.field_2_hps != cHPAbstractType.field_2_hps || this.field_3_ftcAscii != cHPAbstractType.field_3_ftcAscii || this.field_4_ftcFE != cHPAbstractType.field_4_ftcFE || this.field_5_ftcOther != cHPAbstractType.field_5_ftcOther || this.field_6_ftcBi != cHPAbstractType.field_6_ftcBi || this.field_7_dxaSpace != cHPAbstractType.field_7_dxaSpace) {
            return false;
        }
        Colorref colorref = this.field_8_cv;
        if (colorref == null) {
            if (cHPAbstractType.field_8_cv != null) {
                return false;
            }
        } else if (!colorref.equals(cHPAbstractType.field_8_cv)) {
            return false;
        }
        if (this.field_9_ico != cHPAbstractType.field_9_ico || this.field_10_pctCharWidth != cHPAbstractType.field_10_pctCharWidth || this.field_11_lidDefault != cHPAbstractType.field_11_lidDefault || this.field_12_lidFE != cHPAbstractType.field_12_lidFE || this.field_13_kcd != cHPAbstractType.field_13_kcd || this.field_14_fUndetermine != cHPAbstractType.field_14_fUndetermine || this.field_15_iss != cHPAbstractType.field_15_iss || this.field_16_fSpecSymbol != cHPAbstractType.field_16_fSpecSymbol || this.field_17_idct != cHPAbstractType.field_17_idct || this.field_18_idctHint != cHPAbstractType.field_18_idctHint || this.field_19_kul != cHPAbstractType.field_19_kul) {
            return false;
        }
        Hyphenation hyphenation = this.field_20_hresi;
        if (hyphenation == null) {
            if (cHPAbstractType.field_20_hresi != null) {
                return false;
            }
        } else if (!hyphenation.equals(cHPAbstractType.field_20_hresi)) {
            return false;
        }
        if (this.field_21_hpsKern != cHPAbstractType.field_21_hpsKern || this.field_22_hpsPos != cHPAbstractType.field_22_hpsPos) {
            return false;
        }
        ShadingDescriptor shadingDescriptor = this.field_23_shd;
        if (shadingDescriptor == null) {
            if (cHPAbstractType.field_23_shd != null) {
                return false;
            }
        } else if (!shadingDescriptor.equals(cHPAbstractType.field_23_shd)) {
            return false;
        }
        BorderCode borderCode = this.field_24_brc;
        if (borderCode == null) {
            if (cHPAbstractType.field_24_brc != null) {
                return false;
            }
        } else if (!borderCode.equals(cHPAbstractType.field_24_brc)) {
            return false;
        }
        if (this.field_25_ibstRMark != cHPAbstractType.field_25_ibstRMark || this.field_26_sfxtText != cHPAbstractType.field_26_sfxtText || this.field_27_fDblBdr != cHPAbstractType.field_27_fDblBdr || this.field_28_fBorderWS != cHPAbstractType.field_28_fBorderWS || this.field_29_ufel != cHPAbstractType.field_29_ufel || this.field_30_copt != cHPAbstractType.field_30_copt || this.field_31_hpsAsci != cHPAbstractType.field_31_hpsAsci || this.field_32_hpsFE != cHPAbstractType.field_32_hpsFE || this.field_33_hpsBi != cHPAbstractType.field_33_hpsBi || this.field_34_ftcSym != cHPAbstractType.field_34_ftcSym || this.field_35_xchSym != cHPAbstractType.field_35_xchSym || this.field_36_fcPic != cHPAbstractType.field_36_fcPic || this.field_37_fcObj != cHPAbstractType.field_37_fcObj || this.field_38_lTagObj != cHPAbstractType.field_38_lTagObj || this.field_39_fcData != cHPAbstractType.field_39_fcData) {
            return false;
        }
        Hyphenation hyphenation2 = this.field_40_hresiOld;
        if (hyphenation2 == null) {
            if (cHPAbstractType.field_40_hresiOld != null) {
                return false;
            }
        } else if (!hyphenation2.equals(cHPAbstractType.field_40_hresiOld)) {
            return false;
        }
        if (this.field_41_ibstRMarkDel != cHPAbstractType.field_41_ibstRMarkDel) {
            return false;
        }
        DateAndTime dateAndTime = this.field_42_dttmRMark;
        if (dateAndTime == null) {
            if (cHPAbstractType.field_42_dttmRMark != null) {
                return false;
            }
        } else if (!dateAndTime.equals(cHPAbstractType.field_42_dttmRMark)) {
            return false;
        }
        DateAndTime dateAndTime2 = this.field_43_dttmRMarkDel;
        if (dateAndTime2 == null) {
            if (cHPAbstractType.field_43_dttmRMarkDel != null) {
                return false;
            }
        } else if (!dateAndTime2.equals(cHPAbstractType.field_43_dttmRMarkDel)) {
            return false;
        }
        if (this.field_44_istd != cHPAbstractType.field_44_istd || this.field_45_idslRMReason != cHPAbstractType.field_45_idslRMReason || this.field_46_idslReasonDel != cHPAbstractType.field_46_idslReasonDel || this.field_47_cpg != cHPAbstractType.field_47_cpg || this.field_48_Highlight != cHPAbstractType.field_48_Highlight || this.field_49_CharsetFlags != cHPAbstractType.field_49_CharsetFlags || this.field_50_chse != cHPAbstractType.field_50_chse || this.field_51_fPropRMark != cHPAbstractType.field_51_fPropRMark || this.field_52_ibstPropRMark != cHPAbstractType.field_52_ibstPropRMark) {
            return false;
        }
        DateAndTime dateAndTime3 = this.field_53_dttmPropRMark;
        if (dateAndTime3 == null) {
            if (cHPAbstractType.field_53_dttmPropRMark != null) {
                return false;
            }
        } else if (!dateAndTime3.equals(cHPAbstractType.field_53_dttmPropRMark)) {
            return false;
        }
        if (this.field_54_fConflictOrig != cHPAbstractType.field_54_fConflictOrig || this.field_55_fConflictOtherDel != cHPAbstractType.field_55_fConflictOtherDel || this.field_56_wConflict != cHPAbstractType.field_56_wConflict || this.field_57_IbstConflict != cHPAbstractType.field_57_IbstConflict) {
            return false;
        }
        DateAndTime dateAndTime4 = this.field_58_dttmConflict;
        if (dateAndTime4 == null) {
            if (cHPAbstractType.field_58_dttmConflict != null) {
                return false;
            }
        } else if (!dateAndTime4.equals(cHPAbstractType.field_58_dttmConflict)) {
            return false;
        }
        if (this.field_59_fDispFldRMark != cHPAbstractType.field_59_fDispFldRMark || this.field_60_ibstDispFldRMark != cHPAbstractType.field_60_ibstDispFldRMark) {
            return false;
        }
        DateAndTime dateAndTime5 = this.field_61_dttmDispFldRMark;
        if (dateAndTime5 == null) {
            if (cHPAbstractType.field_61_dttmDispFldRMark != null) {
                return false;
            }
        } else if (!dateAndTime5.equals(cHPAbstractType.field_61_dttmDispFldRMark)) {
            return false;
        }
        return Arrays.equals(this.field_62_xstDispFldRMark, cHPAbstractType.field_62_xstDispFldRMark) && this.field_63_fcObjp == cHPAbstractType.field_63_fcObjp && this.field_64_lbrCRJ == cHPAbstractType.field_64_lbrCRJ && this.field_65_fSpecVanish == cHPAbstractType.field_65_fSpecVanish && this.field_66_fHasOldProps == cHPAbstractType.field_66_fHasOldProps && this.field_67_fSdtVanish == cHPAbstractType.field_67_fSdtVanish && this.field_68_wCharScale == cHPAbstractType.field_68_wCharScale;
    }

    @Internal
    public BorderCode getBrc() {
        return this.field_24_brc;
    }

    @Internal
    public short getCharsetFlags() {
        return this.field_49_CharsetFlags;
    }

    @Internal
    public short getChse() {
        return this.field_50_chse;
    }

    @Internal
    public byte getCopt() {
        return this.field_30_copt;
    }

    @Internal
    public int getCpg() {
        return this.field_47_cpg;
    }

    @Internal
    public Colorref getCv() {
        return this.field_8_cv;
    }

    @Internal
    public DateAndTime getDttmConflict() {
        return this.field_58_dttmConflict;
    }

    @Internal
    public DateAndTime getDttmDispFldRMark() {
        return this.field_61_dttmDispFldRMark;
    }

    @Internal
    public DateAndTime getDttmPropRMark() {
        return this.field_53_dttmPropRMark;
    }

    @Internal
    public DateAndTime getDttmRMark() {
        return this.field_42_dttmRMark;
    }

    @Internal
    public DateAndTime getDttmRMarkDel() {
        return this.field_43_dttmRMarkDel;
    }

    @Internal
    public int getDxaSpace() {
        return this.field_7_dxaSpace;
    }

    @Internal
    public boolean getFBorderWS() {
        return this.field_28_fBorderWS;
    }

    @Internal
    public boolean getFConflictOrig() {
        return this.field_54_fConflictOrig;
    }

    @Internal
    public boolean getFConflictOtherDel() {
        return this.field_55_fConflictOtherDel;
    }

    @Internal
    public boolean getFDblBdr() {
        return this.field_27_fDblBdr;
    }

    @Internal
    public boolean getFDispFldRMark() {
        return this.field_59_fDispFldRMark;
    }

    @Internal
    public boolean getFHasOldProps() {
        return this.field_66_fHasOldProps;
    }

    @Internal
    public boolean getFPropRMark() {
        return this.field_51_fPropRMark;
    }

    @Internal
    public boolean getFSdtVanish() {
        return this.field_67_fSdtVanish;
    }

    @Internal
    public boolean getFSpecSymbol() {
        return this.field_16_fSpecSymbol;
    }

    @Internal
    public boolean getFSpecVanish() {
        return this.field_65_fSpecVanish;
    }

    @Internal
    public boolean getFUndetermine() {
        return this.field_14_fUndetermine;
    }

    @Internal
    public int getFcData() {
        return this.field_39_fcData;
    }

    @Internal
    public int getFcObj() {
        return this.field_37_fcObj;
    }

    @Internal
    public int getFcObjp() {
        return this.field_63_fcObjp;
    }

    @Internal
    public int getFcPic() {
        return this.field_36_fcPic;
    }

    @Internal
    public int getFtcAscii() {
        return this.field_3_ftcAscii;
    }

    @Internal
    public int getFtcBi() {
        return this.field_6_ftcBi;
    }

    @Internal
    public int getFtcFE() {
        return this.field_4_ftcFE;
    }

    @Internal
    public int getFtcOther() {
        return this.field_5_ftcOther;
    }

    @Internal
    public int getFtcSym() {
        return this.field_34_ftcSym;
    }

    @Internal
    public int getGrpfChp() {
        return this.field_1_grpfChp;
    }

    @Internal
    public short getHighlight() {
        return this.field_48_Highlight;
    }

    @Internal
    public int getHps() {
        return this.field_2_hps;
    }

    @Internal
    public int getHpsAsci() {
        return this.field_31_hpsAsci;
    }

    @Internal
    public int getHpsBi() {
        return this.field_33_hpsBi;
    }

    @Internal
    public int getHpsFE() {
        return this.field_32_hpsFE;
    }

    @Internal
    public int getHpsKern() {
        return this.field_21_hpsKern;
    }

    @Internal
    public short getHpsPos() {
        return this.field_22_hpsPos;
    }

    @Internal
    public Hyphenation getHresi() {
        return this.field_20_hresi;
    }

    @Internal
    public Hyphenation getHresiOld() {
        return this.field_40_hresiOld;
    }

    @Internal
    public byte getIWarichuBracket() {
        return (byte) iWarichuBracket.getValue(this.field_30_copt);
    }

    @Internal
    public int getIbstConflict() {
        return this.field_57_IbstConflict;
    }

    @Internal
    public int getIbstDispFldRMark() {
        return this.field_60_ibstDispFldRMark;
    }

    @Internal
    public int getIbstPropRMark() {
        return this.field_52_ibstPropRMark;
    }

    @Internal
    public int getIbstRMark() {
        return this.field_25_ibstRMark;
    }

    @Internal
    public int getIbstRMarkDel() {
        return this.field_41_ibstRMarkDel;
    }

    @Internal
    public byte getIco() {
        return this.field_9_ico;
    }

    @Internal
    public byte getIcoHighlight() {
        return (byte) icoHighlight.getValue(this.field_48_Highlight);
    }

    @Internal
    public byte getIdct() {
        return this.field_17_idct;
    }

    @Internal
    public byte getIdctHint() {
        return this.field_18_idctHint;
    }

    @Internal
    public int getIdslRMReason() {
        return this.field_45_idslRMReason;
    }

    @Internal
    public int getIdslReasonDel() {
        return this.field_46_idslReasonDel;
    }

    @Internal
    public byte getIss() {
        return this.field_15_iss;
    }

    @Internal
    public int getIstd() {
        return this.field_44_istd;
    }

    @Internal
    public short getItypFELayout() {
        return (short) itypFELayout.getValue(this.field_29_ufel);
    }

    @Internal
    public byte getKcd() {
        return this.field_13_kcd;
    }

    @Internal
    public byte getKul() {
        return this.field_19_kul;
    }

    @Internal
    public int getLTagObj() {
        return this.field_38_lTagObj;
    }

    @Internal
    public byte getLbrCRJ() {
        return this.field_64_lbrCRJ;
    }

    @Internal
    public int getLidDefault() {
        return this.field_11_lidDefault;
    }

    @Internal
    public int getLidFE() {
        return this.field_12_lidFE;
    }

    @Internal
    public int getPctCharWidth() {
        return this.field_10_pctCharWidth;
    }

    @Internal
    public byte getSfxtText() {
        return this.field_26_sfxtText;
    }

    @Internal
    public ShadingDescriptor getShd() {
        return this.field_23_shd;
    }

    @Internal
    public byte getSpare() {
        return (byte) spare.getValue(this.field_29_ufel);
    }

    @Internal
    public short getUfel() {
        return this.field_29_ufel;
    }

    @Internal
    public int getWCharScale() {
        return this.field_68_wCharScale;
    }

    @Internal
    public int getWConflict() {
        return this.field_56_wConflict;
    }

    @Internal
    public int getXchSym() {
        return this.field_35_xchSym;
    }

    @Internal
    public byte[] getXstDispFldRMark() {
        return this.field_62_xstDispFldRMark;
    }

    public int hashCode() {
        int i2 = (((((((((((((this.field_1_grpfChp + 31) * 31) + this.field_2_hps) * 31) + this.field_3_ftcAscii) * 31) + this.field_4_ftcFE) * 31) + this.field_5_ftcOther) * 31) + this.field_6_ftcBi) * 31) + this.field_7_dxaSpace) * 31;
        Colorref colorref = this.field_8_cv;
        int i3 = 0;
        int i4 = 1231;
        int hashCode = (((((((((((((((((((((((i2 + (colorref == null ? 0 : colorref.hashCode())) * 31) + this.field_9_ico) * 31) + this.field_10_pctCharWidth) * 31) + this.field_11_lidDefault) * 31) + this.field_12_lidFE) * 31) + this.field_13_kcd) * 31) + (this.field_14_fUndetermine ? 1231 : 1237)) * 31) + this.field_15_iss) * 31) + (this.field_16_fSpecSymbol ? 1231 : 1237)) * 31) + this.field_17_idct) * 31) + this.field_18_idctHint) * 31) + this.field_19_kul) * 31;
        Hyphenation hyphenation = this.field_20_hresi;
        int hashCode2 = (((((hashCode + (hyphenation == null ? 0 : hyphenation.hashCode())) * 31) + this.field_21_hpsKern) * 31) + this.field_22_hpsPos) * 31;
        ShadingDescriptor shadingDescriptor = this.field_23_shd;
        int hashCode3 = (hashCode2 + (shadingDescriptor == null ? 0 : shadingDescriptor.hashCode())) * 31;
        BorderCode borderCode = this.field_24_brc;
        int hashCode4 = (((((((((((((((((((((((((((((((hashCode3 + (borderCode == null ? 0 : borderCode.hashCode())) * 31) + this.field_25_ibstRMark) * 31) + this.field_26_sfxtText) * 31) + (this.field_27_fDblBdr ? 1231 : 1237)) * 31) + (this.field_28_fBorderWS ? 1231 : 1237)) * 31) + this.field_29_ufel) * 31) + this.field_30_copt) * 31) + this.field_31_hpsAsci) * 31) + this.field_32_hpsFE) * 31) + this.field_33_hpsBi) * 31) + this.field_34_ftcSym) * 31) + this.field_35_xchSym) * 31) + this.field_36_fcPic) * 31) + this.field_37_fcObj) * 31) + this.field_38_lTagObj) * 31) + this.field_39_fcData) * 31;
        Hyphenation hyphenation2 = this.field_40_hresiOld;
        int hashCode5 = (((hashCode4 + (hyphenation2 == null ? 0 : hyphenation2.hashCode())) * 31) + this.field_41_ibstRMarkDel) * 31;
        DateAndTime dateAndTime = this.field_42_dttmRMark;
        int hashCode6 = (hashCode5 + (dateAndTime == null ? 0 : dateAndTime.hashCode())) * 31;
        DateAndTime dateAndTime2 = this.field_43_dttmRMarkDel;
        int hashCode7 = (((((((((((((((((((hashCode6 + (dateAndTime2 == null ? 0 : dateAndTime2.hashCode())) * 31) + this.field_44_istd) * 31) + this.field_45_idslRMReason) * 31) + this.field_46_idslReasonDel) * 31) + this.field_47_cpg) * 31) + this.field_48_Highlight) * 31) + this.field_49_CharsetFlags) * 31) + this.field_50_chse) * 31) + (this.field_51_fPropRMark ? 1231 : 1237)) * 31) + this.field_52_ibstPropRMark) * 31;
        DateAndTime dateAndTime3 = this.field_53_dttmPropRMark;
        int hashCode8 = (((((((((hashCode7 + (dateAndTime3 == null ? 0 : dateAndTime3.hashCode())) * 31) + (this.field_54_fConflictOrig ? 1231 : 1237)) * 31) + (this.field_55_fConflictOtherDel ? 1231 : 1237)) * 31) + this.field_56_wConflict) * 31) + this.field_57_IbstConflict) * 31;
        DateAndTime dateAndTime4 = this.field_58_dttmConflict;
        int hashCode9 = (((((hashCode8 + (dateAndTime4 == null ? 0 : dateAndTime4.hashCode())) * 31) + (this.field_59_fDispFldRMark ? 1231 : 1237)) * 31) + this.field_60_ibstDispFldRMark) * 31;
        DateAndTime dateAndTime5 = this.field_61_dttmDispFldRMark;
        if (dateAndTime5 != null) {
            i3 = dateAndTime5.hashCode();
        }
        int hashCode10 = (((((((((Arrays.hashCode(this.field_62_xstDispFldRMark) + ((hashCode9 + i3) * 31)) * 31) + this.field_63_fcObjp) * 31) + this.field_64_lbrCRJ) * 31) + (this.field_65_fSpecVanish ? 1231 : 1237)) * 31) + (this.field_66_fHasOldProps ? 1231 : 1237)) * 31;
        if (!this.field_67_fSdtVanish) {
            i4 = 1237;
        }
        return ((hashCode10 + i4) * 31) + this.field_68_wCharScale;
    }

    @Internal
    public boolean isFBiDi() {
        return fBiDi.isSet(this.field_1_grpfChp);
    }

    @Internal
    public boolean isFBold() {
        return fBold.isSet(this.field_1_grpfChp);
    }

    @Internal
    public boolean isFBoldBi() {
        return fBoldBi.isSet(this.field_1_grpfChp);
    }

    @Internal
    public boolean isFBoldOther() {
        return fBoldOther.isSet(this.field_1_grpfChp);
    }

    @Internal
    public boolean isFCalc() {
        return fCalc.isSet(this.field_1_grpfChp);
    }

    @Internal
    public boolean isFCaps() {
        return fCaps.isSet(this.field_1_grpfChp);
    }

    @Internal
    public boolean isFCellFitText() {
        return fCellFitText.isSet(this.field_30_copt);
    }

    @Internal
    public boolean isFChsDiff() {
        return fChsDiff.isSet(this.field_49_CharsetFlags);
    }

    @Internal
    public boolean isFComplexScripts() {
        return fComplexScripts.isSet(this.field_1_grpfChp);
    }

    @Internal
    public boolean isFDStrike() {
        return fDStrike.isSet(this.field_1_grpfChp);
    }

    @Internal
    public boolean isFData() {
        return fData.isSet(this.field_1_grpfChp);
    }

    @Internal
    public boolean isFEmboss() {
        return fEmboss.isSet(this.field_1_grpfChp);
    }

    @Internal
    public boolean isFFitText() {
        return fFitText.isSet(this.field_1_grpfChp);
    }

    @Internal
    public boolean isFFldVanish() {
        return fFldVanish.isSet(this.field_1_grpfChp);
    }

    @Internal
    public boolean isFFmtLineProp() {
        return fFmtLineProp.isSet(this.field_1_grpfChp);
    }

    @Internal
    public boolean isFHighlight() {
        return fHighlight.isSet(this.field_48_Highlight);
    }

    @Internal
    public boolean isFIcoBi() {
        return fIcoBi.isSet(this.field_1_grpfChp);
    }

    @Internal
    public boolean isFImprint() {
        return fImprint.isSet(this.field_1_grpfChp);
    }

    @Internal
    public boolean isFItalic() {
        return fItalic.isSet(this.field_1_grpfChp);
    }

    @Internal
    public boolean isFItalicBi() {
        return fItalicBi.isSet(this.field_1_grpfChp);
    }

    @Internal
    public boolean isFItalicOther() {
        return fItalicOther.isSet(this.field_1_grpfChp);
    }

    @Internal
    public boolean isFKumimoji() {
        return fKumimoji.isSet(this.field_29_ufel);
    }

    @Internal
    public boolean isFLSFitText() {
        return fLSFitText.isSet(this.field_29_ufel);
    }

    @Internal
    public boolean isFLowerCase() {
        return fLowerCase.isSet(this.field_1_grpfChp);
    }

    @Internal
    public boolean isFMacChs() {
        return fMacChs.isSet(this.field_49_CharsetFlags);
    }

    @Internal
    public boolean isFNoProof() {
        return fNoProof.isSet(this.field_1_grpfChp);
    }

    @Internal
    public boolean isFNonGlyph() {
        return fNonGlyph.isSet(this.field_1_grpfChp);
    }

    @Internal
    public boolean isFObj() {
        return fObj.isSet(this.field_1_grpfChp);
    }

    @Internal
    public boolean isFOle2() {
        return fOle2.isSet(this.field_1_grpfChp);
    }

    @Internal
    public boolean isFOutline() {
        return fOutline.isSet(this.field_1_grpfChp);
    }

    @Internal
    public boolean isFRMark() {
        return fRMark.isSet(this.field_1_grpfChp);
    }

    @Internal
    public boolean isFRMarkDel() {
        return fRMarkDel.isSet(this.field_1_grpfChp);
    }

    @Internal
    public boolean isFRuby() {
        return fRuby.isSet(this.field_29_ufel);
    }

    @Internal
    public boolean isFShadow() {
        return fShadow.isSet(this.field_1_grpfChp);
    }

    @Internal
    public boolean isFSmallCaps() {
        return fSmallCaps.isSet(this.field_1_grpfChp);
    }

    @Internal
    public boolean isFSpec() {
        return fSpec.isSet(this.field_1_grpfChp);
    }

    @Internal
    public boolean isFStrike() {
        return fStrike.isSet(this.field_1_grpfChp);
    }

    @Internal
    public boolean isFTNY() {
        return fTNY.isSet(this.field_29_ufel);
    }

    @Internal
    public boolean isFTNYCompress() {
        return fTNYCompress.isSet(this.field_30_copt);
    }

    @Internal
    public boolean isFTNYFetchTxm() {
        return fTNYFetchTxm.isSet(this.field_30_copt);
    }

    @Internal
    public boolean isFUsePgsuSettings() {
        return fUsePgsuSettings.isSet(this.field_1_grpfChp);
    }

    @Internal
    public boolean isFVanish() {
        return fVanish.isSet(this.field_1_grpfChp);
    }

    @Internal
    public boolean isFWarichu() {
        return fWarichu.isSet(this.field_29_ufel);
    }

    @Internal
    public boolean isFWarichuNoOpenBracket() {
        return fWarichuNoOpenBracket.isSet(this.field_30_copt);
    }

    @Internal
    public boolean isFWebHidden() {
        return fWebHidden.isSet(this.field_1_grpfChp);
    }

    @Internal
    public boolean isUnused() {
        return unused.isSet(this.field_30_copt);
    }

    @Internal
    public void setBrc(BorderCode borderCode) {
        this.field_24_brc = borderCode;
    }

    @Internal
    public void setCharsetFlags(short s) {
        this.field_49_CharsetFlags = s;
    }

    @Internal
    public void setChse(short s) {
        this.field_50_chse = s;
    }

    @Internal
    public void setCopt(byte b2) {
        this.field_30_copt = b2;
    }

    @Internal
    public void setCpg(int i2) {
        this.field_47_cpg = i2;
    }

    @Internal
    public void setCv(Colorref colorref) {
        this.field_8_cv = colorref;
    }

    @Internal
    public void setDttmConflict(DateAndTime dateAndTime) {
        this.field_58_dttmConflict = dateAndTime;
    }

    @Internal
    public void setDttmDispFldRMark(DateAndTime dateAndTime) {
        this.field_61_dttmDispFldRMark = dateAndTime;
    }

    @Internal
    public void setDttmPropRMark(DateAndTime dateAndTime) {
        this.field_53_dttmPropRMark = dateAndTime;
    }

    @Internal
    public void setDttmRMark(DateAndTime dateAndTime) {
        this.field_42_dttmRMark = dateAndTime;
    }

    @Internal
    public void setDttmRMarkDel(DateAndTime dateAndTime) {
        this.field_43_dttmRMarkDel = dateAndTime;
    }

    @Internal
    public void setDxaSpace(int i2) {
        this.field_7_dxaSpace = i2;
    }

    @Internal
    public void setFBiDi(boolean z) {
        this.field_1_grpfChp = fBiDi.setBoolean(this.field_1_grpfChp, z);
    }

    @Internal
    public void setFBold(boolean z) {
        this.field_1_grpfChp = fBold.setBoolean(this.field_1_grpfChp, z);
    }

    @Internal
    public void setFBoldBi(boolean z) {
        this.field_1_grpfChp = fBoldBi.setBoolean(this.field_1_grpfChp, z);
    }

    @Internal
    public void setFBoldOther(boolean z) {
        this.field_1_grpfChp = fBoldOther.setBoolean(this.field_1_grpfChp, z);
    }

    @Internal
    public void setFBorderWS(boolean z) {
        this.field_28_fBorderWS = z;
    }

    @Internal
    public void setFCalc(boolean z) {
        this.field_1_grpfChp = fCalc.setBoolean(this.field_1_grpfChp, z);
    }

    @Internal
    public void setFCaps(boolean z) {
        this.field_1_grpfChp = fCaps.setBoolean(this.field_1_grpfChp, z);
    }

    @Internal
    public void setFCellFitText(boolean z) {
        this.field_30_copt = (byte) fCellFitText.setBoolean(this.field_30_copt, z);
    }

    @Internal
    public void setFChsDiff(boolean z) {
        this.field_49_CharsetFlags = (short) fChsDiff.setBoolean(this.field_49_CharsetFlags, z);
    }

    @Internal
    public void setFComplexScripts(boolean z) {
        this.field_1_grpfChp = fComplexScripts.setBoolean(this.field_1_grpfChp, z);
    }

    @Internal
    public void setFConflictOrig(boolean z) {
        this.field_54_fConflictOrig = z;
    }

    @Internal
    public void setFConflictOtherDel(boolean z) {
        this.field_55_fConflictOtherDel = z;
    }

    @Internal
    public void setFDStrike(boolean z) {
        this.field_1_grpfChp = fDStrike.setBoolean(this.field_1_grpfChp, z);
    }

    @Internal
    public void setFData(boolean z) {
        this.field_1_grpfChp = fData.setBoolean(this.field_1_grpfChp, z);
    }

    @Internal
    public void setFDblBdr(boolean z) {
        this.field_27_fDblBdr = z;
    }

    @Internal
    public void setFDispFldRMark(boolean z) {
        this.field_59_fDispFldRMark = z;
    }

    @Internal
    public void setFEmboss(boolean z) {
        this.field_1_grpfChp = fEmboss.setBoolean(this.field_1_grpfChp, z);
    }

    @Internal
    public void setFFitText(boolean z) {
        this.field_1_grpfChp = fFitText.setBoolean(this.field_1_grpfChp, z);
    }

    @Internal
    public void setFFldVanish(boolean z) {
        this.field_1_grpfChp = fFldVanish.setBoolean(this.field_1_grpfChp, z);
    }

    @Internal
    public void setFFmtLineProp(boolean z) {
        this.field_1_grpfChp = fFmtLineProp.setBoolean(this.field_1_grpfChp, z);
    }

    @Internal
    public void setFHasOldProps(boolean z) {
        this.field_66_fHasOldProps = z;
    }

    @Internal
    public void setFHighlight(boolean z) {
        this.field_48_Highlight = (short) fHighlight.setBoolean(this.field_48_Highlight, z);
    }

    @Internal
    public void setFIcoBi(boolean z) {
        this.field_1_grpfChp = fIcoBi.setBoolean(this.field_1_grpfChp, z);
    }

    @Internal
    public void setFImprint(boolean z) {
        this.field_1_grpfChp = fImprint.setBoolean(this.field_1_grpfChp, z);
    }

    @Internal
    public void setFItalic(boolean z) {
        this.field_1_grpfChp = fItalic.setBoolean(this.field_1_grpfChp, z);
    }

    @Internal
    public void setFItalicBi(boolean z) {
        this.field_1_grpfChp = fItalicBi.setBoolean(this.field_1_grpfChp, z);
    }

    @Internal
    public void setFItalicOther(boolean z) {
        this.field_1_grpfChp = fItalicOther.setBoolean(this.field_1_grpfChp, z);
    }

    @Internal
    public void setFKumimoji(boolean z) {
        this.field_29_ufel = (short) fKumimoji.setBoolean(this.field_29_ufel, z);
    }

    @Internal
    public void setFLSFitText(boolean z) {
        this.field_29_ufel = (short) fLSFitText.setBoolean(this.field_29_ufel, z);
    }

    @Internal
    public void setFLowerCase(boolean z) {
        this.field_1_grpfChp = fLowerCase.setBoolean(this.field_1_grpfChp, z);
    }

    @Internal
    public void setFMacChs(boolean z) {
        this.field_49_CharsetFlags = (short) fMacChs.setBoolean(this.field_49_CharsetFlags, z);
    }

    @Internal
    public void setFNoProof(boolean z) {
        this.field_1_grpfChp = fNoProof.setBoolean(this.field_1_grpfChp, z);
    }

    @Internal
    public void setFNonGlyph(boolean z) {
        this.field_1_grpfChp = fNonGlyph.setBoolean(this.field_1_grpfChp, z);
    }

    @Internal
    public void setFObj(boolean z) {
        this.field_1_grpfChp = fObj.setBoolean(this.field_1_grpfChp, z);
    }

    @Internal
    public void setFOle2(boolean z) {
        this.field_1_grpfChp = fOle2.setBoolean(this.field_1_grpfChp, z);
    }

    @Internal
    public void setFOutline(boolean z) {
        this.field_1_grpfChp = fOutline.setBoolean(this.field_1_grpfChp, z);
    }

    @Internal
    public void setFPropRMark(boolean z) {
        this.field_51_fPropRMark = z;
    }

    @Internal
    public void setFRMark(boolean z) {
        this.field_1_grpfChp = fRMark.setBoolean(this.field_1_grpfChp, z);
    }

    @Internal
    public void setFRMarkDel(boolean z) {
        this.field_1_grpfChp = fRMarkDel.setBoolean(this.field_1_grpfChp, z);
    }

    @Internal
    public void setFRuby(boolean z) {
        this.field_29_ufel = (short) fRuby.setBoolean(this.field_29_ufel, z);
    }

    @Internal
    public void setFSdtVanish(boolean z) {
        this.field_67_fSdtVanish = z;
    }

    @Internal
    public void setFShadow(boolean z) {
        this.field_1_grpfChp = fShadow.setBoolean(this.field_1_grpfChp, z);
    }

    @Internal
    public void setFSmallCaps(boolean z) {
        this.field_1_grpfChp = fSmallCaps.setBoolean(this.field_1_grpfChp, z);
    }

    @Internal
    public void setFSpec(boolean z) {
        this.field_1_grpfChp = fSpec.setBoolean(this.field_1_grpfChp, z);
    }

    @Internal
    public void setFSpecSymbol(boolean z) {
        this.field_16_fSpecSymbol = z;
    }

    @Internal
    public void setFSpecVanish(boolean z) {
        this.field_65_fSpecVanish = z;
    }

    @Internal
    public void setFStrike(boolean z) {
        this.field_1_grpfChp = fStrike.setBoolean(this.field_1_grpfChp, z);
    }

    @Internal
    public void setFTNY(boolean z) {
        this.field_29_ufel = (short) fTNY.setBoolean(this.field_29_ufel, z);
    }

    @Internal
    public void setFTNYCompress(boolean z) {
        this.field_30_copt = (byte) fTNYCompress.setBoolean(this.field_30_copt, z);
    }

    @Internal
    public void setFTNYFetchTxm(boolean z) {
        this.field_30_copt = (byte) fTNYFetchTxm.setBoolean(this.field_30_copt, z);
    }

    @Internal
    public void setFUndetermine(boolean z) {
        this.field_14_fUndetermine = z;
    }

    @Internal
    public void setFUsePgsuSettings(boolean z) {
        this.field_1_grpfChp = fUsePgsuSettings.setBoolean(this.field_1_grpfChp, z);
    }

    @Internal
    public void setFVanish(boolean z) {
        this.field_1_grpfChp = fVanish.setBoolean(this.field_1_grpfChp, z);
    }

    @Internal
    public void setFWarichu(boolean z) {
        this.field_29_ufel = (short) fWarichu.setBoolean(this.field_29_ufel, z);
    }

    @Internal
    public void setFWarichuNoOpenBracket(boolean z) {
        this.field_30_copt = (byte) fWarichuNoOpenBracket.setBoolean(this.field_30_copt, z);
    }

    @Internal
    public void setFWebHidden(boolean z) {
        this.field_1_grpfChp = fWebHidden.setBoolean(this.field_1_grpfChp, z);
    }

    @Internal
    public void setFcData(int i2) {
        this.field_39_fcData = i2;
    }

    @Internal
    public void setFcObj(int i2) {
        this.field_37_fcObj = i2;
    }

    @Internal
    public void setFcObjp(int i2) {
        this.field_63_fcObjp = i2;
    }

    @Internal
    public void setFcPic(int i2) {
        this.field_36_fcPic = i2;
    }

    @Internal
    public void setFtcAscii(int i2) {
        this.field_3_ftcAscii = i2;
    }

    @Internal
    public void setFtcBi(int i2) {
        this.field_6_ftcBi = i2;
    }

    @Internal
    public void setFtcFE(int i2) {
        this.field_4_ftcFE = i2;
    }

    @Internal
    public void setFtcOther(int i2) {
        this.field_5_ftcOther = i2;
    }

    @Internal
    public void setFtcSym(int i2) {
        this.field_34_ftcSym = i2;
    }

    @Internal
    public void setGrpfChp(int i2) {
        this.field_1_grpfChp = i2;
    }

    @Internal
    public void setHighlight(short s) {
        this.field_48_Highlight = s;
    }

    @Internal
    public void setHps(int i2) {
        this.field_2_hps = i2;
    }

    @Internal
    public void setHpsAsci(int i2) {
        this.field_31_hpsAsci = i2;
    }

    @Internal
    public void setHpsBi(int i2) {
        this.field_33_hpsBi = i2;
    }

    @Internal
    public void setHpsFE(int i2) {
        this.field_32_hpsFE = i2;
    }

    @Internal
    public void setHpsKern(int i2) {
        this.field_21_hpsKern = i2;
    }

    @Internal
    public void setHpsPos(short s) {
        this.field_22_hpsPos = s;
    }

    @Internal
    public void setHresi(Hyphenation hyphenation) {
        this.field_20_hresi = hyphenation;
    }

    @Internal
    public void setHresiOld(Hyphenation hyphenation) {
        this.field_40_hresiOld = hyphenation;
    }

    @Internal
    public void setIWarichuBracket(byte b2) {
        this.field_30_copt = (byte) iWarichuBracket.setValue(this.field_30_copt, b2);
    }

    @Internal
    public void setIbstConflict(int i2) {
        this.field_57_IbstConflict = i2;
    }

    @Internal
    public void setIbstDispFldRMark(int i2) {
        this.field_60_ibstDispFldRMark = i2;
    }

    @Internal
    public void setIbstPropRMark(int i2) {
        this.field_52_ibstPropRMark = i2;
    }

    @Internal
    public void setIbstRMark(int i2) {
        this.field_25_ibstRMark = i2;
    }

    @Internal
    public void setIbstRMarkDel(int i2) {
        this.field_41_ibstRMarkDel = i2;
    }

    @Internal
    public void setIco(byte b2) {
        this.field_9_ico = b2;
    }

    @Internal
    public void setIcoHighlight(byte b2) {
        this.field_48_Highlight = (short) icoHighlight.setValue(this.field_48_Highlight, b2);
    }

    @Internal
    public void setIdct(byte b2) {
        this.field_17_idct = b2;
    }

    @Internal
    public void setIdctHint(byte b2) {
        this.field_18_idctHint = b2;
    }

    @Internal
    public void setIdslRMReason(int i2) {
        this.field_45_idslRMReason = i2;
    }

    @Internal
    public void setIdslReasonDel(int i2) {
        this.field_46_idslReasonDel = i2;
    }

    @Internal
    public void setIss(byte b2) {
        this.field_15_iss = b2;
    }

    @Internal
    public void setIstd(int i2) {
        this.field_44_istd = i2;
    }

    @Internal
    public void setItypFELayout(short s) {
        this.field_29_ufel = (short) itypFELayout.setValue(this.field_29_ufel, s);
    }

    @Internal
    public void setKcd(byte b2) {
        this.field_13_kcd = b2;
    }

    @Internal
    public void setKul(byte b2) {
        this.field_19_kul = b2;
    }

    @Internal
    public void setLTagObj(int i2) {
        this.field_38_lTagObj = i2;
    }

    @Internal
    public void setLbrCRJ(byte b2) {
        this.field_64_lbrCRJ = b2;
    }

    @Internal
    public void setLidDefault(int i2) {
        this.field_11_lidDefault = i2;
    }

    @Internal
    public void setLidFE(int i2) {
        this.field_12_lidFE = i2;
    }

    @Internal
    public void setPctCharWidth(int i2) {
        this.field_10_pctCharWidth = i2;
    }

    @Internal
    public void setSfxtText(byte b2) {
        this.field_26_sfxtText = b2;
    }

    @Internal
    public void setShd(ShadingDescriptor shadingDescriptor) {
        this.field_23_shd = shadingDescriptor;
    }

    @Internal
    public void setSpare(byte b2) {
        this.field_29_ufel = (short) spare.setValue(this.field_29_ufel, b2);
    }

    @Internal
    public void setUfel(short s) {
        this.field_29_ufel = s;
    }

    @Internal
    public void setUnused(boolean z) {
        this.field_30_copt = (byte) unused.setBoolean(this.field_30_copt, z);
    }

    @Internal
    public void setWCharScale(int i2) {
        this.field_68_wCharScale = i2;
    }

    @Internal
    public void setWConflict(int i2) {
        this.field_56_wConflict = i2;
    }

    @Internal
    public void setXchSym(int i2) {
        this.field_35_xchSym = i2;
    }

    @Internal
    public void setXstDispFldRMark(byte[] bArr) {
        this.field_62_xstDispFldRMark = bArr;
    }

    public String toString() {
        StringBuilder d2 = a.d("[CHP]\n", "    .grpfChp              = ", " (");
        d2.append(getGrpfChp());
        d2.append(" )\n");
        d2.append("         .fBold                    = ");
        d2.append(isFBold());
        d2.append('\n');
        d2.append("         .fItalic                  = ");
        d2.append(isFItalic());
        d2.append('\n');
        d2.append("         .fRMarkDel                = ");
        d2.append(isFRMarkDel());
        d2.append('\n');
        d2.append("         .fOutline                 = ");
        d2.append(isFOutline());
        d2.append('\n');
        d2.append("         .fFldVanish               = ");
        d2.append(isFFldVanish());
        d2.append('\n');
        d2.append("         .fSmallCaps               = ");
        d2.append(isFSmallCaps());
        d2.append('\n');
        d2.append("         .fCaps                    = ");
        d2.append(isFCaps());
        d2.append('\n');
        d2.append("         .fVanish                  = ");
        d2.append(isFVanish());
        d2.append('\n');
        d2.append("         .fRMark                   = ");
        d2.append(isFRMark());
        d2.append('\n');
        d2.append("         .fSpec                    = ");
        d2.append(isFSpec());
        d2.append('\n');
        d2.append("         .fStrike                  = ");
        d2.append(isFStrike());
        d2.append('\n');
        d2.append("         .fObj                     = ");
        d2.append(isFObj());
        d2.append('\n');
        d2.append("         .fShadow                  = ");
        d2.append(isFShadow());
        d2.append('\n');
        d2.append("         .fLowerCase               = ");
        d2.append(isFLowerCase());
        d2.append('\n');
        d2.append("         .fData                    = ");
        d2.append(isFData());
        d2.append('\n');
        d2.append("         .fOle2                    = ");
        d2.append(isFOle2());
        d2.append('\n');
        d2.append("         .fEmboss                  = ");
        d2.append(isFEmboss());
        d2.append('\n');
        d2.append("         .fImprint                 = ");
        d2.append(isFImprint());
        d2.append('\n');
        d2.append("         .fDStrike                 = ");
        d2.append(isFDStrike());
        d2.append('\n');
        d2.append("         .fUsePgsuSettings         = ");
        d2.append(isFUsePgsuSettings());
        d2.append('\n');
        d2.append("         .fBoldBi                  = ");
        d2.append(isFBoldBi());
        d2.append('\n');
        d2.append("         .fComplexScripts          = ");
        d2.append(isFComplexScripts());
        d2.append('\n');
        d2.append("         .fItalicBi                = ");
        d2.append(isFItalicBi());
        d2.append('\n');
        d2.append("         .fBiDi                    = ");
        d2.append(isFBiDi());
        d2.append('\n');
        d2.append("         .fIcoBi                   = ");
        d2.append(isFIcoBi());
        d2.append('\n');
        d2.append("         .fNonGlyph                = ");
        d2.append(isFNonGlyph());
        d2.append('\n');
        d2.append("         .fBoldOther               = ");
        d2.append(isFBoldOther());
        d2.append('\n');
        d2.append("         .fItalicOther             = ");
        d2.append(isFItalicOther());
        d2.append('\n');
        d2.append("         .fNoProof                 = ");
        d2.append(isFNoProof());
        d2.append('\n');
        d2.append("         .fWebHidden               = ");
        d2.append(isFWebHidden());
        d2.append('\n');
        d2.append("         .fFitText                 = ");
        d2.append(isFFitText());
        d2.append('\n');
        d2.append("         .fCalc                    = ");
        d2.append(isFCalc());
        d2.append('\n');
        d2.append("         .fFmtLineProp             = ");
        d2.append(isFFmtLineProp());
        d2.append('\n');
        d2.append("    .hps                  = ");
        d2.append(" (");
        d2.append(getHps());
        d2.append(" )\n");
        d2.append("    .ftcAscii             = ");
        d2.append(" (");
        d2.append(getFtcAscii());
        d2.append(" )\n");
        d2.append("    .ftcFE                = ");
        d2.append(" (");
        d2.append(getFtcFE());
        d2.append(" )\n");
        d2.append("    .ftcOther             = ");
        d2.append(" (");
        d2.append(getFtcOther());
        d2.append(" )\n");
        d2.append("    .ftcBi                = ");
        d2.append(" (");
        d2.append(getFtcBi());
        d2.append(" )\n");
        d2.append("    .dxaSpace             = ");
        d2.append(" (");
        d2.append(getDxaSpace());
        d2.append(" )\n");
        d2.append("    .cv                   = ");
        d2.append(" (");
        d2.append(getCv());
        d2.append(" )\n");
        d2.append("    .ico                  = ");
        d2.append(" (");
        d2.append((int) getIco());
        d2.append(" )\n");
        d2.append("    .pctCharWidth         = ");
        d2.append(" (");
        d2.append(getPctCharWidth());
        d2.append(" )\n");
        d2.append("    .lidDefault           = ");
        d2.append(" (");
        d2.append(getLidDefault());
        d2.append(" )\n");
        d2.append("    .lidFE                = ");
        d2.append(" (");
        d2.append(getLidFE());
        d2.append(" )\n");
        d2.append("    .kcd                  = ");
        d2.append(" (");
        d2.append((int) getKcd());
        d2.append(" )\n");
        d2.append("    .fUndetermine         = ");
        d2.append(" (");
        d2.append(getFUndetermine());
        d2.append(" )\n");
        d2.append("    .iss                  = ");
        d2.append(" (");
        d2.append((int) getIss());
        d2.append(" )\n");
        d2.append("    .fSpecSymbol          = ");
        d2.append(" (");
        d2.append(getFSpecSymbol());
        d2.append(" )\n");
        d2.append("    .idct                 = ");
        d2.append(" (");
        d2.append((int) getIdct());
        d2.append(" )\n");
        d2.append("    .idctHint             = ");
        d2.append(" (");
        d2.append((int) getIdctHint());
        d2.append(" )\n");
        d2.append("    .kul                  = ");
        d2.append(" (");
        d2.append((int) getKul());
        d2.append(" )\n");
        d2.append("    .hresi                = ");
        d2.append(" (");
        d2.append(getHresi());
        d2.append(" )\n");
        d2.append("    .hpsKern              = ");
        d2.append(" (");
        d2.append(getHpsKern());
        d2.append(" )\n");
        d2.append("    .hpsPos               = ");
        d2.append(" (");
        d2.append((int) getHpsPos());
        d2.append(" )\n");
        d2.append("    .shd                  = ");
        d2.append(" (");
        d2.append(getShd());
        d2.append(" )\n");
        d2.append("    .brc                  = ");
        d2.append(" (");
        d2.append(getBrc());
        d2.append(" )\n");
        d2.append("    .ibstRMark            = ");
        d2.append(" (");
        d2.append(getIbstRMark());
        d2.append(" )\n");
        d2.append("    .sfxtText             = ");
        d2.append(" (");
        d2.append((int) getSfxtText());
        d2.append(" )\n");
        d2.append("    .fDblBdr              = ");
        d2.append(" (");
        d2.append(getFDblBdr());
        d2.append(" )\n");
        d2.append("    .fBorderWS            = ");
        d2.append(" (");
        d2.append(getFBorderWS());
        d2.append(" )\n");
        d2.append("    .ufel                 = ");
        d2.append(" (");
        d2.append((int) getUfel());
        d2.append(" )\n");
        d2.append("         .itypFELayout             = ");
        d2.append((int) getItypFELayout());
        d2.append('\n');
        d2.append("         .fTNY                     = ");
        d2.append(isFTNY());
        d2.append('\n');
        d2.append("         .fWarichu                 = ");
        d2.append(isFWarichu());
        d2.append('\n');
        d2.append("         .fKumimoji                = ");
        d2.append(isFKumimoji());
        d2.append('\n');
        d2.append("         .fRuby                    = ");
        d2.append(isFRuby());
        d2.append('\n');
        d2.append("         .fLSFitText               = ");
        d2.append(isFLSFitText());
        d2.append('\n');
        d2.append("         .spare                    = ");
        d2.append((int) getSpare());
        d2.append('\n');
        d2.append("    .copt                 = ");
        d2.append(" (");
        d2.append((int) getCopt());
        d2.append(" )\n");
        d2.append("         .iWarichuBracket          = ");
        d2.append((int) getIWarichuBracket());
        d2.append('\n');
        d2.append("         .fWarichuNoOpenBracket     = ");
        d2.append(isFWarichuNoOpenBracket());
        d2.append('\n');
        d2.append("         .fTNYCompress             = ");
        d2.append(isFTNYCompress());
        d2.append('\n');
        d2.append("         .fTNYFetchTxm             = ");
        d2.append(isFTNYFetchTxm());
        d2.append('\n');
        d2.append("         .fCellFitText             = ");
        d2.append(isFCellFitText());
        d2.append('\n');
        d2.append("         .unused                   = ");
        d2.append(isUnused());
        d2.append('\n');
        d2.append("    .hpsAsci              = ");
        d2.append(" (");
        d2.append(getHpsAsci());
        d2.append(" )\n");
        d2.append("    .hpsFE                = ");
        d2.append(" (");
        d2.append(getHpsFE());
        d2.append(" )\n");
        d2.append("    .hpsBi                = ");
        d2.append(" (");
        d2.append(getHpsBi());
        d2.append(" )\n");
        d2.append("    .ftcSym               = ");
        d2.append(" (");
        d2.append(getFtcSym());
        d2.append(" )\n");
        d2.append("    .xchSym               = ");
        d2.append(" (");
        d2.append(getXchSym());
        d2.append(" )\n");
        d2.append("    .fcPic                = ");
        d2.append(" (");
        d2.append(getFcPic());
        d2.append(" )\n");
        d2.append("    .fcObj                = ");
        d2.append(" (");
        d2.append(getFcObj());
        d2.append(" )\n");
        d2.append("    .lTagObj              = ");
        d2.append(" (");
        d2.append(getLTagObj());
        d2.append(" )\n");
        d2.append("    .fcData               = ");
        d2.append(" (");
        d2.append(getFcData());
        d2.append(" )\n");
        d2.append("    .hresiOld             = ");
        d2.append(" (");
        d2.append(getHresiOld());
        d2.append(" )\n");
        d2.append("    .ibstRMarkDel         = ");
        d2.append(" (");
        d2.append(getIbstRMarkDel());
        d2.append(" )\n");
        d2.append("    .dttmRMark            = ");
        d2.append(" (");
        d2.append(getDttmRMark());
        d2.append(" )\n");
        d2.append("    .dttmRMarkDel         = ");
        d2.append(" (");
        d2.append(getDttmRMarkDel());
        d2.append(" )\n");
        d2.append("    .istd                 = ");
        d2.append(" (");
        d2.append(getIstd());
        d2.append(" )\n");
        d2.append("    .idslRMReason         = ");
        d2.append(" (");
        d2.append(getIdslRMReason());
        d2.append(" )\n");
        d2.append("    .idslReasonDel        = ");
        d2.append(" (");
        d2.append(getIdslReasonDel());
        d2.append(" )\n");
        d2.append("    .cpg                  = ");
        d2.append(" (");
        d2.append(getCpg());
        d2.append(" )\n");
        d2.append("    .Highlight            = ");
        d2.append(" (");
        d2.append((int) getHighlight());
        d2.append(" )\n");
        d2.append("         .icoHighlight             = ");
        d2.append((int) getIcoHighlight());
        d2.append('\n');
        d2.append("         .fHighlight               = ");
        d2.append(isFHighlight());
        d2.append('\n');
        d2.append("    .CharsetFlags         = ");
        d2.append(" (");
        d2.append((int) getCharsetFlags());
        d2.append(" )\n");
        d2.append("         .fChsDiff                 = ");
        d2.append(isFChsDiff());
        d2.append('\n');
        d2.append("         .fMacChs                  = ");
        d2.append(isFMacChs());
        d2.append('\n');
        d2.append("    .chse                 = ");
        d2.append(" (");
        d2.append((int) getChse());
        d2.append(" )\n");
        d2.append("    .fPropRMark           = ");
        d2.append(" (");
        d2.append(getFPropRMark());
        d2.append(" )\n");
        d2.append("    .ibstPropRMark        = ");
        d2.append(" (");
        d2.append(getIbstPropRMark());
        d2.append(" )\n");
        d2.append("    .dttmPropRMark        = ");
        d2.append(" (");
        d2.append(getDttmPropRMark());
        d2.append(" )\n");
        d2.append("    .fConflictOrig        = ");
        d2.append(" (");
        d2.append(getFConflictOrig());
        d2.append(" )\n");
        d2.append("    .fConflictOtherDel    = ");
        d2.append(" (");
        d2.append(getFConflictOtherDel());
        d2.append(" )\n");
        d2.append("    .wConflict            = ");
        d2.append(" (");
        d2.append(getWConflict());
        d2.append(" )\n");
        d2.append("    .IbstConflict         = ");
        d2.append(" (");
        d2.append(getIbstConflict());
        d2.append(" )\n");
        d2.append("    .dttmConflict         = ");
        d2.append(" (");
        d2.append(getDttmConflict());
        d2.append(" )\n");
        d2.append("    .fDispFldRMark        = ");
        d2.append(" (");
        d2.append(getFDispFldRMark());
        d2.append(" )\n");
        d2.append("    .ibstDispFldRMark     = ");
        d2.append(" (");
        d2.append(getIbstDispFldRMark());
        d2.append(" )\n");
        d2.append("    .dttmDispFldRMark     = ");
        d2.append(" (");
        d2.append(getDttmDispFldRMark());
        d2.append(" )\n");
        d2.append("    .xstDispFldRMark      = ");
        d2.append(" (");
        d2.append(Arrays.toString(getXstDispFldRMark()));
        d2.append(" )\n");
        d2.append("    .fcObjp               = ");
        d2.append(" (");
        d2.append(getFcObjp());
        d2.append(" )\n");
        d2.append("    .lbrCRJ               = ");
        d2.append(" (");
        d2.append((int) getLbrCRJ());
        d2.append(" )\n");
        d2.append("    .fSpecVanish          = ");
        d2.append(" (");
        d2.append(getFSpecVanish());
        d2.append(" )\n");
        d2.append("    .fHasOldProps         = ");
        d2.append(" (");
        d2.append(getFHasOldProps());
        d2.append(" )\n");
        d2.append("    .fSdtVanish           = ");
        d2.append(" (");
        d2.append(getFSdtVanish());
        d2.append(" )\n");
        d2.append("    .wCharScale           = ");
        d2.append(" (");
        d2.append(getWCharScale());
        d2.append(" )\n");
        d2.append("[/CHP]\n");
        return d2.toString();
    }
}
