package org.apache.poi.hwpf.model.types;

import b.b.a.a.a;
import org.apache.poi.util.BitField;
import org.apache.poi.util.Internal;
import org.apache.poi.util.LittleEndian;

@Internal
public abstract class FFDataBaseAbstractType {
    public static final byte ITYPETXT_CALC = 0;
    public static final byte ITYPETXT_CURDATE = 0;
    public static final byte ITYPETXT_CURTIME = 0;
    public static final byte ITYPETXT_DATE = 0;
    public static final byte ITYPETXT_NUM = 0;
    public static final byte ITYPETXT_REG = 0;
    public static final byte ITYPE_CHCK = 1;
    public static final byte ITYPE_DROP = 2;
    public static final byte ITYPE_TEXT = 0;
    public static final BitField fHasListBox = new BitField(32768);
    public static final BitField fOwnHelp = new BitField(128);
    public static final BitField fOwnStat = new BitField(256);
    public static final BitField fProt = new BitField(512);
    public static final BitField fRecalc = new BitField(16384);
    public static final BitField iRes = new BitField(124);
    public static final BitField iSize = new BitField(1024);
    public static final BitField iType = new BitField(3);
    public static final BitField iTypeTxt = new BitField(14336);
    public long field_1_version;
    public short field_2_bits;
    public int field_3_cch;
    public int field_4_hps;

    public static int getSize() {
        return 10;
    }

    public boolean equals(Object obj) {
        if (this == obj) {
            return true;
        }
        if (obj == null || getClass() != obj.getClass()) {
            return false;
        }
        FFDataBaseAbstractType fFDataBaseAbstractType = (FFDataBaseAbstractType) obj;
        return this.field_1_version == fFDataBaseAbstractType.field_1_version && this.field_2_bits == fFDataBaseAbstractType.field_2_bits && this.field_3_cch == fFDataBaseAbstractType.field_3_cch && this.field_4_hps == fFDataBaseAbstractType.field_4_hps;
    }

    public void fillFields(byte[] bArr, int i2) {
        this.field_1_version = LittleEndian.getUInt(bArr, i2 + 0);
        this.field_2_bits = LittleEndian.getShort(bArr, i2 + 4);
        this.field_3_cch = LittleEndian.getShort(bArr, i2 + 6);
        this.field_4_hps = LittleEndian.getShort(bArr, i2 + 8);
    }

    @Internal
    public short getBits() {
        return this.field_2_bits;
    }

    @Internal
    public int getCch() {
        return this.field_3_cch;
    }

    @Internal
    public int getHps() {
        return this.field_4_hps;
    }

    @Internal
    public byte getIRes() {
        return (byte) iRes.getValue(this.field_2_bits);
    }

    @Internal
    public byte getIType() {
        return (byte) iType.getValue(this.field_2_bits);
    }

    @Internal
    public byte getITypeTxt() {
        return (byte) iTypeTxt.getValue(this.field_2_bits);
    }

    @Internal
    public long getVersion() {
        return this.field_1_version;
    }

    public int hashCode() {
        long j = this.field_1_version;
        return ((((((((int) (j ^ (j >>> 32))) + 31) * 31) + this.field_2_bits) * 31) + this.field_3_cch) * 31) + this.field_4_hps;
    }

    @Internal
    public boolean isFHasListBox() {
        return fHasListBox.isSet(this.field_2_bits);
    }

    @Internal
    public boolean isFOwnHelp() {
        return fOwnHelp.isSet(this.field_2_bits);
    }

    @Internal
    public boolean isFOwnStat() {
        return fOwnStat.isSet(this.field_2_bits);
    }

    @Internal
    public boolean isFProt() {
        return fProt.isSet(this.field_2_bits);
    }

    @Internal
    public boolean isFRecalc() {
        return fRecalc.isSet(this.field_2_bits);
    }

    @Internal
    public boolean isISize() {
        return iSize.isSet(this.field_2_bits);
    }

    public void serialize(byte[] bArr, int i2) {
        LittleEndian.putUInt(bArr, i2 + 0, this.field_1_version);
        LittleEndian.putShort(bArr, i2 + 4, this.field_2_bits);
        LittleEndian.putUShort(bArr, i2 + 6, this.field_3_cch);
        LittleEndian.putUShort(bArr, i2 + 8, this.field_4_hps);
    }

    @Internal
    public void setBits(short s) {
        this.field_2_bits = s;
    }

    @Internal
    public void setCch(int i2) {
        this.field_3_cch = i2;
    }

    @Internal
    public void setFHasListBox(boolean z) {
        this.field_2_bits = (short) fHasListBox.setBoolean(this.field_2_bits, z);
    }

    @Internal
    public void setFOwnHelp(boolean z) {
        this.field_2_bits = (short) fOwnHelp.setBoolean(this.field_2_bits, z);
    }

    @Internal
    public void setFOwnStat(boolean z) {
        this.field_2_bits = (short) fOwnStat.setBoolean(this.field_2_bits, z);
    }

    @Internal
    public void setFProt(boolean z) {
        this.field_2_bits = (short) fProt.setBoolean(this.field_2_bits, z);
    }

    @Internal
    public void setFRecalc(boolean z) {
        this.field_2_bits = (short) fRecalc.setBoolean(this.field_2_bits, z);
    }

    @Internal
    public void setHps(int i2) {
        this.field_4_hps = i2;
    }

    @Internal
    public void setIRes(byte b2) {
        this.field_2_bits = (short) iRes.setValue(this.field_2_bits, b2);
    }

    @Internal
    public void setISize(boolean z) {
        this.field_2_bits = (short) iSize.setBoolean(this.field_2_bits, z);
    }

    @Internal
    public void setIType(byte b2) {
        this.field_2_bits = (short) iType.setValue(this.field_2_bits, b2);
    }

    @Internal
    public void setITypeTxt(byte b2) {
        this.field_2_bits = (short) iTypeTxt.setValue(this.field_2_bits, b2);
    }

    @Internal
    public void setVersion(long j) {
        this.field_1_version = j;
    }

    public String toString() {
        StringBuilder d2 = a.d("[FFDataBase]\n", "    .version              = ", " ( ");
        d2.append(this.field_1_version);
        d2.append(" )\n");
        d2.append("    .bits                 = ");
        d2.append(" ( ");
        d2.append((int) this.field_2_bits);
        d2.append(" )\n");
        d2.append("         .iType                    = ");
        d2.append((int) getIType());
        d2.append('\n');
        d2.append("         .iRes                     = ");
        d2.append((int) getIRes());
        d2.append('\n');
        d2.append("         .fOwnHelp                 = ");
        d2.append(isFOwnHelp());
        d2.append('\n');
        d2.append("         .fOwnStat                 = ");
        d2.append(isFOwnStat());
        d2.append('\n');
        d2.append("         .fProt                    = ");
        d2.append(isFProt());
        d2.append('\n');
        d2.append("         .iSize                    = ");
        d2.append(isISize());
        d2.append('\n');
        d2.append("         .iTypeTxt                 = ");
        d2.append((int) getITypeTxt());
        d2.append('\n');
        d2.append("         .fRecalc                  = ");
        d2.append(isFRecalc());
        d2.append('\n');
        d2.append("         .fHasListBox              = ");
        d2.append(isFHasListBox());
        d2.append('\n');
        d2.append("    .cch                  = ");
        d2.append(" ( ");
        d2.append(this.field_3_cch);
        d2.append(" )\n");
        d2.append("    .hps                  = ");
        d2.append(" ( ");
        d2.append(this.field_4_hps);
        d2.append(" )\n");
        d2.append("[/FFDataBase]");
        return d2.toString();
    }

    public byte[] serialize() {
        byte[] bArr = new byte[getSize()];
        serialize(bArr, 0);
        return bArr;
    }
}
