package org.apache.poi.hwpf.model.types;

import b.b.a.a.a;
import org.apache.poi.util.BitField;
import org.apache.poi.util.Internal;
import org.apache.poi.util.LittleEndian;

@Internal
public abstract class FSPAAbstractType {
    public static BitField bx = new BitField(6);
    public static BitField by = new BitField(24);
    public static BitField fAnchorLock = new BitField(32768);
    public static BitField fBelowText = new BitField(16384);
    public static BitField fHdr = new BitField(1);
    public static BitField fRcaSimple = new BitField(8192);
    public static BitField wr = new BitField(480);
    public static BitField wrk = new BitField(7680);
    public int field_1_spid;
    public int field_2_xaLeft;
    public int field_3_yaTop;
    public int field_4_xaRight;
    public int field_5_yaBottom;
    public short field_6_flags;
    public int field_7_cTxbx;

    public static int getSize() {
        return 26;
    }

    public void fillFields(byte[] bArr, int i2) {
        this.field_1_spid = LittleEndian.getInt(bArr, i2 + 0);
        this.field_2_xaLeft = LittleEndian.getInt(bArr, i2 + 4);
        this.field_3_yaTop = LittleEndian.getInt(bArr, i2 + 8);
        this.field_4_xaRight = LittleEndian.getInt(bArr, i2 + 12);
        this.field_5_yaBottom = LittleEndian.getInt(bArr, i2 + 16);
        this.field_6_flags = LittleEndian.getShort(bArr, i2 + 20);
        this.field_7_cTxbx = LittleEndian.getInt(bArr, i2 + 22);
    }

    @Internal
    public byte getBx() {
        return (byte) bx.getValue(this.field_6_flags);
    }

    @Internal
    public byte getBy() {
        return (byte) by.getValue(this.field_6_flags);
    }

    @Internal
    public int getCTxbx() {
        return this.field_7_cTxbx;
    }

    @Internal
    public short getFlags() {
        return this.field_6_flags;
    }

    @Internal
    public int getSpid() {
        return this.field_1_spid;
    }

    @Internal
    public byte getWr() {
        return (byte) wr.getValue(this.field_6_flags);
    }

    @Internal
    public byte getWrk() {
        return (byte) wrk.getValue(this.field_6_flags);
    }

    @Internal
    public int getXaLeft() {
        return this.field_2_xaLeft;
    }

    @Internal
    public int getXaRight() {
        return this.field_4_xaRight;
    }

    @Internal
    public int getYaBottom() {
        return this.field_5_yaBottom;
    }

    @Internal
    public int getYaTop() {
        return this.field_3_yaTop;
    }

    @Internal
    public boolean isFAnchorLock() {
        return fAnchorLock.isSet(this.field_6_flags);
    }

    @Internal
    public boolean isFBelowText() {
        return fBelowText.isSet(this.field_6_flags);
    }

    @Internal
    public boolean isFHdr() {
        return fHdr.isSet(this.field_6_flags);
    }

    @Internal
    public boolean isFRcaSimple() {
        return fRcaSimple.isSet(this.field_6_flags);
    }

    public void serialize(byte[] bArr, int i2) {
        LittleEndian.putInt(bArr, i2 + 0, this.field_1_spid);
        LittleEndian.putInt(bArr, i2 + 4, this.field_2_xaLeft);
        LittleEndian.putInt(bArr, i2 + 8, this.field_3_yaTop);
        LittleEndian.putInt(bArr, i2 + 12, this.field_4_xaRight);
        LittleEndian.putInt(bArr, i2 + 16, this.field_5_yaBottom);
        LittleEndian.putShort(bArr, i2 + 20, this.field_6_flags);
        LittleEndian.putInt(bArr, i2 + 22, this.field_7_cTxbx);
    }

    @Internal
    public void setBx(byte b2) {
        this.field_6_flags = (short) bx.setValue(this.field_6_flags, b2);
    }

    @Internal
    public void setBy(byte b2) {
        this.field_6_flags = (short) by.setValue(this.field_6_flags, b2);
    }

    @Internal
    public void setCTxbx(int i2) {
        this.field_7_cTxbx = i2;
    }

    @Internal
    public void setFAnchorLock(boolean z) {
        this.field_6_flags = (short) fAnchorLock.setBoolean(this.field_6_flags, z);
    }

    @Internal
    public void setFBelowText(boolean z) {
        this.field_6_flags = (short) fBelowText.setBoolean(this.field_6_flags, z);
    }

    @Internal
    public void setFHdr(boolean z) {
        this.field_6_flags = (short) fHdr.setBoolean(this.field_6_flags, z);
    }

    @Internal
    public void setFRcaSimple(boolean z) {
        this.field_6_flags = (short) fRcaSimple.setBoolean(this.field_6_flags, z);
    }

    @Internal
    public void setFlags(short s) {
        this.field_6_flags = s;
    }

    @Internal
    public void setSpid(int i2) {
        this.field_1_spid = i2;
    }

    @Internal
    public void setWr(byte b2) {
        this.field_6_flags = (short) wr.setValue(this.field_6_flags, b2);
    }

    @Internal
    public void setWrk(byte b2) {
        this.field_6_flags = (short) wrk.setValue(this.field_6_flags, b2);
    }

    @Internal
    public void setXaLeft(int i2) {
        this.field_2_xaLeft = i2;
    }

    @Internal
    public void setXaRight(int i2) {
        this.field_4_xaRight = i2;
    }

    @Internal
    public void setYaBottom(int i2) {
        this.field_5_yaBottom = i2;
    }

    @Internal
    public void setYaTop(int i2) {
        this.field_3_yaTop = i2;
    }

    public String toString() {
        StringBuilder d2 = a.d("[FSPA]\n", "    .spid                 = ", " (");
        d2.append(getSpid());
        d2.append(" )\n");
        d2.append("    .xaLeft               = ");
        d2.append(" (");
        d2.append(getXaLeft());
        d2.append(" )\n");
        d2.append("    .yaTop                = ");
        d2.append(" (");
        d2.append(getYaTop());
        d2.append(" )\n");
        d2.append("    .xaRight              = ");
        d2.append(" (");
        d2.append(getXaRight());
        d2.append(" )\n");
        d2.append("    .yaBottom             = ");
        d2.append(" (");
        d2.append(getYaBottom());
        d2.append(" )\n");
        d2.append("    .flags                = ");
        d2.append(" (");
        d2.append((int) getFlags());
        d2.append(" )\n");
        d2.append("         .fHdr                     = ");
        d2.append(isFHdr());
        d2.append('\n');
        d2.append("         .bx                       = ");
        d2.append((int) getBx());
        d2.append('\n');
        d2.append("         .by                       = ");
        d2.append((int) getBy());
        d2.append('\n');
        d2.append("         .wr                       = ");
        d2.append((int) getWr());
        d2.append('\n');
        d2.append("         .wrk                      = ");
        d2.append((int) getWrk());
        d2.append('\n');
        d2.append("         .fRcaSimple               = ");
        d2.append(isFRcaSimple());
        d2.append('\n');
        d2.append("         .fBelowText               = ");
        d2.append(isFBelowText());
        d2.append('\n');
        d2.append("         .fAnchorLock              = ");
        d2.append(isFAnchorLock());
        d2.append('\n');
        d2.append("    .cTxbx                = ");
        d2.append(" (");
        d2.append(getCTxbx());
        d2.append(" )\n");
        d2.append("[/FSPA]\n");
        return d2.toString();
    }
}
