package org.apache.poi.hwpf.model.types;

import b.b.a.a.a;
import org.apache.poi.util.BitField;
import org.apache.poi.util.Internal;
import org.apache.poi.util.LittleEndian;

@Internal
public abstract class FibBaseAbstractType {
    public static final BitField cQuickSaves = new BitField(240);
    public static final BitField fComplex = new BitField(4);
    public static final BitField fDot = new BitField(1);
    public static final BitField fEmptySpecial = new BitField(2);
    public static final BitField fEncrypted = new BitField(256);
    public static final BitField fExtChar = new BitField(4096);
    public static final BitField fFarEast = new BitField(16384);
    public static final BitField fGlsy = new BitField(2);
    public static final BitField fHasPic = new BitField(8);
    public static final BitField fLoadOverride = new BitField(8192);
    public static final BitField fLoadOverridePage = new BitField(4);
    public static final BitField fMac = new BitField(1);
    public static final BitField fObfuscated = new BitField(32768);
    public static final BitField fReadOnlyRecommended = new BitField(1024);
    public static final BitField fSpare0 = new BitField(254);
    public static final BitField fWhichTblStm = new BitField(512);
    public static final BitField fWriteReservation = new BitField(2048);
    public static final BitField reserved1 = new BitField(8);
    public static final BitField reserved2 = new BitField(16);
    public byte field_10_flags2;
    @Deprecated
    public short field_11_Chs;
    @Deprecated
    public short field_12_chsTables;
    @Deprecated
    public int field_13_fcMin;
    @Deprecated
    public int field_14_fcMac;
    public int field_1_wIdent;
    public int field_2_nFib;
    public int field_3_unused;
    public int field_4_lid;
    public int field_5_pnNext;
    public short field_6_flags1;
    public int field_7_nFibBack;
    public int field_8_lKey;
    @Deprecated
    public byte field_9_envr;

    public static int getSize() {
        return 32;
    }

    public void fillFields(byte[] bArr, int i2) {
        this.field_1_wIdent = LittleEndian.getShort(bArr, i2 + 0);
        this.field_2_nFib = LittleEndian.getShort(bArr, i2 + 2);
        this.field_3_unused = LittleEndian.getShort(bArr, i2 + 4);
        this.field_4_lid = LittleEndian.getShort(bArr, i2 + 6);
        this.field_5_pnNext = LittleEndian.getShort(bArr, i2 + 8);
        this.field_6_flags1 = LittleEndian.getShort(bArr, i2 + 10);
        this.field_7_nFibBack = LittleEndian.getShort(bArr, i2 + 12);
        this.field_8_lKey = LittleEndian.getInt(bArr, i2 + 14);
        this.field_9_envr = bArr[i2 + 18];
        this.field_10_flags2 = bArr[i2 + 19];
        this.field_11_Chs = LittleEndian.getShort(bArr, i2 + 20);
        this.field_12_chsTables = LittleEndian.getShort(bArr, i2 + 22);
        this.field_13_fcMin = LittleEndian.getInt(bArr, i2 + 24);
        this.field_14_fcMac = LittleEndian.getInt(bArr, i2 + 28);
    }

    @Internal
    public byte getCQuickSaves() {
        return (byte) cQuickSaves.getValue(this.field_6_flags1);
    }

    @Internal
    public short getChs() {
        return this.field_11_Chs;
    }

    @Internal
    public short getChsTables() {
        return this.field_12_chsTables;
    }

    @Internal
    public byte getEnvr() {
        return this.field_9_envr;
    }

    @Internal
    @Deprecated
    public byte getFSpare0() {
        return (byte) fSpare0.getValue(this.field_10_flags2);
    }

    @Internal
    public int getFcMac() {
        return this.field_14_fcMac;
    }

    @Internal
    public int getFcMin() {
        return this.field_13_fcMin;
    }

    @Internal
    public short getFlags1() {
        return this.field_6_flags1;
    }

    @Internal
    public byte getFlags2() {
        return this.field_10_flags2;
    }

    @Internal
    public int getLKey() {
        return this.field_8_lKey;
    }

    @Internal
    public int getLid() {
        return this.field_4_lid;
    }

    @Internal
    public int getNFib() {
        return this.field_2_nFib;
    }

    @Internal
    public int getNFibBack() {
        return this.field_7_nFibBack;
    }

    @Internal
    public int getPnNext() {
        return this.field_5_pnNext;
    }

    @Internal
    public int getUnused() {
        return this.field_3_unused;
    }

    @Internal
    public int getWIdent() {
        return this.field_1_wIdent;
    }

    @Internal
    public boolean isFComplex() {
        return fComplex.isSet(this.field_6_flags1);
    }

    @Internal
    public boolean isFDot() {
        return fDot.isSet(this.field_6_flags1);
    }

    @Internal
    @Deprecated
    public boolean isFEmptySpecial() {
        return fEmptySpecial.isSet(this.field_10_flags2);
    }

    @Internal
    public boolean isFEncrypted() {
        return fEncrypted.isSet(this.field_6_flags1);
    }

    @Internal
    public boolean isFExtChar() {
        return fExtChar.isSet(this.field_6_flags1);
    }

    @Internal
    public boolean isFFarEast() {
        return fFarEast.isSet(this.field_6_flags1);
    }

    @Internal
    public boolean isFGlsy() {
        return fGlsy.isSet(this.field_6_flags1);
    }

    @Internal
    public boolean isFHasPic() {
        return fHasPic.isSet(this.field_6_flags1);
    }

    @Internal
    public boolean isFLoadOverride() {
        return fLoadOverride.isSet(this.field_6_flags1);
    }

    @Internal
    public boolean isFLoadOverridePage() {
        return fLoadOverridePage.isSet(this.field_10_flags2);
    }

    @Internal
    @Deprecated
    public boolean isFMac() {
        return fMac.isSet(this.field_10_flags2);
    }

    @Internal
    public boolean isFObfuscated() {
        return fObfuscated.isSet(this.field_6_flags1);
    }

    @Internal
    public boolean isFReadOnlyRecommended() {
        return fReadOnlyRecommended.isSet(this.field_6_flags1);
    }

    @Internal
    public boolean isFWhichTblStm() {
        return fWhichTblStm.isSet(this.field_6_flags1);
    }

    @Internal
    public boolean isFWriteReservation() {
        return fWriteReservation.isSet(this.field_6_flags1);
    }

    @Internal
    @Deprecated
    public boolean isReserved1() {
        return reserved1.isSet(this.field_10_flags2);
    }

    @Internal
    @Deprecated
    public boolean isReserved2() {
        return reserved2.isSet(this.field_10_flags2);
    }

    public void serialize(byte[] bArr, int i2) {
        LittleEndian.putUShort(bArr, i2 + 0, this.field_1_wIdent);
        LittleEndian.putUShort(bArr, i2 + 2, this.field_2_nFib);
        LittleEndian.putUShort(bArr, i2 + 4, this.field_3_unused);
        LittleEndian.putUShort(bArr, i2 + 6, this.field_4_lid);
        LittleEndian.putUShort(bArr, i2 + 8, this.field_5_pnNext);
        LittleEndian.putShort(bArr, i2 + 10, this.field_6_flags1);
        LittleEndian.putUShort(bArr, i2 + 12, this.field_7_nFibBack);
        LittleEndian.putInt(bArr, i2 + 14, this.field_8_lKey);
        bArr[i2 + 18] = this.field_9_envr;
        bArr[i2 + 19] = this.field_10_flags2;
        LittleEndian.putShort(bArr, i2 + 20, this.field_11_Chs);
        LittleEndian.putShort(bArr, i2 + 22, this.field_12_chsTables);
        LittleEndian.putInt(bArr, i2 + 24, this.field_13_fcMin);
        LittleEndian.putInt(bArr, i2 + 28, this.field_14_fcMac);
    }

    @Internal
    public void setCQuickSaves(byte b2) {
        this.field_6_flags1 = (short) cQuickSaves.setValue(this.field_6_flags1, b2);
    }

    @Internal
    public void setChs(short s) {
        this.field_11_Chs = s;
    }

    @Internal
    public void setChsTables(short s) {
        this.field_12_chsTables = s;
    }

    @Internal
    public void setEnvr(byte b2) {
        this.field_9_envr = b2;
    }

    @Internal
    public void setFComplex(boolean z) {
        this.field_6_flags1 = (short) fComplex.setBoolean(this.field_6_flags1, z);
    }

    @Internal
    public void setFDot(boolean z) {
        this.field_6_flags1 = (short) fDot.setBoolean(this.field_6_flags1, z);
    }

    @Internal
    public void setFEmptySpecial(boolean z) {
        this.field_10_flags2 = (byte) fEmptySpecial.setBoolean(this.field_10_flags2, z);
    }

    @Internal
    public void setFEncrypted(boolean z) {
        this.field_6_flags1 = (short) fEncrypted.setBoolean(this.field_6_flags1, z);
    }

    @Internal
    public void setFExtChar(boolean z) {
        this.field_6_flags1 = (short) fExtChar.setBoolean(this.field_6_flags1, z);
    }

    @Internal
    public void setFFarEast(boolean z) {
        this.field_6_flags1 = (short) fFarEast.setBoolean(this.field_6_flags1, z);
    }

    @Internal
    public void setFGlsy(boolean z) {
        this.field_6_flags1 = (short) fGlsy.setBoolean(this.field_6_flags1, z);
    }

    @Internal
    public void setFHasPic(boolean z) {
        this.field_6_flags1 = (short) fHasPic.setBoolean(this.field_6_flags1, z);
    }

    @Internal
    public void setFLoadOverride(boolean z) {
        this.field_6_flags1 = (short) fLoadOverride.setBoolean(this.field_6_flags1, z);
    }

    @Internal
    public void setFLoadOverridePage(boolean z) {
        this.field_10_flags2 = (byte) fLoadOverridePage.setBoolean(this.field_10_flags2, z);
    }

    @Internal
    public void setFMac(boolean z) {
        this.field_10_flags2 = (byte) fMac.setBoolean(this.field_10_flags2, z);
    }

    @Internal
    public void setFObfuscated(boolean z) {
        this.field_6_flags1 = (short) fObfuscated.setBoolean(this.field_6_flags1, z);
    }

    @Internal
    public void setFReadOnlyRecommended(boolean z) {
        this.field_6_flags1 = (short) fReadOnlyRecommended.setBoolean(this.field_6_flags1, z);
    }

    @Internal
    public void setFSpare0(byte b2) {
        this.field_10_flags2 = (byte) fSpare0.setValue(this.field_10_flags2, b2);
    }

    @Internal
    public void setFWhichTblStm(boolean z) {
        this.field_6_flags1 = (short) fWhichTblStm.setBoolean(this.field_6_flags1, z);
    }

    @Internal
    public void setFWriteReservation(boolean z) {
        this.field_6_flags1 = (short) fWriteReservation.setBoolean(this.field_6_flags1, z);
    }

    @Internal
    public void setFcMac(int i2) {
        this.field_14_fcMac = i2;
    }

    @Internal
    public void setFcMin(int i2) {
        this.field_13_fcMin = i2;
    }

    @Internal
    public void setFlags1(short s) {
        this.field_6_flags1 = s;
    }

    @Internal
    public void setFlags2(byte b2) {
        this.field_10_flags2 = b2;
    }

    @Internal
    public void setLKey(int i2) {
        this.field_8_lKey = i2;
    }

    @Internal
    public void setLid(int i2) {
        this.field_4_lid = i2;
    }

    @Internal
    public void setNFib(int i2) {
        this.field_2_nFib = i2;
    }

    @Internal
    public void setNFibBack(int i2) {
        this.field_7_nFibBack = i2;
    }

    @Internal
    public void setPnNext(int i2) {
        this.field_5_pnNext = i2;
    }

    @Internal
    public void setReserved1(boolean z) {
        this.field_10_flags2 = (byte) reserved1.setBoolean(this.field_10_flags2, z);
    }

    @Internal
    public void setReserved2(boolean z) {
        this.field_10_flags2 = (byte) reserved2.setBoolean(this.field_10_flags2, z);
    }

    @Internal
    public void setUnused(int i2) {
        this.field_3_unused = i2;
    }

    @Internal
    public void setWIdent(int i2) {
        this.field_1_wIdent = i2;
    }

    public String toString() {
        StringBuilder d2 = a.d("[FibBase]\n", "    .wIdent               = ", " (");
        d2.append(getWIdent());
        d2.append(" )\n");
        d2.append("    .nFib                 = ");
        d2.append(" (");
        d2.append(getNFib());
        d2.append(" )\n");
        d2.append("    .unused               = ");
        d2.append(" (");
        d2.append(getUnused());
        d2.append(" )\n");
        d2.append("    .lid                  = ");
        d2.append(" (");
        d2.append(getLid());
        d2.append(" )\n");
        d2.append("    .pnNext               = ");
        d2.append(" (");
        d2.append(getPnNext());
        d2.append(" )\n");
        d2.append("    .flags1               = ");
        d2.append(" (");
        d2.append((int) getFlags1());
        d2.append(" )\n");
        d2.append("         .fDot                     = ");
        d2.append(isFDot());
        d2.append('\n');
        d2.append("         .fGlsy                    = ");
        d2.append(isFGlsy());
        d2.append('\n');
        d2.append("         .fComplex                 = ");
        d2.append(isFComplex());
        d2.append('\n');
        d2.append("         .fHasPic                  = ");
        d2.append(isFHasPic());
        d2.append('\n');
        d2.append("         .cQuickSaves              = ");
        d2.append((int) getCQuickSaves());
        d2.append('\n');
        d2.append("         .fEncrypted               = ");
        d2.append(isFEncrypted());
        d2.append('\n');
        d2.append("         .fWhichTblStm             = ");
        d2.append(isFWhichTblStm());
        d2.append('\n');
        d2.append("         .fReadOnlyRecommended     = ");
        d2.append(isFReadOnlyRecommended());
        d2.append('\n');
        d2.append("         .fWriteReservation        = ");
        d2.append(isFWriteReservation());
        d2.append('\n');
        d2.append("         .fExtChar                 = ");
        d2.append(isFExtChar());
        d2.append('\n');
        d2.append("         .fLoadOverride            = ");
        d2.append(isFLoadOverride());
        d2.append('\n');
        d2.append("         .fFarEast                 = ");
        d2.append(isFFarEast());
        d2.append('\n');
        d2.append("         .fObfuscated              = ");
        d2.append(isFObfuscated());
        d2.append('\n');
        d2.append("    .nFibBack             = ");
        d2.append(" (");
        d2.append(getNFibBack());
        d2.append(" )\n");
        d2.append("    .lKey                 = ");
        d2.append(" (");
        d2.append(getLKey());
        d2.append(" )\n");
        d2.append("    .envr                 = ");
        d2.append(" (");
        d2.append((int) getEnvr());
        d2.append(" )\n");
        d2.append("    .flags2               = ");
        d2.append(" (");
        d2.append((int) getFlags2());
        d2.append(" )\n");
        d2.append("         .fMac                     = ");
        d2.append(isFMac());
        d2.append('\n');
        d2.append("         .fEmptySpecial            = ");
        d2.append(isFEmptySpecial());
        d2.append('\n');
        d2.append("         .fLoadOverridePage        = ");
        d2.append(isFLoadOverridePage());
        d2.append('\n');
        d2.append("         .reserved1                = ");
        d2.append(isReserved1());
        d2.append('\n');
        d2.append("         .reserved2                = ");
        d2.append(isReserved2());
        d2.append('\n');
        d2.append("         .fSpare0                  = ");
        d2.append((int) getFSpare0());
        d2.append('\n');
        d2.append("    .Chs                  = ");
        d2.append(" (");
        d2.append((int) getChs());
        d2.append(" )\n");
        d2.append("    .chsTables            = ");
        d2.append(" (");
        d2.append((int) getChsTables());
        d2.append(" )\n");
        d2.append("    .fcMin                = ");
        d2.append(" (");
        d2.append(getFcMin());
        d2.append(" )\n");
        d2.append("    .fcMac                = ");
        d2.append(" (");
        d2.append(getFcMac());
        d2.append(" )\n");
        d2.append("[/FibBase]\n");
        return d2.toString();
    }

    public byte[] serialize() {
        byte[] bArr = new byte[getSize()];
        serialize(bArr, 0);
        return bArr;
    }
}
