package org.apache.poi.hwpf.model.types;

import b.b.a.a.a;
import org.apache.poi.hwpf.model.Grfhic;
import org.apache.poi.util.Internal;
import org.apache.poi.util.LittleEndian;

@Internal
public abstract class LFOAbstractType {
    public int field_1_lsid;
    public int field_2_unused1;
    public int field_3_unused2;
    public byte field_4_clfolvl;
    public byte field_5_ibstFltAutoNum;
    public Grfhic field_6_grfhic = new Grfhic();
    public byte field_7_unused3;

    public static int getSize() {
        return 16;
    }

    public boolean equals(Object obj) {
        if (this == obj) {
            return true;
        }
        if (obj == null || getClass() != obj.getClass()) {
            return false;
        }
        LFOAbstractType lFOAbstractType = (LFOAbstractType) obj;
        if (this.field_1_lsid != lFOAbstractType.field_1_lsid || this.field_2_unused1 != lFOAbstractType.field_2_unused1 || this.field_3_unused2 != lFOAbstractType.field_3_unused2 || this.field_4_clfolvl != lFOAbstractType.field_4_clfolvl || this.field_5_ibstFltAutoNum != lFOAbstractType.field_5_ibstFltAutoNum) {
            return false;
        }
        Grfhic grfhic = this.field_6_grfhic;
        if (grfhic == null) {
            if (lFOAbstractType.field_6_grfhic != null) {
                return false;
            }
        } else if (!grfhic.equals(lFOAbstractType.field_6_grfhic)) {
            return false;
        }
        return this.field_7_unused3 == lFOAbstractType.field_7_unused3;
    }

    public void fillFields(byte[] bArr, int i2) {
        this.field_1_lsid = LittleEndian.getInt(bArr, i2 + 0);
        this.field_2_unused1 = LittleEndian.getInt(bArr, i2 + 4);
        this.field_3_unused2 = LittleEndian.getInt(bArr, i2 + 8);
        this.field_4_clfolvl = bArr[i2 + 12];
        this.field_5_ibstFltAutoNum = bArr[i2 + 13];
        this.field_6_grfhic = new Grfhic(bArr, i2 + 14);
        this.field_7_unused3 = bArr[i2 + 15];
    }

    @Internal
    public byte getClfolvl() {
        return this.field_4_clfolvl;
    }

    @Internal
    public Grfhic getGrfhic() {
        return this.field_6_grfhic;
    }

    @Internal
    public byte getIbstFltAutoNum() {
        return this.field_5_ibstFltAutoNum;
    }

    @Internal
    public int getLsid() {
        return this.field_1_lsid;
    }

    @Internal
    public int getUnused1() {
        return this.field_2_unused1;
    }

    @Internal
    public int getUnused2() {
        return this.field_3_unused2;
    }

    @Internal
    public byte getUnused3() {
        return this.field_7_unused3;
    }

    public int hashCode() {
        int i2 = (((((((((this.field_1_lsid + 31) * 31) + this.field_2_unused1) * 31) + this.field_3_unused2) * 31) + this.field_4_clfolvl) * 31) + this.field_5_ibstFltAutoNum) * 31;
        Grfhic grfhic = this.field_6_grfhic;
        return ((i2 + (grfhic == null ? 0 : grfhic.hashCode())) * 31) + this.field_7_unused3;
    }

    public void serialize(byte[] bArr, int i2) {
        LittleEndian.putInt(bArr, i2 + 0, this.field_1_lsid);
        LittleEndian.putInt(bArr, i2 + 4, this.field_2_unused1);
        LittleEndian.putInt(bArr, i2 + 8, this.field_3_unused2);
        bArr[i2 + 12] = this.field_4_clfolvl;
        bArr[i2 + 13] = this.field_5_ibstFltAutoNum;
        this.field_6_grfhic.serialize(bArr, i2 + 14);
        bArr[i2 + 15] = this.field_7_unused3;
    }

    @Internal
    public void setClfolvl(byte b2) {
        this.field_4_clfolvl = b2;
    }

    @Internal
    public void setGrfhic(Grfhic grfhic) {
        this.field_6_grfhic = grfhic;
    }

    @Internal
    public void setIbstFltAutoNum(byte b2) {
        this.field_5_ibstFltAutoNum = b2;
    }

    @Internal
    public void setLsid(int i2) {
        this.field_1_lsid = i2;
    }

    @Internal
    public void setUnused1(int i2) {
        this.field_2_unused1 = i2;
    }

    @Internal
    public void setUnused2(int i2) {
        this.field_3_unused2 = i2;
    }

    @Internal
    public void setUnused3(byte b2) {
        this.field_7_unused3 = b2;
    }

    public String toString() {
        StringBuilder d2 = a.d("[LFO]\n", "    .lsid                 = ", " ( ");
        d2.append(this.field_1_lsid);
        d2.append(" )\n");
        d2.append("    .unused1              = ");
        d2.append(" ( ");
        d2.append(this.field_2_unused1);
        d2.append(" )\n");
        d2.append("    .unused2              = ");
        d2.append(" ( ");
        d2.append(this.field_3_unused2);
        d2.append(" )\n");
        d2.append("    .clfolvl              = ");
        d2.append(" ( ");
        d2.append((int) this.field_4_clfolvl);
        d2.append(" )\n");
        d2.append("    .ibstFltAutoNum       = ");
        d2.append(" ( ");
        d2.append((int) this.field_5_ibstFltAutoNum);
        d2.append(" )\n");
        d2.append("    .grfhic               = ");
        d2.append(" ( ");
        Grfhic grfhic = this.field_6_grfhic;
        d2.append(grfhic == null ? "null" : grfhic.toString().replaceAll("\n", "\n    "));
        d2.append(" )\n");
        d2.append("    .unused3              = ");
        d2.append(" ( ");
        d2.append((int) this.field_7_unused3);
        d2.append(" )\n");
        d2.append("[/LFO]");
        return d2.toString();
    }

    public byte[] serialize() {
        byte[] bArr = new byte[getSize()];
        serialize(bArr, 0);
        return bArr;
    }
}
