package org.apache.poi.hwpf.model.types;

import b.b.a.a.a;
import org.apache.poi.util.BitField;
import org.apache.poi.util.Internal;
import org.apache.poi.util.LittleEndian;

@Internal
public abstract class LFOLVLBaseAbstractType {
    public static final BitField fFormatting = new BitField(32);
    public static final BitField fStartAt = new BitField(16);
    public static final BitField grfhic = new BitField(16320);
    public static final BitField iLvl = new BitField(15);
    public static final BitField unused1 = new BitField(536854528);
    public static final BitField unused2 = new BitField(-536870912);
    public int field_1_iStartAt;
    public int field_2_flags;

    public static int getSize() {
        return 8;
    }

    public boolean equals(Object obj) {
        if (this == obj) {
            return true;
        }
        if (obj == null || getClass() != obj.getClass()) {
            return false;
        }
        LFOLVLBaseAbstractType lFOLVLBaseAbstractType = (LFOLVLBaseAbstractType) obj;
        return this.field_1_iStartAt == lFOLVLBaseAbstractType.field_1_iStartAt && this.field_2_flags == lFOLVLBaseAbstractType.field_2_flags;
    }

    public void fillFields(byte[] bArr, int i2) {
        this.field_1_iStartAt = LittleEndian.getInt(bArr, i2 + 0);
        this.field_2_flags = LittleEndian.getInt(bArr, i2 + 4);
    }

    @Internal
    public int getFlags() {
        return this.field_2_flags;
    }

    @Internal
    public short getGrfhic() {
        return (short) grfhic.getValue(this.field_2_flags);
    }

    @Internal
    public byte getILvl() {
        return (byte) iLvl.getValue(this.field_2_flags);
    }

    @Internal
    public int getIStartAt() {
        return this.field_1_iStartAt;
    }

    @Internal
    @Deprecated
    public short getUnused1() {
        return (short) unused1.getValue(this.field_2_flags);
    }

    @Internal
    @Deprecated
    public byte getUnused2() {
        return (byte) unused2.getValue(this.field_2_flags);
    }

    public int hashCode() {
        return ((this.field_1_iStartAt + 31) * 31) + this.field_2_flags;
    }

    @Internal
    public boolean isFFormatting() {
        return fFormatting.isSet(this.field_2_flags);
    }

    @Internal
    public boolean isFStartAt() {
        return fStartAt.isSet(this.field_2_flags);
    }

    public void serialize(byte[] bArr, int i2) {
        LittleEndian.putInt(bArr, i2 + 0, this.field_1_iStartAt);
        LittleEndian.putInt(bArr, i2 + 4, this.field_2_flags);
    }

    @Internal
    public void setFFormatting(boolean z) {
        this.field_2_flags = fFormatting.setBoolean(this.field_2_flags, z);
    }

    @Internal
    public void setFStartAt(boolean z) {
        this.field_2_flags = fStartAt.setBoolean(this.field_2_flags, z);
    }

    @Internal
    public void setFlags(int i2) {
        this.field_2_flags = i2;
    }

    @Internal
    public void setGrfhic(short s) {
        this.field_2_flags = grfhic.setValue(this.field_2_flags, s);
    }

    @Internal
    public void setILvl(byte b2) {
        this.field_2_flags = iLvl.setValue(this.field_2_flags, b2);
    }

    @Internal
    public void setIStartAt(int i2) {
        this.field_1_iStartAt = i2;
    }

    @Internal
    public void setUnused1(short s) {
        this.field_2_flags = unused1.setValue(this.field_2_flags, s);
    }

    @Internal
    public void setUnused2(byte b2) {
        this.field_2_flags = unused2.setValue(this.field_2_flags, b2);
    }

    public String toString() {
        StringBuilder d2 = a.d("[LFOLVLBase]\n", "    .iStartAt             = ", " (");
        d2.append(getIStartAt());
        d2.append(" )\n");
        d2.append("    .flags                = ");
        d2.append(" (");
        d2.append(getFlags());
        d2.append(" )\n");
        d2.append("         .iLvl                     = ");
        d2.append((int) getILvl());
        d2.append('\n');
        d2.append("         .fStartAt                 = ");
        d2.append(isFStartAt());
        d2.append('\n');
        d2.append("         .fFormatting              = ");
        d2.append(isFFormatting());
        d2.append('\n');
        d2.append("         .grfhic                   = ");
        d2.append((int) getGrfhic());
        d2.append('\n');
        d2.append("         .unused1                  = ");
        d2.append((int) getUnused1());
        d2.append('\n');
        d2.append("         .unused2                  = ");
        d2.append((int) getUnused2());
        d2.append('\n');
        d2.append("[/LFOLVLBase]\n");
        return d2.toString();
    }

    public byte[] serialize() {
        byte[] bArr = new byte[getSize()];
        serialize(bArr, 0);
        return bArr;
    }
}
