package org.apache.poi.hwpf.model.types;

import b.b.a.a.a;
import java.util.Arrays;
import org.apache.poi.hwpf.model.Grfhic;
import org.apache.poi.util.BitField;
import org.apache.poi.util.Internal;
import org.apache.poi.util.LittleEndian;

@Internal
public abstract class LSTFAbstractType {
    public static final BitField fAutoNum = new BitField(4);
    public static final BitField fHybrid = new BitField(16);
    public static final BitField fSimpleList = new BitField(1);
    public static final BitField reserved1 = new BitField(224);
    public static final BitField unused1 = new BitField(2);
    public static final BitField unused2 = new BitField(8);
    public int field_1_lsid;
    public int field_2_tplc;
    public short[] field_3_rgistdPara = new short[0];
    public byte field_4_flags;
    public Grfhic field_5_grfhic = new Grfhic();

    public static int getSize() {
        return 28;
    }

    public boolean equals(Object obj) {
        if (this == obj) {
            return true;
        }
        if (obj == null || getClass() != obj.getClass()) {
            return false;
        }
        LSTFAbstractType lSTFAbstractType = (LSTFAbstractType) obj;
        if (this.field_1_lsid != lSTFAbstractType.field_1_lsid || this.field_2_tplc != lSTFAbstractType.field_2_tplc || !Arrays.equals(this.field_3_rgistdPara, lSTFAbstractType.field_3_rgistdPara) || this.field_4_flags != lSTFAbstractType.field_4_flags) {
            return false;
        }
        Grfhic grfhic = this.field_5_grfhic;
        if (grfhic == null) {
            if (lSTFAbstractType.field_5_grfhic != null) {
                return false;
            }
        } else if (!grfhic.equals(lSTFAbstractType.field_5_grfhic)) {
            return false;
        }
        return true;
    }

    public void fillFields(byte[] bArr, int i2) {
        this.field_1_lsid = LittleEndian.getInt(bArr, i2 + 0);
        this.field_2_tplc = LittleEndian.getInt(bArr, i2 + 4);
        this.field_3_rgistdPara = LittleEndian.getShortArray(bArr, i2 + 8, 18);
        this.field_4_flags = bArr[i2 + 26];
        this.field_5_grfhic = new Grfhic(bArr, i2 + 27);
    }

    @Internal
    public byte getFlags() {
        return this.field_4_flags;
    }

    @Internal
    public Grfhic getGrfhic() {
        return this.field_5_grfhic;
    }

    @Internal
    public int getLsid() {
        return this.field_1_lsid;
    }

    @Internal
    @Deprecated
    public byte getReserved1() {
        return (byte) reserved1.getValue(this.field_4_flags);
    }

    @Internal
    public short[] getRgistdPara() {
        return this.field_3_rgistdPara;
    }

    @Internal
    public int getTplc() {
        return this.field_2_tplc;
    }

    public int hashCode() {
        int hashCode = Arrays.hashCode(this.field_3_rgistdPara);
        return this.field_5_grfhic.hashCode() + ((((hashCode + ((((this.field_1_lsid + 31) * 31) + this.field_2_tplc) * 31)) * 31) + this.field_4_flags) * 31);
    }

    @Internal
    public boolean isFAutoNum() {
        return fAutoNum.isSet(this.field_4_flags);
    }

    @Internal
    public boolean isFHybrid() {
        return fHybrid.isSet(this.field_4_flags);
    }

    @Internal
    public boolean isFSimpleList() {
        return fSimpleList.isSet(this.field_4_flags);
    }

    @Internal
    @Deprecated
    public boolean isUnused1() {
        return unused1.isSet(this.field_4_flags);
    }

    @Internal
    @Deprecated
    public boolean isUnused2() {
        return unused2.isSet(this.field_4_flags);
    }

    public void serialize(byte[] bArr, int i2) {
        LittleEndian.putInt(bArr, i2 + 0, this.field_1_lsid);
        LittleEndian.putInt(bArr, i2 + 4, this.field_2_tplc);
        LittleEndian.putShortArray(bArr, i2 + 8, this.field_3_rgistdPara);
        bArr[i2 + 26] = this.field_4_flags;
        this.field_5_grfhic.serialize(bArr, i2 + 27);
    }

    @Internal
    public void setFAutoNum(boolean z) {
        this.field_4_flags = (byte) fAutoNum.setBoolean(this.field_4_flags, z);
    }

    @Internal
    public void setFHybrid(boolean z) {
        this.field_4_flags = (byte) fHybrid.setBoolean(this.field_4_flags, z);
    }

    @Internal
    public void setFSimpleList(boolean z) {
        this.field_4_flags = (byte) fSimpleList.setBoolean(this.field_4_flags, z);
    }

    @Internal
    public void setFlags(byte b2) {
        this.field_4_flags = b2;
    }

    @Internal
    public void setGrfhic(Grfhic grfhic) {
        this.field_5_grfhic = grfhic;
    }

    @Internal
    public void setLsid(int i2) {
        this.field_1_lsid = i2;
    }

    @Internal
    public void setReserved1(byte b2) {
        this.field_4_flags = (byte) reserved1.setValue(this.field_4_flags, b2);
    }

    @Internal
    public void setRgistdPara(short[] sArr) {
        this.field_3_rgistdPara = sArr;
    }

    @Internal
    public void setTplc(int i2) {
        this.field_2_tplc = i2;
    }

    @Internal
    public void setUnused1(boolean z) {
        this.field_4_flags = (byte) unused1.setBoolean(this.field_4_flags, z);
    }

    @Internal
    public void setUnused2(boolean z) {
        this.field_4_flags = (byte) unused2.setBoolean(this.field_4_flags, z);
    }

    public String toString() {
        StringBuilder d2 = a.d("[LSTF]\n", "    .lsid                 = ", " (");
        d2.append(getLsid());
        d2.append(" )\n");
        d2.append("    .tplc                 = ");
        d2.append(" (");
        d2.append(getTplc());
        d2.append(" )\n");
        d2.append("    .rgistdPara           = ");
        d2.append(" (");
        d2.append(Arrays.toString(getRgistdPara()));
        d2.append(" )\n");
        d2.append("    .flags                = ");
        d2.append(" (");
        d2.append((int) getFlags());
        d2.append(" )\n");
        d2.append("         .fSimpleList              = ");
        d2.append(isFSimpleList());
        d2.append('\n');
        d2.append("         .unused1                  = ");
        d2.append(isUnused1());
        d2.append('\n');
        d2.append("         .fAutoNum                 = ");
        d2.append(isFAutoNum());
        d2.append('\n');
        d2.append("         .unused2                  = ");
        d2.append(isUnused2());
        d2.append('\n');
        d2.append("         .fHybrid                  = ");
        d2.append(isFHybrid());
        d2.append('\n');
        d2.append("         .reserved1                = ");
        d2.append((int) getReserved1());
        d2.append('\n');
        d2.append("    .grfhic               = ");
        d2.append(" (");
        d2.append(getGrfhic());
        return a.a(d2, " )\n", "[/LSTF]\n");
    }

    public byte[] serialize() {
        byte[] bArr = new byte[getSize()];
        serialize(bArr, 0);
        return bArr;
    }
}
