package org.apache.poi.hwpf.model.types;

import b.b.a.a.a;
import java.util.Arrays;
import org.apache.poi.hwpf.model.Grfhic;
import org.apache.poi.util.BitField;
import org.apache.poi.util.Internal;
import org.apache.poi.util.LittleEndian;

@Internal
public abstract class LVLFAbstractType {
    public static final BitField fConverted = new BitField(32);
    public static final BitField fIndentSav = new BitField(16);
    public static final BitField fLegal = new BitField(4);
    public static final BitField fNoRestart = new BitField(8);
    public static final BitField fTentative = new BitField(128);
    public static final BitField jc = new BitField(3);
    public static final BitField unused1 = new BitField(64);
    public short field_10_ilvlRestartLim;
    public Grfhic field_11_grfhic = new Grfhic();
    public int field_1_iStartAt;
    public byte field_2_nfc;
    public byte field_3_info;
    public byte[] field_4_rgbxchNums = new byte[9];
    public byte field_5_ixchFollow;
    public int field_6_dxaIndentSav;
    public int field_7_unused2;
    public short field_8_cbGrpprlChpx;
    public short field_9_cbGrpprlPapx;

    public static int getSize() {
        return 28;
    }

    public boolean equals(Object obj) {
        if (this == obj) {
            return true;
        }
        if (obj == null || getClass() != obj.getClass()) {
            return false;
        }
        LVLFAbstractType lVLFAbstractType = (LVLFAbstractType) obj;
        if (this.field_1_iStartAt != lVLFAbstractType.field_1_iStartAt || this.field_2_nfc != lVLFAbstractType.field_2_nfc || this.field_3_info != lVLFAbstractType.field_3_info || !Arrays.equals(this.field_4_rgbxchNums, lVLFAbstractType.field_4_rgbxchNums) || this.field_5_ixchFollow != lVLFAbstractType.field_5_ixchFollow || this.field_6_dxaIndentSav != lVLFAbstractType.field_6_dxaIndentSav || this.field_7_unused2 != lVLFAbstractType.field_7_unused2 || this.field_8_cbGrpprlChpx != lVLFAbstractType.field_8_cbGrpprlChpx || this.field_9_cbGrpprlPapx != lVLFAbstractType.field_9_cbGrpprlPapx || this.field_10_ilvlRestartLim != lVLFAbstractType.field_10_ilvlRestartLim) {
            return false;
        }
        Grfhic grfhic = this.field_11_grfhic;
        if (grfhic == null) {
            if (lVLFAbstractType.field_11_grfhic != null) {
                return false;
            }
        } else if (!grfhic.equals(lVLFAbstractType.field_11_grfhic)) {
            return false;
        }
        return true;
    }

    public void fillFields(byte[] bArr, int i2) {
        this.field_1_iStartAt = LittleEndian.getInt(bArr, i2 + 0);
        this.field_2_nfc = bArr[i2 + 4];
        this.field_3_info = bArr[i2 + 5];
        this.field_4_rgbxchNums = LittleEndian.getByteArray(bArr, i2 + 6, 9);
        this.field_5_ixchFollow = bArr[i2 + 15];
        this.field_6_dxaIndentSav = LittleEndian.getInt(bArr, i2 + 16);
        this.field_7_unused2 = LittleEndian.getInt(bArr, i2 + 20);
        this.field_8_cbGrpprlChpx = LittleEndian.getUByte(bArr, i2 + 24);
        this.field_9_cbGrpprlPapx = LittleEndian.getUByte(bArr, i2 + 25);
        this.field_10_ilvlRestartLim = LittleEndian.getUByte(bArr, i2 + 26);
        this.field_11_grfhic = new Grfhic(bArr, i2 + 27);
    }

    @Internal
    public short getCbGrpprlChpx() {
        return this.field_8_cbGrpprlChpx;
    }

    @Internal
    public short getCbGrpprlPapx() {
        return this.field_9_cbGrpprlPapx;
    }

    @Internal
    public int getDxaIndentSav() {
        return this.field_6_dxaIndentSav;
    }

    @Internal
    public Grfhic getGrfhic() {
        return this.field_11_grfhic;
    }

    @Internal
    public int getIStartAt() {
        return this.field_1_iStartAt;
    }

    @Internal
    public short getIlvlRestartLim() {
        return this.field_10_ilvlRestartLim;
    }

    @Internal
    public byte getInfo() {
        return this.field_3_info;
    }

    @Internal
    public byte getIxchFollow() {
        return this.field_5_ixchFollow;
    }

    @Internal
    public byte getJc() {
        return (byte) jc.getValue(this.field_3_info);
    }

    @Internal
    public byte getNfc() {
        return this.field_2_nfc;
    }

    @Internal
    public byte[] getRgbxchNums() {
        return this.field_4_rgbxchNums;
    }

    @Internal
    public int getUnused2() {
        return this.field_7_unused2;
    }

    public int hashCode() {
        int hashCode = Arrays.hashCode(this.field_4_rgbxchNums);
        return this.field_11_grfhic.hashCode() + ((((((((((((((hashCode + ((((((this.field_1_iStartAt + 31) * 31) + this.field_2_nfc) * 31) + this.field_3_info) * 31)) * 31) + this.field_5_ixchFollow) * 31) + this.field_6_dxaIndentSav) * 31) + this.field_7_unused2) * 31) + this.field_8_cbGrpprlChpx) * 31) + this.field_9_cbGrpprlPapx) * 31) + this.field_10_ilvlRestartLim) * 31);
    }

    @Internal
    public boolean isFConverted() {
        return fConverted.isSet(this.field_3_info);
    }

    @Internal
    public boolean isFIndentSav() {
        return fIndentSav.isSet(this.field_3_info);
    }

    @Internal
    public boolean isFLegal() {
        return fLegal.isSet(this.field_3_info);
    }

    @Internal
    public boolean isFNoRestart() {
        return fNoRestart.isSet(this.field_3_info);
    }

    @Internal
    public boolean isFTentative() {
        return fTentative.isSet(this.field_3_info);
    }

    @Internal
    @Deprecated
    public boolean isUnused1() {
        return unused1.isSet(this.field_3_info);
    }

    public void serialize(byte[] bArr, int i2) {
        LittleEndian.putInt(bArr, i2 + 0, this.field_1_iStartAt);
        bArr[i2 + 4] = this.field_2_nfc;
        bArr[i2 + 5] = this.field_3_info;
        byte[] bArr2 = this.field_4_rgbxchNums;
        System.arraycopy(bArr2, 0, bArr, i2 + 6, bArr2.length);
        bArr[i2 + 15] = this.field_5_ixchFollow;
        LittleEndian.putInt(bArr, i2 + 16, this.field_6_dxaIndentSav);
        LittleEndian.putInt(bArr, i2 + 20, this.field_7_unused2);
        LittleEndian.putUByte(bArr, i2 + 24, this.field_8_cbGrpprlChpx);
        LittleEndian.putUByte(bArr, i2 + 25, this.field_9_cbGrpprlPapx);
        LittleEndian.putUByte(bArr, i2 + 26, this.field_10_ilvlRestartLim);
        this.field_11_grfhic.serialize(bArr, i2 + 27);
    }

    @Internal
    public void setCbGrpprlChpx(short s) {
        this.field_8_cbGrpprlChpx = s;
    }

    @Internal
    public void setCbGrpprlPapx(short s) {
        this.field_9_cbGrpprlPapx = s;
    }

    @Internal
    public void setDxaIndentSav(int i2) {
        this.field_6_dxaIndentSav = i2;
    }

    @Internal
    public void setFConverted(boolean z) {
        this.field_3_info = (byte) fConverted.setBoolean(this.field_3_info, z);
    }

    @Internal
    public void setFIndentSav(boolean z) {
        this.field_3_info = (byte) fIndentSav.setBoolean(this.field_3_info, z);
    }

    @Internal
    public void setFLegal(boolean z) {
        this.field_3_info = (byte) fLegal.setBoolean(this.field_3_info, z);
    }

    @Internal
    public void setFNoRestart(boolean z) {
        this.field_3_info = (byte) fNoRestart.setBoolean(this.field_3_info, z);
    }

    @Internal
    public void setFTentative(boolean z) {
        this.field_3_info = (byte) fTentative.setBoolean(this.field_3_info, z);
    }

    @Internal
    public void setGrfhic(Grfhic grfhic) {
        this.field_11_grfhic = grfhic;
    }

    @Internal
    public void setIStartAt(int i2) {
        this.field_1_iStartAt = i2;
    }

    @Internal
    public void setIlvlRestartLim(short s) {
        this.field_10_ilvlRestartLim = s;
    }

    @Internal
    public void setInfo(byte b2) {
        this.field_3_info = b2;
    }

    @Internal
    public void setIxchFollow(byte b2) {
        this.field_5_ixchFollow = b2;
    }

    @Internal
    public void setJc(byte b2) {
        this.field_3_info = (byte) jc.setValue(this.field_3_info, b2);
    }

    @Internal
    public void setNfc(byte b2) {
        this.field_2_nfc = b2;
    }

    @Internal
    public void setRgbxchNums(byte[] bArr) {
        this.field_4_rgbxchNums = bArr;
    }

    @Internal
    public void setUnused1(boolean z) {
        this.field_3_info = (byte) unused1.setBoolean(this.field_3_info, z);
    }

    @Internal
    public void setUnused2(int i2) {
        this.field_7_unused2 = i2;
    }

    public String toString() {
        StringBuilder d2 = a.d("[LVLF]\n", "    .iStartAt             = ", " (");
        d2.append(getIStartAt());
        d2.append(" )\n");
        d2.append("    .nfc                  = ");
        d2.append(" (");
        d2.append((int) getNfc());
        d2.append(" )\n");
        d2.append("    .info                 = ");
        d2.append(" (");
        d2.append((int) getInfo());
        d2.append(" )\n");
        d2.append("         .jc                       = ");
        d2.append((int) getJc());
        d2.append('\n');
        d2.append("         .fLegal                   = ");
        d2.append(isFLegal());
        d2.append('\n');
        d2.append("         .fNoRestart               = ");
        d2.append(isFNoRestart());
        d2.append('\n');
        d2.append("         .fIndentSav               = ");
        d2.append(isFIndentSav());
        d2.append('\n');
        d2.append("         .fConverted               = ");
        d2.append(isFConverted());
        d2.append('\n');
        d2.append("         .unused1                  = ");
        d2.append(isUnused1());
        d2.append('\n');
        d2.append("         .fTentative               = ");
        d2.append(isFTentative());
        d2.append('\n');
        d2.append("    .rgbxchNums           = ");
        d2.append(" (");
        d2.append(Arrays.toString(getRgbxchNums()));
        d2.append(" )\n");
        d2.append("    .ixchFollow           = ");
        d2.append(" (");
        d2.append((int) getIxchFollow());
        d2.append(" )\n");
        d2.append("    .dxaIndentSav         = ");
        d2.append(" (");
        d2.append(getDxaIndentSav());
        d2.append(" )\n");
        d2.append("    .unused2              = ");
        d2.append(" (");
        d2.append(getUnused2());
        d2.append(" )\n");
        d2.append("    .cbGrpprlChpx         = ");
        d2.append(" (");
        d2.append((int) getCbGrpprlChpx());
        d2.append(" )\n");
        d2.append("    .cbGrpprlPapx         = ");
        d2.append(" (");
        d2.append((int) getCbGrpprlPapx());
        d2.append(" )\n");
        d2.append("    .ilvlRestartLim       = ");
        d2.append(" (");
        d2.append((int) getIlvlRestartLim());
        d2.append(" )\n");
        d2.append("    .grfhic               = ");
        d2.append(" (");
        d2.append(getGrfhic());
        d2.append(" )\n");
        d2.append("[/LVLF]\n");
        return d2.toString();
    }

    public byte[] serialize() {
        byte[] bArr = new byte[getSize()];
        serialize(bArr, 0);
        return bArr;
    }
}
