package org.apache.poi.hwpf.model.types;

import b.b.a.a.a;
import java.util.Arrays;
import org.apache.poi.hwpf.model.TabDescriptor;
import org.apache.poi.hwpf.usermodel.BorderCode;
import org.apache.poi.hwpf.usermodel.DateAndTime;
import org.apache.poi.hwpf.usermodel.DropCapSpecifier;
import org.apache.poi.hwpf.usermodel.LineSpacingDescriptor;
import org.apache.poi.hwpf.usermodel.ShadingDescriptor;
import org.apache.poi.util.BitField;
import org.apache.poi.util.Internal;

@Internal
public abstract class PAPAbstractType {
    public static final byte BRCL_DOUBLE = 2;
    public static final byte BRCL_SHADOW = 3;
    public static final byte BRCL_SINGLE = 0;
    public static final byte BRCL_THICK = 1;
    public static final byte BRCP_BAR_TO_LEFT_OF_PARAGRAPH = 16;
    public static final byte BRCP_BORDER_ABOVE = 1;
    public static final byte BRCP_BORDER_BELOW = 2;
    public static final byte BRCP_BOX_AROUND = 15;
    public static final byte BRCP_NONE = 0;
    public static final boolean FMINHEIGHT_AT_LEAST = true;
    public static final boolean FMINHEIGHT_EXACT = false;
    public static final byte WALIGNFONT_AUTO = 4;
    public static final byte WALIGNFONT_CENTERED = 1;
    public static final byte WALIGNFONT_HANGING = 0;
    public static final byte WALIGNFONT_ROMAN = 2;
    public static final byte WALIGNFONT_VARIABLE = 3;
    public static BitField fBackward = new BitField(2);
    public static BitField fRotateFont = new BitField(4);
    public static BitField fVertical = new BitField(1);
    public boolean field_10_fNoLnn;
    public LineSpacingDescriptor field_11_lspd;
    public int field_12_dyaBefore;
    public int field_13_dyaAfter;
    public boolean field_14_fInTable;
    public boolean field_15_finTableW97;
    public boolean field_16_fTtp;
    public int field_17_dxaAbs;
    public int field_18_dyaAbs;
    public int field_19_dxaWidth;
    public int field_1_istd;
    public boolean field_20_fBrLnAbove;
    public boolean field_21_fBrLnBelow;
    public byte field_22_pcVert;
    public byte field_23_pcHorz;
    public byte field_24_wr;
    public boolean field_25_fNoAutoHyph;
    public int field_26_dyaHeight;
    public boolean field_27_fMinHeight;
    public DropCapSpecifier field_28_dcs;
    public int field_29_dyaFromText;
    public boolean field_2_fSideBySide;
    public int field_30_dxaFromText;
    public boolean field_31_fLocked;
    public boolean field_32_fWidowControl;
    public boolean field_33_fKinsoku;
    public boolean field_34_fWordWrap;
    public boolean field_35_fOverflowPunct;
    public boolean field_36_fTopLinePunct;
    public boolean field_37_fAutoSpaceDE;
    public boolean field_38_fAutoSpaceDN;
    public int field_39_wAlignFont;
    public boolean field_3_fKeep;
    public short field_40_fontAlign;
    public byte field_41_lvl;
    public boolean field_42_fBiDi;
    public boolean field_43_fNumRMIns;
    public boolean field_44_fCrLf;
    public boolean field_45_fUsePgsuSettings;
    public boolean field_46_fAdjustRight;
    public int field_47_itap;
    public boolean field_48_fInnerTableCell;
    public boolean field_49_fOpenTch;
    public boolean field_4_fKeepFollow;
    public boolean field_50_fTtpEmbedded;
    public short field_51_dxcRight;
    public short field_52_dxcLeft;
    public short field_53_dxcLeft1;
    public boolean field_54_fDyaBeforeAuto;
    public boolean field_55_fDyaAfterAuto;
    public int field_56_dxaRight;
    public int field_57_dxaLeft;
    public int field_58_dxaLeft1;
    public byte field_59_jc;
    public boolean field_5_fPageBreakBefore;
    public BorderCode field_60_brcTop;
    public BorderCode field_61_brcLeft;
    public BorderCode field_62_brcBottom;
    public BorderCode field_63_brcRight;
    public BorderCode field_64_brcBetween;
    public BorderCode field_65_brcBar;
    public ShadingDescriptor field_66_shd;
    public byte[] field_67_anld;
    public byte[] field_68_phe;
    public boolean field_69_fPropRMark;
    public byte field_6_brcl;
    public int field_70_ibstPropRMark;
    public DateAndTime field_71_dttmPropRMark;
    public int field_72_itbdMac;
    public int[] field_73_rgdxaTab;
    public TabDescriptor[] field_74_rgtbd;
    public byte[] field_75_numrm;
    public byte[] field_76_ptap;
    public boolean field_77_fNoAllowOverlap;
    public long field_78_ipgp;
    public long field_79_rsid;
    public byte field_7_brcp;
    public byte field_8_ilvl;
    public int field_9_ilfo;

    public PAPAbstractType() {
        this.field_11_lspd = new LineSpacingDescriptor();
        this.field_11_lspd = new LineSpacingDescriptor();
        this.field_28_dcs = new DropCapSpecifier();
        this.field_32_fWidowControl = true;
        this.field_41_lvl = 9;
        this.field_60_brcTop = new BorderCode();
        this.field_61_brcLeft = new BorderCode();
        this.field_62_brcBottom = new BorderCode();
        this.field_63_brcRight = new BorderCode();
        this.field_64_brcBetween = new BorderCode();
        this.field_65_brcBar = new BorderCode();
        this.field_66_shd = new ShadingDescriptor();
        this.field_67_anld = new byte[0];
        this.field_68_phe = new byte[0];
        this.field_71_dttmPropRMark = new DateAndTime();
        this.field_73_rgdxaTab = new int[0];
        this.field_74_rgtbd = new TabDescriptor[0];
        this.field_75_numrm = new byte[0];
        this.field_76_ptap = new byte[0];
    }

    @Internal
    public byte[] getAnld() {
        return this.field_67_anld;
    }

    @Internal
    public BorderCode getBrcBar() {
        return this.field_65_brcBar;
    }

    @Internal
    public BorderCode getBrcBetween() {
        return this.field_64_brcBetween;
    }

    @Internal
    public BorderCode getBrcBottom() {
        return this.field_62_brcBottom;
    }

    @Internal
    public BorderCode getBrcLeft() {
        return this.field_61_brcLeft;
    }

    @Internal
    public BorderCode getBrcRight() {
        return this.field_63_brcRight;
    }

    @Internal
    public BorderCode getBrcTop() {
        return this.field_60_brcTop;
    }

    @Internal
    public byte getBrcl() {
        return this.field_6_brcl;
    }

    @Internal
    public byte getBrcp() {
        return this.field_7_brcp;
    }

    @Internal
    public DropCapSpecifier getDcs() {
        return this.field_28_dcs;
    }

    @Internal
    public DateAndTime getDttmPropRMark() {
        return this.field_71_dttmPropRMark;
    }

    @Internal
    public int getDxaAbs() {
        return this.field_17_dxaAbs;
    }

    @Internal
    public int getDxaFromText() {
        return this.field_30_dxaFromText;
    }

    @Internal
    public int getDxaLeft() {
        return this.field_57_dxaLeft;
    }

    @Internal
    public int getDxaLeft1() {
        return this.field_58_dxaLeft1;
    }

    @Internal
    public int getDxaRight() {
        return this.field_56_dxaRight;
    }

    @Internal
    public int getDxaWidth() {
        return this.field_19_dxaWidth;
    }

    @Internal
    public short getDxcLeft() {
        return this.field_52_dxcLeft;
    }

    @Internal
    public short getDxcLeft1() {
        return this.field_53_dxcLeft1;
    }

    @Internal
    public short getDxcRight() {
        return this.field_51_dxcRight;
    }

    @Internal
    public int getDyaAbs() {
        return this.field_18_dyaAbs;
    }

    @Internal
    public int getDyaAfter() {
        return this.field_13_dyaAfter;
    }

    @Internal
    public int getDyaBefore() {
        return this.field_12_dyaBefore;
    }

    @Internal
    public int getDyaFromText() {
        return this.field_29_dyaFromText;
    }

    @Internal
    public int getDyaHeight() {
        return this.field_26_dyaHeight;
    }

    @Internal
    public boolean getFAdjustRight() {
        return this.field_46_fAdjustRight;
    }

    @Internal
    public boolean getFAutoSpaceDE() {
        return this.field_37_fAutoSpaceDE;
    }

    @Internal
    public boolean getFAutoSpaceDN() {
        return this.field_38_fAutoSpaceDN;
    }

    @Internal
    public boolean getFBiDi() {
        return this.field_42_fBiDi;
    }

    @Internal
    public boolean getFBrLnAbove() {
        return this.field_20_fBrLnAbove;
    }

    @Internal
    public boolean getFBrLnBelow() {
        return this.field_21_fBrLnBelow;
    }

    @Internal
    public boolean getFCrLf() {
        return this.field_44_fCrLf;
    }

    @Internal
    public boolean getFDyaAfterAuto() {
        return this.field_55_fDyaAfterAuto;
    }

    @Internal
    public boolean getFDyaBeforeAuto() {
        return this.field_54_fDyaBeforeAuto;
    }

    @Internal
    public boolean getFInTable() {
        return this.field_14_fInTable;
    }

    @Internal
    public boolean getFInnerTableCell() {
        return this.field_48_fInnerTableCell;
    }

    @Internal
    public boolean getFKeep() {
        return this.field_3_fKeep;
    }

    @Internal
    public boolean getFKeepFollow() {
        return this.field_4_fKeepFollow;
    }

    @Internal
    public boolean getFKinsoku() {
        return this.field_33_fKinsoku;
    }

    @Internal
    public boolean getFLocked() {
        return this.field_31_fLocked;
    }

    @Internal
    public boolean getFMinHeight() {
        return this.field_27_fMinHeight;
    }

    @Internal
    public boolean getFNoAllowOverlap() {
        return this.field_77_fNoAllowOverlap;
    }

    @Internal
    public boolean getFNoAutoHyph() {
        return this.field_25_fNoAutoHyph;
    }

    @Internal
    public boolean getFNoLnn() {
        return this.field_10_fNoLnn;
    }

    @Internal
    public boolean getFNumRMIns() {
        return this.field_43_fNumRMIns;
    }

    @Internal
    public boolean getFOpenTch() {
        return this.field_49_fOpenTch;
    }

    @Internal
    public boolean getFOverflowPunct() {
        return this.field_35_fOverflowPunct;
    }

    @Internal
    public boolean getFPageBreakBefore() {
        return this.field_5_fPageBreakBefore;
    }

    @Internal
    public boolean getFPropRMark() {
        return this.field_69_fPropRMark;
    }

    @Internal
    public boolean getFSideBySide() {
        return this.field_2_fSideBySide;
    }

    @Internal
    public boolean getFTopLinePunct() {
        return this.field_36_fTopLinePunct;
    }

    @Internal
    public boolean getFTtp() {
        return this.field_16_fTtp;
    }

    @Internal
    public boolean getFTtpEmbedded() {
        return this.field_50_fTtpEmbedded;
    }

    @Internal
    public boolean getFUsePgsuSettings() {
        return this.field_45_fUsePgsuSettings;
    }

    @Internal
    public boolean getFWidowControl() {
        return this.field_32_fWidowControl;
    }

    @Internal
    public boolean getFWordWrap() {
        return this.field_34_fWordWrap;
    }

    @Internal
    public boolean getFinTableW97() {
        return this.field_15_finTableW97;
    }

    @Internal
    public short getFontAlign() {
        return this.field_40_fontAlign;
    }

    @Internal
    public int getIbstPropRMark() {
        return this.field_70_ibstPropRMark;
    }

    @Internal
    public int getIlfo() {
        return this.field_9_ilfo;
    }

    @Internal
    public byte getIlvl() {
        return this.field_8_ilvl;
    }

    @Internal
    public long getIpgp() {
        return this.field_78_ipgp;
    }

    @Internal
    public int getIstd() {
        return this.field_1_istd;
    }

    @Internal
    public int getItap() {
        return this.field_47_itap;
    }

    @Internal
    public int getItbdMac() {
        return this.field_72_itbdMac;
    }

    @Internal
    public byte getJc() {
        return this.field_59_jc;
    }

    @Internal
    public LineSpacingDescriptor getLspd() {
        return this.field_11_lspd;
    }

    @Internal
    public byte getLvl() {
        return this.field_41_lvl;
    }

    @Internal
    public byte[] getNumrm() {
        return this.field_75_numrm;
    }

    @Internal
    public byte getPcHorz() {
        return this.field_23_pcHorz;
    }

    @Internal
    public byte getPcVert() {
        return this.field_22_pcVert;
    }

    @Internal
    public byte[] getPhe() {
        return this.field_68_phe;
    }

    @Internal
    public byte[] getPtap() {
        return this.field_76_ptap;
    }

    @Internal
    public int[] getRgdxaTab() {
        return this.field_73_rgdxaTab;
    }

    @Internal
    public TabDescriptor[] getRgtbd() {
        return this.field_74_rgtbd;
    }

    @Internal
    public long getRsid() {
        return this.field_79_rsid;
    }

    @Internal
    public ShadingDescriptor getShd() {
        return this.field_66_shd;
    }

    @Internal
    public int getWAlignFont() {
        return this.field_39_wAlignFont;
    }

    @Internal
    public byte getWr() {
        return this.field_24_wr;
    }

    @Internal
    public boolean isFBackward() {
        return fBackward.isSet(this.field_40_fontAlign);
    }

    @Internal
    public boolean isFRotateFont() {
        return fRotateFont.isSet(this.field_40_fontAlign);
    }

    @Internal
    public boolean isFVertical() {
        return fVertical.isSet(this.field_40_fontAlign);
    }

    @Internal
    public void setAnld(byte[] bArr) {
        this.field_67_anld = bArr;
    }

    @Internal
    public void setBrcBar(BorderCode borderCode) {
        this.field_65_brcBar = borderCode;
    }

    @Internal
    public void setBrcBetween(BorderCode borderCode) {
        this.field_64_brcBetween = borderCode;
    }

    @Internal
    public void setBrcBottom(BorderCode borderCode) {
        this.field_62_brcBottom = borderCode;
    }

    @Internal
    public void setBrcLeft(BorderCode borderCode) {
        this.field_61_brcLeft = borderCode;
    }

    @Internal
    public void setBrcRight(BorderCode borderCode) {
        this.field_63_brcRight = borderCode;
    }

    @Internal
    public void setBrcTop(BorderCode borderCode) {
        this.field_60_brcTop = borderCode;
    }

    @Internal
    public void setBrcl(byte b2) {
        this.field_6_brcl = b2;
    }

    @Internal
    public void setBrcp(byte b2) {
        this.field_7_brcp = b2;
    }

    @Internal
    public void setDcs(DropCapSpecifier dropCapSpecifier) {
        this.field_28_dcs = dropCapSpecifier;
    }

    @Internal
    public void setDttmPropRMark(DateAndTime dateAndTime) {
        this.field_71_dttmPropRMark = dateAndTime;
    }

    @Internal
    public void setDxaAbs(int i2) {
        this.field_17_dxaAbs = i2;
    }

    @Internal
    public void setDxaFromText(int i2) {
        this.field_30_dxaFromText = i2;
    }

    @Internal
    public void setDxaLeft(int i2) {
        this.field_57_dxaLeft = i2;
    }

    @Internal
    public void setDxaLeft1(int i2) {
        this.field_58_dxaLeft1 = i2;
    }

    @Internal
    public void setDxaRight(int i2) {
        this.field_56_dxaRight = i2;
    }

    @Internal
    public void setDxaWidth(int i2) {
        this.field_19_dxaWidth = i2;
    }

    @Internal
    public void setDxcLeft(short s) {
        this.field_52_dxcLeft = s;
    }

    @Internal
    public void setDxcLeft1(short s) {
        this.field_53_dxcLeft1 = s;
    }

    @Internal
    public void setDxcRight(short s) {
        this.field_51_dxcRight = s;
    }

    @Internal
    public void setDyaAbs(int i2) {
        this.field_18_dyaAbs = i2;
    }

    @Internal
    public void setDyaAfter(int i2) {
        this.field_13_dyaAfter = i2;
    }

    @Internal
    public void setDyaBefore(int i2) {
        this.field_12_dyaBefore = i2;
    }

    @Internal
    public void setDyaFromText(int i2) {
        this.field_29_dyaFromText = i2;
    }

    @Internal
    public void setDyaHeight(int i2) {
        this.field_26_dyaHeight = i2;
    }

    @Internal
    public void setFAdjustRight(boolean z) {
        this.field_46_fAdjustRight = z;
    }

    @Internal
    public void setFAutoSpaceDE(boolean z) {
        this.field_37_fAutoSpaceDE = z;
    }

    @Internal
    public void setFAutoSpaceDN(boolean z) {
        this.field_38_fAutoSpaceDN = z;
    }

    @Internal
    public void setFBackward(boolean z) {
        this.field_40_fontAlign = (short) fBackward.setBoolean(this.field_40_fontAlign, z);
    }

    @Internal
    public void setFBiDi(boolean z) {
        this.field_42_fBiDi = z;
    }

    @Internal
    public void setFBrLnAbove(boolean z) {
        this.field_20_fBrLnAbove = z;
    }

    @Internal
    public void setFBrLnBelow(boolean z) {
        this.field_21_fBrLnBelow = z;
    }

    @Internal
    public void setFCrLf(boolean z) {
        this.field_44_fCrLf = z;
    }

    @Internal
    public void setFDyaAfterAuto(boolean z) {
        this.field_55_fDyaAfterAuto = z;
    }

    @Internal
    public void setFDyaBeforeAuto(boolean z) {
        this.field_54_fDyaBeforeAuto = z;
    }

    @Internal
    public void setFInTable(boolean z) {
        this.field_14_fInTable = z;
    }

    @Internal
    public void setFInnerTableCell(boolean z) {
        this.field_48_fInnerTableCell = z;
    }

    @Internal
    public void setFKeep(boolean z) {
        this.field_3_fKeep = z;
    }

    @Internal
    public void setFKeepFollow(boolean z) {
        this.field_4_fKeepFollow = z;
    }

    @Internal
    public void setFKinsoku(boolean z) {
        this.field_33_fKinsoku = z;
    }

    @Internal
    public void setFLocked(boolean z) {
        this.field_31_fLocked = z;
    }

    @Internal
    public void setFMinHeight(boolean z) {
        this.field_27_fMinHeight = z;
    }

    @Internal
    public void setFNoAllowOverlap(boolean z) {
        this.field_77_fNoAllowOverlap = z;
    }

    @Internal
    public void setFNoAutoHyph(boolean z) {
        this.field_25_fNoAutoHyph = z;
    }

    @Internal
    public void setFNoLnn(boolean z) {
        this.field_10_fNoLnn = z;
    }

    @Internal
    public void setFNumRMIns(boolean z) {
        this.field_43_fNumRMIns = z;
    }

    @Internal
    public void setFOpenTch(boolean z) {
        this.field_49_fOpenTch = z;
    }

    @Internal
    public void setFOverflowPunct(boolean z) {
        this.field_35_fOverflowPunct = z;
    }

    @Internal
    public void setFPageBreakBefore(boolean z) {
        this.field_5_fPageBreakBefore = z;
    }

    @Internal
    public void setFPropRMark(boolean z) {
        this.field_69_fPropRMark = z;
    }

    @Internal
    public void setFRotateFont(boolean z) {
        this.field_40_fontAlign = (short) fRotateFont.setBoolean(this.field_40_fontAlign, z);
    }

    @Internal
    public void setFSideBySide(boolean z) {
        this.field_2_fSideBySide = z;
    }

    @Internal
    public void setFTopLinePunct(boolean z) {
        this.field_36_fTopLinePunct = z;
    }

    @Internal
    public void setFTtp(boolean z) {
        this.field_16_fTtp = z;
    }

    @Internal
    public void setFTtpEmbedded(boolean z) {
        this.field_50_fTtpEmbedded = z;
    }

    @Internal
    public void setFUsePgsuSettings(boolean z) {
        this.field_45_fUsePgsuSettings = z;
    }

    @Internal
    public void setFVertical(boolean z) {
        this.field_40_fontAlign = (short) fVertical.setBoolean(this.field_40_fontAlign, z);
    }

    @Internal
    public void setFWidowControl(boolean z) {
        this.field_32_fWidowControl = z;
    }

    @Internal
    public void setFWordWrap(boolean z) {
        this.field_34_fWordWrap = z;
    }

    @Internal
    public void setFinTableW97(boolean z) {
        this.field_15_finTableW97 = z;
    }

    @Internal
    public void setFontAlign(short s) {
        this.field_40_fontAlign = s;
    }

    @Internal
    public void setIbstPropRMark(int i2) {
        this.field_70_ibstPropRMark = i2;
    }

    @Internal
    public void setIlfo(int i2) {
        this.field_9_ilfo = i2;
    }

    @Internal
    public void setIlvl(byte b2) {
        this.field_8_ilvl = b2;
    }

    @Internal
    public void setIpgp(long j) {
        this.field_78_ipgp = j;
    }

    @Internal
    public void setIstd(int i2) {
        this.field_1_istd = i2;
    }

    @Internal
    public void setItap(int i2) {
        this.field_47_itap = i2;
    }

    @Internal
    public void setItbdMac(int i2) {
        this.field_72_itbdMac = i2;
    }

    @Internal
    public void setJc(byte b2) {
        this.field_59_jc = b2;
    }

    @Internal
    public void setLspd(LineSpacingDescriptor lineSpacingDescriptor) {
        this.field_11_lspd = lineSpacingDescriptor;
    }

    @Internal
    public void setLvl(byte b2) {
        this.field_41_lvl = b2;
    }

    @Internal
    public void setNumrm(byte[] bArr) {
        this.field_75_numrm = bArr;
    }

    @Internal
    public void setPcHorz(byte b2) {
        this.field_23_pcHorz = b2;
    }

    @Internal
    public void setPcVert(byte b2) {
        this.field_22_pcVert = b2;
    }

    @Internal
    public void setPhe(byte[] bArr) {
        this.field_68_phe = bArr;
    }

    @Internal
    public void setPtap(byte[] bArr) {
        this.field_76_ptap = bArr;
    }

    @Internal
    public void setRgdxaTab(int[] iArr) {
        this.field_73_rgdxaTab = iArr;
    }

    @Internal
    public void setRgtbd(TabDescriptor[] tabDescriptorArr) {
        this.field_74_rgtbd = tabDescriptorArr;
    }

    @Internal
    public void setRsid(long j) {
        this.field_79_rsid = j;
    }

    @Internal
    public void setShd(ShadingDescriptor shadingDescriptor) {
        this.field_66_shd = shadingDescriptor;
    }

    @Internal
    public void setWAlignFont(int i2) {
        this.field_39_wAlignFont = i2;
    }

    @Internal
    public void setWr(byte b2) {
        this.field_24_wr = b2;
    }

    public String toString() {
        StringBuilder d2 = a.d("[PAP]\n", "    .istd                 = ", " (");
        d2.append(getIstd());
        d2.append(" )\n");
        d2.append("    .fSideBySide          = ");
        d2.append(" (");
        d2.append(getFSideBySide());
        d2.append(" )\n");
        d2.append("    .fKeep                = ");
        d2.append(" (");
        d2.append(getFKeep());
        d2.append(" )\n");
        d2.append("    .fKeepFollow          = ");
        d2.append(" (");
        d2.append(getFKeepFollow());
        d2.append(" )\n");
        d2.append("    .fPageBreakBefore     = ");
        d2.append(" (");
        d2.append(getFPageBreakBefore());
        d2.append(" )\n");
        d2.append("    .brcl                 = ");
        d2.append(" (");
        d2.append((int) getBrcl());
        d2.append(" )\n");
        d2.append("    .brcp                 = ");
        d2.append(" (");
        d2.append((int) getBrcp());
        d2.append(" )\n");
        d2.append("    .ilvl                 = ");
        d2.append(" (");
        d2.append((int) getIlvl());
        d2.append(" )\n");
        d2.append("    .ilfo                 = ");
        d2.append(" (");
        d2.append(getIlfo());
        d2.append(" )\n");
        d2.append("    .fNoLnn               = ");
        d2.append(" (");
        d2.append(getFNoLnn());
        d2.append(" )\n");
        d2.append("    .lspd                 = ");
        d2.append(" (");
        d2.append(getLspd());
        d2.append(" )\n");
        d2.append("    .dyaBefore            = ");
        d2.append(" (");
        d2.append(getDyaBefore());
        d2.append(" )\n");
        d2.append("    .dyaAfter             = ");
        d2.append(" (");
        d2.append(getDyaAfter());
        d2.append(" )\n");
        d2.append("    .fInTable             = ");
        d2.append(" (");
        d2.append(getFInTable());
        d2.append(" )\n");
        d2.append("    .finTableW97          = ");
        d2.append(" (");
        d2.append(getFinTableW97());
        d2.append(" )\n");
        d2.append("    .fTtp                 = ");
        d2.append(" (");
        d2.append(getFTtp());
        d2.append(" )\n");
        d2.append("    .dxaAbs               = ");
        d2.append(" (");
        d2.append(getDxaAbs());
        d2.append(" )\n");
        d2.append("    .dyaAbs               = ");
        d2.append(" (");
        d2.append(getDyaAbs());
        d2.append(" )\n");
        d2.append("    .dxaWidth             = ");
        d2.append(" (");
        d2.append(getDxaWidth());
        d2.append(" )\n");
        d2.append("    .fBrLnAbove           = ");
        d2.append(" (");
        d2.append(getFBrLnAbove());
        d2.append(" )\n");
        d2.append("    .fBrLnBelow           = ");
        d2.append(" (");
        d2.append(getFBrLnBelow());
        d2.append(" )\n");
        d2.append("    .pcVert               = ");
        d2.append(" (");
        d2.append((int) getPcVert());
        d2.append(" )\n");
        d2.append("    .pcHorz               = ");
        d2.append(" (");
        d2.append((int) getPcHorz());
        d2.append(" )\n");
        d2.append("    .wr                   = ");
        d2.append(" (");
        d2.append((int) getWr());
        d2.append(" )\n");
        d2.append("    .fNoAutoHyph          = ");
        d2.append(" (");
        d2.append(getFNoAutoHyph());
        d2.append(" )\n");
        d2.append("    .dyaHeight            = ");
        d2.append(" (");
        d2.append(getDyaHeight());
        d2.append(" )\n");
        d2.append("    .fMinHeight           = ");
        d2.append(" (");
        d2.append(getFMinHeight());
        d2.append(" )\n");
        d2.append("    .dcs                  = ");
        d2.append(" (");
        d2.append(getDcs());
        d2.append(" )\n");
        d2.append("    .dyaFromText          = ");
        d2.append(" (");
        d2.append(getDyaFromText());
        d2.append(" )\n");
        d2.append("    .dxaFromText          = ");
        d2.append(" (");
        d2.append(getDxaFromText());
        d2.append(" )\n");
        d2.append("    .fLocked              = ");
        d2.append(" (");
        d2.append(getFLocked());
        d2.append(" )\n");
        d2.append("    .fWidowControl        = ");
        d2.append(" (");
        d2.append(getFWidowControl());
        d2.append(" )\n");
        d2.append("    .fKinsoku             = ");
        d2.append(" (");
        d2.append(getFKinsoku());
        d2.append(" )\n");
        d2.append("    .fWordWrap            = ");
        d2.append(" (");
        d2.append(getFWordWrap());
        d2.append(" )\n");
        d2.append("    .fOverflowPunct       = ");
        d2.append(" (");
        d2.append(getFOverflowPunct());
        d2.append(" )\n");
        d2.append("    .fTopLinePunct        = ");
        d2.append(" (");
        d2.append(getFTopLinePunct());
        d2.append(" )\n");
        d2.append("    .fAutoSpaceDE         = ");
        d2.append(" (");
        d2.append(getFAutoSpaceDE());
        d2.append(" )\n");
        d2.append("    .fAutoSpaceDN         = ");
        d2.append(" (");
        d2.append(getFAutoSpaceDN());
        d2.append(" )\n");
        d2.append("    .wAlignFont           = ");
        d2.append(" (");
        d2.append(getWAlignFont());
        d2.append(" )\n");
        d2.append("    .fontAlign            = ");
        d2.append(" (");
        d2.append((int) getFontAlign());
        d2.append(" )\n");
        d2.append("         .fVertical                = ");
        d2.append(isFVertical());
        d2.append('\n');
        d2.append("         .fBackward                = ");
        d2.append(isFBackward());
        d2.append('\n');
        d2.append("         .fRotateFont              = ");
        d2.append(isFRotateFont());
        d2.append('\n');
        d2.append("    .lvl                  = ");
        d2.append(" (");
        d2.append((int) getLvl());
        d2.append(" )\n");
        d2.append("    .fBiDi                = ");
        d2.append(" (");
        d2.append(getFBiDi());
        d2.append(" )\n");
        d2.append("    .fNumRMIns            = ");
        d2.append(" (");
        d2.append(getFNumRMIns());
        d2.append(" )\n");
        d2.append("    .fCrLf                = ");
        d2.append(" (");
        d2.append(getFCrLf());
        d2.append(" )\n");
        d2.append("    .fUsePgsuSettings     = ");
        d2.append(" (");
        d2.append(getFUsePgsuSettings());
        d2.append(" )\n");
        d2.append("    .fAdjustRight         = ");
        d2.append(" (");
        d2.append(getFAdjustRight());
        d2.append(" )\n");
        d2.append("    .itap                 = ");
        d2.append(" (");
        d2.append(getItap());
        d2.append(" )\n");
        d2.append("    .fInnerTableCell      = ");
        d2.append(" (");
        d2.append(getFInnerTableCell());
        d2.append(" )\n");
        d2.append("    .fOpenTch             = ");
        d2.append(" (");
        d2.append(getFOpenTch());
        d2.append(" )\n");
        d2.append("    .fTtpEmbedded         = ");
        d2.append(" (");
        d2.append(getFTtpEmbedded());
        d2.append(" )\n");
        d2.append("    .dxcRight             = ");
        d2.append(" (");
        d2.append((int) getDxcRight());
        d2.append(" )\n");
        d2.append("    .dxcLeft              = ");
        d2.append(" (");
        d2.append((int) getDxcLeft());
        d2.append(" )\n");
        d2.append("    .dxcLeft1             = ");
        d2.append(" (");
        d2.append((int) getDxcLeft1());
        d2.append(" )\n");
        d2.append("    .fDyaBeforeAuto       = ");
        d2.append(" (");
        d2.append(getFDyaBeforeAuto());
        d2.append(" )\n");
        d2.append("    .fDyaAfterAuto        = ");
        d2.append(" (");
        d2.append(getFDyaAfterAuto());
        d2.append(" )\n");
        d2.append("    .dxaRight             = ");
        d2.append(" (");
        d2.append(getDxaRight());
        d2.append(" )\n");
        d2.append("    .dxaLeft              = ");
        d2.append(" (");
        d2.append(getDxaLeft());
        d2.append(" )\n");
        d2.append("    .dxaLeft1             = ");
        d2.append(" (");
        d2.append(getDxaLeft1());
        d2.append(" )\n");
        d2.append("    .jc                   = ");
        d2.append(" (");
        d2.append((int) getJc());
        d2.append(" )\n");
        d2.append("    .brcTop               = ");
        d2.append(" (");
        d2.append(getBrcTop());
        d2.append(" )\n");
        d2.append("    .brcLeft              = ");
        d2.append(" (");
        d2.append(getBrcLeft());
        d2.append(" )\n");
        d2.append("    .brcBottom            = ");
        d2.append(" (");
        d2.append(getBrcBottom());
        d2.append(" )\n");
        d2.append("    .brcRight             = ");
        d2.append(" (");
        d2.append(getBrcRight());
        d2.append(" )\n");
        d2.append("    .brcBetween           = ");
        d2.append(" (");
        d2.append(getBrcBetween());
        d2.append(" )\n");
        d2.append("    .brcBar               = ");
        d2.append(" (");
        d2.append(getBrcBar());
        d2.append(" )\n");
        d2.append("    .shd                  = ");
        d2.append(" (");
        d2.append(getShd());
        d2.append(" )\n");
        d2.append("    .anld                 = ");
        d2.append(" (");
        d2.append(Arrays.toString(getAnld()));
        d2.append(" )\n");
        d2.append("    .phe                  = ");
        d2.append(" (");
        d2.append(Arrays.toString(getPhe()));
        d2.append(" )\n");
        d2.append("    .fPropRMark           = ");
        d2.append(" (");
        d2.append(getFPropRMark());
        d2.append(" )\n");
        d2.append("    .ibstPropRMark        = ");
        d2.append(" (");
        d2.append(getIbstPropRMark());
        d2.append(" )\n");
        d2.append("    .dttmPropRMark        = ");
        d2.append(" (");
        d2.append(getDttmPropRMark());
        d2.append(" )\n");
        d2.append("    .itbdMac              = ");
        d2.append(" (");
        d2.append(getItbdMac());
        d2.append(" )\n");
        d2.append("    .rgdxaTab             = ");
        d2.append(" (");
        d2.append(Arrays.toString(getRgdxaTab()));
        d2.append(" )\n");
        d2.append("    .rgtbd                = ");
        d2.append(" (");
        d2.append(Arrays.toString(getRgtbd()));
        d2.append(" )\n");
        d2.append("    .numrm                = ");
        d2.append(" (");
        d2.append(Arrays.toString(getNumrm()));
        d2.append(" )\n");
        d2.append("    .ptap                 = ");
        d2.append(" (");
        d2.append(Arrays.toString(getPtap()));
        d2.append(" )\n");
        d2.append("    .fNoAllowOverlap      = ");
        d2.append(" (");
        d2.append(getFNoAllowOverlap());
        d2.append(" )\n");
        d2.append("    .ipgp                 = ");
        d2.append(" (");
        d2.append(getIpgp());
        d2.append(" )\n");
        d2.append("    .rsid                 = ");
        d2.append(" (");
        d2.append(getRsid());
        return a.a(d2, " )\n", "[/PAP]\n");
    }
}
