package org.apache.poi.hwpf.model.types;

import b.b.a.a.a;
import org.apache.poi.util.BitField;
import org.apache.poi.util.Internal;
import org.apache.poi.util.LittleEndian;

@Internal
public abstract class StdfBaseAbstractType {
    public static final BitField cupx = new BitField(15);
    public static final BitField f97LidsSet = new BitField(4);
    public static final BitField fAutoRedef = new BitField(1);
    public static final BitField fCopyLang = new BitField(8);
    public static final BitField fHasUpe = new BitField(16384);
    public static final BitField fHidden = new BitField(2);
    public static final BitField fInternalUse = new BitField(1024);
    public static final BitField fInvalHeight = new BitField(8192);
    public static final BitField fLocked = new BitField(512);
    public static final BitField fMassCopy = new BitField(32768);
    public static final BitField fNoHtmlExport = new BitField(128);
    public static final BitField fPersonal = new BitField(64);
    public static final BitField fPersonalCompose = new BitField(16);
    public static final BitField fPersonalReply = new BitField(32);
    public static final BitField fQFormat = new BitField(4096);
    public static final BitField fReserved = new BitField(57344);
    public static final BitField fScratch = new BitField(4096);
    public static final BitField fSemiHidden = new BitField(256);
    public static final BitField fUnhideWhenUsed = new BitField(2048);
    public static final BitField istdBase = new BitField(65520);
    public static final BitField istdNext = new BitField(65520);
    public static final BitField sti = new BitField(4095);
    public static final BitField stk = new BitField(15);
    public short field_1_info1;
    public short field_2_info2;
    public short field_3_info3;
    public int field_4_bchUpe;
    public short field_5_grfstd;

    public static int getSize() {
        return 10;
    }

    public void fillFields(byte[] bArr, int i2) {
        this.field_1_info1 = LittleEndian.getShort(bArr, i2 + 0);
        this.field_2_info2 = LittleEndian.getShort(bArr, i2 + 2);
        this.field_3_info3 = LittleEndian.getShort(bArr, i2 + 4);
        this.field_4_bchUpe = LittleEndian.getShort(bArr, i2 + 6);
        this.field_5_grfstd = LittleEndian.getShort(bArr, i2 + 8);
    }

    @Internal
    public int getBchUpe() {
        return this.field_4_bchUpe;
    }

    @Internal
    public byte getCupx() {
        return (byte) cupx.getValue(this.field_3_info3);
    }

    @Internal
    public byte getFReserved() {
        return (byte) fReserved.getValue(this.field_5_grfstd);
    }

    @Internal
    public short getGrfstd() {
        return this.field_5_grfstd;
    }

    @Internal
    public short getInfo1() {
        return this.field_1_info1;
    }

    @Internal
    public short getInfo2() {
        return this.field_2_info2;
    }

    @Internal
    public short getInfo3() {
        return this.field_3_info3;
    }

    @Internal
    public short getIstdBase() {
        return (short) istdBase.getValue(this.field_2_info2);
    }

    @Internal
    public short getIstdNext() {
        return (short) istdNext.getValue(this.field_3_info3);
    }

    @Internal
    public short getSti() {
        return (short) sti.getValue(this.field_1_info1);
    }

    @Internal
    public byte getStk() {
        return (byte) stk.getValue(this.field_2_info2);
    }

    @Internal
    public boolean isF97LidsSet() {
        return f97LidsSet.isSet(this.field_5_grfstd);
    }

    @Internal
    public boolean isFAutoRedef() {
        return fAutoRedef.isSet(this.field_5_grfstd);
    }

    @Internal
    public boolean isFCopyLang() {
        return fCopyLang.isSet(this.field_5_grfstd);
    }

    @Internal
    public boolean isFHasUpe() {
        return fHasUpe.isSet(this.field_1_info1);
    }

    @Internal
    public boolean isFHidden() {
        return fHidden.isSet(this.field_5_grfstd);
    }

    @Internal
    public boolean isFInternalUse() {
        return fInternalUse.isSet(this.field_5_grfstd);
    }

    @Internal
    public boolean isFInvalHeight() {
        return fInvalHeight.isSet(this.field_1_info1);
    }

    @Internal
    public boolean isFLocked() {
        return fLocked.isSet(this.field_5_grfstd);
    }

    @Internal
    public boolean isFMassCopy() {
        return fMassCopy.isSet(this.field_1_info1);
    }

    @Internal
    public boolean isFNoHtmlExport() {
        return fNoHtmlExport.isSet(this.field_5_grfstd);
    }

    @Internal
    public boolean isFPersonal() {
        return fPersonal.isSet(this.field_5_grfstd);
    }

    @Internal
    public boolean isFPersonalCompose() {
        return fPersonalCompose.isSet(this.field_5_grfstd);
    }

    @Internal
    public boolean isFPersonalReply() {
        return fPersonalReply.isSet(this.field_5_grfstd);
    }

    @Internal
    public boolean isFQFormat() {
        return fQFormat.isSet(this.field_5_grfstd);
    }

    @Internal
    public boolean isFScratch() {
        return fScratch.isSet(this.field_1_info1);
    }

    @Internal
    public boolean isFSemiHidden() {
        return fSemiHidden.isSet(this.field_5_grfstd);
    }

    @Internal
    public boolean isFUnhideWhenUsed() {
        return fUnhideWhenUsed.isSet(this.field_5_grfstd);
    }

    public void serialize(byte[] bArr, int i2) {
        LittleEndian.putShort(bArr, i2 + 0, this.field_1_info1);
        LittleEndian.putShort(bArr, i2 + 2, this.field_2_info2);
        LittleEndian.putShort(bArr, i2 + 4, this.field_3_info3);
        LittleEndian.putUShort(bArr, i2 + 6, this.field_4_bchUpe);
        LittleEndian.putShort(bArr, i2 + 8, this.field_5_grfstd);
    }

    @Internal
    public void setBchUpe(int i2) {
        this.field_4_bchUpe = i2;
    }

    @Internal
    public void setCupx(byte b2) {
        this.field_3_info3 = (short) cupx.setValue(this.field_3_info3, b2);
    }

    @Internal
    public void setF97LidsSet(boolean z) {
        this.field_5_grfstd = (short) f97LidsSet.setBoolean(this.field_5_grfstd, z);
    }

    @Internal
    public void setFAutoRedef(boolean z) {
        this.field_5_grfstd = (short) fAutoRedef.setBoolean(this.field_5_grfstd, z);
    }

    @Internal
    public void setFCopyLang(boolean z) {
        this.field_5_grfstd = (short) fCopyLang.setBoolean(this.field_5_grfstd, z);
    }

    @Internal
    public void setFHasUpe(boolean z) {
        this.field_1_info1 = (short) fHasUpe.setBoolean(this.field_1_info1, z);
    }

    @Internal
    public void setFHidden(boolean z) {
        this.field_5_grfstd = (short) fHidden.setBoolean(this.field_5_grfstd, z);
    }

    @Internal
    public void setFInternalUse(boolean z) {
        this.field_5_grfstd = (short) fInternalUse.setBoolean(this.field_5_grfstd, z);
    }

    @Internal
    public void setFInvalHeight(boolean z) {
        this.field_1_info1 = (short) fInvalHeight.setBoolean(this.field_1_info1, z);
    }

    @Internal
    public void setFLocked(boolean z) {
        this.field_5_grfstd = (short) fLocked.setBoolean(this.field_5_grfstd, z);
    }

    @Internal
    public void setFMassCopy(boolean z) {
        this.field_1_info1 = (short) fMassCopy.setBoolean(this.field_1_info1, z);
    }

    @Internal
    public void setFNoHtmlExport(boolean z) {
        this.field_5_grfstd = (short) fNoHtmlExport.setBoolean(this.field_5_grfstd, z);
    }

    @Internal
    public void setFPersonal(boolean z) {
        this.field_5_grfstd = (short) fPersonal.setBoolean(this.field_5_grfstd, z);
    }

    @Internal
    public void setFPersonalCompose(boolean z) {
        this.field_5_grfstd = (short) fPersonalCompose.setBoolean(this.field_5_grfstd, z);
    }

    @Internal
    public void setFPersonalReply(boolean z) {
        this.field_5_grfstd = (short) fPersonalReply.setBoolean(this.field_5_grfstd, z);
    }

    @Internal
    public void setFQFormat(boolean z) {
        this.field_5_grfstd = (short) fQFormat.setBoolean(this.field_5_grfstd, z);
    }

    @Internal
    public void setFReserved(byte b2) {
        this.field_5_grfstd = (short) fReserved.setValue(this.field_5_grfstd, b2);
    }

    @Internal
    public void setFScratch(boolean z) {
        this.field_1_info1 = (short) fScratch.setBoolean(this.field_1_info1, z);
    }

    @Internal
    public void setFSemiHidden(boolean z) {
        this.field_5_grfstd = (short) fSemiHidden.setBoolean(this.field_5_grfstd, z);
    }

    @Internal
    public void setFUnhideWhenUsed(boolean z) {
        this.field_5_grfstd = (short) fUnhideWhenUsed.setBoolean(this.field_5_grfstd, z);
    }

    @Internal
    public void setGrfstd(short s) {
        this.field_5_grfstd = s;
    }

    @Internal
    public void setInfo1(short s) {
        this.field_1_info1 = s;
    }

    @Internal
    public void setInfo2(short s) {
        this.field_2_info2 = s;
    }

    @Internal
    public void setInfo3(short s) {
        this.field_3_info3 = s;
    }

    @Internal
    public void setIstdBase(short s) {
        this.field_2_info2 = (short) istdBase.setValue(this.field_2_info2, s);
    }

    @Internal
    public void setIstdNext(short s) {
        this.field_3_info3 = (short) istdNext.setValue(this.field_3_info3, s);
    }

    @Internal
    public void setSti(short s) {
        this.field_1_info1 = (short) sti.setValue(this.field_1_info1, s);
    }

    @Internal
    public void setStk(byte b2) {
        this.field_2_info2 = (short) stk.setValue(this.field_2_info2, b2);
    }

    public String toString() {
        StringBuilder d2 = a.d("[StdfBase]\n", "    .info1                = ", " (");
        d2.append((int) getInfo1());
        d2.append(" )\n");
        d2.append("         .sti                      = ");
        d2.append((int) getSti());
        d2.append('\n');
        d2.append("         .fScratch                 = ");
        d2.append(isFScratch());
        d2.append('\n');
        d2.append("         .fInvalHeight             = ");
        d2.append(isFInvalHeight());
        d2.append('\n');
        d2.append("         .fHasUpe                  = ");
        d2.append(isFHasUpe());
        d2.append('\n');
        d2.append("         .fMassCopy                = ");
        d2.append(isFMassCopy());
        d2.append('\n');
        d2.append("    .info2                = ");
        d2.append(" (");
        d2.append((int) getInfo2());
        d2.append(" )\n");
        d2.append("         .stk                      = ");
        d2.append((int) getStk());
        d2.append('\n');
        d2.append("         .istdBase                 = ");
        d2.append((int) getIstdBase());
        d2.append('\n');
        d2.append("    .info3                = ");
        d2.append(" (");
        d2.append((int) getInfo3());
        d2.append(" )\n");
        d2.append("         .cupx                     = ");
        d2.append((int) getCupx());
        d2.append('\n');
        d2.append("         .istdNext                 = ");
        d2.append((int) getIstdNext());
        d2.append('\n');
        d2.append("    .bchUpe               = ");
        d2.append(" (");
        d2.append(getBchUpe());
        d2.append(" )\n");
        d2.append("    .grfstd               = ");
        d2.append(" (");
        d2.append((int) getGrfstd());
        d2.append(" )\n");
        d2.append("         .fAutoRedef               = ");
        d2.append(isFAutoRedef());
        d2.append('\n');
        d2.append("         .fHidden                  = ");
        d2.append(isFHidden());
        d2.append('\n');
        d2.append("         .f97LidsSet               = ");
        d2.append(isF97LidsSet());
        d2.append('\n');
        d2.append("         .fCopyLang                = ");
        d2.append(isFCopyLang());
        d2.append('\n');
        d2.append("         .fPersonalCompose         = ");
        d2.append(isFPersonalCompose());
        d2.append('\n');
        d2.append("         .fPersonalReply           = ");
        d2.append(isFPersonalReply());
        d2.append('\n');
        d2.append("         .fPersonal                = ");
        d2.append(isFPersonal());
        d2.append('\n');
        d2.append("         .fNoHtmlExport            = ");
        d2.append(isFNoHtmlExport());
        d2.append('\n');
        d2.append("         .fSemiHidden              = ");
        d2.append(isFSemiHidden());
        d2.append('\n');
        d2.append("         .fLocked                  = ");
        d2.append(isFLocked());
        d2.append('\n');
        d2.append("         .fInternalUse             = ");
        d2.append(isFInternalUse());
        d2.append('\n');
        d2.append("         .fUnhideWhenUsed          = ");
        d2.append(isFUnhideWhenUsed());
        d2.append('\n');
        d2.append("         .fQFormat                 = ");
        d2.append(isFQFormat());
        d2.append('\n');
        d2.append("         .fReserved                = ");
        d2.append((int) getFReserved());
        d2.append('\n');
        d2.append("[/StdfBase]\n");
        return d2.toString();
    }
}
