package org.apache.poi.hwpf.model.types;

import b.b.a.a.a;
import org.apache.poi.util.BitField;
import org.apache.poi.util.Internal;
import org.apache.poi.util.LittleEndian;

@Internal
public abstract class StshifAbstractType {
    public static final BitField fHasOriginalStyle = new BitField(1);
    public static final BitField fReserved = new BitField(65534);
    public int field_1_cstd;
    public int field_2_cbSTDBaseInFile;
    public int field_3_info3;
    public int field_4_stiMaxWhenSaved;
    public int field_5_istdMaxFixedWhenSaved;
    public int field_6_nVerBuiltInNamesWhenSaved;
    public short field_7_ftcAsci;
    public short field_8_ftcFE;
    public short field_9_ftcOther;

    public static int getSize() {
        return 18;
    }

    public void fillFields(byte[] bArr, int i2) {
        this.field_1_cstd = LittleEndian.getShort(bArr, i2 + 0);
        this.field_2_cbSTDBaseInFile = LittleEndian.getShort(bArr, i2 + 2);
        this.field_3_info3 = LittleEndian.getShort(bArr, i2 + 4);
        this.field_4_stiMaxWhenSaved = LittleEndian.getShort(bArr, i2 + 6);
        this.field_5_istdMaxFixedWhenSaved = LittleEndian.getShort(bArr, i2 + 8);
        this.field_6_nVerBuiltInNamesWhenSaved = LittleEndian.getShort(bArr, i2 + 10);
        this.field_7_ftcAsci = LittleEndian.getShort(bArr, i2 + 12);
        this.field_8_ftcFE = LittleEndian.getShort(bArr, i2 + 14);
        this.field_9_ftcOther = LittleEndian.getShort(bArr, i2 + 16);
    }

    @Internal
    public int getCbSTDBaseInFile() {
        return this.field_2_cbSTDBaseInFile;
    }

    @Internal
    public int getCstd() {
        return this.field_1_cstd;
    }

    @Internal
    public short getFReserved() {
        return (short) fReserved.getValue(this.field_3_info3);
    }

    @Internal
    public short getFtcAsci() {
        return this.field_7_ftcAsci;
    }

    @Internal
    public short getFtcFE() {
        return this.field_8_ftcFE;
    }

    @Internal
    public short getFtcOther() {
        return this.field_9_ftcOther;
    }

    @Internal
    public int getInfo3() {
        return this.field_3_info3;
    }

    @Internal
    public int getIstdMaxFixedWhenSaved() {
        return this.field_5_istdMaxFixedWhenSaved;
    }

    @Internal
    public int getNVerBuiltInNamesWhenSaved() {
        return this.field_6_nVerBuiltInNamesWhenSaved;
    }

    @Internal
    public int getStiMaxWhenSaved() {
        return this.field_4_stiMaxWhenSaved;
    }

    @Internal
    public boolean isFHasOriginalStyle() {
        return fHasOriginalStyle.isSet(this.field_3_info3);
    }

    public void serialize(byte[] bArr, int i2) {
        LittleEndian.putUShort(bArr, i2 + 0, this.field_1_cstd);
        LittleEndian.putUShort(bArr, i2 + 2, this.field_2_cbSTDBaseInFile);
        LittleEndian.putUShort(bArr, i2 + 4, this.field_3_info3);
        LittleEndian.putUShort(bArr, i2 + 6, this.field_4_stiMaxWhenSaved);
        LittleEndian.putUShort(bArr, i2 + 8, this.field_5_istdMaxFixedWhenSaved);
        LittleEndian.putUShort(bArr, i2 + 10, this.field_6_nVerBuiltInNamesWhenSaved);
        LittleEndian.putShort(bArr, i2 + 12, this.field_7_ftcAsci);
        LittleEndian.putShort(bArr, i2 + 14, this.field_8_ftcFE);
        LittleEndian.putShort(bArr, i2 + 16, this.field_9_ftcOther);
    }

    @Internal
    public void setCbSTDBaseInFile(int i2) {
        this.field_2_cbSTDBaseInFile = i2;
    }

    @Internal
    public void setCstd(int i2) {
        this.field_1_cstd = i2;
    }

    @Internal
    public void setFHasOriginalStyle(boolean z) {
        this.field_3_info3 = fHasOriginalStyle.setBoolean(this.field_3_info3, z);
    }

    @Internal
    public void setFReserved(short s) {
        this.field_3_info3 = fReserved.setValue(this.field_3_info3, s);
    }

    @Internal
    public void setFtcAsci(short s) {
        this.field_7_ftcAsci = s;
    }

    @Internal
    public void setFtcFE(short s) {
        this.field_8_ftcFE = s;
    }

    @Internal
    public void setFtcOther(short s) {
        this.field_9_ftcOther = s;
    }

    @Internal
    public void setInfo3(int i2) {
        this.field_3_info3 = i2;
    }

    @Internal
    public void setIstdMaxFixedWhenSaved(int i2) {
        this.field_5_istdMaxFixedWhenSaved = i2;
    }

    @Internal
    public void setNVerBuiltInNamesWhenSaved(int i2) {
        this.field_6_nVerBuiltInNamesWhenSaved = i2;
    }

    @Internal
    public void setStiMaxWhenSaved(int i2) {
        this.field_4_stiMaxWhenSaved = i2;
    }

    public String toString() {
        StringBuilder d2 = a.d("[Stshif]\n", "    .cstd                 = ", " (");
        d2.append(getCstd());
        d2.append(" )\n");
        d2.append("    .cbSTDBaseInFile      = ");
        d2.append(" (");
        d2.append(getCbSTDBaseInFile());
        d2.append(" )\n");
        d2.append("    .info3                = ");
        d2.append(" (");
        d2.append(getInfo3());
        d2.append(" )\n");
        d2.append("         .fHasOriginalStyle        = ");
        d2.append(isFHasOriginalStyle());
        d2.append('\n');
        d2.append("         .fReserved                = ");
        d2.append((int) getFReserved());
        d2.append('\n');
        d2.append("    .stiMaxWhenSaved      = ");
        d2.append(" (");
        d2.append(getStiMaxWhenSaved());
        d2.append(" )\n");
        d2.append("    .istdMaxFixedWhenSaved = ");
        d2.append(" (");
        d2.append(getIstdMaxFixedWhenSaved());
        d2.append(" )\n");
        d2.append("    .nVerBuiltInNamesWhenSaved = ");
        d2.append(" (");
        d2.append(getNVerBuiltInNamesWhenSaved());
        d2.append(" )\n");
        d2.append("    .ftcAsci              = ");
        d2.append(" (");
        d2.append((int) getFtcAsci());
        d2.append(" )\n");
        d2.append("    .ftcFE                = ");
        d2.append(" (");
        d2.append((int) getFtcFE());
        d2.append(" )\n");
        d2.append("    .ftcOther             = ");
        d2.append(" (");
        d2.append((int) getFtcOther());
        d2.append(" )\n");
        d2.append("[/Stshif]\n");
        return d2.toString();
    }
}
