package org.apache.poi.hwpf.model.types;

import b.b.a.a.a;
import org.apache.poi.util.BitField;
import org.apache.poi.util.Internal;
import org.apache.poi.util.LittleEndian;

@Internal
public abstract class TLPAbstractType {
    public static final BitField fBestFit = new BitField(16);
    public static final BitField fBorders = new BitField(1);
    public static final BitField fColor = new BitField(8);
    public static final BitField fFont = new BitField(4);
    public static final BitField fHdrRows = new BitField(32);
    public static final BitField fLastRow = new BitField(64);
    public static final BitField fShading = new BitField(2);
    public short field_1_itl;
    public byte field_2_tlp_flags;

    public void fillFields(byte[] bArr, int i2) {
        this.field_1_itl = LittleEndian.getShort(bArr, i2 + 0);
        this.field_2_tlp_flags = bArr[i2 + 2];
    }

    public short getItl() {
        return this.field_1_itl;
    }

    public int getSize() {
        return 7;
    }

    public byte getTlp_flags() {
        return this.field_2_tlp_flags;
    }

    public boolean isFBestFit() {
        return fBestFit.isSet(this.field_2_tlp_flags);
    }

    public boolean isFBorders() {
        return fBorders.isSet(this.field_2_tlp_flags);
    }

    public boolean isFColor() {
        return fColor.isSet(this.field_2_tlp_flags);
    }

    public boolean isFFont() {
        return fFont.isSet(this.field_2_tlp_flags);
    }

    public boolean isFHdrRows() {
        return fHdrRows.isSet(this.field_2_tlp_flags);
    }

    public boolean isFLastRow() {
        return fLastRow.isSet(this.field_2_tlp_flags);
    }

    public boolean isFShading() {
        return fShading.isSet(this.field_2_tlp_flags);
    }

    public void serialize(byte[] bArr, int i2) {
        LittleEndian.putShort(bArr, i2 + 0, this.field_1_itl);
        bArr[i2 + 2] = this.field_2_tlp_flags;
    }

    public void setFBestFit(boolean z) {
        this.field_2_tlp_flags = (byte) fBestFit.setBoolean(this.field_2_tlp_flags, z);
    }

    public void setFBorders(boolean z) {
        this.field_2_tlp_flags = (byte) fBorders.setBoolean(this.field_2_tlp_flags, z);
    }

    public void setFColor(boolean z) {
        this.field_2_tlp_flags = (byte) fColor.setBoolean(this.field_2_tlp_flags, z);
    }

    public void setFFont(boolean z) {
        this.field_2_tlp_flags = (byte) fFont.setBoolean(this.field_2_tlp_flags, z);
    }

    public void setFHdrRows(boolean z) {
        this.field_2_tlp_flags = (byte) fHdrRows.setBoolean(this.field_2_tlp_flags, z);
    }

    public void setFLastRow(boolean z) {
        this.field_2_tlp_flags = (byte) fLastRow.setBoolean(this.field_2_tlp_flags, z);
    }

    public void setFShading(boolean z) {
        this.field_2_tlp_flags = (byte) fShading.setBoolean(this.field_2_tlp_flags, z);
    }

    public void setItl(short s) {
        this.field_1_itl = s;
    }

    public void setTlp_flags(byte b2) {
        this.field_2_tlp_flags = b2;
    }

    public String toString() {
        StringBuffer c = a.c("[TLP]\n", "    .itl                  = ", " (");
        c.append((int) getItl());
        c.append(" )\n");
        c.append("    .tlp_flags            = ");
        c.append(" (");
        c.append((int) getTlp_flags());
        c.append(" )\n");
        c.append("         .fBorders                 = ");
        c.append(isFBorders());
        c.append('\n');
        c.append("         .fShading                 = ");
        c.append(isFShading());
        c.append('\n');
        c.append("         .fFont                    = ");
        c.append(isFFont());
        c.append('\n');
        c.append("         .fColor                   = ");
        c.append(isFColor());
        c.append('\n');
        c.append("         .fBestFit                 = ");
        c.append(isFBestFit());
        c.append('\n');
        c.append("         .fHdrRows                 = ");
        c.append(isFHdrRows());
        c.append('\n');
        c.append("         .fLastRow                 = ");
        c.append(isFLastRow());
        c.append('\n');
        c.append("[/TLP]\n");
        return c.toString();
    }
}
