package org.apache.poi.hwpf.sprm;

import b.b.a.a.a;
import java.util.ArrayList;
import java.util.Collections;
import java.util.HashMap;
import org.apache.poi.hwpf.model.TabDescriptor;
import org.apache.poi.hwpf.model.types.TBDAbstractType;
import org.apache.poi.hwpf.usermodel.BorderCode;
import org.apache.poi.hwpf.usermodel.DateAndTime;
import org.apache.poi.hwpf.usermodel.DropCapSpecifier;
import org.apache.poi.hwpf.usermodel.LineSpacingDescriptor;
import org.apache.poi.hwpf.usermodel.ParagraphProperties;
import org.apache.poi.hwpf.usermodel.ShadingDescriptor;
import org.apache.poi.hwpf.usermodel.ShadingDescriptor80;
import org.apache.poi.util.Internal;
import org.apache.poi.util.LittleEndian;
import org.apache.poi.util.POILogFactory;
import org.apache.poi.util.POILogger;

@Internal
public final class ParagraphSprmUncompressor extends SprmUncompressor {
    public static final POILogger logger = POILogFactory.getLogger(ParagraphSprmUncompressor.class);

    public static void handleTabs(ParagraphProperties paragraphProperties, SprmOperation sprmOperation) {
        byte[] grpprl = sprmOperation.getGrpprl();
        int grpprlOffset = sprmOperation.getGrpprlOffset();
        int i2 = grpprlOffset + 1;
        byte b2 = grpprl[grpprlOffset];
        int[] rgdxaTab = paragraphProperties.getRgdxaTab();
        TabDescriptor[] rgtbd = paragraphProperties.getRgtbd();
        HashMap hashMap = new HashMap();
        for (int i3 = 0; i3 < rgdxaTab.length; i3++) {
            hashMap.put(Integer.valueOf(rgdxaTab[i3]), rgtbd[i3]);
        }
        for (int i4 = 0; i4 < b2; i4++) {
            hashMap.remove(Integer.valueOf(LittleEndian.getShort(grpprl, i2)));
            i2 += 2;
        }
        int i5 = i2 + 1;
        byte b3 = grpprl[i2];
        int i6 = i5;
        for (int i7 = 0; i7 < b3; i7++) {
            hashMap.put(Integer.valueOf(LittleEndian.getShort(grpprl, i6)), new TabDescriptor(grpprl, (TBDAbstractType.getSize() * b3) + i7 + i5));
            i6 += 2;
        }
        int size = hashMap.size();
        int[] iArr = new int[size];
        TabDescriptor[] tabDescriptorArr = new TabDescriptor[size];
        ArrayList arrayList = new ArrayList(hashMap.keySet());
        Collections.sort(arrayList);
        for (int i8 = 0; i8 < size; i8++) {
            Integer num = (Integer) arrayList.get(i8);
            iArr[i8] = num.intValue();
            if (hashMap.containsKey(num)) {
                tabDescriptorArr[i8] = (TabDescriptor) hashMap.get(num);
            } else {
                tabDescriptorArr[i8] = new TabDescriptor();
            }
        }
        paragraphProperties.setRgdxaTab(iArr);
        paragraphProperties.setRgtbd(tabDescriptorArr);
    }

    public static void unCompressPAPOperation(ParagraphProperties paragraphProperties, SprmOperation sprmOperation) {
        int operation = sprmOperation.getOperation();
        if (operation == 93) {
            paragraphProperties.setDxaRight(sprmOperation.getOperand());
        } else if (operation == 94) {
            paragraphProperties.setDxaLeft(sprmOperation.getOperand());
        } else if (operation == 96) {
            paragraphProperties.setDxaLeft1(sprmOperation.getOperand());
        } else if (operation == 97) {
            paragraphProperties.setJustificationLogical((byte) sprmOperation.getOperand());
        } else if (operation != 103) {
            boolean z = false;
            switch (operation) {
                case 0:
                    paragraphProperties.setIstd(sprmOperation.getOperand());
                    return;
                case 1:
                case 21:
                    return;
                case 2:
                    if (paragraphProperties.getIstd() <= 9 || paragraphProperties.getIstd() >= 1) {
                        byte operand = (byte) sprmOperation.getOperand();
                        paragraphProperties.setIstd(paragraphProperties.getIstd() + operand);
                        paragraphProperties.setLvl((byte) (paragraphProperties.getLvl() + operand));
                        if (((operand >> 7) & 1) == 1) {
                            paragraphProperties.setIstd(Math.max(paragraphProperties.getIstd(), 1));
                            return;
                        } else {
                            paragraphProperties.setIstd(Math.min(paragraphProperties.getIstd(), 9));
                            return;
                        }
                    } else {
                        return;
                    }
                case 3:
                    paragraphProperties.setJc((byte) sprmOperation.getOperand());
                    return;
                case 4:
                    if (sprmOperation.getOperand() != 0) {
                        z = true;
                    }
                    paragraphProperties.setFSideBySide(z);
                    return;
                case 5:
                    if (sprmOperation.getOperand() != 0) {
                        z = true;
                    }
                    paragraphProperties.setFKeep(z);
                    return;
                case 6:
                    if (sprmOperation.getOperand() != 0) {
                        z = true;
                    }
                    paragraphProperties.setFKeepFollow(z);
                    return;
                case 7:
                    if (sprmOperation.getOperand() != 0) {
                        z = true;
                    }
                    paragraphProperties.setFPageBreakBefore(z);
                    return;
                case 8:
                    paragraphProperties.setBrcl((byte) sprmOperation.getOperand());
                    return;
                case 9:
                    paragraphProperties.setBrcp((byte) sprmOperation.getOperand());
                    return;
                case 10:
                    paragraphProperties.setIlvl((byte) sprmOperation.getOperand());
                    return;
                case 11:
                    paragraphProperties.setIlfo(sprmOperation.getOperandShortSigned());
                    return;
                case 12:
                    if (sprmOperation.getOperand() != 0) {
                        z = true;
                    }
                    paragraphProperties.setFNoLnn(z);
                    return;
                case 13:
                    handleTabs(paragraphProperties, sprmOperation);
                    return;
                case 14:
                    paragraphProperties.setDxaRight(sprmOperation.getOperand());
                    return;
                case 15:
                    paragraphProperties.setDxaLeft(sprmOperation.getOperand());
                    return;
                case 16:
                    paragraphProperties.setDxaLeft(sprmOperation.getOperand() + paragraphProperties.getDxaLeft());
                    paragraphProperties.setDxaLeft(Math.max(0, paragraphProperties.getDxaLeft()));
                    return;
                case 17:
                    paragraphProperties.setDxaLeft1(sprmOperation.getOperand());
                    return;
                case 18:
                    paragraphProperties.setLspd(new LineSpacingDescriptor(sprmOperation.getGrpprl(), sprmOperation.getGrpprlOffset()));
                    return;
                case 19:
                    paragraphProperties.setDyaBefore(sprmOperation.getOperand());
                    return;
                case 20:
                    paragraphProperties.setDyaAfter(sprmOperation.getOperand());
                    return;
                case 22:
                    if (sprmOperation.getOperand() != 0) {
                        z = true;
                    }
                    paragraphProperties.setFInTable(z);
                    return;
                case 23:
                    if (sprmOperation.getOperand() != 0) {
                        z = true;
                    }
                    paragraphProperties.setFTtp(z);
                    return;
                case 24:
                    paragraphProperties.setDxaAbs(sprmOperation.getOperand());
                    return;
                case 25:
                    paragraphProperties.setDyaAbs(sprmOperation.getOperand());
                    return;
                case 26:
                    paragraphProperties.setDxaWidth(sprmOperation.getOperand());
                    return;
                case 27:
                    byte operand2 = (byte) sprmOperation.getOperand();
                    byte b2 = (byte) ((operand2 & 12) >> 2);
                    byte b3 = (byte) (operand2 & 3);
                    if (b2 != 3) {
                        paragraphProperties.setPcVert(b2);
                    }
                    if (b3 != 3) {
                        paragraphProperties.setPcHorz(b3);
                        return;
                    }
                    return;
                default:
                    switch (operation) {
                        case 34:
                            paragraphProperties.setDxaFromText(sprmOperation.getOperand());
                            return;
                        case 35:
                            paragraphProperties.setWr((byte) sprmOperation.getOperand());
                            return;
                        case 36:
                            paragraphProperties.setBrcTop(new BorderCode(sprmOperation.getGrpprl(), sprmOperation.getGrpprlOffset()));
                            return;
                        case 37:
                            paragraphProperties.setBrcLeft(new BorderCode(sprmOperation.getGrpprl(), sprmOperation.getGrpprlOffset()));
                            return;
                        case 38:
                            paragraphProperties.setBrcBottom(new BorderCode(sprmOperation.getGrpprl(), sprmOperation.getGrpprlOffset()));
                            return;
                        case 39:
                            paragraphProperties.setBrcRight(new BorderCode(sprmOperation.getGrpprl(), sprmOperation.getGrpprlOffset()));
                            return;
                        case 40:
                            paragraphProperties.setBrcBetween(new BorderCode(sprmOperation.getGrpprl(), sprmOperation.getGrpprlOffset()));
                            return;
                        case 41:
                            paragraphProperties.setBrcBar(new BorderCode(sprmOperation.getGrpprl(), sprmOperation.getGrpprlOffset()));
                            return;
                        case 42:
                            if (sprmOperation.getOperand() != 0) {
                                z = true;
                            }
                            paragraphProperties.setFNoAutoHyph(z);
                            return;
                        case 43:
                            paragraphProperties.setDyaHeight(sprmOperation.getOperand());
                            return;
                        case 44:
                            paragraphProperties.setDcs(new DropCapSpecifier((short) sprmOperation.getOperand()));
                            return;
                        case 45:
                            paragraphProperties.setShd(new ShadingDescriptor80((short) sprmOperation.getOperand()).toShadingDescriptor());
                            return;
                        case 46:
                            paragraphProperties.setDyaFromText(sprmOperation.getOperand());
                            return;
                        case 47:
                            paragraphProperties.setDxaFromText(sprmOperation.getOperand());
                            return;
                        case 48:
                            if (sprmOperation.getOperand() != 0) {
                                z = true;
                            }
                            paragraphProperties.setFLocked(z);
                            return;
                        case 49:
                            if (sprmOperation.getOperand() != 0) {
                                z = true;
                            }
                            paragraphProperties.setFWidowControl(z);
                            return;
                        default:
                            switch (operation) {
                                case 51:
                                    if (sprmOperation.getOperand() != 0) {
                                        z = true;
                                    }
                                    paragraphProperties.setFKinsoku(z);
                                    return;
                                case 52:
                                    if (sprmOperation.getOperand() != 0) {
                                        z = true;
                                    }
                                    paragraphProperties.setFWordWrap(z);
                                    return;
                                case 53:
                                    if (sprmOperation.getOperand() != 0) {
                                        z = true;
                                    }
                                    paragraphProperties.setFOverflowPunct(z);
                                    return;
                                case 54:
                                    if (sprmOperation.getOperand() != 0) {
                                        z = true;
                                    }
                                    paragraphProperties.setFTopLinePunct(z);
                                    return;
                                case 55:
                                    if (sprmOperation.getOperand() != 0) {
                                        z = true;
                                    }
                                    paragraphProperties.setFAutoSpaceDE(z);
                                    return;
                                case 56:
                                    if (sprmOperation.getOperand() != 0) {
                                        z = true;
                                    }
                                    paragraphProperties.setFAutoSpaceDN(z);
                                    return;
                                case 57:
                                    paragraphProperties.setWAlignFont(sprmOperation.getOperand());
                                    return;
                                case 58:
                                    paragraphProperties.setFontAlign((short) sprmOperation.getOperand());
                                    return;
                                case 59:
                                    return;
                                default:
                                    switch (operation) {
                                        case 62:
                                            int size = sprmOperation.size() - 3;
                                            byte[] bArr = new byte[size];
                                            System.arraycopy(bArr, 0, sprmOperation.getGrpprl(), sprmOperation.getGrpprlOffset(), size);
                                            paragraphProperties.setAnld(bArr);
                                            return;
                                        case 63:
                                            byte[] grpprl = sprmOperation.getGrpprl();
                                            int grpprlOffset = sprmOperation.getGrpprlOffset();
                                            if (grpprl[grpprlOffset] != 0) {
                                                z = true;
                                            }
                                            paragraphProperties.setFPropRMark(z);
                                            paragraphProperties.setIbstPropRMark(LittleEndian.getShort(grpprl, grpprlOffset + 1));
                                            paragraphProperties.setDttmPropRMark(new DateAndTime(grpprl, grpprlOffset + 3));
                                            return;
                                        case 64:
                                            paragraphProperties.setLvl((byte) sprmOperation.getOperand());
                                            return;
                                        case 65:
                                            if (sprmOperation.getOperand() != 0) {
                                                z = true;
                                            }
                                            paragraphProperties.setFBiDi(z);
                                            return;
                                        default:
                                            switch (operation) {
                                                case 67:
                                                    if (sprmOperation.getOperand() != 0) {
                                                        z = true;
                                                    }
                                                    paragraphProperties.setFNumRMIns(z);
                                                    return;
                                                case 68:
                                                    return;
                                                case 69:
                                                    if (sprmOperation.getSizeCode() == 6) {
                                                        int size2 = sprmOperation.size() - 3;
                                                        byte[] bArr2 = new byte[size2];
                                                        System.arraycopy(bArr2, 0, sprmOperation.getGrpprl(), sprmOperation.getGrpprlOffset(), size2);
                                                        paragraphProperties.setNumrm(bArr2);
                                                        return;
                                                    }
                                                    return;
                                                default:
                                                    switch (operation) {
                                                        case 71:
                                                            if (sprmOperation.getOperand() != 0) {
                                                                z = true;
                                                            }
                                                            paragraphProperties.setFUsePgsuSettings(z);
                                                            return;
                                                        case 72:
                                                            if (sprmOperation.getOperand() != 0) {
                                                                z = true;
                                                            }
                                                            paragraphProperties.setFAdjustRight(z);
                                                            return;
                                                        case 73:
                                                            paragraphProperties.setItap(sprmOperation.getOperand());
                                                            return;
                                                        case 74:
                                                            paragraphProperties.setItap((byte) (sprmOperation.getOperand() + paragraphProperties.getItap()));
                                                            return;
                                                        case 75:
                                                            if (sprmOperation.getOperand() != 0) {
                                                                z = true;
                                                            }
                                                            paragraphProperties.setFInnerTableCell(z);
                                                            return;
                                                        case 76:
                                                            if (sprmOperation.getOperand() != 0) {
                                                                z = true;
                                                            }
                                                            paragraphProperties.setFTtpEmbedded(z);
                                                            return;
                                                        case 77:
                                                            paragraphProperties.setShading(new ShadingDescriptor(sprmOperation.getGrpprl(), 3));
                                                            return;
                                                        default:
                                                            POILogger pOILogger = logger;
                                                            pOILogger.log(1, "Unknown PAP sprm ignored: " + sprmOperation);
                                                            return;
                                                    }
                                            }
                                    }
                            }
                    }
            }
        } else {
            paragraphProperties.setRsid((long) sprmOperation.getOperand());
        }
    }

    public static ParagraphProperties uncompressPAP(ParagraphProperties paragraphProperties, byte[] bArr, int i2) {
        try {
            ParagraphProperties paragraphProperties2 = (ParagraphProperties) paragraphProperties.clone();
            SprmIterator sprmIterator = new SprmIterator(bArr, i2);
            while (sprmIterator.hasNext()) {
                SprmOperation next = sprmIterator.next();
                if (next.getType() == 1) {
                    try {
                        unCompressPAPOperation(paragraphProperties2, next);
                    } catch (Exception e2) {
                        POILogger pOILogger = logger;
                        StringBuilder b2 = a.b("Unable to apply SPRM operation '");
                        b2.append(next.getOperation());
                        b2.append("': ");
                        pOILogger.log(7, b2.toString(), e2);
                    }
                }
            }
            return paragraphProperties2;
        } catch (CloneNotSupportedException unused) {
            throw new RuntimeException("There is no way this exception should happen!!");
        }
    }
}
