package org.apache.poi.hwpf.sprm;

import java.util.ArrayList;
import java.util.Arrays;
import org.apache.poi.hwpf.usermodel.SectionProperties;
import org.apache.poi.util.Internal;
import org.apache.poi.util.LittleEndian;

@Internal
public final class SectionSprmCompressor {
    public static final SectionProperties DEFAULT_SEP = new SectionProperties();

    public static byte[] compressSectionProperty(SectionProperties sectionProperties) {
        ArrayList arrayList = new ArrayList();
        int addSprm = sectionProperties.getCnsPgn() != DEFAULT_SEP.getCnsPgn() ? SprmUtils.addSprm(12288, sectionProperties.getCnsPgn(), null, arrayList) + 0 : 0;
        if (sectionProperties.getIHeadingPgn() != DEFAULT_SEP.getIHeadingPgn()) {
            addSprm += SprmUtils.addSprm(12289, sectionProperties.getIHeadingPgn(), null, arrayList);
        }
        if (!Arrays.equals(sectionProperties.getOlstAnm(), DEFAULT_SEP.getOlstAnm())) {
            addSprm += SprmUtils.addSprm(-11774, 0, sectionProperties.getOlstAnm(), arrayList);
        }
        if (sectionProperties.getFEvenlySpaced() != DEFAULT_SEP.getFEvenlySpaced()) {
            addSprm += SprmUtils.addSprm(12293, sectionProperties.getFEvenlySpaced() ? 1 : 0, null, arrayList);
        }
        if (sectionProperties.getFUnlocked() != DEFAULT_SEP.getFUnlocked()) {
            addSprm += SprmUtils.addSprm(12294, sectionProperties.getFUnlocked() ? 1 : 0, null, arrayList);
        }
        if (sectionProperties.getDmBinFirst() != DEFAULT_SEP.getDmBinFirst()) {
            addSprm += SprmUtils.addSprm(20487, sectionProperties.getDmBinFirst(), null, arrayList);
        }
        if (sectionProperties.getDmBinOther() != DEFAULT_SEP.getDmBinOther()) {
            addSprm += SprmUtils.addSprm(20488, sectionProperties.getDmBinOther(), null, arrayList);
        }
        if (sectionProperties.getBkc() != DEFAULT_SEP.getBkc()) {
            addSprm += SprmUtils.addSprm(12297, sectionProperties.getBkc(), null, arrayList);
        }
        if (sectionProperties.getFTitlePage() != DEFAULT_SEP.getFTitlePage()) {
            addSprm += SprmUtils.addSprm(12298, sectionProperties.getFTitlePage() ? 1 : 0, null, arrayList);
        }
        if (sectionProperties.getCcolM1() != DEFAULT_SEP.getCcolM1()) {
            addSprm += SprmUtils.addSprm(20491, sectionProperties.getCcolM1(), null, arrayList);
        }
        if (sectionProperties.getDxaColumns() != DEFAULT_SEP.getDxaColumns()) {
            addSprm += SprmUtils.addSprm(-28660, sectionProperties.getDxaColumns(), null, arrayList);
        }
        if (sectionProperties.getFAutoPgn() != DEFAULT_SEP.getFAutoPgn()) {
            addSprm += SprmUtils.addSprm(12301, sectionProperties.getFAutoPgn() ? 1 : 0, null, arrayList);
        }
        if (sectionProperties.getNfcPgn() != DEFAULT_SEP.getNfcPgn()) {
            addSprm += SprmUtils.addSprm(12302, sectionProperties.getNfcPgn(), null, arrayList);
        }
        if (sectionProperties.getDyaPgn() != DEFAULT_SEP.getDyaPgn()) {
            addSprm += SprmUtils.addSprm(-20465, sectionProperties.getDyaPgn(), null, arrayList);
        }
        if (sectionProperties.getDxaPgn() != DEFAULT_SEP.getDxaPgn()) {
            addSprm += SprmUtils.addSprm(-20464, sectionProperties.getDxaPgn(), null, arrayList);
        }
        if (sectionProperties.getFPgnRestart() != DEFAULT_SEP.getFPgnRestart()) {
            addSprm += SprmUtils.addSprm(12305, sectionProperties.getFPgnRestart() ? 1 : 0, null, arrayList);
        }
        if (sectionProperties.getFEndNote() != DEFAULT_SEP.getFEndNote()) {
            addSprm += SprmUtils.addSprm(12306, sectionProperties.getFEndNote() ? 1 : 0, null, arrayList);
        }
        if (sectionProperties.getLnc() != DEFAULT_SEP.getLnc()) {
            addSprm += SprmUtils.addSprm(12307, sectionProperties.getLnc(), null, arrayList);
        }
        if (sectionProperties.getGrpfIhdt() != DEFAULT_SEP.getGrpfIhdt()) {
            addSprm += SprmUtils.addSprm(12308, sectionProperties.getGrpfIhdt(), null, arrayList);
        }
        if (sectionProperties.getNLnnMod() != DEFAULT_SEP.getNLnnMod()) {
            addSprm += SprmUtils.addSprm(20501, sectionProperties.getNLnnMod(), null, arrayList);
        }
        if (sectionProperties.getDxaLnn() != DEFAULT_SEP.getDxaLnn()) {
            addSprm += SprmUtils.addSprm(-28650, sectionProperties.getDxaLnn(), null, arrayList);
        }
        if (sectionProperties.getDyaHdrTop() != DEFAULT_SEP.getDyaHdrTop()) {
            addSprm += SprmUtils.addSprm(-20457, sectionProperties.getDyaHdrTop(), null, arrayList);
        }
        if (sectionProperties.getDyaHdrBottom() != DEFAULT_SEP.getDyaHdrBottom()) {
            addSprm += SprmUtils.addSprm(-20456, sectionProperties.getDyaHdrBottom(), null, arrayList);
        }
        if (sectionProperties.getFLBetween() != DEFAULT_SEP.getFLBetween()) {
            addSprm += SprmUtils.addSprm(12313, sectionProperties.getFLBetween() ? 1 : 0, null, arrayList);
        }
        if (sectionProperties.getVjc() != DEFAULT_SEP.getVjc()) {
            addSprm += SprmUtils.addSprm(12314, sectionProperties.getVjc(), null, arrayList);
        }
        if (sectionProperties.getLnnMin() != DEFAULT_SEP.getLnnMin()) {
            addSprm += SprmUtils.addSprm(20507, sectionProperties.getLnnMin(), null, arrayList);
        }
        if (sectionProperties.getPgnStart() != DEFAULT_SEP.getPgnStart()) {
            addSprm += SprmUtils.addSprm(20508, sectionProperties.getPgnStart(), null, arrayList);
        }
        if (sectionProperties.getDmOrientPage() != DEFAULT_SEP.getDmOrientPage()) {
            addSprm += SprmUtils.addSprm(12317, sectionProperties.getDmOrientPage() ? 1 : 0, null, arrayList);
        }
        if (sectionProperties.getXaPage() != DEFAULT_SEP.getXaPage()) {
            addSprm += SprmUtils.addSprm(-20449, sectionProperties.getXaPage(), null, arrayList);
        }
        if (sectionProperties.getYaPage() != DEFAULT_SEP.getYaPage()) {
            addSprm += SprmUtils.addSprm(-20448, sectionProperties.getYaPage(), null, arrayList);
        }
        if (sectionProperties.getDxaLeft() != DEFAULT_SEP.getDxaLeft()) {
            addSprm += SprmUtils.addSprm(-20447, sectionProperties.getDxaLeft(), null, arrayList);
        }
        if (sectionProperties.getDxaRight() != DEFAULT_SEP.getDxaRight()) {
            addSprm += SprmUtils.addSprm(-20446, sectionProperties.getDxaRight(), null, arrayList);
        }
        if (sectionProperties.getDyaTop() != DEFAULT_SEP.getDyaTop()) {
            addSprm += SprmUtils.addSprm(-28637, sectionProperties.getDyaTop(), null, arrayList);
        }
        if (sectionProperties.getDyaBottom() != DEFAULT_SEP.getDyaBottom()) {
            addSprm += SprmUtils.addSprm(-28636, sectionProperties.getDyaBottom(), null, arrayList);
        }
        if (sectionProperties.getDzaGutter() != DEFAULT_SEP.getDzaGutter()) {
            addSprm += SprmUtils.addSprm(-20443, sectionProperties.getDzaGutter(), null, arrayList);
        }
        if (sectionProperties.getDmPaperReq() != DEFAULT_SEP.getDmPaperReq()) {
            addSprm += SprmUtils.addSprm(20518, sectionProperties.getDmPaperReq(), null, arrayList);
        }
        if (!(sectionProperties.getFPropMark() == DEFAULT_SEP.getFPropMark() && sectionProperties.getIbstPropRMark() == DEFAULT_SEP.getIbstPropRMark() && sectionProperties.getDttmPropRMark().equals(DEFAULT_SEP.getDttmPropRMark()))) {
            byte[] bArr = new byte[7];
            bArr[0] = sectionProperties.getFPropMark() ? (byte) 1 : 0;
            LittleEndian.putShort(bArr, 0, (short) sectionProperties.getIbstPropRMark());
            sectionProperties.getDttmPropRMark().serialize(bArr, 3);
            addSprm += SprmUtils.addSprm(-11737, -1, bArr, arrayList);
        }
        if (!sectionProperties.getBrcTop().equals(DEFAULT_SEP.getBrcTop())) {
            addSprm += SprmUtils.addSprm(28715, sectionProperties.getBrcTop().toInt(), null, arrayList);
        }
        if (!sectionProperties.getBrcLeft().equals(DEFAULT_SEP.getBrcLeft())) {
            addSprm += SprmUtils.addSprm(28716, sectionProperties.getBrcLeft().toInt(), null, arrayList);
        }
        if (!sectionProperties.getBrcBottom().equals(DEFAULT_SEP.getBrcBottom())) {
            addSprm += SprmUtils.addSprm(28717, sectionProperties.getBrcBottom().toInt(), null, arrayList);
        }
        if (!sectionProperties.getBrcRight().equals(DEFAULT_SEP.getBrcRight())) {
            addSprm += SprmUtils.addSprm(28718, sectionProperties.getBrcRight().toInt(), null, arrayList);
        }
        if (sectionProperties.getPgbProp() != DEFAULT_SEP.getPgbProp()) {
            addSprm += SprmUtils.addSprm(21039, sectionProperties.getPgbProp(), null, arrayList);
        }
        if (sectionProperties.getDxtCharSpace() != DEFAULT_SEP.getDxtCharSpace()) {
            addSprm += SprmUtils.addSprm(28720, sectionProperties.getDxtCharSpace(), null, arrayList);
        }
        if (sectionProperties.getDyaLinePitch() != DEFAULT_SEP.getDyaLinePitch()) {
            addSprm += SprmUtils.addSprm(-28623, sectionProperties.getDyaLinePitch(), null, arrayList);
        }
        if (sectionProperties.getClm() != DEFAULT_SEP.getClm()) {
            addSprm += SprmUtils.addSprm(20530, sectionProperties.getClm(), null, arrayList);
        }
        if (sectionProperties.getWTextFlow() != DEFAULT_SEP.getWTextFlow()) {
            addSprm += SprmUtils.addSprm(20531, sectionProperties.getWTextFlow(), null, arrayList);
        }
        return SprmUtils.getGrpprl(arrayList, addSprm);
    }
}
