package org.apache.poi.hwpf.sprm;

import b.b.a.a.a;
import java.util.Arrays;
import org.apache.poi.util.Internal;
import org.apache.poi.util.LittleEndian;

@Internal
public final class SprmBuffer implements Cloneable {
    public static final /* synthetic */ boolean $assertionsDisabled = false;
    public byte[] _buf;
    public boolean _istd;
    public int _offset;
    public final int _sprmsStartOffset;

    @Deprecated
    public SprmBuffer() {
        this(0);
    }

    private void ensureCapacity(int i2) {
        int i3 = this._offset;
        int i4 = i3 + i2;
        byte[] bArr = this._buf;
        if (i4 >= bArr.length) {
            byte[] bArr2 = new byte[(i3 + i2)];
            System.arraycopy(bArr, 0, bArr2, 0, bArr.length);
            this._buf = bArr2;
        }
    }

    private int findSprmOffset(short s) {
        SprmOperation findSprm = findSprm(s);
        if (findSprm == null) {
            return -1;
        }
        return findSprm.getGrpprlOffset();
    }

    public void addSprm(short s, byte b2) {
        ensureCapacity(3);
        LittleEndian.putShort(this._buf, this._offset, s);
        int i2 = this._offset + 2;
        this._offset = i2;
        byte[] bArr = this._buf;
        this._offset = i2 + 1;
        bArr[i2] = b2;
    }

    public void append(byte[] bArr) {
        append(bArr, 0);
    }

    public boolean equals(Object obj) {
        if (!(obj instanceof SprmBuffer)) {
            return false;
        }
        return Arrays.equals(this._buf, ((SprmBuffer) obj)._buf);
    }

    public SprmOperation findSprm(short s) {
        int operationFromOpcode = SprmOperation.getOperationFromOpcode(s);
        int typeFromOpcode = SprmOperation.getTypeFromOpcode(s);
        SprmIterator sprmIterator = new SprmIterator(this._buf, 2);
        while (sprmIterator.hasNext()) {
            SprmOperation next = sprmIterator.next();
            if (next.getOperation() == operationFromOpcode && next.getType() == typeFromOpcode) {
                return next;
            }
        }
        return null;
    }

    public int hashCode() {
        return 42;
    }

    public SprmIterator iterator() {
        return new SprmIterator(this._buf, this._sprmsStartOffset);
    }

    public byte[] toByteArray() {
        return this._buf;
    }

    public String toString() {
        StringBuilder b2 = a.b("Sprms (");
        b2.append(this._buf.length);
        b2.append(" byte(s)): ");
        SprmIterator it = iterator();
        while (it.hasNext()) {
            try {
                b2.append(it.next());
            } catch (Exception unused) {
                b2.append("error");
            }
            b2.append("; ");
        }
        return b2.toString();
    }

    public void updateSprm(short s, byte b2) {
        int findSprmOffset = findSprmOffset(s);
        if (findSprmOffset != -1) {
            this._buf[findSprmOffset] = b2;
        } else {
            addSprm(s, b2);
        }
    }

    @Deprecated
    public SprmBuffer(byte[] bArr) {
        this(bArr, 0);
    }

    public void append(byte[] bArr, int i2) {
        ensureCapacity(bArr.length - i2);
        System.arraycopy(bArr, i2, this._buf, this._offset, bArr.length - i2);
        this._offset = (bArr.length - i2) + this._offset;
    }

    @Override // java.lang.Object
    public SprmBuffer clone() {
        try {
            SprmBuffer sprmBuffer = (SprmBuffer) super.clone();
            byte[] bArr = new byte[this._buf.length];
            sprmBuffer._buf = bArr;
            System.arraycopy(this._buf, 0, bArr, 0, this._buf.length);
            return sprmBuffer;
        } catch (CloneNotSupportedException e2) {
            throw new RuntimeException(e2);
        }
    }

    @Deprecated
    public SprmBuffer(byte[] bArr, boolean z) {
        this(bArr, z, 0);
    }

    public SprmBuffer(byte[] bArr, boolean z, int i2) {
        this._offset = bArr.length;
        this._buf = bArr;
        this._istd = z;
        this._sprmsStartOffset = i2;
    }

    /* JADX DEBUG: Multi-variable search result rejected for r4v0, resolved type: boolean */
    /* JADX WARN: Multi-variable type inference failed */
    public void updateSprm(short s, boolean z) {
        int findSprmOffset = findSprmOffset(s);
        if (findSprmOffset != -1) {
            this._buf[findSprmOffset] = z ? (byte) 1 : 0;
        } else {
            addSprm(s, z ? 1 : 0);
        }
    }

    public void addSprm(short s, byte[] bArr) {
        ensureCapacity(bArr.length + 3);
        LittleEndian.putShort(this._buf, this._offset, s);
        int i2 = this._offset + 2;
        this._offset = i2;
        byte[] bArr2 = this._buf;
        int i3 = i2 + 1;
        this._offset = i3;
        bArr2[i2] = (byte) bArr.length;
        System.arraycopy(bArr, 0, bArr2, i3, bArr.length);
    }

    public void updateSprm(short s, int i2) {
        int findSprmOffset = findSprmOffset(s);
        if (findSprmOffset != -1) {
            LittleEndian.putInt(this._buf, findSprmOffset, i2);
        } else {
            addSprm(s, i2);
        }
    }

    public SprmBuffer(byte[] bArr, int i2) {
        this(bArr, false, i2);
    }

    public SprmBuffer(int i2) {
        this._buf = new byte[(i2 + 4)];
        this._offset = i2;
        this._sprmsStartOffset = i2;
    }

    public void updateSprm(short s, short s2) {
        int findSprmOffset = findSprmOffset(s);
        if (findSprmOffset != -1) {
            LittleEndian.putShort(this._buf, findSprmOffset, s2);
        } else {
            addSprm(s, s2);
        }
    }

    public void addSprm(short s, int i2) {
        ensureCapacity(6);
        LittleEndian.putShort(this._buf, this._offset, s);
        int i3 = this._offset + 2;
        this._offset = i3;
        LittleEndian.putInt(this._buf, i3, i2);
        this._offset += 4;
    }

    public void addSprm(short s, short s2) {
        ensureCapacity(4);
        LittleEndian.putShort(this._buf, this._offset, s);
        int i2 = this._offset + 2;
        this._offset = i2;
        LittleEndian.putShort(this._buf, i2, s2);
        this._offset += 2;
    }
}
