package org.apache.poi.hwpf.sprm;

import b.b.a.a.a;
import org.apache.poi.util.BitField;
import org.apache.poi.util.BitFieldFactory;
import org.apache.poi.util.Internal;
import org.apache.poi.util.LittleEndian;

@Internal(since = "3.8 beta 4")
public final class SprmOperation {
    public static final BitField BITFIELD_OP = BitFieldFactory.getInstance(511);
    public static final BitField BITFIELD_SIZECODE = BitFieldFactory.getInstance(57344);
    public static final BitField BITFIELD_SPECIAL = BitFieldFactory.getInstance(512);
    public static final BitField BITFIELD_TYPE = BitFieldFactory.getInstance(7168);
    public static final short SPRM_LONG_PARAGRAPH = -14827;
    public static final short SPRM_LONG_TABLE = -10744;
    public static final int TYPE_CHP = 2;
    public static final int TYPE_PAP = 1;
    public static final int TYPE_PIC = 3;
    public static final int TYPE_SEP = 4;
    public static final int TYPE_TAP = 5;
    public int _gOffset;
    public final byte[] _grpprl;
    public final int _offset;
    public final int _size;
    public final short _value;

    public SprmOperation(byte[] bArr, int i2) {
        this._grpprl = bArr;
        short s = LittleEndian.getShort(bArr, i2);
        this._value = s;
        this._offset = i2;
        this._gOffset = i2 + 2;
        this._size = initSize(s);
    }

    public static int getOperationFromOpcode(short s) {
        return BITFIELD_OP.getValue(s);
    }

    public static int getTypeFromOpcode(short s) {
        return BITFIELD_TYPE.getValue(s);
    }

    private int initSize(short s) {
        switch (getSizeCode()) {
            case 0:
            case 1:
                return 3;
            case 2:
            case 4:
            case 5:
                return 4;
            case 3:
                return 6;
            case 6:
                int i2 = this._gOffset;
                if (s == -10744 || s == -14827) {
                    int i3 = (65535 & LittleEndian.getShort(this._grpprl, i2)) + 3;
                    this._gOffset += 2;
                    return i3;
                }
                byte[] bArr = this._grpprl;
                this._gOffset = i2 + 1;
                return (bArr[i2] & 255) + 3;
            case 7:
                return 5;
            default:
                throw new IllegalArgumentException("SPRM contains an invalid size code");
        }
    }

    public byte[] getGrpprl() {
        return this._grpprl;
    }

    public int getGrpprlOffset() {
        return this._gOffset;
    }

    public int getOperand() {
        switch (getSizeCode()) {
            case 0:
            case 1:
                return this._grpprl[this._gOffset];
            case 2:
            case 4:
            case 5:
                return LittleEndian.getShort(this._grpprl, this._gOffset);
            case 3:
                return LittleEndian.getInt(this._grpprl, this._gOffset);
            case 6:
                byte b2 = this._grpprl[this._gOffset + 1];
                byte[] bArr = new byte[4];
                for (int i2 = 0; i2 < b2; i2++) {
                    int i3 = this._gOffset;
                    int i4 = i3 + i2;
                    byte[] bArr2 = this._grpprl;
                    if (i4 < bArr2.length) {
                        bArr[i2] = bArr2[i3 + 1 + i2];
                    }
                }
                return LittleEndian.getInt(bArr, 0);
            case 7:
                byte[] bArr3 = this._grpprl;
                int i5 = this._gOffset;
                return LittleEndian.getInt(new byte[]{bArr3[i5], bArr3[i5 + 1], bArr3[i5 + 2], 0}, 0);
            default:
                throw new IllegalArgumentException("SPRM contains an invalid size code");
        }
    }

    public short getOperandShortSigned() {
        int sizeCode = getSizeCode();
        if (sizeCode == 2 || sizeCode == 4 || sizeCode == 5) {
            return LittleEndian.getShort(this._grpprl, this._gOffset);
        }
        throw new UnsupportedOperationException("Current SPRM doesn't have signed short operand: " + this);
    }

    public int getOperation() {
        return BITFIELD_OP.getValue(this._value);
    }

    public int getSizeCode() {
        return BITFIELD_SIZECODE.getValue(this._value);
    }

    public int getType() {
        return BITFIELD_TYPE.getValue(this._value);
    }

    public int size() {
        return this._size;
    }

    public byte[] toByteArray() {
        byte[] bArr = new byte[size()];
        System.arraycopy(this._grpprl, this._offset, bArr, 0, size());
        return bArr;
    }

    public String toString() {
        StringBuilder b2 = a.b("[SPRM] (0x");
        b2.append(Integer.toHexString(this._value & 65535));
        b2.append("): ");
        try {
            b2.append(getOperand());
        } catch (Exception unused) {
            b2.append("(error)");
        }
        return b2.toString();
    }
}
