package org.apache.poi.hwpf.sprm;

import java.util.ArrayList;
import java.util.Arrays;
import org.apache.poi.hwpf.usermodel.TableCellDescriptor;
import org.apache.poi.hwpf.usermodel.TableProperties;
import org.apache.poi.hwpf.usermodel.TableRow;
import org.apache.poi.util.Internal;
import org.apache.poi.util.LittleEndian;

@Internal
public final class TableSprmCompressor {
    public static byte[] compressTableProperty(TableProperties tableProperties) {
        ArrayList arrayList = new ArrayList();
        int addSprm = tableProperties.getJc() != 0 ? SprmUtils.addSprm(TableRow.SPRM_TJC, tableProperties.getJc(), null, arrayList) + 0 : 0;
        if (tableProperties.getFCantSplit()) {
            addSprm += SprmUtils.addSprm(TableRow.SPRM_FCANTSPLIT, 1, null, arrayList);
        }
        if (tableProperties.getFTableHeader()) {
            addSprm += SprmUtils.addSprm(TableRow.SPRM_FTABLEHEADER, 1, null, arrayList);
        }
        byte[] bArr = new byte[24];
        tableProperties.getBrcTop().serialize(bArr, 0);
        tableProperties.getBrcLeft().serialize(bArr, 4);
        tableProperties.getBrcBottom().serialize(bArr, 8);
        tableProperties.getBrcRight().serialize(bArr, 12);
        tableProperties.getBrcHorizontal().serialize(bArr, 16);
        tableProperties.getBrcVertical().serialize(bArr, 20);
        if (!Arrays.equals(bArr, new byte[24])) {
            addSprm += SprmUtils.addSprm(-10747, 0, bArr, arrayList);
        }
        if (tableProperties.getDyaRowHeight() != 0) {
            addSprm += SprmUtils.addSprm(TableRow.SPRM_DYAROWHEIGHT, tableProperties.getDyaRowHeight(), null, arrayList);
        }
        if (tableProperties.getItcMac() > 0) {
            short itcMac = tableProperties.getItcMac();
            int i2 = ((itcMac + 1) * 2) + 1;
            byte[] bArr2 = new byte[((itcMac * 20) + i2)];
            bArr2[0] = (byte) itcMac;
            short[] rgdxaCenter = tableProperties.getRgdxaCenter();
            for (int i3 = 0; i3 < rgdxaCenter.length; i3++) {
                LittleEndian.putShort(bArr2, (i3 * 2) + 1, rgdxaCenter[i3]);
            }
            TableCellDescriptor[] rgtc = tableProperties.getRgtc();
            for (int i4 = 0; i4 < rgtc.length; i4++) {
                rgtc[i4].serialize(bArr2, (i4 * 20) + i2);
            }
            addSprm += SprmUtils.addSpecialSprm(SprmOperation.SPRM_LONG_TABLE, bArr2, arrayList);
        }
        if (tableProperties.getTlp() != null && !tableProperties.getTlp().isEmpty()) {
            byte[] bArr3 = new byte[4];
            tableProperties.getTlp().serialize(bArr3, 0);
            addSprm += SprmUtils.addSprm(29706, 0, bArr3, arrayList);
        }
        return SprmUtils.getGrpprl(arrayList, addSprm);
    }
}
