package org.apache.poi.hwpf.usermodel;

import b.b.a.a.a;
import java.util.ArrayList;
import java.util.Arrays;
import java.util.Collection;
import java.util.Collections;
import java.util.HashMap;
import java.util.LinkedHashMap;
import java.util.LinkedList;
import java.util.List;
import java.util.Map;
import org.apache.poi.hwpf.model.BookmarksTables;
import org.apache.poi.hwpf.model.GenericPropertyNode;
import org.apache.poi.hwpf.model.PropertyNode;

public class BookmarksImpl implements Bookmarks {
    public final BookmarksTables bookmarksTables;
    public Map<Integer, List<GenericPropertyNode>> sortedDescriptors = null;
    public int[] sortedStartPositions = null;

    public final class BookmarkImpl implements Bookmark {
        public final GenericPropertyNode first;

        public boolean equals(Object obj) {
            if (this == obj) {
                return true;
            }
            if (obj == null || BookmarkImpl.class != obj.getClass()) {
                return false;
            }
            BookmarkImpl bookmarkImpl = (BookmarkImpl) obj;
            GenericPropertyNode genericPropertyNode = this.first;
            if (genericPropertyNode == null) {
                if (bookmarkImpl.first != null) {
                    return false;
                }
            } else if (!genericPropertyNode.equals(bookmarkImpl.first)) {
                return false;
            }
            return true;
        }

        @Override // org.apache.poi.hwpf.usermodel.Bookmark
        public int getEnd() {
            try {
                return BookmarksImpl.this.bookmarksTables.getDescriptorLim(BookmarksImpl.this.bookmarksTables.getDescriptorFirstIndex(this.first)).getStart();
            } catch (IndexOutOfBoundsException unused) {
                return this.first.getEnd();
            }
        }

        @Override // org.apache.poi.hwpf.usermodel.Bookmark
        public String getName() {
            try {
                return BookmarksImpl.this.bookmarksTables.getName(BookmarksImpl.this.bookmarksTables.getDescriptorFirstIndex(this.first));
            } catch (ArrayIndexOutOfBoundsException unused) {
                return "";
            }
        }

        @Override // org.apache.poi.hwpf.usermodel.Bookmark
        public int getStart() {
            return this.first.getStart();
        }

        public int hashCode() {
            GenericPropertyNode genericPropertyNode = this.first;
            return (genericPropertyNode == null ? 0 : genericPropertyNode.hashCode()) + 31;
        }

        @Override // org.apache.poi.hwpf.usermodel.Bookmark
        public void setName(String str) {
            BookmarksImpl.this.bookmarksTables.setName(BookmarksImpl.this.bookmarksTables.getDescriptorFirstIndex(this.first), str);
        }

        public String toString() {
            StringBuilder b2 = a.b("Bookmark [");
            b2.append(getStart());
            b2.append("; ");
            b2.append(getEnd());
            b2.append("): name: ");
            b2.append(getName());
            return b2.toString();
        }

        public BookmarkImpl(GenericPropertyNode genericPropertyNode) {
            this.first = genericPropertyNode;
        }
    }

    public BookmarksImpl(BookmarksTables bookmarksTables2) {
        this.bookmarksTables = bookmarksTables2;
        reset();
    }

    private Bookmark getBookmark(GenericPropertyNode genericPropertyNode) {
        return new BookmarkImpl(genericPropertyNode);
    }

    private void reset() {
        this.sortedDescriptors = null;
        this.sortedStartPositions = null;
    }

    private void updateSortedDescriptors() {
        if (this.sortedDescriptors == null) {
            HashMap hashMap = new HashMap();
            int i2 = 0;
            for (int i3 = 0; i3 < this.bookmarksTables.getDescriptorsFirstCount(); i3++) {
                GenericPropertyNode descriptorFirst = this.bookmarksTables.getDescriptorFirst(i3);
                Integer valueOf = Integer.valueOf(descriptorFirst.getStart());
                List list = (List) hashMap.get(valueOf);
                if (list == null) {
                    list = new LinkedList();
                    hashMap.put(valueOf, list);
                }
                list.add(descriptorFirst);
            }
            int[] iArr = new int[hashMap.size()];
            for (Map.Entry entry : hashMap.entrySet()) {
                int i4 = i2 + 1;
                iArr[i2] = ((Integer) entry.getKey()).intValue();
                ArrayList arrayList = new ArrayList((Collection) entry.getValue());
                Collections.sort(arrayList, PropertyNode.EndComparator.instance);
                entry.setValue(arrayList);
                i2 = i4;
            }
            Arrays.sort(iArr);
            this.sortedDescriptors = hashMap;
            this.sortedStartPositions = iArr;
        }
    }

    public void afterDelete(int i2, int i3) {
        this.bookmarksTables.afterDelete(i2, i3);
        reset();
    }

    public void afterInsert(int i2, int i3) {
        this.bookmarksTables.afterInsert(i2, i3);
        reset();
    }

    public List<Bookmark> getBookmarksAt(int i2) {
        updateSortedDescriptors();
        List<GenericPropertyNode> list = this.sortedDescriptors.get(Integer.valueOf(i2));
        if (list == null || list.isEmpty()) {
            return Collections.emptyList();
        }
        ArrayList arrayList = new ArrayList(list.size());
        for (GenericPropertyNode genericPropertyNode : list) {
            arrayList.add(getBookmark(genericPropertyNode));
        }
        return Collections.unmodifiableList(arrayList);
    }

    @Override // org.apache.poi.hwpf.usermodel.Bookmarks
    public int getBookmarksCount() {
        return this.bookmarksTables.getDescriptorsFirstCount();
    }

    @Override // org.apache.poi.hwpf.usermodel.Bookmarks
    public Map<Integer, List<Bookmark>> getBookmarksStartedBetween(int i2, int i3) {
        updateSortedDescriptors();
        int binarySearch = Arrays.binarySearch(this.sortedStartPositions, i2);
        if (binarySearch < 0) {
            binarySearch = -(binarySearch + 1);
        }
        int binarySearch2 = Arrays.binarySearch(this.sortedStartPositions, i3);
        if (binarySearch2 < 0) {
            binarySearch2 = -(binarySearch2 + 1);
        }
        LinkedHashMap linkedHashMap = new LinkedHashMap();
        while (binarySearch < binarySearch2) {
            int i4 = this.sortedStartPositions[binarySearch];
            if (i4 >= i2) {
                if (i4 >= i3) {
                    break;
                }
                List<Bookmark> bookmarksAt = getBookmarksAt(i4);
                if (bookmarksAt != null) {
                    linkedHashMap.put(Integer.valueOf(i4), bookmarksAt);
                }
            }
            binarySearch++;
        }
        return Collections.unmodifiableMap(linkedHashMap);
    }

    @Override // org.apache.poi.hwpf.usermodel.Bookmarks
    public void remove(int i2) {
        this.bookmarksTables.remove(i2);
    }

    @Override // org.apache.poi.hwpf.usermodel.Bookmarks
    public Bookmark getBookmark(int i2) {
        return getBookmark(this.bookmarksTables.getDescriptorFirst(i2));
    }
}
