package org.apache.poi.hwpf.usermodel;

import b.b.a.a.a;
import org.apache.poi.hwpf.model.LFO;
import org.apache.poi.hwpf.model.LFOData;
import org.apache.poi.hwpf.model.ListData;
import org.apache.poi.hwpf.model.ListFormatOverrideLevel;
import org.apache.poi.hwpf.model.ListLevel;
import org.apache.poi.hwpf.model.ListTables;
import org.apache.poi.hwpf.model.StyleSheet;
import org.apache.poi.hwpf.sprm.CharacterSprmCompressor;
import org.apache.poi.hwpf.sprm.ParagraphSprmCompressor;
import org.apache.poi.util.Internal;

public final class HWPFList {
    public boolean _ignoreLogicalLeftIdentation = false;
    public LFO _lfo;
    public LFOData _lfoData;
    public ListData _listData;
    public ListTables _listTables;
    public StyleSheet _styleSheet;

    public HWPFList(boolean z, StyleSheet styleSheet) {
        this._listData = new ListData((int) (Math.random() * ((double) System.currentTimeMillis())), z);
        LFO lfo = new LFO();
        this._lfo = lfo;
        lfo.setLsid(this._listData.getLsid());
        this._lfoData = new LFOData();
        this._styleSheet = styleSheet;
    }

    @Internal
    public LFO getLFO() {
        return this._lfo;
    }

    @Internal
    public LFOData getLFOData() {
        return this._lfoData;
    }

    @Internal
    public ListLevel getLVL(char c) {
        if (c < this._listData.numLevels()) {
            return this._listData.getLevels()[c];
        }
        StringBuilder a = a.a("Required level ", c, " is more than number of level for list (");
        a.append(this._listData.numLevels());
        a.append(")");
        throw new IllegalArgumentException(a.toString());
    }

    @Internal
    public ListData getListData() {
        return this._listData;
    }

    public int getLsid() {
        return this._lfo.getLsid();
    }

    public int getNumberFormat(char c) {
        return getLVL(c).getNumberFormat();
    }

    public String getNumberText(char c) {
        return getLVL(c).getNumberText();
    }

    public int getStartAt(char c) {
        if (isStartAtOverriden(c)) {
            return this._lfoData.getRgLfoLvl()[c].getIStartAt();
        }
        return getLVL(c).getStartAt();
    }

    public byte getTypeOfCharFollowingTheNumber(char c) {
        return getLVL(c).getTypeOfCharFollowingTheNumber();
    }

    public boolean isIgnoreLogicalLeftIdentation() {
        return this._ignoreLogicalLeftIdentation;
    }

    public boolean isStartAtOverriden(char c) {
        ListFormatOverrideLevel listFormatOverrideLevel = this._lfoData.getRgLfoLvl().length > c ? this._lfoData.getRgLfoLvl()[c] : null;
        return (listFormatOverrideLevel == null || listFormatOverrideLevel.getIStartAt() == 0 || listFormatOverrideLevel.isFormatting()) ? false : true;
    }

    public void setIgnoreLogicalLeftIdentation(boolean z) {
        this._ignoreLogicalLeftIdentation = z;
    }

    public void setLevelNumberProperties(int i2, CharacterProperties characterProperties) {
        this._listData.getLevel(i2).setNumberProperties(CharacterSprmCompressor.compressCharacterProperty(characterProperties, this._styleSheet.getCharacterStyle(this._listData.getLevelStyle(i2))));
    }

    public void setLevelParagraphProperties(int i2, ParagraphProperties paragraphProperties) {
        this._listData.getLevel(i2).setLevelProperties(ParagraphSprmCompressor.compressParagraphProperty(paragraphProperties, this._styleSheet.getParagraphStyle(this._listData.getLevelStyle(i2))));
    }

    public void setLevelStyle(int i2, int i3) {
        this._listData.setLevelStyle(i2, i3);
    }

    public HWPFList(StyleSheet styleSheet, ListTables listTables, int i2) {
        this._listTables = listTables;
        this._styleSheet = styleSheet;
        if (i2 == 0 || i2 == 63489) {
            throw new IllegalArgumentException("Paragraph not in list");
        }
        if (1 <= i2 && i2 <= 2046) {
            this._lfo = listTables.getLfo(i2);
            this._lfoData = listTables.getLfoData(i2);
        } else if (63490 > i2 || i2 > 65535) {
            throw new IllegalArgumentException(a.c("Incorrect ilfo: ", i2));
        } else {
            int i3 = i2 ^ 65535;
            this._lfo = listTables.getLfo(i3);
            this._lfoData = listTables.getLfoData(i3);
            this._ignoreLogicalLeftIdentation = true;
        }
        this._listData = listTables.getListData(this._lfo.getLsid());
    }
}
