package org.apache.poi.hwpf.usermodel;

import b.b.a.a.a;
import java.util.ArrayList;
import java.util.Collection;
import java.util.Collections;
import java.util.List;
import org.apache.poi.ddf.DefaultEscherRecordFactory;
import org.apache.poi.ddf.EscherBSERecord;
import org.apache.poi.ddf.EscherBlipRecord;
import org.apache.poi.ddf.EscherContainerRecord;
import org.apache.poi.ddf.EscherOptRecord;
import org.apache.poi.ddf.EscherRecord;
import org.apache.poi.ddf.EscherRecordFactory;
import org.apache.poi.ddf.EscherSimpleProperty;
import org.apache.poi.ddf.EscherSpRecord;
import org.apache.poi.ddf.EscherTertiaryOptRecord;
import org.apache.poi.hwpf.model.EscherRecordHolder;
import org.apache.poi.hwpf.model.FSPA;
import org.apache.poi.hwpf.model.FSPATable;
import org.apache.poi.hwpf.usermodel.OfficeDrawing;

public class OfficeDrawingsImpl implements OfficeDrawings {
    public final EscherRecordHolder _escherRecordHolder;
    public final FSPATable _fspaTable;
    public final byte[] _mainStream;

    public OfficeDrawingsImpl(FSPATable fSPATable, EscherRecordHolder escherRecordHolder, byte[] bArr) {
        this._fspaTable = fSPATable;
        this._escherRecordHolder = escherRecordHolder;
        this._mainStream = bArr;
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private EscherBlipRecord getBitmapRecord(int i2) {
        List<? extends EscherContainerRecord> bStoreContainers = this._escherRecordHolder.getBStoreContainers();
        if (bStoreContainers != null && bStoreContainers.size() == 1) {
            List<EscherRecord> childRecords = ((EscherContainerRecord) bStoreContainers.get(0)).getChildRecords();
            if (childRecords.size() < i2) {
                return null;
            }
            EscherRecord escherRecord = childRecords.get(i2 - 1);
            if (escherRecord instanceof EscherBlipRecord) {
                return (EscherBlipRecord) escherRecord;
            }
            if (escherRecord instanceof EscherBSERecord) {
                EscherBSERecord escherBSERecord = (EscherBSERecord) escherRecord;
                EscherBlipRecord blipRecord = escherBSERecord.getBlipRecord();
                if (blipRecord != null) {
                    return blipRecord;
                }
                if (escherBSERecord.getOffset() > 0) {
                    EscherRecordFactory defaultEscherRecordFactory = new DefaultEscherRecordFactory();
                    EscherRecord createRecord = defaultEscherRecordFactory.createRecord(this._mainStream, escherBSERecord.getOffset());
                    if (createRecord instanceof EscherBlipRecord) {
                        createRecord.fillFields(this._mainStream, escherBSERecord.getOffset(), defaultEscherRecordFactory);
                        return (EscherBlipRecord) createRecord;
                    }
                }
            }
        }
        return null;
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private EscherContainerRecord getEscherShapeRecordContainer(int i2) {
        for (EscherContainerRecord escherContainerRecord : this._escherRecordHolder.getSpContainers()) {
            EscherSpRecord escherSpRecord = (EscherSpRecord) escherContainerRecord.getChildById(EscherSpRecord.RECORD_ID);
            if (escherSpRecord != null && escherSpRecord.getShapeId() == i2) {
                return escherContainerRecord;
            }
        }
        return null;
    }

    private OfficeDrawing getOfficeDrawing(final FSPA fspa) {
        return new OfficeDrawing() {
            /* class org.apache.poi.hwpf.usermodel.OfficeDrawingsImpl.AnonymousClass1 */

            private int getTertiaryPropertyValue(int i2, int i3) {
                EscherTertiaryOptRecord escherTertiaryOptRecord;
                EscherSimpleProperty escherSimpleProperty;
                EscherContainerRecord escherShapeRecordContainer = OfficeDrawingsImpl.this.getEscherShapeRecordContainer(getShapeId());
                if (escherShapeRecordContainer == null || (escherTertiaryOptRecord = (EscherTertiaryOptRecord) escherShapeRecordContainer.getChildById(EscherTertiaryOptRecord.RECORD_ID)) == null || (escherSimpleProperty = (EscherSimpleProperty) escherTertiaryOptRecord.lookup(i2)) == null) {
                    return i3;
                }
                return escherSimpleProperty.getPropertyValue();
            }

            @Override // org.apache.poi.hwpf.usermodel.OfficeDrawing
            public OfficeDrawing.HorizontalPositioning getHorizontalPositioning() {
                int tertiaryPropertyValue = getTertiaryPropertyValue(911, -1);
                if (tertiaryPropertyValue == 0) {
                    return OfficeDrawing.HorizontalPositioning.ABSOLUTE;
                }
                if (tertiaryPropertyValue == 1) {
                    return OfficeDrawing.HorizontalPositioning.LEFT;
                }
                if (tertiaryPropertyValue == 2) {
                    return OfficeDrawing.HorizontalPositioning.CENTER;
                }
                if (tertiaryPropertyValue == 3) {
                    return OfficeDrawing.HorizontalPositioning.RIGHT;
                }
                if (tertiaryPropertyValue == 4) {
                    return OfficeDrawing.HorizontalPositioning.INSIDE;
                }
                if (tertiaryPropertyValue != 5) {
                    return OfficeDrawing.HorizontalPositioning.ABSOLUTE;
                }
                return OfficeDrawing.HorizontalPositioning.OUTSIDE;
            }

            @Override // org.apache.poi.hwpf.usermodel.OfficeDrawing
            public OfficeDrawing.HorizontalRelativeElement getHorizontalRelative() {
                int tertiaryPropertyValue = getTertiaryPropertyValue(912, -1);
                if (tertiaryPropertyValue == 1) {
                    return OfficeDrawing.HorizontalRelativeElement.MARGIN;
                }
                if (tertiaryPropertyValue == 2) {
                    return OfficeDrawing.HorizontalRelativeElement.PAGE;
                }
                if (tertiaryPropertyValue == 3) {
                    return OfficeDrawing.HorizontalRelativeElement.TEXT;
                }
                if (tertiaryPropertyValue != 4) {
                    return OfficeDrawing.HorizontalRelativeElement.TEXT;
                }
                return OfficeDrawing.HorizontalRelativeElement.CHAR;
            }

            @Override // org.apache.poi.hwpf.usermodel.OfficeDrawing
            public EscherContainerRecord getOfficeArtSpContainer() {
                return OfficeDrawingsImpl.this.getEscherShapeRecordContainer(getShapeId());
            }

            @Override // org.apache.poi.hwpf.usermodel.OfficeDrawing
            public byte[] getPictureData() {
                EscherOptRecord escherOptRecord;
                EscherSimpleProperty escherSimpleProperty;
                EscherBlipRecord bitmapRecord;
                EscherContainerRecord escherShapeRecordContainer = OfficeDrawingsImpl.this.getEscherShapeRecordContainer(getShapeId());
                if (escherShapeRecordContainer == null || (escherOptRecord = (EscherOptRecord) escherShapeRecordContainer.getChildById(EscherOptRecord.RECORD_ID)) == null || (escherSimpleProperty = (EscherSimpleProperty) escherOptRecord.lookup(260)) == null || (bitmapRecord = OfficeDrawingsImpl.this.getBitmapRecord(escherSimpleProperty.getPropertyValue())) == null) {
                    return null;
                }
                return bitmapRecord.getPicturedata();
            }

            @Override // org.apache.poi.hwpf.usermodel.OfficeDrawing
            public int getRectangleBottom() {
                return fspa.getYaBottom();
            }

            @Override // org.apache.poi.hwpf.usermodel.OfficeDrawing
            public int getRectangleLeft() {
                return fspa.getXaLeft();
            }

            @Override // org.apache.poi.hwpf.usermodel.OfficeDrawing
            public int getRectangleRight() {
                return fspa.getXaRight();
            }

            @Override // org.apache.poi.hwpf.usermodel.OfficeDrawing
            public int getRectangleTop() {
                return fspa.getYaTop();
            }

            @Override // org.apache.poi.hwpf.usermodel.OfficeDrawing
            public int getShapeId() {
                return fspa.getSpid();
            }

            @Override // org.apache.poi.hwpf.usermodel.OfficeDrawing
            public OfficeDrawing.VerticalPositioning getVerticalPositioning() {
                int tertiaryPropertyValue = getTertiaryPropertyValue(913, -1);
                if (tertiaryPropertyValue == 0) {
                    return OfficeDrawing.VerticalPositioning.ABSOLUTE;
                }
                if (tertiaryPropertyValue == 1) {
                    return OfficeDrawing.VerticalPositioning.TOP;
                }
                if (tertiaryPropertyValue == 2) {
                    return OfficeDrawing.VerticalPositioning.CENTER;
                }
                if (tertiaryPropertyValue == 3) {
                    return OfficeDrawing.VerticalPositioning.BOTTOM;
                }
                if (tertiaryPropertyValue == 4) {
                    return OfficeDrawing.VerticalPositioning.INSIDE;
                }
                if (tertiaryPropertyValue != 5) {
                    return OfficeDrawing.VerticalPositioning.ABSOLUTE;
                }
                return OfficeDrawing.VerticalPositioning.OUTSIDE;
            }

            @Override // org.apache.poi.hwpf.usermodel.OfficeDrawing
            public OfficeDrawing.VerticalRelativeElement getVerticalRelativeElement() {
                int tertiaryPropertyValue = getTertiaryPropertyValue(913, -1);
                if (tertiaryPropertyValue == 1) {
                    return OfficeDrawing.VerticalRelativeElement.MARGIN;
                }
                if (tertiaryPropertyValue == 2) {
                    return OfficeDrawing.VerticalRelativeElement.PAGE;
                }
                if (tertiaryPropertyValue == 3) {
                    return OfficeDrawing.VerticalRelativeElement.TEXT;
                }
                if (tertiaryPropertyValue != 4) {
                    return OfficeDrawing.VerticalRelativeElement.TEXT;
                }
                return OfficeDrawing.VerticalRelativeElement.LINE;
            }

            public String toString() {
                StringBuilder b2 = a.b("OfficeDrawingImpl: ");
                b2.append(fspa);
                return b2.toString();
            }
        };
    }

    @Override // org.apache.poi.hwpf.usermodel.OfficeDrawings
    public OfficeDrawing getOfficeDrawingAt(int i2) {
        FSPA fspaFromCp = this._fspaTable.getFspaFromCp(i2);
        if (fspaFromCp == null) {
            return null;
        }
        return getOfficeDrawing(fspaFromCp);
    }

    @Override // org.apache.poi.hwpf.usermodel.OfficeDrawings
    public Collection<OfficeDrawing> getOfficeDrawings() {
        ArrayList arrayList = new ArrayList();
        for (FSPA fspa : this._fspaTable.getShapes()) {
            arrayList.add(getOfficeDrawing(fspa));
        }
        return Collections.unmodifiableList(arrayList);
    }
}
