package org.apache.poi.hwpf.usermodel;

import java.util.ArrayList;
import java.util.HashMap;
import java.util.HashSet;
import java.util.List;
import java.util.Map;
import java.util.Set;
import org.apache.poi.hwpf.HWPFDocument;
import org.apache.poi.hwpf.model.PicturesTable;

public class PictureRunMapper {
    public List<Picture> all;
    public Set<Picture> claimed = new HashSet();
    public Map<Integer, Picture> lookup;
    public List<Picture> nonU1based;
    public PicturesTable picturesTable;
    public int pn;

    public PictureRunMapper(HWPFDocument hWPFDocument) {
        this.pn = 0;
        PicturesTable picturesTable2 = hWPFDocument.getPicturesTable();
        this.picturesTable = picturesTable2;
        this.all = picturesTable2.getAllPictures();
        this.lookup = new HashMap();
        for (Picture picture : this.all) {
            this.lookup.put(Integer.valueOf(picture.getStartOffset()), picture);
        }
        ArrayList arrayList = new ArrayList();
        this.nonU1based = arrayList;
        arrayList.addAll(this.all);
        Range range = hWPFDocument.getRange();
        for (int i2 = 0; i2 < range.numCharacterRuns(); i2++) {
            CharacterRun characterRun = range.getCharacterRun(i2);
            if (this.picturesTable.hasPicture(characterRun)) {
                this.nonU1based.set(this.nonU1based.indexOf(getFor(characterRun)), null);
            }
        }
    }

    public Picture getFor(CharacterRun characterRun) {
        return this.lookup.get(Integer.valueOf(characterRun.getPicOffset()));
    }

    public boolean hasBeenClaimed(Picture picture) {
        return this.claimed.contains(picture);
    }

    public boolean hasPicture(CharacterRun characterRun) {
        return this.picturesTable.hasPicture(characterRun);
    }

    public void markAsClaimed(Picture picture) {
        this.claimed.add(picture);
    }

    public Picture nextUnclaimed() {
        while (this.pn < this.nonU1based.size()) {
            Picture picture = this.nonU1based.get(this.pn);
            this.pn++;
            if (picture != null) {
                this.claimed.add(picture);
                return picture;
            }
        }
        return null;
    }

    public int pictureNumber(Picture picture) {
        return this.all.indexOf(picture) + 1;
    }
}
