package org.apache.poi.hwpf.usermodel;

import b.b.a.a.a;
import java.lang.ref.WeakReference;
import java.util.List;
import org.apache.poi.hwpf.HWPFDocument;
import org.apache.poi.hwpf.HWPFDocumentCore;
import org.apache.poi.hwpf.model.CHPX;
import org.apache.poi.hwpf.model.FileInformationBlock;
import org.apache.poi.hwpf.model.PAPX;
import org.apache.poi.hwpf.model.PropertyNode;
import org.apache.poi.hwpf.model.SEPX;
import org.apache.poi.hwpf.model.StyleSheet;
import org.apache.poi.hwpf.model.SubdocumentType;
import org.apache.poi.hwpf.sprm.CharacterSprmCompressor;
import org.apache.poi.hwpf.sprm.ParagraphSprmCompressor;
import org.apache.poi.hwpf.sprm.SprmBuffer;
import org.apache.poi.util.DocumentFormatException;
import org.apache.poi.util.Internal;
import org.apache.poi.util.LittleEndian;
import org.apache.poi.util.POILogFactory;
import org.apache.poi.util.POILogger;

public class Range {
    public static final /* synthetic */ boolean $assertionsDisabled = false;
    @Deprecated
    public static final int TYPE_CHARACTER = 1;
    @Deprecated
    public static final int TYPE_LISTENTRY = 4;
    @Deprecated
    public static final int TYPE_PARAGRAPH = 0;
    @Deprecated
    public static final int TYPE_SECTION = 2;
    @Deprecated
    public static final int TYPE_TABLE = 5;
    @Deprecated
    public static final int TYPE_TEXT = 3;
    @Deprecated
    public static final int TYPE_UNDEFINED = 6;
    public int _charEnd;
    public boolean _charRangeFound;
    public int _charStart;
    public List<CHPX> _characters;
    public final HWPFDocumentCore _doc;
    public int _end;
    public int _parEnd;
    public boolean _parRangeFound;
    public int _parStart;
    public final List<PAPX> _paragraphs;
    public final WeakReference<Range> _parent;
    public int _sectionEnd;
    public boolean _sectionRangeFound;
    public int _sectionStart;
    public final List<SEPX> _sections;
    public final int _start;
    public StringBuilder _text;
    public POILogger logger = POILogFactory.getLogger(Range.class);

    public Range(int i2, int i3, HWPFDocumentCore hWPFDocumentCore) {
        this._start = i2;
        this._end = i3;
        this._doc = hWPFDocumentCore;
        this._sections = hWPFDocumentCore.getSectionTable().getSections();
        this._paragraphs = this._doc.getParagraphTable().getParagraphs();
        this._characters = this._doc.getCharacterTable().getTextRuns();
        this._text = this._doc.getText();
        this._parent = new WeakReference<>(null);
        sanityCheckStartEnd();
    }

    private void adjustForInsert(int i2) {
        this._end += i2;
        reset();
        Range range = this._parent.get();
        if (range != null) {
            range.adjustForInsert(i2);
        }
    }

    public static int binarySearchEnd(List<? extends PropertyNode<?>> list, int i2, int i3) {
        if (((PropertyNode) list.get(list.size() - 1)).getEnd() <= i3) {
            return list.size() - 1;
        }
        int size = list.size() - 1;
        while (i2 <= size) {
            int i4 = (i2 + size) >>> 1;
            PropertyNode propertyNode = (PropertyNode) list.get(i4);
            if (propertyNode.getEnd() < i3) {
                i2 = i4 + 1;
            } else if (propertyNode.getEnd() <= i3) {
                return i4;
            } else {
                size = i4 - 1;
            }
        }
        return i2;
    }

    public static int binarySearchStart(List<? extends PropertyNode<?>> list, int i2) {
        if (list.size() == 0) {
            return -1;
        }
        int i3 = 0;
        if (((PropertyNode) list.get(0)).getStart() >= i2) {
            return 0;
        }
        int size = list.size() - 1;
        while (i3 <= size) {
            int i4 = (i3 + size) >>> 1;
            PropertyNode propertyNode = (PropertyNode) list.get(i4);
            if (propertyNode.getStart() < i2) {
                i3 = i4 + 1;
            } else if (propertyNode.getStart() <= i2) {
                return i4;
            } else {
                size = i4 - 1;
            }
        }
        return i3 - 1;
    }

    private int[] findRange(List<? extends PropertyNode<?>> list, int i2, int i3) {
        int binarySearchStart = binarySearchStart(list, i2);
        while (binarySearchStart > 0 && ((PropertyNode) list.get(binarySearchStart - 1)).getStart() >= i2) {
            binarySearchStart--;
        }
        int binarySearchEnd = binarySearchEnd(list, binarySearchStart, i3);
        while (binarySearchEnd < list.size() - 1) {
            int i4 = binarySearchEnd + 1;
            if (((PropertyNode) list.get(i4)).getEnd() > i3) {
                break;
            }
            binarySearchEnd = i4;
        }
        if (binarySearchStart < 0 || binarySearchStart >= list.size() || binarySearchStart > binarySearchEnd || binarySearchEnd < 0 || binarySearchEnd >= list.size()) {
            throw new DocumentFormatException("problem finding range");
        }
        return new int[]{binarySearchStart, binarySearchEnd + 1};
    }

    private void initCharacterRuns() {
        if (!this._charRangeFound) {
            int[] findRange = findRange(this._characters, this._start, this._end);
            this._charStart = findRange[0];
            this._charEnd = findRange[1];
            this._charRangeFound = true;
        }
    }

    private void initParagraphs() {
        if (!this._parRangeFound) {
            int[] findRange = findRange(this._paragraphs, this._start, this._end);
            this._parStart = findRange[0];
            this._parEnd = findRange[1];
            this._parRangeFound = true;
        }
    }

    private void initSections() {
        if (!this._sectionRangeFound) {
            int[] findRange = findRange(this._sections, this._sectionStart, this._start, this._end);
            this._sectionStart = findRange[0];
            this._sectionEnd = findRange[1];
            this._sectionRangeFound = true;
        }
    }

    private void sanityCheckStartEnd() {
        int i2 = this._start;
        if (i2 < 0) {
            StringBuilder b2 = a.b("Range start must not be negative. Given ");
            b2.append(this._start);
            throw new IllegalArgumentException(b2.toString());
        } else if (this._end < i2) {
            StringBuilder b3 = a.b("The end (");
            b3.append(this._end);
            b3.append(") must not be before the start (");
            throw new IllegalArgumentException(a.a(b3, this._start, ")"));
        }
    }

    public static String stripFields(String str) {
        if (str.indexOf(19) == -1) {
            return str;
        }
        while (str.indexOf(19) > -1 && str.indexOf(21) > -1) {
            int indexOf = str.indexOf(19);
            int i2 = indexOf + 1;
            int indexOf2 = str.indexOf(19, i2);
            int indexOf3 = str.indexOf(20, i2);
            int lastIndexOf = str.lastIndexOf(21);
            if (lastIndexOf < indexOf) {
                return str;
            }
            if (indexOf2 == -1 && indexOf3 == -1) {
                return str.substring(0, indexOf) + str.substring(lastIndexOf + 1);
            } else if (indexOf3 == -1 || (indexOf3 >= indexOf2 && indexOf2 != -1)) {
                str = str.substring(0, indexOf) + str.substring(lastIndexOf + 1);
            } else {
                str = str.substring(0, indexOf) + str.substring(indexOf3 + 1, lastIndexOf) + str.substring(lastIndexOf + 1);
            }
        }
        return str;
    }

    public void adjustFIB(int i2) {
        HWPFDocumentCore hWPFDocumentCore = this._doc;
        if (hWPFDocumentCore instanceof HWPFDocument) {
            FileInformationBlock fileInformationBlock = hWPFDocumentCore.getFileInformationBlock();
            SubdocumentType[] subdocumentTypeArr = SubdocumentType.ORDERED;
            int i3 = 0;
            for (SubdocumentType subdocumentType : subdocumentTypeArr) {
                int subdocumentTextStreamLength = fileInformationBlock.getSubdocumentTextStreamLength(subdocumentType);
                i3 += subdocumentTextStreamLength;
                if (this._start <= i3) {
                    fileInformationBlock.setSubdocumentTextStreamLength(subdocumentType, subdocumentTextStreamLength + i2);
                    return;
                }
            }
            return;
        }
        throw new IllegalArgumentException("doc must be instance of HWPFDocument");
    }

    public void delete() {
        initAll();
        int size = this._sections.size();
        int size2 = this._characters.size();
        int size3 = this._paragraphs.size();
        for (int i2 = this._charStart; i2 < size2; i2++) {
            int i3 = this._start;
            this._characters.get(i2).adjustForDelete(i3, this._end - i3);
        }
        for (int i4 = this._parStart; i4 < size3; i4++) {
            int i5 = this._start;
            this._paragraphs.get(i4).adjustForDelete(i5, this._end - i5);
        }
        for (int i6 = this._sectionStart; i6 < size; i6++) {
            int i7 = this._start;
            this._sections.get(i6).adjustForDelete(i7, this._end - i7);
        }
        HWPFDocumentCore hWPFDocumentCore = this._doc;
        if (hWPFDocumentCore instanceof HWPFDocument) {
            int i8 = this._start;
            ((BookmarksImpl) ((HWPFDocument) hWPFDocumentCore).getBookmarks()).afterDelete(i8, this._end - i8);
        }
        this._text.delete(this._start, this._end);
        Range range = this._parent.get();
        if (range != null) {
            range.adjustForInsert(-(this._end - this._start));
        }
        adjustFIB(-(this._end - this._start));
    }

    public CharacterRun getCharacterRun(int i2) {
        short s;
        initCharacterRuns();
        int i3 = this._charStart;
        if (i2 + i3 < this._charEnd) {
            CHPX chpx = this._characters.get(i2 + i3);
            if (chpx == null) {
                return null;
            }
            if (this instanceof Paragraph) {
                s = ((Paragraph) this)._istd;
            } else {
                int[] findRange = findRange(this._paragraphs, Math.max(chpx.getStart(), this._start), Math.min(chpx.getEnd(), this._end));
                initParagraphs();
                if (Math.max(findRange[0], this._parStart) >= this._paragraphs.size()) {
                    return null;
                }
                s = this._paragraphs.get(findRange[0]).getIstd();
            }
            return new CharacterRun(chpx, this._doc.getStyleSheet(), s, this);
        }
        StringBuilder a = a.a("CHPX #", i2, " (");
        a.append(i2 + this._charStart);
        a.append(") not in range [");
        a.append(this._charStart);
        a.append("; ");
        throw new IndexOutOfBoundsException(a.a(a, this._charEnd, ")"));
    }

    public HWPFDocumentCore getDocument() {
        return this._doc;
    }

    public int getEndOffset() {
        return this._end;
    }

    public Paragraph getParagraph(int i2) {
        initParagraphs();
        int i3 = this._parStart;
        if (i2 + i3 < this._parEnd) {
            return Paragraph.newParagraph(this, this._paragraphs.get(i2 + i3));
        }
        StringBuilder a = a.a("Paragraph #", i2, " (");
        a.append(i2 + this._parStart);
        a.append(") not in range [");
        a.append(this._parStart);
        a.append("; ");
        throw new IndexOutOfBoundsException(a.a(a, this._parEnd, ")"));
    }

    public Section getSection(int i2) {
        initSections();
        return new Section(this._sections.get(i2 + this._sectionStart), this);
    }

    public int getStartOffset() {
        return this._start;
    }

    public Table getTable(Paragraph paragraph) {
        if (!paragraph.isInTable()) {
            throw new IllegalArgumentException("This paragraph doesn't belong to a table");
        } else if (paragraph._parent.get() == this) {
            paragraph.initAll();
            int tableLevel = paragraph.getTableLevel();
            int i2 = paragraph._parStart;
            if (i2 != 0) {
                Paragraph newParagraph = Paragraph.newParagraph(this, this._paragraphs.get(i2 - 1));
                if (newParagraph.isInTable() && newParagraph.getTableLevel() == tableLevel && newParagraph._sectionEnd >= paragraph._sectionStart) {
                    throw new IllegalArgumentException("This paragraph is not the first one in the table");
                }
            }
            Range overallRange = this._doc.getOverallRange();
            int size = this._paragraphs.size();
            while (i2 < size - 1) {
                int i3 = i2 + 1;
                Paragraph newParagraph2 = Paragraph.newParagraph(overallRange, this._paragraphs.get(i3));
                if (!newParagraph2.isInTable() || newParagraph2.getTableLevel() < tableLevel) {
                    break;
                }
                i2 = i3;
            }
            initAll();
            if (i2 >= this._parEnd) {
                POILogger pOILogger = this.logger;
                StringBuilder b2 = a.b("[");
                b2.append(this._parStart);
                b2.append("; ");
                b2.append(i2);
                b2.append(")");
                StringBuilder b3 = a.b("[");
                b3.append(this._parStart);
                b3.append("; ");
                pOILogger.log(5, "The table's bounds ", b2.toString(), " fall outside of this Range paragraphs numbers ", a.a(b3, this._parEnd, ")"));
            }
            if (i2 >= 0) {
                return new Table(paragraph.getStartOffset(), this._paragraphs.get(i2).getEnd(), this, paragraph.getTableLevel());
            }
            throw new ArrayIndexOutOfBoundsException("The table's end is negative, which isn't allowed!");
        } else {
            throw new IllegalArgumentException("This paragraph is not a child of this range instance");
        }
    }

    public void initAll() {
        initCharacterRuns();
        initParagraphs();
        initSections();
    }

    public CharacterRun insertAfter(String str) {
        initAll();
        this._text.insert(this._end, str);
        this._doc.getCharacterTable().adjustForInsert(this._charEnd - 1, str.length());
        this._doc.getParagraphTable().adjustForInsert(this._parEnd - 1, str.length());
        this._doc.getSectionTable().adjustForInsert(this._sectionEnd - 1, str.length());
        HWPFDocumentCore hWPFDocumentCore = this._doc;
        if (hWPFDocumentCore instanceof HWPFDocument) {
            ((BookmarksImpl) ((HWPFDocument) hWPFDocumentCore).getBookmarks()).afterInsert(this._end, str.length());
        }
        adjustForInsert(str.length());
        sanityCheck();
        return getCharacterRun(numCharacterRuns() - 1);
    }

    public CharacterRun insertBefore(String str) {
        initAll();
        this._text.insert(this._start, str);
        this._doc.getCharacterTable().adjustForInsert(this._charStart, str.length());
        this._doc.getParagraphTable().adjustForInsert(this._parStart, str.length());
        this._doc.getSectionTable().adjustForInsert(this._sectionStart, str.length());
        HWPFDocumentCore hWPFDocumentCore = this._doc;
        if (hWPFDocumentCore instanceof HWPFDocument) {
            ((BookmarksImpl) ((HWPFDocument) hWPFDocumentCore).getBookmarks()).afterInsert(this._start, str.length());
        }
        adjustForInsert(str.length());
        adjustFIB(str.length());
        sanityCheck();
        return getCharacterRun(0);
    }

    public Table insertTableBefore(short s, int i2) {
        ParagraphProperties paragraphProperties = new ParagraphProperties();
        paragraphProperties.setFInTable(true);
        paragraphProperties.setItap(1);
        int i3 = this._end;
        for (int i4 = 0; i4 < i2; i4++) {
            Paragraph insertBefore = insertBefore(paragraphProperties, 4095);
            insertBefore.insertAfter(String.valueOf((char) 7));
            for (int i5 = 1; i5 < s; i5++) {
                insertBefore = insertBefore.insertAfter(paragraphProperties, 4095);
                insertBefore.insertAfter(String.valueOf((char) 7));
            }
            insertBefore.insertAfter(paragraphProperties, 4095, String.valueOf((char) 7)).setTableRowEnd(new TableProperties(s));
        }
        int i6 = this._start;
        return new Table(i6, (this._end - i3) + i6, this, 1);
    }

    public int numCharacterRuns() {
        initCharacterRuns();
        return this._charEnd - this._charStart;
    }

    public int numParagraphs() {
        initParagraphs();
        return this._parEnd - this._parStart;
    }

    public int numSections() {
        initSections();
        return this._sectionEnd - this._sectionStart;
    }

    public void replaceText(String str, boolean z) {
        if (z) {
            int endOffset = getEndOffset();
            insertAfter(str);
            new Range(getStartOffset(), endOffset, this).delete();
            return;
        }
        int startOffset = getStartOffset();
        int endOffset2 = getEndOffset();
        insertBefore(str);
        new Range(str.length() + startOffset, str.length() + endOffset2, this).delete();
    }

    public void reset() {
        this._charRangeFound = false;
        this._parRangeFound = false;
        this._sectionRangeFound = false;
    }

    public boolean sanityCheck() {
        DocumentFormatException.check(this._start >= 0, "start can't be < 0");
        DocumentFormatException.check(this._start <= this._text.length(), "start can't be > text length");
        DocumentFormatException.check(this._end >= 0, "end can't be < 0");
        DocumentFormatException.check(this._end <= this._text.length(), "end can't be > text length");
        DocumentFormatException.check(this._start <= this._end, "start can't be > end");
        if (this._charRangeFound) {
            for (int i2 = this._charStart; i2 < this._charEnd; i2++) {
                CHPX chpx = this._characters.get(i2);
                DocumentFormatException.check(Math.max(this._start, chpx.getStart()) < Math.min(this._end, chpx.getEnd()), "left must be < right");
            }
        }
        if (this._parRangeFound) {
            for (int i3 = this._parStart; i3 < this._parEnd; i3++) {
                PAPX papx = this._paragraphs.get(i3);
                DocumentFormatException.check(Math.max(this._start, papx.getStart()) < Math.min(this._end, papx.getEnd()), "left must be < right");
            }
        }
        return true;
    }

    public String text() {
        return this._text.substring(this._start, this._end);
    }

    public String toString() {
        StringBuilder b2 = a.b("Range from ");
        b2.append(getStartOffset());
        b2.append(" to ");
        b2.append(getEndOffset());
        b2.append(" (chars)");
        return b2.toString();
    }

    private int[] findRange(List<? extends PropertyNode<?>> list, int i2, int i3, int i4) {
        if (list.size() == i2) {
            return new int[]{i2, i2};
        }
        PropertyNode propertyNode = (PropertyNode) list.get(i2);
        while (true) {
            if (propertyNode == null || (propertyNode.getEnd() <= i3 && i2 < list.size() - 1)) {
                i2++;
                if (i2 >= list.size()) {
                    return new int[]{0, 0};
                }
                propertyNode = (PropertyNode) list.get(i2);
            }
        }
        if (propertyNode.getStart() > i4) {
            return new int[]{0, 0};
        }
        if (propertyNode.getEnd() <= i3) {
            return new int[]{list.size(), list.size()};
        }
        for (int i5 = i2; i5 < list.size(); i5++) {
            PropertyNode propertyNode2 = (PropertyNode) list.get(i5);
            if (propertyNode2 != null && (propertyNode2.getStart() >= i4 || propertyNode2.getEnd() > i4)) {
                if (propertyNode2.getStart() < i4) {
                    return new int[]{i2, i5 + 1};
                } else {
                    return new int[]{i2, i5};
                }
            }
        }
        return new int[]{i2, list.size()};
    }

    @Internal
    public void replaceText(String str, String str2, int i2) {
        int startOffset = getStartOffset() + i2;
        new Range(startOffset, str.length() + startOffset, this).insertBefore(str2);
        new Range(str2.length() + startOffset, str2.length() + str.length() + startOffset, this).delete();
    }

    @Deprecated
    private CharacterRun insertAfter(String str, CharacterProperties characterProperties) {
        initAll();
        this._doc.getCharacterTable().insert(this._charEnd, this._end, new SprmBuffer(CharacterSprmCompressor.compressCharacterProperty(characterProperties, this._doc.getStyleSheet().getCharacterStyle(this._paragraphs.get(this._parEnd - 1).getIstd())), 0));
        this._charEnd++;
        return insertAfter(str);
    }

    public Range(int i2, int i3, Range range) {
        this._start = i2;
        this._end = i3;
        this._doc = range._doc;
        this._sections = range._sections;
        this._paragraphs = range._paragraphs;
        this._characters = range._characters;
        this._text = range._text;
        this._parent = new WeakReference<>(range);
        sanityCheckStartEnd();
        sanityCheck();
    }

    @Deprecated
    private CharacterRun insertBefore(String str, CharacterProperties characterProperties) {
        initAll();
        this._doc.getCharacterTable().insert(this._charStart, this._start, new SprmBuffer(CharacterSprmCompressor.compressCharacterProperty(characterProperties, this._doc.getStyleSheet().getCharacterStyle(this._paragraphs.get(this._parStart).getIstd())), 0));
        return insertBefore(str);
    }

    public void replaceText(String str, String str2) {
        while (true) {
            int indexOf = text().indexOf(str);
            if (indexOf >= 0) {
                replaceText(str, str2, indexOf);
            } else {
                return;
            }
        }
    }

    @Deprecated
    private Paragraph insertBefore(ParagraphProperties paragraphProperties, int i2) {
        return insertBefore(paragraphProperties, i2, "\r");
    }

    @Deprecated
    public Paragraph insertAfter(ParagraphProperties paragraphProperties, int i2) {
        return insertAfter(paragraphProperties, i2, "\r");
    }

    @Deprecated
    private Paragraph insertBefore(ParagraphProperties paragraphProperties, int i2, String str) {
        initAll();
        StyleSheet styleSheet = this._doc.getStyleSheet();
        ParagraphProperties paragraphStyle = styleSheet.getParagraphStyle(i2);
        CharacterProperties characterStyle = styleSheet.getCharacterStyle(i2);
        byte[] compressParagraphProperty = ParagraphSprmCompressor.compressParagraphProperty(paragraphProperties, paragraphStyle);
        byte[] bArr = new byte[(compressParagraphProperty.length + 2)];
        LittleEndian.putShort(bArr, 0, (short) i2);
        System.arraycopy(compressParagraphProperty, 0, bArr, 2, compressParagraphProperty.length);
        this._doc.getParagraphTable().insert(this._parStart, this._start, new SprmBuffer(bArr, 2));
        insertBefore(str, characterStyle);
        return getParagraph(0);
    }

    @Deprecated
    public Paragraph insertAfter(ParagraphProperties paragraphProperties, int i2, String str) {
        initAll();
        StyleSheet styleSheet = this._doc.getStyleSheet();
        ParagraphProperties paragraphStyle = styleSheet.getParagraphStyle(i2);
        CharacterProperties characterStyle = styleSheet.getCharacterStyle(i2);
        byte[] compressParagraphProperty = ParagraphSprmCompressor.compressParagraphProperty(paragraphProperties, paragraphStyle);
        byte[] bArr = new byte[(compressParagraphProperty.length + 2)];
        LittleEndian.putShort(bArr, 0, (short) i2);
        System.arraycopy(compressParagraphProperty, 0, bArr, 2, compressParagraphProperty.length);
        this._doc.getParagraphTable().insert(this._parEnd, this._end, new SprmBuffer(bArr, 2));
        this._parEnd++;
        insertAfter(str, characterStyle);
        return getParagraph(numParagraphs() - 1);
    }
}
