package org.apache.poi.openxml4j.opc;

import b.b.a.a.a;
import java.io.IOException;
import java.io.InputStream;
import java.io.OutputStream;
import java.net.URI;
import java.net.URISyntaxException;
import org.apache.poi.openxml4j.exceptions.InvalidFormatException;
import org.apache.poi.openxml4j.exceptions.InvalidOperationException;
import org.apache.poi.openxml4j.opc.internal.ContentType;

public abstract class PackagePart implements RelationshipSource, Comparable<PackagePart> {
    public OPCPackage _container;
    public ContentType _contentType;
    public boolean _isDeleted;
    public boolean _isRelationshipPart;
    public PackagePartName _partName;
    public PackageRelationshipCollection _relationships;

    public PackagePart(OPCPackage oPCPackage, PackagePartName packagePartName, ContentType contentType) {
        this(oPCPackage, packagePartName, contentType, true);
    }

    private PackageRelationshipCollection getRelationshipsCore(String str) {
        this._container.throwExceptionIfWriteOnly();
        if (this._relationships == null) {
            throwExceptionIfRelationship();
            this._relationships = new PackageRelationshipCollection(this);
        }
        return new PackageRelationshipCollection(this._relationships, str);
    }

    private void loadRelationships() {
        if (this._relationships == null && !this._isRelationshipPart) {
            throwExceptionIfRelationship();
            this._relationships = new PackageRelationshipCollection(this);
        }
    }

    private void throwExceptionIfRelationship() {
        if (this._isRelationshipPart) {
            throw new InvalidOperationException("Can do this operation on a relationship part !");
        }
    }

    @Override // org.apache.poi.openxml4j.opc.RelationshipSource
    public PackageRelationship addExternalRelationship(String str, String str2) {
        return addExternalRelationship(str, str2, null);
    }

    @Override // org.apache.poi.openxml4j.opc.RelationshipSource
    public PackageRelationship addRelationship(PackagePartName packagePartName, TargetMode targetMode, String str) {
        return addRelationship(packagePartName, targetMode, str, (String) null);
    }

    public void clear() {
    }

    @Override // org.apache.poi.openxml4j.opc.RelationshipSource
    public void clearRelationships() {
        PackageRelationshipCollection packageRelationshipCollection = this._relationships;
        if (packageRelationshipCollection != null) {
            packageRelationshipCollection.clear();
        }
    }

    public abstract void close();

    public PackageRelationship findExistingRelation(PackagePart packagePart) {
        return this._relationships.findExistingInternalRelation(packagePart);
    }

    public abstract void flush();

    public String getContentType() {
        return this._contentType.toString();
    }

    public ContentType getContentTypeDetails() {
        return this._contentType;
    }

    public InputStream getInputStream() {
        InputStream inputStreamImpl = getInputStreamImpl();
        if (inputStreamImpl != null) {
            return inputStreamImpl;
        }
        StringBuilder b2 = a.b("Can't obtain the input stream from ");
        b2.append(this._partName.getName());
        throw new IOException(b2.toString());
    }

    public abstract InputStream getInputStreamImpl();

    public OutputStream getOutputStream() {
        if (!(this instanceof ZipPackagePart)) {
            return getOutputStreamImpl();
        }
        this._container.removePart(this._partName);
        PackagePart createPart = this._container.createPart(this._partName, this._contentType.toString(), false);
        if (createPart != null) {
            createPart._relationships = this._relationships;
            return createPart.getOutputStreamImpl();
        }
        throw new InvalidOperationException("Can't create a temporary part !");
    }

    public abstract OutputStream getOutputStreamImpl();

    public OPCPackage getPackage() {
        return this._container;
    }

    public PackagePartName getPartName() {
        return this._partName;
    }

    public PackagePart getRelatedPart(PackageRelationship packageRelationship) {
        if (isRelationshipExists(packageRelationship)) {
            URI targetURI = packageRelationship.getTargetURI();
            if (targetURI.getFragment() != null) {
                String uri = targetURI.toString();
                try {
                    targetURI = new URI(uri.substring(0, uri.indexOf(35)));
                } catch (URISyntaxException unused) {
                    throw new InvalidFormatException("Invalid target URI: " + targetURI);
                }
            }
            PackagePart part = this._container.getPart(PackagingURIHelper.createPartName(targetURI));
            if (part != null) {
                return part;
            }
            throw new IllegalArgumentException("No part found for relationship " + packageRelationship);
        }
        throw new IllegalArgumentException("Relationship " + packageRelationship + " doesn't start with this part " + this._partName);
    }

    @Override // org.apache.poi.openxml4j.opc.RelationshipSource
    public PackageRelationship getRelationship(String str) {
        return this._relationships.getRelationshipByID(str);
    }

    @Override // org.apache.poi.openxml4j.opc.RelationshipSource
    public PackageRelationshipCollection getRelationships() {
        return getRelationshipsCore(null);
    }

    @Override // org.apache.poi.openxml4j.opc.RelationshipSource
    public PackageRelationshipCollection getRelationshipsByType(String str) {
        this._container.throwExceptionIfWriteOnly();
        return getRelationshipsCore(str);
    }

    public long getSize() {
        return -1;
    }

    @Override // org.apache.poi.openxml4j.opc.RelationshipSource
    public boolean hasRelationships() {
        PackageRelationshipCollection packageRelationshipCollection;
        return !this._isRelationshipPart && (packageRelationshipCollection = this._relationships) != null && packageRelationshipCollection.size() > 0;
    }

    public boolean isDeleted() {
        return this._isDeleted;
    }

    @Override // org.apache.poi.openxml4j.opc.RelationshipSource
    public boolean isRelationshipExists(PackageRelationship packageRelationship) {
        return this._relationships.getRelationshipByID(packageRelationship.getId()) != null;
    }

    public boolean isRelationshipPart() {
        return this._isRelationshipPart;
    }

    public abstract boolean load(InputStream inputStream);

    @Override // org.apache.poi.openxml4j.opc.RelationshipSource
    public void removeRelationship(String str) {
        this._container.throwExceptionIfReadOnly();
        PackageRelationshipCollection packageRelationshipCollection = this._relationships;
        if (packageRelationshipCollection != null) {
            packageRelationshipCollection.removeRelationship(str);
        }
    }

    public abstract boolean save(OutputStream outputStream);

    public void setContentType(String str) {
        OPCPackage oPCPackage = this._container;
        if (oPCPackage == null) {
            this._contentType = new ContentType(str);
            return;
        }
        oPCPackage.unregisterPartAndContentType(this._partName);
        this._contentType = new ContentType(str);
        this._container.registerPartAndContentType(this);
    }

    public void setDeleted(boolean z) {
        this._isDeleted = z;
    }

    public String toString() {
        StringBuilder b2 = a.b("Name: ");
        b2.append(this._partName);
        b2.append(" - Content Type: ");
        b2.append(this._contentType);
        return b2.toString();
    }

    public PackagePart(OPCPackage oPCPackage, PackagePartName packagePartName, ContentType contentType, boolean z) {
        this._partName = packagePartName;
        this._contentType = contentType;
        this._container = oPCPackage;
        this._isRelationshipPart = packagePartName.isRelationshipPartURI();
        if (z) {
            loadRelationships();
        }
    }

    @Override // org.apache.poi.openxml4j.opc.RelationshipSource
    public PackageRelationship addExternalRelationship(String str, String str2, String str3) {
        if (str == null) {
            throw new IllegalArgumentException(a.b("target is null for type ", str2));
        } else if (str2 != null) {
            if (this._relationships == null) {
                this._relationships = new PackageRelationshipCollection();
            }
            try {
                return this._relationships.addRelationship(new URI(str), TargetMode.EXTERNAL, str2, str3);
            } catch (URISyntaxException e2) {
                throw new IllegalArgumentException("Invalid target - " + e2);
            }
        } else {
            throw new IllegalArgumentException("relationshipType");
        }
    }

    @Override // org.apache.poi.openxml4j.opc.RelationshipSource
    public PackageRelationship addRelationship(PackagePartName packagePartName, TargetMode targetMode, String str, String str2) {
        this._container.throwExceptionIfReadOnly();
        if (packagePartName == null) {
            throw new IllegalArgumentException("targetPartName");
        } else if (targetMode == null) {
            throw new IllegalArgumentException("targetMode");
        } else if (str == null) {
            throw new IllegalArgumentException("relationshipType");
        } else if (this._isRelationshipPart || packagePartName.isRelationshipPartURI()) {
            throw new InvalidOperationException("Rule M1.25: The Relationships part shall not have relationships to any other part.");
        } else {
            if (this._relationships == null) {
                this._relationships = new PackageRelationshipCollection();
            }
            return this._relationships.addRelationship(packagePartName.getURI(), targetMode, str, str2);
        }
    }

    public int compareTo(PackagePart packagePart) {
        if (packagePart == null) {
            return -1;
        }
        return PackagePartName.compare(this._partName, packagePart._partName);
    }

    public PackagePart(OPCPackage oPCPackage, PackagePartName packagePartName, String str) {
        this(oPCPackage, packagePartName, new ContentType(str));
    }

    public PackageRelationship addRelationship(URI uri, TargetMode targetMode, String str) {
        return addRelationship(uri, targetMode, str, (String) null);
    }

    public PackageRelationship addRelationship(URI uri, TargetMode targetMode, String str, String str2) {
        this._container.throwExceptionIfReadOnly();
        if (uri == null) {
            throw new IllegalArgumentException("targetPartName");
        } else if (targetMode == null) {
            throw new IllegalArgumentException("targetMode");
        } else if (str == null) {
            throw new IllegalArgumentException("relationshipType");
        } else if (this._isRelationshipPart || PackagingURIHelper.isRelationshipPartURI(uri)) {
            throw new InvalidOperationException("Rule M1.25: The Relationships part shall not have relationships to any other part.");
        } else {
            if (this._relationships == null) {
                this._relationships = new PackageRelationshipCollection();
            }
            return this._relationships.addRelationship(uri, targetMode, str, str2);
        }
    }
}
