package org.apache.poi.openxml4j.opc;

import b.b.a.a.a;
import java.math.BigInteger;
import java.net.URI;
import java.net.URISyntaxException;
import java.util.Locale;
import org.apache.poi.openxml4j.exceptions.InvalidFormatException;
import org.apache.poi.openxml4j.exceptions.OpenXML4JRuntimeException;
import org.apache.poi.openxml4j.opc.internal.ZipHelper;
import org.apache.poi.ss.formula.ptg.ConcatPtg;
import org.apache.poi.ss.formula.ptg.UnaryMinusPtg;
import org.apache.poi.xssf.usermodel.XSSFDataValidationConstraint;

public final class PackagePartName implements Comparable<PackagePartName> {
    public static String[] RFC3986_PCHAR_AUTHORIZED_SUP = {":", "@"};
    public static String[] RFC3986_PCHAR_SUB_DELIMS = {"!", "$", ConcatPtg.CONCAT, "'", "(", ")", "*", "+", XSSFDataValidationConstraint.LIST_SEPARATOR, ";", "="};
    public static String[] RFC3986_PCHAR_UNRESERVED_SUP = {UnaryMinusPtg.MINUS, ".", "_", "~"};
    public boolean isRelationship;
    public URI partNameURI;

    public PackagePartName(URI uri, boolean z) {
        if (z) {
            throwExceptionIfInvalidPartUri(uri);
        } else if (!PackagingURIHelper.PACKAGE_ROOT_URI.equals(uri)) {
            throw new OpenXML4JRuntimeException("OCP conformance must be check for ALL part name except special cases : ['/']");
        }
        this.partNameURI = uri;
        this.isRelationship = isRelationshipPartURI(uri);
    }

    public static void checkPCharCompliance(String str) {
        boolean z;
        int length = str.length();
        int i2 = 0;
        while (i2 < length) {
            char charAt = str.charAt(i2);
            if ((charAt < 'A' || charAt > 'Z') && ((charAt < 'a' || charAt > 'z') && (charAt < '0' || charAt > '9'))) {
                int i3 = 0;
                while (true) {
                    String[] strArr = RFC3986_PCHAR_UNRESERVED_SUP;
                    if (i3 >= strArr.length) {
                        z = true;
                        break;
                    } else if (charAt == strArr[i3].charAt(0)) {
                        z = false;
                        break;
                    } else {
                        i3++;
                    }
                }
                int i4 = 0;
                while (z) {
                    String[] strArr2 = RFC3986_PCHAR_AUTHORIZED_SUP;
                    if (i4 >= strArr2.length) {
                        break;
                    }
                    if (charAt == strArr2[i4].charAt(0)) {
                        z = false;
                    }
                    i4++;
                }
                int i5 = 0;
                while (z) {
                    String[] strArr3 = RFC3986_PCHAR_SUB_DELIMS;
                    if (i5 >= strArr3.length) {
                        break;
                    }
                    if (charAt == strArr3[i5].charAt(0)) {
                        z = false;
                    }
                    i5++;
                }
            } else {
                z = false;
            }
            if (z && charAt == '%') {
                if (length - i2 >= 2) {
                    char parseInt = (char) Integer.parseInt(str.substring(i2 + 1, i2 + 3), 16);
                    i2 += 2;
                    if (parseInt == '/' || parseInt == '\\') {
                        throw new InvalidFormatException("A segment shall not contain percent-encoded forward slash ('/'), or backward slash ('') characters. [M1.7]");
                    }
                    boolean z2 = (parseInt >= 'A' && parseInt <= 'Z') || (parseInt >= 'a' && parseInt <= 'z') || (parseInt >= '0' && parseInt <= '9');
                    int i6 = 0;
                    while (true) {
                        if (z2) {
                            break;
                        }
                        String[] strArr4 = RFC3986_PCHAR_UNRESERVED_SUP;
                        if (i6 >= strArr4.length) {
                            break;
                        } else if (charAt == strArr4[i6].charAt(0)) {
                            z = true;
                            break;
                        } else {
                            i6++;
                        }
                    }
                    z = z2;
                    if (z) {
                        throw new InvalidFormatException("A segment shall not contain percent-encoded unreserved characters. [M1.8]");
                    }
                } else {
                    throw new InvalidFormatException(a.b("The segment ", str, " contain invalid encoded character !"));
                }
            }
            if (!z) {
                i2++;
            } else {
                throw new InvalidFormatException("A segment shall not hold any characters other than pchar characters. [M1.6]");
            }
        }
    }

    public static int compare(PackagePartName packagePartName, PackagePartName packagePartName2) {
        if (packagePartName == null) {
            return packagePartName2 == null ? 0 : -1;
        }
        if (packagePartName2 == null) {
            return 1;
        }
        return compare(packagePartName.getURI().toASCIIString().toLowerCase(Locale.ROOT), packagePartName2.getURI().toASCIIString().toLowerCase(Locale.ROOT));
    }

    private boolean isRelationshipPartURI(URI uri) {
        if (uri != null) {
            String path = uri.getPath();
            StringBuilder b2 = a.b("^.*/");
            b2.append(PackagingURIHelper.RELATIONSHIP_PART_SEGMENT_NAME);
            b2.append("/.*\\");
            b2.append(PackagingURIHelper.RELATIONSHIP_PART_EXTENSION_NAME);
            b2.append("$");
            return path.matches(b2.toString());
        }
        throw new IllegalArgumentException("partUri");
    }

    public static void throwExceptionIfAbsoluteUri(URI uri) {
        if (uri.isAbsolute()) {
            throw new InvalidFormatException("Absolute URI forbidden: " + uri);
        }
    }

    public static void throwExceptionIfEmptyURI(URI uri) {
        if (uri != null) {
            String path = uri.getPath();
            if (path.length() == 0 || (path.length() == 1 && path.charAt(0) == PackagingURIHelper.FORWARD_SLASH_CHAR)) {
                StringBuilder b2 = a.b("A part name shall not be empty [M1.1]: ");
                b2.append(uri.getPath());
                throw new InvalidFormatException(b2.toString());
            }
            return;
        }
        throw new IllegalArgumentException("partURI");
    }

    public static void throwExceptionIfInvalidPartUri(URI uri) {
        if (uri != null) {
            throwExceptionIfEmptyURI(uri);
            throwExceptionIfAbsoluteUri(uri);
            throwExceptionIfPartNameNotStartsWithForwardSlashChar(uri);
            throwExceptionIfPartNameEndsWithForwardSlashChar(uri);
            throwExceptionIfPartNameHaveInvalidSegments(uri);
            return;
        }
        throw new IllegalArgumentException("partUri");
    }

    public static void throwExceptionIfPartNameEndsWithForwardSlashChar(URI uri) {
        String path = uri.getPath();
        if (path.length() > 0 && path.charAt(path.length() - 1) == PackagingURIHelper.FORWARD_SLASH_CHAR) {
            StringBuilder b2 = a.b("A part name shall not have a forward slash as the last character [M1.5]: ");
            b2.append(uri.getPath());
            throw new InvalidFormatException(b2.toString());
        }
    }

    public static void throwExceptionIfPartNameHaveInvalidSegments(URI uri) {
        if (uri != null) {
            String[] split = uri.toASCIIString().split(ZipHelper.FORWARD_SLASH);
            if (split.length <= 1 || !split[0].equals("")) {
                StringBuilder b2 = a.b("A part name shall not have empty segments [M1.3]: ");
                b2.append(uri.getPath());
                throw new InvalidFormatException(b2.toString());
            }
            for (int i2 = 1; i2 < split.length; i2++) {
                String str = split[i2];
                if (str == null || "".equals(str)) {
                    StringBuilder b3 = a.b("A part name shall not have empty segments [M1.3]: ");
                    b3.append(uri.getPath());
                    throw new InvalidFormatException(b3.toString());
                } else if (str.endsWith(".")) {
                    StringBuilder b4 = a.b("A segment shall not end with a dot ('.') character [M1.9]: ");
                    b4.append(uri.getPath());
                    throw new InvalidFormatException(b4.toString());
                } else if (!"".equals(str.replaceAll("\\\\.", ""))) {
                    checkPCharCompliance(str);
                } else {
                    StringBuilder b5 = a.b("A segment shall include at least one non-dot character. [M1.10]: ");
                    b5.append(uri.getPath());
                    throw new InvalidFormatException(b5.toString());
                }
            }
            return;
        }
        throw new IllegalArgumentException("partUri");
    }

    public static void throwExceptionIfPartNameNotStartsWithForwardSlashChar(URI uri) {
        String path = uri.getPath();
        if (path.length() > 0 && path.charAt(0) != PackagingURIHelper.FORWARD_SLASH_CHAR) {
            StringBuilder b2 = a.b("A part name shall start with a forward slash ('/') character [M1.4]: ");
            b2.append(uri.getPath());
            throw new InvalidFormatException(b2.toString());
        }
    }

    public boolean equals(Object obj) {
        if (obj instanceof PackagePartName) {
            return this.partNameURI.toASCIIString().toLowerCase(Locale.ROOT).equals(((PackagePartName) obj).partNameURI.toASCIIString().toLowerCase(Locale.ROOT));
        }
        return false;
    }

    public String getExtension() {
        int lastIndexOf;
        String path = this.partNameURI.getPath();
        return (path.length() <= 0 || (lastIndexOf = path.lastIndexOf(".")) <= -1) ? "" : path.substring(lastIndexOf + 1);
    }

    public String getName() {
        return this.partNameURI.toASCIIString();
    }

    public URI getURI() {
        return this.partNameURI;
    }

    public int hashCode() {
        return this.partNameURI.toASCIIString().toLowerCase(Locale.ROOT).hashCode();
    }

    public String toString() {
        return getName();
    }

    public static int compare(String str, String str2) {
        int i2 = 0;
        if (str == null) {
            return str2 == null ? 0 : -1;
        }
        if (str2 == null) {
            return 1;
        }
        int length = str.length();
        int length2 = str2.length();
        int i3 = 0;
        while (i2 < length && i3 < length2) {
            int i4 = i2 + 1;
            char charAt = str.charAt(i2);
            int i5 = i3 + 1;
            char charAt2 = str2.charAt(i3);
            if (Character.isDigit(charAt) && Character.isDigit(charAt2)) {
                int i6 = i4 - 1;
                while (i4 < length && Character.isDigit(str.charAt(i4))) {
                    i4++;
                }
                int i7 = i5 - 1;
                while (i5 < length2 && Character.isDigit(str2.charAt(i5))) {
                    i5++;
                }
                int compareTo = new BigInteger(str.substring(i6, i4)).compareTo(new BigInteger(str2.substring(i7, i5)));
                if (compareTo != 0) {
                    return compareTo;
                }
            } else if (charAt != charAt2) {
                return charAt - charAt2;
            }
            i2 = i4;
            i3 = i5;
        }
        return length - length2;
    }

    public int compareTo(PackagePartName packagePartName) {
        return compare(this, packagePartName);
    }

    public boolean isRelationshipPartURI() {
        return this.isRelationship;
    }

    public PackagePartName(String str, boolean z) {
        try {
            URI uri = new URI(str);
            if (z) {
                throwExceptionIfInvalidPartUri(uri);
            } else if (!PackagingURIHelper.PACKAGE_ROOT_URI.equals(uri)) {
                throw new OpenXML4JRuntimeException("OCP conformance must be check for ALL part name except special cases : ['/']");
            }
            this.partNameURI = uri;
            this.isRelationship = isRelationshipPartURI(uri);
        } catch (URISyntaxException unused) {
            throw new IllegalArgumentException("partName argmument is not a valid OPC part name !");
        }
    }
}
