package org.apache.poi.openxml4j.opc;

import b.b.a.a.a;
import java.net.URI;
import java.net.URISyntaxException;
import org.apache.poi.openxml4j.opc.internal.ZipHelper;

public final class PackageRelationship {
    public static final String ID_ATTRIBUTE_NAME = "Id";
    public static final String RELATIONSHIPS_TAG_NAME = "Relationships";
    public static final String RELATIONSHIP_TAG_NAME = "Relationship";
    public static final String TARGET_ATTRIBUTE_NAME = "Target";
    public static final String TARGET_MODE_ATTRIBUTE_NAME = "TargetMode";
    public static final String TYPE_ATTRIBUTE_NAME = "Type";
    public static URI containerRelationshipPart;
    public OPCPackage container;
    public String id;
    public String relationshipType;
    public PackagePart source;
    public TargetMode targetMode;
    public URI targetUri;

    static {
        try {
            containerRelationshipPart = new URI("/_rels/.rels");
        } catch (URISyntaxException unused) {
        }
    }

    public PackageRelationship(OPCPackage oPCPackage, PackagePart packagePart, URI uri, TargetMode targetMode2, String str, String str2) {
        if (oPCPackage == null) {
            throw new IllegalArgumentException("pkg");
        } else if (uri == null) {
            throw new IllegalArgumentException("targetUri");
        } else if (str == null) {
            throw new IllegalArgumentException("relationshipType");
        } else if (str2 != null) {
            this.container = oPCPackage;
            this.source = packagePart;
            this.targetUri = uri;
            this.targetMode = targetMode2;
            this.relationshipType = str;
            this.id = str2;
        } else {
            throw new IllegalArgumentException("id");
        }
    }

    public static URI getContainerPartRelationship() {
        return containerRelationshipPart;
    }

    public boolean equals(Object obj) {
        if (!(obj instanceof PackageRelationship)) {
            return false;
        }
        PackageRelationship packageRelationship = (PackageRelationship) obj;
        if (!this.id.equals(packageRelationship.id) || !this.relationshipType.equals(packageRelationship.relationshipType)) {
            return false;
        }
        PackagePart packagePart = packageRelationship.source;
        if ((packagePart == null || packagePart.equals(this.source)) && this.targetMode == packageRelationship.targetMode && this.targetUri.equals(packageRelationship.targetUri)) {
            return true;
        }
        return false;
    }

    public String getId() {
        return this.id;
    }

    public OPCPackage getPackage() {
        return this.container;
    }

    public String getRelationshipType() {
        return this.relationshipType;
    }

    public PackagePart getSource() {
        return this.source;
    }

    public URI getSourceURI() {
        PackagePart packagePart = this.source;
        if (packagePart == null) {
            return PackagingURIHelper.PACKAGE_ROOT_URI;
        }
        return packagePart._partName.getURI();
    }

    public TargetMode getTargetMode() {
        return this.targetMode;
    }

    public URI getTargetURI() {
        if (this.targetMode == TargetMode.EXTERNAL) {
            return this.targetUri;
        }
        if (!this.targetUri.toASCIIString().startsWith(ZipHelper.FORWARD_SLASH)) {
            return PackagingURIHelper.resolvePartUri(getSourceURI(), this.targetUri);
        }
        return this.targetUri;
    }

    public int hashCode() {
        int hashCode = this.relationshipType.hashCode() + this.id.hashCode();
        PackagePart packagePart = this.source;
        return this.targetUri.hashCode() + this.targetMode.hashCode() + hashCode + (packagePart == null ? 0 : packagePart.hashCode());
    }

    public String toString() {
        String str;
        String str2;
        String str3;
        String str4;
        String str5;
        String str6;
        StringBuilder sb = new StringBuilder();
        if (this.id == null) {
            str = "id=null";
        } else {
            StringBuilder b2 = a.b("id=");
            b2.append(this.id);
            str = b2.toString();
        }
        sb.append(str);
        if (this.container == null) {
            str2 = " - container=null";
        } else {
            StringBuilder b3 = a.b(" - container=");
            b3.append(this.container);
            str2 = b3.toString();
        }
        sb.append(str2);
        if (this.relationshipType == null) {
            str3 = " - relationshipType=null";
        } else {
            StringBuilder b4 = a.b(" - relationshipType=");
            b4.append(this.relationshipType);
            str3 = b4.toString();
        }
        sb.append(str3);
        if (this.source == null) {
            str4 = " - source=null";
        } else {
            StringBuilder b5 = a.b(" - source=");
            b5.append(getSourceURI().toASCIIString());
            str4 = b5.toString();
        }
        sb.append(str4);
        if (this.targetUri == null) {
            str5 = " - target=null";
        } else {
            StringBuilder b6 = a.b(" - target=");
            b6.append(getTargetURI().toASCIIString());
            str5 = b6.toString();
        }
        sb.append(str5);
        if (this.targetMode == null) {
            str6 = ",targetMode=null";
        } else {
            StringBuilder b7 = a.b(",targetMode=");
            b7.append(this.targetMode);
            str6 = b7.toString();
        }
        sb.append(str6);
        return sb.toString();
    }
}
