package org.apache.poi.openxml4j.opc;

import b.b.a.a.a;
import java.net.URI;
import java.net.URISyntaxException;
import java.nio.ByteBuffer;
import java.nio.charset.Charset;
import java.util.regex.Pattern;
import org.apache.poi.openxml4j.exceptions.InvalidFormatException;
import org.apache.poi.openxml4j.exceptions.InvalidOperationException;
import org.apache.poi.openxml4j.opc.internal.ZipHelper;
import org.apache.poi.ss.usermodel.DataFormatter;
import org.apache.poi.ss.util.SheetUtil;
import org.apache.poi.util.POILogFactory;
import org.apache.poi.util.POILogger;
import org.apache.xmlbeans.impl.common.JarHelper;

public final class PackagingURIHelper {
    public static final PackagePartName CORE_PROPERTIES_PART_NAME;
    public static final URI CORE_PROPERTIES_URI;
    public static final char FORWARD_SLASH_CHAR = JarHelper.SEP;
    public static final String FORWARD_SLASH_STRING = ZipHelper.FORWARD_SLASH;
    public static final String PACKAGE_CORE_PROPERTIES_NAME = "core.xml";
    public static final String PACKAGE_PROPERTIES_SEGMENT_NAME = "docProps";
    public static final PackagePartName PACKAGE_RELATIONSHIPS_ROOT_PART_NAME;
    public static final URI PACKAGE_RELATIONSHIPS_ROOT_URI;
    public static final PackagePartName PACKAGE_ROOT_PART_NAME;
    public static final URI PACKAGE_ROOT_URI;
    public static final String RELATIONSHIP_PART_EXTENSION_NAME = ".rels";
    public static final String RELATIONSHIP_PART_SEGMENT_NAME = "_rels";
    public static final POILogger _logger = POILogFactory.getLogger(PackagingURIHelper.class);
    public static final char[] hexDigits = {SheetUtil.defaultChar, '1', '2', '3', '4', '5', '6', '7', '8', '9', 'A', 'B', 'C', 'D', 'E', 'F'};
    public static final Pattern missingAuthPattern = Pattern.compile("\\w+://");
    public static URI packageRootUri;

    static {
        URI uri;
        URI uri2;
        URI uri3;
        PackagePartName packagePartName;
        PackagePartName packagePartName2;
        PackagePartName packagePartName3 = null;
        try {
            uri2 = new URI(ZipHelper.FORWARD_SLASH);
            try {
                uri = new URI(FORWARD_SLASH_CHAR + RELATIONSHIP_PART_SEGMENT_NAME + FORWARD_SLASH_CHAR + RELATIONSHIP_PART_EXTENSION_NAME);
                try {
                    packageRootUri = new URI(ZipHelper.FORWARD_SLASH);
                    uri3 = new URI(FORWARD_SLASH_CHAR + PACKAGE_PROPERTIES_SEGMENT_NAME + FORWARD_SLASH_CHAR + PACKAGE_CORE_PROPERTIES_NAME);
                } catch (URISyntaxException unused) {
                }
            } catch (URISyntaxException unused2) {
                uri = null;
                uri3 = null;
                PACKAGE_ROOT_URI = uri2;
                PACKAGE_RELATIONSHIPS_ROOT_URI = uri;
                CORE_PROPERTIES_URI = uri3;
                packagePartName2 = createPartName(uri);
                packagePartName = createPartName(CORE_PROPERTIES_URI);
                try {
                    packagePartName3 = new PackagePartName(PACKAGE_ROOT_URI, false);
                } catch (InvalidFormatException unused3) {
                }
                PACKAGE_RELATIONSHIPS_ROOT_PART_NAME = packagePartName2;
                CORE_PROPERTIES_PART_NAME = packagePartName;
                PACKAGE_ROOT_PART_NAME = packagePartName3;
            }
        } catch (URISyntaxException unused4) {
            uri2 = null;
            uri = null;
            uri3 = null;
            PACKAGE_ROOT_URI = uri2;
            PACKAGE_RELATIONSHIPS_ROOT_URI = uri;
            CORE_PROPERTIES_URI = uri3;
            packagePartName2 = createPartName(uri);
            packagePartName = createPartName(CORE_PROPERTIES_URI);
            packagePartName3 = new PackagePartName(PACKAGE_ROOT_URI, false);
            PACKAGE_RELATIONSHIPS_ROOT_PART_NAME = packagePartName2;
            CORE_PROPERTIES_PART_NAME = packagePartName;
            PACKAGE_ROOT_PART_NAME = packagePartName3;
        }
        PACKAGE_ROOT_URI = uri2;
        PACKAGE_RELATIONSHIPS_ROOT_URI = uri;
        CORE_PROPERTIES_URI = uri3;
        try {
            packagePartName2 = createPartName(uri);
            try {
                packagePartName = createPartName(CORE_PROPERTIES_URI);
                packagePartName3 = new PackagePartName(PACKAGE_ROOT_URI, false);
            } catch (InvalidFormatException unused5) {
                packagePartName = null;
            }
        } catch (InvalidFormatException unused6) {
            packagePartName2 = null;
            packagePartName = null;
        }
        PACKAGE_RELATIONSHIPS_ROOT_PART_NAME = packagePartName2;
        CORE_PROPERTIES_PART_NAME = packagePartName;
        PACKAGE_ROOT_PART_NAME = packagePartName3;
    }

    public static URI combine(URI uri, URI uri2) {
        try {
            return new URI(combine(uri.getPath(), uri2.getPath()));
        } catch (URISyntaxException unused) {
            throw new IllegalArgumentException("Prefix and suffix can't be combine !");
        }
    }

    public static PackagePartName createPartName(URI uri) {
        if (uri != null) {
            return new PackagePartName(uri, true);
        }
        throw new IllegalArgumentException("partName");
    }

    public static String decodeURI(URI uri) {
        StringBuffer stringBuffer = new StringBuffer();
        String aSCIIString = uri.toASCIIString();
        int length = aSCIIString.length();
        int i2 = 0;
        while (i2 < length) {
            char charAt = aSCIIString.charAt(i2);
            if (charAt != '%') {
                stringBuffer.append(charAt);
            } else if (length - i2 >= 2) {
                stringBuffer.append((char) Integer.parseInt(aSCIIString.substring(i2 + 1, i2 + 3), 16));
                i2 += 2;
            } else {
                throw new IllegalArgumentException(a.b("The uri ", aSCIIString, " contain invalid encoded character !"));
            }
            i2++;
        }
        return stringBuffer.toString();
    }

    public static String encode(String str) {
        if (str.length() == 0) {
            return str;
        }
        ByteBuffer wrap = ByteBuffer.wrap(str.getBytes(Charset.forName("UTF-8")));
        StringBuilder sb = new StringBuilder();
        while (wrap.hasRemaining()) {
            int i2 = wrap.get() & 255;
            if (isUnsafe(i2)) {
                sb.append('%');
                sb.append(hexDigits[(i2 >> 4) & 15]);
                sb.append(hexDigits[(i2 >> 0) & 15]);
            } else {
                sb.append((char) i2);
            }
        }
        return sb.toString();
    }

    public static String getFilename(URI uri) {
        if (uri == null) {
            return "";
        }
        String path = uri.getPath();
        int length = path.length();
        int i2 = length;
        do {
            i2--;
            if (i2 < 0) {
                return "";
            }
        } while (path.charAt(i2) != FORWARD_SLASH_CHAR);
        return path.substring(i2 + 1, length);
    }

    public static String getFilenameWithoutExtension(URI uri) {
        String filename = getFilename(uri);
        int lastIndexOf = filename.lastIndexOf(".");
        if (lastIndexOf == -1) {
            return filename;
        }
        return filename.substring(0, lastIndexOf);
    }

    public static URI getPackageRootUri() {
        return packageRootUri;
    }

    public static URI getPath(URI uri) {
        if (uri != null) {
            String path = uri.getPath();
            int length = path.length();
            do {
                length--;
                if (length >= 0) {
                }
            } while (path.charAt(length) != FORWARD_SLASH_CHAR);
            try {
                return new URI(path.substring(0, length));
            } catch (URISyntaxException unused) {
            }
        }
        return null;
    }

    public static PackagePartName getRelationshipPartName(PackagePartName packagePartName) {
        if (packagePartName == null) {
            throw new IllegalArgumentException("partName");
        } else if (PACKAGE_ROOT_URI.getPath().equals(packagePartName.getURI().getPath())) {
            return PACKAGE_RELATIONSHIPS_ROOT_PART_NAME;
        } else {
            if (!packagePartName.isRelationshipPartURI()) {
                String path = packagePartName.getURI().getPath();
                String filename = getFilename(packagePartName.getURI());
                StringBuilder b2 = a.b(combine(combine(path.substring(0, path.length() - filename.length()), RELATIONSHIP_PART_SEGMENT_NAME), filename));
                b2.append(RELATIONSHIP_PART_EXTENSION_NAME);
                try {
                    return createPartName(b2.toString());
                } catch (InvalidFormatException unused) {
                    return null;
                }
            } else {
                throw new InvalidOperationException("Can't be a relationship part");
            }
        }
    }

    public static URI getSourcePartUriFromRelationshipPartUri(URI uri) {
        if (uri == null) {
            throw new IllegalArgumentException("Must not be null");
        } else if (!isRelationshipPartURI(uri)) {
            throw new IllegalArgumentException("Must be a relationship part");
        } else if (uri.compareTo(PACKAGE_RELATIONSHIPS_ROOT_URI) == 0) {
            return PACKAGE_ROOT_URI;
        } else {
            String path = uri.getPath();
            String filenameWithoutExtension = getFilenameWithoutExtension(uri);
            String substring = path.substring(0, (path.length() - filenameWithoutExtension.length()) - RELATIONSHIP_PART_EXTENSION_NAME.length());
            return getURIFromPath(combine(substring.substring(0, (substring.length() - RELATIONSHIP_PART_SEGMENT_NAME.length()) - 1), filenameWithoutExtension));
        }
    }

    public static URI getURIFromPath(String str) {
        try {
            return toURI(str);
        } catch (URISyntaxException unused) {
            throw new IllegalArgumentException("path");
        }
    }

    public static boolean isRelationshipPartURI(URI uri) {
        if (uri != null) {
            String path = uri.getPath();
            StringBuilder b2 = a.b(".*");
            b2.append(RELATIONSHIP_PART_SEGMENT_NAME);
            b2.append(".*");
            b2.append(RELATIONSHIP_PART_EXTENSION_NAME);
            b2.append("$");
            return path.matches(b2.toString());
        }
        throw new IllegalArgumentException("partUri");
    }

    public static boolean isUnsafe(int i2) {
        return i2 > 128 || Character.isWhitespace(i2);
    }

    public static boolean isValidPartName(URI uri) {
        if (uri != null) {
            try {
                createPartName(uri);
                return true;
            } catch (Exception unused) {
                return false;
            }
        } else {
            throw new IllegalArgumentException("partUri");
        }
    }

    public static URI relativizeURI(URI uri, URI uri2, boolean z) {
        StringBuilder sb = new StringBuilder();
        String[] split = uri.getPath().split(ZipHelper.FORWARD_SLASH, -1);
        String[] split2 = uri2.getPath().split(ZipHelper.FORWARD_SLASH, -1);
        if (split.length == 0) {
            throw new IllegalArgumentException("Can't relativize an empty source URI !");
        } else if (split2.length == 0) {
            throw new IllegalArgumentException("Can't relativize an empty target URI !");
        } else if (uri.toString().equals(ZipHelper.FORWARD_SLASH)) {
            String path = uri2.getPath();
            if (!z || path.length() <= 0 || path.charAt(0) != '/') {
                return uri2;
            }
            try {
                return new URI(path.substring(1));
            } catch (Exception e2) {
                _logger.log(5, e2);
                return null;
            }
        } else {
            int i2 = 0;
            int i3 = 0;
            while (i2 < split.length && i2 < split2.length && split[i2].equals(split2[i2])) {
                i3++;
                i2++;
            }
            if ((i3 == 0 || i3 == 1) && split[0].equals("") && split2[0].equals("")) {
                for (int i4 = 0; i4 < split.length - 2; i4++) {
                    sb.append("../");
                }
                for (int i5 = 0; i5 < split2.length; i5++) {
                    if (!split2[i5].equals("")) {
                        sb.append(split2[i5]);
                        if (i5 != split2.length - 1) {
                            sb.append(ZipHelper.FORWARD_SLASH);
                        }
                    }
                }
                try {
                    return new URI(sb.toString());
                } catch (Exception e3) {
                    _logger.log(5, e3);
                    return null;
                }
            } else {
                if (i3 != split.length || i3 != split2.length) {
                    if (i3 == 1) {
                        sb.append(ZipHelper.FORWARD_SLASH);
                    } else {
                        for (int i6 = i3; i6 < split.length - 1; i6++) {
                            sb.append("../");
                        }
                    }
                    while (i3 < split2.length) {
                        if (sb.length() > 0 && sb.charAt(sb.length() - 1) != '/') {
                            sb.append(ZipHelper.FORWARD_SLASH);
                        }
                        sb.append(split2[i3]);
                        i3++;
                    }
                } else if (uri.equals(uri2)) {
                    sb.append(split[split.length - 1]);
                } else {
                    sb.append("");
                }
                String rawFragment = uri2.getRawFragment();
                if (rawFragment != null) {
                    sb.append(DataFormatter.defaultFractionWholePartFormat);
                    sb.append(rawFragment);
                }
                try {
                    return new URI(sb.toString());
                } catch (Exception e4) {
                    _logger.log(5, e4);
                    return null;
                }
            }
        }
    }

    public static URI resolvePartUri(URI uri, URI uri2) {
        if (uri == null || uri.isAbsolute()) {
            throw new IllegalArgumentException("sourcePartUri invalid - " + uri);
        } else if (uri2 != null && !uri2.isAbsolute()) {
            return uri.resolve(uri2);
        } else {
            throw new IllegalArgumentException("targetUri invalid - " + uri2);
        }
    }

    public static URI toURI(String str) {
        if (str.indexOf("\\") != -1) {
            str = str.replace('\\', JarHelper.SEP);
        }
        int indexOf = str.indexOf(35);
        if (indexOf != -1) {
            String substring = str.substring(0, indexOf);
            String substring2 = str.substring(indexOf + 1);
            StringBuilder d2 = a.d(substring, DataFormatter.defaultFractionWholePartFormat);
            d2.append(encode(substring2));
            str = d2.toString();
        }
        if (str.length() > 0) {
            StringBuilder sb = new StringBuilder();
            int length = str.length();
            while (true) {
                length--;
                if (length < 0) {
                    break;
                }
                char charAt = str.charAt(length);
                if (!Character.isWhitespace(charAt) && charAt != 160) {
                    break;
                }
                sb.append(charAt);
            }
            if (sb.length() > 0) {
                str = str.substring(0, length + 1) + encode(sb.reverse().toString());
            }
        }
        if (missingAuthPattern.matcher(str).matches()) {
            str = a.b(str, ZipHelper.FORWARD_SLASH);
        }
        return new URI(str);
    }

    /* JADX WARNING: Code restructure failed: missing block: B:13:0x0083, code lost:
        if (r4.startsWith(r1.toString()) == false) goto L_0x0085;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:15:0x0089, code lost:
        return b.b.a.a.a.b(r3, r4);
     */
    /* JADX WARNING: Code restructure failed: missing block: B:9:0x005d, code lost:
        if (r4.startsWith(r1.toString()) == false) goto L_0x005f;
     */
    public static String combine(String str, String str2) {
        StringBuilder b2 = a.b("");
        b2.append(FORWARD_SLASH_CHAR);
        if (!str.endsWith(b2.toString())) {
            StringBuilder b3 = a.b("");
            b3.append(FORWARD_SLASH_CHAR);
            if (!str2.startsWith(b3.toString())) {
                StringBuilder b4 = a.b(str);
                b4.append(FORWARD_SLASH_CHAR);
                b4.append(str2);
                return b4.toString();
            }
        }
        StringBuilder b5 = a.b("");
        b5.append(FORWARD_SLASH_CHAR);
        if (!str.endsWith(b5.toString())) {
            StringBuilder b6 = a.b("");
            b6.append(FORWARD_SLASH_CHAR);
        }
        StringBuilder b7 = a.b("");
        b7.append(FORWARD_SLASH_CHAR);
        if (str.endsWith(b7.toString())) {
            StringBuilder b8 = a.b("");
            b8.append(FORWARD_SLASH_CHAR);
        }
        return "";
    }

    public static PackagePartName createPartName(String str) {
        try {
            return createPartName(toURI(str));
        } catch (URISyntaxException e2) {
            throw new InvalidFormatException(e2.getMessage());
        }
    }

    public static PackagePartName createPartName(String str, PackagePart packagePart) {
        try {
            return createPartName(resolvePartUri(packagePart.getPartName().getURI(), new URI(str)));
        } catch (URISyntaxException e2) {
            throw new InvalidFormatException(e2.getMessage());
        }
    }

    public static PackagePartName createPartName(URI uri, PackagePart packagePart) {
        return createPartName(resolvePartUri(packagePart.getPartName().getURI(), uri));
    }

    public static URI relativizeURI(URI uri, URI uri2) {
        return relativizeURI(uri, uri2, false);
    }
}
