package org.apache.poi.openxml4j.opc;

import java.io.FilterOutputStream;
import java.io.InputStream;
import java.io.OutputStream;
import javax.xml.transform.OutputKeys;
import javax.xml.transform.Transformer;
import javax.xml.transform.TransformerException;
import javax.xml.transform.TransformerFactory;
import javax.xml.transform.dom.DOMSource;
import javax.xml.transform.stream.StreamResult;
import org.w3c.dom.Document;

public final class StreamHelper {
    public static final TransformerFactory transformerFactory = TransformerFactory.newInstance();

    public static boolean copyStream(InputStream inputStream, OutputStream outputStream) {
        try {
            byte[] bArr = new byte[1024];
            while (true) {
                int read = inputStream.read(bArr);
                if (read < 0) {
                    return true;
                }
                outputStream.write(bArr, 0, read);
            }
        } catch (Exception unused) {
            return false;
        }
    }

    public static synchronized Transformer getIdentityTransformer() {
        Transformer newTransformer;
        synchronized (StreamHelper.class) {
            newTransformer = transformerFactory.newTransformer();
        }
        return newTransformer;
    }

    public static boolean saveXmlInStream(Document document, OutputStream outputStream) {
        try {
            Transformer identityTransformer = getIdentityTransformer();
            DOMSource dOMSource = new DOMSource(document);
            StreamResult streamResult = new StreamResult(new FilterOutputStream(outputStream) {
                /* class org.apache.poi.openxml4j.opc.StreamHelper.AnonymousClass1 */

                @Override // java.io.OutputStream, java.io.Closeable, java.io.FilterOutputStream, java.lang.AutoCloseable
                public void close() {
                    ((FilterOutputStream) this).out.flush();
                }

                @Override // java.io.OutputStream, java.io.FilterOutputStream
                public void write(byte[] bArr, int i2, int i3) {
                    ((FilterOutputStream) this).out.write(bArr, i2, i3);
                }
            });
            identityTransformer.setOutputProperty(OutputKeys.ENCODING, "UTF-8");
            identityTransformer.setOutputProperty(OutputKeys.INDENT, "yes");
            identityTransformer.setOutputProperty(OutputKeys.STANDALONE, "yes");
            identityTransformer.transform(dOMSource, streamResult);
            return true;
        } catch (TransformerException unused) {
            return false;
        }
    }
}
