package org.apache.poi.openxml4j.opc.internal.marshallers;

import java.io.OutputStream;
import org.apache.poi.javax.xml.stream.XMLEventFactory;
import org.apache.poi.javax.xml.stream.events.Namespace;
import org.apache.poi.openxml4j.opc.PackagePart;
import org.apache.poi.openxml4j.opc.internal.PackagePropertiesPart;
import org.apache.poi.openxml4j.opc.internal.PartMarshaller;
import org.apache.poi.openxml4j.util.Nullable;
import org.apache.poi.util.DocumentHelper;
import org.apache.xmlbeans.impl.jam.xml.JamXmlElements;
import org.w3c.dom.Document;
import org.w3c.dom.Element;

public class PackagePropertiesMarshaller implements PartMarshaller {
    public static final String KEYWORD_CATEGORY = "category";
    public static final String KEYWORD_CONTENT_STATUS = "contentStatus";
    public static final String KEYWORD_CONTENT_TYPE = "contentType";
    public static final String KEYWORD_CREATED = "created";
    public static final String KEYWORD_CREATOR = "creator";
    public static final String KEYWORD_DESCRIPTION = "description";
    public static final String KEYWORD_IDENTIFIER = "identifier";
    public static final String KEYWORD_KEYWORDS = "keywords";
    public static final String KEYWORD_LANGUAGE = "language";
    public static final String KEYWORD_LAST_MODIFIED_BY = "lastModifiedBy";
    public static final String KEYWORD_LAST_PRINTED = "lastPrinted";
    public static final String KEYWORD_MODIFIED = "modified";
    public static final String KEYWORD_REVISION = "revision";
    public static final String KEYWORD_SUBJECT = "subject";
    public static final String KEYWORD_TITLE = "title";
    public static final String KEYWORD_VERSION = "version";
    public static final Namespace namespaceCoreProperties;
    public static final Namespace namespaceDC;
    public static final Namespace namespaceDcTerms;
    public static final Namespace namespaceXSI;
    public PackagePropertiesPart propsPart;
    public Document xmlDoc = null;

    static {
        XMLEventFactory newInstance = XMLEventFactory.newInstance();
        namespaceDC = newInstance.createNamespace("dc", "http://purl.org/dc/elements/1.1/");
        namespaceCoreProperties = newInstance.createNamespace("cp", "http://schemas.openxmlformats.org/package/2006/metadata/core-properties");
        namespaceDcTerms = newInstance.createNamespace("dcterms", "http://purl.org/dc/terms/");
        namespaceXSI = newInstance.createNamespace("xsi", "http://www.w3.org/2001/XMLSchema-instance");
    }

    private void addCategory() {
        setElementTextContent("category", namespaceCoreProperties, this.propsPart.getCategoryProperty());
    }

    private void addContentStatus() {
        setElementTextContent("contentStatus", namespaceCoreProperties, this.propsPart.getContentStatusProperty());
    }

    private void addContentType() {
        setElementTextContent("contentType", namespaceCoreProperties, this.propsPart.getContentTypeProperty());
    }

    private void addCreated() {
        setElementTextContent("created", namespaceDcTerms, this.propsPart.getCreatedProperty(), this.propsPart.getCreatedPropertyString(), "dcterms:W3CDTF");
    }

    private void addCreator() {
        setElementTextContent("creator", namespaceDC, this.propsPart.getCreatorProperty());
    }

    private void addDescription() {
        setElementTextContent("description", namespaceDC, this.propsPart.getDescriptionProperty());
    }

    private void addIdentifier() {
        setElementTextContent("identifier", namespaceDC, this.propsPart.getIdentifierProperty());
    }

    private void addKeywords() {
        setElementTextContent("keywords", namespaceCoreProperties, this.propsPart.getKeywordsProperty());
    }

    private void addLanguage() {
        setElementTextContent("language", namespaceDC, this.propsPart.getLanguageProperty());
    }

    private void addLastModifiedBy() {
        setElementTextContent("lastModifiedBy", namespaceCoreProperties, this.propsPart.getLastModifiedByProperty());
    }

    private void addLastPrinted() {
        setElementTextContent("lastPrinted", namespaceCoreProperties, this.propsPart.getLastPrintedProperty(), this.propsPart.getLastPrintedPropertyString());
    }

    private void addModified() {
        setElementTextContent("modified", namespaceDcTerms, this.propsPart.getModifiedProperty(), this.propsPart.getModifiedPropertyString(), "dcterms:W3CDTF");
    }

    private void addRevision() {
        setElementTextContent("revision", namespaceCoreProperties, this.propsPart.getRevisionProperty());
    }

    private void addSubject() {
        setElementTextContent("subject", namespaceDC, this.propsPart.getSubjectProperty());
    }

    private void addTitle() {
        setElementTextContent("title", namespaceDC, this.propsPart.getTitleProperty());
    }

    private void addVersion() {
        setElementTextContent("version", namespaceCoreProperties, this.propsPart.getVersionProperty());
    }

    private String getQName(String str, Namespace namespace) {
        if (namespace.getPrefix().isEmpty()) {
            return str;
        }
        return namespace.getPrefix() + ':' + str;
    }

    private Element setElementTextContent(String str, Namespace namespace, Nullable<String> nullable) {
        return setElementTextContent(str, namespace, nullable, nullable.getValue());
    }

    @Override // org.apache.poi.openxml4j.opc.internal.PartMarshaller
    public boolean marshall(PackagePart packagePart, OutputStream outputStream) {
        if (packagePart instanceof PackagePropertiesPart) {
            this.propsPart = (PackagePropertiesPart) packagePart;
            Document createDocument = DocumentHelper.createDocument();
            this.xmlDoc = createDocument;
            Element createElementNS = createDocument.createElementNS(namespaceCoreProperties.getNamespaceURI(), getQName("coreProperties", namespaceCoreProperties));
            DocumentHelper.addNamespaceDeclaration(createElementNS, namespaceCoreProperties);
            DocumentHelper.addNamespaceDeclaration(createElementNS, namespaceDC);
            DocumentHelper.addNamespaceDeclaration(createElementNS, namespaceDcTerms);
            DocumentHelper.addNamespaceDeclaration(createElementNS, namespaceXSI);
            this.xmlDoc.appendChild(createElementNS);
            addCategory();
            addContentStatus();
            addContentType();
            addCreated();
            addCreator();
            addDescription();
            addIdentifier();
            addKeywords();
            addLanguage();
            addLastModifiedBy();
            addLastPrinted();
            addModified();
            addRevision();
            addSubject();
            addTitle();
            addVersion();
            return true;
        }
        throw new IllegalArgumentException("'part' must be a PackagePropertiesPart instance.");
    }

    private Element setElementTextContent(String str, Namespace namespace, Nullable<?> nullable, String str2) {
        if (!nullable.hasValue()) {
            return null;
        }
        Element documentElement = this.xmlDoc.getDocumentElement();
        Element element = (Element) documentElement.getElementsByTagNameNS(namespace.getNamespaceURI(), str).item(0);
        if (element == null) {
            element = this.xmlDoc.createElementNS(namespace.getNamespaceURI(), getQName(str, namespace));
            documentElement.appendChild(element);
        }
        element.setTextContent(str2);
        return element;
    }

    private Element setElementTextContent(String str, Namespace namespace, Nullable<?> nullable, String str2, String str3) {
        Element elementTextContent = setElementTextContent(str, namespace, nullable, str2);
        if (elementTextContent != null) {
            elementTextContent.setAttributeNS(namespaceXSI.getNamespaceURI(), getQName(JamXmlElements.TYPE, namespaceXSI), str3);
        }
        return elementTextContent;
    }
}
