package org.apache.poi.openxml4j.util;

import java.io.ByteArrayInputStream;
import java.io.ByteArrayOutputStream;
import java.io.IOException;
import java.io.InputStream;
import java.util.ArrayList;
import java.util.Enumeration;
import java.util.Iterator;
import java.util.zip.ZipEntry;
import org.apache.poi.openxml4j.util.ZipSecureFile;

public class ZipInputStreamZipEntrySource implements ZipEntrySource {
    public static final /* synthetic */ boolean $assertionsDisabled = false;
    public ArrayList<FakeZipEntry> zipEntries = new ArrayList<>();

    public class EntryEnumerator implements Enumeration<ZipEntry> {
        public Iterator<? extends ZipEntry> iterator;

        public boolean hasMoreElements() {
            return this.iterator.hasNext();
        }

        public EntryEnumerator() {
            this.iterator = ZipInputStreamZipEntrySource.this.zipEntries.iterator();
        }

        @Override // java.util.Enumeration
        public ZipEntry nextElement() {
            return (ZipEntry) this.iterator.next();
        }
    }

    public static class FakeZipEntry extends ZipEntry {
        public byte[] data;

        public FakeZipEntry(ZipEntry zipEntry, InputStream inputStream) {
            super(zipEntry.getName());
            ByteArrayOutputStream byteArrayOutputStream;
            long size = zipEntry.getSize();
            if (size == -1) {
                byteArrayOutputStream = new ByteArrayOutputStream();
            } else if (size < 2147483647L) {
                byteArrayOutputStream = new ByteArrayOutputStream((int) size);
            } else {
                throw new IOException("ZIP entry size is too large");
            }
            byte[] bArr = new byte[4096];
            while (true) {
                int read = inputStream.read(bArr);
                if (read != -1) {
                    byteArrayOutputStream.write(bArr, 0, read);
                } else {
                    this.data = byteArrayOutputStream.toByteArray();
                    return;
                }
            }
        }

        public InputStream getInputStream() {
            return new ByteArrayInputStream(this.data);
        }
    }

    public ZipInputStreamZipEntrySource(ZipSecureFile.ThresholdInputStream thresholdInputStream) {
        boolean z = true;
        while (z) {
            ZipEntry nextEntry = thresholdInputStream.getNextEntry();
            if (nextEntry == null) {
                z = false;
            } else {
                FakeZipEntry fakeZipEntry = new FakeZipEntry(nextEntry, thresholdInputStream);
                thresholdInputStream.closeEntry();
                this.zipEntries.add(fakeZipEntry);
            }
        }
        thresholdInputStream.close();
    }

    @Override // org.apache.poi.openxml4j.util.ZipEntrySource, java.io.Closeable, java.lang.AutoCloseable
    public void close() {
        this.zipEntries = null;
    }

    @Override // org.apache.poi.openxml4j.util.ZipEntrySource
    public Enumeration<? extends ZipEntry> getEntries() {
        return new EntryEnumerator();
    }

    @Override // org.apache.poi.openxml4j.util.ZipEntrySource
    public InputStream getInputStream(ZipEntry zipEntry) {
        return ((FakeZipEntry) zipEntry).getInputStream();
    }

    @Override // org.apache.poi.openxml4j.util.ZipEntrySource
    public boolean isClosed() {
        return this.zipEntries == null;
    }
}
