package org.apache.poi.poifs.crypt;

import b.b.a.a.a;
import org.apache.poi.EncryptedDocumentException;
import org.apache.poi.hssf.usermodel.HSSFShapeTypes;
import org.apache.poi.openxml4j.opc.internal.ZipHelper;

public enum CipherAlgorithm {
    rc4(CipherProvider.rc4, "RC4", 26625, 64, new int[]{40, 48, 56, 64, 72, 80, 88, 96, 104, 112, 120, 128}, -1, 20, "RC4", false),
    aes128(CipherProvider.aes, "AES", 26126, 128, new int[]{128}, 16, 32, "AES", false),
    aes192(CipherProvider.aes, "AES", 26127, HSSFShapeTypes.ActionButtonInformation, new int[]{192}, 16, 32, "AES", false),
    aes256(CipherProvider.aes, "AES", 26128, 256, new int[]{256}, 16, 32, "AES", false),
    rc2(null, "RC2", -1, 128, new int[]{40, 48, 56, 64, 72, 80, 88, 96, 104, 112, 120, 128}, 8, 20, "RC2", false),
    des(null, "DES", -1, 64, new int[]{64}, 8, 32, "DES", false),
    des3(null, "DESede", -1, HSSFShapeTypes.ActionButtonInformation, new int[]{192}, 8, 32, "3DES", false),
    des3_112(null, "DESede", -1, 128, new int[]{128}, 8, 32, "3DES_112", true),
    rsa(null, "RSA", -1, 1024, new int[]{1024, 2048, 3072, 4096}, -1, -1, "", false);
    
    public final int[] allowedKeySize;
    public final int blockSize;
    public final int defaultKeySize;
    public final int ecmaId;
    public final int encryptedVerifierHashLength;
    public final String jceId;
    public final boolean needsBouncyCastle;
    public final CipherProvider provider;
    public final String xmlId;

    /* access modifiers changed from: public */
    CipherAlgorithm(CipherProvider cipherProvider, String str, int i2, int i3, int[] iArr, int i4, int i5, String str2, boolean z) {
        this.provider = cipherProvider;
        this.jceId = str;
        this.ecmaId = i2;
        this.defaultKeySize = i3;
        this.allowedKeySize = (int[]) iArr.clone();
        this.blockSize = i4;
        this.encryptedVerifierHashLength = i5;
        this.xmlId = str2;
        this.needsBouncyCastle = z;
    }

    public static CipherAlgorithm fromEcmaId(int i2) {
        CipherAlgorithm[] values = values();
        for (CipherAlgorithm cipherAlgorithm : values) {
            if (cipherAlgorithm.ecmaId == i2) {
                return cipherAlgorithm;
            }
        }
        throw new EncryptedDocumentException(a.b("cipher algorithm ", i2, " not found"));
    }

    public static CipherAlgorithm fromXmlId(String str, int i2) {
        CipherAlgorithm[] values = values();
        for (CipherAlgorithm cipherAlgorithm : values) {
            if (cipherAlgorithm.xmlId.equals(str)) {
                for (int i3 : cipherAlgorithm.allowedKeySize) {
                    if (i3 == i2) {
                        return cipherAlgorithm;
                    }
                }
                continue;
            }
        }
        throw new EncryptedDocumentException("cipher algorithm " + str + ZipHelper.FORWARD_SLASH + i2 + " not found");
    }
}
