package org.apache.poi.poifs.crypt;

import java.io.InputStream;
import javax.crypto.Cipher;
import javax.crypto.SecretKey;
import javax.crypto.spec.SecretKeySpec;
import org.apache.poi.EncryptedDocumentException;
import org.apache.poi.poifs.filesystem.DirectoryNode;
import org.apache.poi.poifs.filesystem.NPOIFSFileSystem;
import org.apache.poi.poifs.filesystem.OPOIFSFileSystem;
import org.apache.poi.poifs.filesystem.POIFSFileSystem;

public abstract class Decryptor implements Cloneable {
    public static final String DEFAULT_PASSWORD = "VelvetSweatshop";
    public static final String DEFAULT_POIFS_ENTRY = "EncryptedPackage";
    public EncryptionInfo encryptionInfo;
    public byte[] integrityHmacKey;
    public byte[] integrityHmacValue;
    public SecretKey secretKey;
    public byte[] verifier;

    public static Decryptor getInstance(EncryptionInfo encryptionInfo2) {
        Decryptor decryptor = encryptionInfo2.getDecryptor();
        if (decryptor != null) {
            return decryptor;
        }
        throw new EncryptedDocumentException("Unsupported version");
    }

    public int getBlockSizeInBytes() {
        return this.encryptionInfo.getHeader().getBlockSize();
    }

    public InputStream getDataStream(InputStream inputStream, int i2, int i3) {
        throw new EncryptedDocumentException("this decryptor doesn't support reading from a stream");
    }

    public abstract InputStream getDataStream(DirectoryNode directoryNode);

    public EncryptionInfo getEncryptionInfo() {
        return this.encryptionInfo;
    }

    public byte[] getIntegrityHmacKey() {
        return this.integrityHmacKey;
    }

    public byte[] getIntegrityHmacValue() {
        return this.integrityHmacValue;
    }

    public int getKeySizeInBytes() {
        return this.encryptionInfo.getHeader().getKeySize() / 8;
    }

    public abstract long getLength();

    public SecretKey getSecretKey() {
        return this.secretKey;
    }

    public byte[] getVerifier() {
        return this.verifier;
    }

    public Cipher initCipherForBlock(Cipher cipher, int i2) {
        throw new EncryptedDocumentException("this decryptor doesn't support initCipherForBlock");
    }

    public void setChunkSize(int i2) {
        throw new EncryptedDocumentException("this decryptor doesn't support changing the chunk size");
    }

    public void setEncryptionInfo(EncryptionInfo encryptionInfo2) {
        this.encryptionInfo = encryptionInfo2;
    }

    public void setIntegrityHmacKey(byte[] bArr) {
        this.integrityHmacKey = bArr == null ? null : (byte[]) bArr.clone();
    }

    public void setIntegrityHmacValue(byte[] bArr) {
        this.integrityHmacValue = bArr == null ? null : (byte[]) bArr.clone();
    }

    public void setSecretKey(SecretKey secretKey2) {
        this.secretKey = secretKey2;
    }

    public void setVerifier(byte[] bArr) {
        this.verifier = bArr == null ? null : (byte[]) bArr.clone();
    }

    public abstract boolean verifyPassword(String str);

    @Override // java.lang.Object
    public Decryptor clone() {
        Decryptor decryptor = (Decryptor) super.clone();
        decryptor.integrityHmacKey = (byte[]) this.integrityHmacKey.clone();
        decryptor.integrityHmacValue = (byte[]) this.integrityHmacValue.clone();
        decryptor.verifier = (byte[]) this.verifier.clone();
        decryptor.secretKey = new SecretKeySpec(this.secretKey.getEncoded(), this.secretKey.getAlgorithm());
        return decryptor;
    }

    public InputStream getDataStream(NPOIFSFileSystem nPOIFSFileSystem) {
        return getDataStream(nPOIFSFileSystem.getRoot());
    }

    public InputStream getDataStream(OPOIFSFileSystem oPOIFSFileSystem) {
        return getDataStream(oPOIFSFileSystem.getRoot());
    }

    public InputStream getDataStream(POIFSFileSystem pOIFSFileSystem) {
        return getDataStream(pOIFSFileSystem.getRoot());
    }
}
