package org.apache.poi.poifs.crypt;

import b.b.a.a.a;
import org.apache.poi.EncryptedDocumentException;
import org.apache.poi.util.Removal;

public abstract class EncryptionHeader implements Cloneable {
    public static final int ALGORITHM_AES_128 = CipherAlgorithm.aes128.ecmaId;
    public static final int ALGORITHM_AES_192 = CipherAlgorithm.aes192.ecmaId;
    public static final int ALGORITHM_AES_256 = CipherAlgorithm.aes256.ecmaId;
    public static final int ALGORITHM_RC4 = CipherAlgorithm.rc4.ecmaId;
    public static final int HASH_NONE = HashAlgorithm.none.ecmaId;
    public static final int HASH_SHA1 = HashAlgorithm.sha1.ecmaId;
    public static final int HASH_SHA256 = HashAlgorithm.sha256.ecmaId;
    public static final int HASH_SHA384 = HashAlgorithm.sha384.ecmaId;
    public static final int HASH_SHA512 = HashAlgorithm.sha512.ecmaId;
    public static final int MODE_CBC = ChainingMode.cbc.ecmaId;
    public static final int MODE_CFB = ChainingMode.cfb.ecmaId;
    public static final int MODE_ECB = ChainingMode.ecb.ecmaId;
    public static final int PROVIDER_AES = CipherProvider.aes.ecmaId;
    public static final int PROVIDER_RC4 = CipherProvider.rc4.ecmaId;
    public int blockSize;
    public ChainingMode chainingMode;
    public CipherAlgorithm cipherAlgorithm;
    public String cspName;
    public int flags;
    public HashAlgorithm hashAlgorithm;
    public int keyBits;
    public byte[] keySalt;
    public CipherProvider providerType;
    public int sizeExtra;

    public int getBlockSize() {
        return this.blockSize;
    }

    public ChainingMode getChainingMode() {
        return this.chainingMode;
    }

    public CipherAlgorithm getCipherAlgorithm() {
        return this.cipherAlgorithm;
    }

    public CipherProvider getCipherProvider() {
        return this.providerType;
    }

    public String getCspName() {
        return this.cspName;
    }

    public int getFlags() {
        return this.flags;
    }

    public HashAlgorithm getHashAlgorithm() {
        return this.hashAlgorithm;
    }

    @Removal(version = "3.18")
    public HashAlgorithm getHashAlgorithmEx() {
        return this.hashAlgorithm;
    }

    public byte[] getKeySalt() {
        return this.keySalt;
    }

    public int getKeySize() {
        return this.keyBits;
    }

    public int getSizeExtra() {
        return this.sizeExtra;
    }

    public void setBlockSize(int i2) {
        this.blockSize = i2;
    }

    public void setChainingMode(ChainingMode chainingMode2) {
        this.chainingMode = chainingMode2;
    }

    public void setCipherAlgorithm(CipherAlgorithm cipherAlgorithm2) {
        this.cipherAlgorithm = cipherAlgorithm2;
        if (cipherAlgorithm2.allowedKeySize.length == 1) {
            setKeySize(cipherAlgorithm2.defaultKeySize);
        }
    }

    public void setCipherProvider(CipherProvider cipherProvider) {
        this.providerType = cipherProvider;
    }

    public void setCspName(String str) {
        this.cspName = str;
    }

    public void setFlags(int i2) {
        this.flags = i2;
    }

    public void setHashAlgorithm(HashAlgorithm hashAlgorithm2) {
        this.hashAlgorithm = hashAlgorithm2;
    }

    public void setKeySalt(byte[] bArr) {
        this.keySalt = bArr == null ? null : (byte[]) bArr.clone();
    }

    public void setKeySize(int i2) {
        this.keyBits = i2;
        for (int i3 : getCipherAlgorithm().allowedKeySize) {
            if (i3 == i2) {
                return;
            }
        }
        StringBuilder a = a.a("KeySize ", i2, " not allowed for cipher ");
        a.append(getCipherAlgorithm());
        throw new EncryptedDocumentException(a.toString());
    }

    public void setSizeExtra(int i2) {
        this.sizeExtra = i2;
    }

    @Override // java.lang.Object
    public EncryptionHeader clone() {
        EncryptionHeader encryptionHeader = (EncryptionHeader) super.clone();
        byte[] bArr = this.keySalt;
        encryptionHeader.keySalt = bArr == null ? null : (byte[]) bArr.clone();
        return encryptionHeader;
    }
}
