package org.apache.poi.poifs.crypt;

import b.b.a.a.a;
import java.io.IOException;
import org.apache.poi.EncryptedDocumentException;
import org.apache.poi.poifs.filesystem.DirectoryNode;
import org.apache.poi.poifs.filesystem.NPOIFSFileSystem;
import org.apache.poi.poifs.filesystem.OPOIFSFileSystem;
import org.apache.poi.poifs.filesystem.POIFSFileSystem;
import org.apache.poi.util.BitField;
import org.apache.poi.util.BitFieldFactory;
import org.apache.poi.util.LittleEndianInput;

public class EncryptionInfo implements Cloneable {
    public static final BitField flagAES = BitFieldFactory.getInstance(32);
    public static final BitField flagCryptoAPI = BitFieldFactory.getInstance(4);
    public static final BitField flagDocProps = BitFieldFactory.getInstance(8);
    public static final BitField flagExternal = BitFieldFactory.getInstance(16);
    public Decryptor decryptor;
    public final int encryptionFlags;
    public final EncryptionMode encryptionMode;
    public Encryptor encryptor;
    public EncryptionHeader header;
    public EncryptionVerifier verifier;
    public final int versionMajor;
    public final int versionMinor;

    public EncryptionInfo(POIFSFileSystem pOIFSFileSystem) {
        this(pOIFSFileSystem.getRoot());
    }

    public static EncryptionInfoBuilder getBuilder(EncryptionMode encryptionMode2) {
        return (EncryptionInfoBuilder) Thread.currentThread().getContextClassLoader().loadClass(encryptionMode2.builder).newInstance();
    }

    public Decryptor getDecryptor() {
        return this.decryptor;
    }

    public int getEncryptionFlags() {
        return this.encryptionFlags;
    }

    public EncryptionMode getEncryptionMode() {
        return this.encryptionMode;
    }

    public Encryptor getEncryptor() {
        return this.encryptor;
    }

    public EncryptionHeader getHeader() {
        return this.header;
    }

    public EncryptionVerifier getVerifier() {
        return this.verifier;
    }

    public int getVersionMajor() {
        return this.versionMajor;
    }

    public int getVersionMinor() {
        return this.versionMinor;
    }

    public boolean isDocPropsEncrypted() {
        return !flagDocProps.isSet(getEncryptionFlags());
    }

    public void setDecryptor(Decryptor decryptor2) {
        this.decryptor = decryptor2;
    }

    public void setEncryptor(Encryptor encryptor2) {
        this.encryptor = encryptor2;
    }

    public void setHeader(EncryptionHeader encryptionHeader) {
        this.header = encryptionHeader;
    }

    public void setVerifier(EncryptionVerifier encryptionVerifier) {
        this.verifier = encryptionVerifier;
    }

    public EncryptionInfo(OPOIFSFileSystem oPOIFSFileSystem) {
        this(oPOIFSFileSystem.getRoot());
    }

    @Override // java.lang.Object
    public EncryptionInfo clone() {
        EncryptionInfo encryptionInfo = (EncryptionInfo) super.clone();
        encryptionInfo.header = this.header.clone();
        encryptionInfo.verifier = this.verifier.clone();
        Decryptor clone = this.decryptor.clone();
        encryptionInfo.decryptor = clone;
        clone.setEncryptionInfo(encryptionInfo);
        Encryptor clone2 = this.encryptor.clone();
        encryptionInfo.encryptor = clone2;
        clone2.setEncryptionInfo(encryptionInfo);
        return encryptionInfo;
    }

    public EncryptionInfo(NPOIFSFileSystem nPOIFSFileSystem) {
        this(nPOIFSFileSystem.getRoot());
    }

    public EncryptionInfo(DirectoryNode directoryNode) {
        this(directoryNode.createDocumentInputStream("EncryptionInfo"), null);
    }

    public EncryptionInfo(LittleEndianInput littleEndianInput, EncryptionMode encryptionMode2) {
        EncryptionMode encryptionMode3 = EncryptionMode.xor;
        if (encryptionMode2 == encryptionMode3) {
            this.versionMajor = encryptionMode3.versionMajor;
            this.versionMinor = encryptionMode3.versionMinor;
        } else {
            this.versionMajor = littleEndianInput.readUShort();
            this.versionMinor = littleEndianInput.readUShort();
        }
        int i2 = this.versionMajor;
        EncryptionMode encryptionMode4 = EncryptionMode.xor;
        if (i2 == encryptionMode4.versionMajor && this.versionMinor == encryptionMode4.versionMinor) {
            this.encryptionMode = encryptionMode4;
            this.encryptionFlags = -1;
        } else {
            int i3 = this.versionMajor;
            EncryptionMode encryptionMode5 = EncryptionMode.binaryRC4;
            if (i3 == encryptionMode5.versionMajor && this.versionMinor == encryptionMode5.versionMinor) {
                this.encryptionMode = encryptionMode5;
                this.encryptionFlags = -1;
            } else {
                int i4 = this.versionMajor;
                if (2 > i4 || i4 > 4 || this.versionMinor != 2) {
                    int i5 = this.versionMajor;
                    EncryptionMode encryptionMode6 = EncryptionMode.agile;
                    if (i5 == encryptionMode6.versionMajor && this.versionMinor == encryptionMode6.versionMinor) {
                        this.encryptionMode = encryptionMode6;
                        this.encryptionFlags = littleEndianInput.readInt();
                    } else {
                        this.encryptionFlags = littleEndianInput.readInt();
                        StringBuilder b2 = a.b("Unknown encryption: version major: ");
                        b2.append(this.versionMajor);
                        b2.append(" / version minor: ");
                        b2.append(this.versionMinor);
                        b2.append(" / fCrypto: ");
                        b2.append(flagCryptoAPI.isSet(this.encryptionFlags));
                        b2.append(" / fExternal: ");
                        b2.append(flagExternal.isSet(this.encryptionFlags));
                        b2.append(" / fDocProps: ");
                        b2.append(flagDocProps.isSet(this.encryptionFlags));
                        b2.append(" / fAES: ");
                        b2.append(flagAES.isSet(this.encryptionFlags));
                        throw new EncryptedDocumentException(b2.toString());
                    }
                } else {
                    int readInt = littleEndianInput.readInt();
                    this.encryptionFlags = readInt;
                    this.encryptionMode = (encryptionMode2 == EncryptionMode.cryptoAPI || !flagAES.isSet(readInt)) ? EncryptionMode.cryptoAPI : EncryptionMode.standard;
                }
            }
        }
        try {
            getBuilder(this.encryptionMode).initialize(this, littleEndianInput);
        } catch (Exception e2) {
            throw new IOException(e2);
        }
    }

    public EncryptionInfo(EncryptionMode encryptionMode2) {
        this(encryptionMode2, null, null, -1, -1, null);
    }

    public EncryptionInfo(EncryptionMode encryptionMode2, CipherAlgorithm cipherAlgorithm, HashAlgorithm hashAlgorithm, int i2, int i3, ChainingMode chainingMode) {
        this.encryptionMode = encryptionMode2;
        this.versionMajor = encryptionMode2.versionMajor;
        this.versionMinor = encryptionMode2.versionMinor;
        this.encryptionFlags = encryptionMode2.encryptionFlags;
        try {
            getBuilder(encryptionMode2).initialize(this, cipherAlgorithm, hashAlgorithm, i2, i3, chainingMode);
        } catch (Exception e2) {
            throw new EncryptedDocumentException(e2);
        }
    }
}
