package org.apache.poi.poifs.crypt;

import org.apache.poi.util.Removal;

public abstract class EncryptionVerifier implements Cloneable {
    public ChainingMode chainingMode;
    public CipherAlgorithm cipherAlgorithm;
    public byte[] encryptedKey;
    public byte[] encryptedVerifier;
    public byte[] encryptedVerifierHash;
    public HashAlgorithm hashAlgorithm;
    public byte[] salt;
    public int spinCount;

    public int getAlgorithm() {
        return this.cipherAlgorithm.ecmaId;
    }

    public ChainingMode getChainingMode() {
        return this.chainingMode;
    }

    public CipherAlgorithm getCipherAlgorithm() {
        return this.cipherAlgorithm;
    }

    @Removal(version = "3.18")
    public int getCipherMode() {
        return this.chainingMode.ecmaId;
    }

    public byte[] getEncryptedKey() {
        return this.encryptedKey;
    }

    public byte[] getEncryptedVerifier() {
        return this.encryptedVerifier;
    }

    public byte[] getEncryptedVerifierHash() {
        return this.encryptedVerifierHash;
    }

    public HashAlgorithm getHashAlgorithm() {
        return this.hashAlgorithm;
    }

    public byte[] getSalt() {
        return this.salt;
    }

    public int getSpinCount() {
        return this.spinCount;
    }

    public void setChainingMode(ChainingMode chainingMode2) {
        this.chainingMode = chainingMode2;
    }

    public void setCipherAlgorithm(CipherAlgorithm cipherAlgorithm2) {
        this.cipherAlgorithm = cipherAlgorithm2;
    }

    public void setEncryptedKey(byte[] bArr) {
        this.encryptedKey = bArr == null ? null : (byte[]) bArr.clone();
    }

    public void setEncryptedVerifier(byte[] bArr) {
        this.encryptedVerifier = bArr == null ? null : (byte[]) bArr.clone();
    }

    public void setEncryptedVerifierHash(byte[] bArr) {
        this.encryptedVerifierHash = bArr == null ? null : (byte[]) bArr.clone();
    }

    public void setHashAlgorithm(HashAlgorithm hashAlgorithm2) {
        this.hashAlgorithm = hashAlgorithm2;
    }

    public void setSalt(byte[] bArr) {
        this.salt = bArr == null ? null : (byte[]) bArr.clone();
    }

    public void setSpinCount(int i2) {
        this.spinCount = i2;
    }

    @Override // java.lang.Object
    public EncryptionVerifier clone() {
        EncryptionVerifier encryptionVerifier = (EncryptionVerifier) super.clone();
        byte[] bArr = this.salt;
        byte[] bArr2 = null;
        encryptionVerifier.salt = bArr == null ? null : (byte[]) bArr.clone();
        byte[] bArr3 = this.encryptedVerifier;
        encryptionVerifier.encryptedVerifier = bArr3 == null ? null : (byte[]) bArr3.clone();
        byte[] bArr4 = this.encryptedVerifierHash;
        encryptionVerifier.encryptedVerifierHash = bArr4 == null ? null : (byte[]) bArr4.clone();
        byte[] bArr5 = this.encryptedKey;
        if (bArr5 != null) {
            bArr2 = (byte[]) bArr5.clone();
        }
        encryptionVerifier.encryptedKey = bArr2;
        return encryptionVerifier;
    }
}
