package org.apache.poi.poifs.crypt.cryptoapi;

import java.io.ByteArrayInputStream;
import javax.crypto.Cipher;
import javax.crypto.ShortBufferException;
import org.apache.poi.EncryptedDocumentException;
import org.apache.poi.util.Internal;

@Internal
public class CryptoAPIDocumentInputStream extends ByteArrayInputStream {
    public Cipher cipher;
    public final CryptoAPIDecryptor decryptor;
    public byte[] oneByte = {0};

    public CryptoAPIDocumentInputStream(CryptoAPIDecryptor cryptoAPIDecryptor, byte[] bArr) {
        super(bArr);
        this.decryptor = cryptoAPIDecryptor;
        this.cipher = cryptoAPIDecryptor.initCipherForBlock(null, 0);
    }

    @Override // java.io.InputStream
    public synchronized int read() {
        int read = super.read();
        if (read == -1) {
            return -1;
        }
        this.oneByte[0] = (byte) read;
        try {
            this.cipher.update(this.oneByte, 0, 1, this.oneByte);
            return this.oneByte[0];
        } catch (ShortBufferException e2) {
            throw new EncryptedDocumentException(e2);
        }
    }

    public void seek(int i2) {
        if (i2 <= ((ByteArrayInputStream) this).count) {
            ((ByteArrayInputStream) this).pos = i2;
            ((ByteArrayInputStream) this).mark = i2;
            return;
        }
        throw new ArrayIndexOutOfBoundsException(i2);
    }

    public void setBlock(int i2) {
        this.cipher = this.decryptor.initCipherForBlock(this.cipher, i2);
    }

    @Override // java.io.InputStream
    public synchronized int read(byte[] bArr, int i2, int i3) {
        int read = super.read(bArr, i2, i3);
        if (read == -1) {
            return -1;
        }
        try {
            this.cipher.update(bArr, i2, read, bArr, i2);
            return read;
        } catch (ShortBufferException e2) {
            throw new EncryptedDocumentException(e2);
        }
    }
}
