package org.apache.poi.poifs.crypt.cryptoapi;

import java.io.ByteArrayInputStream;
import java.io.File;
import java.io.IOException;
import java.io.OutputStream;
import java.security.GeneralSecurityException;
import java.security.SecureRandom;
import java.util.ArrayList;
import java.util.Iterator;
import javax.crypto.Cipher;
import org.apache.poi.EncryptedDocumentException;
import org.apache.poi.poifs.crypt.ChunkedCipherOutputStream;
import org.apache.poi.poifs.crypt.CryptoFunctions;
import org.apache.poi.poifs.crypt.DataSpaceMapUtils;
import org.apache.poi.poifs.crypt.EncryptionInfo;
import org.apache.poi.poifs.crypt.Encryptor;
import org.apache.poi.poifs.crypt.cryptoapi.CryptoAPIDecryptor;
import org.apache.poi.poifs.crypt.standard.EncryptionRecord;
import org.apache.poi.poifs.filesystem.DirectoryNode;
import org.apache.poi.poifs.filesystem.DocumentInputStream;
import org.apache.poi.poifs.filesystem.Entry;
import org.apache.poi.poifs.filesystem.NPOIFSFileSystem;
import org.apache.poi.util.IOUtils;
import org.apache.poi.util.LittleEndian;
import org.apache.poi.util.LittleEndianByteArrayOutputStream;
import org.apache.poi.util.StringUtil;

public class CryptoAPIEncryptor extends Encryptor implements Cloneable {
    public static final /* synthetic */ boolean $assertionsDisabled = false;
    public int chunkSize = 512;

    public class CryptoAPICipherOutputStream extends ChunkedCipherOutputStream {
        public CryptoAPICipherOutputStream(OutputStream outputStream) {
            super(outputStream, CryptoAPIEncryptor.this.chunkSize);
        }

        @Override // org.apache.poi.poifs.crypt.ChunkedCipherOutputStream
        public void calculateChecksum(File file, int i2) {
        }

        @Override // org.apache.poi.poifs.crypt.ChunkedCipherOutputStream
        public void createEncryptionInfoEntry(DirectoryNode directoryNode, File file) {
            throw new EncryptedDocumentException("createEncryptionInfoEntry not supported");
        }

        @Override // java.io.OutputStream, java.io.FilterOutputStream, java.io.Flushable
        public void flush() {
            writeChunk(false);
            super.flush();
        }

        @Override // org.apache.poi.poifs.crypt.ChunkedCipherOutputStream
        public Cipher initCipherForBlock(Cipher cipher, int i2, boolean z) {
            flush();
            return CryptoAPIDecryptor.initCipherForBlock(cipher, i2, CryptoAPIEncryptor.this.getEncryptionInfo(), CryptoAPIEncryptor.this.getSecretKey(), 1);
        }
    }

    @Override // org.apache.poi.poifs.crypt.Encryptor
    public void confirmPassword(String str) {
        SecureRandom secureRandom = new SecureRandom();
        byte[] bArr = new byte[16];
        byte[] bArr2 = new byte[16];
        secureRandom.nextBytes(bArr);
        secureRandom.nextBytes(bArr2);
        confirmPassword(str, null, null, bArr2, bArr, null);
    }

    public void createEncryptionInfoEntry(DirectoryNode directoryNode) {
        DataSpaceMapUtils.addDefaultDataSpace(directoryNode);
        final EncryptionInfo encryptionInfo = getEncryptionInfo();
        final CryptoAPIEncryptionHeader cryptoAPIEncryptionHeader = (CryptoAPIEncryptionHeader) getEncryptionInfo().getHeader();
        final CryptoAPIEncryptionVerifier cryptoAPIEncryptionVerifier = (CryptoAPIEncryptionVerifier) getEncryptionInfo().getVerifier();
        DataSpaceMapUtils.createEncryptionEntry(directoryNode, "EncryptionInfo", new EncryptionRecord() {
            /* class org.apache.poi.poifs.crypt.cryptoapi.CryptoAPIEncryptor.AnonymousClass1 */

            @Override // org.apache.poi.poifs.crypt.standard.EncryptionRecord
            public void write(LittleEndianByteArrayOutputStream littleEndianByteArrayOutputStream) {
                littleEndianByteArrayOutputStream.writeShort(encryptionInfo.getVersionMajor());
                littleEndianByteArrayOutputStream.writeShort(encryptionInfo.getVersionMinor());
                cryptoAPIEncryptionHeader.write(littleEndianByteArrayOutputStream);
                cryptoAPIEncryptionVerifier.write(littleEndianByteArrayOutputStream);
            }
        });
    }

    public int getKeySizeInBytes() {
        return getEncryptionInfo().getHeader().getKeySize() / 8;
    }

    public Cipher initCipherForBlock(Cipher cipher, int i2) {
        return CryptoAPIDecryptor.initCipherForBlock(cipher, i2, getEncryptionInfo(), getSecretKey(), 1);
    }

    @Override // org.apache.poi.poifs.crypt.Encryptor
    public void setChunkSize(int i2) {
        this.chunkSize = i2;
    }

    public void setSummaryEntries(DirectoryNode directoryNode, String str, NPOIFSFileSystem nPOIFSFileSystem) {
        CryptoAPIDocumentOutputStream cryptoAPIDocumentOutputStream = new CryptoAPIDocumentOutputStream(this);
        byte[] bArr = new byte[8];
        cryptoAPIDocumentOutputStream.write(bArr, 0, 8);
        ArrayList arrayList = new ArrayList();
        Iterator<Entry> it = nPOIFSFileSystem.getRoot().iterator();
        int i2 = 0;
        while (it.hasNext()) {
            Entry next = it.next();
            if (!next.isDirectoryEntry()) {
                CryptoAPIDecryptor.StreamDescriptorEntry streamDescriptorEntry = new CryptoAPIDecryptor.StreamDescriptorEntry();
                streamDescriptorEntry.block = i2;
                streamDescriptorEntry.streamOffset = cryptoAPIDocumentOutputStream.size();
                streamDescriptorEntry.streamName = next.getName();
                streamDescriptorEntry.flags = CryptoAPIDecryptor.StreamDescriptorEntry.flagStream.setValue(0, 1);
                streamDescriptorEntry.reserved2 = 0;
                cryptoAPIDocumentOutputStream.setBlock(i2);
                DocumentInputStream createDocumentInputStream = directoryNode.createDocumentInputStream(next);
                IOUtils.copy(createDocumentInputStream, cryptoAPIDocumentOutputStream);
                createDocumentInputStream.close();
                streamDescriptorEntry.streamSize = cryptoAPIDocumentOutputStream.size() - streamDescriptorEntry.streamOffset;
                arrayList.add(streamDescriptorEntry);
                i2++;
            }
        }
        int size = cryptoAPIDocumentOutputStream.size();
        cryptoAPIDocumentOutputStream.setBlock(0);
        LittleEndian.putUInt(bArr, 0, (long) arrayList.size());
        cryptoAPIDocumentOutputStream.write(bArr, 0, 4);
        Iterator it2 = arrayList.iterator();
        while (it2.hasNext()) {
            CryptoAPIDecryptor.StreamDescriptorEntry streamDescriptorEntry2 = (CryptoAPIDecryptor.StreamDescriptorEntry) it2.next();
            LittleEndian.putUInt(bArr, 0, (long) streamDescriptorEntry2.streamOffset);
            cryptoAPIDocumentOutputStream.write(bArr, 0, 4);
            LittleEndian.putUInt(bArr, 0, (long) streamDescriptorEntry2.streamSize);
            cryptoAPIDocumentOutputStream.write(bArr, 0, 4);
            LittleEndian.putUShort(bArr, 0, streamDescriptorEntry2.block);
            cryptoAPIDocumentOutputStream.write(bArr, 0, 2);
            LittleEndian.putUByte(bArr, 0, (short) streamDescriptorEntry2.streamName.length());
            cryptoAPIDocumentOutputStream.write(bArr, 0, 1);
            LittleEndian.putUByte(bArr, 0, (short) streamDescriptorEntry2.flags);
            cryptoAPIDocumentOutputStream.write(bArr, 0, 1);
            LittleEndian.putUInt(bArr, 0, (long) streamDescriptorEntry2.reserved2);
            cryptoAPIDocumentOutputStream.write(bArr, 0, 4);
            byte[] toUnicodeLE = StringUtil.getToUnicodeLE(streamDescriptorEntry2.streamName);
            cryptoAPIDocumentOutputStream.write(toUnicodeLE, 0, toUnicodeLE.length);
            LittleEndian.putShort(bArr, 0, 0);
            cryptoAPIDocumentOutputStream.write(bArr, 0, 2);
        }
        int size2 = cryptoAPIDocumentOutputStream.size();
        LittleEndian.putUInt(bArr, 0, (long) size);
        LittleEndian.putUInt(bArr, 4, (long) (size2 - size));
        cryptoAPIDocumentOutputStream.reset();
        cryptoAPIDocumentOutputStream.setBlock(0);
        cryptoAPIDocumentOutputStream.write(bArr, 0, 8);
        cryptoAPIDocumentOutputStream.setSize(size2);
        directoryNode.createDocument(str, new ByteArrayInputStream(cryptoAPIDocumentOutputStream.getBuf(), 0, size2));
    }

    @Override // org.apache.poi.poifs.crypt.Encryptor, org.apache.poi.poifs.crypt.Encryptor, java.lang.Object
    public CryptoAPIEncryptor clone() {
        return (CryptoAPIEncryptor) super.clone();
    }

    @Override // org.apache.poi.poifs.crypt.Encryptor
    public ChunkedCipherOutputStream getDataStream(DirectoryNode directoryNode) {
        throw new IOException("not supported");
    }

    @Override // org.apache.poi.poifs.crypt.Encryptor
    public CryptoAPICipherOutputStream getDataStream(OutputStream outputStream, int i2) {
        return new CryptoAPICipherOutputStream(outputStream);
    }

    @Override // org.apache.poi.poifs.crypt.Encryptor
    public void confirmPassword(String str, byte[] bArr, byte[] bArr2, byte[] bArr3, byte[] bArr4, byte[] bArr5) {
        CryptoAPIEncryptionVerifier cryptoAPIEncryptionVerifier = (CryptoAPIEncryptionVerifier) getEncryptionInfo().getVerifier();
        cryptoAPIEncryptionVerifier.setSalt(bArr4);
        setSecretKey(CryptoAPIDecryptor.generateSecretKey(str, cryptoAPIEncryptionVerifier));
        try {
            Cipher initCipherForBlock = initCipherForBlock(null, 0);
            byte[] bArr6 = new byte[bArr3.length];
            initCipherForBlock.update(bArr3, 0, bArr3.length, bArr6);
            cryptoAPIEncryptionVerifier.setEncryptedVerifier(bArr6);
            cryptoAPIEncryptionVerifier.setEncryptedVerifierHash(initCipherForBlock.doFinal(CryptoFunctions.getMessageDigest(cryptoAPIEncryptionVerifier.getHashAlgorithm()).digest(bArr3)));
        } catch (GeneralSecurityException e2) {
            throw new EncryptedDocumentException("Password confirmation failed", e2);
        }
    }
}
