package org.apache.poi.poifs.crypt.standard;

import java.io.InputStream;
import java.security.GeneralSecurityException;
import java.util.Arrays;
import javax.crypto.Cipher;
import javax.crypto.CipherInputStream;
import javax.crypto.SecretKey;
import javax.crypto.spec.SecretKeySpec;
import org.apache.poi.EncryptedDocumentException;
import org.apache.poi.poifs.crypt.CryptoFunctions;
import org.apache.poi.poifs.crypt.Decryptor;
import org.apache.poi.poifs.crypt.EncryptionHeader;
import org.apache.poi.poifs.crypt.EncryptionVerifier;
import org.apache.poi.poifs.crypt.HashAlgorithm;
import org.apache.poi.poifs.filesystem.DirectoryNode;
import org.apache.poi.poifs.filesystem.DocumentInputStream;
import org.apache.poi.util.BoundedInputStream;
import org.apache.poi.util.LittleEndian;

public class StandardDecryptor extends Decryptor implements Cloneable {
    public static final /* synthetic */ boolean $assertionsDisabled = false;
    public long _length = -1;

    public static byte[] fillAndXor(byte[] bArr, byte b2) {
        byte[] bArr2 = new byte[64];
        Arrays.fill(bArr2, b2);
        for (int i2 = 0; i2 < bArr.length; i2++) {
            bArr2[i2] = (byte) (bArr2[i2] ^ bArr[i2]);
        }
        return CryptoFunctions.getMessageDigest(HashAlgorithm.sha1).digest(bArr2);
    }

    public static SecretKey generateSecretKey(String str, EncryptionVerifier encryptionVerifier, int i2) {
        HashAlgorithm hashAlgorithm = encryptionVerifier.getHashAlgorithm();
        byte[] hashPassword = CryptoFunctions.hashPassword(str, hashAlgorithm, encryptionVerifier.getSalt(), encryptionVerifier.getSpinCount());
        byte[] bArr = new byte[4];
        LittleEndian.putInt(bArr, 0, 0);
        byte[] generateKey = CryptoFunctions.generateKey(hashPassword, hashAlgorithm, bArr, hashAlgorithm.hashSize);
        byte[] fillAndXor = fillAndXor(generateKey, (byte) 54);
        byte[] fillAndXor2 = fillAndXor(generateKey, (byte) 92);
        byte[] bArr2 = new byte[(fillAndXor.length + fillAndXor2.length)];
        System.arraycopy(fillAndXor, 0, bArr2, 0, fillAndXor.length);
        System.arraycopy(fillAndXor2, 0, bArr2, fillAndXor.length, fillAndXor2.length);
        return new SecretKeySpec(Arrays.copyOf(bArr2, i2), encryptionVerifier.getCipherAlgorithm().jceId);
    }

    private Cipher getCipher(SecretKey secretKey) {
        EncryptionHeader header = getEncryptionInfo().getHeader();
        return CryptoFunctions.getCipher(secretKey, header.getCipherAlgorithm(), header.getChainingMode(), null, 2);
    }

    @Override // org.apache.poi.poifs.crypt.Decryptor
    public InputStream getDataStream(DirectoryNode directoryNode) {
        DocumentInputStream createDocumentInputStream = directoryNode.createDocumentInputStream("EncryptedPackage");
        this._length = createDocumentInputStream.readLong();
        if (getSecretKey() == null) {
            verifyPassword(null);
        }
        long j = (long) getEncryptionInfo().getHeader().getCipherAlgorithm().blockSize;
        return new BoundedInputStream(new CipherInputStream(new BoundedInputStream(createDocumentInputStream, ((this._length / j) + 1) * j), getCipher(getSecretKey())), this._length);
    }

    @Override // org.apache.poi.poifs.crypt.Decryptor
    public long getLength() {
        long j = this._length;
        if (j != -1) {
            return j;
        }
        throw new IllegalStateException("Decryptor.getDataStream() was not called");
    }

    @Override // org.apache.poi.poifs.crypt.Decryptor
    public boolean verifyPassword(String str) {
        EncryptionVerifier verifier = getEncryptionInfo().getVerifier();
        SecretKey generateSecretKey = generateSecretKey(str, verifier, getKeySizeInBytes());
        Cipher cipher = getCipher(generateSecretKey);
        try {
            byte[] doFinal = cipher.doFinal(verifier.getEncryptedVerifier());
            setVerifier(doFinal);
            byte[] digest = CryptoFunctions.getMessageDigest(verifier.getHashAlgorithm()).digest(doFinal);
            if (!Arrays.equals(digest, Arrays.copyOf(cipher.doFinal(verifier.getEncryptedVerifierHash()), digest.length))) {
                return false;
            }
            setSecretKey(generateSecretKey);
            return true;
        } catch (GeneralSecurityException e2) {
            throw new EncryptedDocumentException(e2);
        }
    }

    @Override // org.apache.poi.poifs.crypt.Decryptor, org.apache.poi.poifs.crypt.Decryptor, java.lang.Object
    public StandardDecryptor clone() {
        return (StandardDecryptor) super.clone();
    }
}
