package org.apache.poi.poifs.crypt.standard;

import org.apache.poi.EncryptedDocumentException;
import org.apache.poi.poifs.crypt.ChainingMode;
import org.apache.poi.poifs.crypt.CipherAlgorithm;
import org.apache.poi.poifs.crypt.Decryptor;
import org.apache.poi.poifs.crypt.EncryptionInfo;
import org.apache.poi.poifs.crypt.EncryptionInfoBuilder;
import org.apache.poi.poifs.crypt.HashAlgorithm;
import org.apache.poi.util.LittleEndianInput;

public class StandardEncryptionInfoBuilder implements EncryptionInfoBuilder {
    @Override // org.apache.poi.poifs.crypt.EncryptionInfoBuilder
    public void initialize(EncryptionInfo encryptionInfo, LittleEndianInput littleEndianInput) {
        littleEndianInput.readInt();
        StandardEncryptionHeader standardEncryptionHeader = new StandardEncryptionHeader(littleEndianInput);
        encryptionInfo.setHeader(standardEncryptionHeader);
        encryptionInfo.setVerifier(new StandardEncryptionVerifier(littleEndianInput, standardEncryptionHeader));
        if (encryptionInfo.getVersionMinor() != 2) {
            return;
        }
        if (encryptionInfo.getVersionMajor() == 3 || encryptionInfo.getVersionMajor() == 4) {
            Decryptor standardDecryptor = new StandardDecryptor();
            standardDecryptor.setEncryptionInfo(encryptionInfo);
            encryptionInfo.setDecryptor(standardDecryptor);
        }
    }

    @Override // org.apache.poi.poifs.crypt.EncryptionInfoBuilder
    public void initialize(EncryptionInfo encryptionInfo, CipherAlgorithm cipherAlgorithm, HashAlgorithm hashAlgorithm, int i2, int i3, ChainingMode chainingMode) {
        if (cipherAlgorithm == null) {
            cipherAlgorithm = CipherAlgorithm.aes128;
        }
        if (cipherAlgorithm == CipherAlgorithm.aes128 || cipherAlgorithm == CipherAlgorithm.aes192 || cipherAlgorithm == CipherAlgorithm.aes256) {
            if (hashAlgorithm == null) {
                hashAlgorithm = HashAlgorithm.sha1;
            }
            if (hashAlgorithm == HashAlgorithm.sha1) {
                if (chainingMode == null) {
                    chainingMode = ChainingMode.ecb;
                }
                if (chainingMode == ChainingMode.ecb) {
                    if (i2 == -1) {
                        i2 = cipherAlgorithm.defaultKeySize;
                    }
                    if (i3 == -1) {
                        i3 = cipherAlgorithm.blockSize;
                    }
                    int[] iArr = cipherAlgorithm.allowedKeySize;
                    int length = iArr.length;
                    boolean z = false;
                    for (int i4 = 0; i4 < length; i4++) {
                        z |= iArr[i4] == i2;
                    }
                    if (z) {
                        encryptionInfo.setHeader(new StandardEncryptionHeader(cipherAlgorithm, hashAlgorithm, i2, i3, chainingMode));
                        encryptionInfo.setVerifier(new StandardEncryptionVerifier(cipherAlgorithm, hashAlgorithm, i2, i3, chainingMode));
                        StandardDecryptor standardDecryptor = new StandardDecryptor();
                        standardDecryptor.setEncryptionInfo(encryptionInfo);
                        encryptionInfo.setDecryptor(standardDecryptor);
                        StandardEncryptor standardEncryptor = new StandardEncryptor();
                        standardEncryptor.setEncryptionInfo(encryptionInfo);
                        encryptionInfo.setEncryptor(standardEncryptor);
                        return;
                    }
                    throw new EncryptedDocumentException("KeySize " + i2 + " not allowed for Cipher " + cipherAlgorithm);
                }
                throw new EncryptedDocumentException("Standard encryption only supports ECB chaining.");
            }
            throw new EncryptedDocumentException("Standard encryption only supports SHA-1.");
        }
        throw new EncryptedDocumentException("Standard encryption only supports AES128/192/256.");
    }
}
