package org.apache.poi.poifs.crypt.xor;

import java.io.InputStream;
import javax.crypto.Cipher;
import javax.crypto.SecretKey;
import javax.crypto.spec.SecretKeySpec;
import org.apache.poi.EncryptedDocumentException;
import org.apache.poi.poifs.crypt.ChunkedCipherInputStream;
import org.apache.poi.poifs.crypt.CryptoFunctions;
import org.apache.poi.poifs.crypt.Decryptor;
import org.apache.poi.poifs.crypt.EncryptionInfo;
import org.apache.poi.poifs.filesystem.DirectoryNode;
import org.apache.poi.util.LittleEndian;

public class XORDecryptor extends Decryptor implements Cloneable {
    public int chunkSize = 512;
    public long length = -1;

    public class XORCipherInputStream extends ChunkedCipherInputStream {
        public final int initialOffset;
        public int recordEnd = 0;
        public int recordStart = 0;

        public XORCipherInputStream(InputStream inputStream, int i2) {
            super(inputStream, 2147483647L, XORDecryptor.this.chunkSize);
            this.initialOffset = i2;
        }

        private byte rotateLeft(byte b2, int i2) {
            int i3 = b2 & 255;
            return (byte) ((i3 >>> (8 - i2)) | (i3 << i2));
        }

        @Override // org.apache.poi.poifs.crypt.ChunkedCipherInputStream
        public Cipher initCipherForBlock(Cipher cipher, int i2) {
            return XORDecryptor.this.initCipherForBlock(cipher, i2);
        }

        @Override // org.apache.poi.poifs.crypt.ChunkedCipherInputStream
        public int invokeCipher(int i2, boolean z) {
            int pos = (int) getPos();
            byte[] encoded = XORDecryptor.this.getEncryptionInfo().getDecryptor().getSecretKey().getEncoded();
            byte[] chunk = getChunk();
            byte[] plain = getPlain();
            int chunkMask = getChunkMask() & pos;
            int i3 = (pos - this.recordStart) + this.initialOffset + this.recordEnd;
            int i4 = 0;
            while (pos + i4 < this.recordEnd && i4 < i2) {
                int i5 = chunkMask + i4;
                chunk[i5] = (byte) (rotateLeft(plain[i5], 3) ^ encoded[(i3 + i4) & 15]);
                i4++;
            }
            return i2;
        }

        @Override // org.apache.poi.poifs.crypt.ChunkedCipherInputStream
        public void setNextRecordSize(int i2) {
            int pos = (int) getPos();
            byte[] chunk = getChunk();
            int chunkMask = getChunkMask();
            this.recordStart = pos;
            this.recordEnd = pos + i2;
            invokeCipher(Math.min(i2, chunk.length - (pos & chunkMask)), true);
        }
    }

    public static Cipher initCipherForBlock(Cipher cipher, int i2, EncryptionInfo encryptionInfo, SecretKey secretKey, int i3) {
        return null;
    }

    @Override // org.apache.poi.poifs.crypt.Decryptor
    public long getLength() {
        long j = this.length;
        if (j != -1) {
            return j;
        }
        throw new IllegalStateException("Decryptor.getDataStream() was not called");
    }

    @Override // org.apache.poi.poifs.crypt.Decryptor
    public Cipher initCipherForBlock(Cipher cipher, int i2) {
        return null;
    }

    @Override // org.apache.poi.poifs.crypt.Decryptor
    public void setChunkSize(int i2) {
        this.chunkSize = i2;
    }

    @Override // org.apache.poi.poifs.crypt.Decryptor
    public boolean verifyPassword(String str) {
        XOREncryptionVerifier xOREncryptionVerifier = (XOREncryptionVerifier) getEncryptionInfo().getVerifier();
        int uShort = LittleEndian.getUShort(xOREncryptionVerifier.getEncryptedKey());
        int uShort2 = LittleEndian.getUShort(xOREncryptionVerifier.getEncryptedVerifier());
        int createXorKey1 = CryptoFunctions.createXorKey1(str);
        int createXorVerifier1 = CryptoFunctions.createXorVerifier1(str);
        if (uShort != createXorKey1 || uShort2 != createXorVerifier1) {
            return false;
        }
        setSecretKey(new SecretKeySpec(CryptoFunctions.createXorArray1(str), "XOR"));
        return true;
    }

    @Override // org.apache.poi.poifs.crypt.Decryptor
    public ChunkedCipherInputStream getDataStream(DirectoryNode directoryNode) {
        throw new EncryptedDocumentException("not supported");
    }

    @Override // org.apache.poi.poifs.crypt.Decryptor, org.apache.poi.poifs.crypt.Decryptor, java.lang.Object
    public XORDecryptor clone() {
        return (XORDecryptor) super.clone();
    }

    @Override // org.apache.poi.poifs.crypt.Decryptor
    public InputStream getDataStream(InputStream inputStream, int i2, int i3) {
        return new XORCipherInputStream(inputStream, i3);
    }
}
