package org.apache.poi.poifs.crypt.xor;

import java.io.File;
import java.io.OutputStream;
import java.util.BitSet;
import javax.crypto.Cipher;
import javax.crypto.spec.SecretKeySpec;
import org.apache.poi.poifs.crypt.ChunkedCipherOutputStream;
import org.apache.poi.poifs.crypt.CryptoFunctions;
import org.apache.poi.poifs.crypt.Encryptor;
import org.apache.poi.poifs.filesystem.DirectoryNode;
import org.apache.poi.util.LittleEndian;

public class XOREncryptor extends Encryptor implements Cloneable {
    @Override // org.apache.poi.poifs.crypt.Encryptor
    public void confirmPassword(String str) {
        int createXorKey1 = CryptoFunctions.createXorKey1(str);
        int createXorVerifier1 = CryptoFunctions.createXorVerifier1(str);
        byte[] createXorArray1 = CryptoFunctions.createXorArray1(str);
        byte[] bArr = new byte[2];
        XOREncryptionVerifier xOREncryptionVerifier = (XOREncryptionVerifier) getEncryptionInfo().getVerifier();
        LittleEndian.putUShort(bArr, 0, createXorKey1);
        xOREncryptionVerifier.setEncryptedKey(bArr);
        LittleEndian.putUShort(bArr, 0, createXorVerifier1);
        xOREncryptionVerifier.setEncryptedVerifier(bArr);
        setSecretKey(new SecretKeySpec(createXorArray1, "XOR"));
    }

    public void createEncryptionInfoEntry(DirectoryNode directoryNode) {
    }

    public int getKeySizeInBytes() {
        return -1;
    }

    @Override // org.apache.poi.poifs.crypt.Encryptor
    public void setChunkSize(int i2) {
    }

    @Override // org.apache.poi.poifs.crypt.Encryptor
    public OutputStream getDataStream(DirectoryNode directoryNode) {
        return new XORCipherOutputStream(directoryNode);
    }

    @Override // org.apache.poi.poifs.crypt.Encryptor, org.apache.poi.poifs.crypt.Encryptor, java.lang.Object
    public XOREncryptor clone() {
        return (XOREncryptor) super.clone();
    }

    @Override // org.apache.poi.poifs.crypt.Encryptor
    public XORCipherOutputStream getDataStream(OutputStream outputStream, int i2) {
        return new XORCipherOutputStream(outputStream, i2);
    }

    public class XORCipherOutputStream extends ChunkedCipherOutputStream {
        public int recordEnd = 0;
        public int recordStart = 0;

        public XORCipherOutputStream(OutputStream outputStream, int i2) {
            super(outputStream, -1);
        }

        private byte rotateLeft(byte b2, int i2) {
            int i3 = b2 & 255;
            return (byte) ((i3 >>> (8 - i2)) | (i3 << i2));
        }

        @Override // org.apache.poi.poifs.crypt.ChunkedCipherOutputStream
        public void calculateChecksum(File file, int i2) {
        }

        @Override // org.apache.poi.poifs.crypt.ChunkedCipherOutputStream
        public void createEncryptionInfoEntry(DirectoryNode directoryNode, File file) {
            XOREncryptor.this.createEncryptionInfoEntry(directoryNode);
        }

        @Override // java.io.OutputStream, java.io.FilterOutputStream, java.io.Flushable
        public void flush() {
            setNextRecordSize(0, true);
            super.flush();
        }

        @Override // org.apache.poi.poifs.crypt.ChunkedCipherOutputStream
        public Cipher initCipherForBlock(Cipher cipher, int i2, boolean z) {
            return XORDecryptor.initCipherForBlock(cipher, i2, XOREncryptor.this.getEncryptionInfo(), XOREncryptor.this.getSecretKey(), 1);
        }

        @Override // org.apache.poi.poifs.crypt.ChunkedCipherOutputStream
        public int invokeCipher(int i2, boolean z) {
            if (i2 == 0) {
                return 0;
            }
            int max = Math.max(i2 - (this.recordEnd - this.recordStart), 0);
            BitSet plainByteFlags = getPlainByteFlags();
            byte[] encoded = XOREncryptor.this.getEncryptionInfo().getEncryptor().getSecretKey().getEncoded();
            byte[] chunk = getChunk();
            byte[] bArr = plainByteFlags.isEmpty() ? null : (byte[]) chunk.clone();
            int i3 = (max - this.recordStart) + this.recordEnd;
            int i4 = max;
            while (i4 < i2) {
                chunk[i4] = rotateLeft((byte) (encoded[i3 & 15] ^ chunk[i4]), 5);
                i4++;
                i3++;
            }
            while (true) {
                int nextSetBit = plainByteFlags.nextSetBit(max);
                if (nextSetBit < 0 || nextSetBit >= i2) {
                    return i2;
                }
                chunk[nextSetBit] = bArr[nextSetBit];
                max = nextSetBit + 1;
            }
            return i2;
        }

        @Override // org.apache.poi.poifs.crypt.ChunkedCipherOutputStream
        public void setNextRecordSize(int i2, boolean z) {
            if (this.recordEnd > 0 && !z) {
                invokeCipher((int) getPos(), true);
            }
            int totalPos = ((int) getTotalPos()) + 4;
            this.recordStart = totalPos;
            this.recordEnd = totalPos + i2;
        }

        public XORCipherOutputStream(DirectoryNode directoryNode) {
            super(directoryNode, -1);
        }
    }

    @Override // org.apache.poi.poifs.crypt.Encryptor
    public void confirmPassword(String str, byte[] bArr, byte[] bArr2, byte[] bArr3, byte[] bArr4, byte[] bArr5) {
        confirmPassword(str);
    }
}
