package org.apache.poi.poifs.dev;

import b.b.a.a.a;
import java.io.FileInputStream;
import java.io.PrintStream;
import java.util.Iterator;
import org.apache.poi.poifs.common.POIFSBigBlockSize;
import org.apache.poi.poifs.property.DirectoryProperty;
import org.apache.poi.poifs.property.Property;
import org.apache.poi.poifs.property.PropertyTable;
import org.apache.poi.poifs.storage.BlockAllocationTableReader;
import org.apache.poi.poifs.storage.HeaderBlock;
import org.apache.poi.poifs.storage.ListManagedBlock;
import org.apache.poi.poifs.storage.RawDataBlockList;
import org.apache.poi.poifs.storage.SmallBlockTableReader;
import org.apache.poi.util.HexDump;
import org.apache.poi.util.IntList;
import org.apache.xmlbeans.impl.jam.internal.JamPrinter;

public class POIFSHeaderDumper {
    public static void displayBATReader(String str, BlockAllocationTableReader blockAllocationTableReader) {
        PrintStream printStream = System.out;
        printStream.println("Sectors, as referenced from the " + str + " FAT:");
        IntList entries = blockAllocationTableReader.getEntries();
        for (int i2 = 0; i2 < entries.size(); i2++) {
            int i3 = entries.get(i2);
            String num = Integer.toString(i3);
            if (i3 == -2) {
                num = "End Of Chain";
            } else if (i3 == -4) {
                num = "DI Fat Block";
            } else if (i3 == -3) {
                num = "Normal Fat Block";
            } else if (i3 == -1) {
                num = "Block Not Used (Free)";
            }
            PrintStream printStream2 = System.out;
            printStream2.println("  Block  # " + i2 + " -> " + num);
        }
        System.out.println("");
    }

    public static void displayHeader(HeaderBlock headerBlock) {
        System.out.println("Header Details:");
        PrintStream printStream = System.out;
        StringBuilder b2 = a.b(" Block size: ");
        b2.append(headerBlock.getBigBlockSize().getBigBlockSize());
        printStream.println(b2.toString());
        PrintStream printStream2 = System.out;
        StringBuilder b3 = a.b(" BAT (FAT) header blocks: ");
        b3.append(headerBlock.getBATArray().length);
        printStream2.println(b3.toString());
        PrintStream printStream3 = System.out;
        StringBuilder b4 = a.b(" BAT (FAT) block count: ");
        b4.append(headerBlock.getBATCount());
        printStream3.println(b4.toString());
        if (headerBlock.getBATCount() > 0) {
            PrintStream printStream4 = System.out;
            StringBuilder b5 = a.b(" BAT (FAT) block 1 at: ");
            b5.append(headerBlock.getBATArray()[0]);
            printStream4.println(b5.toString());
        }
        PrintStream printStream5 = System.out;
        StringBuilder b6 = a.b(" XBAT (FAT) block count: ");
        b6.append(headerBlock.getXBATCount());
        printStream5.println(b6.toString());
        PrintStream printStream6 = System.out;
        StringBuilder b7 = a.b(" XBAT (FAT) block 1 at: ");
        b7.append(headerBlock.getXBATIndex());
        printStream6.println(b7.toString());
        PrintStream printStream7 = System.out;
        StringBuilder b8 = a.b(" SBAT (MiniFAT) block count: ");
        b8.append(headerBlock.getSBATCount());
        printStream7.println(b8.toString());
        PrintStream printStream8 = System.out;
        StringBuilder b9 = a.b(" SBAT (MiniFAT) block 1 at: ");
        b9.append(headerBlock.getSBATStart());
        printStream8.println(b9.toString());
        PrintStream printStream9 = System.out;
        StringBuilder b10 = a.b(" Property table at: ");
        b10.append(headerBlock.getPropertyStart());
        printStream9.println(b10.toString());
        System.out.println("");
    }

    public static void displayProperties(DirectoryProperty directoryProperty, String str) {
        String b2 = a.b(str, JamPrinter.INDENT);
        PrintStream printStream = System.out;
        StringBuilder d2 = a.d(str, "-> ");
        d2.append(directoryProperty.getName());
        printStream.println(d2.toString());
        Iterator<Property> it = directoryProperty.iterator();
        while (it.hasNext()) {
            Property next = it.next();
            if (next instanceof DirectoryProperty) {
                displayProperties((DirectoryProperty) next, b2);
            } else {
                PrintStream printStream2 = System.out;
                StringBuilder d3 = a.d(b2, "=> ");
                d3.append(next.getName());
                printStream2.println(d3.toString());
                PrintStream printStream3 = System.out;
                StringBuilder d4 = a.d(b2, "   ");
                d4.append(next.getSize());
                d4.append(" bytes in ");
                printStream3.print(d4.toString());
                if (next.shouldUseSmallBlocks()) {
                    System.out.print("mini");
                } else {
                    System.out.print("main");
                }
                PrintStream printStream4 = System.out;
                StringBuilder b3 = a.b(" stream, starts at ");
                b3.append(next.getStartBlock());
                printStream4.println(b3.toString());
            }
        }
    }

    public static void displayPropertiesSummary(PropertyTable propertyTable) {
        PrintStream printStream = System.out;
        StringBuilder b2 = a.b("Mini Stream starts at ");
        b2.append(propertyTable.getRoot().getStartBlock());
        printStream.println(b2.toString());
        PrintStream printStream2 = System.out;
        StringBuilder b3 = a.b("Mini Stream length is ");
        b3.append(propertyTable.getRoot().getSize());
        printStream2.println(b3.toString());
        System.out.println();
        System.out.println("Properties and their block start:");
        displayProperties(propertyTable.getRoot(), "");
        System.out.println("");
    }

    public static void displayRawBlocksSummary(RawDataBlockList rawDataBlockList) {
        System.out.println("Raw Blocks Details:");
        PrintStream printStream = System.out;
        StringBuilder b2 = a.b(" Number of blocks: ");
        b2.append(rawDataBlockList.blockCount());
        printStream.println(b2.toString());
        for (int i2 = 0; i2 < Math.min(16, rawDataBlockList.blockCount()); i2++) {
            ListManagedBlock listManagedBlock = rawDataBlockList.get(i2);
            int min = Math.min(48, listManagedBlock.getData().length);
            byte[] bArr = new byte[min];
            System.arraycopy(listManagedBlock.getData(), 0, bArr, 0, min);
            PrintStream printStream2 = System.out;
            printStream2.println(" Block #" + i2 + ":");
            System.out.println(HexDump.dump(bArr, 0, 0));
        }
        System.out.println("");
    }

    public static void main(String[] strArr) {
        if (strArr.length == 0) {
            System.err.println("Must specify at least one file to view");
            System.exit(1);
        }
        for (String str : strArr) {
            viewFile(str);
        }
    }

    public static void viewFile(String str) {
        PrintStream printStream = System.out;
        printStream.println("Dumping headers from: " + str);
        FileInputStream fileInputStream = new FileInputStream(str);
        HeaderBlock headerBlock = new HeaderBlock(fileInputStream);
        displayHeader(headerBlock);
        POIFSBigBlockSize bigBlockSize = headerBlock.getBigBlockSize();
        RawDataBlockList rawDataBlockList = new RawDataBlockList(fileInputStream, bigBlockSize);
        displayRawBlocksSummary(rawDataBlockList);
        displayBATReader("Big Blocks", new BlockAllocationTableReader(headerBlock.getBigBlockSize(), headerBlock.getBATCount(), headerBlock.getBATArray(), headerBlock.getXBATCount(), headerBlock.getXBATIndex(), rawDataBlockList));
        PropertyTable propertyTable = new PropertyTable(headerBlock, rawDataBlockList);
        displayBATReader("Small Blocks", SmallBlockTableReader._getSmallDocumentBlockReader(bigBlockSize, rawDataBlockList, propertyTable.getRoot(), headerBlock.getSBATStart()));
        displayPropertiesSummary(propertyTable);
    }
}
