package org.apache.poi.poifs.eventfilesystem;

import java.util.HashMap;
import java.util.HashSet;
import java.util.Iterator;
import java.util.Map;
import java.util.Set;
import org.apache.poi.poifs.filesystem.DocumentDescriptor;
import org.apache.poi.poifs.filesystem.POIFSDocumentPath;

public class POIFSReaderRegistry {
    public Map<DocumentDescriptor, Set<POIFSReaderListener>> chosenDocumentDescriptors = new HashMap();
    public Set<POIFSReaderListener> omnivorousListeners = new HashSet();
    public Map<POIFSReaderListener, Set<DocumentDescriptor>> selectiveListeners = new HashMap();

    private void dropDocument(POIFSReaderListener pOIFSReaderListener, DocumentDescriptor documentDescriptor) {
        Set<POIFSReaderListener> set = this.chosenDocumentDescriptors.get(documentDescriptor);
        set.remove(pOIFSReaderListener);
        if (set.size() == 0) {
            this.chosenDocumentDescriptors.remove(documentDescriptor);
        }
    }

    private void removeSelectiveListener(POIFSReaderListener pOIFSReaderListener) {
        Set<DocumentDescriptor> remove = this.selectiveListeners.remove(pOIFSReaderListener);
        if (remove != null) {
            for (DocumentDescriptor documentDescriptor : remove) {
                dropDocument(pOIFSReaderListener, documentDescriptor);
            }
        }
    }

    public Iterator<POIFSReaderListener> getListeners(POIFSDocumentPath pOIFSDocumentPath, String str) {
        HashSet hashSet = new HashSet(this.omnivorousListeners);
        Set<POIFSReaderListener> set = this.chosenDocumentDescriptors.get(new DocumentDescriptor(pOIFSDocumentPath, str));
        if (set != null) {
            hashSet.addAll(set);
        }
        return hashSet.iterator();
    }

    public void registerListener(POIFSReaderListener pOIFSReaderListener, POIFSDocumentPath pOIFSDocumentPath, String str) {
        if (!this.omnivorousListeners.contains(pOIFSReaderListener)) {
            Set<DocumentDescriptor> set = this.selectiveListeners.get(pOIFSReaderListener);
            if (set == null) {
                set = new HashSet<>();
                this.selectiveListeners.put(pOIFSReaderListener, set);
            }
            DocumentDescriptor documentDescriptor = new DocumentDescriptor(pOIFSDocumentPath, str);
            if (set.add(documentDescriptor)) {
                Set<POIFSReaderListener> set2 = this.chosenDocumentDescriptors.get(documentDescriptor);
                if (set2 == null) {
                    set2 = new HashSet<>();
                    this.chosenDocumentDescriptors.put(documentDescriptor, set2);
                }
                set2.add(pOIFSReaderListener);
            }
        }
    }

    public void registerListener(POIFSReaderListener pOIFSReaderListener) {
        if (!this.omnivorousListeners.contains(pOIFSReaderListener)) {
            removeSelectiveListener(pOIFSReaderListener);
            this.omnivorousListeners.add(pOIFSReaderListener);
        }
    }
}
