package org.apache.poi.poifs.filesystem;

import b.b.a.a.a;
import java.io.FileNotFoundException;
import java.io.IOException;
import java.io.InputStream;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.Iterator;
import java.util.Map;
import java.util.Set;
import org.apache.poi.hpsf.ClassID;
import org.apache.poi.poifs.dev.POIFSViewable;
import org.apache.poi.poifs.property.DirectoryProperty;
import org.apache.poi.poifs.property.DocumentProperty;
import org.apache.poi.poifs.property.Property;

public class DirectoryNode extends EntryNode implements DirectoryEntry, POIFSViewable, Iterable<Entry> {
    public Map<String, Entry> _byname;
    public ArrayList<Entry> _entries;
    public NPOIFSFileSystem _nfilesystem;
    public OPOIFSFileSystem _ofilesystem;
    public POIFSDocumentPath _path;

    public DirectoryNode(DirectoryProperty directoryProperty, OPOIFSFileSystem oPOIFSFileSystem, DirectoryNode directoryNode) {
        this(directoryProperty, directoryNode, oPOIFSFileSystem, null);
    }

    public boolean changeName(String str, String str2) {
        EntryNode entryNode = (EntryNode) this._byname.get(str);
        if (entryNode == null) {
            return false;
        }
        boolean changeName = ((DirectoryProperty) getProperty()).changeName(entryNode.getProperty(), str2);
        if (!changeName) {
            return changeName;
        }
        this._byname.remove(str);
        this._byname.put(entryNode.getProperty().getName(), entryNode);
        return changeName;
    }

    @Override // org.apache.poi.poifs.filesystem.DirectoryEntry
    public DirectoryEntry createDirectory(String str) {
        DirectoryNode directoryNode;
        DirectoryProperty directoryProperty = new DirectoryProperty(str);
        OPOIFSFileSystem oPOIFSFileSystem = this._ofilesystem;
        if (oPOIFSFileSystem != null) {
            directoryNode = new DirectoryNode(directoryProperty, oPOIFSFileSystem, this);
            this._ofilesystem.addDirectory(directoryProperty);
        } else {
            directoryNode = new DirectoryNode(directoryProperty, this._nfilesystem, this);
            this._nfilesystem.addDirectory(directoryProperty);
        }
        ((DirectoryProperty) getProperty()).addChild(directoryProperty);
        this._entries.add(directoryNode);
        this._byname.put(str, directoryNode);
        return directoryNode;
    }

    public DocumentEntry createDocument(OPOIFSDocument oPOIFSDocument) {
        DocumentProperty documentProperty = oPOIFSDocument.getDocumentProperty();
        DocumentNode documentNode = new DocumentNode(documentProperty, this);
        ((DirectoryProperty) getProperty()).addChild(documentProperty);
        this._ofilesystem.addDocument(oPOIFSDocument);
        this._entries.add(documentNode);
        this._byname.put(documentProperty.getName(), documentNode);
        return documentNode;
    }

    public DocumentInputStream createDocumentInputStream(String str) {
        return createDocumentInputStream(getEntry(str));
    }

    public DocumentEntry createOrUpdateDocument(String str, InputStream inputStream) {
        if (!hasEntry(str)) {
            return createDocument(str, inputStream);
        }
        DocumentNode documentNode = (DocumentNode) getEntry(str);
        if (this._nfilesystem != null) {
            new NPOIFSDocument(documentNode).replaceContents(inputStream);
            return documentNode;
        }
        deleteEntry(documentNode);
        return createDocument(str, inputStream);
    }

    public boolean deleteEntry(EntryNode entryNode) {
        boolean deleteChild = ((DirectoryProperty) getProperty()).deleteChild(entryNode.getProperty());
        if (deleteChild) {
            this._entries.remove(entryNode);
            this._byname.remove(entryNode.getName());
            OPOIFSFileSystem oPOIFSFileSystem = this._ofilesystem;
            if (oPOIFSFileSystem != null) {
                oPOIFSFileSystem.remove(entryNode);
            } else {
                try {
                    this._nfilesystem.remove(entryNode);
                } catch (IOException unused) {
                }
            }
        }
        return deleteChild;
    }

    @Override // org.apache.poi.poifs.filesystem.DirectoryEntry
    public Iterator<Entry> getEntries() {
        return this._entries.iterator();
    }

    @Override // org.apache.poi.poifs.filesystem.DirectoryEntry
    public Entry getEntry(String str) {
        Entry entry = str != null ? this._byname.get(str) : null;
        if (entry != null) {
            return entry;
        }
        StringBuilder d2 = a.d("no such entry: \"", str, "\", had: ");
        d2.append(this._byname.keySet());
        throw new FileNotFoundException(d2.toString());
    }

    @Override // org.apache.poi.poifs.filesystem.DirectoryEntry
    public int getEntryCount() {
        return this._entries.size();
    }

    @Override // org.apache.poi.poifs.filesystem.DirectoryEntry
    public Set<String> getEntryNames() {
        return this._byname.keySet();
    }

    public NPOIFSFileSystem getFileSystem() {
        return this._nfilesystem;
    }

    public NPOIFSFileSystem getNFileSystem() {
        return this._nfilesystem;
    }

    public OPOIFSFileSystem getOFileSystem() {
        return this._ofilesystem;
    }

    public POIFSDocumentPath getPath() {
        return this._path;
    }

    @Override // org.apache.poi.poifs.dev.POIFSViewable
    public String getShortDescription() {
        return getName();
    }

    @Override // org.apache.poi.poifs.filesystem.DirectoryEntry
    public ClassID getStorageClsid() {
        return getProperty().getStorageClsid();
    }

    @Override // org.apache.poi.poifs.dev.POIFSViewable
    public Object[] getViewableArray() {
        return new Object[0];
    }

    @Override // org.apache.poi.poifs.dev.POIFSViewable
    public Iterator<Object> getViewableIterator() {
        ArrayList arrayList = new ArrayList();
        arrayList.add(getProperty());
        Iterator<Entry> it = this._entries.iterator();
        while (it.hasNext()) {
            arrayList.add(it.next());
        }
        return arrayList.iterator();
    }

    @Override // org.apache.poi.poifs.filesystem.DirectoryEntry
    public boolean hasEntry(String str) {
        return str != null && this._byname.containsKey(str);
    }

    @Override // org.apache.poi.poifs.filesystem.EntryNode
    public boolean isDeleteOK() {
        return isEmpty();
    }

    @Override // org.apache.poi.poifs.filesystem.Entry, org.apache.poi.poifs.filesystem.EntryNode
    public boolean isDirectoryEntry() {
        return true;
    }

    @Override // org.apache.poi.poifs.filesystem.DirectoryEntry
    public boolean isEmpty() {
        return this._entries.isEmpty();
    }

    @Override // java.lang.Iterable
    public Iterator<Entry> iterator() {
        return getEntries();
    }

    @Override // org.apache.poi.poifs.dev.POIFSViewable
    public boolean preferArray() {
        return false;
    }

    @Override // org.apache.poi.poifs.filesystem.DirectoryEntry
    public void setStorageClsid(ClassID classID) {
        getProperty().setStorageClsid(classID);
    }

    public DirectoryNode(DirectoryProperty directoryProperty, NPOIFSFileSystem nPOIFSFileSystem, DirectoryNode directoryNode) {
        this(directoryProperty, directoryNode, null, nPOIFSFileSystem);
    }

    public DocumentInputStream createDocumentInputStream(Entry entry) {
        if (entry.isDocumentEntry()) {
            return new DocumentInputStream((DocumentEntry) entry);
        }
        StringBuilder b2 = a.b("Entry '");
        b2.append(entry.getName());
        b2.append("' is not a DocumentEntry");
        throw new IOException(b2.toString());
    }

    public DirectoryNode(DirectoryProperty directoryProperty, DirectoryNode directoryNode, OPOIFSFileSystem oPOIFSFileSystem, NPOIFSFileSystem nPOIFSFileSystem) {
        super(directoryProperty, directoryNode);
        Entry entry;
        this._ofilesystem = oPOIFSFileSystem;
        this._nfilesystem = nPOIFSFileSystem;
        if (directoryNode == null) {
            this._path = new POIFSDocumentPath();
        } else {
            this._path = new POIFSDocumentPath(directoryNode._path, new String[]{directoryProperty.getName()});
        }
        this._byname = new HashMap();
        this._entries = new ArrayList<>();
        Iterator<Property> children = directoryProperty.getChildren();
        while (children.hasNext()) {
            Property next = children.next();
            if (next.isDirectory()) {
                DirectoryProperty directoryProperty2 = (DirectoryProperty) next;
                OPOIFSFileSystem oPOIFSFileSystem2 = this._ofilesystem;
                if (oPOIFSFileSystem2 != null) {
                    entry = new DirectoryNode(directoryProperty2, oPOIFSFileSystem2, this);
                } else {
                    entry = new DirectoryNode(directoryProperty2, this._nfilesystem, this);
                }
            } else {
                entry = new DocumentNode((DocumentProperty) next, this);
            }
            this._entries.add(entry);
            this._byname.put(entry.getName(), entry);
        }
    }

    public DocumentEntry createDocument(NPOIFSDocument nPOIFSDocument) {
        DocumentProperty documentProperty = nPOIFSDocument.getDocumentProperty();
        DocumentNode documentNode = new DocumentNode(documentProperty, this);
        ((DirectoryProperty) getProperty()).addChild(documentProperty);
        this._nfilesystem.addDocument(nPOIFSDocument);
        this._entries.add(documentNode);
        this._byname.put(documentProperty.getName(), documentNode);
        return documentNode;
    }

    @Override // org.apache.poi.poifs.filesystem.DirectoryEntry
    public DocumentEntry createDocument(String str, InputStream inputStream) {
        NPOIFSFileSystem nPOIFSFileSystem = this._nfilesystem;
        if (nPOIFSFileSystem != null) {
            return createDocument(new NPOIFSDocument(str, nPOIFSFileSystem, inputStream));
        }
        return createDocument(new OPOIFSDocument(str, inputStream));
    }

    @Override // org.apache.poi.poifs.filesystem.DirectoryEntry
    public DocumentEntry createDocument(String str, int i2, POIFSWriterListener pOIFSWriterListener) {
        NPOIFSFileSystem nPOIFSFileSystem = this._nfilesystem;
        if (nPOIFSFileSystem != null) {
            return createDocument(new NPOIFSDocument(str, i2, nPOIFSFileSystem, pOIFSWriterListener));
        }
        return createDocument(new OPOIFSDocument(str, i2, this._path, pOIFSWriterListener));
    }
}
