package org.apache.poi.poifs.filesystem;

import java.io.IOException;
import java.io.InputStream;
import org.apache.poi.hpsf.Filetime;
import org.apache.poi.util.LittleEndianInput;
import org.apache.poi.util.SuppressForbidden;

public class DocumentInputStream extends InputStream implements LittleEndianInput {
    public static final int EOF = -1;
    public static final int SIZE_INT = 4;
    public static final int SIZE_LONG = 8;
    public static final int SIZE_SHORT = 2;
    public DocumentInputStream delegate;

    public DocumentInputStream() {
    }

    @Override // org.apache.poi.util.LittleEndianInput, java.io.InputStream
    @SuppressForbidden("just delegating")
    public int available() {
        return this.delegate.available();
    }

    @Override // java.io.Closeable, java.lang.AutoCloseable, java.io.InputStream
    public void close() {
        this.delegate.close();
    }

    public void mark(int i2) {
        this.delegate.mark(i2);
    }

    public boolean markSupported() {
        return true;
    }

    @Override // java.io.InputStream
    public int read() {
        return this.delegate.read();
    }

    @Override // org.apache.poi.util.LittleEndianInput
    public byte readByte() {
        return this.delegate.readByte();
    }

    @Override // org.apache.poi.util.LittleEndianInput
    public double readDouble() {
        return this.delegate.readDouble();
    }

    @Override // org.apache.poi.util.LittleEndianInput
    public void readFully(byte[] bArr) {
        readFully(bArr, 0, bArr.length);
    }

    @Override // org.apache.poi.util.LittleEndianInput
    public int readInt() {
        return this.delegate.readInt();
    }

    @Override // org.apache.poi.util.LittleEndianInput
    public long readLong() {
        return this.delegate.readLong();
    }

    @Override // org.apache.poi.util.LittleEndianInput
    public void readPlain(byte[] bArr, int i2, int i3) {
        readFully(bArr, i2, i3);
    }

    @Override // org.apache.poi.util.LittleEndianInput
    public short readShort() {
        return (short) readUShort();
    }

    @Override // org.apache.poi.util.LittleEndianInput
    public int readUByte() {
        return this.delegate.readUByte();
    }

    public long readUInt() {
        return ((long) readInt()) & Filetime.UINT_MASK;
    }

    @Override // org.apache.poi.util.LittleEndianInput
    public int readUShort() {
        return this.delegate.readUShort();
    }

    @Override // java.io.InputStream
    public void reset() {
        this.delegate.reset();
    }

    @Override // java.io.InputStream
    public long skip(long j) {
        return this.delegate.skip(j);
    }

    public DocumentInputStream(DocumentEntry documentEntry) {
        if (documentEntry instanceof DocumentNode) {
            DirectoryNode directoryNode = (DirectoryNode) documentEntry.getParent();
            if (((DocumentNode) documentEntry).getDocument() != null) {
                this.delegate = new ODocumentInputStream(documentEntry);
            } else if (directoryNode.getOFileSystem() != null) {
                this.delegate = new ODocumentInputStream(documentEntry);
            } else if (directoryNode.getNFileSystem() != null) {
                this.delegate = new NDocumentInputStream(documentEntry);
            } else {
                throw new IOException("No FileSystem bound on the parent, can't read contents");
            }
        } else {
            throw new IOException("Cannot open internal document storage");
        }
    }

    @Override // java.io.InputStream
    public int read(byte[] bArr) {
        return read(bArr, 0, bArr.length);
    }

    @Override // org.apache.poi.util.LittleEndianInput
    public void readFully(byte[] bArr, int i2, int i3) {
        this.delegate.readFully(bArr, i2, i3);
    }

    @Override // java.io.InputStream
    public int read(byte[] bArr, int i2, int i3) {
        return this.delegate.read(bArr, i2, i3);
    }

    public DocumentInputStream(OPOIFSDocument oPOIFSDocument) {
        this.delegate = new ODocumentInputStream(oPOIFSDocument);
    }

    public DocumentInputStream(NPOIFSDocument nPOIFSDocument) {
        this.delegate = new NDocumentInputStream(nPOIFSDocument);
    }
}
