package org.apache.poi.poifs.filesystem;

import b.b.a.a.a;
import java.io.IOException;
import java.nio.ByteBuffer;
import java.util.Iterator;
import org.apache.poi.poifs.property.DocumentProperty;
import org.apache.poi.util.LittleEndian;

public final class NDocumentInputStream extends DocumentInputStream {
    public ByteBuffer _buffer;
    public boolean _closed;
    public int _current_block_count;
    public int _current_offset;
    public Iterator<ByteBuffer> _data;
    public final NPOIFSDocument _document;
    public final int _document_size;
    public int _marked_offset;
    public int _marked_offset_count;

    public NDocumentInputStream(DocumentEntry documentEntry) {
        if (documentEntry instanceof DocumentNode) {
            this._current_offset = 0;
            this._current_block_count = 0;
            this._marked_offset = 0;
            this._marked_offset_count = 0;
            this._document_size = documentEntry.getSize();
            this._closed = false;
            DocumentNode documentNode = (DocumentNode) documentEntry;
            NPOIFSDocument nPOIFSDocument = new NPOIFSDocument((DocumentProperty) documentNode.getProperty(), ((DirectoryNode) documentNode.getParent()).getNFileSystem());
            this._document = nPOIFSDocument;
            this._data = nPOIFSDocument.getBlockIterator();
            return;
        }
        throw new IOException("Cannot open internal document storage, " + documentEntry + " not a Document Node");
    }

    private boolean atEOD() {
        return this._current_offset == this._document_size;
    }

    private void checkAvaliable(int i2) {
        if (this._closed) {
            throw new IllegalStateException("cannot perform requested operation on a closed stream");
        } else if (i2 > this._document_size - this._current_offset) {
            StringBuilder a = a.a("Buffer underrun - requested ", i2, " bytes but ");
            a.append(this._document_size - this._current_offset);
            a.append(" was available");
            throw new RuntimeException(a.toString());
        }
    }

    private void dieIfClosed() {
        if (this._closed) {
            throw new IOException("cannot perform requested operation on a closed stream");
        }
    }

    private int remainingBytes() {
        if (!this._closed) {
            return this._document_size - this._current_offset;
        }
        throw new IllegalStateException("cannot perform requested operation on a closed stream");
    }

    @Override // org.apache.poi.util.LittleEndianInput, org.apache.poi.poifs.filesystem.DocumentInputStream, java.io.InputStream
    public int available() {
        return remainingBytes();
    }

    @Override // java.io.Closeable, java.lang.AutoCloseable, org.apache.poi.poifs.filesystem.DocumentInputStream, java.io.InputStream
    public void close() {
        this._closed = true;
    }

    @Override // org.apache.poi.poifs.filesystem.DocumentInputStream
    public void mark(int i2) {
        this._marked_offset = this._current_offset;
        this._marked_offset_count = Math.max(0, this._current_block_count - 1);
    }

    @Override // org.apache.poi.poifs.filesystem.DocumentInputStream, java.io.InputStream
    public int read() {
        dieIfClosed();
        if (atEOD()) {
            return -1;
        }
        byte[] bArr = new byte[1];
        int read = read(bArr, 0, 1);
        if (read < 0) {
            return read;
        }
        if (bArr[0] < 0) {
            return bArr[0] + 256;
        }
        return bArr[0];
    }

    @Override // org.apache.poi.util.LittleEndianInput, org.apache.poi.poifs.filesystem.DocumentInputStream
    public byte readByte() {
        return (byte) readUByte();
    }

    @Override // org.apache.poi.util.LittleEndianInput, org.apache.poi.poifs.filesystem.DocumentInputStream
    public double readDouble() {
        return Double.longBitsToDouble(readLong());
    }

    @Override // org.apache.poi.util.LittleEndianInput, org.apache.poi.poifs.filesystem.DocumentInputStream
    public void readFully(byte[] bArr, int i2, int i3) {
        if (i3 >= 0) {
            checkAvaliable(i3);
            int i4 = 0;
            while (i4 < i3) {
                ByteBuffer byteBuffer = this._buffer;
                if (byteBuffer == null || byteBuffer.remaining() == 0) {
                    this._current_block_count++;
                    this._buffer = this._data.next();
                }
                int min = Math.min(i3 - i4, this._buffer.remaining());
                this._buffer.get(bArr, i2 + i4, min);
                this._current_offset += min;
                i4 += min;
            }
            return;
        }
        throw new RuntimeException("Can't read negative number of bytes");
    }

    @Override // org.apache.poi.util.LittleEndianInput, org.apache.poi.poifs.filesystem.DocumentInputStream
    public int readInt() {
        checkAvaliable(4);
        byte[] bArr = new byte[4];
        readFully(bArr, 0, 4);
        return LittleEndian.getInt(bArr);
    }

    @Override // org.apache.poi.util.LittleEndianInput, org.apache.poi.poifs.filesystem.DocumentInputStream
    public long readLong() {
        checkAvaliable(8);
        byte[] bArr = new byte[8];
        readFully(bArr, 0, 8);
        return LittleEndian.getLong(bArr, 0);
    }

    @Override // org.apache.poi.util.LittleEndianInput, org.apache.poi.poifs.filesystem.DocumentInputStream
    public short readShort() {
        checkAvaliable(2);
        byte[] bArr = new byte[2];
        readFully(bArr, 0, 2);
        return LittleEndian.getShort(bArr);
    }

    @Override // org.apache.poi.util.LittleEndianInput, org.apache.poi.poifs.filesystem.DocumentInputStream
    public int readUByte() {
        checkAvaliable(1);
        byte[] bArr = new byte[1];
        readFully(bArr, 0, 1);
        if (bArr[0] >= 0) {
            return bArr[0];
        }
        return bArr[0] + 256;
    }

    @Override // org.apache.poi.util.LittleEndianInput, org.apache.poi.poifs.filesystem.DocumentInputStream
    public int readUShort() {
        checkAvaliable(2);
        byte[] bArr = new byte[2];
        readFully(bArr, 0, 2);
        return LittleEndian.getUShort(bArr);
    }

    @Override // org.apache.poi.poifs.filesystem.DocumentInputStream, java.io.InputStream
    public void reset() {
        int i2;
        int i3;
        int i4 = this._marked_offset;
        if (i4 == 0 && (i3 = this._marked_offset_count) == 0) {
            this._current_block_count = i3;
            this._current_offset = i4;
            this._data = this._document.getBlockIterator();
            this._buffer = null;
            return;
        }
        this._data = this._document.getBlockIterator();
        int i5 = 0;
        this._current_offset = 0;
        while (true) {
            i2 = this._marked_offset_count;
            if (i5 >= i2) {
                break;
            }
            ByteBuffer next = this._data.next();
            this._buffer = next;
            this._current_offset = next.remaining() + this._current_offset;
            i5++;
        }
        this._current_block_count = i2;
        if (this._current_offset != this._marked_offset) {
            ByteBuffer next2 = this._data.next();
            this._buffer = next2;
            this._current_block_count++;
            next2.position(next2.position() + (this._marked_offset - this._current_offset));
        }
        this._current_offset = this._marked_offset;
    }

    /* JADX WARNING: Code restructure failed: missing block: B:8:0x001c, code lost:
        if (r1 > ((long) r6)) goto L_0x0015;
     */
    @Override // org.apache.poi.poifs.filesystem.DocumentInputStream, java.io.InputStream
    public long skip(long j) {
        int i2;
        dieIfClosed();
        if (j < 0) {
            return 0;
        }
        int i3 = this._current_offset;
        long j2 = ((long) i3) + j;
        if (j2 < ((long) i3)) {
            i2 = this._document_size;
        } else {
            i2 = this._document_size;
        }
        j2 = (long) i2;
        long j3 = j2 - ((long) this._current_offset);
        readFully(new byte[((int) j3)]);
        return j3;
    }

    @Override // org.apache.poi.poifs.filesystem.DocumentInputStream, java.io.InputStream
    public int read(byte[] bArr, int i2, int i3) {
        dieIfClosed();
        if (bArr == null) {
            throw new IllegalArgumentException("buffer must not be null");
        } else if (i2 < 0 || i3 < 0 || bArr.length < i2 + i3) {
            throw new IndexOutOfBoundsException("can't read past buffer boundaries");
        } else if (i3 == 0) {
            return 0;
        } else {
            if (atEOD()) {
                return -1;
            }
            int min = Math.min(remainingBytes(), i3);
            readFully(bArr, i2, min);
            return min;
        }
    }

    public NDocumentInputStream(NPOIFSDocument nPOIFSDocument) {
        this._current_offset = 0;
        this._current_block_count = 0;
        this._marked_offset = 0;
        this._marked_offset_count = 0;
        this._document_size = nPOIFSDocument.getSize();
        this._closed = false;
        this._document = nPOIFSDocument;
        this._data = nPOIFSDocument.getBlockIterator();
    }
}
