package org.apache.poi.poifs.filesystem;

import java.io.ByteArrayInputStream;
import java.io.ByteArrayOutputStream;
import java.io.IOException;
import java.io.OutputStream;
import org.apache.poi.poifs.property.DocumentProperty;

public final class NDocumentOutputStream extends OutputStream {
    public ByteArrayOutputStream _buffer = new ByteArrayOutputStream(4096);
    public boolean _closed;
    public NPOIFSDocument _document;
    public int _document_size;
    public DocumentProperty _property;
    public NPOIFSStream _stream;
    public OutputStream _stream_output;

    public NDocumentOutputStream(DocumentEntry documentEntry) {
        if (documentEntry instanceof DocumentNode) {
            this._document_size = 0;
            this._closed = false;
            DocumentNode documentNode = (DocumentNode) documentEntry;
            this._property = (DocumentProperty) documentNode.getProperty();
            NPOIFSDocument nPOIFSDocument = new NPOIFSDocument(documentNode);
            this._document = nPOIFSDocument;
            nPOIFSDocument.free();
            return;
        }
        throw new IOException("Cannot open internal document storage, " + documentEntry + " not a Document Node");
    }

    private void checkBufferSize() {
        if (this._buffer.size() > 4096) {
            byte[] byteArray = this._buffer.toByteArray();
            this._buffer = null;
            write(byteArray, 0, byteArray.length);
        }
    }

    private void dieIfClosed() {
        if (this._closed) {
            throw new IOException("cannot perform requested operation on a closed stream");
        }
    }

    @Override // java.io.OutputStream, java.io.Closeable, java.lang.AutoCloseable
    public void close() {
        if (this._buffer != null) {
            this._document.replaceContents(new ByteArrayInputStream(this._buffer.toByteArray()));
        } else {
            this._stream_output.close();
            this._property.updateSize(this._document_size);
            this._property.setStartBlock(this._stream.getStartBlock());
        }
        this._closed = true;
    }

    @Override // java.io.OutputStream
    public void write(int i2) {
        dieIfClosed();
        ByteArrayOutputStream byteArrayOutputStream = this._buffer;
        if (byteArrayOutputStream != null) {
            byteArrayOutputStream.write(i2);
            checkBufferSize();
            return;
        }
        write(new byte[]{(byte) i2});
    }

    @Override // java.io.OutputStream
    public void write(byte[] bArr) {
        dieIfClosed();
        ByteArrayOutputStream byteArrayOutputStream = this._buffer;
        if (byteArrayOutputStream != null) {
            byteArrayOutputStream.write(bArr);
            checkBufferSize();
            return;
        }
        write(bArr, 0, bArr.length);
    }

    public NDocumentOutputStream(DirectoryEntry directoryEntry, String str) {
        if (directoryEntry instanceof DirectoryNode) {
            this._document_size = 0;
            this._closed = false;
            DocumentNode documentNode = (DocumentNode) directoryEntry.createDocument(str, new ByteArrayInputStream(new byte[0]));
            this._property = (DocumentProperty) documentNode.getProperty();
            this._document = new NPOIFSDocument(documentNode);
            return;
        }
        throw new IOException("Cannot open internal directory storage, " + directoryEntry + " not a Directory Node");
    }

    @Override // java.io.OutputStream
    public void write(byte[] bArr, int i2, int i3) {
        dieIfClosed();
        ByteArrayOutputStream byteArrayOutputStream = this._buffer;
        if (byteArrayOutputStream != null) {
            byteArrayOutputStream.write(bArr, i2, i3);
            checkBufferSize();
            return;
        }
        if (this._stream == null) {
            NPOIFSStream nPOIFSStream = new NPOIFSStream(this._document.getFileSystem());
            this._stream = nPOIFSStream;
            this._stream_output = nPOIFSStream.getOutputStream();
        }
        this._stream_output.write(bArr, i2, i3);
        this._document_size += i3;
    }
}
