package org.apache.poi.poifs.filesystem;

import b.b.a.a.a;
import java.nio.ByteBuffer;
import java.util.Iterator;
import java.util.List;
import org.apache.poi.poifs.filesystem.BlockStore;
import org.apache.poi.poifs.property.RootProperty;
import org.apache.poi.poifs.storage.BATBlock;
import org.apache.poi.poifs.storage.BlockAllocationTableWriter;
import org.apache.poi.poifs.storage.HeaderBlock;

public class NPOIFSMiniStore extends BlockStore {
    public NPOIFSFileSystem _filesystem;
    public HeaderBlock _header;
    public NPOIFSStream _mini_stream;
    public RootProperty _root;
    public List<BATBlock> _sbat_blocks;

    public NPOIFSMiniStore(NPOIFSFileSystem nPOIFSFileSystem, RootProperty rootProperty, List<BATBlock> list, HeaderBlock headerBlock) {
        this._filesystem = nPOIFSFileSystem;
        this._sbat_blocks = list;
        this._header = headerBlock;
        this._root = rootProperty;
        this._mini_stream = new NPOIFSStream(nPOIFSFileSystem, rootProperty.getStartBlock());
    }

    @Override // org.apache.poi.poifs.filesystem.BlockStore
    public ByteBuffer createBlockIfNeeded(int i2) {
        boolean z = this._mini_stream.getStartBlock() == -2;
        if (!z) {
            try {
                return getBlockAt(i2);
            } catch (IndexOutOfBoundsException unused) {
            }
        }
        int freeBlock = this._filesystem.getFreeBlock();
        this._filesystem.createBlockIfNeeded(freeBlock);
        if (z) {
            this._filesystem._get_property_table().getRoot().setStartBlock(freeBlock);
            this._mini_stream = new NPOIFSStream(this._filesystem, freeBlock);
        } else {
            BlockStore.ChainLoopDetector chainLoopDetector = this._filesystem.getChainLoopDetector();
            int startBlock = this._mini_stream.getStartBlock();
            while (true) {
                chainLoopDetector.claim(startBlock);
                int nextBlock = this._filesystem.getNextBlock(startBlock);
                if (nextBlock == -2) {
                    break;
                }
                startBlock = nextBlock;
            }
            this._filesystem.setNextBlock(startBlock, freeBlock);
        }
        this._filesystem.setNextBlock(freeBlock, -2);
        return createBlockIfNeeded(i2);
    }

    @Override // org.apache.poi.poifs.filesystem.BlockStore
    public BATBlock.BATBlockAndIndex getBATBlockAndIndex(int i2) {
        return BATBlock.getSBATBlockAndIndex(i2, this._header, this._sbat_blocks);
    }

    @Override // org.apache.poi.poifs.filesystem.BlockStore
    public ByteBuffer getBlockAt(int i2) {
        int i3 = i2 * 64;
        int bigBlockSize = i3 / this._filesystem.getBigBlockSize();
        int bigBlockSize2 = i3 % this._filesystem.getBigBlockSize();
        Iterator<ByteBuffer> blockIterator = this._mini_stream.getBlockIterator();
        for (int i4 = 0; i4 < bigBlockSize; i4++) {
            blockIterator.next();
        }
        ByteBuffer next = blockIterator.next();
        if (next != null) {
            next.position(next.position() + bigBlockSize2);
            ByteBuffer slice = next.slice();
            slice.limit(64);
            return slice;
        }
        throw new IndexOutOfBoundsException(a.b("Big block ", bigBlockSize, " outside stream"));
    }

    @Override // org.apache.poi.poifs.filesystem.BlockStore
    public int getBlockStoreBlockSize() {
        return 64;
    }

    @Override // org.apache.poi.poifs.filesystem.BlockStore
    public BlockStore.ChainLoopDetector getChainLoopDetector() {
        return new BlockStore.ChainLoopDetector((long) this._root.getSize());
    }

    @Override // org.apache.poi.poifs.filesystem.BlockStore
    public int getFreeBlock() {
        int bATEntriesPerBlock = this._filesystem.getBigBlockSizeDetails().getBATEntriesPerBlock();
        int i2 = 0;
        for (int i3 = 0; i3 < this._sbat_blocks.size(); i3++) {
            BATBlock bATBlock = this._sbat_blocks.get(i3);
            if (bATBlock.hasFreeSectors()) {
                for (int i4 = 0; i4 < bATEntriesPerBlock; i4++) {
                    if (bATBlock.getValueAt(i4) == -1) {
                        return i2 + i4;
                    }
                }
                continue;
            }
            i2 += bATEntriesPerBlock;
        }
        BATBlock createEmptyBATBlock = BATBlock.createEmptyBATBlock(this._filesystem.getBigBlockSizeDetails(), false);
        int freeBlock = this._filesystem.getFreeBlock();
        createEmptyBATBlock.setOurBlockIndex(freeBlock);
        if (this._header.getSBATCount() == 0) {
            this._header.setSBATStart(freeBlock);
            this._header.setSBATBlockCount(1);
        } else {
            BlockStore.ChainLoopDetector chainLoopDetector = this._filesystem.getChainLoopDetector();
            int sBATStart = this._header.getSBATStart();
            while (true) {
                chainLoopDetector.claim(sBATStart);
                int nextBlock = this._filesystem.getNextBlock(sBATStart);
                if (nextBlock == -2) {
                    break;
                }
                sBATStart = nextBlock;
            }
            this._filesystem.setNextBlock(sBATStart, freeBlock);
            HeaderBlock headerBlock = this._header;
            headerBlock.setSBATBlockCount(headerBlock.getSBATCount() + 1);
        }
        this._filesystem.setNextBlock(freeBlock, -2);
        this._sbat_blocks.add(createEmptyBATBlock);
        return i2;
    }

    @Override // org.apache.poi.poifs.filesystem.BlockStore
    public int getNextBlock(int i2) {
        BATBlock.BATBlockAndIndex bATBlockAndIndex = getBATBlockAndIndex(i2);
        return bATBlockAndIndex.getBlock().getValueAt(bATBlockAndIndex.getIndex());
    }

    @Override // org.apache.poi.poifs.filesystem.BlockStore
    public void setNextBlock(int i2, int i3) {
        BATBlock.BATBlockAndIndex bATBlockAndIndex = getBATBlockAndIndex(i2);
        bATBlockAndIndex.getBlock().setValueAt(bATBlockAndIndex.getIndex(), i3);
    }

    public void syncWithDataSource() {
        int i2;
        int i3 = 0;
        for (BATBlock bATBlock : this._sbat_blocks) {
            BlockAllocationTableWriter.writeBlock(bATBlock, this._filesystem.getBlockAt(bATBlock.getOurBlockIndex()));
            if (!bATBlock.hasFreeSectors()) {
                i2 = this._filesystem.getBigBlockSizeDetails().getBATEntriesPerBlock();
            } else {
                i2 = bATBlock.getUsedSectors(false);
            }
            i3 = i2 + i3;
        }
        this._filesystem._get_property_table().getRoot().setSize(i3);
    }
}
