package org.apache.poi.poifs.filesystem;

import b.b.a.a.a;
import java.io.IOException;
import org.apache.poi.poifs.storage.DataInputBlock;
import org.apache.poi.util.RecordFormatException;

public final class ODocumentInputStream extends DocumentInputStream {
    public boolean _closed;
    public DataInputBlock _currentBlock;
    public int _current_offset;
    public final OPOIFSDocument _document;
    public final int _document_size;
    public int _marked_offset;

    public ODocumentInputStream(DocumentEntry documentEntry) {
        if (documentEntry instanceof DocumentNode) {
            DocumentNode documentNode = (DocumentNode) documentEntry;
            if (documentNode.getDocument() != null) {
                this._current_offset = 0;
                this._marked_offset = 0;
                int size = documentEntry.getSize();
                this._document_size = size;
                if (size >= 0) {
                    this._closed = false;
                    this._document = documentNode.getDocument();
                    this._currentBlock = getDataInputBlock(0);
                    return;
                }
                throw new RecordFormatException("document_size cannot be < 0");
            }
            throw new IOException("Cannot open internal document storage");
        }
        throw new IOException("Cannot open internal document storage");
    }

    private boolean atEOD() {
        return this._current_offset == this._document_size;
    }

    private void checkAvaliable(int i2) {
        if (this._closed) {
            throw new IllegalStateException("cannot perform requested operation on a closed stream");
        } else if (i2 > this._document_size - this._current_offset) {
            StringBuilder a = a.a("Buffer underrun - requested ", i2, " bytes but ");
            a.append(this._document_size - this._current_offset);
            a.append(" was available");
            throw new RuntimeException(a.toString());
        }
    }

    private void dieIfClosed() {
        if (this._closed) {
            throw new IOException("cannot perform requested operation on a closed stream");
        }
    }

    private DataInputBlock getDataInputBlock(int i2) {
        return this._document.getDataInputBlock(i2);
    }

    @Override // org.apache.poi.util.LittleEndianInput, org.apache.poi.poifs.filesystem.DocumentInputStream, java.io.InputStream
    public int available() {
        if (!this._closed) {
            return this._document_size - this._current_offset;
        }
        throw new IllegalStateException("cannot perform requested operation on a closed stream");
    }

    @Override // java.io.Closeable, java.lang.AutoCloseable, org.apache.poi.poifs.filesystem.DocumentInputStream, java.io.InputStream
    public void close() {
        this._closed = true;
    }

    @Override // org.apache.poi.poifs.filesystem.DocumentInputStream
    public void mark(int i2) {
        this._marked_offset = this._current_offset;
    }

    @Override // org.apache.poi.poifs.filesystem.DocumentInputStream, java.io.InputStream
    public int read() {
        dieIfClosed();
        if (atEOD()) {
            return -1;
        }
        int readUByte = this._currentBlock.readUByte();
        this._current_offset++;
        if (this._currentBlock.available() < 1) {
            this._currentBlock = getDataInputBlock(this._current_offset);
        }
        return readUByte;
    }

    @Override // org.apache.poi.util.LittleEndianInput, org.apache.poi.poifs.filesystem.DocumentInputStream
    public byte readByte() {
        return (byte) readUByte();
    }

    @Override // org.apache.poi.util.LittleEndianInput, org.apache.poi.poifs.filesystem.DocumentInputStream
    public double readDouble() {
        return Double.longBitsToDouble(readLong());
    }

    @Override // org.apache.poi.util.LittleEndianInput, org.apache.poi.poifs.filesystem.DocumentInputStream
    public void readFully(byte[] bArr, int i2, int i3) {
        checkAvaliable(i3);
        int available = this._currentBlock.available();
        if (available > i3) {
            this._currentBlock.readFully(bArr, i2, i3);
            this._current_offset += i3;
            return;
        }
        while (i3 > 0) {
            boolean z = i3 >= available;
            int i4 = z ? available : i3;
            this._currentBlock.readFully(bArr, i2, i4);
            i3 -= i4;
            i2 += i4;
            int i5 = this._current_offset + i4;
            this._current_offset = i5;
            if (z) {
                if (i5 != this._document_size) {
                    DataInputBlock dataInputBlock = getDataInputBlock(i5);
                    this._currentBlock = dataInputBlock;
                    available = dataInputBlock.available();
                } else if (i3 <= 0) {
                    this._currentBlock = null;
                    return;
                } else {
                    throw new IllegalStateException("reached end of document stream unexpectedly");
                }
            }
        }
    }

    @Override // org.apache.poi.util.LittleEndianInput, org.apache.poi.poifs.filesystem.DocumentInputStream
    public int readInt() {
        int i2;
        checkAvaliable(4);
        int available = this._currentBlock.available();
        if (available > 4) {
            i2 = this._currentBlock.readIntLE();
        } else {
            DataInputBlock dataInputBlock = getDataInputBlock(this._current_offset + available);
            if (available == 4) {
                i2 = this._currentBlock.readIntLE();
            } else {
                i2 = dataInputBlock.readIntLE(this._currentBlock, available);
            }
            this._currentBlock = dataInputBlock;
        }
        this._current_offset += 4;
        return i2;
    }

    @Override // org.apache.poi.util.LittleEndianInput, org.apache.poi.poifs.filesystem.DocumentInputStream
    public long readLong() {
        long j;
        long j2;
        checkAvaliable(8);
        int available = this._currentBlock.available();
        if (available > 8) {
            j = this._currentBlock.readLongLE();
        } else {
            DataInputBlock dataInputBlock = getDataInputBlock(this._current_offset + available);
            if (available == 8) {
                j2 = this._currentBlock.readLongLE();
            } else {
                j2 = dataInputBlock.readLongLE(this._currentBlock, available);
            }
            this._currentBlock = dataInputBlock;
            j = j2;
        }
        this._current_offset += 8;
        return j;
    }

    @Override // org.apache.poi.util.LittleEndianInput, org.apache.poi.poifs.filesystem.DocumentInputStream
    public short readShort() {
        return (short) readUShort();
    }

    @Override // org.apache.poi.util.LittleEndianInput, org.apache.poi.poifs.filesystem.DocumentInputStream
    public int readUByte() {
        checkAvaliable(1);
        int readUByte = this._currentBlock.readUByte();
        this._current_offset++;
        if (this._currentBlock.available() < 1) {
            this._currentBlock = getDataInputBlock(this._current_offset);
        }
        return readUByte;
    }

    @Override // org.apache.poi.util.LittleEndianInput, org.apache.poi.poifs.filesystem.DocumentInputStream
    public int readUShort() {
        int i2;
        checkAvaliable(2);
        int available = this._currentBlock.available();
        if (available > 2) {
            i2 = this._currentBlock.readUShortLE();
        } else {
            DataInputBlock dataInputBlock = getDataInputBlock(this._current_offset + available);
            if (available == 2) {
                i2 = this._currentBlock.readUShortLE();
            } else {
                i2 = dataInputBlock.readUShortLE(this._currentBlock);
            }
            this._currentBlock = dataInputBlock;
        }
        this._current_offset += 2;
        return i2;
    }

    @Override // org.apache.poi.poifs.filesystem.DocumentInputStream, java.io.InputStream
    public void reset() {
        int i2 = this._marked_offset;
        this._current_offset = i2;
        this._currentBlock = getDataInputBlock(i2);
    }

    @Override // org.apache.poi.poifs.filesystem.DocumentInputStream, java.io.InputStream
    public long skip(long j) {
        dieIfClosed();
        if (j < 0) {
            return 0;
        }
        int i2 = this._current_offset;
        int i3 = ((int) j) + i2;
        if (i3 < i2) {
            i3 = this._document_size;
        } else {
            int i4 = this._document_size;
            if (i3 > i4) {
                i3 = i4;
            }
        }
        long j2 = (long) (i3 - this._current_offset);
        this._current_offset = i3;
        this._currentBlock = getDataInputBlock(i3);
        return j2;
    }

    @Override // org.apache.poi.poifs.filesystem.DocumentInputStream, java.io.InputStream
    public int read(byte[] bArr, int i2, int i3) {
        dieIfClosed();
        if (bArr == null) {
            throw new IllegalArgumentException("buffer must not be null");
        } else if (i2 < 0 || i3 < 0 || bArr.length < i2 + i3) {
            throw new IndexOutOfBoundsException("can't read past buffer boundaries");
        } else if (i3 == 0) {
            return 0;
        } else {
            if (atEOD()) {
                return -1;
            }
            int min = Math.min(available(), i3);
            readFully(bArr, i2, min);
            return min;
        }
    }

    public ODocumentInputStream(OPOIFSDocument oPOIFSDocument) {
        this._current_offset = 0;
        this._marked_offset = 0;
        this._document_size = oPOIFSDocument.getSize();
        this._closed = false;
        this._document = oPOIFSDocument;
        this._currentBlock = getDataInputBlock(0);
    }
}
