package org.apache.poi.poifs.filesystem;

import b.b.a.a.a;
import java.io.ByteArrayOutputStream;
import java.io.IOException;
import java.io.InputStream;
import java.io.OutputStream;
import java.util.ArrayList;
import java.util.Collections;
import java.util.Iterator;
import org.apache.poi.poifs.common.POIFSBigBlockSize;
import org.apache.poi.poifs.common.POIFSConstants;
import org.apache.poi.poifs.dev.POIFSViewable;
import org.apache.poi.poifs.property.DocumentProperty;
import org.apache.poi.poifs.property.Property;
import org.apache.poi.poifs.storage.BlockWritable;
import org.apache.poi.poifs.storage.DataInputBlock;
import org.apache.poi.poifs.storage.DocumentBlock;
import org.apache.poi.poifs.storage.ListManagedBlock;
import org.apache.poi.poifs.storage.RawDataBlock;
import org.apache.poi.poifs.storage.SmallDocumentBlock;
import org.apache.poi.util.HexDump;

public final class OPOIFSDocument implements BATManaged, BlockWritable, POIFSViewable {
    public static final DocumentBlock[] EMPTY_BIG_BLOCK_ARRAY = new DocumentBlock[0];
    public static final SmallDocumentBlock[] EMPTY_SMALL_BLOCK_ARRAY = new SmallDocumentBlock[0];
    public final POIFSBigBlockSize _bigBigBlockSize;
    public BigBlockStore _big_store;
    public DocumentProperty _property;
    public int _size;
    public SmallBlockStore _small_store;

    public OPOIFSDocument(String str, RawDataBlock[] rawDataBlockArr, int i2) {
        this._size = i2;
        if (rawDataBlockArr.length == 0) {
            this._bigBigBlockSize = POIFSConstants.SMALLER_BIG_BLOCK_SIZE_DETAILS;
        } else {
            this._bigBigBlockSize = rawDataBlockArr[0].getBigBlockSize() == 512 ? POIFSConstants.SMALLER_BIG_BLOCK_SIZE_DETAILS : POIFSConstants.LARGER_BIG_BLOCK_SIZE_DETAILS;
        }
        this._big_store = new BigBlockStore(this._bigBigBlockSize, convertRawBlocksToBigBlocks(rawDataBlockArr));
        this._property = new DocumentProperty(str, this._size);
        this._small_store = new SmallBlockStore(this._bigBigBlockSize, EMPTY_SMALL_BLOCK_ARRAY);
        this._property.setDocument(this);
    }

    public static DocumentBlock[] convertRawBlocksToBigBlocks(ListManagedBlock[] listManagedBlockArr) {
        int length = listManagedBlockArr.length;
        DocumentBlock[] documentBlockArr = new DocumentBlock[length];
        for (int i2 = 0; i2 < length; i2++) {
            documentBlockArr[i2] = new DocumentBlock((RawDataBlock) listManagedBlockArr[i2]);
        }
        return documentBlockArr;
    }

    public static SmallDocumentBlock[] convertRawBlocksToSmallBlocks(ListManagedBlock[] listManagedBlockArr) {
        if (listManagedBlockArr instanceof SmallDocumentBlock[]) {
            return (SmallDocumentBlock[]) listManagedBlockArr;
        }
        SmallDocumentBlock[] smallDocumentBlockArr = new SmallDocumentBlock[listManagedBlockArr.length];
        System.arraycopy(listManagedBlockArr, 0, smallDocumentBlockArr, 0, listManagedBlockArr.length);
        return smallDocumentBlockArr;
    }

    @Override // org.apache.poi.poifs.filesystem.BATManaged
    public int countBlocks() {
        return this._big_store.countBlocks();
    }

    public DataInputBlock getDataInputBlock(int i2) {
        int i3 = this._size;
        if (i2 >= i3) {
            if (i2 <= i3) {
                return null;
            }
            StringBuilder a = a.a("Request for Offset ", i2, " doc size is ");
            a.append(this._size);
            throw new RuntimeException(a.toString());
        } else if (this._property.shouldUseSmallBlocks()) {
            return SmallDocumentBlock.getDataInputBlock(this._small_store.getBlocks(), i2);
        } else {
            return DocumentBlock.getDataInputBlock(this._big_store.getBlocks(), i2);
        }
    }

    public DocumentProperty getDocumentProperty() {
        return this._property;
    }

    @Override // org.apache.poi.poifs.dev.POIFSViewable
    public String getShortDescription() {
        StringBuffer a = a.a("Document: \"");
        a.append(this._property.getName());
        a.append("\"");
        a.append(" size = ");
        a.append(getSize());
        return a.toString();
    }

    public int getSize() {
        return this._size;
    }

    public SmallDocumentBlock[] getSmallBlocks() {
        return this._small_store.getBlocks();
    }

    @Override // org.apache.poi.poifs.dev.POIFSViewable
    public Object[] getViewableArray() {
        String str;
        BlockWritable[] blockWritableArr = null;
        try {
            if (this._big_store.isValid()) {
                blockWritableArr = this._big_store.getBlocks();
            } else if (this._small_store.isValid()) {
                blockWritableArr = this._small_store.getBlocks();
            }
            if (blockWritableArr != null) {
                ByteArrayOutputStream byteArrayOutputStream = new ByteArrayOutputStream();
                for (BlockWritable blockWritable : blockWritableArr) {
                    blockWritable.writeBlocks(byteArrayOutputStream);
                }
                str = HexDump.dump(byteArrayOutputStream.toByteArray(), 0, 0, Math.min(byteArrayOutputStream.size(), this._property.getSize()));
            } else {
                str = "<NO DATA>";
            }
        } catch (IOException e2) {
            str = e2.getMessage();
        }
        return new String[]{str};
    }

    @Override // org.apache.poi.poifs.dev.POIFSViewable
    public Iterator<Object> getViewableIterator() {
        return Collections.emptyList().iterator();
    }

    @Override // org.apache.poi.poifs.dev.POIFSViewable
    public boolean preferArray() {
        return true;
    }

    public void read(byte[] bArr, int i2) {
        int length = bArr.length;
        DataInputBlock dataInputBlock = getDataInputBlock(i2);
        int available = dataInputBlock.available();
        if (available > length) {
            dataInputBlock.readFully(bArr, 0, length);
            return;
        }
        int i3 = 0;
        while (length > 0) {
            boolean z = length >= available;
            int i4 = z ? available : length;
            dataInputBlock.readFully(bArr, i3, i4);
            length -= i4;
            i3 += i4;
            i2 += i4;
            if (z) {
                if (i2 != this._size) {
                    dataInputBlock = getDataInputBlock(i2);
                    available = dataInputBlock.available();
                } else if (length > 0) {
                    throw new IllegalStateException("reached end of document stream unexpectedly");
                } else {
                    return;
                }
            }
        }
    }

    @Override // org.apache.poi.poifs.filesystem.BATManaged
    public void setStartBlock(int i2) {
        this._property.setStartBlock(i2);
    }

    @Override // org.apache.poi.poifs.storage.BlockWritable
    public void writeBlocks(OutputStream outputStream) {
        this._big_store.writeBlocks(outputStream);
    }

    public static final class BigBlockStore {
        public final POIFSBigBlockSize _bigBlockSize;
        public final String _name;
        public final POIFSDocumentPath _path;
        public final int _size;
        public final POIFSWriterListener _writer;
        public DocumentBlock[] bigBlocks;

        public BigBlockStore(POIFSBigBlockSize pOIFSBigBlockSize, DocumentBlock[] documentBlockArr) {
            this._bigBlockSize = pOIFSBigBlockSize;
            this.bigBlocks = (DocumentBlock[]) documentBlockArr.clone();
            this._path = null;
            this._name = null;
            this._size = -1;
            this._writer = null;
        }

        public int countBlocks() {
            if (!isValid()) {
                return 0;
            }
            if (this._writer == null) {
                return this.bigBlocks.length;
            }
            return ((this._bigBlockSize.getBigBlockSize() + this._size) - 1) / this._bigBlockSize.getBigBlockSize();
        }

        public DocumentBlock[] getBlocks() {
            if (isValid() && this._writer != null) {
                ByteArrayOutputStream byteArrayOutputStream = new ByteArrayOutputStream(this._size);
                this._writer.processPOIFSWriterEvent(new POIFSWriterEvent(new DocumentOutputStream(byteArrayOutputStream, this._size), this._path, this._name, this._size));
                this.bigBlocks = DocumentBlock.convert(this._bigBlockSize, byteArrayOutputStream.toByteArray(), this._size);
            }
            return this.bigBlocks;
        }

        public boolean isValid() {
            return this.bigBlocks.length > 0 || this._writer != null;
        }

        public void writeBlocks(OutputStream outputStream) {
            if (!isValid()) {
                return;
            }
            if (this._writer != null) {
                DocumentOutputStream documentOutputStream = new DocumentOutputStream(outputStream, this._size);
                this._writer.processPOIFSWriterEvent(new POIFSWriterEvent(documentOutputStream, this._path, this._name, this._size));
                documentOutputStream.writeFiller(this._bigBlockSize.getBigBlockSize() * countBlocks(), DocumentBlock.getFillByte());
                return;
            }
            int i2 = 0;
            while (true) {
                DocumentBlock[] documentBlockArr = this.bigBlocks;
                if (i2 < documentBlockArr.length) {
                    documentBlockArr[i2].writeBlocks(outputStream);
                    i2++;
                } else {
                    return;
                }
            }
        }

        public BigBlockStore(POIFSBigBlockSize pOIFSBigBlockSize, POIFSDocumentPath pOIFSDocumentPath, String str, int i2, POIFSWriterListener pOIFSWriterListener) {
            this._bigBlockSize = pOIFSBigBlockSize;
            this.bigBlocks = new DocumentBlock[0];
            this._path = pOIFSDocumentPath;
            this._name = str;
            this._size = i2;
            this._writer = pOIFSWriterListener;
        }
    }

    public static final class SmallBlockStore {
        public final POIFSBigBlockSize _bigBlockSize;
        public final String _name;
        public final POIFSDocumentPath _path;
        public final int _size;
        public SmallDocumentBlock[] _smallBlocks;
        public final POIFSWriterListener _writer;

        public SmallBlockStore(POIFSBigBlockSize pOIFSBigBlockSize, SmallDocumentBlock[] smallDocumentBlockArr) {
            this._bigBlockSize = pOIFSBigBlockSize;
            this._smallBlocks = (SmallDocumentBlock[]) smallDocumentBlockArr.clone();
            this._path = null;
            this._name = null;
            this._size = -1;
            this._writer = null;
        }

        public SmallDocumentBlock[] getBlocks() {
            if (isValid() && this._writer != null) {
                ByteArrayOutputStream byteArrayOutputStream = new ByteArrayOutputStream(this._size);
                this._writer.processPOIFSWriterEvent(new POIFSWriterEvent(new DocumentOutputStream(byteArrayOutputStream, this._size), this._path, this._name, this._size));
                this._smallBlocks = SmallDocumentBlock.convert(this._bigBlockSize, byteArrayOutputStream.toByteArray(), this._size);
            }
            return this._smallBlocks;
        }

        public boolean isValid() {
            return this._smallBlocks.length > 0 || this._writer != null;
        }

        public SmallBlockStore(POIFSBigBlockSize pOIFSBigBlockSize, POIFSDocumentPath pOIFSDocumentPath, String str, int i2, POIFSWriterListener pOIFSWriterListener) {
            this._bigBlockSize = pOIFSBigBlockSize;
            this._smallBlocks = new SmallDocumentBlock[0];
            this._path = pOIFSDocumentPath;
            this._name = str;
            this._size = i2;
            this._writer = pOIFSWriterListener;
        }
    }

    public OPOIFSDocument(String str, SmallDocumentBlock[] smallDocumentBlockArr, int i2) {
        this._size = i2;
        if (smallDocumentBlockArr.length == 0) {
            this._bigBigBlockSize = POIFSConstants.SMALLER_BIG_BLOCK_SIZE_DETAILS;
        } else {
            this._bigBigBlockSize = smallDocumentBlockArr[0].getBigBlockSize();
        }
        this._big_store = new BigBlockStore(this._bigBigBlockSize, EMPTY_BIG_BLOCK_ARRAY);
        this._property = new DocumentProperty(str, this._size);
        this._small_store = new SmallBlockStore(this._bigBigBlockSize, smallDocumentBlockArr);
        this._property.setDocument(this);
    }

    public OPOIFSDocument(String str, POIFSBigBlockSize pOIFSBigBlockSize, ListManagedBlock[] listManagedBlockArr, int i2) {
        this._size = i2;
        this._bigBigBlockSize = pOIFSBigBlockSize;
        DocumentProperty documentProperty = new DocumentProperty(str, i2);
        this._property = documentProperty;
        documentProperty.setDocument(this);
        if (Property.isSmall(this._size)) {
            this._big_store = new BigBlockStore(pOIFSBigBlockSize, EMPTY_BIG_BLOCK_ARRAY);
            this._small_store = new SmallBlockStore(pOIFSBigBlockSize, convertRawBlocksToSmallBlocks(listManagedBlockArr));
            return;
        }
        this._big_store = new BigBlockStore(pOIFSBigBlockSize, convertRawBlocksToBigBlocks(listManagedBlockArr));
        this._small_store = new SmallBlockStore(pOIFSBigBlockSize, EMPTY_SMALL_BLOCK_ARRAY);
    }

    public OPOIFSDocument(String str, ListManagedBlock[] listManagedBlockArr, int i2) {
        this(str, POIFSConstants.SMALLER_BIG_BLOCK_SIZE_DETAILS, listManagedBlockArr, i2);
    }

    public OPOIFSDocument(String str, POIFSBigBlockSize pOIFSBigBlockSize, InputStream inputStream) {
        DocumentBlock documentBlock;
        ArrayList arrayList = new ArrayList();
        this._size = 0;
        this._bigBigBlockSize = pOIFSBigBlockSize;
        do {
            documentBlock = new DocumentBlock(inputStream, pOIFSBigBlockSize);
            int size = documentBlock.size();
            if (size > 0) {
                arrayList.add(documentBlock);
                this._size += size;
            }
        } while (!documentBlock.partiallyRead());
        DocumentBlock[] documentBlockArr = (DocumentBlock[]) arrayList.toArray(new DocumentBlock[arrayList.size()]);
        this._big_store = new BigBlockStore(pOIFSBigBlockSize, documentBlockArr);
        DocumentProperty documentProperty = new DocumentProperty(str, this._size);
        this._property = documentProperty;
        documentProperty.setDocument(this);
        if (this._property.shouldUseSmallBlocks()) {
            this._small_store = new SmallBlockStore(pOIFSBigBlockSize, SmallDocumentBlock.convert(pOIFSBigBlockSize, documentBlockArr, this._size));
            this._big_store = new BigBlockStore(pOIFSBigBlockSize, new DocumentBlock[0]);
            return;
        }
        this._small_store = new SmallBlockStore(pOIFSBigBlockSize, EMPTY_SMALL_BLOCK_ARRAY);
    }

    public OPOIFSDocument(String str, InputStream inputStream) {
        this(str, POIFSConstants.SMALLER_BIG_BLOCK_SIZE_DETAILS, inputStream);
    }

    public OPOIFSDocument(String str, int i2, POIFSBigBlockSize pOIFSBigBlockSize, POIFSDocumentPath pOIFSDocumentPath, POIFSWriterListener pOIFSWriterListener) {
        this._size = i2;
        this._bigBigBlockSize = pOIFSBigBlockSize;
        DocumentProperty documentProperty = new DocumentProperty(str, i2);
        this._property = documentProperty;
        documentProperty.setDocument(this);
        if (this._property.shouldUseSmallBlocks()) {
            this._small_store = new SmallBlockStore(this._bigBigBlockSize, pOIFSDocumentPath, str, i2, pOIFSWriterListener);
            this._big_store = new BigBlockStore(this._bigBigBlockSize, EMPTY_BIG_BLOCK_ARRAY);
            return;
        }
        this._small_store = new SmallBlockStore(this._bigBigBlockSize, EMPTY_SMALL_BLOCK_ARRAY);
        this._big_store = new BigBlockStore(this._bigBigBlockSize, pOIFSDocumentPath, str, i2, pOIFSWriterListener);
    }

    public OPOIFSDocument(String str, int i2, POIFSDocumentPath pOIFSDocumentPath, POIFSWriterListener pOIFSWriterListener) {
        this(str, i2, POIFSConstants.SMALLER_BIG_BLOCK_SIZE_DETAILS, pOIFSDocumentPath, pOIFSWriterListener);
    }
}
