package org.apache.poi.poifs.filesystem;

import java.io.File;
import org.apache.poi.util.POILogFactory;
import org.apache.poi.util.POILogger;

public class POIFSDocumentPath {
    public static final POILogger log = POILogFactory.getLogger(POIFSDocumentPath.class);
    public final String[] components;
    public int hashcode;

    public POIFSDocumentPath(String[] strArr) {
        this.hashcode = 0;
        if (strArr == null) {
            this.components = new String[0];
            return;
        }
        this.components = new String[strArr.length];
        for (int i2 = 0; i2 < strArr.length; i2++) {
            if (strArr[i2] == null || strArr[i2].length() == 0) {
                throw new IllegalArgumentException("components cannot contain null or empty strings");
            }
            this.components[i2] = strArr[i2];
        }
    }

    private int computeHashCode() {
        int i2 = 0;
        int i3 = 0;
        while (true) {
            String[] strArr = this.components;
            if (i2 >= strArr.length) {
                return i3;
            }
            i3 += strArr[i2].hashCode();
            i2++;
        }
    }

    public boolean equals(Object obj) {
        if (obj != null && obj.getClass() == POIFSDocumentPath.class) {
            if (this == obj) {
                return true;
            }
            POIFSDocumentPath pOIFSDocumentPath = (POIFSDocumentPath) obj;
            if (pOIFSDocumentPath.components.length == this.components.length) {
                int i2 = 0;
                while (true) {
                    String[] strArr = this.components;
                    if (i2 >= strArr.length) {
                        return true;
                    }
                    if (!pOIFSDocumentPath.components[i2].equals(strArr[i2])) {
                        break;
                    }
                    i2++;
                }
            }
        }
        return false;
    }

    public String getComponent(int i2) {
        return this.components[i2];
    }

    public String getName() {
        String[] strArr = this.components;
        if (strArr.length == 0) {
            return "";
        }
        return strArr[strArr.length - 1];
    }

    public POIFSDocumentPath getParent() {
        String[] strArr = this.components;
        int length = strArr.length - 1;
        if (length < 0) {
            return null;
        }
        String[] strArr2 = new String[length];
        System.arraycopy(strArr, 0, strArr2, 0, length);
        return new POIFSDocumentPath(strArr2);
    }

    public int hashCode() {
        if (this.hashcode == 0) {
            this.hashcode = computeHashCode();
        }
        return this.hashcode;
    }

    public int length() {
        return this.components.length;
    }

    public String toString() {
        StringBuffer stringBuffer = new StringBuffer();
        int length = length();
        stringBuffer.append(File.separatorChar);
        for (int i2 = 0; i2 < length; i2++) {
            stringBuffer.append(getComponent(i2));
            if (i2 < length - 1) {
                stringBuffer.append(File.separatorChar);
            }
        }
        return stringBuffer.toString();
    }

    public POIFSDocumentPath() {
        this.hashcode = 0;
        this.components = new String[0];
    }

    public POIFSDocumentPath(POIFSDocumentPath pOIFSDocumentPath, String[] strArr) {
        this.hashcode = 0;
        if (strArr == null) {
            this.components = new String[pOIFSDocumentPath.components.length];
        } else {
            this.components = new String[(pOIFSDocumentPath.components.length + strArr.length)];
        }
        int i2 = 0;
        while (true) {
            String[] strArr2 = pOIFSDocumentPath.components;
            if (i2 >= strArr2.length) {
                break;
            }
            this.components[i2] = strArr2[i2];
            i2++;
        }
        if (strArr != null) {
            for (int i3 = 0; i3 < strArr.length; i3++) {
                if (strArr[i3] != null) {
                    if (strArr[i3].length() == 0) {
                        POILogger pOILogger = log;
                        pOILogger.log(5, "Directory under " + pOIFSDocumentPath + " has an empty name, " + "not all OLE2 readers will handle this file correctly!");
                    }
                    this.components[pOIFSDocumentPath.components.length + i3] = strArr[i3];
                } else {
                    throw new IllegalArgumentException("components cannot contain null");
                }
            }
        }
    }
}
