package org.apache.poi.poifs.nio;

import java.io.OutputStream;
import java.nio.ByteBuffer;

public class ByteArrayBackedDataSource extends DataSource {
    public byte[] buffer;
    public long size;

    public ByteArrayBackedDataSource(byte[] bArr, int i2) {
        this.buffer = bArr;
        this.size = (long) i2;
    }

    private void extend(long j) {
        byte[] bArr = this.buffer;
        long length = j - ((long) bArr.length);
        if (((double) length) < ((double) bArr.length) * 0.25d) {
            length = (long) (((double) bArr.length) * 0.25d);
        }
        if (length < 4096) {
            length = 4096;
        }
        byte[] bArr2 = this.buffer;
        byte[] bArr3 = new byte[((int) (length + ((long) bArr2.length)))];
        System.arraycopy(bArr2, 0, bArr3, 0, (int) this.size);
        this.buffer = bArr3;
    }

    @Override // org.apache.poi.poifs.nio.DataSource
    public void close() {
        this.buffer = null;
        this.size = -1;
    }

    @Override // org.apache.poi.poifs.nio.DataSource
    public void copyTo(OutputStream outputStream) {
        outputStream.write(this.buffer, 0, (int) this.size);
    }

    @Override // org.apache.poi.poifs.nio.DataSource
    public ByteBuffer read(int i2, long j) {
        long j2 = this.size;
        if (j < j2) {
            return ByteBuffer.wrap(this.buffer, (int) j, (int) Math.min((long) i2, j2 - j));
        }
        throw new IndexOutOfBoundsException("Unable to read " + i2 + " bytes from " + j + " in stream of length " + this.size);
    }

    @Override // org.apache.poi.poifs.nio.DataSource
    public long size() {
        return this.size;
    }

    @Override // org.apache.poi.poifs.nio.DataSource
    public void write(ByteBuffer byteBuffer, long j) {
        long capacity = ((long) byteBuffer.capacity()) + j;
        if (capacity > ((long) this.buffer.length)) {
            extend(capacity);
        }
        byteBuffer.get(this.buffer, (int) j, byteBuffer.capacity());
        if (capacity > this.size) {
            this.size = capacity;
        }
    }

    public ByteArrayBackedDataSource(byte[] bArr) {
        this(bArr, bArr.length);
    }
}
