package org.apache.poi.poifs.property;

import b.b.a.a.a;
import java.io.IOException;
import java.io.Serializable;
import java.util.ArrayList;
import java.util.Arrays;
import java.util.Comparator;
import java.util.HashSet;
import java.util.Iterator;
import java.util.List;
import java.util.Set;

public class DirectoryProperty extends Property implements Parent, Iterable<Property> {
    public List<Property> _children = new ArrayList();
    public Set<String> _children_names = new HashSet();

    public static class PropertyComparator implements Comparator<Property>, Serializable {
        public int compare(Property property, Property property2) {
            String name = property.getName();
            String name2 = property2.getName();
            int length = name.length() - name2.length();
            if (length != 0) {
                return length;
            }
            if (name.compareTo("_VBA_PROJECT") != 0) {
                if (name2.compareTo("_VBA_PROJECT") != 0) {
                    if (name.startsWith("__") && name2.startsWith("__")) {
                        return name.compareToIgnoreCase(name2);
                    }
                    if (!name.startsWith("__")) {
                        if (!name2.startsWith("__")) {
                            return name.compareToIgnoreCase(name2);
                        }
                    }
                }
                return -1;
            }
            return 1;
        }
    }

    public DirectoryProperty(String str) {
        setName(str);
        setSize(0);
        setPropertyType((byte) 1);
        setStartBlock(0);
        setNodeColor((byte) 1);
    }

    @Override // org.apache.poi.poifs.property.Parent
    public void addChild(Property property) {
        String name = property.getName();
        if (!this._children_names.contains(name)) {
            this._children_names.add(name);
            this._children.add(property);
            return;
        }
        throw new IOException(a.b("Duplicate name \"", name, "\""));
    }

    public boolean changeName(Property property, String str) {
        String name = property.getName();
        property.setName(str);
        String name2 = property.getName();
        if (this._children_names.contains(name2)) {
            property.setName(name);
            return false;
        }
        this._children_names.add(name2);
        this._children_names.remove(name);
        return true;
    }

    public boolean deleteChild(Property property) {
        boolean remove = this._children.remove(property);
        if (remove) {
            this._children_names.remove(property.getName());
        }
        return remove;
    }

    @Override // org.apache.poi.poifs.property.Parent
    public Iterator<Property> getChildren() {
        return this._children.iterator();
    }

    @Override // org.apache.poi.poifs.property.Property
    public boolean isDirectory() {
        return true;
    }

    @Override // java.lang.Iterable
    public Iterator<Property> iterator() {
        return getChildren();
    }

    @Override // org.apache.poi.poifs.property.Property
    public void preWrite() {
        if (this._children.size() > 0) {
            Property[] propertyArr = (Property[]) this._children.toArray(new Property[0]);
            Arrays.sort(propertyArr, new PropertyComparator());
            int length = propertyArr.length / 2;
            setChildProperty(propertyArr[length].getIndex());
            propertyArr[0].setPreviousChild(null);
            propertyArr[0].setNextChild(null);
            for (int i2 = 1; i2 < length; i2++) {
                propertyArr[i2].setPreviousChild(propertyArr[i2 - 1]);
                propertyArr[i2].setNextChild(null);
            }
            if (length != 0) {
                propertyArr[length].setPreviousChild(propertyArr[length - 1]);
            }
            if (length != propertyArr.length - 1) {
                Property property = propertyArr[length];
                int i3 = length + 1;
                property.setNextChild(propertyArr[i3]);
                while (i3 < propertyArr.length - 1) {
                    propertyArr[i3].setPreviousChild(null);
                    Property property2 = propertyArr[i3];
                    i3++;
                    property2.setNextChild(propertyArr[i3]);
                }
                propertyArr[propertyArr.length - 1].setPreviousChild(null);
                propertyArr[propertyArr.length - 1].setNextChild(null);
                return;
            }
            propertyArr[length].setNextChild(null);
        }
    }

    public DirectoryProperty(int i2, byte[] bArr, int i3) {
        super(i2, bArr, i3);
    }
}
