package org.apache.poi.poifs.property;

import b.b.a.a.a;
import java.io.OutputStream;
import java.nio.ByteBuffer;
import java.util.ArrayList;
import java.util.Iterator;
import java.util.List;
import org.apache.poi.poifs.common.POIFSBigBlockSize;
import org.apache.poi.poifs.filesystem.NPOIFSFileSystem;
import org.apache.poi.poifs.filesystem.NPOIFSStream;
import org.apache.poi.poifs.storage.HeaderBlock;
import org.apache.poi.util.POILogFactory;
import org.apache.poi.util.POILogger;

public final class NPropertyTable extends PropertyTableBase {
    public static final POILogger _logger = POILogFactory.getLogger(NPropertyTable.class);
    public POIFSBigBlockSize _bigBigBlockSize;

    public NPropertyTable(HeaderBlock headerBlock) {
        super(headerBlock);
        this._bigBigBlockSize = headerBlock.getBigBlockSize();
    }

    public static List<Property> buildProperties(Iterator<ByteBuffer> it, POIFSBigBlockSize pOIFSBigBlockSize) {
        byte[] bArr;
        ArrayList arrayList = new ArrayList();
        while (it.hasNext()) {
            ByteBuffer next = it.next();
            if (next.hasArray() && next.arrayOffset() == 0 && next.array().length == pOIFSBigBlockSize.getBigBlockSize()) {
                bArr = next.array();
            } else {
                int bigBlockSize = pOIFSBigBlockSize.getBigBlockSize();
                byte[] bArr2 = new byte[bigBlockSize];
                if (next.remaining() < pOIFSBigBlockSize.getBigBlockSize()) {
                    POILogger pOILogger = _logger;
                    StringBuilder b2 = a.b(" bytes instead of the expected ");
                    b2.append(pOIFSBigBlockSize.getBigBlockSize());
                    pOILogger.log(5, "Short Property Block, ", Integer.valueOf(next.remaining()), b2.toString());
                    bigBlockSize = next.remaining();
                }
                next.get(bArr2, 0, bigBlockSize);
                bArr = bArr2;
            }
            PropertyFactory.convertToProperties(bArr, arrayList);
        }
        return arrayList;
    }

    @Override // org.apache.poi.poifs.filesystem.BATManaged
    public int countBlocks() {
        long size = ((long) this._properties.size()) * 128;
        long bigBlockSize = (long) this._bigBigBlockSize.getBigBlockSize();
        int i2 = (int) (size / bigBlockSize);
        return size % bigBlockSize != 0 ? i2 + 1 : i2;
    }

    public void preWrite() {
        ArrayList arrayList = new ArrayList();
        int i2 = 0;
        for (Property property : this._properties) {
            if (property != null) {
                property.setIndex(i2);
                arrayList.add(property);
                i2++;
            }
        }
        Iterator it = arrayList.iterator();
        while (it.hasNext()) {
            ((Property) it.next()).preWrite();
        }
    }

    public void write(NPOIFSStream nPOIFSStream) {
        OutputStream outputStream = nPOIFSStream.getOutputStream();
        for (Property property : this._properties) {
            if (property != null) {
                property.writeData(outputStream);
            }
        }
        outputStream.close();
        if (getStartBlock() != nPOIFSStream.getStartBlock()) {
            setStartBlock(nPOIFSStream.getStartBlock());
        }
    }

    public NPropertyTable(HeaderBlock headerBlock, NPOIFSFileSystem nPOIFSFileSystem) {
        super(headerBlock, buildProperties(new NPOIFSStream(nPOIFSFileSystem, headerBlock.getPropertyStart()).iterator(), headerBlock.getBigBlockSize()));
        this._bigBigBlockSize = headerBlock.getBigBlockSize();
    }
}
