package org.apache.poi.poifs.property;

import b.b.a.a.a;
import java.util.ArrayList;
import java.util.List;
import java.util.Stack;
import org.apache.poi.poifs.filesystem.BATManaged;
import org.apache.poi.poifs.storage.HeaderBlock;
import org.apache.poi.util.POILogFactory;
import org.apache.poi.util.POILogger;

public abstract class PropertyTableBase implements BATManaged {
    public static final POILogger _logger = POILogFactory.getLogger(PropertyTableBase.class);
    public final HeaderBlock _header_block;
    public final List<Property> _properties;

    public PropertyTableBase(HeaderBlock headerBlock) {
        this._header_block = headerBlock;
        this._properties = new ArrayList();
        addProperty(new RootProperty());
    }

    private void populatePropertyTree(DirectoryProperty directoryProperty) {
        int childIndex = directoryProperty.getChildIndex();
        if (Property.isValidIndex(childIndex)) {
            Stack stack = new Stack();
            stack.push(this._properties.get(childIndex));
            while (!stack.empty()) {
                Property property = (Property) stack.pop();
                if (property != null) {
                    directoryProperty.addChild(property);
                    if (property.isDirectory()) {
                        populatePropertyTree((DirectoryProperty) property);
                    }
                    int previousChildIndex = property.getPreviousChildIndex();
                    if (isValidIndex(previousChildIndex)) {
                        stack.push(this._properties.get(previousChildIndex));
                    }
                    int nextChildIndex = property.getNextChildIndex();
                    if (isValidIndex(nextChildIndex)) {
                        stack.push(this._properties.get(nextChildIndex));
                    }
                }
            }
        }
    }

    public void addProperty(Property property) {
        this._properties.add(property);
    }

    public RootProperty getRoot() {
        return (RootProperty) this._properties.get(0);
    }

    public int getStartBlock() {
        return this._header_block.getPropertyStart();
    }

    public boolean isValidIndex(int i2) {
        if (!Property.isValidIndex(i2)) {
            return false;
        }
        if (i2 >= 0 && i2 < this._properties.size()) {
            return true;
        }
        POILogger pOILogger = _logger;
        StringBuilder a = a.a("Property index ", i2, "outside the valid range 0..");
        a.append(this._properties.size());
        pOILogger.log(5, a.toString());
        return false;
    }

    public void removeProperty(Property property) {
        this._properties.remove(property);
    }

    @Override // org.apache.poi.poifs.filesystem.BATManaged
    public void setStartBlock(int i2) {
        this._header_block.setPropertyStart(i2);
    }

    public PropertyTableBase(HeaderBlock headerBlock, List<Property> list) {
        this._header_block = headerBlock;
        this._properties = list;
        populatePropertyTree((DirectoryProperty) list.get(0));
    }
}
