package org.apache.poi.poifs.storage;

import b.b.a.a.a;
import java.io.IOException;
import java.util.ArrayList;
import org.apache.poi.poifs.common.POIFSBigBlockSize;
import org.apache.poi.util.IntList;
import org.apache.poi.util.Internal;
import org.apache.poi.util.LittleEndian;
import org.apache.poi.util.POILogFactory;
import org.apache.poi.util.POILogger;

public final class BlockAllocationTableReader {
    public static final int MAX_BLOCK_COUNT = 65535;
    public static final POILogger _logger = POILogFactory.getLogger(BlockAllocationTableReader.class);
    public final IntList _entries;
    public POIFSBigBlockSize bigBlockSize;

    public BlockAllocationTableReader(POIFSBigBlockSize pOIFSBigBlockSize, int i2, int[] iArr, int i3, int i4, BlockList blockList) {
        this(pOIFSBigBlockSize);
        sanityCheckBlockCount(i2);
        int min = Math.min(i2, iArr.length);
        RawDataBlock[] rawDataBlockArr = new RawDataBlock[i2];
        int i5 = 0;
        while (i5 < min) {
            int i6 = iArr[i5];
            if (i6 <= blockList.blockCount()) {
                rawDataBlockArr[i5] = (RawDataBlock) blockList.remove(i6);
                i5++;
            } else {
                StringBuilder b2 = a.b("Your file contains ");
                b2.append(blockList.blockCount());
                b2.append(" sectors, but the initial DIFAT array at index ");
                b2.append(i5);
                b2.append(" referenced block # ");
                b2.append(i6);
                b2.append(". This isn't allowed and ");
                b2.append(" your file is corrupt");
                throw new IOException(b2.toString());
            }
        }
        if (i5 < i2) {
            if (i4 >= 0) {
                int xBATEntriesPerBlock = pOIFSBigBlockSize.getXBATEntriesPerBlock();
                int nextXBATChainOffset = pOIFSBigBlockSize.getNextXBATChainOffset();
                for (int i7 = 0; i7 < i3; i7++) {
                    int min2 = Math.min(i2 - i5, xBATEntriesPerBlock);
                    byte[] data = blockList.remove(i4).getData();
                    int i8 = 0;
                    int i9 = 0;
                    while (i8 < min2) {
                        rawDataBlockArr[i5] = (RawDataBlock) blockList.remove(LittleEndian.getInt(data, i9));
                        i9 += 4;
                        i8++;
                        i5++;
                    }
                    i4 = LittleEndian.getInt(data, nextXBATChainOffset);
                    if (i4 == -2) {
                        break;
                    }
                }
            } else {
                throw new IOException("BAT count exceeds limit, yet XBAT index indicates no valid entries");
            }
        }
        if (i5 == i2) {
            setEntries(rawDataBlockArr, blockList);
            return;
        }
        throw new IOException("Could not find all blocks");
    }

    public static void sanityCheckBlockCount(int i2) {
        if (i2 <= 0) {
            throw new IOException(a.b("Illegal block count; minimum count is 1, got ", i2, " instead"));
        } else if (i2 > 65535) {
            throw new IOException(a.b("Block count ", i2, " is too high. POI maximum is ", 65535, "."));
        }
    }

    private void setEntries(ListManagedBlock[] listManagedBlockArr, BlockList blockList) {
        int bATEntriesPerBlock = this.bigBlockSize.getBATEntriesPerBlock();
        for (int i2 = 0; i2 < listManagedBlockArr.length; i2++) {
            byte[] data = listManagedBlockArr[i2].getData();
            int i3 = 0;
            for (int i4 = 0; i4 < bATEntriesPerBlock; i4++) {
                int i5 = LittleEndian.getInt(data, i3);
                if (i5 == -1) {
                    blockList.zap(this._entries.size());
                }
                this._entries.add(i5);
                i3 += 4;
            }
            listManagedBlockArr[i2] = null;
        }
        blockList.setBAT(this);
    }

    public ListManagedBlock[] fetchBlocks(int i2, int i3, BlockList blockList) {
        ArrayList arrayList = new ArrayList();
        boolean z = true;
        while (i2 != -2) {
            try {
                arrayList.add(blockList.remove(i2));
                i2 = this._entries.get(i2);
                z = false;
            } catch (IOException e2) {
                if (i2 == i3) {
                    _logger.log(5, "Warning, header block comes after data blocks in POIFS block listing");
                } else if (i2 != 0 || !z) {
                    throw e2;
                } else {
                    _logger.log(5, "Warning, incorrectly terminated empty data blocks in POIFS block listing (should end at -2, ended at 0)");
                }
                i2 = -2;
            }
        }
        return (ListManagedBlock[]) arrayList.toArray(new ListManagedBlock[arrayList.size()]);
    }

    @Internal
    public IntList getEntries() {
        return this._entries;
    }

    public int getNextBlockIndex(int i2) {
        if (isUsed(i2)) {
            return this._entries.get(i2);
        }
        throw new IOException(a.b("index ", i2, " is unused"));
    }

    public boolean isUsed(int i2) {
        try {
            return this._entries.get(i2) != -1;
        } catch (IndexOutOfBoundsException unused) {
            return false;
        }
    }

    public BlockAllocationTableReader(POIFSBigBlockSize pOIFSBigBlockSize, ListManagedBlock[] listManagedBlockArr, BlockList blockList) {
        this(pOIFSBigBlockSize);
        setEntries(listManagedBlockArr, blockList);
    }

    public BlockAllocationTableReader(POIFSBigBlockSize pOIFSBigBlockSize) {
        this.bigBlockSize = pOIFSBigBlockSize;
        this._entries = new IntList();
    }
}
