package org.apache.poi.poifs.storage;

import java.io.OutputStream;
import java.nio.ByteBuffer;
import org.apache.poi.poifs.common.POIFSBigBlockSize;
import org.apache.poi.poifs.filesystem.BATManaged;
import org.apache.poi.util.IntList;

public final class BlockAllocationTableWriter implements BlockWritable, BATManaged {
    public POIFSBigBlockSize _bigBlockSize;
    public BATBlock[] _blocks = new BATBlock[0];
    public IntList _entries = new IntList();
    public int _start_block = -2;

    public BlockAllocationTableWriter(POIFSBigBlockSize pOIFSBigBlockSize) {
        this._bigBlockSize = pOIFSBigBlockSize;
    }

    public static void writeBlock(BATBlock bATBlock, ByteBuffer byteBuffer) {
        bATBlock.writeData(byteBuffer);
    }

    public int allocateSpace(int i2) {
        int size = this._entries.size();
        if (i2 > 0) {
            int i3 = i2 - 1;
            int i4 = size + 1;
            int i5 = 0;
            while (i5 < i3) {
                this._entries.add(i4);
                i5++;
                i4++;
            }
            this._entries.add(-2);
        }
        return size;
    }

    @Override // org.apache.poi.poifs.filesystem.BATManaged
    public int countBlocks() {
        return this._blocks.length;
    }

    public int createBlocks() {
        int i2 = 0;
        int i3 = 0;
        while (true) {
            int calculateStorageRequirements = BATBlock.calculateStorageRequirements(this._bigBlockSize, this._entries.size() + i2 + i3);
            int calculateXBATStorageRequirements = HeaderBlockWriter.calculateXBATStorageRequirements(this._bigBlockSize, calculateStorageRequirements);
            if (i2 == calculateStorageRequirements && i3 == calculateXBATStorageRequirements) {
                int allocateSpace = allocateSpace(i2);
                allocateSpace(i3);
                simpleCreateBlocks();
                return allocateSpace;
            }
            i2 = calculateStorageRequirements;
            i3 = calculateXBATStorageRequirements;
        }
    }

    public int getStartBlock() {
        return this._start_block;
    }

    @Override // org.apache.poi.poifs.filesystem.BATManaged
    public void setStartBlock(int i2) {
        this._start_block = i2;
    }

    public void simpleCreateBlocks() {
        this._blocks = BATBlock.createBATBlocks(this._bigBlockSize, this._entries.toArray());
    }

    @Override // org.apache.poi.poifs.storage.BlockWritable
    public void writeBlocks(OutputStream outputStream) {
        int i2 = 0;
        while (true) {
            BATBlock[] bATBlockArr = this._blocks;
            if (i2 < bATBlockArr.length) {
                bATBlockArr[i2].writeBlocks(outputStream);
                i2++;
            } else {
                return;
            }
        }
    }
}
