package org.apache.poi.poifs.storage;

import java.io.OutputStream;
import java.util.ArrayList;
import java.util.List;
import org.apache.poi.poifs.common.POIFSBigBlockSize;
import org.apache.poi.poifs.filesystem.BATManaged;
import org.apache.poi.poifs.filesystem.OPOIFSDocument;
import org.apache.poi.poifs.property.RootProperty;

public class SmallBlockTableWriter implements BlockWritable, BATManaged {
    public int _big_block_count;
    public RootProperty _root;
    public BlockAllocationTableWriter _sbat;
    public List<SmallDocumentBlock> _small_blocks = new ArrayList();

    public SmallBlockTableWriter(POIFSBigBlockSize pOIFSBigBlockSize, List<OPOIFSDocument> list, RootProperty rootProperty) {
        this._sbat = new BlockAllocationTableWriter(pOIFSBigBlockSize);
        this._root = rootProperty;
        for (OPOIFSDocument oPOIFSDocument : list) {
            SmallDocumentBlock[] smallBlocks = oPOIFSDocument.getSmallBlocks();
            if (smallBlocks.length != 0) {
                oPOIFSDocument.setStartBlock(this._sbat.allocateSpace(smallBlocks.length));
                for (SmallDocumentBlock smallDocumentBlock : smallBlocks) {
                    this._small_blocks.add(smallDocumentBlock);
                }
            } else {
                oPOIFSDocument.setStartBlock(-2);
            }
        }
        this._sbat.simpleCreateBlocks();
        this._root.setSize(this._small_blocks.size());
        this._big_block_count = SmallDocumentBlock.fill(pOIFSBigBlockSize, this._small_blocks);
    }

    @Override // org.apache.poi.poifs.filesystem.BATManaged
    public int countBlocks() {
        return this._big_block_count;
    }

    public BlockAllocationTableWriter getSBAT() {
        return this._sbat;
    }

    public int getSBATBlockCount() {
        return (this._big_block_count + 15) / 16;
    }

    @Override // org.apache.poi.poifs.filesystem.BATManaged
    public void setStartBlock(int i2) {
        this._root.setStartBlock(i2);
    }

    @Override // org.apache.poi.poifs.storage.BlockWritable
    public void writeBlocks(OutputStream outputStream) {
        for (SmallDocumentBlock smallDocumentBlock : this._small_blocks) {
            smallDocumentBlock.writeBlocks(outputStream);
        }
    }
}
