package org.apache.poi.sl.draw;

import java.awt.Graphics2D;
import java.awt.geom.AffineTransform;
import java.awt.geom.Rectangle2D;
import java.util.Iterator;
import org.apache.poi.sl.usermodel.GroupShape;
import org.apache.poi.sl.usermodel.Shape;
import org.apache.poi.ss.formula.functions.NumericFunction;

public class DrawGroupShape extends DrawShape {
    public DrawGroupShape(GroupShape<?, ?> groupShape) {
        super(groupShape);
    }

    @Override // org.apache.poi.sl.draw.DrawShape, org.apache.poi.sl.draw.Drawable
    public void draw(Graphics2D graphics2D) {
        Rectangle2D interiorAnchor = getShape().getInteriorAnchor();
        Rectangle2D anchor = getShape().getAnchor();
        AffineTransform affineTransform = (AffineTransform) graphics2D.getRenderingHint(Drawable.GROUP_TRANSFORM);
        AffineTransform affineTransform2 = new AffineTransform(affineTransform);
        double d2 = 1.0d;
        double width = interiorAnchor.getWidth() == NumericFunction.LOG_10_TO_BASE_e ? 1.0d : anchor.getWidth() / interiorAnchor.getWidth();
        if (interiorAnchor.getHeight() != NumericFunction.LOG_10_TO_BASE_e) {
            d2 = anchor.getHeight() / interiorAnchor.getHeight();
        }
        affineTransform.translate(anchor.getX(), anchor.getY());
        affineTransform.scale(width, d2);
        affineTransform.translate(-interiorAnchor.getX(), -interiorAnchor.getY());
        DrawFactory instance = DrawFactory.getInstance(graphics2D);
        AffineTransform transform = graphics2D.getTransform();
        Iterator<T> it = getShape().iterator();
        while (it.hasNext()) {
            AffineTransform transform2 = graphics2D.getTransform();
            graphics2D.setRenderingHint(Drawable.GSAVE, true);
            Drawable drawable = instance.getDrawable((Shape<?, ?>) it.next());
            drawable.applyTransform(graphics2D);
            drawable.draw(graphics2D);
            graphics2D.setTransform(transform2);
            graphics2D.setRenderingHint(Drawable.GRESTORE, true);
        }
        graphics2D.setTransform(transform);
        graphics2D.setRenderingHint(Drawable.GROUP_TRANSFORM, affineTransform2);
    }

    @Override // org.apache.poi.sl.draw.DrawShape
    public GroupShape<?, ?> getShape() {
        return (GroupShape) this.shape;
    }
}
