package org.apache.poi.sl.draw;

import b.b.a.a.a;
import java.awt.Graphics2D;
import java.awt.font.TextLayout;
import java.text.AttributedCharacterIterator;
import java.text.AttributedString;
import org.apache.poi.ss.formula.functions.NumericFunction;

public class DrawTextFragment implements Drawable {
    public final TextLayout layout;
    public final AttributedString str;
    public double x;
    public double y;

    public DrawTextFragment(TextLayout textLayout, AttributedString attributedString) {
        this.layout = textLayout;
        this.str = attributedString;
    }

    @Override // org.apache.poi.sl.draw.Drawable
    public void applyTransform(Graphics2D graphics2D) {
    }

    @Override // org.apache.poi.sl.draw.Drawable
    public void draw(Graphics2D graphics2D) {
        if (this.str != null) {
            double ascent = this.y + ((double) this.layout.getAscent());
            Integer num = (Integer) graphics2D.getRenderingHint(Drawable.TEXT_RENDERING_MODE);
            if (num == null || num.intValue() != 2) {
                graphics2D.drawString(this.str.getIterator(), (float) this.x, (float) ascent);
            } else {
                this.layout.draw(graphics2D, (float) this.x, (float) ascent);
            }
        }
    }

    @Override // org.apache.poi.sl.draw.Drawable
    public void drawContent(Graphics2D graphics2D) {
    }

    public AttributedString getAttributedString() {
        return this.str;
    }

    public float getHeight() {
        return (float) ((double) (getLeading() + this.layout.getAscent() + this.layout.getDescent()));
    }

    public TextLayout getLayout() {
        return this.layout;
    }

    public float getLeading() {
        double leading = (double) this.layout.getLeading();
        if (leading == NumericFunction.LOG_10_TO_BASE_e) {
            leading = ((double) (this.layout.getAscent() + this.layout.getDescent())) * 0.15d;
        }
        return (float) leading;
    }

    public String getString() {
        AttributedString attributedString = this.str;
        if (attributedString == null) {
            return "";
        }
        AttributedCharacterIterator iterator = attributedString.getIterator();
        StringBuilder sb = new StringBuilder();
        for (char first = iterator.first(); first != 65535; first = iterator.next()) {
            sb.append(first);
        }
        return sb.toString();
    }

    public float getWidth() {
        return this.layout.getAdvance();
    }

    public void setPosition(double d2, double d3) {
        this.x = d2;
        this.y = d3;
    }

    public String toString() {
        StringBuilder b2 = a.b("[");
        b2.append(DrawTextFragment.class.getSimpleName());
        b2.append("] ");
        b2.append(getString());
        return b2.toString();
    }
}
