package org.apache.poi.sl.draw.geom;

import java.awt.geom.Rectangle2D;
import java.util.HashMap;
import java.util.Map;

public class Context {
    public final Rectangle2D _anchor;
    public final Map<String, Double> _ctx = new HashMap();
    public final IAdjustableShape _props;

    public Context(CustomGeometry customGeometry, Rectangle2D rectangle2D, IAdjustableShape iAdjustableShape) {
        this._props = iAdjustableShape;
        this._anchor = rectangle2D;
        for (Guide guide : customGeometry.adjusts) {
            evaluate(guide);
        }
        for (Guide guide2 : customGeometry.guides) {
            evaluate(guide2);
        }
    }

    public double evaluate(Formula formula) {
        String name;
        double evaluate = formula.evaluate(this);
        if ((formula instanceof Guide) && (name = ((Guide) formula).getName()) != null) {
            this._ctx.put(name, Double.valueOf(evaluate));
        }
        return evaluate;
    }

    public Guide getAdjustValue(String str) {
        return this._props.getAdjustValue(str);
    }

    public Rectangle2D getShapeAnchor() {
        return this._anchor;
    }

    public double getValue(String str) {
        if (str.matches("(\\+|-)?\\d+")) {
            return Double.parseDouble(str);
        }
        Double d2 = this._ctx.get(str);
        if (d2 != null) {
            return d2.doubleValue();
        }
        return evaluate(BuiltInGuide.valueOf("_" + str));
    }
}
