package org.apache.poi.sl.draw.geom;

import java.util.ArrayList;
import java.util.Iterator;
import java.util.List;
import org.apache.poi.sl.draw.binding.CTCustomGeometry2D;
import org.apache.poi.sl.draw.binding.CTGeomGuide;
import org.apache.poi.sl.draw.binding.CTGeomGuideList;
import org.apache.poi.sl.draw.binding.CTGeomRect;
import org.apache.poi.sl.draw.binding.CTPath2D;
import org.apache.poi.sl.draw.binding.CTPath2DList;

public class CustomGeometry implements Iterable<Path> {
    public final List<Guide> adjusts = new ArrayList();
    public final List<Guide> guides = new ArrayList();
    public final List<Path> paths = new ArrayList();
    public Path textBounds;

    public CustomGeometry(CTCustomGeometry2D cTCustomGeometry2D) {
        CTGeomGuideList avLst = cTCustomGeometry2D.getAvLst();
        if (avLst != null) {
            for (CTGeomGuide cTGeomGuide : avLst.getGd()) {
                this.adjusts.add(new AdjustValue(cTGeomGuide));
            }
        }
        CTGeomGuideList gdLst = cTCustomGeometry2D.getGdLst();
        if (gdLst != null) {
            for (CTGeomGuide cTGeomGuide2 : gdLst.getGd()) {
                this.guides.add(new Guide(cTGeomGuide2));
            }
        }
        CTPath2DList pathLst = cTCustomGeometry2D.getPathLst();
        if (pathLst != null) {
            for (CTPath2D cTPath2D : pathLst.getPath()) {
                this.paths.add(new Path(cTPath2D));
            }
        }
        CTGeomRect rect = cTCustomGeometry2D.getRect();
        if (rect != null) {
            Path path = new Path();
            this.textBounds = path;
            path.addCommand(new MoveToCommand(rect.getL(), rect.getT()));
            this.textBounds.addCommand(new LineToCommand(rect.getR(), rect.getT()));
            this.textBounds.addCommand(new LineToCommand(rect.getR(), rect.getB()));
            this.textBounds.addCommand(new LineToCommand(rect.getL(), rect.getB()));
            this.textBounds.addCommand(new ClosePathCommand());
        }
    }

    public Path getTextBounds() {
        return this.textBounds;
    }

    @Override // java.lang.Iterable
    public Iterator<Path> iterator() {
        return this.paths.iterator();
    }
}
