package org.apache.poi.sl.usermodel;

import java.awt.Dimension;
import org.apache.poi.openxml4j.opc.ContentTypes;

public interface PictureData {

    public enum PictureType {
        EMF(2, 2, "image/x-emf", ".emf"),
        WMF(3, 3, "image/x-wmf", ".wmf"),
        PICT(4, 4, ContentTypes.IMAGE_PICT, ".pict"),
        JPEG(5, 5, ContentTypes.IMAGE_JPEG, ".jpg"),
        PNG(6, 6, ContentTypes.IMAGE_PNG, ".png"),
        DIB(7, 7, "image/dib", ".dib"),
        GIF(-1, 8, ContentTypes.IMAGE_GIF, ".gif"),
        TIFF(-1, 9, ContentTypes.IMAGE_TIFF, ".tif"),
        EPS(-1, 10, "image/x-eps", ".eps"),
        BMP(-1, 11, "image/x-ms-bmp", ".bmp"),
        WPG(-1, 12, "image/x-wpg", ".wpg"),
        WDP(-1, 13, "image/vnd.ms-photo", ".wdp");
        
        public final String contentType;
        public final String extension;
        public final int nativeId;
        public final int ooxmlId;

        /* access modifiers changed from: public */
        PictureType(int i2, int i3, String str, String str2) {
            this.nativeId = i2;
            this.ooxmlId = i3;
            this.contentType = str;
            this.extension = str2;
        }

        public static PictureType forNativeID(int i2) {
            PictureType[] values = values();
            for (PictureType pictureType : values) {
                if (pictureType.nativeId == i2) {
                    return pictureType;
                }
            }
            return null;
        }

        public static PictureType forOoxmlID(int i2) {
            PictureType[] values = values();
            for (PictureType pictureType : values) {
                if (pictureType.ooxmlId == i2) {
                    return pictureType;
                }
            }
            return null;
        }
    }

    byte[] getChecksum();

    String getContentType();

    byte[] getData();

    Dimension getImageDimension();

    Dimension getImageDimensionInPixels();

    PictureType getType();

    void setData(byte[] bArr);
}
