package org.apache.poi.sl.usermodel;

public interface StrokeStyle {

    public enum LineCap {
        ROUND(0, 1),
        SQUARE(1, 2),
        FLAT(2, 3);
        
        public final int nativeId;
        public final int ooxmlId;

        /* access modifiers changed from: public */
        LineCap(int i2, int i3) {
            this.nativeId = i2;
            this.ooxmlId = i3;
        }

        public static LineCap fromNativeId(int i2) {
            LineCap[] values = values();
            for (LineCap lineCap : values) {
                if (lineCap.nativeId == i2) {
                    return lineCap;
                }
            }
            return null;
        }

        public static LineCap fromOoxmlId(int i2) {
            LineCap[] values = values();
            for (LineCap lineCap : values) {
                if (lineCap.ooxmlId == i2) {
                    return lineCap;
                }
            }
            return null;
        }
    }

    public enum LineCompound {
        SINGLE(0, 1),
        DOUBLE(1, 2),
        THICK_THIN(2, 3),
        THIN_THICK(3, 4),
        TRIPLE(4, 5);
        
        public final int nativeId;
        public final int ooxmlId;

        /* access modifiers changed from: public */
        LineCompound(int i2, int i3) {
            this.nativeId = i2;
            this.ooxmlId = i3;
        }

        public static LineCompound fromNativeId(int i2) {
            LineCompound[] values = values();
            for (LineCompound lineCompound : values) {
                if (lineCompound.nativeId == i2) {
                    return lineCompound;
                }
            }
            return null;
        }

        public static LineCompound fromOoxmlId(int i2) {
            LineCompound[] values = values();
            for (LineCompound lineCompound : values) {
                if (lineCompound.ooxmlId == i2) {
                    return lineCompound;
                }
            }
            return null;
        }
    }

    public enum LineDash {
        SOLID(1, 1, null),
        DOT(6, 2, 1, 1),
        DASH(7, 3, 3, 4),
        DASH_DOT(9, 5, 4, 3, 1, 3),
        LG_DASH(8, 4, 8, 3),
        LG_DASH_DOT(10, 6, 8, 3, 1, 3),
        LG_DASH_DOT_DOT(11, 7, 8, 3, 1, 3, 1, 3),
        SYS_DASH(2, 8, 2, 2),
        SYS_DOT(3, 9, 1, 1),
        SYS_DASH_DOT(4, 10, 2, 2, 1, 1),
        SYS_DASH_DOT_DOT(5, 11, 2, 2, 1, 1, 1, 1);
        
        public final int nativeId;
        public final int ooxmlId;
        public final int[] pattern;

        /* access modifiers changed from: public */
        LineDash(int i2, int i3, int... iArr) {
            this.nativeId = i2;
            this.ooxmlId = i3;
            this.pattern = (iArr == null || iArr.length == 0) ? null : iArr;
        }

        public static LineDash fromNativeId(int i2) {
            LineDash[] values = values();
            for (LineDash lineDash : values) {
                if (lineDash.nativeId == i2) {
                    return lineDash;
                }
            }
            return null;
        }

        public static LineDash fromOoxmlId(int i2) {
            LineDash[] values = values();
            for (LineDash lineDash : values) {
                if (lineDash.ooxmlId == i2) {
                    return lineDash;
                }
            }
            return null;
        }
    }

    LineCap getLineCap();

    LineCompound getLineCompound();

    LineDash getLineDash();

    double getLineWidth();

    PaintStyle getPaint();
}
