package org.apache.poi.ss.format;

import b.b.a.a.a;
import java.util.ArrayList;
import java.util.Formatter;
import java.util.List;
import java.util.ListIterator;
import java.util.Locale;
import java.util.regex.Matcher;
import java.util.regex.Pattern;
import org.apache.poi.ss.format.CellFormatPart;
import org.apache.poi.ss.formula.functions.NumericFunction;
import org.apache.poi.ss.formula.ptg.PercentPtg;
import org.apache.xmlbeans.impl.common.NameUtil;

public class CellElapsedFormatter extends CellFormatter {
    public static final double HOUR__FACTOR = 0.041666666666666664d;
    public static final double MIN__FACTOR = 6.944444444444444E-4d;
    public static final Pattern PERCENTS = Pattern.compile(PercentPtg.PERCENT);
    public static final double SEC__FACTOR = 1.1574074074074073E-5d;
    public final String printfFmt;
    public final List<TimeSpec> specs = new ArrayList();
    public TimeSpec topmost;

    public class ElapsedPartHandler implements CellFormatPart.PartHandler {
        public ElapsedPartHandler() {
        }

        @Override // org.apache.poi.ss.format.CellFormatPart.PartHandler
        public String handlePart(Matcher matcher, String str, CellFormatType cellFormatType, StringBuffer stringBuffer) {
            int length = stringBuffer.length();
            char charAt = str.charAt(0);
            if (charAt == '\n') {
                return "%n";
            }
            if (charAt == '\"') {
                str = str.substring(1, str.length() - 1);
            } else if (charAt != '*') {
                if (charAt != '0') {
                    if (charAt == '_') {
                        return null;
                    }
                    if (!(charAt == 'h' || charAt == 'm' || charAt == 's')) {
                        if (charAt != '[') {
                            if (charAt == '\\') {
                                str = str.substring(1);
                            }
                        } else if (str.length() >= 3) {
                            if (CellElapsedFormatter.this.topmost == null) {
                                String lowerCase = str.toLowerCase(Locale.ROOT);
                                int length2 = lowerCase.length() - 2;
                                CellElapsedFormatter cellElapsedFormatter = CellElapsedFormatter.this;
                                cellElapsedFormatter.topmost = cellElapsedFormatter.assignSpec(lowerCase.charAt(1), length, length2);
                                return lowerCase.substring(1, length2 + 1);
                            }
                            throw new IllegalArgumentException("Duplicate '[' times in format");
                        }
                    }
                }
                String lowerCase2 = str.toLowerCase(Locale.ROOT);
                CellElapsedFormatter.this.assignSpec(lowerCase2.charAt(0), length, lowerCase2.length());
                return lowerCase2;
            } else if (str.length() > 1) {
                str = CellFormatPart.expandChar(str);
            }
            return CellElapsedFormatter.PERCENTS.matcher(str).replaceAll("%%");
        }
    }

    public static class TimeSpec {
        public final double factor;
        public final int len;
        public double modBy = NumericFunction.LOG_10_TO_BASE_e;
        public final int pos;
        public final char type;

        public TimeSpec(char c, int i2, int i3, double d2) {
            this.type = c;
            this.pos = i2;
            this.len = i3;
            this.factor = d2;
        }

        public long valueFor(double d2) {
            double d3;
            double d4 = this.modBy;
            if (d4 == NumericFunction.LOG_10_TO_BASE_e) {
                d3 = d2 / this.factor;
            } else {
                d3 = (d2 / this.factor) % d4;
            }
            return this.type == '0' ? Math.round(d3) : (long) d3;
        }
    }

    public CellElapsedFormatter(String str) {
        super(str);
        StringBuffer parseFormat = CellFormatPart.parseFormat(str, CellFormatType.ELAPSED, new ElapsedPartHandler());
        List<TimeSpec> list = this.specs;
        ListIterator<TimeSpec> listIterator = list.listIterator(list.size());
        while (listIterator.hasPrevious()) {
            TimeSpec previous = listIterator.previous();
            int i2 = previous.pos;
            parseFormat.replace(i2, previous.len + i2, a.a(a.b("%0"), previous.len, "d"));
            char c = previous.type;
            if (c != this.topmost.type) {
                previous.modBy = modFor(c, previous.len);
            }
        }
        this.printfFmt = parseFormat.toString();
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private TimeSpec assignSpec(char c, int i2, int i3) {
        TimeSpec timeSpec = new TimeSpec(c, i2, i3, factorFor(c, i3));
        this.specs.add(timeSpec);
        return timeSpec;
    }

    public static double factorFor(char c, int i2) {
        if (c == '0') {
            return 1.1574074074074073E-5d / Math.pow(10.0d, (double) i2);
        }
        if (c == 'h') {
            return 0.041666666666666664d;
        }
        if (c == 'm') {
            return 6.944444444444444E-4d;
        }
        if (c == 's') {
            return 1.1574074074074073E-5d;
        }
        throw new IllegalArgumentException("Uknown elapsed time spec: " + c);
    }

    public static double modFor(char c, int i2) {
        if (c == '0') {
            return Math.pow(10.0d, (double) i2);
        }
        if (c == 'h') {
            return 24.0d;
        }
        if (c == 'm' || c == 's') {
            return 60.0d;
        }
        throw new IllegalArgumentException("Uknown elapsed time spec: " + c);
    }

    @Override // org.apache.poi.ss.format.CellFormatter
    public void formatValue(StringBuffer stringBuffer, Object obj) {
        double doubleValue = ((Number) obj).doubleValue();
        if (doubleValue < NumericFunction.LOG_10_TO_BASE_e) {
            stringBuffer.append(NameUtil.HYPHEN);
            doubleValue = -doubleValue;
        }
        Long[] lArr = new Long[this.specs.size()];
        for (int i2 = 0; i2 < this.specs.size(); i2++) {
            lArr[i2] = Long.valueOf(this.specs.get(i2).valueFor(doubleValue));
        }
        Formatter formatter = new Formatter(stringBuffer, Locale.ROOT);
        try {
            formatter.format(this.printfFmt, lArr);
        } finally {
            formatter.close();
        }
    }

    @Override // org.apache.poi.ss.format.CellFormatter
    public void simpleValue(StringBuffer stringBuffer, Object obj) {
        formatValue(stringBuffer, obj);
    }
}
