package org.apache.poi.ss.format;

import b.b.a.a.a;
import java.awt.Color;
import java.util.Locale;
import java.util.Map;
import java.util.TreeMap;
import java.util.logging.Logger;
import java.util.regex.Matcher;
import java.util.regex.Pattern;
import javax.swing.JLabel;
import org.apache.poi.hssf.util.HSSFColor;
import org.apache.poi.ss.formula.ptg.PercentPtg;
import org.apache.poi.util.LocaleUtil;
import org.apache.xmlbeans.impl.common.NameUtil;

public class CellFormatPart {
    public static final int COLOR_GROUP;
    public static final Pattern COLOR_PAT = Pattern.compile("\\[(black|blue|cyan|green|magenta|red|white|yellow|color [0-9]+)\\]", 6);
    public static final int CONDITION_OPERATOR_GROUP = findGroup(FORMAT_PAT, "[>=1]@", ">=");
    public static final Pattern CONDITION_PAT = Pattern.compile("([<>=]=?|!=|<>)    # The operator\n  \\s*([0-9]+(?:\\.[0-9]*)?)\\s*  # The constant to test against\n", 6);
    public static final int CONDITION_VALUE_GROUP = findGroup(FORMAT_PAT, "[>=1]@", "1");
    public static final Pattern CURRENCY_PAT = Pattern.compile("(\\[\\$.{0,3}-[0-9a-f]{3}\\])", 6);
    public static final Pattern FORMAT_PAT;
    public static final Map<String, Color> NAMED_COLORS = new TreeMap(String.CASE_INSENSITIVE_ORDER);
    public static final int SPECIFICATION_GROUP = findGroup(FORMAT_PAT, "[Blue][>1]\\a ?", "\\a ?");
    public static final Pattern SPECIFICATION_PAT;
    public final Color color;
    public CellFormatCondition condition;
    public final CellFormatter format;
    public final CellFormatType type;

    public interface PartHandler {
        String handlePart(Matcher matcher, String str, CellFormatType cellFormatType, StringBuffer stringBuffer);
    }

    static {
        for (HSSFColor hSSFColor : HSSFColor.getIndexHash().values()) {
            String simpleName = hSSFColor.getClass().getSimpleName();
            if (simpleName.equals(simpleName.toUpperCase(Locale.ROOT))) {
                short[] triplet = hSSFColor.getTriplet();
                Color color2 = new Color(triplet[0], triplet[1], triplet[2]);
                NAMED_COLORS.put(simpleName, color2);
                if (simpleName.indexOf(95) > 0) {
                    NAMED_COLORS.put(simpleName.replace(NameUtil.USCORE, ' '), color2);
                }
                if (simpleName.indexOf("_PERCENT") > 0) {
                    NAMED_COLORS.put(simpleName.replace("_PERCENT", PercentPtg.PERCENT).replace(NameUtil.USCORE, ' '), color2);
                }
            }
        }
        StringBuilder sb = new StringBuilder();
        sb.append("\\\\.                 # Quoted single character\n|\"([^\\\\\"]|\\\\.)*\"         # Quoted string of characters (handles escaped quotes like \\\") \n|");
        sb.append("(\\[\\$.{0,3}-[0-9a-f]{3}\\])");
        sb.append("                   # Currency symbol in a given locale\n");
        sb.append("|_.                             # Space as wide as a given character\n");
        sb.append("|\\*.                           # Repeating fill character\n");
        sb.append("|@                              # Text: cell text\n");
        sb.append("|([0?\\#](?:[0?\\#,]*))         # Number: digit + other digits and commas\n");
        sb.append("|e[-+]                          # Number: Scientific: Exponent\n");
        sb.append("|m{1,5}                         # Date: month or minute spec\n");
        sb.append("|d{1,4}                         # Date: day/date spec\n");
        sb.append("|y{2,4}                         # Date: year spec\n");
        sb.append("|h{1,2}                         # Date: hour spec\n");
        sb.append("|s{1,2}                         # Date: second spec\n");
        sb.append("|am?/pm?                        # Date: am/pm spec\n");
        sb.append("|\\[h{1,2}\\]                   # Elapsed time: hour spec\n");
        sb.append("|\\[m{1,2}\\]                   # Elapsed time: minute spec\n");
        sb.append("|\\[s{1,2}\\]                   # Elapsed time: second spec\n");
        String a = a.a(sb, "|[^;]                           # A character\n", "");
        SPECIFICATION_PAT = Pattern.compile(a, 6);
        Pattern compile = Pattern.compile("(?:" + "\\[(black|blue|cyan|green|magenta|red|white|yellow|color [0-9]+)\\]" + ")?                 # Text color\n" + "(?:\\[" + "([<>=]=?|!=|<>)    # The operator\n  \\s*([0-9]+(?:\\.[0-9]*)?)\\s*  # The constant to test against\n" + "\\])?               # Condition\n" + "(?:\\[\\$-[0-9a-fA-F]+\\])?                # Optional locale id, ignored currently\n" + "((?:" + a + ")+)                        # Format spec\n", 6);
        FORMAT_PAT = compile;
        COLOR_GROUP = findGroup(compile, "[Blue]@", "Blue");
    }

    public CellFormatPart(String str) {
        this(LocaleUtil.getUserLocale(), str);
    }

    public static String expandChar(String str) {
        char charAt = str.charAt(1);
        return "" + charAt + charAt + charAt;
    }

    public static int findGroup(Pattern pattern, String str, String str2) {
        Matcher matcher = pattern.matcher(str);
        if (matcher.find()) {
            for (int i2 = 1; i2 <= matcher.groupCount(); i2++) {
                String group = matcher.group(i2);
                if (group != null && group.equals(str2)) {
                    return i2;
                }
            }
            StringBuilder d2 = a.d("\"", str2, "\" not found in \"");
            d2.append(pattern.pattern());
            d2.append("\"");
            throw new IllegalArgumentException(d2.toString());
        }
        StringBuilder b2 = a.b("Pattern \"");
        b2.append(pattern.pattern());
        b2.append("\" doesn't match \"");
        b2.append(str);
        b2.append("\"");
        throw new IllegalArgumentException(b2.toString());
    }

    private CellFormatType formatType(String str) {
        String trim = str.trim();
        if (trim.equals("") || trim.equalsIgnoreCase("General")) {
            return CellFormatType.GENERAL;
        }
        Matcher matcher = SPECIFICATION_PAT.matcher(trim);
        boolean z = false;
        boolean z2 = false;
        while (matcher.find()) {
            String group = matcher.group(0);
            if (group.length() > 0) {
                char charAt = group.charAt(0);
                char lowerCase = group.length() > 1 ? Character.toLowerCase(group.charAt(1)) : 0;
                switch (charAt) {
                    case '#':
                    case '?':
                        return CellFormatType.NUMBER;
                    case '0':
                        z2 = true;
                        continue;
                    case '@':
                        return CellFormatType.TEXT;
                    case 'D':
                    case 'Y':
                    case 'd':
                    case 'y':
                        return CellFormatType.DATE;
                    case 'H':
                    case 'M':
                    case 'S':
                    case 'h':
                    case 'm':
                    case 's':
                        z = true;
                        continue;
                    case '[':
                        if (lowerCase == 'h' || lowerCase == 'm' || lowerCase == 's') {
                            return CellFormatType.ELAPSED;
                        }
                        if (lowerCase == '$') {
                            return CellFormatType.NUMBER;
                        }
                        throw new IllegalArgumentException("Unsupported [] format block '" + group + "' in '" + trim + "' with c2: " + lowerCase);
                }
            }
        }
        if (z) {
            return CellFormatType.DATE;
        }
        if (z2) {
            return CellFormatType.NUMBER;
        }
        return CellFormatType.TEXT;
    }

    private CellFormatType getCellFormatType(Matcher matcher) {
        return formatType(matcher.group(SPECIFICATION_GROUP));
    }

    public static Color getColor(Matcher matcher) {
        String group = matcher.group(COLOR_GROUP);
        if (group == null || group.length() == 0) {
            return null;
        }
        Color color2 = NAMED_COLORS.get(group);
        if (color2 == null) {
            Logger logger = CellFormatter.logger;
            StringBuilder b2 = a.b("Unknown color: ");
            b2.append(CellFormatter.quote(group));
            logger.warning(b2.toString());
        }
        return color2;
    }

    private CellFormatCondition getCondition(Matcher matcher) {
        String group = matcher.group(CONDITION_OPERATOR_GROUP);
        if (group == null || group.length() == 0) {
            return null;
        }
        return CellFormatCondition.getInstance(matcher.group(CONDITION_OPERATOR_GROUP), matcher.group(CONDITION_VALUE_GROUP));
    }

    private CellFormatter getFormatter(Locale locale, Matcher matcher) {
        String str;
        String group = matcher.group(SPECIFICATION_GROUP);
        Matcher matcher2 = CURRENCY_PAT.matcher(group);
        if (matcher2.find()) {
            String group2 = matcher2.group(1);
            if (group2.startsWith("[$-")) {
                str = "$";
            } else {
                str = group2.substring(2, group2.lastIndexOf(45));
            }
            group = group.replace(group2, str);
        }
        return this.type.formatter(locale, group);
    }

    public static String group(Matcher matcher, int i2) {
        String group = matcher.group(i2);
        return group == null ? "" : group;
    }

    public static StringBuffer parseFormat(String str, CellFormatType cellFormatType, PartHandler partHandler) {
        int i2;
        Matcher matcher = SPECIFICATION_PAT.matcher(str);
        StringBuffer stringBuffer = new StringBuffer();
        while (true) {
            i2 = 0;
            if (!matcher.find()) {
                break;
            }
            String group = group(matcher, 0);
            if (group.length() > 0) {
                String handlePart = partHandler.handlePart(matcher, group, cellFormatType, stringBuffer);
                if (handlePart == null) {
                    char charAt = group.charAt(0);
                    if (charAt == '\"') {
                        group = quoteSpecial(group.substring(1, group.length() - 1), cellFormatType);
                    } else if (charAt == '*') {
                        group = expandChar(group);
                    } else if (charAt == '\\') {
                        group = quoteSpecial(group.substring(1), cellFormatType);
                    } else if (charAt == '_') {
                        group = " ";
                    }
                } else {
                    group = handlePart;
                }
                matcher.appendReplacement(stringBuffer, Matcher.quoteReplacement(group));
            }
        }
        matcher.appendTail(stringBuffer);
        if (cellFormatType.isSpecial('\'')) {
            int i3 = 0;
            while (true) {
                i3 = stringBuffer.indexOf("''", i3);
                if (i3 < 0) {
                    break;
                }
                stringBuffer.delete(i3, i3 + 2);
            }
            while (true) {
                i2 = stringBuffer.indexOf("\u0000", i2);
                if (i2 < 0) {
                    break;
                }
                stringBuffer.replace(i2, i2 + 1, "''");
            }
        }
        return stringBuffer;
    }

    public static String quoteSpecial(String str, CellFormatType cellFormatType) {
        StringBuilder sb = new StringBuilder();
        for (int i2 = 0; i2 < str.length(); i2++) {
            char charAt = str.charAt(i2);
            if (charAt != '\'' || !cellFormatType.isSpecial('\'')) {
                boolean isSpecial = cellFormatType.isSpecial(charAt);
                if (isSpecial) {
                    sb.append("'");
                }
                sb.append(charAt);
                if (isSpecial) {
                    sb.append("'");
                }
            } else {
                sb.append((char) 0);
            }
        }
        return sb.toString();
    }

    public boolean applies(Object obj) {
        CellFormatCondition cellFormatCondition = this.condition;
        if (cellFormatCondition != null && (obj instanceof Number)) {
            return cellFormatCondition.pass(((Number) obj).doubleValue());
        }
        if (obj != null) {
            return true;
        }
        throw new NullPointerException("valueObject");
    }

    public CellFormatResult apply(Object obj) {
        String str;
        Color color2;
        boolean applies = applies(obj);
        if (applies) {
            str = this.format.format(obj);
            color2 = this.color;
        } else {
            str = this.format.simpleFormat(obj);
            color2 = null;
        }
        return new CellFormatResult(applies, str, color2);
    }

    public boolean hasCondition() {
        return this.condition != null;
    }

    public String toString() {
        return this.format.format;
    }

    public CellFormatPart(Locale locale, String str) {
        Matcher matcher = FORMAT_PAT.matcher(str);
        if (matcher.matches()) {
            this.color = getColor(matcher);
            this.condition = getCondition(matcher);
            this.type = getCellFormatType(matcher);
            this.format = getFormatter(locale, matcher);
            return;
        }
        StringBuilder b2 = a.b("Unrecognized format: ");
        b2.append(CellFormatter.quote(str));
        throw new IllegalArgumentException(b2.toString());
    }

    public CellFormatType getCellFormatType() {
        return this.type;
    }

    public CellFormatResult apply(JLabel jLabel, Object obj) {
        CellFormatResult apply = apply(obj);
        jLabel.setText(apply.text);
        Color color2 = apply.textColor;
        if (color2 != null) {
            jLabel.setForeground(color2);
        }
        return apply;
    }
}
