package org.apache.poi.ss.format;

import java.util.Locale;

public enum CellFormatType {
    GENERAL {
        @Override // org.apache.poi.ss.format.CellFormatType
        public CellFormatter formatter(String str) {
            return new CellGeneralFormatter();
        }

        @Override // org.apache.poi.ss.format.CellFormatType
        public boolean isSpecial(char c) {
            return false;
        }

        @Override // org.apache.poi.ss.format.CellFormatType
        public CellFormatter formatter(Locale locale, String str) {
            return new CellGeneralFormatter(locale);
        }
    },
    NUMBER {
        @Override // org.apache.poi.ss.format.CellFormatType
        public CellFormatter formatter(String str) {
            return new CellNumberFormatter(str);
        }

        @Override // org.apache.poi.ss.format.CellFormatType
        public boolean isSpecial(char c) {
            return false;
        }

        @Override // org.apache.poi.ss.format.CellFormatType
        public CellFormatter formatter(Locale locale, String str) {
            return new CellNumberFormatter(locale, str);
        }
    },
    DATE {
        @Override // org.apache.poi.ss.format.CellFormatType
        public CellFormatter formatter(String str) {
            return new CellDateFormatter(str);
        }

        @Override // org.apache.poi.ss.format.CellFormatType
        public boolean isSpecial(char c) {
            return c == '\'' || (c <= 127 && Character.isLetter(c));
        }

        @Override // org.apache.poi.ss.format.CellFormatType
        public CellFormatter formatter(Locale locale, String str) {
            return new CellDateFormatter(locale, str);
        }
    },
    ELAPSED {
        @Override // org.apache.poi.ss.format.CellFormatType
        public CellFormatter formatter(String str) {
            return new CellElapsedFormatter(str);
        }

        @Override // org.apache.poi.ss.format.CellFormatType
        public boolean isSpecial(char c) {
            return false;
        }

        @Override // org.apache.poi.ss.format.CellFormatType
        public CellFormatter formatter(Locale locale, String str) {
            return new CellElapsedFormatter(str);
        }
    },
    TEXT {
        @Override // org.apache.poi.ss.format.CellFormatType
        public CellFormatter formatter(String str) {
            return new CellTextFormatter(str);
        }

        @Override // org.apache.poi.ss.format.CellFormatType
        public boolean isSpecial(char c) {
            return false;
        }

        @Override // org.apache.poi.ss.format.CellFormatType
        public CellFormatter formatter(Locale locale, String str) {
            return new CellTextFormatter(str);
        }
    };

    public abstract CellFormatter formatter(String str);

    public abstract CellFormatter formatter(Locale locale, String str);

    public abstract boolean isSpecial(char c);
}
