package org.apache.poi.ss.format;

import b.b.a.a.a;
import java.text.DecimalFormat;
import java.text.DecimalFormatSymbols;
import java.text.FieldPosition;
import java.util.ArrayList;
import java.util.BitSet;
import java.util.Collections;
import java.util.Formatter;
import java.util.Iterator;
import java.util.List;
import java.util.ListIterator;
import java.util.Locale;
import java.util.Set;
import java.util.TreeSet;
import org.apache.poi.ss.formula.functions.NumericFunction;
import org.apache.poi.ss.formula.ptg.PercentPtg;
import org.apache.poi.ss.util.SheetUtil;
import org.apache.poi.util.LittleEndianCP950Reader;
import org.apache.poi.util.LocaleUtil;
import org.apache.poi.util.POILogFactory;
import org.apache.poi.util.POILogger;
import org.apache.poi.xssf.usermodel.XSSFDataValidationConstraint;
import org.apache.xmlbeans.impl.common.NameUtil;

public class CellNumberFormatter extends CellFormatter {
    public static final POILogger LOG = POILogFactory.getLogger(CellNumberFormatter.class);
    public final CellFormatter SIMPLE_NUMBER;
    public final Special afterFractional;
    public final Special afterInteger;
    public final DecimalFormat decimalFmt;
    public final Special decimalPoint;
    public final String denominatorFmt;
    public final List<Special> denominatorSpecials;
    public final String desc;
    public final Special exponent;
    public final List<Special> exponentDigitSpecials;
    public final List<Special> exponentSpecials;
    public final List<Special> fractionalSpecials;
    public final boolean improperFraction;
    public final List<Special> integerSpecials;
    public final int maxDenominator;
    public final Special numerator;
    public final String numeratorFmt;
    public final List<Special> numeratorSpecials;
    public final String printfFmt;
    public final double scale;
    public final boolean showGroupingSeparator;
    public final Special slash;
    public final List<Special> specials;

    public static class GeneralNumberFormatter extends CellFormatter {
        @Override // org.apache.poi.ss.format.CellFormatter
        public void formatValue(StringBuffer stringBuffer, Object obj) {
            CellFormatter cellFormatter;
            if (obj != null) {
                if (obj instanceof Number) {
                    int i2 = ((((Number) obj).doubleValue() % 1.0d) > NumericFunction.LOG_10_TO_BASE_e ? 1 : ((((Number) obj).doubleValue() % 1.0d) == NumericFunction.LOG_10_TO_BASE_e ? 0 : -1));
                    Locale locale = this.locale;
                    if (i2 != 0) {
                        cellFormatter = new CellNumberFormatter(locale, "#.#");
                    }
                } else {
                    cellFormatter = CellTextFormatter.SIMPLE_TEXT;
                }
                cellFormatter.formatValue(stringBuffer, obj);
            }
        }

        @Override // org.apache.poi.ss.format.CellFormatter
        public void simpleValue(StringBuffer stringBuffer, Object obj) {
            formatValue(stringBuffer, obj);
        }

        public GeneralNumberFormatter(Locale locale) {
            super(locale, "General");
        }
    }

    public static class Special {
        public final char ch;
        public int pos;

        public Special(char c, int i2) {
            this.ch = c;
            this.pos = i2;
        }

        public String toString() {
            StringBuilder b2 = a.b("'");
            b2.append(this.ch);
            b2.append("' @ ");
            b2.append(this.pos);
            return b2.toString();
        }
    }

    public CellNumberFormatter(String str) {
        this(LocaleUtil.getUserLocale(), str);
    }

    private int calculateIntegerPartWidth() {
        Special next;
        Iterator<Special> it = this.specials.iterator();
        int i2 = 0;
        while (it.hasNext() && (next = it.next()) != this.afterInteger) {
            if (isDigitFmt(next)) {
                i2++;
            }
        }
        return i2;
    }

    public static CellNumberStringMod deleteMod(Special special, boolean z, Special special2, boolean z2) {
        return new CellNumberStringMod(special, z, special2, z2);
    }

    private int fractionalEnd() {
        Special special = this.afterFractional;
        return special == null ? this.specials.size() : this.specials.indexOf(special);
    }

    private DecimalFormatSymbols getDecimalFormatSymbols() {
        return DecimalFormatSymbols.getInstance(this.locale);
    }

    public static boolean hasChar(char c, List<Special>... listArr) {
        for (List<Special> list : listArr) {
            for (Special special : list) {
                if (special.ch == c) {
                    return true;
                }
            }
        }
        return false;
    }

    public static CellNumberStringMod insertMod(Special special, CharSequence charSequence, int i2) {
        return new CellNumberStringMod(special, charSequence, i2);
    }

    private int integerEnd() {
        Special special = this.afterInteger;
        return special == null ? this.specials.size() : this.specials.indexOf(special);
    }

    public static boolean interpretIntegerCommas(StringBuffer stringBuffer, List<Special> list, Special special, int i2, int i3, double[] dArr) {
        ListIterator<Special> listIterator = list.listIterator(i2);
        int i4 = 0;
        boolean z = true;
        boolean z2 = false;
        while (listIterator.hasPrevious()) {
            if (listIterator.previous().ch != ',') {
                z = false;
            } else if (z) {
                dArr[0] = dArr[0] / 1000.0d;
            } else {
                z2 = true;
            }
        }
        if (special != null) {
            ListIterator<Special> listIterator2 = list.listIterator(i3);
            while (listIterator2.hasPrevious() && listIterator2.previous().ch == ',') {
                dArr[0] = dArr[0] / 1000.0d;
            }
        }
        ListIterator<Special> listIterator3 = list.listIterator();
        while (listIterator3.hasNext()) {
            Special next = listIterator3.next();
            next.pos -= i4;
            if (next.ch == ',') {
                i4++;
                listIterator3.remove();
                stringBuffer.deleteCharAt(next.pos);
            }
        }
        return z2;
    }

    public static int interpretPrecision(Special special, List<Special> list) {
        int indexOf = list.indexOf(special);
        int i2 = 0;
        if (indexOf != -1) {
            ListIterator<Special> listIterator = list.listIterator(indexOf + 1);
            while (listIterator.hasNext() && isDigitFmt(listIterator.next())) {
                i2++;
            }
        }
        return i2;
    }

    public static boolean isDigitFmt(Special special) {
        char c = special.ch;
        return c == '0' || c == '?' || c == '#';
    }

    public static Special lastSpecial(List<Special> list) {
        return list.get(list.size() - 1);
    }

    private String localiseFormat(String str) {
        DecimalFormatSymbols decimalFormatSymbols = getDecimalFormatSymbols();
        if (!str.contains(XSSFDataValidationConstraint.LIST_SEPARATOR) || decimalFormatSymbols.getGroupingSeparator() == ',') {
            return (!str.contains(".") || decimalFormatSymbols.getDecimalSeparator() == '.') ? str : str.replace(NameUtil.PERIOD, decimalFormatSymbols.getDecimalSeparator());
        }
        if (!str.contains(".") || decimalFormatSymbols.getDecimalSeparator() == '.') {
            return str.replace(',', decimalFormatSymbols.getGroupingSeparator());
        }
        return replaceLast(str, "\\.", "[DECIMAL_SEPARATOR]").replace(',', decimalFormatSymbols.getGroupingSeparator()).replace("[DECIMAL_SEPARATOR]", Character.toString(decimalFormatSymbols.getDecimalSeparator()));
    }

    public static int maxValue(List<Special> list) {
        return (int) Math.round(Math.pow(10.0d, (double) list.size()) - 1.0d);
    }

    public static void placeZeros(StringBuffer stringBuffer, List<Special> list) {
        for (Special special : list) {
            if (isDigitFmt(special)) {
                stringBuffer.append(SheetUtil.defaultChar);
            }
        }
    }

    public static String replaceLast(String str, String str2, String str3) {
        String b2 = a.b("(?s)(.*)", str2);
        return str.replaceFirst(b2, "$1" + str3);
    }

    public static CellNumberStringMod replaceMod(Special special, boolean z, Special special2, boolean z2, char c) {
        return new CellNumberStringMod(special, z, special2, z2, c);
    }

    public static String singleNumberFormat(List<Special> list) {
        StringBuilder b2 = a.b("%0");
        b2.append(list.size());
        b2.append("d");
        return b2.toString();
    }

    private List<Special> specialsFor(int i2, int i3) {
        if (i2 >= this.specials.size()) {
            return Collections.emptyList();
        }
        int i4 = i3 + i2;
        ListIterator<Special> listIterator = this.specials.listIterator(i4);
        Special next = listIterator.next();
        while (listIterator.hasNext()) {
            Special next2 = listIterator.next();
            if (!isDigitFmt(next2) || next2.pos - next.pos > 1) {
                break;
            }
            i4++;
            next = next2;
        }
        return this.specials.subList(i2, i4 + 1);
    }

    /* JADX WARNING: Code restructure failed: missing block: B:15:0x009b, code lost:
        if (hasChar('#', r16.integerSpecials) != false) goto L_0x00a0;
     */
    /* JADX WARNING: Removed duplicated region for block: B:49:0x011b A[Catch:{ RuntimeException -> 0x0142 }] */
    private void writeFraction(double d2, StringBuffer stringBuffer, double d3, StringBuffer stringBuffer2, Set<CellNumberStringMod> set) {
        int i2;
        int i3;
        boolean z;
        if (!this.improperFraction) {
            int i4 = (d3 > NumericFunction.LOG_10_TO_BASE_e ? 1 : (d3 == NumericFunction.LOG_10_TO_BASE_e ? 0 : -1));
            if (i4 == 0) {
                if (!hasChar(SheetUtil.defaultChar, this.numeratorSpecials)) {
                    writeInteger(stringBuffer, stringBuffer2, this.integerSpecials, set, false);
                    Special lastSpecial = lastSpecial(this.integerSpecials);
                    Special lastSpecial2 = lastSpecial(this.denominatorSpecials);
                    if (hasChar(LittleEndianCP950Reader.UNMAPPABLE, this.integerSpecials, this.numeratorSpecials, this.denominatorSpecials)) {
                        set.add(replaceMod(lastSpecial, false, lastSpecial2, true, ' '));
                        return;
                    } else {
                        set.add(deleteMod(lastSpecial, false, lastSpecial2, true));
                        return;
                    }
                }
            }
            boolean z2 = !hasChar(SheetUtil.defaultChar, this.numeratorSpecials);
            boolean z3 = !hasChar(SheetUtil.defaultChar, this.integerSpecials);
            if (!this.integerSpecials.isEmpty()) {
                if (this.integerSpecials.size() == 1) {
                }
                z = false;
                boolean z4 = i4 != 0 && (z || z2);
                boolean z5 = i4 == 0 && z3;
                if (d2 == NumericFunction.LOG_10_TO_BASE_e || (!z4 && !z5)) {
                    writeInteger(stringBuffer, stringBuffer2, this.integerSpecials, set, false);
                } else {
                    Special lastSpecial3 = lastSpecial(this.integerSpecials);
                    set.add(hasChar(LittleEndianCP950Reader.UNMAPPABLE, new List[]{this.integerSpecials, this.numeratorSpecials}) ? replaceMod(lastSpecial3, true, this.numerator, false, ' ') : deleteMod(lastSpecial3, true, this.numerator, false));
                }
            }
            z = true;
            if (i4 != 0) {
            }
            if (i4 == 0) {
            }
            if (d2 == NumericFunction.LOG_10_TO_BASE_e) {
            }
            writeInteger(stringBuffer, stringBuffer2, this.integerSpecials, set, false);
        }
        if (d3 != NumericFunction.LOG_10_TO_BASE_e) {
            try {
                if (!this.improperFraction || d3 % 1.0d != NumericFunction.LOG_10_TO_BASE_e) {
                    SimpleFraction buildFractionMaxDenominator = SimpleFraction.buildFractionMaxDenominator(d3, this.maxDenominator);
                    i3 = buildFractionMaxDenominator.getNumerator();
                    i2 = buildFractionMaxDenominator.getDenominator();
                    if (this.improperFraction) {
                        i3 = (int) (((long) i3) + Math.round(((double) i2) * d2));
                    }
                    writeSingleInteger(this.numeratorFmt, i3, stringBuffer2, this.numeratorSpecials, set);
                    writeSingleInteger(this.denominatorFmt, i2, stringBuffer2, this.denominatorSpecials, set);
                }
            } catch (RuntimeException e2) {
                LOG.log(7, "error while fraction evaluation", e2);
                return;
            }
        }
        i3 = (int) Math.round(d3);
        i2 = 1;
        if (this.improperFraction) {
        }
        writeSingleInteger(this.numeratorFmt, i3, stringBuffer2, this.numeratorSpecials, set);
        writeSingleInteger(this.denominatorFmt, i2, stringBuffer2, this.denominatorSpecials, set);
    }

    private void writeFractional(StringBuffer stringBuffer, StringBuffer stringBuffer2) {
        int i2;
        char c;
        if (this.fractionalSpecials.size() > 0) {
            int indexOf = stringBuffer.indexOf(Character.toString(getDecimalFormatSymbols().getDecimalSeparator())) + 1;
            if (this.exponent != null) {
                i2 = stringBuffer.indexOf("e");
            } else {
                i2 = stringBuffer.length();
            }
            while (true) {
                i2--;
                if (i2 <= indexOf || stringBuffer.charAt(i2) != '0') {
                }
            }
            for (Special special : this.fractionalSpecials) {
                char charAt = stringBuffer.charAt(indexOf);
                if (charAt != '0' || (c = special.ch) == '0' || indexOf < i2) {
                    stringBuffer2.setCharAt(special.pos, charAt);
                } else if (c == '?') {
                    stringBuffer2.setCharAt(special.pos, ' ');
                }
                indexOf++;
            }
        }
    }

    private void writeInteger(StringBuffer stringBuffer, StringBuffer stringBuffer2, List<Special> list, Set<CellNumberStringMod> set, boolean z) {
        Special special;
        boolean z2;
        char c;
        int i2;
        DecimalFormatSymbols decimalFormatSymbols = getDecimalFormatSymbols();
        String ch = Character.toString(decimalFormatSymbols.getDecimalSeparator());
        String ch2 = Character.toString(decimalFormatSymbols.getGroupingSeparator());
        int indexOf = stringBuffer.indexOf(ch) - 1;
        if (indexOf < 0) {
            if (this.exponent == null || list != this.integerSpecials) {
                i2 = stringBuffer.length();
            } else {
                i2 = stringBuffer.indexOf("E");
            }
            indexOf = i2 - 1;
        }
        int i3 = 0;
        while (i3 < indexOf && ((r11 = stringBuffer.charAt(i3)) == '0' || r11 == decimalFormatSymbols.getGroupingSeparator())) {
            i3++;
        }
        ListIterator<Special> listIterator = list.listIterator(list.size());
        Special special2 = null;
        int i4 = 0;
        while (listIterator.hasPrevious()) {
            char charAt = indexOf >= 0 ? stringBuffer.charAt(indexOf) : SheetUtil.defaultChar;
            Special previous = listIterator.previous();
            boolean z3 = z && i4 > 0 && i4 % 3 == 0;
            if (charAt != '0' || (c = previous.ch) == '0' || c == '?' || indexOf >= i3) {
                z2 = previous.ch == '?' && indexOf < i3;
                int i5 = previous.pos;
                if (z2) {
                    charAt = ' ';
                }
                stringBuffer2.setCharAt(i5, charAt);
                special = previous;
            } else {
                special = special2;
                z2 = false;
            }
            if (z3) {
                set.add(insertMod(previous, z2 ? " " : ch2, 2));
            }
            i4++;
            indexOf--;
            special2 = special;
        }
        if (indexOf >= 0) {
            int i6 = indexOf + 1;
            StringBuffer stringBuffer3 = new StringBuffer(stringBuffer.substring(0, i6));
            if (z) {
                while (i6 > 0) {
                    if (i4 > 0 && i4 % 3 == 0) {
                        stringBuffer3.insert(i6, ch2);
                    }
                    i4++;
                    i6--;
                }
            }
            set.add(insertMod(special2, stringBuffer3, 1));
        }
    }

    private void writeScientific(double d2, StringBuffer stringBuffer, Set<CellNumberStringMod> set) {
        StringBuffer stringBuffer2 = new StringBuffer();
        FieldPosition fieldPosition = new FieldPosition(1);
        this.decimalFmt.format(d2, stringBuffer2, fieldPosition);
        writeInteger(stringBuffer2, stringBuffer, this.integerSpecials, set, this.showGroupingSeparator);
        writeFractional(stringBuffer2, stringBuffer);
        int endIndex = fieldPosition.getEndIndex() + 1;
        char charAt = stringBuffer2.charAt(endIndex);
        if (charAt != '-') {
            stringBuffer2.insert(endIndex, '+');
            charAt = '+';
        }
        Special next = this.exponentSpecials.listIterator(1).next();
        char c = next.ch;
        if (charAt == '-' || c == '+') {
            set.add(replaceMod(next, true, next, true, charAt));
        } else {
            set.add(deleteMod(next, true, next, true));
        }
        writeInteger(new StringBuffer(stringBuffer2.substring(endIndex + 1)), stringBuffer, this.exponentDigitSpecials, set, false);
    }

    /* JADX INFO: finally extract failed */
    private void writeSingleInteger(String str, int i2, StringBuffer stringBuffer, List<Special> list, Set<CellNumberStringMod> set) {
        StringBuffer stringBuffer2 = new StringBuffer();
        Formatter formatter = new Formatter(stringBuffer2, this.locale);
        try {
            formatter.format(this.locale, str, Integer.valueOf(i2));
            formatter.close();
            writeInteger(stringBuffer2, stringBuffer, list, set, false);
        } catch (Throwable th) {
            formatter.close();
            throw th;
        }
    }

    /* JADX INFO: finally extract failed */
    /* JADX WARNING: Code restructure failed: missing block: B:48:0x010a, code lost:
        if (r3.isStartInclusive() == false) goto L_0x0113;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:50:0x0111, code lost:
        if (r3.get(r10) == false) goto L_0x0118;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:51:0x0113, code lost:
        r10 = r10 + 1;
        r13 = r13 + 1;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:52:0x0118, code lost:
        r14 = r3.getEnd().pos;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:53:0x0122, code lost:
        if (r3.isEndInclusive() == false) goto L_0x0126;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:54:0x0124, code lost:
        r14 = r14 + 1;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:55:0x0126, code lost:
        r15 = r14 + r6;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:56:0x0128, code lost:
        if (r13 >= r15) goto L_0x0153;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:57:0x012a, code lost:
        r17 = r0;
        r18 = r1;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:58:0x0138, code lost:
        if ("".equals(r3.getToAdd()) == false) goto L_0x013e;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:59:0x013a, code lost:
        r12.delete(r13, r15);
     */
    /* JADX WARNING: Code restructure failed: missing block: B:60:0x013e, code lost:
        r0 = r3.getToAdd().charAt(0);
     */
    /* JADX WARNING: Code restructure failed: missing block: B:61:0x0147, code lost:
        if (r13 >= r15) goto L_0x014f;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:62:0x0149, code lost:
        r12.setCharAt(r13, r0);
        r13 = r13 + 1;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:63:0x014f, code lost:
        r3.set(r10, r14);
     */
    /* JADX WARNING: Code restructure failed: missing block: B:64:0x0153, code lost:
        r17 = r0;
        r18 = r1;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:65:0x0157, code lost:
        r0 = r17;
        r1 = r18;
     */
    /* JADX WARNING: Removed duplicated region for block: B:15:0x0044  */
    /* JADX WARNING: Removed duplicated region for block: B:16:0x0048  */
    /* JADX WARNING: Removed duplicated region for block: B:28:0x00a5  */
    /* JADX WARNING: Removed duplicated region for block: B:29:0x00ac  */
    /* JADX WARNING: Removed duplicated region for block: B:33:0x00c7  */
    /* JADX WARNING: Removed duplicated region for block: B:81:0x01b3  */
    @Override // org.apache.poi.ss.format.CellFormatter
    public void formatValue(StringBuffer stringBuffer, Object obj) {
        double d2;
        Iterator<Special> it;
        double doubleValue = ((Number) obj).doubleValue() * this.scale;
        double d3 = NumericFunction.LOG_10_TO_BASE_e;
        int i2 = 1;
        boolean z = doubleValue < NumericFunction.LOG_10_TO_BASE_e;
        if (z) {
            doubleValue = -doubleValue;
        }
        if (this.slash != null) {
            if (this.improperFraction) {
                d2 = doubleValue;
                TreeSet treeSet = new TreeSet();
                StringBuffer stringBuffer2 = new StringBuffer(localiseFormat(this.desc));
                if (this.exponent == null) {
                    writeScientific(d3, stringBuffer2, treeSet);
                } else if (this.improperFraction) {
                    writeFraction(d3, null, d2, stringBuffer2, treeSet);
                } else {
                    StringBuffer stringBuffer3 = new StringBuffer();
                    Formatter formatter = new Formatter(stringBuffer3, this.locale);
                    try {
                        formatter.format(this.locale, this.printfFmt, Double.valueOf(d3));
                        formatter.close();
                        if (this.numerator == null) {
                            writeFractional(stringBuffer3, stringBuffer2);
                            writeInteger(stringBuffer3, stringBuffer2, this.integerSpecials, treeSet, this.showGroupingSeparator);
                        } else {
                            writeFraction(d3, stringBuffer3, d2, stringBuffer2, treeSet);
                        }
                    } catch (Throwable th) {
                        formatter.close();
                        throw th;
                    }
                }
                String ch = Character.toString(getDecimalFormatSymbols().getGroupingSeparator());
                Iterator it2 = treeSet.iterator();
                CellNumberStringMod cellNumberStringMod = !it2.hasNext() ? (CellNumberStringMod) it2.next() : null;
                BitSet bitSet = new BitSet();
                it = this.specials.iterator();
                int i3 = 0;
                CellNumberStringMod cellNumberStringMod2 = cellNumberStringMod;
                Iterator it3 = it2;
                StringBuffer stringBuffer4 = stringBuffer;
                while (it.hasNext()) {
                    Special next = it.next();
                    int i4 = next.pos;
                    int i5 = i4 + i3;
                    if (!bitSet.get(i4) && stringBuffer2.charAt(i5) == '#') {
                        stringBuffer2.deleteCharAt(i5);
                        i3--;
                        bitSet.set(next.pos);
                    }
                    while (cellNumberStringMod2 != null && next == cellNumberStringMod2.getSpecial()) {
                        int length = stringBuffer2.length();
                        int i6 = next.pos + i3;
                        int op = cellNumberStringMod2.getOp();
                        if (op == i2) {
                            stringBuffer2.insert(i6, cellNumberStringMod2.getToAdd());
                        } else if (op != 2) {
                            if (op == 3) {
                                int i7 = next.pos;
                            } else {
                                StringBuilder b2 = a.b("Unknown op: ");
                                b2.append(cellNumberStringMod2.getOp());
                                throw new IllegalStateException(b2.toString());
                            }
                        } else if (!cellNumberStringMod2.getToAdd().equals(ch) || !bitSet.get(next.pos)) {
                            stringBuffer2.insert(i6 + 1, cellNumberStringMod2.getToAdd());
                        }
                        i3 += stringBuffer2.length() - length;
                        cellNumberStringMod2 = it3.hasNext() ? (CellNumberStringMod) it3.next() : null;
                        i2 = 1;
                    }
                    i2 = 1;
                }
                if (z) {
                    stringBuffer4.append(NameUtil.HYPHEN);
                }
                stringBuffer4.append(stringBuffer2);
            }
            d3 = doubleValue % 1.0d;
            doubleValue = (double) ((long) doubleValue);
        }
        d2 = d3;
        d3 = doubleValue;
        TreeSet treeSet2 = new TreeSet();
        StringBuffer stringBuffer22 = new StringBuffer(localiseFormat(this.desc));
        if (this.exponent == null) {
        }
        String ch2 = Character.toString(getDecimalFormatSymbols().getGroupingSeparator());
        Iterator it22 = treeSet2.iterator();
        if (!it22.hasNext()) {
        }
        BitSet bitSet2 = new BitSet();
        it = this.specials.iterator();
        int i32 = 0;
        CellNumberStringMod cellNumberStringMod22 = cellNumberStringMod;
        Iterator it32 = it22;
        StringBuffer stringBuffer42 = stringBuffer;
        while (it.hasNext()) {
        }
        if (z) {
        }
        stringBuffer42.append(stringBuffer22);
    }

    @Override // org.apache.poi.ss.format.CellFormatter
    public void simpleValue(StringBuffer stringBuffer, Object obj) {
        this.SIMPLE_NUMBER.formatValue(stringBuffer, obj);
    }

    public CellNumberFormatter(Locale locale, String str) {
        super(locale, str);
        int i2;
        this.specials = new ArrayList();
        this.integerSpecials = new ArrayList();
        this.fractionalSpecials = new ArrayList();
        this.numeratorSpecials = new ArrayList();
        this.denominatorSpecials = new ArrayList();
        this.exponentSpecials = new ArrayList();
        this.exponentDigitSpecials = new ArrayList();
        this.SIMPLE_NUMBER = new GeneralNumberFormatter(this.locale);
        CellNumberPartHandler cellNumberPartHandler = new CellNumberPartHandler();
        StringBuffer parseFormat = CellFormatPart.parseFormat(str, CellFormatType.NUMBER, cellNumberPartHandler);
        this.exponent = cellNumberPartHandler.getExponent();
        this.specials.addAll(cellNumberPartHandler.getSpecials());
        this.improperFraction = cellNumberPartHandler.isImproperFraction();
        if ((cellNumberPartHandler.getDecimalPoint() == null && cellNumberPartHandler.getExponent() == null) || cellNumberPartHandler.getSlash() == null) {
            this.slash = cellNumberPartHandler.getSlash();
            this.numerator = cellNumberPartHandler.getNumerator();
        } else {
            this.slash = null;
            this.numerator = null;
        }
        int interpretPrecision = interpretPrecision(cellNumberPartHandler.getDecimalPoint(), this.specials);
        if (cellNumberPartHandler.getDecimalPoint() != null) {
            int i3 = interpretPrecision + 1;
            if (interpretPrecision == 0) {
                this.specials.remove(cellNumberPartHandler.getDecimalPoint());
                this.decimalPoint = null;
            } else {
                this.decimalPoint = cellNumberPartHandler.getDecimalPoint();
            }
            i2 = i3;
        } else {
            this.decimalPoint = null;
            i2 = 0;
        }
        Special special = this.decimalPoint;
        if (special != null) {
            this.afterInteger = special;
        } else {
            Special special2 = this.exponent;
            if (special2 != null) {
                this.afterInteger = special2;
            } else {
                Special special3 = this.numerator;
                if (special3 != null) {
                    this.afterInteger = special3;
                } else {
                    this.afterInteger = null;
                }
            }
        }
        Special special4 = this.exponent;
        if (special4 != null) {
            this.afterFractional = special4;
        } else {
            Special special5 = this.numerator;
            if (special5 != null) {
                this.afterFractional = special5;
            } else {
                this.afterFractional = null;
            }
        }
        boolean z = true;
        double[] dArr = {cellNumberPartHandler.getScale()};
        this.showGroupingSeparator = interpretIntegerCommas(parseFormat, this.specials, this.decimalPoint, integerEnd(), fractionalEnd(), dArr);
        if (this.exponent == null) {
            this.scale = dArr[0];
        } else {
            this.scale = 1.0d;
        }
        if (interpretPrecision != 0) {
            List<Special> list = this.fractionalSpecials;
            List<Special> list2 = this.specials;
            list.addAll(list2.subList(list2.indexOf(this.decimalPoint) + 1, fractionalEnd()));
        }
        Special special6 = this.exponent;
        if (special6 != null) {
            int indexOf = this.specials.indexOf(special6);
            this.exponentSpecials.addAll(specialsFor(indexOf, 2));
            this.exponentDigitSpecials.addAll(specialsFor(indexOf + 2));
        }
        if (this.slash != null) {
            Special special7 = this.numerator;
            if (special7 != null) {
                this.numeratorSpecials.addAll(specialsFor(this.specials.indexOf(special7)));
            }
            this.denominatorSpecials.addAll(specialsFor(this.specials.indexOf(this.slash) + 1));
            if (this.denominatorSpecials.isEmpty()) {
                this.numeratorSpecials.clear();
                this.maxDenominator = 1;
                this.numeratorFmt = null;
                this.denominatorFmt = null;
            } else {
                this.maxDenominator = maxValue(this.denominatorSpecials);
                this.numeratorFmt = singleNumberFormat(this.numeratorSpecials);
                this.denominatorFmt = singleNumberFormat(this.denominatorSpecials);
            }
        } else {
            this.maxDenominator = 1;
            this.numeratorFmt = null;
            this.denominatorFmt = null;
        }
        this.integerSpecials.addAll(this.specials.subList(0, integerEnd()));
        if (this.exponent == null) {
            StringBuffer stringBuffer = new StringBuffer(PercentPtg.PERCENT);
            stringBuffer.append(SheetUtil.defaultChar);
            stringBuffer.append(calculateIntegerPartWidth() + i2);
            stringBuffer.append(NameUtil.PERIOD);
            stringBuffer.append(interpretPrecision);
            stringBuffer.append("f");
            this.printfFmt = stringBuffer.toString();
            this.decimalFmt = null;
        } else {
            StringBuffer stringBuffer2 = new StringBuffer();
            List<Special> list3 = this.integerSpecials;
            if (list3.size() == 1) {
                stringBuffer2.append("0");
                z = false;
            } else {
                for (Special special8 : list3) {
                    if (isDigitFmt(special8)) {
                        stringBuffer2.append(z ? '#' : SheetUtil.defaultChar);
                        z = false;
                    }
                }
            }
            if (this.fractionalSpecials.size() > 0) {
                stringBuffer2.append(NameUtil.PERIOD);
                for (Special special9 : this.fractionalSpecials) {
                    if (isDigitFmt(special9)) {
                        if (!z) {
                            stringBuffer2.append(SheetUtil.defaultChar);
                        }
                        z = false;
                    }
                }
            }
            stringBuffer2.append('E');
            List<Special> list4 = this.exponentSpecials;
            placeZeros(stringBuffer2, list4.subList(2, list4.size()));
            this.decimalFmt = new DecimalFormat(stringBuffer2.toString(), getDecimalFormatSymbols());
            this.printfFmt = null;
        }
        this.desc = parseFormat.toString();
    }

    private List<Special> specialsFor(int i2) {
        return specialsFor(i2, 0);
    }
}
