package org.apache.poi.ss.formula;

import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import org.apache.poi.ss.util.CellReference;

public final class FormulaUsedBlankCellSet {
    public final Map<BookSheetKey, BlankCellSheetGroup> _sheetGroupsByBookSheet = new HashMap();

    public static final class BlankCellRectangleGroup {
        public final int _firstColumnIndex;
        public final int _firstRowIndex;
        public final int _lastColumnIndex;
        public int _lastRowIndex;

        public BlankCellRectangleGroup(int i2, int i3, int i4) {
            this._firstRowIndex = i2;
            this._firstColumnIndex = i3;
            this._lastColumnIndex = i4;
            this._lastRowIndex = i2;
        }

        public boolean acceptRow(int i2, int i3, int i4) {
            if (i3 != this._firstColumnIndex || i4 != this._lastColumnIndex || i2 != this._lastRowIndex + 1) {
                return false;
            }
            this._lastRowIndex = i2;
            return true;
        }

        public boolean containsCell(int i2, int i3) {
            if (i3 >= this._firstColumnIndex && i3 <= this._lastColumnIndex && i2 >= this._firstRowIndex && i2 <= this._lastRowIndex) {
                return true;
            }
            return false;
        }

        public String toString() {
            StringBuffer stringBuffer = new StringBuffer(64);
            CellReference cellReference = new CellReference(this._firstRowIndex, this._firstColumnIndex, false, false);
            CellReference cellReference2 = new CellReference(this._lastRowIndex, this._lastColumnIndex, false, false);
            stringBuffer.append(BlankCellRectangleGroup.class.getName());
            stringBuffer.append(" [");
            stringBuffer.append(cellReference.formatAsString());
            stringBuffer.append(':');
            stringBuffer.append(cellReference2.formatAsString());
            stringBuffer.append("]");
            return stringBuffer.toString();
        }
    }

    public static final class BlankCellSheetGroup {
        public BlankCellRectangleGroup _currentRectangleGroup;
        public int _currentRowIndex = -1;
        public int _firstColumnIndex;
        public int _lastColumnIndex;
        public final List<BlankCellRectangleGroup> _rectangleGroups = new ArrayList();

        public void addCell(int i2, int i3) {
            int i4 = this._currentRowIndex;
            if (i4 == -1) {
                this._currentRowIndex = i2;
                this._firstColumnIndex = i3;
                this._lastColumnIndex = i3;
            } else if (i4 == i2 && this._lastColumnIndex + 1 == i3) {
                this._lastColumnIndex = i3;
            } else {
                BlankCellRectangleGroup blankCellRectangleGroup = this._currentRectangleGroup;
                if (blankCellRectangleGroup == null) {
                    this._currentRectangleGroup = new BlankCellRectangleGroup(this._currentRowIndex, this._firstColumnIndex, this._lastColumnIndex);
                } else if (!blankCellRectangleGroup.acceptRow(this._currentRowIndex, this._firstColumnIndex, this._lastColumnIndex)) {
                    this._rectangleGroups.add(this._currentRectangleGroup);
                    this._currentRectangleGroup = new BlankCellRectangleGroup(this._currentRowIndex, this._firstColumnIndex, this._lastColumnIndex);
                }
                this._currentRowIndex = i2;
                this._firstColumnIndex = i3;
                this._lastColumnIndex = i3;
            }
        }

        public boolean containsCell(int i2, int i3) {
            for (int size = this._rectangleGroups.size() - 1; size >= 0; size--) {
                if (this._rectangleGroups.get(size).containsCell(i2, i3)) {
                    return true;
                }
            }
            BlankCellRectangleGroup blankCellRectangleGroup = this._currentRectangleGroup;
            if (blankCellRectangleGroup != null && blankCellRectangleGroup.containsCell(i2, i3)) {
                return true;
            }
            int i4 = this._currentRowIndex;
            if (i4 == -1 || i4 != i2 || this._firstColumnIndex > i3 || i3 > this._lastColumnIndex) {
                return false;
            }
            return true;
        }
    }

    public static final class BookSheetKey {
        public final int _bookIndex;
        public final int _sheetIndex;

        public BookSheetKey(int i2, int i3) {
            this._bookIndex = i2;
            this._sheetIndex = i3;
        }

        public boolean equals(Object obj) {
            if (!(obj instanceof BookSheetKey)) {
                return false;
            }
            BookSheetKey bookSheetKey = (BookSheetKey) obj;
            if (this._bookIndex == bookSheetKey._bookIndex && this._sheetIndex == bookSheetKey._sheetIndex) {
                return true;
            }
            return false;
        }

        public int hashCode() {
            return (this._bookIndex * 17) + this._sheetIndex;
        }
    }

    private BlankCellSheetGroup getSheetGroup(int i2, int i3) {
        BookSheetKey bookSheetKey = new BookSheetKey(i2, i3);
        BlankCellSheetGroup blankCellSheetGroup = this._sheetGroupsByBookSheet.get(bookSheetKey);
        if (blankCellSheetGroup != null) {
            return blankCellSheetGroup;
        }
        BlankCellSheetGroup blankCellSheetGroup2 = new BlankCellSheetGroup();
        this._sheetGroupsByBookSheet.put(bookSheetKey, blankCellSheetGroup2);
        return blankCellSheetGroup2;
    }

    public void addCell(int i2, int i3, int i4, int i5) {
        getSheetGroup(i2, i3).addCell(i4, i5);
    }

    public boolean containsCell(BookSheetKey bookSheetKey, int i2, int i3) {
        BlankCellSheetGroup blankCellSheetGroup = this._sheetGroupsByBookSheet.get(bookSheetKey);
        if (blankCellSheetGroup == null) {
            return false;
        }
        return blankCellSheetGroup.containsCell(i2, i3);
    }

    public boolean isEmpty() {
        return this._sheetGroupsByBookSheet.isEmpty();
    }
}
