package org.apache.poi.ss.formula;

import b.b.a.a.a;
import org.apache.poi.ss.formula.eval.AreaEval;
import org.apache.poi.ss.formula.eval.AreaEvalBase;
import org.apache.poi.ss.formula.eval.ValueEval;
import org.apache.poi.ss.formula.ptg.AreaI;
import org.apache.poi.ss.util.CellReference;

public final class LazyAreaEval extends AreaEvalBase {
    public final SheetRangeEvaluator _evaluator;

    public LazyAreaEval(AreaI areaI, SheetRangeEvaluator sheetRangeEvaluator) {
        super(areaI, sheetRangeEvaluator);
        this._evaluator = sheetRangeEvaluator;
    }

    @Override // org.apache.poi.ss.formula.eval.AreaEval, org.apache.poi.ss.formula.eval.AreaEvalBase
    public ValueEval getRelativeValue(int i2, int i3) {
        return getRelativeValue(getFirstSheetIndex(), i2, i3);
    }

    @Override // org.apache.poi.ss.formula.eval.AreaEvalBase, org.apache.poi.ss.formula.TwoDEval
    public boolean isSubTotal(int i2, int i3) {
        SheetRangeEvaluator sheetRangeEvaluator = this._evaluator;
        return sheetRangeEvaluator.getSheetEvaluator(sheetRangeEvaluator.getFirstSheetIndex()).isSubTotal(getFirstRow() + i2, getFirstColumn() + i3);
    }

    @Override // org.apache.poi.ss.formula.eval.AreaEval
    public AreaEval offset(int i2, int i3, int i4, int i5) {
        return new LazyAreaEval(new AreaI.OffsetArea(getFirstRow(), getFirstColumn(), i2, i3, i4, i5), this._evaluator);
    }

    public String toString() {
        CellReference cellReference = new CellReference(getFirstRow(), getFirstColumn());
        CellReference cellReference2 = new CellReference(getLastRow(), getLastColumn());
        return LazyAreaEval.class.getName() + "[" + this._evaluator.getSheetNameRange() + '!' + cellReference.formatAsString() + ':' + cellReference2.formatAsString() + "]";
    }

    @Override // org.apache.poi.ss.formula.TwoDEval
    public LazyAreaEval getColumn(int i2) {
        if (i2 < getWidth()) {
            int firstColumn = getFirstColumn() + i2;
            return new LazyAreaEval(getFirstRow(), firstColumn, getLastRow(), firstColumn, this._evaluator);
        }
        StringBuilder a = a.a("Invalid columnIndex ", i2, ".  Allowable range is (0..");
        a.append(getWidth());
        a.append(").");
        throw new IllegalArgumentException(a.toString());
    }

    @Override // org.apache.poi.ss.formula.eval.AreaEvalBase
    public ValueEval getRelativeValue(int i2, int i3, int i4) {
        return this._evaluator.getEvalForCell(i2, getFirstRow() + i3, getFirstColumn() + i4);
    }

    @Override // org.apache.poi.ss.formula.TwoDEval
    public LazyAreaEval getRow(int i2) {
        if (i2 < getHeight()) {
            int firstRow = getFirstRow() + i2;
            return new LazyAreaEval(firstRow, getFirstColumn(), firstRow, getLastColumn(), this._evaluator);
        }
        StringBuilder a = a.a("Invalid rowIndex ", i2, ".  Allowable range is (0..");
        a.append(getHeight());
        a.append(").");
        throw new IllegalArgumentException(a.toString());
    }

    public LazyAreaEval(int i2, int i3, int i4, int i5, SheetRangeEvaluator sheetRangeEvaluator) {
        super(sheetRangeEvaluator, i2, i3, i4, i5);
        this._evaluator = sheetRangeEvaluator;
    }
}
