package org.apache.poi.ss.formula;

import b.b.a.a.a;
import org.apache.poi.ss.formula.ptg.ArrayPtg;
import org.apache.poi.ss.formula.ptg.AttrPtg;
import org.apache.poi.ss.formula.ptg.FuncVarPtg;
import org.apache.poi.ss.formula.ptg.MemAreaPtg;
import org.apache.poi.ss.formula.ptg.MemFuncPtg;
import org.apache.poi.ss.formula.ptg.Ptg;

public final class ParseNode {
    public static final ParseNode[] EMPTY_ARRAY = new ParseNode[0];
    public final ParseNode[] _children;
    public boolean _isIf;
    public final Ptg _token;
    public final int _tokenCount;

    public static final class TokenCollector {
        public int _offset = 0;
        public final Ptg[] _ptgs;

        public TokenCollector(int i2) {
            this._ptgs = new Ptg[i2];
        }

        public void add(Ptg ptg) {
            if (ptg != null) {
                Ptg[] ptgArr = this._ptgs;
                int i2 = this._offset;
                ptgArr[i2] = ptg;
                this._offset = i2 + 1;
                return;
            }
            throw new IllegalArgumentException("token must not be null");
        }

        public int createPlaceholder() {
            int i2 = this._offset;
            this._offset = i2 + 1;
            return i2;
        }

        public Ptg[] getResult() {
            return this._ptgs;
        }

        public void setPlaceholder(int i2, Ptg ptg) {
            Ptg[] ptgArr = this._ptgs;
            if (ptgArr[i2] == null) {
                ptgArr[i2] = ptg;
                return;
            }
            throw new IllegalStateException(a.b("Invalid placeholder index (", i2, ")"));
        }

        public int sumTokenSizes(int i2, int i3) {
            int i4 = 0;
            while (i2 < i3) {
                i4 += this._ptgs[i2].getSize();
                i2++;
            }
            return i4;
        }
    }

    public ParseNode(Ptg ptg, ParseNode[] parseNodeArr) {
        if (ptg != null) {
            this._token = ptg;
            this._children = (ParseNode[]) parseNodeArr.clone();
            this._isIf = isIf(ptg);
            int i2 = 1;
            for (ParseNode parseNode : parseNodeArr) {
                i2 += parseNode.getTokenCount();
            }
            this._tokenCount = this._isIf ? i2 + parseNodeArr.length : i2;
            return;
        }
        throw new IllegalArgumentException("token must not be null");
    }

    private void collectIfPtgs(TokenCollector tokenCollector) {
        getChildren()[0].collectPtgs(tokenCollector);
        int createPlaceholder = tokenCollector.createPlaceholder();
        getChildren()[1].collectPtgs(tokenCollector);
        int createPlaceholder2 = tokenCollector.createPlaceholder();
        AttrPtg createIf = AttrPtg.createIf(tokenCollector.sumTokenSizes(createPlaceholder + 1, createPlaceholder2) + 4);
        if (getChildren().length > 2) {
            getChildren()[2].collectPtgs(tokenCollector);
            int createPlaceholder3 = tokenCollector.createPlaceholder();
            AttrPtg createSkip = AttrPtg.createSkip(((tokenCollector.sumTokenSizes(createPlaceholder2 + 1, createPlaceholder3) + 4) + 4) - 1);
            AttrPtg createSkip2 = AttrPtg.createSkip(3);
            tokenCollector.setPlaceholder(createPlaceholder, createIf);
            tokenCollector.setPlaceholder(createPlaceholder2, createSkip);
            tokenCollector.setPlaceholder(createPlaceholder3, createSkip2);
        } else {
            AttrPtg createSkip3 = AttrPtg.createSkip(3);
            tokenCollector.setPlaceholder(createPlaceholder, createIf);
            tokenCollector.setPlaceholder(createPlaceholder2, createSkip3);
        }
        tokenCollector.add(this._token);
    }

    private void collectPtgs(TokenCollector tokenCollector) {
        if (isIf(this._token)) {
            collectIfPtgs(tokenCollector);
            return;
        }
        Ptg ptg = this._token;
        boolean z = (ptg instanceof MemFuncPtg) || (ptg instanceof MemAreaPtg);
        if (z) {
            tokenCollector.add(this._token);
        }
        for (int i2 = 0; i2 < getChildren().length; i2++) {
            getChildren()[i2].collectPtgs(tokenCollector);
        }
        if (!z) {
            tokenCollector.add(this._token);
        }
    }

    private int getTokenCount() {
        return this._tokenCount;
    }

    public static boolean isIf(Ptg ptg) {
        return (ptg instanceof FuncVarPtg) && "IF".equals(((FuncVarPtg) ptg).getName());
    }

    public static Ptg[] toTokenArray(ParseNode parseNode) {
        TokenCollector tokenCollector = new TokenCollector(parseNode.getTokenCount());
        parseNode.collectPtgs(tokenCollector);
        return tokenCollector.getResult();
    }

    public ParseNode[] getChildren() {
        return this._children;
    }

    public int getEncodedSize() {
        Ptg ptg = this._token;
        int size = ptg instanceof ArrayPtg ? 8 : ptg.getSize();
        int i2 = 0;
        while (true) {
            ParseNode[] parseNodeArr = this._children;
            if (i2 >= parseNodeArr.length) {
                return size;
            }
            size += parseNodeArr[i2].getEncodedSize();
            i2++;
        }
    }

    public Ptg getToken() {
        return this._token;
    }

    public ParseNode(Ptg ptg) {
        this(ptg, EMPTY_ARRAY);
    }

    public ParseNode(Ptg ptg, ParseNode parseNode) {
        this(ptg, new ParseNode[]{parseNode});
    }

    public ParseNode(Ptg ptg, ParseNode parseNode, ParseNode parseNode2) {
        this(ptg, new ParseNode[]{parseNode, parseNode2});
    }
}
