package org.apache.poi.ss.formula;

import java.util.HashMap;
import java.util.Map;

public final class PlainCellCache {
    public Map<Loc, PlainValueCellCacheEntry> _plainValueEntriesByLoc = new HashMap();

    public void clear() {
        this._plainValueEntriesByLoc.clear();
    }

    public PlainValueCellCacheEntry get(Loc loc) {
        return this._plainValueEntriesByLoc.get(loc);
    }

    public void put(Loc loc, PlainValueCellCacheEntry plainValueCellCacheEntry) {
        this._plainValueEntriesByLoc.put(loc, plainValueCellCacheEntry);
    }

    public void remove(Loc loc) {
        this._plainValueEntriesByLoc.remove(loc);
    }

    public static final class Loc {
        public final long _bookSheetColumn;
        public final int _rowIndex;

        public Loc(int i2, int i3, int i4, int i5) {
            this._bookSheetColumn = toBookSheetColumn(i2, i3, i5);
            this._rowIndex = i4;
        }

        public static long toBookSheetColumn(int i2, int i3, int i4) {
            return ((((long) i2) & 65535) << 48) + ((((long) i3) & 65535) << 32) + ((((long) i4) & 65535) << 0);
        }

        public boolean equals(Object obj) {
            if (!(obj instanceof Loc)) {
                return false;
            }
            Loc loc = (Loc) obj;
            if (this._bookSheetColumn == loc._bookSheetColumn && this._rowIndex == loc._rowIndex) {
                return true;
            }
            return false;
        }

        public int getBookIndex() {
            return (int) ((this._bookSheetColumn >> 48) & 65535);
        }

        public int getColumnIndex() {
            return (int) (this._bookSheetColumn & 65535);
        }

        public int getRowIndex() {
            return this._rowIndex;
        }

        public int getSheetIndex() {
            return (int) ((this._bookSheetColumn >> 32) & 65535);
        }

        public int hashCode() {
            long j = this._bookSheetColumn;
            return (this._rowIndex * 17) + ((int) (j ^ (j >>> 32)));
        }

        public Loc(long j, int i2) {
            this._bookSheetColumn = j;
            this._rowIndex = i2;
        }
    }
}
