package org.apache.poi.ss.formula;

import org.apache.poi.ss.SpreadsheetVersion;
import org.apache.poi.ss.formula.ptg.AreaPtg;
import org.apache.poi.ss.formula.ptg.AreaPtgBase;
import org.apache.poi.ss.formula.ptg.OperandPtg;
import org.apache.poi.ss.formula.ptg.Ptg;
import org.apache.poi.ss.formula.ptg.RefPtg;
import org.apache.poi.ss.formula.ptg.RefPtgBase;

public class SharedFormula {
    public final int _columnWrappingMask;
    public final int _rowWrappingMask;

    public SharedFormula(SpreadsheetVersion spreadsheetVersion) {
        this._columnWrappingMask = spreadsheetVersion.getLastColumnIndex();
        this._rowWrappingMask = spreadsheetVersion.getLastRowIndex();
    }

    private int fixupRelativeColumn(int i2, int i3, boolean z) {
        if (!z) {
            return i3;
        }
        return this._columnWrappingMask & (i3 + i2);
    }

    private int fixupRelativeRow(int i2, int i3, boolean z) {
        if (!z) {
            return i3;
        }
        return this._rowWrappingMask & (i3 + i2);
    }

    public Ptg[] convertSharedFormulas(Ptg[] ptgArr, int i2, int i3) {
        SharedFormula sharedFormula = this;
        Ptg[] ptgArr2 = new Ptg[ptgArr.length];
        int i4 = 0;
        while (i4 < ptgArr.length) {
            OperandPtg operandPtg = ptgArr[i4];
            byte b2 = -1;
            if (!operandPtg.isBaseToken()) {
                b2 = operandPtg.getPtgClass();
            }
            if (operandPtg instanceof RefPtgBase) {
                RefPtgBase refPtgBase = (RefPtgBase) operandPtg;
                RefPtg refPtg = new RefPtg(sharedFormula.fixupRelativeRow(i2, refPtgBase.getRow(), refPtgBase.isRowRelative()), sharedFormula.fixupRelativeColumn(i3, refPtgBase.getColumn(), refPtgBase.isColRelative()), refPtgBase.isRowRelative(), refPtgBase.isColRelative());
                refPtg.setClass(b2);
                operandPtg = refPtg;
            } else if (operandPtg instanceof AreaPtgBase) {
                AreaPtgBase areaPtgBase = (AreaPtgBase) operandPtg;
                AreaPtg areaPtg = new AreaPtg(sharedFormula.fixupRelativeRow(i2, areaPtgBase.getFirstRow(), areaPtgBase.isFirstRowRelative()), sharedFormula.fixupRelativeRow(i2, areaPtgBase.getLastRow(), areaPtgBase.isLastRowRelative()), sharedFormula.fixupRelativeColumn(i3, areaPtgBase.getFirstColumn(), areaPtgBase.isFirstColRelative()), sharedFormula.fixupRelativeColumn(i3, areaPtgBase.getLastColumn(), areaPtgBase.isLastColRelative()), areaPtgBase.isFirstRowRelative(), areaPtgBase.isLastRowRelative(), areaPtgBase.isFirstColRelative(), areaPtgBase.isLastColRelative());
                areaPtg.setClass(b2);
                operandPtg = areaPtg;
            } else if (operandPtg instanceof OperandPtg) {
                operandPtg = ((OperandPtg) operandPtg).copy();
            }
            ptgArr2[i4] = operandPtg;
            i4++;
            sharedFormula = this;
        }
        return ptgArr2;
    }
}
