package org.apache.poi.ss.formula;

import b.b.a.a.a;
import java.util.regex.Matcher;
import java.util.regex.Pattern;
import org.apache.poi.ss.SpreadsheetVersion;
import org.apache.poi.ss.util.CellReference;
import org.apache.poi.xssf.usermodel.XSSFCell;

public final class SheetNameFormatter {
    public static final Pattern CELL_REF_PATTERN = Pattern.compile("([A-Za-z]+)([0-9]+)");
    public static final char DELIMITER = '\'';

    public static void appendAndEscape(StringBuffer stringBuffer, String str) {
        int length = str.length();
        for (int i2 = 0; i2 < length; i2++) {
            char charAt = str.charAt(i2);
            if (charAt == '\'') {
                stringBuffer.append('\'');
            }
            stringBuffer.append(charAt);
        }
    }

    public static void appendFormat(StringBuffer stringBuffer, String str) {
        if (needsDelimiting(str)) {
            stringBuffer.append('\'');
            appendAndEscape(stringBuffer, str);
            stringBuffer.append('\'');
            return;
        }
        stringBuffer.append(str);
    }

    public static boolean cellReferenceIsWithinRange(String str, String str2) {
        return CellReference.cellReferenceIsWithinRange(str, str2, SpreadsheetVersion.EXCEL97);
    }

    public static String format(String str) {
        StringBuffer stringBuffer = new StringBuffer(str.length() + 2);
        appendFormat(stringBuffer, str);
        return stringBuffer.toString();
    }

    public static boolean isSpecialChar(char c) {
        if (Character.isLetterOrDigit(c)) {
            return false;
        }
        if (c != '\t' && c != '\n' && c != '\r') {
            return (c == '.' || c == '_') ? false : true;
        }
        throw new RuntimeException(a.a(c, a.b("Illegal character (0x"), ") found in sheet name"));
    }

    public static boolean nameLooksLikeBooleanLiteral(String str) {
        char charAt = str.charAt(0);
        if (charAt != 'F') {
            if (charAt != 'T') {
                if (charAt != 'f') {
                    if (charAt != 't') {
                        return false;
                    }
                }
            }
            return XSSFCell.TRUE.equalsIgnoreCase(str);
        }
        return XSSFCell.FALSE.equalsIgnoreCase(str);
    }

    public static boolean nameLooksLikePlainCellReference(String str) {
        Matcher matcher = CELL_REF_PATTERN.matcher(str);
        if (!matcher.matches()) {
            return false;
        }
        return cellReferenceIsWithinRange(matcher.group(1), matcher.group(2));
    }

    public static boolean needsDelimiting(String str) {
        int length = str.length();
        if (length < 1) {
            throw new RuntimeException("Zero length string is an invalid sheet name");
        } else if (Character.isDigit(str.charAt(0))) {
            return true;
        } else {
            for (int i2 = 0; i2 < length; i2++) {
                if (isSpecialChar(str.charAt(i2))) {
                    return true;
                }
            }
            return (Character.isLetter(str.charAt(0)) && Character.isDigit(str.charAt(length - 1)) && nameLooksLikePlainCellReference(str)) || nameLooksLikeBooleanLiteral(str);
        }
    }

    public static void appendFormat(StringBuffer stringBuffer, String str, String str2) {
        if (needsDelimiting(str) || needsDelimiting(str2)) {
            stringBuffer.append('\'');
            stringBuffer.append('[');
            appendAndEscape(stringBuffer, str.replace('[', '(').replace(']', ')'));
            stringBuffer.append(']');
            appendAndEscape(stringBuffer, str2);
            stringBuffer.append('\'');
            return;
        }
        stringBuffer.append('[');
        stringBuffer.append(str);
        stringBuffer.append(']');
        stringBuffer.append(str2);
    }
}
