package org.apache.poi.ss.formula;

import b.b.a.a.a;
import java.util.Arrays;
import java.util.Collection;
import java.util.Collections;
import java.util.IdentityHashMap;
import java.util.Map;
import java.util.Stack;
import java.util.TreeSet;
import org.apache.poi.ss.SpreadsheetVersion;
import org.apache.poi.ss.formula.CollaboratingWorkbooksEnvironment;
import org.apache.poi.ss.formula.atp.AnalysisToolPak;
import org.apache.poi.ss.formula.eval.BlankEval;
import org.apache.poi.ss.formula.eval.BoolEval;
import org.apache.poi.ss.formula.eval.ErrorEval;
import org.apache.poi.ss.formula.eval.EvaluationException;
import org.apache.poi.ss.formula.eval.ExternalNameEval;
import org.apache.poi.ss.formula.eval.FunctionEval;
import org.apache.poi.ss.formula.eval.FunctionNameEval;
import org.apache.poi.ss.formula.eval.MissingArgEval;
import org.apache.poi.ss.formula.eval.NotImplementedException;
import org.apache.poi.ss.formula.eval.NumberEval;
import org.apache.poi.ss.formula.eval.OperandResolver;
import org.apache.poi.ss.formula.eval.RefListEval;
import org.apache.poi.ss.formula.eval.StringEval;
import org.apache.poi.ss.formula.eval.ValueEval;
import org.apache.poi.ss.formula.functions.Choose;
import org.apache.poi.ss.formula.functions.FreeRefFunction;
import org.apache.poi.ss.formula.functions.Function;
import org.apache.poi.ss.formula.functions.IfFunc;
import org.apache.poi.ss.formula.ptg.Area3DPtg;
import org.apache.poi.ss.formula.ptg.Area3DPxg;
import org.apache.poi.ss.formula.ptg.AreaErrPtg;
import org.apache.poi.ss.formula.ptg.AreaPtg;
import org.apache.poi.ss.formula.ptg.AttrPtg;
import org.apache.poi.ss.formula.ptg.BoolPtg;
import org.apache.poi.ss.formula.ptg.ControlPtg;
import org.apache.poi.ss.formula.ptg.DeletedArea3DPtg;
import org.apache.poi.ss.formula.ptg.DeletedRef3DPtg;
import org.apache.poi.ss.formula.ptg.ErrPtg;
import org.apache.poi.ss.formula.ptg.ExpPtg;
import org.apache.poi.ss.formula.ptg.FuncVarPtg;
import org.apache.poi.ss.formula.ptg.IntPtg;
import org.apache.poi.ss.formula.ptg.MemAreaPtg;
import org.apache.poi.ss.formula.ptg.MemErrPtg;
import org.apache.poi.ss.formula.ptg.MemFuncPtg;
import org.apache.poi.ss.formula.ptg.MissingArgPtg;
import org.apache.poi.ss.formula.ptg.NamePtg;
import org.apache.poi.ss.formula.ptg.NameXPtg;
import org.apache.poi.ss.formula.ptg.NameXPxg;
import org.apache.poi.ss.formula.ptg.NumberPtg;
import org.apache.poi.ss.formula.ptg.OperationPtg;
import org.apache.poi.ss.formula.ptg.Ptg;
import org.apache.poi.ss.formula.ptg.Ref3DPtg;
import org.apache.poi.ss.formula.ptg.Ref3DPxg;
import org.apache.poi.ss.formula.ptg.RefErrorPtg;
import org.apache.poi.ss.formula.ptg.RefPtg;
import org.apache.poi.ss.formula.ptg.RefPtgBase;
import org.apache.poi.ss.formula.ptg.StringPtg;
import org.apache.poi.ss.formula.ptg.UnionPtg;
import org.apache.poi.ss.formula.ptg.UnknownPtg;
import org.apache.poi.ss.formula.udf.AggregatingUDFFinder;
import org.apache.poi.ss.formula.udf.UDFFinder;
import org.apache.poi.ss.usermodel.CellType;
import org.apache.poi.ss.util.CellRangeAddressBase;
import org.apache.poi.ss.util.CellReference;
import org.apache.poi.util.Internal;
import org.apache.poi.util.POILogFactory;
import org.apache.poi.util.POILogger;

@Internal
public final class WorkbookEvaluator {
    public static final POILogger LOG = POILogFactory.getLogger(WorkbookEvaluator.class);
    public final POILogger EVAL_LOG;
    public EvaluationCache _cache;
    public CollaboratingWorkbooksEnvironment _collaboratingWorkbookEnvironment;
    public final IEvaluationListener _evaluationListener;
    public boolean _ignoreMissingWorkbooks;
    public final Map<String, Integer> _sheetIndexesByName;
    public final Map<EvaluationSheet, Integer> _sheetIndexesBySheet;
    public final IStabilityClassifier _stabilityClassifier;
    public final AggregatingUDFFinder _udfFinder;
    public final EvaluationWorkbook _workbook;
    public int _workbookIx;
    public boolean dbgEvaluationOutputForNextEval;
    public int dbgEvaluationOutputIndent;

    /* renamed from: org.apache.poi.ss.formula.WorkbookEvaluator$1  reason: invalid class name */
    public static /* synthetic */ class AnonymousClass1 {
        public static final /* synthetic */ int[] $SwitchMap$org$apache$poi$ss$usermodel$CellType;

        /* JADX WARNING: Can't wrap try/catch for region: R(17:0|1|2|3|4|5|7|8|9|11|12|13|15|16|17|18|20) */
        /* JADX WARNING: Code restructure failed: missing block: B:21:?, code lost:
            return;
         */
        /* JADX WARNING: Failed to process nested try/catch */
        /* JADX WARNING: Missing exception handler attribute for start block: B:17:0x002b */
        /* JADX WARNING: Missing exception handler attribute for start block: B:3:0x000e */
        static {
            int[] iArr = new int[CellType.values().length];
            $SwitchMap$org$apache$poi$ss$usermodel$CellType = iArr;
            CellType cellType = CellType.NUMERIC;
            iArr[1] = 1;
            try {
                int[] iArr2 = $SwitchMap$org$apache$poi$ss$usermodel$CellType;
                CellType cellType2 = CellType.STRING;
                iArr2[2] = 2;
            } catch (NoSuchFieldError unused) {
            }
            try {
                int[] iArr3 = $SwitchMap$org$apache$poi$ss$usermodel$CellType;
                CellType cellType3 = CellType.BLANK;
                iArr3[4] = 3;
            } catch (NoSuchFieldError unused2) {
            }
            try {
                int[] iArr4 = $SwitchMap$org$apache$poi$ss$usermodel$CellType;
                CellType cellType4 = CellType.BOOLEAN;
                iArr4[5] = 4;
            } catch (NoSuchFieldError unused3) {
            }
            int[] iArr5 = $SwitchMap$org$apache$poi$ss$usermodel$CellType;
            CellType cellType5 = CellType.ERROR;
            iArr5[6] = 5;
            int[] iArr6 = $SwitchMap$org$apache$poi$ss$usermodel$CellType;
            CellType cellType6 = CellType.FORMULA;
            iArr6[3] = 6;
        }
    }

    public WorkbookEvaluator(EvaluationWorkbook evaluationWorkbook, IStabilityClassifier iStabilityClassifier, UDFFinder uDFFinder) {
        this(evaluationWorkbook, null, iStabilityClassifier, uDFFinder);
    }

    private NotImplementedException addExceptionInfo(NotImplementedException notImplementedException, int i2, int i3, int i4) {
        try {
            CellReference cellReference = new CellReference(this._workbook.getSheetName(i2), i3, i4, false, false);
            return new NotImplementedException("Error evaluating cell " + cellReference.formatAsString(), notImplementedException);
        } catch (Exception e2) {
            LOG.log(7, "Can't add exception info", e2);
            return notImplementedException;
        }
    }

    public static int countTokensToBeSkipped(Ptg[] ptgArr, int i2, int i3) {
        int i4 = i2;
        while (i3 != 0) {
            i4++;
            i3 -= ptgArr[i4].getSize();
            if (i3 < 0) {
                throw new RuntimeException("Bad skip distance (wrong token size calculation).");
            } else if (i4 >= ptgArr.length) {
                throw new RuntimeException("Skip distance too far (ran out of formula tokens).");
            }
        }
        return i4 - i2;
    }

    public static ValueEval dereferenceResult(ValueEval valueEval, int i2, int i3) {
        try {
            ValueEval singleValue = OperandResolver.getSingleValue(valueEval, i2, i3);
            return singleValue == BlankEval.instance ? NumberEval.ZERO : singleValue;
        } catch (EvaluationException e2) {
            return e2.getErrorEval();
        }
    }

    private ValueEval evaluateAny(EvaluationCell evaluationCell, int i2, int i3, int i4, EvaluationTracker evaluationTracker) {
        ValueEval valueEval;
        IStabilityClassifier iStabilityClassifier = this._stabilityClassifier;
        boolean z = iStabilityClassifier == null || !iStabilityClassifier.isCellFinal(i2, i3, i4);
        if (evaluationCell == null || evaluationCell.getCellTypeEnum() != CellType.FORMULA) {
            ValueEval valueFromNonFormulaCell = getValueFromNonFormulaCell(evaluationCell);
            if (z) {
                evaluationTracker.acceptPlainValueDependency(this._workbookIx, i2, i3, i4, valueFromNonFormulaCell);
            }
            return valueFromNonFormulaCell;
        }
        FormulaCellCacheEntry orCreateFormulaCellEntry = this._cache.getOrCreateFormulaCellEntry(evaluationCell);
        if (z || orCreateFormulaCellEntry.isInputSensitive()) {
            evaluationTracker.acceptFormulaDependency(orCreateFormulaCellEntry);
        }
        IEvaluationListener iEvaluationListener = this._evaluationListener;
        if (orCreateFormulaCellEntry.getValue() != null) {
            if (iEvaluationListener != null) {
                iEvaluationListener.onCacheHit(i2, i3, i4, orCreateFormulaCellEntry.getValue());
            }
            return orCreateFormulaCellEntry.getValue();
        } else if (!evaluationTracker.startEvaluate(orCreateFormulaCellEntry)) {
            return ErrorEval.CIRCULAR_REF_ERROR;
        } else {
            OperationEvaluationContext operationEvaluationContext = new OperationEvaluationContext(this, this._workbook, i2, i3, i4, evaluationTracker);
            try {
                Ptg[] formulaTokens = this._workbook.getFormulaTokens(evaluationCell);
                if (iEvaluationListener == null) {
                    valueEval = evaluateFormula(operationEvaluationContext, formulaTokens);
                } else {
                    iEvaluationListener.onStartEvaluate(evaluationCell, orCreateFormulaCellEntry);
                    ValueEval evaluateFormula = evaluateFormula(operationEvaluationContext, formulaTokens);
                    iEvaluationListener.onEndEvaluate(orCreateFormulaCellEntry, evaluateFormula);
                    valueEval = evaluateFormula;
                }
                evaluationTracker.updateCacheResult(valueEval);
            } catch (NotImplementedException e2) {
                throw addExceptionInfo(e2, i2, i3, i4);
            } catch (RuntimeException e3) {
                if (!(e3.getCause() instanceof CollaboratingWorkbooksEnvironment.WorkbookNotFoundException) || !this._ignoreMissingWorkbooks) {
                    throw e3;
                }
                logInfo(e3.getCause().getMessage() + " - Continuing with cached value!");
                int ordinal = evaluationCell.getCachedFormulaResultTypeEnum().ordinal();
                if (ordinal == 1) {
                    valueEval = new NumberEval(evaluationCell.getNumericCellValue());
                } else if (ordinal == 2) {
                    valueEval = new StringEval(evaluationCell.getStringCellValue());
                } else if (ordinal == 4) {
                    valueEval = BlankEval.instance;
                } else if (ordinal == 5) {
                    valueEval = BoolEval.valueOf(evaluationCell.getBooleanCellValue());
                } else if (ordinal == 6) {
                    valueEval = ErrorEval.valueOf(evaluationCell.getErrorCellValue());
                } else {
                    throw new RuntimeException("Unexpected cell type '" + evaluationCell.getCellTypeEnum() + "' found!");
                }
            } catch (Throwable th) {
                evaluationTracker.endEvaluate(orCreateFormulaCellEntry);
                throw th;
            }
            evaluationTracker.endEvaluate(orCreateFormulaCellEntry);
            if (isDebugLogEnabled()) {
                String sheetName = getSheetName(i2);
                CellReference cellReference = new CellReference(i3, i4);
                StringBuilder d2 = a.d("Evaluated ", sheetName, "!");
                d2.append(cellReference.formatAsString());
                d2.append(" to ");
                d2.append(valueEval);
                logDebug(d2.toString());
            }
            return valueEval;
        }
    }

    private ValueEval getEvalForNameRecord(EvaluationName evaluationName, OperationEvaluationContext operationEvaluationContext) {
        if (evaluationName.isFunctionName()) {
            return new FunctionNameEval(evaluationName.getNameText());
        }
        if (evaluationName.hasFormula()) {
            return evaluateNameFormula(evaluationName.getNameDefinition(), operationEvaluationContext);
        }
        StringBuilder b2 = a.b("Don't now how to evalate name '");
        b2.append(evaluationName.getNameText());
        b2.append("'");
        throw new RuntimeException(b2.toString());
    }

    private ValueEval getEvalForPtg(Ptg ptg, OperationEvaluationContext operationEvaluationContext) {
        if (ptg instanceof NamePtg) {
            return getEvalForNameRecord(this._workbook.getName((NamePtg) ptg), operationEvaluationContext);
        } else if (ptg instanceof NameXPtg) {
            return processNameEval(operationEvaluationContext.getNameXEval((NameXPtg) ptg), operationEvaluationContext);
        } else {
            if (ptg instanceof NameXPxg) {
                return processNameEval(operationEvaluationContext.getNameXEval((NameXPxg) ptg), operationEvaluationContext);
            }
            if (ptg instanceof IntPtg) {
                return new NumberEval((double) ((IntPtg) ptg).getValue());
            }
            if (ptg instanceof NumberPtg) {
                return new NumberEval(((NumberPtg) ptg).getValue());
            }
            if (ptg instanceof StringPtg) {
                return new StringEval(((StringPtg) ptg).getValue());
            }
            if (ptg instanceof BoolPtg) {
                return BoolEval.valueOf(((BoolPtg) ptg).getValue());
            }
            if (ptg instanceof ErrPtg) {
                return ErrorEval.valueOf(((ErrPtg) ptg).getErrorCode());
            }
            if (ptg instanceof MissingArgPtg) {
                return MissingArgEval.instance;
            }
            if ((ptg instanceof AreaErrPtg) || (ptg instanceof RefErrorPtg) || (ptg instanceof DeletedArea3DPtg) || (ptg instanceof DeletedRef3DPtg)) {
                return ErrorEval.REF_INVALID;
            }
            if (ptg instanceof Ref3DPtg) {
                return operationEvaluationContext.getRef3DEval((Ref3DPtg) ptg);
            }
            if (ptg instanceof Ref3DPxg) {
                return operationEvaluationContext.getRef3DEval((Ref3DPxg) ptg);
            }
            if (ptg instanceof Area3DPtg) {
                return operationEvaluationContext.getArea3DEval((Area3DPtg) ptg);
            }
            if (ptg instanceof Area3DPxg) {
                return operationEvaluationContext.getArea3DEval((Area3DPxg) ptg);
            }
            if (ptg instanceof RefPtg) {
                RefPtg refPtg = (RefPtg) ptg;
                return operationEvaluationContext.getRefEval(refPtg.getRow(), refPtg.getColumn());
            } else if (ptg instanceof AreaPtg) {
                AreaPtg areaPtg = (AreaPtg) ptg;
                return operationEvaluationContext.getAreaEval(areaPtg.getFirstRow(), areaPtg.getFirstColumn(), areaPtg.getLastRow(), areaPtg.getLastColumn());
            } else if (ptg instanceof UnknownPtg) {
                throw new RuntimeException("UnknownPtg not allowed");
            } else if (ptg instanceof ExpPtg) {
                throw new RuntimeException("ExpPtg currently not supported");
            } else {
                StringBuilder b2 = a.b("Unexpected ptg class (");
                b2.append(ptg.getClass().getName());
                b2.append(")");
                throw new RuntimeException(b2.toString());
            }
        }
    }

    public static Collection<String> getNotSupportedFunctionNames() {
        TreeSet treeSet = new TreeSet();
        treeSet.addAll(FunctionEval.getNotSupportedFunctionNames());
        treeSet.addAll(AnalysisToolPak.getNotSupportedFunctionNames());
        return Collections.unmodifiableCollection(treeSet);
    }

    private int getSheetIndex(EvaluationSheet evaluationSheet) {
        Integer num = this._sheetIndexesBySheet.get(evaluationSheet);
        if (num == null) {
            int sheetIndex = this._workbook.getSheetIndex(evaluationSheet);
            if (sheetIndex >= 0) {
                num = Integer.valueOf(sheetIndex);
                this._sheetIndexesBySheet.put(evaluationSheet, num);
            } else {
                throw new RuntimeException("Specified sheet from a different book");
            }
        }
        return num.intValue();
    }

    public static Collection<String> getSupportedFunctionNames() {
        TreeSet treeSet = new TreeSet();
        treeSet.addAll(FunctionEval.getSupportedFunctionNames());
        treeSet.addAll(AnalysisToolPak.getSupportedFunctionNames());
        return Collections.unmodifiableCollection(treeSet);
    }

    public static ValueEval getValueFromNonFormulaCell(EvaluationCell evaluationCell) {
        if (evaluationCell == null) {
            return BlankEval.instance;
        }
        CellType cellTypeEnum = evaluationCell.getCellTypeEnum();
        int ordinal = cellTypeEnum.ordinal();
        if (ordinal == 1) {
            return new NumberEval(evaluationCell.getNumericCellValue());
        }
        if (ordinal == 2) {
            return new StringEval(evaluationCell.getStringCellValue());
        }
        if (ordinal == 4) {
            return BlankEval.instance;
        }
        if (ordinal == 5) {
            return BoolEval.valueOf(evaluationCell.getBooleanCellValue());
        }
        if (ordinal == 6) {
            return ErrorEval.valueOf(evaluationCell.getErrorCellValue());
        }
        throw new RuntimeException("Unexpected cell type (" + cellTypeEnum + ")");
    }

    public static boolean isDebugLogEnabled() {
        return LOG.check(1);
    }

    public static boolean isInfoLogEnabled() {
        return LOG.check(3);
    }

    public static void logDebug(String str) {
        if (isDebugLogEnabled()) {
            LOG.log(1, str);
        }
    }

    public static void logInfo(String str) {
        if (isInfoLogEnabled()) {
            LOG.log(3, str);
        }
    }

    private ValueEval processNameEval(ValueEval valueEval, OperationEvaluationContext operationEvaluationContext) {
        return valueEval instanceof ExternalNameEval ? getEvalForNameRecord(((ExternalNameEval) valueEval).getName(), operationEvaluationContext) : valueEval;
    }

    public static void registerFunction(String str, FreeRefFunction freeRefFunction) {
        AnalysisToolPak.registerFunction(str, freeRefFunction);
    }

    public boolean adjustRegionRelativeReference(Ptg[] ptgArr, CellReference cellReference, CellRangeAddressBase cellRangeAddressBase) {
        if (cellRangeAddressBase.isInRange(cellReference)) {
            return adjustRegionRelativeReference(ptgArr, cellReference.getRow() - cellRangeAddressBase.getFirstRow(), cellReference.getCol() - cellRangeAddressBase.getFirstColumn());
        }
        throw new IllegalArgumentException(cellReference + " is not within " + cellRangeAddressBase);
    }

    public void attachToEnvironment(CollaboratingWorkbooksEnvironment collaboratingWorkbooksEnvironment, EvaluationCache evaluationCache, int i2) {
        this._collaboratingWorkbookEnvironment = collaboratingWorkbooksEnvironment;
        this._cache = evaluationCache;
        this._workbookIx = i2;
    }

    public void clearAllCachedResultValues() {
        this._cache.clear();
        this._sheetIndexesBySheet.clear();
        this._workbook.clearAllCachedResultValues();
    }

    public void detachFromEnvironment() {
        this._collaboratingWorkbookEnvironment = CollaboratingWorkbooksEnvironment.EMPTY;
        this._cache = new EvaluationCache(this._evaluationListener);
        this._workbookIx = 0;
    }

    public ValueEval evaluate(EvaluationCell evaluationCell) {
        return evaluateAny(evaluationCell, getSheetIndex(evaluationCell.getSheet()), evaluationCell.getRowIndex(), evaluationCell.getColumnIndex(), new EvaluationTracker(this._cache));
    }

    @Internal
    public ValueEval evaluateFormula(OperationEvaluationContext operationEvaluationContext, Ptg[] ptgArr) {
        ValueEval valueEval;
        int i2;
        int i3;
        if (this.dbgEvaluationOutputForNextEval) {
            this.dbgEvaluationOutputIndent = 1;
            this.dbgEvaluationOutputForNextEval = false;
        }
        int i4 = this.dbgEvaluationOutputIndent;
        String str = "";
        if (i4 > 0) {
            String substring = "                                                                                                    ".substring(0, Math.min(100, i4 * 2));
            POILogger pOILogger = this.EVAL_LOG;
            StringBuilder d2 = a.d(substring, "- evaluateFormula('");
            d2.append(operationEvaluationContext.getRefEvaluatorForCurrentSheet().getSheetNameRange());
            d2.append("'/");
            d2.append(new CellReference(operationEvaluationContext.getRowIndex(), operationEvaluationContext.getColumnIndex()).formatAsString());
            d2.append("): ");
            d2.append(Arrays.toString(ptgArr).replaceAll("\\Qorg.apache.poi.ss.formula.ptg.\\E", str));
            pOILogger.log(5, d2.toString());
            this.dbgEvaluationOutputIndent++;
            str = substring;
        }
        Stack stack = new Stack();
        int length = ptgArr.length;
        int i5 = 0;
        while (i5 < length) {
            Ptg ptg = ptgArr[i5];
            if (this.dbgEvaluationOutputIndent > 0) {
                this.EVAL_LOG.log(3, str + "  * ptg " + i5 + ": " + ptg + ", stack: " + stack);
            }
            if (ptg instanceof AttrPtg) {
                AttrPtg attrPtg = (AttrPtg) ptg;
                if (attrPtg.isSum()) {
                    ptg = FuncVarPtg.SUM;
                }
                if (attrPtg.isOptimizedChoose()) {
                    ValueEval valueEval2 = (ValueEval) stack.pop();
                    int[] jumpTable = attrPtg.getJumpTable();
                    int length2 = jumpTable.length;
                    try {
                        int evaluateFirstArg = Choose.evaluateFirstArg(valueEval2, operationEvaluationContext.getRowIndex(), operationEvaluationContext.getColumnIndex());
                        if (evaluateFirstArg >= 1) {
                            if (evaluateFirstArg <= length2) {
                                i2 = jumpTable[evaluateFirstArg - 1];
                                i5 += countTokensToBeSkipped(ptgArr, i5, i2 - ((length2 * 2) + 2));
                            }
                        }
                        stack.push(ErrorEval.VALUE_INVALID);
                        i3 = attrPtg.getChooseFuncOffset();
                    } catch (EvaluationException e2) {
                        stack.push(e2.getErrorEval());
                        i3 = attrPtg.getChooseFuncOffset();
                    }
                    i2 = i3 + 4;
                    i5 += countTokensToBeSkipped(ptgArr, i5, i2 - ((length2 * 2) + 2));
                } else if (attrPtg.isOptimizedIf()) {
                    try {
                        if (!IfFunc.evaluateFirstArg((ValueEval) stack.pop(), operationEvaluationContext.getRowIndex(), operationEvaluationContext.getColumnIndex())) {
                            i5 += countTokensToBeSkipped(ptgArr, i5, attrPtg.getData());
                            int i6 = i5 + 1;
                            Ptg ptg2 = ptgArr[i6];
                            if ((ptgArr[i5] instanceof AttrPtg) && (ptg2 instanceof FuncVarPtg) && ((FuncVarPtg) ptg2).getFunctionIndex() == 1) {
                                stack.push(BoolEval.FALSE);
                                i5 = i6;
                            }
                        }
                    } catch (EvaluationException e3) {
                        stack.push(e3.getErrorEval());
                        int countTokensToBeSkipped = countTokensToBeSkipped(ptgArr, i5, attrPtg.getData()) + i5;
                        i5 = countTokensToBeSkipped(ptgArr, countTokensToBeSkipped, ((AttrPtg) ptgArr[countTokensToBeSkipped]).getData() + 1) + countTokensToBeSkipped;
                    }
                } else if (attrPtg.isSkip()) {
                    i5 += countTokensToBeSkipped(ptgArr, i5, attrPtg.getData() + 1);
                    if (stack.peek() == MissingArgEval.instance) {
                        stack.pop();
                        stack.push(BlankEval.instance);
                    }
                }
                i5++;
            }
            if (!(ptg instanceof ControlPtg) && !(ptg instanceof MemFuncPtg) && !(ptg instanceof MemAreaPtg) && !(ptg instanceof MemErrPtg)) {
                if (ptg instanceof UnionPtg) {
                    stack.push(new RefListEval((ValueEval) stack.pop(), (ValueEval) stack.pop()));
                } else {
                    if (ptg instanceof OperationPtg) {
                        OperationPtg operationPtg = (OperationPtg) ptg;
                        int numberOfOperands = operationPtg.getNumberOfOperands();
                        ValueEval[] valueEvalArr = new ValueEval[numberOfOperands];
                        for (int i7 = numberOfOperands - 1; i7 >= 0; i7--) {
                            valueEvalArr[i7] = (ValueEval) stack.pop();
                        }
                        valueEval = OperationEvaluatorFactory.evaluate(operationPtg, valueEvalArr, operationEvaluationContext);
                    } else {
                        valueEval = getEvalForPtg(ptg, operationEvaluationContext);
                    }
                    if (valueEval != null) {
                        stack.push(valueEval);
                        if (this.dbgEvaluationOutputIndent > 0) {
                            this.EVAL_LOG.log(3, str + "    = " + valueEval);
                        }
                    } else {
                        throw new RuntimeException("Evaluation result must not be null");
                    }
                }
            }
            i5++;
        }
        ValueEval valueEval3 = (ValueEval) stack.pop();
        if (stack.isEmpty()) {
            if (operationEvaluationContext.isSingleValue()) {
                valueEval3 = dereferenceResult(valueEval3, operationEvaluationContext.getRowIndex(), operationEvaluationContext.getColumnIndex());
            }
            if (this.dbgEvaluationOutputIndent > 0) {
                POILogger pOILogger2 = this.EVAL_LOG;
                StringBuilder d3 = a.d(str, "finshed eval of ");
                d3.append(new CellReference(operationEvaluationContext.getRowIndex(), operationEvaluationContext.getColumnIndex()).formatAsString());
                d3.append(": ");
                d3.append(valueEval3);
                pOILogger2.log(3, d3.toString());
                int i8 = this.dbgEvaluationOutputIndent - 1;
                this.dbgEvaluationOutputIndent = i8;
                if (i8 == 1) {
                    this.dbgEvaluationOutputIndent = -1;
                }
            }
            return valueEval3;
        }
        throw new IllegalStateException("evaluation stack not empty");
    }

    public ValueEval evaluateList(String str, CellReference cellReference, CellRangeAddressBase cellRangeAddressBase) {
        return evaluate(str, cellReference, cellRangeAddressBase, FormulaType.DATAVALIDATION_LIST);
    }

    public ValueEval evaluateNameFormula(Ptg[] ptgArr, OperationEvaluationContext operationEvaluationContext) {
        if (ptgArr.length == 1) {
            return getEvalForPtg(ptgArr[0], operationEvaluationContext);
        }
        return evaluateFormula(operationEvaluationContext, ptgArr);
    }

    public ValueEval evaluateReference(EvaluationSheet evaluationSheet, int i2, int i3, int i4, EvaluationTracker evaluationTracker) {
        return evaluateAny(evaluationSheet.getCell(i3, i4), i2, i3, i4, evaluationTracker);
    }

    public FreeRefFunction findUserDefinedFunction(String str) {
        return this._udfFinder.findFunction(str);
    }

    public CollaboratingWorkbooksEnvironment getEnvironment() {
        return this._collaboratingWorkbookEnvironment;
    }

    public IEvaluationListener getEvaluationListener() {
        return this._evaluationListener;
    }

    public EvaluationName getName(String str, int i2) {
        return this._workbook.getName(str, i2);
    }

    public WorkbookEvaluator getOtherWorkbookEvaluator(String str) {
        return this._collaboratingWorkbookEnvironment.getWorkbookEvaluator(str);
    }

    public EvaluationSheet getSheet(int i2) {
        return this._workbook.getSheet(i2);
    }

    public int getSheetIndexByExternIndex(int i2) {
        return this._workbook.convertFromExternSheetIndex(i2);
    }

    public String getSheetName(int i2) {
        return this._workbook.getSheetName(i2);
    }

    public EvaluationWorkbook getWorkbook() {
        return this._workbook;
    }

    public boolean isDebugEvaluationOutputForNextEval() {
        return this.dbgEvaluationOutputForNextEval;
    }

    public boolean isIgnoreMissingWorkbooks() {
        return this._ignoreMissingWorkbooks;
    }

    public void notifyDeleteCell(EvaluationCell evaluationCell) {
        this._cache.notifyDeleteCell(this._workbookIx, getSheetIndex(evaluationCell.getSheet()), evaluationCell);
    }

    public void notifyUpdateCell(EvaluationCell evaluationCell) {
        this._cache.notifyUpdateCell(this._workbookIx, getSheetIndex(evaluationCell.getSheet()), evaluationCell);
    }

    public void setDebugEvaluationOutputForNextEval(boolean z) {
        this.dbgEvaluationOutputForNextEval = z;
    }

    public void setIgnoreMissingWorkbooks(boolean z) {
        this._ignoreMissingWorkbooks = z;
    }

    public WorkbookEvaluator(EvaluationWorkbook evaluationWorkbook, IEvaluationListener iEvaluationListener, IStabilityClassifier iStabilityClassifier, UDFFinder uDFFinder) {
        AggregatingUDFFinder aggregatingUDFFinder;
        this.EVAL_LOG = POILogFactory.getLogger("POI.FormulaEval");
        this.dbgEvaluationOutputIndent = -1;
        this._workbook = evaluationWorkbook;
        this._evaluationListener = iEvaluationListener;
        this._cache = new EvaluationCache(iEvaluationListener);
        this._sheetIndexesBySheet = new IdentityHashMap();
        this._sheetIndexesByName = new IdentityHashMap();
        this._collaboratingWorkbookEnvironment = CollaboratingWorkbooksEnvironment.EMPTY;
        this._workbookIx = 0;
        this._stabilityClassifier = iStabilityClassifier;
        if (evaluationWorkbook == null) {
            aggregatingUDFFinder = null;
        } else {
            aggregatingUDFFinder = (AggregatingUDFFinder) evaluationWorkbook.getUDFFinder();
        }
        if (!(aggregatingUDFFinder == null || uDFFinder == null)) {
            aggregatingUDFFinder.add(uDFFinder);
        }
        this._udfFinder = aggregatingUDFFinder;
    }

    public static void registerFunction(String str, Function function) {
        FunctionEval.registerFunction(str, function);
    }

    public ValueEval evaluate(String str, CellReference cellReference) {
        int i2;
        int i3;
        short s;
        String sheetName = cellReference == null ? null : cellReference.getSheetName();
        if (sheetName == null) {
            i2 = -1;
        } else {
            i2 = getWorkbook().getSheetIndex(sheetName);
        }
        if (cellReference == null) {
            i3 = -1;
        } else {
            i3 = cellReference.getRow();
        }
        if (cellReference == null) {
            s = -1;
        } else {
            s = cellReference.getCol();
        }
        return evaluateNameFormula(FormulaParser.parse(str, (FormulaParsingWorkbook) getWorkbook(), FormulaType.CELL, i2, i3), new OperationEvaluationContext(this, getWorkbook(), i2, i3, s, new EvaluationTracker(this._cache)));
    }

    public boolean adjustRegionRelativeReference(Ptg[] ptgArr, int i2, int i3) {
        if (i2 < 0) {
            throw new IllegalArgumentException("offset row must be positive");
        } else if (i3 >= 0) {
            boolean z = false;
            for (Ptg ptg : ptgArr) {
                if (ptg instanceof RefPtgBase) {
                    RefPtgBase refPtgBase = (RefPtgBase) ptg;
                    SpreadsheetVersion spreadsheetVersion = this._workbook.getSpreadsheetVersion();
                    if (refPtgBase.isRowRelative()) {
                        int row = refPtgBase.getRow() + i2;
                        if (row <= spreadsheetVersion.getMaxRows()) {
                            refPtgBase.setRow(row);
                            z = true;
                        } else {
                            throw new IndexOutOfBoundsException(spreadsheetVersion.name() + " files can only have " + spreadsheetVersion.getMaxRows() + " rows, but row " + row + " was requested.");
                        }
                    }
                    if (!refPtgBase.isColRelative()) {
                        continue;
                    } else {
                        int column = refPtgBase.getColumn() + i3;
                        if (column <= spreadsheetVersion.getMaxColumns()) {
                            refPtgBase.setColumn(column);
                            z = true;
                        } else {
                            throw new IndexOutOfBoundsException(spreadsheetVersion.name() + " files can only have " + spreadsheetVersion.getMaxColumns() + " columns, but column " + column + " was requested.");
                        }
                    }
                }
            }
            return z;
        } else {
            throw new IllegalArgumentException("offset column must be positive");
        }
    }

    public int getSheetIndex(String str) {
        Integer num = this._sheetIndexesByName.get(str);
        if (num == null) {
            int sheetIndex = this._workbook.getSheetIndex(str);
            if (sheetIndex < 0) {
                return -1;
            }
            num = Integer.valueOf(sheetIndex);
            this._sheetIndexesByName.put(str, num);
        }
        return num.intValue();
    }

    public ValueEval evaluate(String str, CellReference cellReference, CellRangeAddressBase cellRangeAddressBase) {
        return evaluate(str, cellReference, cellRangeAddressBase, FormulaType.CELL);
    }

    private ValueEval evaluate(String str, CellReference cellReference, CellRangeAddressBase cellRangeAddressBase, FormulaType formulaType) {
        String sheetName = cellReference == null ? null : cellReference.getSheetName();
        if (sheetName != null) {
            int sheetIndex = getWorkbook().getSheetIndex(sheetName);
            Ptg[] parse = FormulaParser.parse(str, (FormulaParsingWorkbook) getWorkbook(), formulaType, sheetIndex, cellReference.getRow());
            adjustRegionRelativeReference(parse, cellReference, cellRangeAddressBase);
            return evaluateNameFormula(parse, new OperationEvaluationContext(this, getWorkbook(), sheetIndex, cellReference.getRow(), cellReference.getCol(), new EvaluationTracker(this._cache), formulaType.isSingleValue()));
        }
        throw new IllegalArgumentException("Sheet name is required");
    }
}
