package org.apache.poi.ss.formula.atp;

import java.util.ArrayList;
import org.apache.poi.ss.formula.eval.AreaEvalBase;
import org.apache.poi.ss.formula.eval.OperandResolver;
import org.apache.poi.ss.formula.eval.StringEval;
import org.apache.poi.ss.formula.eval.ValueEval;
import org.apache.poi.ss.formula.functions.NumericFunction;
import org.apache.poi.ss.usermodel.DateUtil;

public final class ArgumentsEvaluator {
    public static final ArgumentsEvaluator instance = new ArgumentsEvaluator();

    public double evaluateDateArg(ValueEval valueEval, int i2, int i3) {
        ValueEval singleValue = OperandResolver.getSingleValue(valueEval, i2, (short) i3);
        if (!(singleValue instanceof StringEval)) {
            return OperandResolver.coerceValueToDouble(singleValue);
        }
        String stringValue = ((StringEval) singleValue).getStringValue();
        Double parseDouble = OperandResolver.parseDouble(stringValue);
        if (parseDouble != null) {
            return parseDouble.doubleValue();
        }
        return DateUtil.getExcelDate(DateParser.parseDate(stringValue), false);
    }

    public double[] evaluateDatesArg(ValueEval valueEval, int i2, int i3) {
        if (valueEval == null) {
            return new double[0];
        }
        if (valueEval instanceof StringEval) {
            return new double[]{evaluateDateArg(valueEval, i2, i3)};
        } else if (valueEval instanceof AreaEvalBase) {
            ArrayList arrayList = new ArrayList();
            AreaEvalBase areaEvalBase = (AreaEvalBase) valueEval;
            for (int firstRow = areaEvalBase.getFirstRow(); firstRow <= areaEvalBase.getLastRow(); firstRow++) {
                for (int firstColumn = areaEvalBase.getFirstColumn(); firstColumn <= areaEvalBase.getLastColumn(); firstColumn++) {
                    arrayList.add(Double.valueOf(evaluateDateArg(areaEvalBase.getAbsoluteValue(firstRow, firstColumn), firstRow, firstColumn)));
                }
            }
            double[] dArr = new double[arrayList.size()];
            for (int i4 = 0; i4 < arrayList.size(); i4++) {
                dArr[i4] = ((Double) arrayList.get(i4)).doubleValue();
            }
            return dArr;
        } else {
            return new double[]{OperandResolver.coerceValueToDouble(valueEval)};
        }
    }

    public double evaluateNumberArg(ValueEval valueEval, int i2, int i3) {
        return valueEval == null ? NumericFunction.LOG_10_TO_BASE_e : OperandResolver.coerceValueToDouble(valueEval);
    }
}
