package org.apache.poi.ss.formula.atp;

import org.apache.poi.ss.formula.OperationEvaluationContext;
import org.apache.poi.ss.formula.eval.ErrorEval;
import org.apache.poi.ss.formula.eval.EvaluationException;
import org.apache.poi.ss.formula.eval.NumberEval;
import org.apache.poi.ss.formula.eval.OperandResolver;
import org.apache.poi.ss.formula.eval.ValueEval;
import org.apache.poi.ss.formula.functions.FreeRefFunction;
import org.apache.poi.ss.formula.functions.NumericFunction;

public final class MRound implements FreeRefFunction {
    public static final FreeRefFunction instance = new MRound();

    @Override // org.apache.poi.ss.formula.functions.FreeRefFunction
    public ValueEval evaluate(ValueEval[] valueEvalArr, OperationEvaluationContext operationEvaluationContext) {
        if (valueEvalArr.length != 2) {
            return ErrorEval.VALUE_INVALID;
        }
        try {
            double coerceValueToDouble = OperandResolver.coerceValueToDouble(OperandResolver.getSingleValue(valueEvalArr[0], operationEvaluationContext.getRowIndex(), operationEvaluationContext.getColumnIndex()));
            double coerceValueToDouble2 = OperandResolver.coerceValueToDouble(OperandResolver.getSingleValue(valueEvalArr[1], operationEvaluationContext.getRowIndex(), operationEvaluationContext.getColumnIndex()));
            double d2 = NumericFunction.LOG_10_TO_BASE_e;
            if (coerceValueToDouble2 != NumericFunction.LOG_10_TO_BASE_e) {
                if (coerceValueToDouble * coerceValueToDouble2 >= NumericFunction.LOG_10_TO_BASE_e) {
                    d2 = coerceValueToDouble2 * ((double) Math.round(coerceValueToDouble / coerceValueToDouble2));
                } else {
                    throw new EvaluationException(ErrorEval.NUM_ERROR);
                }
            }
            NumericFunction.checkValue(d2);
            return new NumberEval(d2);
        } catch (EvaluationException e2) {
            return e2.getErrorEval();
        }
    }
}
