package org.apache.poi.ss.formula.atp;

import java.util.Calendar;
import java.util.Date;
import org.apache.poi.ss.usermodel.DateUtil;
import org.apache.poi.util.LocaleUtil;
import org.apache.poi.util.Removal;

public class WorkdayCalculator {
    public static final WorkdayCalculator instance = new WorkdayCalculator();

    public int calculateNonWeekendHolidays(double d2, double d3, double[] dArr) {
        int i2 = (d2 > d3 ? 1 : (d2 == d3 ? 0 : -1));
        double d4 = i2 < 0 ? d2 : d3;
        double d5 = d3 > d2 ? d3 : d2;
        int i3 = 0;
        for (double d6 : dArr) {
            if (isInARange(d4, d5, d6)) {
                if (!isWeekend(d6)) {
                    i3++;
                }
            }
        }
        return i2 <= 0 ? i3 : -i3;
    }

    public int calculateWorkdays(double d2, double d3, double[] dArr) {
        int pastDaysOfWeek = pastDaysOfWeek(d2, d3, 7);
        int pastDaysOfWeek2 = pastDaysOfWeek(d2, d3, 1);
        return ((((int) ((d3 - d2) + 1.0d)) - pastDaysOfWeek) - pastDaysOfWeek2) - calculateNonWeekendHolidays(d2, d3, dArr);
    }

    public boolean isHoliday(double d2, double[] dArr) {
        for (double d3 : dArr) {
            if (Math.round(d3) == Math.round(d2)) {
                return true;
            }
        }
        return false;
    }

    public boolean isInARange(double d2, double d3, double d4) {
        return d4 >= d2 && d4 <= d3;
    }

    @Removal(version = "3.18")
    public int isNonWorkday(double d2, double[] dArr) {
        return (isWeekend(d2) || isHoliday(d2, dArr)) ? 1 : 0;
    }

    public boolean isWeekend(double d2) {
        Calendar localeCalendar = LocaleUtil.getLocaleCalendar();
        localeCalendar.setTime(DateUtil.getJavaDate(d2));
        return localeCalendar.get(7) == 7 || localeCalendar.get(7) == 1;
    }

    public int pastDaysOfWeek(double d2, double d3, int i2) {
        int i3 = (d2 > d3 ? 1 : (d2 == d3 ? 0 : -1));
        if (d3 > d2) {
            d2 = d3;
        }
        int floor = (int) Math.floor(d2);
        int i4 = 0;
        for (int floor2 = (int) Math.floor(i3 < 0 ? d2 : d3); floor2 <= floor; floor2++) {
            Calendar localeCalendar = LocaleUtil.getLocaleCalendar();
            localeCalendar.setTime(DateUtil.getJavaDate((double) floor2));
            if (localeCalendar.get(7) == i2) {
                i4++;
            }
        }
        return i3 <= 0 ? i4 : -i4;
    }

    public Date calculateWorkdays(double d2, int i2, double[] dArr) {
        Date javaDate = DateUtil.getJavaDate(d2);
        int i3 = i2 < 0 ? -1 : 1;
        Calendar localeCalendar = LocaleUtil.getLocaleCalendar();
        localeCalendar.setTime(javaDate);
        double excelDate = DateUtil.getExcelDate(localeCalendar.getTime());
        while (i2 != 0) {
            localeCalendar.add(6, i3);
            excelDate += (double) i3;
            if (!(localeCalendar.get(7) == 7 || localeCalendar.get(7) == 1 || isHoliday(excelDate, dArr))) {
                i2 -= i3;
            }
        }
        return localeCalendar.getTime();
    }
}
