package org.apache.poi.ss.formula.atp;

import org.apache.poi.ss.formula.OperationEvaluationContext;
import org.apache.poi.ss.formula.eval.ErrorEval;
import org.apache.poi.ss.formula.eval.EvaluationException;
import org.apache.poi.ss.formula.eval.NumberEval;
import org.apache.poi.ss.formula.eval.OperandResolver;
import org.apache.poi.ss.formula.eval.StringEval;
import org.apache.poi.ss.formula.eval.ValueEval;
import org.apache.poi.ss.formula.functions.FreeRefFunction;
import org.apache.poi.ss.usermodel.DateUtil;

public final class YearFrac implements FreeRefFunction {
    public static final FreeRefFunction instance = new YearFrac();

    public static double evaluateDateArg(ValueEval valueEval, int i2, int i3) {
        ValueEval singleValue = OperandResolver.getSingleValue(valueEval, i2, (short) i3);
        if (!(singleValue instanceof StringEval)) {
            return OperandResolver.coerceValueToDouble(singleValue);
        }
        String stringValue = ((StringEval) singleValue).getStringValue();
        Double parseDouble = OperandResolver.parseDouble(stringValue);
        if (parseDouble != null) {
            return parseDouble.doubleValue();
        }
        return DateUtil.getExcelDate(DateParser.parseDate(stringValue), false);
    }

    public static int evaluateIntArg(ValueEval valueEval, int i2, int i3) {
        return OperandResolver.coerceValueToInt(OperandResolver.getSingleValue(valueEval, i2, (short) i3));
    }

    @Override // org.apache.poi.ss.formula.functions.FreeRefFunction
    public ValueEval evaluate(ValueEval[] valueEvalArr, OperationEvaluationContext operationEvaluationContext) {
        int i2;
        int rowIndex = operationEvaluationContext.getRowIndex();
        int columnIndex = operationEvaluationContext.getColumnIndex();
        try {
            int length = valueEvalArr.length;
            if (length == 2) {
                i2 = 0;
            } else if (length != 3) {
                return ErrorEval.VALUE_INVALID;
            } else {
                i2 = evaluateIntArg(valueEvalArr[2], rowIndex, columnIndex);
            }
            return new NumberEval(YearFracCalculator.calculate(evaluateDateArg(valueEvalArr[0], rowIndex, columnIndex), evaluateDateArg(valueEvalArr[1], rowIndex, columnIndex), i2));
        } catch (EvaluationException e2) {
            return e2.getErrorEval();
        }
    }
}
