package org.apache.poi.ss.formula.constant;

import b.b.a.a.a;
import org.apache.poi.util.LittleEndianInput;
import org.apache.poi.util.LittleEndianOutput;
import org.apache.poi.util.StringUtil;

public final class ConstantValueParser {
    public static final Object EMPTY_REPRESENTATION = null;
    public static final int FALSE_ENCODING = 0;
    public static final int TRUE_ENCODING = 1;
    public static final int TYPE_BOOLEAN = 4;
    public static final int TYPE_EMPTY = 0;
    public static final int TYPE_ERROR_CODE = 16;
    public static final int TYPE_NUMBER = 1;
    public static final int TYPE_STRING = 2;

    public static void encode(LittleEndianOutput littleEndianOutput, Object[] objArr) {
        for (Object obj : objArr) {
            encodeSingleValue(littleEndianOutput, obj);
        }
    }

    public static void encodeSingleValue(LittleEndianOutput littleEndianOutput, Object obj) {
        long j = 0;
        if (obj == EMPTY_REPRESENTATION) {
            littleEndianOutput.writeByte(0);
            littleEndianOutput.writeLong(0);
        } else if (obj instanceof Boolean) {
            littleEndianOutput.writeByte(4);
            if (((Boolean) obj).booleanValue()) {
                j = 1;
            }
            littleEndianOutput.writeLong(j);
        } else if (obj instanceof Double) {
            littleEndianOutput.writeByte(1);
            littleEndianOutput.writeDouble(((Double) obj).doubleValue());
        } else if (obj instanceof String) {
            littleEndianOutput.writeByte(2);
            StringUtil.writeUnicodeString(littleEndianOutput, (String) obj);
        } else if (obj instanceof ErrorConstant) {
            littleEndianOutput.writeByte(16);
            littleEndianOutput.writeLong((long) ((ErrorConstant) obj).getErrorCode());
        } else {
            StringBuilder b2 = a.b("Unexpected value type (");
            b2.append(obj.getClass().getName());
            b2.append("'");
            throw new IllegalStateException(b2.toString());
        }
    }

    public static int getEncodedSize(Object[] objArr) {
        int length = objArr.length * 1;
        for (Object obj : objArr) {
            length += getEncodedSize(obj);
        }
        return length;
    }

    public static Object[] parse(LittleEndianInput littleEndianInput, int i2) {
        Object[] objArr = new Object[i2];
        for (int i3 = 0; i3 < i2; i3++) {
            objArr[i3] = readAConstantValue(littleEndianInput);
        }
        return objArr;
    }

    public static Object readAConstantValue(LittleEndianInput littleEndianInput) {
        byte readByte = littleEndianInput.readByte();
        if (readByte == 0) {
            littleEndianInput.readLong();
            return EMPTY_REPRESENTATION;
        } else if (readByte == 1) {
            return new Double(littleEndianInput.readDouble());
        } else {
            if (readByte == 2) {
                return StringUtil.readUnicodeString(littleEndianInput);
            }
            if (readByte == 4) {
                return readBoolean(littleEndianInput);
            }
            if (readByte == 16) {
                int readUShort = littleEndianInput.readUShort();
                littleEndianInput.readUShort();
                littleEndianInput.readInt();
                return ErrorConstant.valueOf(readUShort);
            }
            throw new RuntimeException(a.b("Unknown grbit value (", readByte, ")"));
        }
    }

    public static Object readBoolean(LittleEndianInput littleEndianInput) {
        byte readLong = (byte) ((int) littleEndianInput.readLong());
        if (readLong == 0) {
            return Boolean.FALSE;
        }
        if (readLong == 1) {
            return Boolean.TRUE;
        }
        throw new RuntimeException(a.b("unexpected boolean encoding (", readLong, ")"));
    }

    public static int getEncodedSize(Object obj) {
        Class<?> cls;
        if (obj == EMPTY_REPRESENTATION || (cls = obj.getClass()) == Boolean.class || cls == Double.class || cls == ErrorConstant.class) {
            return 8;
        }
        return StringUtil.getEncodedSize((String) obj);
    }
}
