package org.apache.poi.ss.formula.eval;

import b.b.a.a.a;
import java.util.regex.Pattern;
import org.apache.poi.ss.formula.functions.NumericFunction;
import org.apache.xerces.impl.xs.SchemaSymbols;

public final class OperandResolver {
    public static final String Digits = "(\\p{Digit}+)";
    public static final String Exp = "[eE][+-]?(\\p{Digit}+)";
    public static final String fpRegex = "[\\x00-\\x20]*[+-]?(((((\\p{Digit}+)(\\.)?((\\p{Digit}+)?)([eE][+-]?(\\p{Digit}+))?)|(\\.((\\p{Digit}+))([eE][+-]?(\\p{Digit}+))?))))[\\x00-\\x20]*";

    public static ValueEval chooseSingleElementFromArea(AreaEval areaEval, int i2, int i3) {
        ValueEval chooseSingleElementFromAreaInternal = chooseSingleElementFromAreaInternal(areaEval, i2, i3);
        if (!(chooseSingleElementFromAreaInternal instanceof ErrorEval)) {
            return chooseSingleElementFromAreaInternal;
        }
        throw new EvaluationException((ErrorEval) chooseSingleElementFromAreaInternal);
    }

    public static ValueEval chooseSingleElementFromAreaInternal(AreaEval areaEval, int i2, int i3) {
        if (areaEval.isColumn()) {
            if (areaEval.isRow()) {
                return areaEval.getRelativeValue(0, 0);
            }
            if (areaEval.containsRow(i2)) {
                return areaEval.getAbsoluteValue(i2, areaEval.getFirstColumn());
            }
            throw EvaluationException.invalidValue();
        } else if (!areaEval.isRow()) {
            if (areaEval.containsRow(i2) && areaEval.containsColumn(i3)) {
                return areaEval.getAbsoluteValue(areaEval.getFirstRow(), areaEval.getFirstColumn());
            }
            throw EvaluationException.invalidValue();
        } else if (areaEval.containsColumn(i3)) {
            return areaEval.getAbsoluteValue(areaEval.getFirstRow(), i3);
        } else {
            throw EvaluationException.invalidValue();
        }
    }

    public static ValueEval chooseSingleElementFromRef(RefEval refEval) {
        return refEval.getInnerValueEval(refEval.getFirstSheetIndex());
    }

    public static Boolean coerceValueToBoolean(ValueEval valueEval, boolean z) {
        BlankEval blankEval;
        if (valueEval == null || valueEval == (blankEval = BlankEval.instance)) {
            return null;
        }
        if (valueEval instanceof BoolEval) {
            return Boolean.valueOf(((BoolEval) valueEval).getBooleanValue());
        }
        if (valueEval == blankEval) {
            return null;
        }
        if (valueEval instanceof StringEval) {
            if (z) {
                return null;
            }
            String stringValue = ((StringEval) valueEval).getStringValue();
            if (stringValue.equalsIgnoreCase(SchemaSymbols.ATTVAL_TRUE)) {
                return Boolean.TRUE;
            }
            if (stringValue.equalsIgnoreCase(SchemaSymbols.ATTVAL_FALSE)) {
                return Boolean.FALSE;
            }
            throw new EvaluationException(ErrorEval.VALUE_INVALID);
        } else if (valueEval instanceof NumericValueEval) {
            double numberValue = ((NumericValueEval) valueEval).getNumberValue();
            if (!Double.isNaN(numberValue)) {
                return Boolean.valueOf(numberValue != NumericFunction.LOG_10_TO_BASE_e);
            }
            throw new EvaluationException(ErrorEval.VALUE_INVALID);
        } else if (valueEval instanceof ErrorEval) {
            throw new EvaluationException((ErrorEval) valueEval);
        } else {
            StringBuilder b2 = a.b("Unexpected eval (");
            b2.append(valueEval.getClass().getName());
            b2.append(")");
            throw new RuntimeException(b2.toString());
        }
    }

    public static double coerceValueToDouble(ValueEval valueEval) {
        if (valueEval == BlankEval.instance) {
            return NumericFunction.LOG_10_TO_BASE_e;
        }
        if (valueEval instanceof NumericValueEval) {
            return ((NumericValueEval) valueEval).getNumberValue();
        }
        if (valueEval instanceof StringEval) {
            Double parseDouble = parseDouble(((StringEval) valueEval).getStringValue());
            if (parseDouble != null) {
                return parseDouble.doubleValue();
            }
            throw EvaluationException.invalidValue();
        }
        StringBuilder b2 = a.b("Unexpected arg eval type (");
        b2.append(valueEval.getClass().getName());
        b2.append(")");
        throw new RuntimeException(b2.toString());
    }

    public static int coerceValueToInt(ValueEval valueEval) {
        if (valueEval == BlankEval.instance) {
            return 0;
        }
        return (int) Math.floor(coerceValueToDouble(valueEval));
    }

    public static String coerceValueToString(ValueEval valueEval) {
        if (valueEval instanceof StringValueEval) {
            return ((StringValueEval) valueEval).getStringValue();
        }
        if (valueEval == BlankEval.instance) {
            return "";
        }
        StringBuilder b2 = a.b("Unexpected eval class (");
        b2.append(valueEval.getClass().getName());
        b2.append(")");
        throw new IllegalArgumentException(b2.toString());
    }

    public static ValueEval getSingleValue(ValueEval valueEval, int i2, int i3) {
        if (valueEval instanceof RefEval) {
            valueEval = chooseSingleElementFromRef((RefEval) valueEval);
        } else if (valueEval instanceof AreaEval) {
            valueEval = chooseSingleElementFromArea((AreaEval) valueEval, i2, i3);
        }
        if (!(valueEval instanceof ErrorEval)) {
            return valueEval;
        }
        throw new EvaluationException((ErrorEval) valueEval);
    }

    public static Double parseDouble(String str) {
        if (Pattern.matches(fpRegex, str)) {
            try {
                return Double.valueOf(Double.parseDouble(str));
            } catch (NumberFormatException unused) {
            }
        }
        return null;
    }
}
