package org.apache.poi.ss.formula.eval;

import org.apache.poi.ss.formula.functions.Fixed2ArgFunction;
import org.apache.poi.ss.formula.functions.Function;
import org.apache.poi.ss.formula.functions.NumericFunction;

public abstract class TwoOperandNumericOperation extends Fixed2ArgFunction {
    public static final Function AddEval = new TwoOperandNumericOperation() {
        /* class org.apache.poi.ss.formula.eval.TwoOperandNumericOperation.AnonymousClass1 */

        @Override // org.apache.poi.ss.formula.eval.TwoOperandNumericOperation
        public double evaluate(double d2, double d3) {
            return d2 + d3;
        }
    };
    public static final Function DivideEval = new TwoOperandNumericOperation() {
        /* class org.apache.poi.ss.formula.eval.TwoOperandNumericOperation.AnonymousClass2 */

        @Override // org.apache.poi.ss.formula.eval.TwoOperandNumericOperation
        public double evaluate(double d2, double d3) {
            if (d3 != NumericFunction.LOG_10_TO_BASE_e) {
                return d2 / d3;
            }
            throw new EvaluationException(ErrorEval.DIV_ZERO);
        }
    };
    public static final Function MultiplyEval = new TwoOperandNumericOperation() {
        /* class org.apache.poi.ss.formula.eval.TwoOperandNumericOperation.AnonymousClass3 */

        @Override // org.apache.poi.ss.formula.eval.TwoOperandNumericOperation
        public double evaluate(double d2, double d3) {
            return d2 * d3;
        }
    };
    public static final Function PowerEval = new TwoOperandNumericOperation() {
        /* class org.apache.poi.ss.formula.eval.TwoOperandNumericOperation.AnonymousClass4 */

        @Override // org.apache.poi.ss.formula.eval.TwoOperandNumericOperation
        public double evaluate(double d2, double d3) {
            return Math.pow(d2, d3);
        }
    };
    public static final Function SubtractEval = new SubtractEvalClass();

    public static final class SubtractEvalClass extends TwoOperandNumericOperation {
        @Override // org.apache.poi.ss.formula.eval.TwoOperandNumericOperation
        public double evaluate(double d2, double d3) {
            return d2 - d3;
        }
    }

    public abstract double evaluate(double d2, double d3);

    @Override // org.apache.poi.ss.formula.functions.Function2Arg
    public ValueEval evaluate(int i2, int i3, ValueEval valueEval, ValueEval valueEval2) {
        try {
            double evaluate = evaluate(singleOperandEvaluate(valueEval, i2, i3), singleOperandEvaluate(valueEval2, i2, i3));
            if (evaluate == NumericFunction.LOG_10_TO_BASE_e && !(this instanceof SubtractEvalClass)) {
                return NumberEval.ZERO;
            }
            if (Double.isNaN(evaluate) || Double.isInfinite(evaluate)) {
                return ErrorEval.NUM_ERROR;
            }
            return new NumberEval(evaluate);
        } catch (EvaluationException e2) {
            return e2.getErrorEval();
        }
    }

    public final double singleOperandEvaluate(ValueEval valueEval, int i2, int i3) {
        return OperandResolver.coerceValueToDouble(OperandResolver.getSingleValue(valueEval, i2, i3));
    }
}
