package org.apache.poi.ss.formula.eval.forked;

import b.b.a.a.a;
import java.util.Arrays;
import java.util.HashMap;
import java.util.Map;
import org.apache.poi.ss.formula.EvaluationCell;
import org.apache.poi.ss.formula.EvaluationSheet;
import org.apache.poi.ss.formula.EvaluationWorkbook;
import org.apache.poi.ss.usermodel.Cell;
import org.apache.poi.ss.usermodel.Row;
import org.apache.poi.ss.usermodel.Sheet;
import org.apache.poi.ss.util.CellReference;
import org.apache.poi.util.Internal;

@Internal
public final class ForkedEvaluationSheet implements EvaluationSheet {
    public final EvaluationSheet _masterSheet;
    public final Map<RowColKey, ForkedEvaluationCell> _sharedCellsByRowCol = new HashMap();

    public static final class RowColKey implements Comparable<RowColKey> {
        public final int _columnIndex;
        public final int _rowIndex;

        public RowColKey(int i2, int i3) {
            this._rowIndex = i2;
            this._columnIndex = i3;
        }

        public boolean equals(Object obj) {
            if (!(obj instanceof RowColKey)) {
                return false;
            }
            RowColKey rowColKey = (RowColKey) obj;
            if (this._rowIndex == rowColKey._rowIndex && this._columnIndex == rowColKey._columnIndex) {
                return true;
            }
            return false;
        }

        public int getColumnIndex() {
            return this._columnIndex;
        }

        public int getRowIndex() {
            return this._rowIndex;
        }

        public int hashCode() {
            return this._rowIndex ^ this._columnIndex;
        }

        public int compareTo(RowColKey rowColKey) {
            int i2 = this._rowIndex - rowColKey._rowIndex;
            if (i2 != 0) {
                return i2;
            }
            return this._columnIndex - rowColKey._columnIndex;
        }
    }

    public ForkedEvaluationSheet(EvaluationSheet evaluationSheet) {
        this._masterSheet = evaluationSheet;
    }

    @Override // org.apache.poi.ss.formula.EvaluationSheet
    public void clearAllCachedResultValues() {
        this._masterSheet.clearAllCachedResultValues();
    }

    public void copyUpdatedCells(Sheet sheet) {
        int size = this._sharedCellsByRowCol.size();
        RowColKey[] rowColKeyArr = new RowColKey[size];
        this._sharedCellsByRowCol.keySet().toArray(rowColKeyArr);
        Arrays.sort(rowColKeyArr);
        for (int i2 = 0; i2 < size; i2++) {
            RowColKey rowColKey = rowColKeyArr[i2];
            Row row = sheet.getRow(rowColKey.getRowIndex());
            if (row == null) {
                row = sheet.createRow(rowColKey.getRowIndex());
            }
            Cell cell = row.getCell(rowColKey.getColumnIndex());
            if (cell == null) {
                cell = row.createCell(rowColKey.getColumnIndex());
            }
            this._sharedCellsByRowCol.get(rowColKey).copyValue(cell);
        }
    }

    @Override // org.apache.poi.ss.formula.EvaluationSheet
    public EvaluationCell getCell(int i2, int i3) {
        ForkedEvaluationCell forkedEvaluationCell = this._sharedCellsByRowCol.get(new RowColKey(i2, i3));
        return forkedEvaluationCell == null ? this._masterSheet.getCell(i2, i3) : forkedEvaluationCell;
    }

    public ForkedEvaluationCell getOrCreateUpdatableCell(int i2, int i3) {
        RowColKey rowColKey = new RowColKey(i2, i3);
        ForkedEvaluationCell forkedEvaluationCell = this._sharedCellsByRowCol.get(rowColKey);
        if (forkedEvaluationCell != null) {
            return forkedEvaluationCell;
        }
        EvaluationCell cell = this._masterSheet.getCell(i2, i3);
        if (cell != null) {
            ForkedEvaluationCell forkedEvaluationCell2 = new ForkedEvaluationCell(this, cell);
            this._sharedCellsByRowCol.put(rowColKey, forkedEvaluationCell2);
            return forkedEvaluationCell2;
        }
        CellReference cellReference = new CellReference(i2, i3);
        StringBuilder b2 = a.b("Underlying cell '");
        b2.append(cellReference.formatAsString());
        b2.append("' is missing in master sheet.");
        throw new UnsupportedOperationException(b2.toString());
    }

    public int getSheetIndex(EvaluationWorkbook evaluationWorkbook) {
        return evaluationWorkbook.getSheetIndex(this._masterSheet);
    }
}
