package org.apache.poi.ss.formula.function;

import b.b.a.a.a;
import java.io.BufferedReader;
import java.io.IOException;
import java.io.InputStream;
import java.io.InputStreamReader;
import java.io.UnsupportedEncodingException;
import java.util.Arrays;
import java.util.HashSet;
import java.util.Set;
import java.util.regex.Pattern;

public final class FunctionMetadataReader {
    public static final String[] DIGIT_ENDING_FUNCTION_NAMES = {"LOG10", "ATAN2", "DAYS360", "SUMXMY2", "SUMX2MY2", "SUMX2PY2"};
    public static final Set<String> DIGIT_ENDING_FUNCTION_NAMES_SET = new HashSet(Arrays.asList(DIGIT_ENDING_FUNCTION_NAMES));
    public static final String ELLIPSIS = "...";
    public static final byte[] EMPTY_BYTE_ARRAY = new byte[0];
    public static final String METADATA_FILE_NAME = "functionMetadata.txt";
    public static final Pattern SPACE_DELIM_PATTERN = Pattern.compile(" ");
    public static final Pattern TAB_DELIM_PATTERN = Pattern.compile("\t");

    public static FunctionMetadataRegistry createRegistry() {
        try {
            InputStream resourceAsStream = FunctionMetadataReader.class.getResourceAsStream(METADATA_FILE_NAME);
            if (resourceAsStream != null) {
                try {
                    BufferedReader bufferedReader = new BufferedReader(new InputStreamReader(resourceAsStream, "UTF-8"));
                    try {
                        FunctionDataBuilder functionDataBuilder = new FunctionDataBuilder(400);
                        while (true) {
                            String readLine = bufferedReader.readLine();
                            if (readLine == null) {
                                try {
                                    return functionDataBuilder.build();
                                } finally {
                                    resourceAsStream.close();
                                }
                            } else if (readLine.length() >= 1 && readLine.charAt(0) != '#' && readLine.trim().length() >= 1) {
                                processLine(functionDataBuilder, readLine);
                            }
                        }
                    } finally {
                        bufferedReader.close();
                    }
                } catch (UnsupportedEncodingException e2) {
                    throw new RuntimeException(e2);
                }
            } else {
                throw new RuntimeException("resource 'functionMetadata.txt' not found");
            }
        } catch (IOException e3) {
            throw new RuntimeException(e3);
        }
    }

    public static boolean isDash(String str) {
        return str.length() == 1 && str.charAt(0) == '-';
    }

    public static int parseInt(String str) {
        try {
            return Integer.parseInt(str);
        } catch (NumberFormatException unused) {
            throw new RuntimeException(a.b("Value '", str, "' could not be parsed as an integer"));
        }
    }

    public static byte parseOperandTypeCode(String str) {
        if (str.length() == 1) {
            char charAt = str.charAt(0);
            if (charAt == 'A') {
                return 64;
            }
            if (charAt == 'R') {
                return 0;
            }
            if (charAt == 'V') {
                return 32;
            }
            StringBuilder d2 = a.d("Unexpected operand type code '", str, "' (");
            d2.append((int) str.charAt(0));
            d2.append(")");
            throw new IllegalArgumentException(d2.toString());
        }
        throw new RuntimeException(a.b("Bad operand type code format '", str, "' expected single char"));
    }

    public static byte[] parseOperandTypeCodes(String str) {
        if (str.length() < 1) {
            return EMPTY_BYTE_ARRAY;
        }
        if (isDash(str)) {
            return EMPTY_BYTE_ARRAY;
        }
        String[] split = SPACE_DELIM_PATTERN.split(str);
        int length = split.length;
        if (ELLIPSIS.equals(split[length - 1])) {
            length--;
        }
        byte[] bArr = new byte[length];
        for (int i2 = 0; i2 < length; i2++) {
            bArr[i2] = parseOperandTypeCode(split[i2]);
        }
        return bArr;
    }

    public static byte parseReturnTypeCode(String str) {
        if (str.length() == 0) {
            return 0;
        }
        return parseOperandTypeCode(str);
    }

    public static void processLine(FunctionDataBuilder functionDataBuilder, String str) {
        String[] split = TAB_DELIM_PATTERN.split(str, -2);
        if (split.length == 8) {
            int parseInt = parseInt(split[0]);
            String str2 = split[1];
            int parseInt2 = parseInt(split[2]);
            int parseInt3 = parseInt(split[3]);
            byte parseReturnTypeCode = parseReturnTypeCode(split[4]);
            byte[] parseOperandTypeCodes = parseOperandTypeCodes(split[5]);
            boolean z = split[7].length() > 0;
            validateFunctionName(str2);
            functionDataBuilder.add(parseInt, str2, parseInt2, parseInt3, parseReturnTypeCode, parseOperandTypeCodes, z);
            return;
        }
        throw new RuntimeException(a.b("Bad line format '", str, "' - expected 8 data fields"));
    }

    public static void validateFunctionName(String str) {
        int length = str.length() - 1;
        if (Character.isDigit(str.charAt(length))) {
            while (length >= 0 && Character.isDigit(str.charAt(length))) {
                length--;
            }
            if (!DIGIT_ENDING_FUNCTION_NAMES_SET.contains(str)) {
                throw new RuntimeException(a.b("Invalid function name '", str, "' (is footnote number incorrectly appended)"));
            }
        }
    }
}
