package org.apache.poi.ss.formula.functions;

import org.apache.poi.ss.formula.eval.ErrorEval;
import org.apache.poi.ss.formula.eval.EvaluationException;
import org.apache.poi.ss.formula.eval.NumberEval;
import org.apache.poi.ss.formula.eval.OperandResolver;
import org.apache.poi.ss.formula.eval.ValueEval;

public abstract class AggregateFunction extends MultiOperandNumericFunction {
    public static final Function AVEDEV = new AggregateFunction() {
        /* class org.apache.poi.ss.formula.functions.AggregateFunction.AnonymousClass2 */

        @Override // org.apache.poi.ss.formula.functions.MultiOperandNumericFunction
        public double evaluate(double[] dArr) {
            return StatsLib.avedev(dArr);
        }
    };
    public static final Function AVERAGE = new AggregateFunction() {
        /* class org.apache.poi.ss.formula.functions.AggregateFunction.AnonymousClass3 */

        @Override // org.apache.poi.ss.formula.functions.MultiOperandNumericFunction
        public double evaluate(double[] dArr) {
            if (dArr.length >= 1) {
                return MathX.average(dArr);
            }
            throw new EvaluationException(ErrorEval.DIV_ZERO);
        }
    };
    public static final Function DEVSQ = new AggregateFunction() {
        /* class org.apache.poi.ss.formula.functions.AggregateFunction.AnonymousClass4 */

        @Override // org.apache.poi.ss.formula.functions.MultiOperandNumericFunction
        public double evaluate(double[] dArr) {
            return StatsLib.devsq(dArr);
        }
    };
    public static final Function LARGE = new LargeSmall(true);
    public static final Function MAX = new AggregateFunction() {
        /* class org.apache.poi.ss.formula.functions.AggregateFunction.AnonymousClass5 */

        @Override // org.apache.poi.ss.formula.functions.MultiOperandNumericFunction
        public double evaluate(double[] dArr) {
            return dArr.length > 0 ? MathX.max(dArr) : NumericFunction.LOG_10_TO_BASE_e;
        }
    };
    public static final Function MEDIAN = new AggregateFunction() {
        /* class org.apache.poi.ss.formula.functions.AggregateFunction.AnonymousClass6 */

        @Override // org.apache.poi.ss.formula.functions.MultiOperandNumericFunction
        public double evaluate(double[] dArr) {
            return StatsLib.median(dArr);
        }
    };
    public static final Function MIN = new AggregateFunction() {
        /* class org.apache.poi.ss.formula.functions.AggregateFunction.AnonymousClass7 */

        @Override // org.apache.poi.ss.formula.functions.MultiOperandNumericFunction
        public double evaluate(double[] dArr) {
            return dArr.length > 0 ? MathX.min(dArr) : NumericFunction.LOG_10_TO_BASE_e;
        }
    };
    public static final Function PERCENTILE = new Percentile();
    public static final Function PRODUCT = new AggregateFunction() {
        /* class org.apache.poi.ss.formula.functions.AggregateFunction.AnonymousClass8 */

        @Override // org.apache.poi.ss.formula.functions.MultiOperandNumericFunction
        public double evaluate(double[] dArr) {
            return MathX.product(dArr);
        }
    };
    public static final Function SMALL = new LargeSmall(false);
    public static final Function STDEV = new AggregateFunction() {
        /* class org.apache.poi.ss.formula.functions.AggregateFunction.AnonymousClass9 */

        @Override // org.apache.poi.ss.formula.functions.MultiOperandNumericFunction
        public double evaluate(double[] dArr) {
            if (dArr.length >= 1) {
                return StatsLib.stdev(dArr);
            }
            throw new EvaluationException(ErrorEval.DIV_ZERO);
        }
    };
    public static final Function SUM = new AggregateFunction() {
        /* class org.apache.poi.ss.formula.functions.AggregateFunction.AnonymousClass10 */

        @Override // org.apache.poi.ss.formula.functions.MultiOperandNumericFunction
        public double evaluate(double[] dArr) {
            return MathX.sum(dArr);
        }
    };
    public static final Function SUMSQ = new AggregateFunction() {
        /* class org.apache.poi.ss.formula.functions.AggregateFunction.AnonymousClass11 */

        @Override // org.apache.poi.ss.formula.functions.MultiOperandNumericFunction
        public double evaluate(double[] dArr) {
            return MathX.sumsq(dArr);
        }
    };
    public static final Function VAR = new AggregateFunction() {
        /* class org.apache.poi.ss.formula.functions.AggregateFunction.AnonymousClass12 */

        @Override // org.apache.poi.ss.formula.functions.MultiOperandNumericFunction
        public double evaluate(double[] dArr) {
            if (dArr.length >= 1) {
                return StatsLib.var(dArr);
            }
            throw new EvaluationException(ErrorEval.DIV_ZERO);
        }
    };
    public static final Function VARP = new AggregateFunction() {
        /* class org.apache.poi.ss.formula.functions.AggregateFunction.AnonymousClass13 */

        @Override // org.apache.poi.ss.formula.functions.MultiOperandNumericFunction
        public double evaluate(double[] dArr) {
            if (dArr.length >= 1) {
                return StatsLib.varp(dArr);
            }
            throw new EvaluationException(ErrorEval.DIV_ZERO);
        }
    };

    public static final class LargeSmall extends Fixed2ArgFunction {
        public final boolean _isLarge;

        public LargeSmall(boolean z) {
            this._isLarge = z;
        }

        @Override // org.apache.poi.ss.formula.functions.Function2Arg
        public ValueEval evaluate(int i2, int i3, ValueEval valueEval, ValueEval valueEval2) {
            try {
                double coerceValueToDouble = OperandResolver.coerceValueToDouble(OperandResolver.getSingleValue(valueEval2, i2, i3));
                if (coerceValueToDouble < 1.0d) {
                    return ErrorEval.NUM_ERROR;
                }
                int ceil = (int) Math.ceil(coerceValueToDouble);
                try {
                    double[] collectValues = ValueCollector.collectValues(valueEval);
                    if (ceil > collectValues.length) {
                        return ErrorEval.NUM_ERROR;
                    }
                    double kthLargest = this._isLarge ? StatsLib.kthLargest(collectValues, ceil) : StatsLib.kthSmallest(collectValues, ceil);
                    NumericFunction.checkValue(kthLargest);
                    return new NumberEval(kthLargest);
                } catch (EvaluationException e2) {
                    return e2.getErrorEval();
                }
            } catch (EvaluationException unused) {
                return ErrorEval.VALUE_INVALID;
            }
        }
    }

    public static final class Percentile extends Fixed2ArgFunction {
        @Override // org.apache.poi.ss.formula.functions.Function2Arg
        public ValueEval evaluate(int i2, int i3, ValueEval valueEval, ValueEval valueEval2) {
            double d2;
            try {
                double coerceValueToDouble = OperandResolver.coerceValueToDouble(OperandResolver.getSingleValue(valueEval2, i2, i3));
                if (coerceValueToDouble < NumericFunction.LOG_10_TO_BASE_e || coerceValueToDouble > 1.0d) {
                    return ErrorEval.NUM_ERROR;
                }
                try {
                    double[] collectValues = ValueCollector.collectValues(valueEval);
                    int length = collectValues.length;
                    if (length != 0) {
                        if (length <= 8191) {
                            double d3 = (((double) (length - 1)) * coerceValueToDouble) + 1.0d;
                            if (d3 == 1.0d) {
                                d2 = StatsLib.kthSmallest(collectValues, 1);
                            } else if (Double.compare(d3, (double) length) == 0) {
                                d2 = StatsLib.kthLargest(collectValues, 1);
                            } else {
                                int i4 = (int) d3;
                                double kthSmallest = StatsLib.kthSmallest(collectValues, i4);
                                d2 = ((StatsLib.kthSmallest(collectValues, i4 + 1) - StatsLib.kthSmallest(collectValues, i4)) * (d3 - ((double) i4))) + kthSmallest;
                            }
                            NumericFunction.checkValue(d2);
                            return new NumberEval(d2);
                        }
                    }
                    return ErrorEval.NUM_ERROR;
                } catch (EvaluationException e2) {
                    return e2.getErrorEval();
                }
            } catch (EvaluationException unused) {
                return ErrorEval.VALUE_INVALID;
            }
        }
    }

    public static final class ValueCollector extends MultiOperandNumericFunction {
        public static final ValueCollector instance = new ValueCollector();

        public ValueCollector() {
            super(false, false);
        }

        public static double[] collectValues(ValueEval... valueEvalArr) {
            return instance.getNumberArray(valueEvalArr);
        }

        @Override // org.apache.poi.ss.formula.functions.MultiOperandNumericFunction
        public double evaluate(double[] dArr) {
            throw new IllegalStateException("should not be called");
        }
    }

    public AggregateFunction() {
        super(false, false);
    }

    public static Function subtotalInstance(Function function) {
        return new AggregateFunction((AggregateFunction) function) {
            /* class org.apache.poi.ss.formula.functions.AggregateFunction.AnonymousClass1 */
            public final /* synthetic */ AggregateFunction val$arg;

            {
                this.val$arg = r1;
            }

            @Override // org.apache.poi.ss.formula.functions.MultiOperandNumericFunction
            public double evaluate(double[] dArr) {
                return this.val$arg.evaluate(dArr);
            }

            @Override // org.apache.poi.ss.formula.functions.MultiOperandNumericFunction
            public boolean isSubtotalCounted() {
                return false;
            }
        };
    }
}
