package org.apache.poi.ss.formula.functions;

import org.apache.poi.ss.formula.OperationEvaluationContext;
import org.apache.poi.ss.formula.eval.ErrorEval;
import org.apache.poi.ss.formula.eval.NumberEval;
import org.apache.poi.ss.formula.eval.OperandResolver;
import org.apache.poi.ss.formula.eval.RefEval;
import org.apache.poi.ss.formula.eval.ValueEval;
import org.apache.poi.ss.formula.ptg.UnaryMinusPtg;
import org.apache.poi.ss.util.SheetUtil;

public class Bin2Dec extends Fixed1ArgFunction implements FreeRefFunction {
    public static final FreeRefFunction instance = new Bin2Dec();

    private int getDecimalValue(String str) {
        int length = str.length();
        int i2 = length - 1;
        int i3 = 0;
        int i4 = 0;
        while (i3 < length) {
            int i5 = i3 + 1;
            i4 += (int) (Math.pow(2.0d, (double) i2) * ((double) Integer.parseInt(str.substring(i3, i5))));
            i2--;
            i3 = i5;
        }
        return i4;
    }

    public static String toggleBits(String str) {
        String binaryString = Long.toBinaryString(Long.parseLong(str, 2) ^ ((1 << str.length()) - 1));
        while (binaryString.length() < str.length()) {
            binaryString = SheetUtil.defaultChar + binaryString;
        }
        return binaryString;
    }

    @Override // org.apache.poi.ss.formula.functions.Function1Arg
    public ValueEval evaluate(int i2, int i3, ValueEval valueEval) {
        String str;
        String str2;
        boolean z;
        String str3;
        if (valueEval instanceof RefEval) {
            RefEval refEval = (RefEval) valueEval;
            str = OperandResolver.coerceValueToString(refEval.getInnerValueEval(refEval.getFirstSheetIndex()));
        } else {
            str = OperandResolver.coerceValueToString(valueEval);
        }
        if (str.length() > 10) {
            return ErrorEval.NUM_ERROR;
        }
        if (str.length() < 10) {
            str2 = str;
            z = true;
        } else {
            str2 = str.substring(1);
            z = str.startsWith("0");
        }
        if (z) {
            try {
                str3 = String.valueOf(getDecimalValue(str2));
            } catch (NumberFormatException unused) {
                return ErrorEval.NUM_ERROR;
            }
        } else {
            str3 = UnaryMinusPtg.MINUS + (getDecimalValue(toggleBits(str2)) + 1);
        }
        return new NumberEval((double) Long.parseLong(str3));
    }

    @Override // org.apache.poi.ss.formula.functions.FreeRefFunction
    public ValueEval evaluate(ValueEval[] valueEvalArr, OperationEvaluationContext operationEvaluationContext) {
        if (valueEvalArr.length != 1) {
            return ErrorEval.VALUE_INVALID;
        }
        return evaluate(operationEvaluationContext.getRowIndex(), operationEvaluationContext.getColumnIndex(), valueEvalArr[0]);
    }
}
