package org.apache.poi.ss.formula.functions;

import org.apache.poi.ss.formula.eval.ErrorEval;
import org.apache.poi.ss.formula.eval.EvaluationException;
import org.apache.poi.ss.formula.eval.NumberEval;
import org.apache.poi.ss.formula.eval.OperandResolver;
import org.apache.poi.ss.formula.eval.ValueEval;
import org.apache.poi.ss.usermodel.DateUtil;

public final class CalendarFieldFunction extends Fixed1ArgFunction {
    public static final Function DAY = new CalendarFieldFunction(5);
    public static final Function HOUR = new CalendarFieldFunction(11);
    public static final Function MINUTE = new CalendarFieldFunction(12);
    public static final Function MONTH = new CalendarFieldFunction(2);
    public static final Function SECOND = new CalendarFieldFunction(13);
    public static final Function YEAR = new CalendarFieldFunction(1);
    public final int _dateFieldId;

    public CalendarFieldFunction(int i2) {
        this._dateFieldId = i2;
    }

    private int getCalField(double d2) {
        if (((int) d2) == 0) {
            int i2 = this._dateFieldId;
            if (i2 == 1) {
                return 1900;
            }
            if (i2 == 2) {
                return 1;
            }
            if (i2 == 5) {
                return 0;
            }
        }
        int i3 = DateUtil.getJavaCalendarUTC(d2 + 5.78125E-6d, false).get(this._dateFieldId);
        return this._dateFieldId == 2 ? i3 + 1 : i3;
    }

    @Override // org.apache.poi.ss.formula.functions.Function1Arg
    public final ValueEval evaluate(int i2, int i3, ValueEval valueEval) {
        try {
            double coerceValueToDouble = OperandResolver.coerceValueToDouble(OperandResolver.getSingleValue(valueEval, i2, i3));
            if (coerceValueToDouble < NumericFunction.LOG_10_TO_BASE_e) {
                return ErrorEval.NUM_ERROR;
            }
            return new NumberEval((double) getCalField(coerceValueToDouble));
        } catch (EvaluationException e2) {
            return e2.getErrorEval();
        }
    }
}
