package org.apache.poi.ss.formula.functions;

import org.apache.poi.ss.formula.ThreeDEval;
import org.apache.poi.ss.formula.TwoDEval;
import org.apache.poi.ss.formula.eval.RefEval;
import org.apache.poi.ss.formula.eval.ValueEval;

public final class CountUtils {

    public interface I_MatchAreaPredicate extends I_MatchPredicate {
        boolean matches(TwoDEval twoDEval, int i2, int i3);
    }

    public interface I_MatchPredicate {
        boolean matches(ValueEval valueEval);
    }

    public static int countArg(ValueEval valueEval, I_MatchPredicate i_MatchPredicate) {
        if (valueEval == null) {
            throw new IllegalArgumentException("eval must not be null");
        } else if (valueEval instanceof ThreeDEval) {
            return countMatchingCellsInArea((ThreeDEval) valueEval, i_MatchPredicate);
        } else {
            if (valueEval instanceof TwoDEval) {
                throw new IllegalArgumentException("Count requires 3D Evals, 2D ones aren't supported");
            } else if (valueEval instanceof RefEval) {
                return countMatchingCellsInRef((RefEval) valueEval, i_MatchPredicate);
            } else {
                return i_MatchPredicate.matches(valueEval) ? 1 : 0;
            }
        }
    }

    public static int countMatchingCellsInArea(ThreeDEval threeDEval, I_MatchPredicate i_MatchPredicate) {
        int lastSheetIndex = threeDEval.getLastSheetIndex();
        int i2 = 0;
        for (int firstSheetIndex = threeDEval.getFirstSheetIndex(); firstSheetIndex <= lastSheetIndex; firstSheetIndex++) {
            int height = threeDEval.getHeight();
            int width = threeDEval.getWidth();
            for (int i3 = 0; i3 < height; i3++) {
                for (int i4 = 0; i4 < width; i4++) {
                    ValueEval value = threeDEval.getValue(firstSheetIndex, i3, i4);
                    if ((!(i_MatchPredicate instanceof I_MatchAreaPredicate) || ((I_MatchAreaPredicate) i_MatchPredicate).matches(threeDEval, i3, i4)) && i_MatchPredicate.matches(value)) {
                        i2++;
                    }
                }
            }
        }
        return i2;
    }

    public static int countMatchingCellsInRef(RefEval refEval, I_MatchPredicate i_MatchPredicate) {
        int lastSheetIndex = refEval.getLastSheetIndex();
        int i2 = 0;
        for (int firstSheetIndex = refEval.getFirstSheetIndex(); firstSheetIndex <= lastSheetIndex; firstSheetIndex++) {
            if (i_MatchPredicate.matches(refEval.getInnerValueEval(firstSheetIndex))) {
                i2++;
            }
        }
        return i2;
    }
}
