package org.apache.poi.ss.formula.functions;

import b.b.a.a.a;
import java.util.regex.Pattern;
import org.apache.poi.ss.formula.ThreeDEval;
import org.apache.poi.ss.formula.eval.BlankEval;
import org.apache.poi.ss.formula.eval.BoolEval;
import org.apache.poi.ss.formula.eval.ErrorEval;
import org.apache.poi.ss.formula.eval.EvaluationException;
import org.apache.poi.ss.formula.eval.NumberEval;
import org.apache.poi.ss.formula.eval.OperandResolver;
import org.apache.poi.ss.formula.eval.RefEval;
import org.apache.poi.ss.formula.eval.StringEval;
import org.apache.poi.ss.formula.eval.ValueEval;
import org.apache.poi.ss.formula.functions.CountUtils;
import org.apache.poi.ss.formula.ptg.GreaterThanPtg;
import org.apache.poi.ss.formula.ptg.LessThanPtg;
import org.apache.poi.ss.usermodel.FormulaError;
import org.apache.poi.xssf.usermodel.XSSFCell;
import org.apache.xmlbeans.impl.common.NameUtil;

public final class Countif extends Fixed2ArgFunction {

    public static final class BooleanMatcher extends MatcherBase {
        public final int _value;

        public BooleanMatcher(boolean z, CmpOp cmpOp) {
            super(cmpOp);
            this._value = boolToInt(z);
        }

        public static int boolToInt(boolean z) {
            return z ? 1 : 0;
        }

        @Override // org.apache.poi.ss.formula.functions.Countif.MatcherBase
        public String getValueText() {
            return this._value == 1 ? XSSFCell.TRUE : XSSFCell.FALSE;
        }

        @Override // org.apache.poi.ss.formula.functions.CountUtils.I_MatchPredicate
        public boolean matches(ValueEval valueEval) {
            if (valueEval instanceof StringEval) {
                return false;
            }
            if (valueEval instanceof BoolEval) {
                return evaluate(boolToInt(((BoolEval) valueEval).getBooleanValue()) - this._value);
            }
            if (valueEval instanceof BlankEval) {
                if (getCode() != 2) {
                    return false;
                }
                return true;
            } else if (!(valueEval instanceof NumberEval) || getCode() != 2) {
                return false;
            } else {
                return true;
            }
        }
    }

    public static final class ErrorMatcher extends MatcherBase {
        public final int _value;

        public ErrorMatcher(int i2, CmpOp cmpOp) {
            super(cmpOp);
            this._value = i2;
        }

        public int getValue() {
            return this._value;
        }

        @Override // org.apache.poi.ss.formula.functions.Countif.MatcherBase
        public String getValueText() {
            return FormulaError.forInt(this._value).getString();
        }

        @Override // org.apache.poi.ss.formula.functions.CountUtils.I_MatchPredicate
        public boolean matches(ValueEval valueEval) {
            if (valueEval instanceof ErrorEval) {
                return evaluate(((ErrorEval) valueEval).getErrorCode() - this._value);
            }
            return false;
        }
    }

    public static abstract class MatcherBase implements CountUtils.I_MatchPredicate {
        public final CmpOp _operator;

        public MatcherBase(CmpOp cmpOp) {
            this._operator = cmpOp;
        }

        public final boolean evaluate(int i2) {
            return this._operator.evaluate(i2);
        }

        public final int getCode() {
            return this._operator.getCode();
        }

        public abstract String getValueText();

        public final String toString() {
            StringBuffer stringBuffer = new StringBuffer(64);
            stringBuffer.append(getClass().getName());
            stringBuffer.append(" [");
            stringBuffer.append(this._operator.getRepresentation());
            stringBuffer.append(getValueText());
            stringBuffer.append("]");
            return stringBuffer.toString();
        }

        public final boolean evaluate(boolean z) {
            return this._operator.evaluate(z);
        }
    }

    public static final class NumberMatcher extends MatcherBase {
        public final double _value;

        public NumberMatcher(double d2, CmpOp cmpOp) {
            super(cmpOp);
            this._value = d2;
        }

        @Override // org.apache.poi.ss.formula.functions.Countif.MatcherBase
        public String getValueText() {
            return String.valueOf(this._value);
        }

        @Override // org.apache.poi.ss.formula.functions.CountUtils.I_MatchPredicate
        public boolean matches(ValueEval valueEval) {
            if (valueEval instanceof StringEval) {
                int code = getCode();
                if (code != 0 && code != 1) {
                    return code == 2;
                }
                Double parseDouble = OperandResolver.parseDouble(((StringEval) valueEval).getStringValue());
                if (parseDouble != null && this._value == parseDouble.doubleValue()) {
                    return true;
                }
                return false;
            } else if (valueEval instanceof NumberEval) {
                return evaluate(Double.compare(((NumberEval) valueEval).getNumberValue(), this._value));
            } else {
                return (valueEval instanceof BlankEval) && getCode() == 2;
            }
        }
    }

    public static final class StringMatcher extends MatcherBase {
        public final Pattern _pattern;
        public final String _value;

        public StringMatcher(String str, CmpOp cmpOp) {
            super(cmpOp);
            this._value = str;
            int code = cmpOp.getCode();
            if (code == 0 || code == 1 || code == 2) {
                this._pattern = getWildCardPattern(str);
            } else {
                this._pattern = null;
            }
        }

        public static Pattern getWildCardPattern(String str) {
            char charAt;
            int length = str.length();
            StringBuffer stringBuffer = new StringBuffer(length);
            int i2 = 0;
            boolean z = false;
            while (i2 < length) {
                char charAt2 = str.charAt(i2);
                if (!(charAt2 == '$' || charAt2 == '.')) {
                    if (charAt2 == '?') {
                        stringBuffer.append(NameUtil.PERIOD);
                    } else if (charAt2 != '[') {
                        if (charAt2 == '~') {
                            int i3 = i2 + 1;
                            if (i3 >= length || !((charAt = str.charAt(i3)) == '*' || charAt == '?')) {
                                stringBuffer.append('~');
                                i2++;
                            } else {
                                stringBuffer.append('[');
                                stringBuffer.append(charAt);
                                stringBuffer.append(']');
                                i2 = i3;
                            }
                        } else if (!(charAt2 == ']' || charAt2 == '^')) {
                            switch (charAt2) {
                                case '(':
                                case ')':
                                    break;
                                case '*':
                                    stringBuffer.append(".*");
                                    break;
                                default:
                                    stringBuffer.append(charAt2);
                                    break;
                            }
                            i2++;
                        }
                    }
                    z = true;
                    i2++;
                }
                stringBuffer.append("\\");
                stringBuffer.append(charAt2);
                i2++;
            }
            if (z) {
                return Pattern.compile(stringBuffer.toString(), 2);
            }
            return null;
        }

        @Override // org.apache.poi.ss.formula.functions.Countif.MatcherBase
        public String getValueText() {
            Pattern pattern = this._pattern;
            if (pattern == null) {
                return this._value;
            }
            return pattern.pattern();
        }

        @Override // org.apache.poi.ss.formula.functions.CountUtils.I_MatchPredicate
        public boolean matches(ValueEval valueEval) {
            if (valueEval instanceof BlankEval) {
                int code = getCode();
                if (code == 0 || code == 1) {
                    if (this._value.length() == 0) {
                        return true;
                    }
                    return false;
                } else if (code == 2 && this._value.length() != 0) {
                    return true;
                } else {
                    return false;
                }
            } else if (!(valueEval instanceof StringEval)) {
                return false;
            } else {
                String stringValue = ((StringEval) valueEval).getStringValue();
                if (stringValue.length() >= 1 || this._value.length() >= 1) {
                    Pattern pattern = this._pattern;
                    if (pattern != null) {
                        return evaluate(pattern.matcher(stringValue).matches());
                    }
                    return evaluate(stringValue.compareToIgnoreCase(this._value));
                }
                int code2 = getCode();
                return code2 == 0 || code2 == 2;
            }
        }
    }

    private double countMatchingCellsInArea(ValueEval valueEval, CountUtils.I_MatchPredicate i_MatchPredicate) {
        int i2;
        if (valueEval instanceof RefEval) {
            i2 = CountUtils.countMatchingCellsInRef((RefEval) valueEval, i_MatchPredicate);
        } else if (valueEval instanceof ThreeDEval) {
            i2 = CountUtils.countMatchingCellsInArea((ThreeDEval) valueEval, i_MatchPredicate);
        } else {
            StringBuilder b2 = a.b("Bad range arg type (");
            b2.append(valueEval.getClass().getName());
            b2.append(")");
            throw new IllegalArgumentException(b2.toString());
        }
        return (double) i2;
    }

    public static CountUtils.I_MatchPredicate createCriteriaPredicate(ValueEval valueEval, int i2, int i3) {
        ValueEval evaluateCriteriaArg = evaluateCriteriaArg(valueEval, i2, i3);
        if (evaluateCriteriaArg instanceof NumberEval) {
            return new NumberMatcher(((NumberEval) evaluateCriteriaArg).getNumberValue(), CmpOp.OP_NONE);
        }
        if (evaluateCriteriaArg instanceof BoolEval) {
            return new BooleanMatcher(((BoolEval) evaluateCriteriaArg).getBooleanValue(), CmpOp.OP_NONE);
        }
        if (evaluateCriteriaArg instanceof StringEval) {
            return createGeneralMatchPredicate((StringEval) evaluateCriteriaArg);
        }
        if (evaluateCriteriaArg instanceof ErrorEval) {
            return new ErrorMatcher(((ErrorEval) evaluateCriteriaArg).getErrorCode(), CmpOp.OP_NONE);
        }
        if (evaluateCriteriaArg == BlankEval.instance) {
            return null;
        }
        StringBuilder b2 = a.b("Unexpected type for criteria (");
        b2.append(evaluateCriteriaArg.getClass().getName());
        b2.append(")");
        throw new RuntimeException(b2.toString());
    }

    public static CountUtils.I_MatchPredicate createGeneralMatchPredicate(StringEval stringEval) {
        String stringValue = stringEval.getStringValue();
        CmpOp operator = CmpOp.getOperator(stringValue);
        String substring = stringValue.substring(operator.getLength());
        Boolean parseBoolean = parseBoolean(substring);
        if (parseBoolean != null) {
            return new BooleanMatcher(parseBoolean.booleanValue(), operator);
        }
        Double parseDouble = OperandResolver.parseDouble(substring);
        if (parseDouble != null) {
            return new NumberMatcher(parseDouble.doubleValue(), operator);
        }
        ErrorEval parseError = parseError(substring);
        if (parseError != null) {
            return new ErrorMatcher(parseError.getErrorCode(), operator);
        }
        return new StringMatcher(substring, operator);
    }

    public static ValueEval evaluateCriteriaArg(ValueEval valueEval, int i2, int i3) {
        try {
            return OperandResolver.getSingleValue(valueEval, i2, i3);
        } catch (EvaluationException e2) {
            return e2.getErrorEval();
        }
    }

    /* JADX WARNING: Code restructure failed: missing block: B:10:0x001c, code lost:
        if (r0 != 't') goto L_0x0035;
     */
    public static Boolean parseBoolean(String str) {
        if (str.length() < 1) {
            return null;
        }
        char charAt = str.charAt(0);
        if (charAt != 'F') {
            if (charAt != 'T') {
                if (charAt != 'f') {
                }
            }
            if (XSSFCell.TRUE.equalsIgnoreCase(str)) {
                return Boolean.TRUE;
            }
            return null;
        }
        if (XSSFCell.FALSE.equalsIgnoreCase(str)) {
            return Boolean.FALSE;
        }
        return null;
    }

    public static ErrorEval parseError(String str) {
        if (str.length() >= 4 && str.charAt(0) == '#') {
            if (str.equals("#NULL!")) {
                return ErrorEval.NULL_INTERSECTION;
            }
            if (str.equals("#DIV/0!")) {
                return ErrorEval.DIV_ZERO;
            }
            if (str.equals("#VALUE!")) {
                return ErrorEval.VALUE_INVALID;
            }
            if (str.equals("#REF!")) {
                return ErrorEval.REF_INVALID;
            }
            if (str.equals("#NAME?")) {
                return ErrorEval.NAME_INVALID;
            }
            if (str.equals("#NUM!")) {
                return ErrorEval.NUM_ERROR;
            }
            if (str.equals("#N/A")) {
                return ErrorEval.NA;
            }
        }
        return null;
    }

    @Override // org.apache.poi.ss.formula.functions.Function2Arg
    public ValueEval evaluate(int i2, int i3, ValueEval valueEval, ValueEval valueEval2) {
        CountUtils.I_MatchPredicate createCriteriaPredicate = createCriteriaPredicate(valueEval2, i2, i3);
        if (createCriteriaPredicate == null) {
            return NumberEval.ZERO;
        }
        return new NumberEval(countMatchingCellsInArea(valueEval, createCriteriaPredicate));
    }

    public static final class CmpOp {
        public static final int EQ = 1;
        public static final int GE = 6;
        public static final int GT = 5;
        public static final int LE = 3;
        public static final int LT = 4;
        public static final int NE = 2;
        public static final int NONE = 0;
        public static final CmpOp OP_EQ = op("=", 1);
        public static final CmpOp OP_GE = op(">=", 6);
        public static final CmpOp OP_GT = op(GreaterThanPtg.GREATERTHAN, 5);
        public static final CmpOp OP_LE = op("<=", 3);
        public static final CmpOp OP_LT = op(LessThanPtg.LESSTHAN, 4);
        public static final CmpOp OP_NE = op("<>", 2);
        public static final CmpOp OP_NONE = op("", 0);
        public final int _code;
        public final String _representation;

        public CmpOp(String str, int i2) {
            this._representation = str;
            this._code = i2;
        }

        public static CmpOp getOperator(String str) {
            int length = str.length();
            if (length < 1) {
                return OP_NONE;
            }
            switch (str.charAt(0)) {
                case '<':
                    if (length > 1) {
                        char charAt = str.charAt(1);
                        if (charAt == '=') {
                            return OP_LE;
                        }
                        if (charAt == '>') {
                            return OP_NE;
                        }
                    }
                    return OP_LT;
                case '=':
                    return OP_EQ;
                case '>':
                    if (length <= 1 || str.charAt(1) != '=') {
                        return OP_GT;
                    }
                    return OP_GE;
                default:
                    return OP_NONE;
            }
        }

        public static CmpOp op(String str, int i2) {
            return new CmpOp(str, i2);
        }

        public boolean evaluate(boolean z) {
            int i2 = this._code;
            if (i2 == 0 || i2 == 1) {
                return z;
            }
            if (i2 == 2) {
                return !z;
            }
            throw new RuntimeException(a.a(a.b("Cannot call boolean evaluate on non-equality operator '"), this._representation, "'"));
        }

        public int getCode() {
            return this._code;
        }

        public int getLength() {
            return this._representation.length();
        }

        public String getRepresentation() {
            return this._representation;
        }

        public String toString() {
            StringBuffer stringBuffer = new StringBuffer(64);
            a.a(CmpOp.class, stringBuffer, " [");
            return a.a(stringBuffer, this._representation, "]");
        }

        public boolean evaluate(int i2) {
            switch (this._code) {
                case 0:
                case 1:
                    if (i2 == 0) {
                        return true;
                    }
                    return false;
                case 2:
                    if (i2 != 0) {
                        return true;
                    }
                    return false;
                case 3:
                    if (i2 <= 0) {
                        return true;
                    }
                    return false;
                case 4:
                    if (i2 < 0) {
                        return true;
                    }
                    return false;
                case 5:
                    if (i2 > 0) {
                        return true;
                    }
                    return false;
                case 6:
                    if (i2 >= 0) {
                        return true;
                    }
                    return false;
                default:
                    throw new RuntimeException(a.a(a.b("Cannot call boolean evaluate on non-equality operator '"), this._representation, "'"));
            }
        }
    }
}
