package org.apache.poi.ss.formula.functions;

import java.util.Calendar;
import org.apache.poi.ss.formula.eval.ErrorEval;
import org.apache.poi.ss.formula.eval.EvaluationException;
import org.apache.poi.ss.formula.eval.NumberEval;
import org.apache.poi.ss.formula.eval.ValueEval;
import org.apache.poi.ss.usermodel.DateUtil;
import org.apache.poi.util.LocaleUtil;

public final class DateFunc extends Fixed3ArgFunction {
    public static final Function instance = new DateFunc();

    public static int getYear(double d2) {
        int i2 = (int) d2;
        if (i2 < 0) {
            return -1;
        }
        return i2 < 1900 ? i2 + 1900 : i2;
    }

    @Override // org.apache.poi.ss.formula.functions.Function3Arg
    public ValueEval evaluate(int i2, int i3, ValueEval valueEval, ValueEval valueEval2, ValueEval valueEval3) {
        try {
            double evaluate = evaluate(getYear(NumericFunction.singleOperandEvaluate(valueEval, i2, i3)), (int) (NumericFunction.singleOperandEvaluate(valueEval2, i2, i3) - 1.0d), (int) NumericFunction.singleOperandEvaluate(valueEval3, i2, i3));
            NumericFunction.checkValue(evaluate);
            return new NumberEval(evaluate);
        } catch (EvaluationException e2) {
            return e2.getErrorEval();
        }
    }

    public static double evaluate(int i2, int i3, int i4) {
        if (i2 >= 0) {
            while (i3 < 0) {
                i2--;
                i3 += 12;
            }
            if (i2 == 1900 && i3 == 1 && i4 == 29) {
                return 60.0d;
            }
            Calendar localeCalendar = LocaleUtil.getLocaleCalendar(i2, i3, (i2 != 1900 || ((i3 != 0 || i4 < 60) && (i3 != 1 || i4 < 30))) ? i4 : i4 - 1);
            if (i4 < 0 && localeCalendar.get(1) == 1900 && i3 > 1 && localeCalendar.get(2) < 2) {
                localeCalendar.add(5, 1);
            }
            return DateUtil.getExcelDate(localeCalendar.getTime(), false);
        }
        throw new EvaluationException(ErrorEval.VALUE_INVALID);
    }
}
