package org.apache.poi.ss.formula.functions;

import java.util.Calendar;
import org.apache.poi.ss.formula.eval.EvaluationException;
import org.apache.poi.ss.formula.eval.NumberEval;
import org.apache.poi.ss.formula.eval.OperandResolver;
import org.apache.poi.ss.formula.eval.ValueEval;
import org.apache.poi.ss.usermodel.DateUtil;
import org.apache.poi.util.LocaleUtil;

public class Days360 extends Var2or3ArgFunction {
    public static Calendar getDate(double d2) {
        Calendar localeCalendar = LocaleUtil.getLocaleCalendar();
        localeCalendar.setTime(DateUtil.getJavaDate(d2, false));
        return localeCalendar;
    }

    public static int[] getEndingDate(Calendar calendar, int[] iArr, boolean z) {
        int i2 = calendar.get(1);
        int i3 = calendar.get(2);
        int i4 = 30;
        int min = Math.min(30, calendar.get(5));
        if (z || calendar.get(5) != 31) {
            i4 = min;
        } else if (iArr[2] < 30) {
            calendar.set(5, 1);
            calendar.add(2, 1);
            i2 = calendar.get(1);
            i3 = calendar.get(2);
            i4 = 1;
        }
        return new int[]{i2, i3, i4};
    }

    public static int[] getStartingDate(Calendar calendar, boolean z) {
        int i2 = calendar.get(1);
        int i3 = calendar.get(2);
        int i4 = 30;
        int min = Math.min(30, calendar.get(5));
        if (z || !isLastDayOfMonth(calendar)) {
            i4 = min;
        }
        return new int[]{i2, i3, i4};
    }

    public static boolean isLastDayOfMonth(Calendar calendar) {
        return calendar.get(5) == calendar.getActualMaximum(5);
    }

    @Override // org.apache.poi.ss.formula.functions.Function2Arg
    public ValueEval evaluate(int i2, int i3, ValueEval valueEval, ValueEval valueEval2) {
        try {
            return new NumberEval(evaluate(NumericFunction.singleOperandEvaluate(valueEval, i2, i3), NumericFunction.singleOperandEvaluate(valueEval2, i2, i3), false));
        } catch (EvaluationException e2) {
            return e2.getErrorEval();
        }
    }

    @Override // org.apache.poi.ss.formula.functions.Function3Arg
    public ValueEval evaluate(int i2, int i3, ValueEval valueEval, ValueEval valueEval2, ValueEval valueEval3) {
        try {
            double singleOperandEvaluate = NumericFunction.singleOperandEvaluate(valueEval, i2, i3);
            double singleOperandEvaluate2 = NumericFunction.singleOperandEvaluate(valueEval2, i2, i3);
            ValueEval singleValue = OperandResolver.getSingleValue(valueEval3, i2, i3);
            boolean z = false;
            Boolean coerceValueToBoolean = OperandResolver.coerceValueToBoolean(singleValue, false);
            if (coerceValueToBoolean != null && coerceValueToBoolean.booleanValue()) {
                z = true;
            }
            return new NumberEval(evaluate(singleOperandEvaluate, singleOperandEvaluate2, z));
        } catch (EvaluationException e2) {
            return e2.getErrorEval();
        }
    }

    public static double evaluate(double d2, double d3, boolean z) {
        Calendar date = getDate(d2);
        Calendar date2 = getDate(d3);
        int[] startingDate = getStartingDate(date, z);
        int[] endingDate = getEndingDate(date2, startingDate, z);
        return (double) ((((endingDate[1] * 30) + (endingDate[0] * 360)) + endingDate[2]) - (((startingDate[1] * 30) + (startingDate[0] * 360)) + startingDate[2]));
    }
}
