package org.apache.poi.ss.formula.functions;

import org.apache.poi.ss.formula.OperationEvaluationContext;
import org.apache.poi.ss.formula.eval.ErrorEval;
import org.apache.poi.ss.formula.eval.EvaluationException;
import org.apache.poi.ss.formula.eval.OperandResolver;
import org.apache.poi.ss.formula.eval.StringEval;
import org.apache.poi.ss.formula.eval.ValueEval;

public class Dec2Bin extends Var1or2ArgFunction implements FreeRefFunction {
    public static final int DEFAULT_PLACES_VALUE = 10;
    public static final long MAX_VALUE = 511;
    public static final long MIN_VALUE = -512;
    public static final FreeRefFunction instance = new Dec2Bin();

    @Override // org.apache.poi.ss.formula.functions.Function2Arg
    public ValueEval evaluate(int i2, int i3, ValueEval valueEval, ValueEval valueEval2) {
        int i4;
        try {
            Double parseDouble = OperandResolver.parseDouble(OperandResolver.coerceValueToString(OperandResolver.getSingleValue(valueEval, i2, i3)));
            if (parseDouble == null) {
                return ErrorEval.VALUE_INVALID;
            }
            if (parseDouble.longValue() < -512 || parseDouble.longValue() > 511) {
                return ErrorEval.NUM_ERROR;
            }
            if (parseDouble.doubleValue() < NumericFunction.LOG_10_TO_BASE_e || valueEval2 == null) {
                i4 = 10;
            } else {
                try {
                    Double parseDouble2 = OperandResolver.parseDouble(OperandResolver.coerceValueToString(OperandResolver.getSingleValue(valueEval2, i2, i3)));
                    if (parseDouble2 == null) {
                        return ErrorEval.VALUE_INVALID;
                    }
                    i4 = parseDouble2.intValue();
                    if (i4 < 0 || i4 == 0) {
                        return ErrorEval.NUM_ERROR;
                    }
                } catch (EvaluationException e2) {
                    return e2.getErrorEval();
                }
            }
            String binaryString = Integer.toBinaryString(parseDouble.intValue());
            if (binaryString.length() > 10) {
                binaryString = binaryString.substring(binaryString.length() - 10, binaryString.length());
            }
            if (binaryString.length() > i4) {
                return ErrorEval.NUM_ERROR;
            }
            return new StringEval(binaryString);
        } catch (EvaluationException e3) {
            return e3.getErrorEval();
        }
    }

    @Override // org.apache.poi.ss.formula.functions.Function1Arg
    public ValueEval evaluate(int i2, int i3, ValueEval valueEval) {
        return evaluate(i2, i3, valueEval, null);
    }

    @Override // org.apache.poi.ss.formula.functions.FreeRefFunction
    public ValueEval evaluate(ValueEval[] valueEvalArr, OperationEvaluationContext operationEvaluationContext) {
        if (valueEvalArr.length == 1) {
            return evaluate(operationEvaluationContext.getRowIndex(), operationEvaluationContext.getColumnIndex(), valueEvalArr[0]);
        }
        if (valueEvalArr.length == 2) {
            return evaluate(operationEvaluationContext.getRowIndex(), operationEvaluationContext.getColumnIndex(), valueEvalArr[0], valueEvalArr[1]);
        }
        return ErrorEval.VALUE_INVALID;
    }
}
