package org.apache.poi.ss.formula.functions;

import java.util.Calendar;
import java.util.Date;
import org.apache.poi.ss.formula.OperationEvaluationContext;
import org.apache.poi.ss.formula.eval.BlankEval;
import org.apache.poi.ss.formula.eval.ErrorEval;
import org.apache.poi.ss.formula.eval.EvaluationException;
import org.apache.poi.ss.formula.eval.NumberEval;
import org.apache.poi.ss.formula.eval.RefEval;
import org.apache.poi.ss.formula.eval.ValueEval;
import org.apache.poi.ss.usermodel.DateUtil;
import org.apache.poi.util.LocaleUtil;

public class EDate implements FreeRefFunction {
    public static final FreeRefFunction instance = new EDate();

    private double getValue(ValueEval valueEval) {
        if (valueEval instanceof NumberEval) {
            return ((NumberEval) valueEval).getNumberValue();
        }
        if (valueEval instanceof BlankEval) {
            return NumericFunction.LOG_10_TO_BASE_e;
        }
        if (valueEval instanceof RefEval) {
            RefEval refEval = (RefEval) valueEval;
            if (refEval.getNumberOfSheets() <= 1) {
                ValueEval innerValueEval = refEval.getInnerValueEval(refEval.getFirstSheetIndex());
                if (innerValueEval instanceof NumberEval) {
                    return ((NumberEval) innerValueEval).getNumberValue();
                }
                if (innerValueEval instanceof BlankEval) {
                    return NumericFunction.LOG_10_TO_BASE_e;
                }
            } else {
                throw new EvaluationException(ErrorEval.VALUE_INVALID);
            }
        }
        throw new EvaluationException(ErrorEval.VALUE_INVALID);
    }

    @Override // org.apache.poi.ss.formula.functions.FreeRefFunction
    public ValueEval evaluate(ValueEval[] valueEvalArr, OperationEvaluationContext operationEvaluationContext) {
        if (valueEvalArr.length != 2) {
            return ErrorEval.VALUE_INVALID;
        }
        try {
            Date javaDate = DateUtil.getJavaDate(getValue(valueEvalArr[0]));
            Calendar localeCalendar = LocaleUtil.getLocaleCalendar();
            localeCalendar.setTime(javaDate);
            localeCalendar.add(2, (int) getValue(valueEvalArr[1]));
            return new NumberEval(DateUtil.getExcelDate(localeCalendar.getTime()));
        } catch (EvaluationException e2) {
            return e2.getErrorEval();
        }
    }
}
