package org.apache.poi.ss.formula.functions;

import java.math.BigInteger;
import java.util.HashMap;
import org.apache.poi.ss.formula.OperationEvaluationContext;
import org.apache.poi.ss.formula.eval.ErrorEval;
import org.apache.poi.ss.formula.eval.EvaluationException;
import org.apache.poi.ss.formula.eval.NumberEval;
import org.apache.poi.ss.formula.eval.OperandResolver;
import org.apache.poi.ss.formula.eval.ValueEval;

public class FactDouble extends Fixed1ArgFunction implements FreeRefFunction {
    public static HashMap<Integer, BigInteger> cache = new HashMap<>();
    public static final FreeRefFunction instance = new FactDouble();

    public static BigInteger factorial(int i2) {
        if (i2 == 0 || i2 < 0) {
            return BigInteger.ONE;
        }
        if (cache.containsKey(Integer.valueOf(i2))) {
            return cache.get(Integer.valueOf(i2));
        }
        BigInteger multiply = BigInteger.valueOf((long) i2).multiply(factorial(i2 - 2));
        cache.put(Integer.valueOf(i2), multiply);
        return multiply;
    }

    @Override // org.apache.poi.ss.formula.functions.Function1Arg
    public ValueEval evaluate(int i2, int i3, ValueEval valueEval) {
        try {
            int coerceValueToInt = OperandResolver.coerceValueToInt(valueEval);
            if (coerceValueToInt < 0) {
                return ErrorEval.NUM_ERROR;
            }
            return new NumberEval((double) factorial(coerceValueToInt).longValue());
        } catch (EvaluationException unused) {
            return ErrorEval.VALUE_INVALID;
        }
    }

    @Override // org.apache.poi.ss.formula.functions.FreeRefFunction
    public ValueEval evaluate(ValueEval[] valueEvalArr, OperationEvaluationContext operationEvaluationContext) {
        if (valueEvalArr.length != 1) {
            return ErrorEval.VALUE_INVALID;
        }
        return evaluate(operationEvaluationContext.getRowIndex(), operationEvaluationContext.getColumnIndex(), valueEvalArr[0]);
    }
}
