package org.apache.poi.ss.formula.functions;

public class Finance {
    public static double fv(double d2, int i2, double d3, double d4, int i3) {
        double d5 = d2 + 1.0d;
        double d6 = (double) i2;
        return -((((Math.pow(d5, d6) - 1.0d) * (((((double) i3) * d2) + 1.0d) * d3)) / d2) + (Math.pow(d5, d6) * d4));
    }

    public static double ipmt(double d2, int i2, int i3, double d3, double d4, int i4) {
        double fv = fv(d2, i2 - 1, pmt(d2, i3, d3, d4, i4), d3, i4) * d2;
        return i4 == 1 ? fv / (1.0d + d2) : fv;
    }

    public static double pmt(double d2, int i2, double d3, double d4, int i3) {
        double d5 = d2 + 1.0d;
        double d6 = (double) i2;
        return (((Math.pow(d5, d6) * d3) + d4) * (-d2)) / ((Math.pow(d5, d6) - 1.0d) * ((d2 * ((double) i3)) + 1.0d));
    }

    public static double ppmt(double d2, int i2, int i3, double d3, double d4, int i4) {
        return pmt(d2, i3, d3, d4, i4) - ipmt(d2, i2, i3, d3, d4, i4);
    }

    public static double fv(double d2, int i2, double d3, double d4) {
        return fv(d2, i2, d3, d4, 0);
    }

    public static double ipmt(double d2, int i2, int i3, double d3, double d4) {
        return ipmt(d2, i2, i3, d3, d4, 0);
    }

    public static double pmt(double d2, int i2, double d3, double d4) {
        return pmt(d2, i2, d3, d4, 0);
    }

    public static double ppmt(double d2, int i2, int i3, double d3, double d4) {
        return pmt(d2, i3, d3, d4) - ipmt(d2, i2, i3, d3, d4);
    }

    public static double ipmt(double d2, int i2, int i3, double d3) {
        return ipmt(d2, i2, i3, d3, NumericFunction.LOG_10_TO_BASE_e);
    }

    public static double pmt(double d2, int i2, double d3) {
        return pmt(d2, i2, d3, NumericFunction.LOG_10_TO_BASE_e);
    }

    public static double ppmt(double d2, int i2, int i3, double d3) {
        return pmt(d2, i3, d3) - ipmt(d2, i2, i3, d3);
    }
}
