package org.apache.poi.ss.formula.functions;

public final class FinanceLib {
    public static double fv(double d2, double d3, double d4, double d5, boolean z) {
        if (d2 == NumericFunction.LOG_10_TO_BASE_e) {
            return ((d3 * d4) + d5) * -1.0d;
        }
        double d6 = 1.0d;
        double d7 = d2 + 1.0d;
        double pow = 1.0d - Math.pow(d7, d3);
        if (z) {
            d6 = d7;
        }
        return (((pow * d6) * d4) / d2) - (Math.pow(d7, d3) * d5);
    }

    public static double nper(double d2, double d3, double d4, double d5, boolean z) {
        if (d2 == NumericFunction.LOG_10_TO_BASE_e) {
            return ((d5 + d4) * -1.0d) / d3;
        }
        double d6 = 1.0d;
        double d7 = d2 + 1.0d;
        if (z) {
            d6 = d7;
        }
        double d8 = (d6 * d3) / d2;
        double d9 = d8 - d5;
        int i2 = (d9 > NumericFunction.LOG_10_TO_BASE_e ? 1 : (d9 == NumericFunction.LOG_10_TO_BASE_e ? 0 : -1));
        return ((i2 < 0 ? Math.log(d5 - d8) : Math.log(d9)) - (i2 < 0 ? Math.log((-d4) - d8) : Math.log(d4 + d8))) / Math.log(d7);
    }

    public static double npv(double d2, double[] dArr) {
        double d3 = d2 + 1.0d;
        double d4 = NumericFunction.LOG_10_TO_BASE_e;
        double d5 = d3;
        for (double d6 : dArr) {
            d4 += d6 / d5;
            d5 *= d3;
        }
        return d4;
    }

    public static double pmt(double d2, double d3, double d4, double d5, boolean z) {
        if (d2 == NumericFunction.LOG_10_TO_BASE_e) {
            return ((d5 + d4) * -1.0d) / d3;
        }
        double d6 = d2 + 1.0d;
        return (((Math.pow(d6, d3) * d4) + d5) * d2) / ((1.0d - Math.pow(d6, d3)) * (z ? d6 : 1.0d));
    }

    public static double pv(double d2, double d3, double d4, double d5, boolean z) {
        if (d2 == NumericFunction.LOG_10_TO_BASE_e) {
            return ((d3 * d4) + d5) * -1.0d;
        }
        double d6 = 1.0d;
        double d7 = d2 + 1.0d;
        double pow = (1.0d - Math.pow(d7, d3)) / d2;
        if (z) {
            d6 = d7;
        }
        return (((pow * d6) * d4) - d5) / Math.pow(d7, d3);
    }
}
