package org.apache.poi.ss.formula.functions;

import org.apache.poi.ss.formula.eval.ErrorEval;
import org.apache.poi.ss.formula.eval.EvaluationException;
import org.apache.poi.ss.formula.eval.NumberEval;
import org.apache.poi.ss.formula.eval.ValueEval;
import org.apache.poi.ss.formula.functions.AggregateFunction;

public final class Irr implements Function {
    public static double irr(double[] dArr) {
        return irr(dArr, 0.1d);
    }

    @Override // org.apache.poi.ss.formula.functions.Function
    public ValueEval evaluate(ValueEval[] valueEvalArr, int i2, int i3) {
        if (valueEvalArr.length == 0 || valueEvalArr.length > 2) {
            return ErrorEval.VALUE_INVALID;
        }
        try {
            double irr = irr(AggregateFunction.ValueCollector.collectValues(valueEvalArr[0]), valueEvalArr.length == 2 ? NumericFunction.singleOperandEvaluate(valueEvalArr[1], i2, i3) : 0.1d);
            NumericFunction.checkValue(irr);
            return new NumberEval(irr);
        } catch (EvaluationException e2) {
            return e2.getErrorEval();
        }
    }

    public static double irr(double[] dArr, double d2) {
        char c = 0;
        double d3 = d2;
        int i2 = 0;
        while (i2 < 20) {
            double d4 = 1.0d + d3;
            double d5 = dArr[c];
            double d6 = NumericFunction.LOG_10_TO_BASE_e;
            double d7 = d4;
            int i3 = 0;
            while (true) {
                i3++;
                if (i3 >= dArr.length) {
                    break;
                }
                double d8 = dArr[i3];
                d5 = (d8 / d7) + d5;
                d7 *= d4;
                d6 -= (((double) i3) * d8) / d7;
                d3 = d3;
            }
            double d9 = d3 - (d5 / d6);
            if (Math.abs(d9 - d3) <= 1.0E-7d) {
                return d9;
            }
            i2++;
            d3 = d9;
            c = 0;
        }
        return Double.NaN;
    }
}
