package org.apache.poi.ss.formula.functions;

import b.b.a.a.a;
import org.apache.poi.ss.formula.TwoDEval;
import org.apache.poi.ss.formula.eval.ErrorEval;
import org.apache.poi.ss.formula.eval.EvaluationException;
import org.apache.poi.ss.formula.eval.NumberEval;
import org.apache.poi.ss.formula.eval.RefEval;
import org.apache.poi.ss.formula.eval.ValueEval;
import org.apache.poi.ss.formula.functions.LookupUtils;

public final class LinearRegressionFunction extends Fixed2ArgFunction {
    public FUNCTION function;

    public static final class AreaValueArray extends ValueArray {
        public final TwoDEval _ae;
        public final int _width;

        public AreaValueArray(TwoDEval twoDEval) {
            super(twoDEval.getHeight() * twoDEval.getWidth());
            this._ae = twoDEval;
            this._width = twoDEval.getWidth();
        }

        @Override // org.apache.poi.ss.formula.functions.LinearRegressionFunction.ValueArray
        public ValueEval getItemInternal(int i2) {
            int i3 = this._width;
            return this._ae.getValue(i2 / i3, i2 % i3);
        }
    }

    public enum FUNCTION {
        INTERCEPT,
        SLOPE
    }

    public static final class RefValueArray extends ValueArray {
        public final RefEval _ref;
        public final int _width;

        public RefValueArray(RefEval refEval) {
            super(refEval.getNumberOfSheets());
            this._ref = refEval;
            this._width = refEval.getNumberOfSheets();
        }

        @Override // org.apache.poi.ss.formula.functions.LinearRegressionFunction.ValueArray
        public ValueEval getItemInternal(int i2) {
            return this._ref.getInnerValueEval(this._ref.getFirstSheetIndex() + (i2 % this._width));
        }
    }

    public static final class SingleCellValueArray extends ValueArray {
        public final ValueEval _value;

        public SingleCellValueArray(ValueEval valueEval) {
            super(1);
            this._value = valueEval;
        }

        @Override // org.apache.poi.ss.formula.functions.LinearRegressionFunction.ValueArray
        public ValueEval getItemInternal(int i2) {
            return this._value;
        }
    }

    public static abstract class ValueArray implements LookupUtils.ValueVector {
        public final int _size;

        public ValueArray(int i2) {
            this._size = i2;
        }

        @Override // org.apache.poi.ss.formula.functions.LookupUtils.ValueVector
        public ValueEval getItem(int i2) {
            if (i2 >= 0 && i2 <= this._size) {
                return getItemInternal(i2);
            }
            StringBuilder a = a.a("Specified index ", i2, " is outside range (0..");
            a.append(this._size - 1);
            a.append(")");
            throw new IllegalArgumentException(a.toString());
        }

        public abstract ValueEval getItemInternal(int i2);

        @Override // org.apache.poi.ss.formula.functions.LookupUtils.ValueVector
        public final int getSize() {
            return this._size;
        }
    }

    public LinearRegressionFunction(FUNCTION function2) {
        this.function = function2;
    }

    public static LookupUtils.ValueVector createValueVector(ValueEval valueEval) {
        if (valueEval instanceof ErrorEval) {
            throw new EvaluationException((ErrorEval) valueEval);
        } else if (valueEval instanceof TwoDEval) {
            return new AreaValueArray((TwoDEval) valueEval);
        } else {
            if (valueEval instanceof RefEval) {
                return new RefValueArray((RefEval) valueEval);
            }
            return new SingleCellValueArray(valueEval);
        }
    }

    private double evaluateInternal(LookupUtils.ValueVector valueVector, LookupUtils.ValueVector valueVector2, int i2) {
        LookupUtils.ValueVector valueVector3 = valueVector;
        LookupUtils.ValueVector valueVector4 = valueVector2;
        ErrorEval errorEval = null;
        double d2 = NumericFunction.LOG_10_TO_BASE_e;
        ErrorEval errorEval2 = null;
        double d3 = 0.0d;
        double d4 = 0.0d;
        boolean z = false;
        for (int i3 = 0; i3 < i2; i3++) {
            ValueEval item = valueVector3.getItem(i3);
            ValueEval item2 = valueVector4.getItem(i3);
            if ((item instanceof ErrorEval) && errorEval == null) {
                errorEval = (ErrorEval) item;
            } else if ((item2 instanceof ErrorEval) && errorEval2 == null) {
                errorEval2 = (ErrorEval) item2;
            } else if ((item instanceof NumberEval) && (item2 instanceof NumberEval)) {
                d3 += ((NumberEval) item).getNumberValue();
                d4 += ((NumberEval) item2).getNumberValue();
                z = true;
            }
        }
        double d5 = (double) i2;
        double d6 = d3 / d5;
        double d7 = d4 / d5;
        ErrorEval errorEval3 = errorEval2;
        int i4 = 0;
        double d8 = 0.0d;
        while (i4 < i2) {
            ValueEval item3 = valueVector3.getItem(i4);
            ValueEval item4 = valueVector4.getItem(i4);
            if ((item3 instanceof ErrorEval) && errorEval == null) {
                errorEval = (ErrorEval) item3;
            } else if ((item4 instanceof ErrorEval) && errorEval3 == null) {
                errorEval3 = (ErrorEval) item4;
            } else if ((item3 instanceof NumberEval) && (item4 instanceof NumberEval)) {
                NumberEval numberEval = (NumberEval) item3;
                double numberValue = ((numberEval.getNumberValue() - d6) * (numberEval.getNumberValue() - d6)) + d8;
                d2 = ((((NumberEval) item4).getNumberValue() - d7) * (numberEval.getNumberValue() - d6)) + d2;
                d8 = numberValue;
            }
            i4++;
            valueVector3 = valueVector;
            valueVector4 = valueVector2;
        }
        double d9 = d2 / d8;
        double d10 = d7 - (d6 * d9);
        if (errorEval != null) {
            throw new EvaluationException(errorEval);
        } else if (errorEval3 != null) {
            throw new EvaluationException(errorEval3);
        } else if (z) {
            return this.function == FUNCTION.INTERCEPT ? d10 : d9;
        } else {
            throw new EvaluationException(ErrorEval.DIV_ZERO);
        }
    }

    @Override // org.apache.poi.ss.formula.functions.Function2Arg
    public ValueEval evaluate(int i2, int i3, ValueEval valueEval, ValueEval valueEval2) {
        try {
            LookupUtils.ValueVector createValueVector = createValueVector(valueEval);
            LookupUtils.ValueVector createValueVector2 = createValueVector(valueEval2);
            int size = createValueVector2.getSize();
            if (size != 0) {
                if (createValueVector.getSize() == size) {
                    double evaluateInternal = evaluateInternal(createValueVector2, createValueVector, size);
                    if (Double.isNaN(evaluateInternal) || Double.isInfinite(evaluateInternal)) {
                        return ErrorEval.NUM_ERROR;
                    }
                    return new NumberEval(evaluateInternal);
                }
            }
            return ErrorEval.NA;
        } catch (EvaluationException e2) {
            return e2.getErrorEval();
        }
    }
}
