package org.apache.poi.ss.formula.functions;

import org.apache.poi.ss.formula.eval.AreaEval;
import org.apache.poi.ss.formula.eval.BlankEval;
import org.apache.poi.ss.formula.eval.BoolEval;
import org.apache.poi.ss.formula.eval.ErrorEval;
import org.apache.poi.ss.formula.eval.EvaluationException;
import org.apache.poi.ss.formula.eval.NumberEval;
import org.apache.poi.ss.formula.eval.OperandResolver;
import org.apache.poi.ss.formula.eval.RefEval;
import org.apache.poi.ss.formula.eval.RefListEval;
import org.apache.poi.ss.formula.eval.StringEval;
import org.apache.poi.ss.formula.eval.ValueEval;

public abstract class LogicalFunction extends Fixed1ArgFunction {
    public static final Function ISBLANK = new LogicalFunction() {
        /* class org.apache.poi.ss.formula.functions.LogicalFunction.AnonymousClass5 */

        @Override // org.apache.poi.ss.formula.functions.LogicalFunction
        public boolean evaluate(ValueEval valueEval) {
            return valueEval instanceof BlankEval;
        }
    };
    public static final Function ISERR = new LogicalFunction() {
        /* class org.apache.poi.ss.formula.functions.LogicalFunction.AnonymousClass7 */

        @Override // org.apache.poi.ss.formula.functions.LogicalFunction
        public boolean evaluate(ValueEval valueEval) {
            if (!(valueEval instanceof ErrorEval) || valueEval == ErrorEval.NA) {
                return false;
            }
            return true;
        }
    };
    public static final Function ISERROR = new LogicalFunction() {
        /* class org.apache.poi.ss.formula.functions.LogicalFunction.AnonymousClass6 */

        @Override // org.apache.poi.ss.formula.functions.LogicalFunction
        public boolean evaluate(ValueEval valueEval) {
            return valueEval instanceof ErrorEval;
        }
    };
    public static final Function ISLOGICAL = new LogicalFunction() {
        /* class org.apache.poi.ss.formula.functions.LogicalFunction.AnonymousClass1 */

        @Override // org.apache.poi.ss.formula.functions.LogicalFunction
        public boolean evaluate(ValueEval valueEval) {
            return valueEval instanceof BoolEval;
        }
    };
    public static final Function ISNA = new LogicalFunction() {
        /* class org.apache.poi.ss.formula.functions.LogicalFunction.AnonymousClass8 */

        @Override // org.apache.poi.ss.formula.functions.LogicalFunction
        public boolean evaluate(ValueEval valueEval) {
            return valueEval == ErrorEval.NA;
        }
    };
    public static final Function ISNONTEXT = new LogicalFunction() {
        /* class org.apache.poi.ss.formula.functions.LogicalFunction.AnonymousClass2 */

        @Override // org.apache.poi.ss.formula.functions.LogicalFunction
        public boolean evaluate(ValueEval valueEval) {
            return !(valueEval instanceof StringEval);
        }
    };
    public static final Function ISNUMBER = new LogicalFunction() {
        /* class org.apache.poi.ss.formula.functions.LogicalFunction.AnonymousClass3 */

        @Override // org.apache.poi.ss.formula.functions.LogicalFunction
        public boolean evaluate(ValueEval valueEval) {
            return valueEval instanceof NumberEval;
        }
    };
    public static final Function ISREF = new Fixed1ArgFunction() {
        /* class org.apache.poi.ss.formula.functions.LogicalFunction.AnonymousClass9 */

        @Override // org.apache.poi.ss.formula.functions.Function1Arg
        public ValueEval evaluate(int i2, int i3, ValueEval valueEval) {
            if ((valueEval instanceof RefEval) || (valueEval instanceof AreaEval) || (valueEval instanceof RefListEval)) {
                return BoolEval.TRUE;
            }
            return BoolEval.FALSE;
        }
    };
    public static final Function ISTEXT = new LogicalFunction() {
        /* class org.apache.poi.ss.formula.functions.LogicalFunction.AnonymousClass4 */

        @Override // org.apache.poi.ss.formula.functions.LogicalFunction
        public boolean evaluate(ValueEval valueEval) {
            return valueEval instanceof StringEval;
        }
    };

    @Override // org.apache.poi.ss.formula.functions.Function1Arg
    public ValueEval evaluate(int i2, int i3, ValueEval valueEval) {
        ValueEval valueEval2;
        try {
            valueEval2 = OperandResolver.getSingleValue(valueEval, i2, i3);
        } catch (EvaluationException e2) {
            valueEval2 = e2.getErrorEval();
        }
        return BoolEval.valueOf(evaluate(valueEval2));
    }

    public abstract boolean evaluate(ValueEval valueEval);
}
