package org.apache.poi.ss.formula.functions;

import b.b.a.a.a;
import java.util.regex.Pattern;
import org.apache.poi.ss.formula.TwoDEval;
import org.apache.poi.ss.formula.eval.BlankEval;
import org.apache.poi.ss.formula.eval.BoolEval;
import org.apache.poi.ss.formula.eval.ErrorEval;
import org.apache.poi.ss.formula.eval.EvaluationException;
import org.apache.poi.ss.formula.eval.NumberEval;
import org.apache.poi.ss.formula.eval.NumericValueEval;
import org.apache.poi.ss.formula.eval.OperandResolver;
import org.apache.poi.ss.formula.eval.RefEval;
import org.apache.poi.ss.formula.eval.StringEval;
import org.apache.poi.ss.formula.eval.ValueEval;
import org.apache.poi.ss.formula.functions.Countif;

public final class LookupUtils {

    public static final class BinarySearchIndexes {
        public int _highIx;
        public int _lowIx = -1;

        public BinarySearchIndexes(int i2) {
            this._highIx = i2;
        }

        public int getHighIx() {
            return this._highIx;
        }

        public int getLowIx() {
            return this._lowIx;
        }

        public int getMidIx() {
            int i2 = this._highIx;
            int i3 = this._lowIx;
            int i4 = i2 - i3;
            if (i4 < 2) {
                return -1;
            }
            return (i4 / 2) + i3;
        }

        public void narrowSearch(int i2, boolean z) {
            if (z) {
                this._highIx = i2;
            } else {
                this._lowIx = i2;
            }
        }
    }

    public static final class BooleanLookupComparer extends LookupValueComparerBase {
        public boolean _value;

        public BooleanLookupComparer(BoolEval boolEval) {
            super(boolEval);
            this._value = boolEval.getBooleanValue();
        }

        @Override // org.apache.poi.ss.formula.functions.LookupUtils.LookupValueComparerBase
        public CompareResult compareSameType(ValueEval valueEval) {
            boolean booleanValue = ((BoolEval) valueEval).getBooleanValue();
            boolean z = this._value;
            if (z == booleanValue) {
                return CompareResult.EQUAL;
            }
            if (z) {
                return CompareResult.GREATER_THAN;
            }
            return CompareResult.LESS_THAN;
        }

        @Override // org.apache.poi.ss.formula.functions.LookupUtils.LookupValueComparerBase
        public String getValueAsString() {
            return String.valueOf(this._value);
        }
    }

    public static final class ColumnVector implements ValueVector {
        public final int _columnIndex;
        public final int _size;
        public final TwoDEval _tableArray;

        public ColumnVector(TwoDEval twoDEval, int i2) {
            this._columnIndex = i2;
            int width = twoDEval.getWidth() - 1;
            if (i2 < 0 || i2 > width) {
                throw new IllegalArgumentException(a.b("Specified column index (", i2, ") is outside the allowed range (0..", width, ")"));
            }
            this._tableArray = twoDEval;
            this._size = twoDEval.getHeight();
        }

        @Override // org.apache.poi.ss.formula.functions.LookupUtils.ValueVector
        public ValueEval getItem(int i2) {
            if (i2 <= this._size) {
                return this._tableArray.getValue(i2, this._columnIndex);
            }
            StringBuilder a = a.a("Specified index (", i2, ") is outside the allowed range (0..");
            a.append(this._size - 1);
            a.append(")");
            throw new ArrayIndexOutOfBoundsException(a.toString());
        }

        @Override // org.apache.poi.ss.formula.functions.LookupUtils.ValueVector
        public int getSize() {
            return this._size;
        }
    }

    public interface LookupValueComparer {
        CompareResult compareTo(ValueEval valueEval);
    }

    public static abstract class LookupValueComparerBase implements LookupValueComparer {
        public final Class<? extends ValueEval> _targetClass;

        /* JADX DEBUG: Type inference failed for r2v2. Raw type applied. Possible types: java.lang.Class<?>, java.lang.Class<? extends org.apache.poi.ss.formula.eval.ValueEval> */
        public LookupValueComparerBase(ValueEval valueEval) {
            if (valueEval != null) {
                this._targetClass = valueEval.getClass();
                return;
            }
            throw new RuntimeException("targetValue cannot be null");
        }

        public abstract CompareResult compareSameType(ValueEval valueEval);

        @Override // org.apache.poi.ss.formula.functions.LookupUtils.LookupValueComparer
        public final CompareResult compareTo(ValueEval valueEval) {
            if (valueEval == null) {
                throw new RuntimeException("compare to value cannot be null");
            } else if (this._targetClass != valueEval.getClass()) {
                return CompareResult.TYPE_MISMATCH;
            } else {
                return compareSameType(valueEval);
            }
        }

        public abstract String getValueAsString();

        public String toString() {
            return getClass().getName() + " [" + getValueAsString() + "]";
        }
    }

    public static final class NumberLookupComparer extends LookupValueComparerBase {
        public double _value;

        public NumberLookupComparer(NumberEval numberEval) {
            super(numberEval);
            this._value = numberEval.getNumberValue();
        }

        @Override // org.apache.poi.ss.formula.functions.LookupUtils.LookupValueComparerBase
        public CompareResult compareSameType(ValueEval valueEval) {
            return CompareResult.valueOf(Double.compare(this._value, ((NumberEval) valueEval).getNumberValue()));
        }

        @Override // org.apache.poi.ss.formula.functions.LookupUtils.LookupValueComparerBase
        public String getValueAsString() {
            return String.valueOf(this._value);
        }
    }

    public static final class RowVector implements ValueVector {
        public final int _rowIndex;
        public final int _size;
        public final TwoDEval _tableArray;

        public RowVector(TwoDEval twoDEval, int i2) {
            this._rowIndex = i2;
            int height = twoDEval.getHeight() - 1;
            if (i2 < 0 || i2 > height) {
                throw new IllegalArgumentException(a.b("Specified row index (", i2, ") is outside the allowed range (0..", height, ")"));
            }
            this._tableArray = twoDEval;
            this._size = twoDEval.getWidth();
        }

        @Override // org.apache.poi.ss.formula.functions.LookupUtils.ValueVector
        public ValueEval getItem(int i2) {
            if (i2 <= this._size) {
                return this._tableArray.getValue(this._rowIndex, i2);
            }
            StringBuilder a = a.a("Specified index (", i2, ") is outside the allowed range (0..");
            a.append(this._size - 1);
            a.append(")");
            throw new ArrayIndexOutOfBoundsException(a.toString());
        }

        @Override // org.apache.poi.ss.formula.functions.LookupUtils.ValueVector
        public int getSize() {
            return this._size;
        }
    }

    public static final class SheetVector implements ValueVector {
        public final RefEval _re;
        public final int _size;

        public SheetVector(RefEval refEval) {
            this._size = refEval.getNumberOfSheets();
            this._re = refEval;
        }

        @Override // org.apache.poi.ss.formula.functions.LookupUtils.ValueVector
        public ValueEval getItem(int i2) {
            if (i2 < this._size) {
                return this._re.getInnerValueEval(this._re.getFirstSheetIndex() + i2);
            }
            StringBuilder a = a.a("Specified index (", i2, ") is outside the allowed range (0..");
            a.append(this._size - 1);
            a.append(")");
            throw new ArrayIndexOutOfBoundsException(a.toString());
        }

        @Override // org.apache.poi.ss.formula.functions.LookupUtils.ValueVector
        public int getSize() {
            return this._size;
        }
    }

    public static final class StringLookupComparer extends LookupValueComparerBase {
        public boolean _isMatchFunction;
        public boolean _matchExact;
        public String _value;
        public final Pattern _wildCardPattern;

        public StringLookupComparer(StringEval stringEval, boolean z, boolean z2) {
            super(stringEval);
            String stringValue = stringEval.getStringValue();
            this._value = stringValue;
            this._wildCardPattern = Countif.StringMatcher.getWildCardPattern(stringValue);
            this._matchExact = z;
            this._isMatchFunction = z2;
        }

        @Override // org.apache.poi.ss.formula.functions.LookupUtils.LookupValueComparerBase
        public CompareResult compareSameType(ValueEval valueEval) {
            String stringValue = ((StringEval) valueEval).getStringValue();
            Pattern pattern = this._wildCardPattern;
            if (pattern != null) {
                boolean matches = pattern.matcher(stringValue).matches();
                if (this._isMatchFunction || !this._matchExact) {
                    return CompareResult.valueOf(matches);
                }
            }
            return CompareResult.valueOf(this._value.compareToIgnoreCase(stringValue));
        }

        @Override // org.apache.poi.ss.formula.functions.LookupUtils.LookupValueComparerBase
        public String getValueAsString() {
            return this._value;
        }
    }

    public interface ValueVector {
        ValueEval getItem(int i2);

        int getSize();
    }

    public static ValueVector createColumnVector(TwoDEval twoDEval, int i2) {
        return new ColumnVector(twoDEval, i2);
    }

    public static LookupValueComparer createLookupComparer(ValueEval valueEval, boolean z, boolean z2) {
        if (valueEval == BlankEval.instance) {
            return new NumberLookupComparer(NumberEval.ZERO);
        }
        if (valueEval instanceof StringEval) {
            return new StringLookupComparer((StringEval) valueEval, z, z2);
        }
        if (valueEval instanceof NumberEval) {
            return new NumberLookupComparer((NumberEval) valueEval);
        }
        if (valueEval instanceof BoolEval) {
            return new BooleanLookupComparer((BoolEval) valueEval);
        }
        StringBuilder b2 = a.b("Bad lookup value type (");
        b2.append(valueEval.getClass().getName());
        b2.append(")");
        throw new IllegalArgumentException(b2.toString());
    }

    public static ValueVector createRowVector(TwoDEval twoDEval, int i2) {
        return new RowVector(twoDEval, i2);
    }

    public static ValueVector createVector(TwoDEval twoDEval) {
        if (twoDEval.isColumn()) {
            return createColumnVector(twoDEval, 0);
        }
        if (twoDEval.isRow()) {
            return createRowVector(twoDEval, 0);
        }
        return null;
    }

    public static int findLastIndexInRunOfEqualValues(LookupValueComparer lookupValueComparer, ValueVector valueVector, int i2, int i3) {
        do {
            i2++;
            if (i2 >= i3) {
                return i3 - 1;
            }
        } while (lookupValueComparer.compareTo(valueVector.getItem(i2)).isEqual());
        return i2 - 1;
    }

    public static int handleMidValueTypeMismatch(LookupValueComparer lookupValueComparer, ValueVector valueVector, BinarySearchIndexes binarySearchIndexes, int i2) {
        CompareResult compareTo;
        int highIx = binarySearchIndexes.getHighIx();
        int i3 = i2;
        do {
            i3++;
            if (i3 == highIx) {
                binarySearchIndexes.narrowSearch(i2, true);
                return -1;
            }
            compareTo = lookupValueComparer.compareTo(valueVector.getItem(i3));
            if (compareTo.isLessThan() && i3 == highIx - 1) {
                binarySearchIndexes.narrowSearch(i2, true);
                return -1;
            }
        } while (compareTo.isTypeMismatch());
        if (compareTo.isEqual()) {
            return i3;
        }
        binarySearchIndexes.narrowSearch(i3, compareTo.isLessThan());
        return -1;
    }

    public static int lookupIndexOfExactValue(LookupValueComparer lookupValueComparer, ValueVector valueVector) {
        int size = valueVector.getSize();
        for (int i2 = 0; i2 < size; i2++) {
            if (lookupValueComparer.compareTo(valueVector.getItem(i2)).isEqual()) {
                return i2;
            }
        }
        return -1;
    }

    public static int lookupIndexOfValue(ValueEval valueEval, ValueVector valueVector, boolean z) {
        int i2;
        LookupValueComparer createLookupComparer = createLookupComparer(valueEval, z, false);
        if (z) {
            i2 = performBinarySearch(valueVector, createLookupComparer);
        } else {
            i2 = lookupIndexOfExactValue(createLookupComparer, valueVector);
        }
        if (i2 >= 0) {
            return i2;
        }
        throw new EvaluationException(ErrorEval.NA);
    }

    public static int performBinarySearch(ValueVector valueVector, LookupValueComparer lookupValueComparer) {
        BinarySearchIndexes binarySearchIndexes = new BinarySearchIndexes(valueVector.getSize());
        while (true) {
            int midIx = binarySearchIndexes.getMidIx();
            if (midIx < 0) {
                return binarySearchIndexes.getLowIx();
            }
            CompareResult compareTo = lookupValueComparer.compareTo(valueVector.getItem(midIx));
            if (compareTo.isTypeMismatch()) {
                midIx = handleMidValueTypeMismatch(lookupValueComparer, valueVector, binarySearchIndexes, midIx);
                if (midIx < 0) {
                    continue;
                } else {
                    compareTo = lookupValueComparer.compareTo(valueVector.getItem(midIx));
                }
            }
            if (compareTo.isEqual()) {
                return findLastIndexInRunOfEqualValues(lookupValueComparer, valueVector, midIx, binarySearchIndexes.getHighIx());
            }
            binarySearchIndexes.narrowSearch(midIx, compareTo.isLessThan());
        }
    }

    public static boolean resolveRangeLookupArg(ValueEval valueEval, int i2, int i3) {
        ValueEval singleValue = OperandResolver.getSingleValue(valueEval, i2, i3);
        if (singleValue instanceof BlankEval) {
            return false;
        }
        if (singleValue instanceof BoolEval) {
            return ((BoolEval) singleValue).getBooleanValue();
        }
        if (singleValue instanceof StringEval) {
            String stringValue = ((StringEval) singleValue).getStringValue();
            if (stringValue.length() >= 1) {
                Boolean parseBoolean = Countif.parseBoolean(stringValue);
                if (parseBoolean != null) {
                    return parseBoolean.booleanValue();
                }
                throw EvaluationException.invalidValue();
            }
            throw EvaluationException.invalidValue();
        } else if (!(singleValue instanceof NumericValueEval)) {
            throw new RuntimeException("Unexpected eval type (" + singleValue + ")");
        } else if (NumericFunction.LOG_10_TO_BASE_e != ((NumericValueEval) singleValue).getNumberValue()) {
            return true;
        } else {
            return false;
        }
    }

    public static int resolveRowOrColIndexArg(ValueEval valueEval, int i2, int i3) {
        if (valueEval != null) {
            try {
                ValueEval singleValue = OperandResolver.getSingleValue(valueEval, i2, (short) i3);
                if (!(singleValue instanceof StringEval) || OperandResolver.parseDouble(((StringEval) singleValue).getStringValue()) != null) {
                    int coerceValueToInt = OperandResolver.coerceValueToInt(singleValue);
                    if (coerceValueToInt >= 1) {
                        return coerceValueToInt - 1;
                    }
                    throw EvaluationException.invalidValue();
                }
                throw EvaluationException.invalidRef();
            } catch (EvaluationException unused) {
                throw EvaluationException.invalidRef();
            }
        } else {
            throw new IllegalArgumentException("argument must not be null");
        }
    }

    public static TwoDEval resolveTableArrayArg(ValueEval valueEval) {
        if (valueEval instanceof TwoDEval) {
            return (TwoDEval) valueEval;
        }
        if (valueEval instanceof RefEval) {
            return ((RefEval) valueEval).offset(0, 0, 0, 0);
        }
        throw EvaluationException.invalidValue();
    }

    public static final class CompareResult {
        public static final CompareResult EQUAL = new CompareResult(false, 0);
        public static final CompareResult GREATER_THAN = new CompareResult(false, 1);
        public static final CompareResult LESS_THAN = new CompareResult(false, -1);
        public static final CompareResult TYPE_MISMATCH = new CompareResult(true, 0);
        public final boolean _isEqual;
        public final boolean _isGreaterThan;
        public final boolean _isLessThan;
        public final boolean _isTypeMismatch;

        public CompareResult(boolean z, int i2) {
            boolean z2 = true;
            if (z) {
                this._isTypeMismatch = true;
                this._isLessThan = false;
                this._isEqual = false;
                this._isGreaterThan = false;
                return;
            }
            this._isTypeMismatch = false;
            this._isLessThan = i2 < 0;
            this._isEqual = i2 == 0;
            this._isGreaterThan = i2 <= 0 ? false : z2;
        }

        private String formatAsString() {
            if (this._isTypeMismatch) {
                return "TYPE_MISMATCH";
            }
            if (this._isLessThan) {
                return "LESS_THAN";
            }
            if (this._isEqual) {
                return "EQUAL";
            }
            return this._isGreaterThan ? "GREATER_THAN" : "??error??";
        }

        public static CompareResult valueOf(int i2) {
            if (i2 < 0) {
                return LESS_THAN;
            }
            if (i2 > 0) {
                return GREATER_THAN;
            }
            return EQUAL;
        }

        public boolean isEqual() {
            return this._isEqual;
        }

        public boolean isGreaterThan() {
            return this._isGreaterThan;
        }

        public boolean isLessThan() {
            return this._isLessThan;
        }

        public boolean isTypeMismatch() {
            return this._isTypeMismatch;
        }

        public String toString() {
            StringBuilder sb = new StringBuilder();
            sb.append(CompareResult.class.getName());
            sb.append(" [");
            return a.a(sb, formatAsString(), "]");
        }

        public static CompareResult valueOf(boolean z) {
            if (z) {
                return EQUAL;
            }
            return LESS_THAN;
        }
    }

    public static ValueVector createVector(RefEval refEval) {
        return new SheetVector(refEval);
    }
}
