package org.apache.poi.ss.formula.functions;

import b.b.a.a.a;
import org.apache.poi.ss.formula.TwoDEval;
import org.apache.poi.ss.formula.eval.ErrorEval;
import org.apache.poi.ss.formula.eval.EvaluationException;
import org.apache.poi.ss.formula.eval.NumberEval;
import org.apache.poi.ss.formula.eval.NumericValueEval;
import org.apache.poi.ss.formula.eval.OperandResolver;
import org.apache.poi.ss.formula.eval.RefEval;
import org.apache.poi.ss.formula.eval.StringEval;
import org.apache.poi.ss.formula.eval.ValueEval;
import org.apache.poi.ss.formula.functions.LookupUtils;

public final class Match extends Var2or3ArgFunction {

    public static final class SingleValueVector implements LookupUtils.ValueVector {
        public final ValueEval _value;

        public SingleValueVector(ValueEval valueEval) {
            this._value = valueEval;
        }

        @Override // org.apache.poi.ss.formula.functions.LookupUtils.ValueVector
        public ValueEval getItem(int i2) {
            if (i2 == 0) {
                return this._value;
            }
            throw new RuntimeException(a.b("Invalid index (", i2, ") only zero is allowed"));
        }

        @Override // org.apache.poi.ss.formula.functions.LookupUtils.ValueVector
        public int getSize() {
            return 1;
        }
    }

    public static LookupUtils.LookupValueComparer createLookupComparer(ValueEval valueEval, boolean z) {
        return LookupUtils.createLookupComparer(valueEval, z, true);
    }

    public static ValueEval eval(int i2, int i3, ValueEval valueEval, ValueEval valueEval2, double d2) {
        boolean z = false;
        int i4 = (d2 > NumericFunction.LOG_10_TO_BASE_e ? 1 : (d2 == NumericFunction.LOG_10_TO_BASE_e ? 0 : -1));
        boolean z2 = i4 == 0;
        if (i4 > 0) {
            z = true;
        }
        try {
            return new NumberEval((double) (findIndexOfValue(OperandResolver.getSingleValue(valueEval, i2, i3), evaluateLookupRange(valueEval2), z2, z) + 1));
        } catch (EvaluationException e2) {
            return e2.getErrorEval();
        }
    }

    public static LookupUtils.ValueVector evaluateLookupRange(ValueEval valueEval) {
        if (valueEval instanceof RefEval) {
            RefEval refEval = (RefEval) valueEval;
            if (refEval.getNumberOfSheets() == 1) {
                return new SingleValueVector(refEval.getInnerValueEval(refEval.getFirstSheetIndex()));
            }
            return LookupUtils.createVector(refEval);
        } else if (valueEval instanceof TwoDEval) {
            LookupUtils.ValueVector createVector = LookupUtils.createVector((TwoDEval) valueEval);
            if (createVector != null) {
                return createVector;
            }
            throw new EvaluationException(ErrorEval.NA);
        } else if (valueEval instanceof NumericValueEval) {
            throw new EvaluationException(ErrorEval.NA);
        } else if (!(valueEval instanceof StringEval)) {
            throw new RuntimeException("Unexpected eval type (" + valueEval + ")");
        } else if (OperandResolver.parseDouble(((StringEval) valueEval).getStringValue()) == null) {
            throw new EvaluationException(ErrorEval.VALUE_INVALID);
        } else {
            throw new EvaluationException(ErrorEval.NA);
        }
    }

    public static double evaluateMatchTypeArg(ValueEval valueEval, int i2, int i3) {
        ValueEval singleValue = OperandResolver.getSingleValue(valueEval, i2, i3);
        if (singleValue instanceof ErrorEval) {
            throw new EvaluationException((ErrorEval) singleValue);
        } else if (singleValue instanceof NumericValueEval) {
            return ((NumericValueEval) singleValue).getNumberValue();
        } else {
            if (singleValue instanceof StringEval) {
                Double parseDouble = OperandResolver.parseDouble(((StringEval) singleValue).getStringValue());
                if (parseDouble != null) {
                    return parseDouble.doubleValue();
                }
                throw new EvaluationException(ErrorEval.VALUE_INVALID);
            }
            StringBuilder b2 = a.b("Unexpected match_type type (");
            b2.append(singleValue.getClass().getName());
            b2.append(")");
            throw new RuntimeException(b2.toString());
        }
    }

    public static int findIndexOfValue(ValueEval valueEval, LookupUtils.ValueVector valueVector, boolean z, boolean z2) {
        LookupUtils.LookupValueComparer createLookupComparer = createLookupComparer(valueEval, z);
        int size = valueVector.getSize();
        int i2 = 0;
        if (z) {
            while (i2 < size) {
                if (createLookupComparer.compareTo(valueVector.getItem(i2)).isEqual()) {
                    return i2;
                }
                i2++;
            }
            throw new EvaluationException(ErrorEval.NA);
        } else if (z2) {
            for (int i3 = size - 1; i3 >= 0; i3--) {
                LookupUtils.CompareResult compareTo = createLookupComparer.compareTo(valueVector.getItem(i3));
                if (!compareTo.isTypeMismatch() && !compareTo.isLessThan()) {
                    return i3;
                }
            }
            throw new EvaluationException(ErrorEval.NA);
        } else {
            while (i2 < size) {
                LookupUtils.CompareResult compareTo2 = createLookupComparer.compareTo(valueVector.getItem(i2));
                if (compareTo2.isEqual()) {
                    return i2;
                }
                if (!compareTo2.isGreaterThan()) {
                    i2++;
                } else if (i2 >= 1) {
                    return i2 - 1;
                } else {
                    throw new EvaluationException(ErrorEval.NA);
                }
            }
            return size - 1;
        }
    }

    @Override // org.apache.poi.ss.formula.functions.Function2Arg
    public ValueEval evaluate(int i2, int i3, ValueEval valueEval, ValueEval valueEval2) {
        return eval(i2, i3, valueEval, valueEval2, 1.0d);
    }

    @Override // org.apache.poi.ss.formula.functions.Function3Arg
    public ValueEval evaluate(int i2, int i3, ValueEval valueEval, ValueEval valueEval2, ValueEval valueEval3) {
        try {
            return eval(i2, i3, valueEval, valueEval2, evaluateMatchTypeArg(valueEval3, i2, i3));
        } catch (EvaluationException unused) {
            return ErrorEval.REF_INVALID;
        }
    }
}
