package org.apache.poi.ss.formula.functions;

import b.b.a.a.a;
import java.util.ArrayList;
import java.util.Arrays;
import java.util.List;
import org.apache.poi.ss.formula.TwoDEval;
import org.apache.poi.ss.formula.eval.BlankEval;
import org.apache.poi.ss.formula.eval.BoolEval;
import org.apache.poi.ss.formula.eval.ErrorEval;
import org.apache.poi.ss.formula.eval.EvaluationException;
import org.apache.poi.ss.formula.eval.NumberEval;
import org.apache.poi.ss.formula.eval.RefEval;
import org.apache.poi.ss.formula.eval.StringEval;
import org.apache.poi.ss.formula.eval.ValueEval;

public final class Mode implements Function {
    public static void collectValue(ValueEval valueEval, List<Double> list, boolean z) {
        if (valueEval instanceof ErrorEval) {
            throw new EvaluationException((ErrorEval) valueEval);
        } else if (valueEval == BlankEval.instance || (valueEval instanceof BoolEval) || (valueEval instanceof StringEval)) {
            if (z) {
                throw EvaluationException.invalidValue();
            }
        } else if (valueEval instanceof NumberEval) {
            list.add(new Double(((NumberEval) valueEval).getNumberValue()));
        } else {
            StringBuilder b2 = a.b("Unexpected value type (");
            b2.append(valueEval.getClass().getName());
            b2.append(")");
            throw new RuntimeException(b2.toString());
        }
    }

    public static void collectValues(ValueEval valueEval, List<Double> list) {
        if (valueEval instanceof TwoDEval) {
            TwoDEval twoDEval = (TwoDEval) valueEval;
            int width = twoDEval.getWidth();
            int height = twoDEval.getHeight();
            for (int i2 = 0; i2 < height; i2++) {
                for (int i3 = 0; i3 < width; i3++) {
                    collectValue(twoDEval.getValue(i2, i3), list, false);
                }
            }
        } else if (valueEval instanceof RefEval) {
            RefEval refEval = (RefEval) valueEval;
            int lastSheetIndex = refEval.getLastSheetIndex();
            for (int firstSheetIndex = refEval.getFirstSheetIndex(); firstSheetIndex <= lastSheetIndex; firstSheetIndex++) {
                collectValue(refEval.getInnerValueEval(firstSheetIndex), list, true);
            }
        } else {
            collectValue(valueEval, list, true);
        }
    }

    public static double evaluate(double[] dArr) {
        if (dArr.length >= 2) {
            int length = dArr.length;
            int[] iArr = new int[length];
            Arrays.fill(iArr, 1);
            int length2 = dArr.length;
            int i2 = 0;
            while (i2 < length2) {
                int i3 = i2 + 1;
                int length3 = dArr.length;
                for (int i4 = i3; i4 < length3; i4++) {
                    if (dArr[i2] == dArr[i4]) {
                        iArr[i2] = iArr[i2] + 1;
                    }
                }
                i2 = i3;
            }
            double d2 = NumericFunction.LOG_10_TO_BASE_e;
            int i5 = 0;
            for (int i6 = 0; i6 < length; i6++) {
                if (iArr[i6] > i5) {
                    d2 = dArr[i6];
                    i5 = iArr[i6];
                }
            }
            if (i5 > 1) {
                return d2;
            }
            throw new EvaluationException(ErrorEval.NA);
        }
        throw new EvaluationException(ErrorEval.NA);
    }

    @Override // org.apache.poi.ss.formula.functions.Function
    public ValueEval evaluate(ValueEval[] valueEvalArr, int i2, int i3) {
        try {
            ArrayList arrayList = new ArrayList();
            for (ValueEval valueEval : valueEvalArr) {
                collectValues(valueEval, arrayList);
            }
            int size = arrayList.size();
            double[] dArr = new double[size];
            for (int i4 = 0; i4 < size; i4++) {
                dArr[i4] = ((Double) arrayList.get(i4)).doubleValue();
            }
            return new NumberEval(evaluate(dArr));
        } catch (EvaluationException e2) {
            return e2.getErrorEval();
        }
    }
}
