package org.apache.poi.ss.formula.functions;

import b.b.a.a.a;
import org.apache.poi.ss.SpreadsheetVersion;
import org.apache.poi.ss.formula.ThreeDEval;
import org.apache.poi.ss.formula.TwoDEval;
import org.apache.poi.ss.formula.eval.BlankEval;
import org.apache.poi.ss.formula.eval.BoolEval;
import org.apache.poi.ss.formula.eval.ErrorEval;
import org.apache.poi.ss.formula.eval.EvaluationException;
import org.apache.poi.ss.formula.eval.NumberEval;
import org.apache.poi.ss.formula.eval.NumericValueEval;
import org.apache.poi.ss.formula.eval.OperandResolver;
import org.apache.poi.ss.formula.eval.RefEval;
import org.apache.poi.ss.formula.eval.StringValueEval;
import org.apache.poi.ss.formula.eval.ValueEval;

public abstract class MultiOperandNumericFunction implements Function {
    public static final int DEFAULT_MAX_NUM_OPERANDS = SpreadsheetVersion.EXCEL2007.getMaxFunctionArgs();
    public static final double[] EMPTY_DOUBLE_ARRAY = new double[0];
    public final boolean _isBlankCounted;
    public final boolean _isReferenceBoolCounted;

    public static class DoubleList {
        public double[] _array = new double[8];
        public int _count = 0;

        private void ensureCapacity(int i2) {
            double[] dArr = this._array;
            if (i2 > dArr.length) {
                double[] dArr2 = new double[((i2 * 3) / 2)];
                System.arraycopy(dArr, 0, dArr2, 0, this._count);
                this._array = dArr2;
            }
        }

        public void add(double d2) {
            ensureCapacity(this._count + 1);
            double[] dArr = this._array;
            int i2 = this._count;
            dArr[i2] = d2;
            this._count = i2 + 1;
        }

        public double[] toArray() {
            int i2 = this._count;
            if (i2 < 1) {
                return MultiOperandNumericFunction.EMPTY_DOUBLE_ARRAY;
            }
            double[] dArr = new double[i2];
            System.arraycopy(this._array, 0, dArr, 0, i2);
            return dArr;
        }
    }

    public MultiOperandNumericFunction(boolean z, boolean z2) {
        this._isReferenceBoolCounted = z;
        this._isBlankCounted = z2;
    }

    private void collectValue(ValueEval valueEval, boolean z, DoubleList doubleList) {
        if (valueEval == null) {
            throw new IllegalArgumentException("ve must not be null");
        } else if (valueEval instanceof BoolEval) {
            if (!z || this._isReferenceBoolCounted) {
                doubleList.add(((BoolEval) valueEval).getNumberValue());
            }
        } else if (valueEval instanceof NumericValueEval) {
            doubleList.add(((NumericValueEval) valueEval).getNumberValue());
        } else if (valueEval instanceof StringValueEval) {
            if (!z) {
                Double parseDouble = OperandResolver.parseDouble(((StringValueEval) valueEval).getStringValue());
                if (parseDouble != null) {
                    doubleList.add(parseDouble.doubleValue());
                    return;
                }
                throw new EvaluationException(ErrorEval.VALUE_INVALID);
            }
        } else if (valueEval instanceof ErrorEval) {
            throw new EvaluationException((ErrorEval) valueEval);
        } else if (valueEval != BlankEval.instance) {
            StringBuilder b2 = a.b("Invalid ValueEval type passed for conversion: (");
            b2.append(valueEval.getClass());
            b2.append(")");
            throw new RuntimeException(b2.toString());
        } else if (this._isBlankCounted) {
            doubleList.add(NumericFunction.LOG_10_TO_BASE_e);
        }
    }

    private void collectValues(ValueEval valueEval, DoubleList doubleList) {
        if (valueEval instanceof ThreeDEval) {
            ThreeDEval threeDEval = (ThreeDEval) valueEval;
            for (int firstSheetIndex = threeDEval.getFirstSheetIndex(); firstSheetIndex <= threeDEval.getLastSheetIndex(); firstSheetIndex++) {
                int width = threeDEval.getWidth();
                int height = threeDEval.getHeight();
                for (int i2 = 0; i2 < height; i2++) {
                    for (int i3 = 0; i3 < width; i3++) {
                        ValueEval value = threeDEval.getValue(firstSheetIndex, i2, i3);
                        if (isSubtotalCounted() || !threeDEval.isSubTotal(i2, i3)) {
                            collectValue(value, true, doubleList);
                        }
                    }
                }
            }
        } else if (valueEval instanceof TwoDEval) {
            TwoDEval twoDEval = (TwoDEval) valueEval;
            int width2 = twoDEval.getWidth();
            int height2 = twoDEval.getHeight();
            for (int i4 = 0; i4 < height2; i4++) {
                for (int i5 = 0; i5 < width2; i5++) {
                    ValueEval value2 = twoDEval.getValue(i4, i5);
                    if (isSubtotalCounted() || !twoDEval.isSubTotal(i4, i5)) {
                        collectValue(value2, true, doubleList);
                    }
                }
            }
        } else if (valueEval instanceof RefEval) {
            RefEval refEval = (RefEval) valueEval;
            for (int firstSheetIndex2 = refEval.getFirstSheetIndex(); firstSheetIndex2 <= refEval.getLastSheetIndex(); firstSheetIndex2++) {
                collectValue(refEval.getInnerValueEval(firstSheetIndex2), true, doubleList);
            }
        } else {
            collectValue(valueEval, false, doubleList);
        }
    }

    public abstract double evaluate(double[] dArr);

    @Override // org.apache.poi.ss.formula.functions.Function
    public final ValueEval evaluate(ValueEval[] valueEvalArr, int i2, int i3) {
        try {
            double evaluate = evaluate(getNumberArray(valueEvalArr));
            if (Double.isNaN(evaluate) || Double.isInfinite(evaluate)) {
                return ErrorEval.NUM_ERROR;
            }
            return new NumberEval(evaluate);
        } catch (EvaluationException e2) {
            return e2.getErrorEval();
        }
    }

    public int getMaxNumOperands() {
        return DEFAULT_MAX_NUM_OPERANDS;
    }

    public final double[] getNumberArray(ValueEval[] valueEvalArr) {
        if (valueEvalArr.length <= getMaxNumOperands()) {
            DoubleList doubleList = new DoubleList();
            for (ValueEval valueEval : valueEvalArr) {
                collectValues(valueEval, doubleList);
            }
            return doubleList.toArray();
        }
        throw EvaluationException.invalidValue();
    }

    public boolean isSubtotalCounted() {
        return true;
    }
}
