package org.apache.poi.ss.formula.functions;

import org.apache.poi.ss.formula.eval.BoolEval;
import org.apache.poi.ss.formula.eval.ErrorEval;
import org.apache.poi.ss.formula.eval.EvaluationException;
import org.apache.poi.ss.formula.eval.NumberEval;
import org.apache.poi.ss.formula.eval.OperandResolver;
import org.apache.poi.ss.formula.eval.ValueEval;

public abstract class NumericFunction implements Function {
    public static final Function ABS = new OneArg() {
        /* class org.apache.poi.ss.formula.functions.NumericFunction.AnonymousClass1 */

        @Override // org.apache.poi.ss.formula.functions.NumericFunction.OneArg
        public double evaluate(double d2) {
            return Math.abs(d2);
        }
    };
    public static final Function ACOS = new OneArg() {
        /* class org.apache.poi.ss.formula.functions.NumericFunction.AnonymousClass2 */

        @Override // org.apache.poi.ss.formula.functions.NumericFunction.OneArg
        public double evaluate(double d2) {
            return Math.acos(d2);
        }
    };
    public static final Function ACOSH = new OneArg() {
        /* class org.apache.poi.ss.formula.functions.NumericFunction.AnonymousClass3 */

        @Override // org.apache.poi.ss.formula.functions.NumericFunction.OneArg
        public double evaluate(double d2) {
            return MathX.acosh(d2);
        }
    };
    public static final Function ASIN = new OneArg() {
        /* class org.apache.poi.ss.formula.functions.NumericFunction.AnonymousClass4 */

        @Override // org.apache.poi.ss.formula.functions.NumericFunction.OneArg
        public double evaluate(double d2) {
            return Math.asin(d2);
        }
    };
    public static final Function ASINH = new OneArg() {
        /* class org.apache.poi.ss.formula.functions.NumericFunction.AnonymousClass5 */

        @Override // org.apache.poi.ss.formula.functions.NumericFunction.OneArg
        public double evaluate(double d2) {
            return MathX.asinh(d2);
        }
    };
    public static final Function ATAN = new OneArg() {
        /* class org.apache.poi.ss.formula.functions.NumericFunction.AnonymousClass6 */

        @Override // org.apache.poi.ss.formula.functions.NumericFunction.OneArg
        public double evaluate(double d2) {
            return Math.atan(d2);
        }
    };
    public static final Function ATAN2 = new TwoArg() {
        /* class org.apache.poi.ss.formula.functions.NumericFunction.AnonymousClass24 */

        @Override // org.apache.poi.ss.formula.functions.NumericFunction.TwoArg
        public double evaluate(double d2, double d3) {
            if (d2 != NumericFunction.LOG_10_TO_BASE_e || d3 != NumericFunction.LOG_10_TO_BASE_e) {
                return Math.atan2(d3, d2);
            }
            throw new EvaluationException(ErrorEval.DIV_ZERO);
        }
    };
    public static final Function ATANH = new OneArg() {
        /* class org.apache.poi.ss.formula.functions.NumericFunction.AnonymousClass7 */

        @Override // org.apache.poi.ss.formula.functions.NumericFunction.OneArg
        public double evaluate(double d2) {
            return MathX.atanh(d2);
        }
    };
    public static final Function CEILING = new TwoArg() {
        /* class org.apache.poi.ss.formula.functions.NumericFunction.AnonymousClass25 */

        @Override // org.apache.poi.ss.formula.functions.NumericFunction.TwoArg
        public double evaluate(double d2, double d3) {
            return MathX.ceiling(d2, d3);
        }
    };
    public static final Function COMBIN = new TwoArg() {
        /* class org.apache.poi.ss.formula.functions.NumericFunction.AnonymousClass26 */

        @Override // org.apache.poi.ss.formula.functions.NumericFunction.TwoArg
        public double evaluate(double d2, double d3) {
            if (d2 <= 2.147483647E9d && d3 <= 2.147483647E9d) {
                return MathX.nChooseK((int) d2, (int) d3);
            }
            throw new EvaluationException(ErrorEval.NUM_ERROR);
        }
    };
    public static final Function COS = new OneArg() {
        /* class org.apache.poi.ss.formula.functions.NumericFunction.AnonymousClass8 */

        @Override // org.apache.poi.ss.formula.functions.NumericFunction.OneArg
        public double evaluate(double d2) {
            return Math.cos(d2);
        }
    };
    public static final Function COSH = new OneArg() {
        /* class org.apache.poi.ss.formula.functions.NumericFunction.AnonymousClass9 */

        @Override // org.apache.poi.ss.formula.functions.NumericFunction.OneArg
        public double evaluate(double d2) {
            return MathX.cosh(d2);
        }
    };
    public static final Function DEGREES = new OneArg() {
        /* class org.apache.poi.ss.formula.functions.NumericFunction.AnonymousClass10 */

        @Override // org.apache.poi.ss.formula.functions.NumericFunction.OneArg
        public double evaluate(double d2) {
            return Math.toDegrees(d2);
        }
    };
    public static final Function DOLLAR = new Var1or2ArgFunction() {
        /* class org.apache.poi.ss.formula.functions.NumericFunction.AnonymousClass11 */

        @Override // org.apache.poi.ss.formula.functions.Function1Arg
        public ValueEval evaluate(int i2, int i3, ValueEval valueEval) {
            return evaluate(i2, i3, valueEval, NumericFunction.DOLLAR_ARG2_DEFAULT);
        }

        @Override // org.apache.poi.ss.formula.functions.Function2Arg
        public ValueEval evaluate(int i2, int i3, ValueEval valueEval, ValueEval valueEval2) {
            try {
                double singleOperandEvaluate = NumericFunction.singleOperandEvaluate(valueEval, i2, i3);
                if (((int) NumericFunction.singleOperandEvaluate(valueEval2, i2, i3)) > 127) {
                    return ErrorEval.VALUE_INVALID;
                }
                return new NumberEval(singleOperandEvaluate);
            } catch (EvaluationException e2) {
                return e2.getErrorEval();
            }
        }
    };
    public static final NumberEval DOLLAR_ARG2_DEFAULT = new NumberEval(2.0d);
    public static final Function EXP = new OneArg() {
        /* class org.apache.poi.ss.formula.functions.NumericFunction.AnonymousClass12 */

        @Override // org.apache.poi.ss.formula.functions.NumericFunction.OneArg
        public double evaluate(double d2) {
            return Math.pow(2.718281828459045d, d2);
        }
    };
    public static final Function FACT = new OneArg() {
        /* class org.apache.poi.ss.formula.functions.NumericFunction.AnonymousClass13 */

        @Override // org.apache.poi.ss.formula.functions.NumericFunction.OneArg
        public double evaluate(double d2) {
            return MathX.factorial((int) d2);
        }
    };
    public static final Function FLOOR = new TwoArg() {
        /* class org.apache.poi.ss.formula.functions.NumericFunction.AnonymousClass27 */

        @Override // org.apache.poi.ss.formula.functions.NumericFunction.TwoArg
        public double evaluate(double d2, double d3) {
            if (d3 != NumericFunction.LOG_10_TO_BASE_e) {
                return MathX.floor(d2, d3);
            }
            if (d2 == NumericFunction.LOG_10_TO_BASE_e) {
                return NumericFunction.LOG_10_TO_BASE_e;
            }
            throw new EvaluationException(ErrorEval.DIV_ZERO);
        }
    };
    public static final Function INT = new OneArg() {
        /* class org.apache.poi.ss.formula.functions.NumericFunction.AnonymousClass14 */

        @Override // org.apache.poi.ss.formula.functions.NumericFunction.OneArg
        public double evaluate(double d2) {
            return (double) Math.round(d2 - 0.5d);
        }
    };
    public static final Function LN = new OneArg() {
        /* class org.apache.poi.ss.formula.functions.NumericFunction.AnonymousClass15 */

        @Override // org.apache.poi.ss.formula.functions.NumericFunction.OneArg
        public double evaluate(double d2) {
            return Math.log(d2);
        }
    };
    public static final Function LOG = new Log();
    public static final Function LOG10 = new OneArg() {
        /* class org.apache.poi.ss.formula.functions.NumericFunction.AnonymousClass16 */

        @Override // org.apache.poi.ss.formula.functions.NumericFunction.OneArg
        public double evaluate(double d2) {
            return Math.log(d2) / NumericFunction.LOG_10_TO_BASE_e;
        }
    };
    public static final double LOG_10_TO_BASE_e = Math.log(10.0d);
    public static final Function MOD = new TwoArg() {
        /* class org.apache.poi.ss.formula.functions.NumericFunction.AnonymousClass28 */

        @Override // org.apache.poi.ss.formula.functions.NumericFunction.TwoArg
        public double evaluate(double d2, double d3) {
            if (d3 != NumericFunction.LOG_10_TO_BASE_e) {
                return MathX.mod(d2, d3);
            }
            throw new EvaluationException(ErrorEval.DIV_ZERO);
        }
    };
    public static final Function PI = new Fixed0ArgFunction() {
        /* class org.apache.poi.ss.formula.functions.NumericFunction.AnonymousClass34 */

        @Override // org.apache.poi.ss.formula.functions.Function0Arg
        public ValueEval evaluate(int i2, int i3) {
            return NumericFunction.PI_EVAL;
        }
    };
    public static final NumberEval PI_EVAL = new NumberEval(3.141592653589793d);
    public static final Function POISSON = new Fixed3ArgFunction() {
        /* class org.apache.poi.ss.formula.functions.NumericFunction.AnonymousClass36 */
        public static final double DEFAULT_RETURN_RESULT = 1.0d;
        public final long[] FACTORIALS = {1, 1, 2, 6, 24, 120, 720, 5040, 40320, 362880, 3628800, 39916800, 479001600, 6227020800L, 87178291200L, 1307674368000L, 20922789888000L, 355687428096000L, 6402373705728000L, 121645100408832000L, 2432902008176640000L};

        private boolean checkArgument(double d2) {
            NumericFunction.checkValue(d2);
            if (d2 >= NumericFunction.LOG_10_TO_BASE_e) {
                return true;
            }
            throw new EvaluationException(ErrorEval.NUM_ERROR);
        }

        private double cumulativeProbability(int i2, double d2) {
            double d3 = NumericFunction.LOG_10_TO_BASE_e;
            for (int i3 = 0; i3 <= i2; i3++) {
                d3 += probability(i3, d2);
            }
            return d3;
        }

        private boolean isDefaultResult(double d2, double d3) {
            return d2 == NumericFunction.LOG_10_TO_BASE_e && d3 == NumericFunction.LOG_10_TO_BASE_e;
        }

        private double probability(int i2, double d2) {
            return (Math.exp(-d2) * Math.pow(d2, (double) i2)) / ((double) factorial(i2));
        }

        @Override // org.apache.poi.ss.formula.functions.Function3Arg
        public ValueEval evaluate(int i2, int i3, ValueEval valueEval, ValueEval valueEval2, ValueEval valueEval3) {
            double d2;
            boolean booleanValue = ((BoolEval) valueEval3).getBooleanValue();
            try {
                double singleOperandEvaluate = NumericFunction.singleOperandEvaluate(valueEval, i2, i3);
                double singleOperandEvaluate2 = NumericFunction.singleOperandEvaluate(valueEval2, i2, i3);
                if (isDefaultResult(singleOperandEvaluate, singleOperandEvaluate2)) {
                    return new NumberEval(1.0d);
                }
                checkArgument(singleOperandEvaluate);
                checkArgument(singleOperandEvaluate2);
                if (booleanValue) {
                    d2 = cumulativeProbability((int) singleOperandEvaluate, singleOperandEvaluate2);
                } else {
                    d2 = probability((int) singleOperandEvaluate, singleOperandEvaluate2);
                }
                NumericFunction.checkValue(d2);
                return new NumberEval(d2);
            } catch (EvaluationException e2) {
                return e2.getErrorEval();
            }
        }

        public long factorial(int i2) {
            if (i2 >= 0 && i2 <= 20) {
                return this.FACTORIALS[i2];
            }
            throw new IllegalArgumentException("Valid argument should be in the range [0..20]");
        }
    };
    public static final Function POWER = new TwoArg() {
        /* class org.apache.poi.ss.formula.functions.NumericFunction.AnonymousClass29 */

        @Override // org.apache.poi.ss.formula.functions.NumericFunction.TwoArg
        public double evaluate(double d2, double d3) {
            return Math.pow(d2, d3);
        }
    };
    public static final Function RADIANS = new OneArg() {
        /* class org.apache.poi.ss.formula.functions.NumericFunction.AnonymousClass17 */

        @Override // org.apache.poi.ss.formula.functions.NumericFunction.OneArg
        public double evaluate(double d2) {
            return Math.toRadians(d2);
        }
    };
    public static final Function RAND = new Fixed0ArgFunction() {
        /* class org.apache.poi.ss.formula.functions.NumericFunction.AnonymousClass35 */

        @Override // org.apache.poi.ss.formula.functions.Function0Arg
        public ValueEval evaluate(int i2, int i3) {
            return new NumberEval(Math.random());
        }
    };
    public static final Function ROUND = new TwoArg() {
        /* class org.apache.poi.ss.formula.functions.NumericFunction.AnonymousClass30 */

        @Override // org.apache.poi.ss.formula.functions.NumericFunction.TwoArg
        public double evaluate(double d2, double d3) {
            return MathX.round(d2, (int) d3);
        }
    };
    public static final Function ROUNDDOWN = new TwoArg() {
        /* class org.apache.poi.ss.formula.functions.NumericFunction.AnonymousClass31 */

        @Override // org.apache.poi.ss.formula.functions.NumericFunction.TwoArg
        public double evaluate(double d2, double d3) {
            return MathX.roundDown(d2, (int) d3);
        }
    };
    public static final Function ROUNDUP = new TwoArg() {
        /* class org.apache.poi.ss.formula.functions.NumericFunction.AnonymousClass32 */

        @Override // org.apache.poi.ss.formula.functions.NumericFunction.TwoArg
        public double evaluate(double d2, double d3) {
            return MathX.roundUp(d2, (int) d3);
        }
    };
    public static final Function SIGN = new OneArg() {
        /* class org.apache.poi.ss.formula.functions.NumericFunction.AnonymousClass18 */

        @Override // org.apache.poi.ss.formula.functions.NumericFunction.OneArg
        public double evaluate(double d2) {
            return (double) MathX.sign(d2);
        }
    };
    public static final Function SIN = new OneArg() {
        /* class org.apache.poi.ss.formula.functions.NumericFunction.AnonymousClass19 */

        @Override // org.apache.poi.ss.formula.functions.NumericFunction.OneArg
        public double evaluate(double d2) {
            return Math.sin(d2);
        }
    };
    public static final Function SINH = new OneArg() {
        /* class org.apache.poi.ss.formula.functions.NumericFunction.AnonymousClass20 */

        @Override // org.apache.poi.ss.formula.functions.NumericFunction.OneArg
        public double evaluate(double d2) {
            return MathX.sinh(d2);
        }
    };
    public static final Function SQRT = new OneArg() {
        /* class org.apache.poi.ss.formula.functions.NumericFunction.AnonymousClass21 */

        @Override // org.apache.poi.ss.formula.functions.NumericFunction.OneArg
        public double evaluate(double d2) {
            return Math.sqrt(d2);
        }
    };
    public static final Function TAN = new OneArg() {
        /* class org.apache.poi.ss.formula.functions.NumericFunction.AnonymousClass22 */

        @Override // org.apache.poi.ss.formula.functions.NumericFunction.OneArg
        public double evaluate(double d2) {
            return Math.tan(d2);
        }
    };
    public static final Function TANH = new OneArg() {
        /* class org.apache.poi.ss.formula.functions.NumericFunction.AnonymousClass23 */

        @Override // org.apache.poi.ss.formula.functions.NumericFunction.OneArg
        public double evaluate(double d2) {
            return MathX.tanh(d2);
        }
    };
    public static final double TEN = 10.0d;
    public static final Function TRUNC = new Var1or2ArgFunction() {
        /* class org.apache.poi.ss.formula.functions.NumericFunction.AnonymousClass33 */

        @Override // org.apache.poi.ss.formula.functions.Function1Arg
        public ValueEval evaluate(int i2, int i3, ValueEval valueEval) {
            return evaluate(i2, i3, valueEval, NumericFunction.TRUNC_ARG2_DEFAULT);
        }

        @Override // org.apache.poi.ss.formula.functions.Function2Arg
        public ValueEval evaluate(int i2, int i3, ValueEval valueEval, ValueEval valueEval2) {
            double floor;
            try {
                double singleOperandEvaluate = NumericFunction.singleOperandEvaluate(valueEval, i2, i3);
                double pow = Math.pow(10.0d, NumericFunction.singleOperandEvaluate(valueEval2, i2, i3));
                if (singleOperandEvaluate < NumericFunction.LOG_10_TO_BASE_e) {
                    floor = -Math.floor((-singleOperandEvaluate) * pow);
                } else {
                    floor = Math.floor(singleOperandEvaluate * pow);
                }
                double d2 = floor / pow;
                NumericFunction.checkValue(d2);
                return new NumberEval(d2);
            } catch (EvaluationException e2) {
                return e2.getErrorEval();
            }
        }
    };
    public static final NumberEval TRUNC_ARG2_DEFAULT = new NumberEval((double) LOG_10_TO_BASE_e);
    public static final double ZERO = 0.0d;

    public static abstract class OneArg extends Fixed1ArgFunction {
        public final double eval(ValueEval[] valueEvalArr, int i2, int i3) {
            if (valueEvalArr.length == 1) {
                return evaluate(NumericFunction.singleOperandEvaluate(valueEvalArr[0], i2, i3));
            }
            throw new EvaluationException(ErrorEval.VALUE_INVALID);
        }

        public abstract double evaluate(double d2);

        @Override // org.apache.poi.ss.formula.functions.Function1Arg
        public ValueEval evaluate(int i2, int i3, ValueEval valueEval) {
            try {
                double evaluate = evaluate(NumericFunction.singleOperandEvaluate(valueEval, i2, i3));
                NumericFunction.checkValue(evaluate);
                return new NumberEval(evaluate);
            } catch (EvaluationException e2) {
                return e2.getErrorEval();
            }
        }
    }

    public static abstract class TwoArg extends Fixed2ArgFunction {
        public abstract double evaluate(double d2, double d3);

        @Override // org.apache.poi.ss.formula.functions.Function2Arg
        public ValueEval evaluate(int i2, int i3, ValueEval valueEval, ValueEval valueEval2) {
            try {
                double evaluate = evaluate(NumericFunction.singleOperandEvaluate(valueEval, i2, i3), NumericFunction.singleOperandEvaluate(valueEval2, i2, i3));
                NumericFunction.checkValue(evaluate);
                return new NumberEval(evaluate);
            } catch (EvaluationException e2) {
                return e2.getErrorEval();
            }
        }
    }

    public static final void checkValue(double d2) {
        if (Double.isNaN(d2) || Double.isInfinite(d2)) {
            throw new EvaluationException(ErrorEval.NUM_ERROR);
        }
    }

    public static final double singleOperandEvaluate(ValueEval valueEval, int i2, int i3) {
        if (valueEval != null) {
            double coerceValueToDouble = OperandResolver.coerceValueToDouble(OperandResolver.getSingleValue(valueEval, i2, i3));
            checkValue(coerceValueToDouble);
            return coerceValueToDouble;
        }
        throw new IllegalArgumentException("arg must not be null");
    }

    public abstract double eval(ValueEval[] valueEvalArr, int i2, int i3);

    @Override // org.apache.poi.ss.formula.functions.Function
    public final ValueEval evaluate(ValueEval[] valueEvalArr, int i2, int i3) {
        try {
            double eval = eval(valueEvalArr, i2, i3);
            checkValue(eval);
            return new NumberEval(eval);
        } catch (EvaluationException e2) {
            return e2.getErrorEval();
        }
    }

    public static final class Log extends Var1or2ArgFunction {
        @Override // org.apache.poi.ss.formula.functions.Function1Arg
        public ValueEval evaluate(int i2, int i3, ValueEval valueEval) {
            try {
                double log = Math.log(NumericFunction.singleOperandEvaluate(valueEval, i2, i3)) / NumericFunction.LOG_10_TO_BASE_e;
                NumericFunction.checkValue(log);
                return new NumberEval(log);
            } catch (EvaluationException e2) {
                return e2.getErrorEval();
            }
        }

        @Override // org.apache.poi.ss.formula.functions.Function2Arg
        public ValueEval evaluate(int i2, int i3, ValueEval valueEval, ValueEval valueEval2) {
            try {
                double singleOperandEvaluate = NumericFunction.singleOperandEvaluate(valueEval, i2, i3);
                double singleOperandEvaluate2 = NumericFunction.singleOperandEvaluate(valueEval2, i2, i3);
                double log = Math.log(singleOperandEvaluate);
                if (Double.compare(singleOperandEvaluate2, 2.718281828459045d) != 0) {
                    log /= Math.log(singleOperandEvaluate2);
                }
                NumericFunction.checkValue(log);
                return new NumberEval(log);
            } catch (EvaluationException e2) {
                return e2.getErrorEval();
            }
        }
    }
}
