package org.apache.poi.ss.formula.functions;

import java.util.Iterator;
import org.apache.poi.ss.formula.eval.AreaEval;
import org.apache.poi.ss.formula.eval.ErrorEval;
import org.apache.poi.ss.formula.eval.EvaluationException;
import org.apache.poi.ss.formula.eval.NumberEval;
import org.apache.poi.ss.formula.eval.OperandResolver;
import org.apache.poi.ss.formula.eval.RefEval;
import org.apache.poi.ss.formula.eval.RefListEval;
import org.apache.poi.ss.formula.eval.ValueEval;

public class Rank extends Var2or3ArgFunction {
    public static AreaEval convertRangeArg(ValueEval valueEval) {
        if (valueEval instanceof AreaEval) {
            return (AreaEval) valueEval;
        }
        if (valueEval instanceof RefEval) {
            return ((RefEval) valueEval).offset(0, 0, 0, 0);
        }
        throw new EvaluationException(ErrorEval.VALUE_INVALID);
    }

    public static ValueEval eval(double d2, AreaEval areaEval, boolean z) {
        int height = areaEval.getHeight();
        int width = areaEval.getWidth();
        int i2 = 1;
        for (int i3 = 0; i3 < height; i3++) {
            for (int i4 = 0; i4 < width; i4++) {
                Double value = getValue(areaEval, i3, i4);
                if (value != null && ((z && value.doubleValue() > d2) || (!z && value.doubleValue() < d2))) {
                    i2++;
                }
            }
        }
        return new NumberEval((double) i2);
    }

    public static Double getValue(AreaEval areaEval, int i2, int i3) {
        ValueEval relativeValue = areaEval.getRelativeValue(i2, i3);
        if (relativeValue instanceof NumberEval) {
            return Double.valueOf(((NumberEval) relativeValue).getNumberValue());
        }
        return null;
    }

    @Override // org.apache.poi.ss.formula.functions.Function2Arg
    public ValueEval evaluate(int i2, int i3, ValueEval valueEval, ValueEval valueEval2) {
        try {
            double coerceValueToDouble = OperandResolver.coerceValueToDouble(OperandResolver.getSingleValue(valueEval, i2, i3));
            if (Double.isNaN(coerceValueToDouble) || Double.isInfinite(coerceValueToDouble)) {
                throw new EvaluationException(ErrorEval.NUM_ERROR);
            } else if (valueEval2 instanceof RefListEval) {
                return eval(coerceValueToDouble, (RefListEval) valueEval2, true);
            } else {
                return eval(coerceValueToDouble, convertRangeArg(valueEval2), true);
            }
        } catch (EvaluationException e2) {
            return e2.getErrorEval();
        }
    }

    public static ValueEval eval(double d2, RefListEval refListEval, boolean z) {
        Iterator<ValueEval> it = refListEval.getList().iterator();
        int i2 = 1;
        while (it.hasNext()) {
            ValueEval next = it.next();
            if (next instanceof RefEval) {
                RefEval refEval = (RefEval) next;
                next = refEval.getInnerValueEval(refEval.getFirstSheetIndex());
            }
            if (next instanceof NumberEval) {
                Double valueOf = Double.valueOf(((NumberEval) next).getNumberValue());
                if ((z && valueOf.doubleValue() > d2) || (!z && valueOf.doubleValue() < d2)) {
                    i2++;
                }
            }
        }
        return new NumberEval((double) i2);
    }

    @Override // org.apache.poi.ss.formula.functions.Function3Arg
    public ValueEval evaluate(int i2, int i3, ValueEval valueEval, ValueEval valueEval2, ValueEval valueEval3) {
        try {
            double coerceValueToDouble = OperandResolver.coerceValueToDouble(OperandResolver.getSingleValue(valueEval, i2, i3));
            if (Double.isNaN(coerceValueToDouble) || Double.isInfinite(coerceValueToDouble)) {
                throw new EvaluationException(ErrorEval.NUM_ERROR);
            }
            int coerceValueToInt = OperandResolver.coerceValueToInt(OperandResolver.getSingleValue(valueEval3, i2, i3));
            boolean z = true;
            if (coerceValueToInt != 0) {
                if (coerceValueToInt == 1) {
                    z = false;
                } else {
                    throw new EvaluationException(ErrorEval.NUM_ERROR);
                }
            }
            if (valueEval2 instanceof RefListEval) {
                return eval(coerceValueToDouble, (RefListEval) valueEval2, z);
            }
            return eval(coerceValueToDouble, convertRangeArg(valueEval2), z);
        } catch (EvaluationException e2) {
            return e2.getErrorEval();
        }
    }
}
