package org.apache.poi.ss.formula.functions;

import org.apache.poi.ss.formula.eval.ErrorEval;
import org.apache.poi.ss.formula.eval.EvaluationException;
import org.apache.poi.ss.formula.eval.NumberEval;
import org.apache.poi.ss.formula.eval.OperandResolver;
import org.apache.poi.ss.formula.eval.ValueEval;
import org.apache.poi.util.POILogFactory;
import org.apache.poi.util.POILogger;

public class Rate implements Function {
    public static final POILogger LOG = POILogFactory.getLogger(Rate.class);

    private double calculateRate(double d2, double d3, double d4, double d5, double d6, double d7) {
        double d8;
        double d9;
        double abs = Math.abs(d7);
        double d10 = NumericFunction.LOG_10_TO_BASE_e;
        if (abs < 1.0E-7d) {
            d8 = 0.0d;
        } else {
            d8 = Math.exp(Math.log(d7 + 1.0d) * d2);
        }
        double d11 = ((d8 - 1.0d) * ((1.0d / d7) + d6) * d3) + (d4 * d8) + d5;
        double d12 = (d3 * d2) + d4 + d5;
        double d13 = d7;
        double d14 = 0.0d;
        while (Math.abs(d12 - d11) > 1.0E-7d && d10 < ((double) 20)) {
            double d15 = ((d14 * d11) - (d12 * d13)) / (d11 - d12);
            if (Math.abs(d15) < 1.0E-7d) {
                d9 = (((d15 * d6) + 1.0d) * d3 * d2) + (((d2 * d15) + 1.0d) * d4) + d5;
            } else {
                double exp = Math.exp(Math.log(d15 + 1.0d) * d2);
                d9 = ((exp - 1.0d) * ((1.0d / d15) + d6) * d3) + (d4 * exp) + d5;
            }
            d10 += 1.0d;
            d12 = d11;
            d11 = d9;
            d13 = d15;
            d14 = d13;
        }
        return d13;
    }

    public static final void checkValue(double d2) {
        if (Double.isNaN(d2) || Double.isInfinite(d2)) {
            throw new EvaluationException(ErrorEval.NUM_ERROR);
        }
    }

    @Override // org.apache.poi.ss.formula.functions.Function
    public ValueEval evaluate(ValueEval[] valueEvalArr, int i2, int i3) {
        if (valueEvalArr.length < 3) {
            return ErrorEval.VALUE_INVALID;
        }
        try {
            ValueEval singleValue = OperandResolver.getSingleValue(valueEvalArr[0], i2, i3);
            ValueEval singleValue2 = OperandResolver.getSingleValue(valueEvalArr[1], i2, i3);
            ValueEval singleValue3 = OperandResolver.getSingleValue(valueEvalArr[2], i2, i3);
            ValueEval valueEval = null;
            ValueEval singleValue4 = valueEvalArr.length >= 4 ? OperandResolver.getSingleValue(valueEvalArr[3], i2, i3) : null;
            ValueEval singleValue5 = valueEvalArr.length >= 5 ? OperandResolver.getSingleValue(valueEvalArr[4], i2, i3) : null;
            if (valueEvalArr.length >= 6) {
                valueEval = OperandResolver.getSingleValue(valueEvalArr[5], i2, i3);
            }
            double calculateRate = calculateRate(OperandResolver.coerceValueToDouble(singleValue), OperandResolver.coerceValueToDouble(singleValue2), OperandResolver.coerceValueToDouble(singleValue3), valueEvalArr.length >= 4 ? OperandResolver.coerceValueToDouble(singleValue4) : 0.0d, valueEvalArr.length >= 5 ? OperandResolver.coerceValueToDouble(singleValue5) : 0.0d, valueEvalArr.length >= 6 ? OperandResolver.coerceValueToDouble(valueEval) : 0.1d);
            checkValue(calculateRate);
            return new NumberEval(calculateRate);
        } catch (EvaluationException e2) {
            LOG.log(7, "Can't evaluate rate function", e2);
            return e2.getErrorEval();
        }
    }
}
