package org.apache.poi.ss.formula.functions;

import org.apache.poi.ss.formula.eval.ErrorEval;
import org.apache.poi.ss.formula.eval.EvaluationException;
import org.apache.poi.ss.formula.eval.OperandResolver;
import org.apache.poi.ss.formula.eval.StringEval;
import org.apache.poi.ss.formula.eval.ValueEval;
import org.apache.xerces.impl.xs.SchemaSymbols;
import org.apache.xmlbeans.impl.piccolo.xml.Piccolo;

public class Roman extends Fixed2ArgFunction {
    public static final String[] ROMAN = {"M", "CM", "D", "CD", "C", "XC", "L", "XL", "X", "IX", "V", "IV", "I"};
    public static final int[] VALUES = {1000, 900, Piccolo.YYSTACKSIZE, 400, 100, 90, 50, 40, 10, 9, 5, 4, 1};

    private String integerToRoman(int i2) {
        StringBuilder sb = new StringBuilder();
        for (int i3 = 0; i3 < 13; i3++) {
            while (true) {
                int[] iArr = VALUES;
                if (i2 < iArr[i3]) {
                    break;
                }
                i2 -= iArr[i3];
                sb.append(ROMAN[i3]);
            }
        }
        return sb.toString();
    }

    @Override // org.apache.poi.ss.formula.functions.Function2Arg
    public ValueEval evaluate(int i2, int i3, ValueEval valueEval, ValueEval valueEval2) {
        try {
            int coerceValueToInt = OperandResolver.coerceValueToInt(OperandResolver.getSingleValue(valueEval, i2, i3));
            if (coerceValueToInt < 0) {
                return ErrorEval.VALUE_INVALID;
            }
            if (coerceValueToInt > 3999) {
                return ErrorEval.VALUE_INVALID;
            }
            if (coerceValueToInt == 0) {
                return new StringEval("");
            }
            try {
                int coerceValueToInt2 = OperandResolver.coerceValueToInt(OperandResolver.getSingleValue(valueEval2, i2, i3));
                if (coerceValueToInt2 > 4 || coerceValueToInt2 < 0) {
                    return ErrorEval.VALUE_INVALID;
                }
                String integerToRoman = integerToRoman(coerceValueToInt);
                if (coerceValueToInt2 == 0) {
                    return new StringEval(integerToRoman);
                }
                return new StringEval(makeConcise(integerToRoman, coerceValueToInt2));
            } catch (EvaluationException unused) {
                return ErrorEval.NUM_ERROR;
            }
        } catch (EvaluationException unused2) {
            return ErrorEval.VALUE_INVALID;
        }
    }

    public String makeConcise(String str, int i2) {
        if (i2 > 0) {
            str = str.replaceAll("XLV", "VL").replaceAll("XCV", "VC").replaceAll("CDL", "LD").replaceAll("CML", "LM").replaceAll("CMVC", "LMVL");
        }
        if (i2 == 1) {
            str = str.replaceAll("CDXC", "LDXL").replaceAll("CDVC", "LDVL").replaceAll("CMXC", "LMXL").replaceAll("XCIX", "VCIV").replaceAll("XLIX", "VLIV");
        }
        if (i2 > 1) {
            str = str.replaceAll("XLIX", "IL").replaceAll("XCIX", "IC").replaceAll("CDXC", "XD").replaceAll("CDVC", "XDV").replaceAll("CDIC", "XDIX").replaceAll("LMVL", "XMV").replaceAll("CMIC", "XMIX").replaceAll("CMXC", "XM");
        }
        if (i2 > 2) {
            str = str.replaceAll("XDV", "VD").replaceAll("XDIX", "VDIV").replaceAll("XMV", "VM").replaceAll("XMIX", "VMIV");
        }
        return i2 == 4 ? str.replaceAll("VDIV", SchemaSymbols.ATTVAL_ID).replaceAll("VMIV", "IM") : str;
    }
}
