package org.apache.poi.ss.formula.functions;

import java.util.Arrays;

public final class StatsLib {
    public static double avedev(double[] dArr) {
        double d2 = NumericFunction.LOG_10_TO_BASE_e;
        double d3 = 0.0d;
        for (double d4 : dArr) {
            d3 += d4;
        }
        double length = d3 / ((double) dArr.length);
        for (double d5 : dArr) {
            d2 += Math.abs(d5 - length);
        }
        return d2 / ((double) dArr.length);
    }

    public static double devsq(double[] dArr) {
        if (dArr == null || dArr.length < 1) {
            return Double.NaN;
        }
        int length = dArr.length;
        double d2 = 0.0d;
        for (double d3 : dArr) {
            d2 += d3;
        }
        double d4 = d2 / ((double) length);
        double d5 = 0.0d;
        for (int i2 = 0; i2 < length; i2++) {
            d5 += (dArr[i2] - d4) * (dArr[i2] - d4);
        }
        if (length == 1) {
            return NumericFunction.LOG_10_TO_BASE_e;
        }
        return d5;
    }

    public static double kthLargest(double[] dArr, int i2) {
        int i3 = i2 - 1;
        if (dArr == null || dArr.length <= i3 || i3 < 0) {
            return Double.NaN;
        }
        Arrays.sort(dArr);
        return dArr[(dArr.length - i3) - 1];
    }

    public static double kthSmallest(double[] dArr, int i2) {
        int i3 = i2 - 1;
        if (dArr == null || dArr.length <= i3 || i3 < 0) {
            return Double.NaN;
        }
        Arrays.sort(dArr);
        return dArr[i3];
    }

    public static double median(double[] dArr) {
        if (dArr == null || dArr.length < 1) {
            return Double.NaN;
        }
        int length = dArr.length;
        Arrays.sort(dArr);
        int i2 = length % 2;
        int i3 = length / 2;
        return i2 == 0 ? (dArr[i3] + dArr[i3 - 1]) / 2.0d : dArr[i3];
    }

    public static double stdev(double[] dArr) {
        if (dArr == null || dArr.length <= 1) {
            return Double.NaN;
        }
        return Math.sqrt(devsq(dArr) / ((double) (dArr.length - 1)));
    }

    public static double var(double[] dArr) {
        if (dArr == null || dArr.length <= 1) {
            return Double.NaN;
        }
        return devsq(dArr) / ((double) (dArr.length - 1));
    }

    public static double varp(double[] dArr) {
        if (dArr == null || dArr.length <= 1) {
            return Double.NaN;
        }
        return devsq(dArr) / ((double) dArr.length);
    }
}
