package org.apache.poi.ss.formula.functions;

import b.b.a.a.a;
import org.apache.poi.ss.formula.TwoDEval;
import org.apache.poi.ss.formula.eval.AreaEval;
import org.apache.poi.ss.formula.eval.BlankEval;
import org.apache.poi.ss.formula.eval.ErrorEval;
import org.apache.poi.ss.formula.eval.EvaluationException;
import org.apache.poi.ss.formula.eval.NumberEval;
import org.apache.poi.ss.formula.eval.NumericValueEval;
import org.apache.poi.ss.formula.eval.RefEval;
import org.apache.poi.ss.formula.eval.StringEval;
import org.apache.poi.ss.formula.eval.ValueEval;

public final class Sumproduct implements Function {
    public static boolean areasAllSameSize(TwoDEval[] twoDEvalArr, int i2, int i3) {
        for (TwoDEval twoDEval : twoDEvalArr) {
            if (!(twoDEval.getHeight() == i2 && twoDEval.getWidth() == i3)) {
                return false;
            }
        }
        return true;
    }

    public static ValueEval evaluateAreaSumProduct(ValueEval[] valueEvalArr) {
        int length = valueEvalArr.length;
        TwoDEval[] twoDEvalArr = new TwoDEval[length];
        try {
            System.arraycopy(valueEvalArr, 0, twoDEvalArr, 0, length);
            TwoDEval twoDEval = twoDEvalArr[0];
            int height = twoDEval.getHeight();
            int width = twoDEval.getWidth();
            if (!areasAllSameSize(twoDEvalArr, height, width)) {
                for (int i2 = 1; i2 < length; i2++) {
                    throwFirstError(twoDEvalArr[i2]);
                }
                return ErrorEval.VALUE_INVALID;
            }
            double d2 = NumericFunction.LOG_10_TO_BASE_e;
            for (int i3 = 0; i3 < height; i3++) {
                for (int i4 = 0; i4 < width; i4++) {
                    double d3 = 1.0d;
                    for (int i5 = 0; i5 < length; i5++) {
                        d3 *= getProductTerm(twoDEvalArr[i5].getValue(i3, i4), false);
                    }
                    d2 += d3;
                }
            }
            return new NumberEval(d2);
        } catch (ArrayStoreException unused) {
            return ErrorEval.VALUE_INVALID;
        }
    }

    public static ValueEval evaluateSingleProduct(ValueEval[] valueEvalArr) {
        double d2 = 1.0d;
        for (ValueEval valueEval : valueEvalArr) {
            d2 *= getScalarValue(valueEval);
        }
        return new NumberEval(d2);
    }

    public static double getProductTerm(ValueEval valueEval, boolean z) {
        if ((valueEval instanceof BlankEval) || valueEval == null) {
            if (!z) {
                return NumericFunction.LOG_10_TO_BASE_e;
            }
            throw new EvaluationException(ErrorEval.VALUE_INVALID);
        } else if (valueEval instanceof ErrorEval) {
            throw new EvaluationException((ErrorEval) valueEval);
        } else if (valueEval instanceof StringEval) {
            if (!z) {
                return NumericFunction.LOG_10_TO_BASE_e;
            }
            throw new EvaluationException(ErrorEval.VALUE_INVALID);
        } else if (valueEval instanceof NumericValueEval) {
            return ((NumericValueEval) valueEval).getNumberValue();
        } else {
            StringBuilder b2 = a.b("Unexpected value eval class (");
            b2.append(valueEval.getClass().getName());
            b2.append(")");
            throw new RuntimeException(b2.toString());
        }
    }

    public static double getScalarValue(ValueEval valueEval) {
        if (valueEval instanceof RefEval) {
            RefEval refEval = (RefEval) valueEval;
            if (refEval.getNumberOfSheets() <= 1) {
                valueEval = refEval.getInnerValueEval(refEval.getFirstSheetIndex());
            } else {
                throw new EvaluationException(ErrorEval.VALUE_INVALID);
            }
        }
        if (valueEval != null) {
            if (valueEval instanceof AreaEval) {
                AreaEval areaEval = (AreaEval) valueEval;
                if (!areaEval.isColumn() || !areaEval.isRow()) {
                    throw new EvaluationException(ErrorEval.VALUE_INVALID);
                }
                valueEval = areaEval.getRelativeValue(0, 0);
            }
            return getProductTerm(valueEval, true);
        }
        throw new RuntimeException("parameter may not be null");
    }

    public static void throwFirstError(TwoDEval twoDEval) {
        int height = twoDEval.getHeight();
        int width = twoDEval.getWidth();
        for (int i2 = 0; i2 < height; i2++) {
            for (int i3 = 0; i3 < width; i3++) {
                ValueEval value = twoDEval.getValue(i2, i3);
                if (value instanceof ErrorEval) {
                    throw new EvaluationException((ErrorEval) value);
                }
            }
        }
    }

    @Override // org.apache.poi.ss.formula.functions.Function
    public ValueEval evaluate(ValueEval[] valueEvalArr, int i2, int i3) {
        if (valueEvalArr.length < 1) {
            return ErrorEval.VALUE_INVALID;
        }
        ValueEval valueEval = valueEvalArr[0];
        try {
            if (valueEval instanceof NumericValueEval) {
                return evaluateSingleProduct(valueEvalArr);
            }
            if (valueEval instanceof RefEval) {
                return evaluateSingleProduct(valueEvalArr);
            }
            if (valueEval instanceof TwoDEval) {
                TwoDEval twoDEval = (TwoDEval) valueEval;
                if (!twoDEval.isRow() || !twoDEval.isColumn()) {
                    return evaluateAreaSumProduct(valueEvalArr);
                }
                return evaluateSingleProduct(valueEvalArr);
            }
            StringBuilder b2 = a.b("Invalid arg type for SUMPRODUCT: (");
            b2.append(valueEval.getClass().getName());
            b2.append(")");
            throw new RuntimeException(b2.toString());
        } catch (EvaluationException e2) {
            return e2.getErrorEval();
        }
    }
}
