package org.apache.poi.ss.formula.functions;

import org.apache.poi.ss.formula.eval.ErrorEval;
import org.apache.poi.ss.formula.eval.EvaluationException;
import org.apache.poi.ss.formula.eval.MissingArgEval;
import org.apache.poi.ss.formula.eval.NumberEval;
import org.apache.poi.ss.formula.eval.OperandResolver;
import org.apache.poi.ss.formula.eval.ValueEval;

public final class TimeFunc extends Fixed3ArgFunction {
    public static final int HOURS_PER_DAY = 24;
    public static final int SECONDS_PER_DAY = 86400;
    public static final int SECONDS_PER_HOUR = 3600;
    public static final int SECONDS_PER_MINUTE = 60;

    public static int evalArg(ValueEval valueEval, int i2, int i3) {
        if (valueEval == MissingArgEval.instance) {
            return 0;
        }
        return OperandResolver.coerceValueToInt(OperandResolver.getSingleValue(valueEval, i2, i3));
    }

    @Override // org.apache.poi.ss.formula.functions.Function3Arg
    public ValueEval evaluate(int i2, int i3, ValueEval valueEval, ValueEval valueEval2, ValueEval valueEval3) {
        try {
            return new NumberEval(evaluate(evalArg(valueEval, i2, i3), evalArg(valueEval2, i2, i3), evalArg(valueEval3, i2, i3)));
        } catch (EvaluationException e2) {
            return e2.getErrorEval();
        }
    }

    public static double evaluate(int i2, int i3, int i4) {
        if (i2 > 32767 || i3 > 32767 || i4 > 32767) {
            throw new EvaluationException(ErrorEval.VALUE_INVALID);
        }
        int i5 = (i3 * 60) + (i2 * SECONDS_PER_HOUR) + i4;
        if (i5 >= 0) {
            return ((double) (i5 % 86400)) / 86400.0d;
        }
        throw new EvaluationException(ErrorEval.VALUE_INVALID);
    }
}
