package org.apache.poi.ss.formula.functions;

import org.apache.poi.ss.formula.TwoDEval;
import org.apache.poi.ss.formula.eval.BoolEval;
import org.apache.poi.ss.formula.eval.EvaluationException;
import org.apache.poi.ss.formula.eval.OperandResolver;
import org.apache.poi.ss.formula.eval.ValueEval;
import org.apache.poi.ss.formula.functions.LookupUtils;

public final class Vlookup extends Var3or4ArgFunction {
    public static final ValueEval DEFAULT_ARG3 = BoolEval.TRUE;

    private LookupUtils.ValueVector createResultColumnVector(TwoDEval twoDEval, int i2) {
        if (i2 < twoDEval.getWidth()) {
            return LookupUtils.createColumnVector(twoDEval, i2);
        }
        throw EvaluationException.invalidRef();
    }

    @Override // org.apache.poi.ss.formula.functions.Function3Arg
    public ValueEval evaluate(int i2, int i3, ValueEval valueEval, ValueEval valueEval2, ValueEval valueEval3) {
        return evaluate(i2, i3, valueEval, valueEval2, valueEval3, DEFAULT_ARG3);
    }

    @Override // org.apache.poi.ss.formula.functions.Function4Arg
    public ValueEval evaluate(int i2, int i3, ValueEval valueEval, ValueEval valueEval2, ValueEval valueEval3, ValueEval valueEval4) {
        try {
            ValueEval singleValue = OperandResolver.getSingleValue(valueEval, i2, i3);
            TwoDEval resolveTableArrayArg = LookupUtils.resolveTableArrayArg(valueEval2);
            return createResultColumnVector(resolveTableArrayArg, LookupUtils.resolveRowOrColIndexArg(valueEval3, i2, i3)).getItem(LookupUtils.lookupIndexOfValue(singleValue, LookupUtils.createColumnVector(resolveTableArrayArg, 0), LookupUtils.resolveRangeLookupArg(valueEval4, i2, i3)));
        } catch (EvaluationException e2) {
            return e2.getErrorEval();
        }
    }
}
