package org.apache.poi.ss.formula.functions;

import b.b.a.a.a;
import org.apache.poi.ss.formula.TwoDEval;
import org.apache.poi.ss.formula.eval.ErrorEval;
import org.apache.poi.ss.formula.eval.EvaluationException;
import org.apache.poi.ss.formula.eval.NumberEval;
import org.apache.poi.ss.formula.eval.RefEval;
import org.apache.poi.ss.formula.eval.ValueEval;
import org.apache.poi.ss.formula.functions.LookupUtils;

public abstract class XYNumericFunction extends Fixed2ArgFunction {

    public interface Accumulator {
        double accumulate(double d2, double d3);
    }

    public static final class AreaValueArray extends ValueArray {
        public final TwoDEval _ae;
        public final int _width;

        public AreaValueArray(TwoDEval twoDEval) {
            super(twoDEval.getHeight() * twoDEval.getWidth());
            this._ae = twoDEval;
            this._width = twoDEval.getWidth();
        }

        @Override // org.apache.poi.ss.formula.functions.XYNumericFunction.ValueArray
        public ValueEval getItemInternal(int i2) {
            int i3 = this._width;
            return this._ae.getValue(i2 / i3, i2 % i3);
        }
    }

    public static final class RefValueArray extends ValueArray {
        public final RefEval _ref;
        public final int _width;

        public RefValueArray(RefEval refEval) {
            super(refEval.getNumberOfSheets());
            this._ref = refEval;
            this._width = refEval.getNumberOfSheets();
        }

        @Override // org.apache.poi.ss.formula.functions.XYNumericFunction.ValueArray
        public ValueEval getItemInternal(int i2) {
            return this._ref.getInnerValueEval(this._ref.getFirstSheetIndex() + (i2 % this._width));
        }
    }

    public static final class SingleCellValueArray extends ValueArray {
        public final ValueEval _value;

        public SingleCellValueArray(ValueEval valueEval) {
            super(1);
            this._value = valueEval;
        }

        @Override // org.apache.poi.ss.formula.functions.XYNumericFunction.ValueArray
        public ValueEval getItemInternal(int i2) {
            return this._value;
        }
    }

    public static abstract class ValueArray implements LookupUtils.ValueVector {
        public final int _size;

        public ValueArray(int i2) {
            this._size = i2;
        }

        @Override // org.apache.poi.ss.formula.functions.LookupUtils.ValueVector
        public ValueEval getItem(int i2) {
            if (i2 >= 0 && i2 <= this._size) {
                return getItemInternal(i2);
            }
            StringBuilder a = a.a("Specified index ", i2, " is outside range (0..");
            a.append(this._size - 1);
            a.append(")");
            throw new IllegalArgumentException(a.toString());
        }

        public abstract ValueEval getItemInternal(int i2);

        @Override // org.apache.poi.ss.formula.functions.LookupUtils.ValueVector
        public final int getSize() {
            return this._size;
        }
    }

    public static LookupUtils.ValueVector createValueVector(ValueEval valueEval) {
        if (valueEval instanceof ErrorEval) {
            throw new EvaluationException((ErrorEval) valueEval);
        } else if (valueEval instanceof TwoDEval) {
            return new AreaValueArray((TwoDEval) valueEval);
        } else {
            if (valueEval instanceof RefEval) {
                return new RefValueArray((RefEval) valueEval);
            }
            return new SingleCellValueArray(valueEval);
        }
    }

    private double evaluateInternal(LookupUtils.ValueVector valueVector, LookupUtils.ValueVector valueVector2, int i2) {
        Accumulator createAccumulator = createAccumulator();
        double d2 = 0.0d;
        ErrorEval errorEval = null;
        ErrorEval errorEval2 = null;
        boolean z = false;
        for (int i3 = 0; i3 < i2; i3++) {
            ValueEval item = valueVector.getItem(i3);
            ValueEval item2 = valueVector2.getItem(i3);
            if ((item instanceof ErrorEval) && errorEval == null) {
                errorEval = (ErrorEval) item;
            } else if ((item2 instanceof ErrorEval) && errorEval2 == null) {
                errorEval2 = (ErrorEval) item2;
            } else if ((item instanceof NumberEval) && (item2 instanceof NumberEval)) {
                z = true;
                d2 = createAccumulator.accumulate(((NumberEval) item).getNumberValue(), ((NumberEval) item2).getNumberValue()) + d2;
            }
        }
        if (errorEval != null) {
            throw new EvaluationException(errorEval);
        } else if (errorEval2 != null) {
            throw new EvaluationException(errorEval2);
        } else if (z) {
            return d2;
        } else {
            throw new EvaluationException(ErrorEval.DIV_ZERO);
        }
    }

    public abstract Accumulator createAccumulator();

    @Override // org.apache.poi.ss.formula.functions.Function2Arg
    public ValueEval evaluate(int i2, int i3, ValueEval valueEval, ValueEval valueEval2) {
        try {
            LookupUtils.ValueVector createValueVector = createValueVector(valueEval);
            LookupUtils.ValueVector createValueVector2 = createValueVector(valueEval2);
            int size = createValueVector.getSize();
            if (size != 0) {
                if (createValueVector2.getSize() == size) {
                    double evaluateInternal = evaluateInternal(createValueVector, createValueVector2, size);
                    if (Double.isNaN(evaluateInternal) || Double.isInfinite(evaluateInternal)) {
                        return ErrorEval.NUM_ERROR;
                    }
                    return new NumberEval(evaluateInternal);
                }
            }
            return ErrorEval.NA;
        } catch (EvaluationException e2) {
            return e2.getErrorEval();
        }
    }
}
