package org.apache.poi.ss.formula.ptg;

import b.b.a.a.a;
import java.util.Locale;
import org.apache.poi.ss.formula.function.FunctionMetadata;
import org.apache.poi.ss.formula.function.FunctionMetadataRegistry;

public abstract class AbstractFunctionPtg extends OperationPtg {
    public static final short FUNCTION_INDEX_EXTERNAL = 255;
    public static final String FUNCTION_NAME_IF = "IF";
    public final short _functionIndex;
    public final int _numberOfArgs;
    public final byte[] paramClass;
    public final byte returnClass;

    public AbstractFunctionPtg(int i2, int i3, byte[] bArr, int i4) {
        this._numberOfArgs = i4;
        if (i2 < -32768 || i2 > 32767) {
            throw new RuntimeException(a.b("functionIndex ", i2, " cannot be cast to short"));
        }
        this._functionIndex = (short) i2;
        if (i3 < -128 || i3 > 127) {
            throw new RuntimeException(a.b("pReturnClass ", i3, " cannot be cast to byte"));
        }
        this.returnClass = (byte) i3;
        this.paramClass = bArr;
    }

    public static void appendArgs(StringBuilder sb, int i2, String[] strArr) {
        sb.append('(');
        for (int i3 = i2; i3 < strArr.length; i3++) {
            if (i3 > i2) {
                sb.append(',');
            }
            sb.append(strArr[i3]);
        }
        sb.append(")");
    }

    public static final boolean isBuiltInFunctionName(String str) {
        return FunctionMetadataRegistry.lookupIndexByName(str.toUpperCase(Locale.ROOT)) >= 0;
    }

    public static short lookupIndex(String str) {
        short lookupIndexByName = FunctionMetadataRegistry.lookupIndexByName(str.toUpperCase(Locale.ROOT));
        if (lookupIndexByName < 0) {
            return 255;
        }
        return lookupIndexByName;
    }

    @Override // org.apache.poi.ss.formula.ptg.Ptg, org.apache.poi.ss.formula.ptg.OperationPtg
    public byte getDefaultOperandClass() {
        return this.returnClass;
    }

    public final short getFunctionIndex() {
        return this._functionIndex;
    }

    public final String getName() {
        return lookupName(this._functionIndex);
    }

    @Override // org.apache.poi.ss.formula.ptg.OperationPtg
    public final int getNumberOfOperands() {
        return this._numberOfArgs;
    }

    public final byte getParameterClass(int i2) {
        byte[] bArr = this.paramClass;
        if (i2 >= bArr.length) {
            return bArr[bArr.length - 1];
        }
        return bArr[i2];
    }

    @Override // org.apache.poi.ss.formula.ptg.Ptg
    public abstract int getSize();

    @Override // org.apache.poi.ss.formula.ptg.Ptg
    public final boolean isBaseToken() {
        return false;
    }

    public final boolean isExternalFunction() {
        return this._functionIndex == 255;
    }

    public final String lookupName(short s) {
        if (s == 255) {
            return "#external#";
        }
        FunctionMetadata functionByIndex = FunctionMetadataRegistry.getFunctionByIndex(s);
        if (functionByIndex != null) {
            return functionByIndex.getName();
        }
        throw new RuntimeException(a.b("bad function index (", s, ")"));
    }

    @Override // org.apache.poi.ss.formula.ptg.Ptg
    public final String toFormulaString() {
        return getName();
    }

    @Override // org.apache.poi.ss.formula.ptg.Ptg
    public final String toString() {
        StringBuilder sb = new StringBuilder(64);
        sb.append(getClass().getName());
        sb.append(" [");
        sb.append(lookupName(this._functionIndex));
        sb.append(" nArgs=");
        return a.a(sb, this._numberOfArgs, "]");
    }

    @Override // org.apache.poi.ss.formula.ptg.OperationPtg
    public String toFormulaString(String[] strArr) {
        StringBuilder sb = new StringBuilder();
        if (isExternalFunction()) {
            sb.append(strArr[0]);
            appendArgs(sb, 1, strArr);
        } else {
            sb.append(getName());
            appendArgs(sb, 0, strArr);
        }
        return sb.toString();
    }
}
