package org.apache.poi.ss.formula.ptg;

import b.b.a.a.a;
import java.lang.reflect.Array;
import org.apache.poi.ss.formula.constant.ConstantValueParser;
import org.apache.poi.ss.formula.constant.ErrorConstant;
import org.apache.poi.ss.util.NumberToTextConverter;
import org.apache.poi.util.LittleEndianInput;
import org.apache.poi.util.LittleEndianOutput;
import org.apache.poi.xssf.usermodel.XSSFCell;
import org.apache.poi.xssf.usermodel.XSSFDataValidationConstraint;
import org.apache.xmlbeans.impl.jam.internal.JamPrinter;

public final class ArrayPtg extends Ptg {
    public static final int PLAIN_TOKEN_SIZE = 8;
    public static final int RESERVED_FIELD_LEN = 7;
    public static final byte sid = 32;
    public final Object[] _arrayValues;
    public final int _nColumns;
    public final int _nRows;
    public final int _reserved0Int;
    public final int _reserved1Short;
    public final int _reserved2Byte;

    public static final class Initial extends Ptg {
        public final int _reserved0;
        public final int _reserved1;
        public final int _reserved2;

        public Initial(LittleEndianInput littleEndianInput) {
            this._reserved0 = littleEndianInput.readInt();
            this._reserved1 = littleEndianInput.readUShort();
            this._reserved2 = littleEndianInput.readUByte();
        }

        public static RuntimeException invalid() {
            throw new IllegalStateException("This object is a partially initialised tArray, and cannot be used as a Ptg");
        }

        public ArrayPtg finishReading(LittleEndianInput littleEndianInput) {
            int readUByte = littleEndianInput.readUByte() + 1;
            short readShort = (short) (littleEndianInput.readShort() + 1);
            ArrayPtg arrayPtg = new ArrayPtg(this._reserved0, this._reserved1, this._reserved2, readUByte, readShort, ConstantValueParser.parse(littleEndianInput, readShort * readUByte));
            arrayPtg.setClass(getPtgClass());
            return arrayPtg;
        }

        @Override // org.apache.poi.ss.formula.ptg.Ptg
        public byte getDefaultOperandClass() {
            throw invalid();
        }

        @Override // org.apache.poi.ss.formula.ptg.Ptg
        public int getSize() {
            return 8;
        }

        @Override // org.apache.poi.ss.formula.ptg.Ptg
        public boolean isBaseToken() {
            return false;
        }

        @Override // org.apache.poi.ss.formula.ptg.Ptg
        public String toFormulaString() {
            throw invalid();
        }

        @Override // org.apache.poi.ss.formula.ptg.Ptg
        public void write(LittleEndianOutput littleEndianOutput) {
            throw invalid();
        }
    }

    public ArrayPtg(int i2, int i3, int i4, int i5, int i6, Object[] objArr) {
        this._reserved0Int = i2;
        this._reserved1Short = i3;
        this._reserved2Byte = i4;
        this._nColumns = i5;
        this._nRows = i6;
        this._arrayValues = (Object[]) objArr.clone();
    }

    public static String getConstantText(Object obj) {
        if (obj == null) {
            throw new RuntimeException("Array item cannot be null");
        } else if (obj instanceof String) {
            return a.a(a.b("\""), (String) obj, "\"");
        } else {
            if (obj instanceof Double) {
                return NumberToTextConverter.toText(((Double) obj).doubleValue());
            }
            if (obj instanceof Boolean) {
                return ((Boolean) obj).booleanValue() ? XSSFCell.TRUE : XSSFCell.FALSE;
            }
            if (obj instanceof ErrorConstant) {
                return ((ErrorConstant) obj).getText();
            }
            StringBuilder b2 = a.b("Unexpected constant class (");
            b2.append(obj.getClass().getName());
            b2.append(")");
            throw new IllegalArgumentException(b2.toString());
        }
    }

    public int getColumnCount() {
        return this._nColumns;
    }

    @Override // org.apache.poi.ss.formula.ptg.Ptg
    public byte getDefaultOperandClass() {
        return 64;
    }

    public int getRowCount() {
        return this._nRows;
    }

    @Override // org.apache.poi.ss.formula.ptg.Ptg
    public int getSize() {
        return ConstantValueParser.getEncodedSize(this._arrayValues) + 11;
    }

    public Object[][] getTokenArrayValues() {
        if (this._arrayValues != null) {
            int i2 = this._nRows;
            int[] iArr = new int[2];
            iArr[1] = this._nColumns;
            iArr[0] = i2;
            Object[][] objArr = (Object[][]) Array.newInstance(Object.class, iArr);
            for (int i3 = 0; i3 < this._nRows; i3++) {
                Object[] objArr2 = objArr[i3];
                for (int i4 = 0; i4 < this._nColumns; i4++) {
                    objArr2[i4] = this._arrayValues[getValueIndex(i4, i3)];
                }
            }
            return objArr;
        }
        throw new IllegalStateException("array values not read yet");
    }

    public int getValueIndex(int i2, int i3) {
        int i4;
        if (i2 < 0 || i2 >= (i4 = this._nColumns)) {
            StringBuilder a = a.a("Specified colIx (", i2, ") is outside the allowed range (0..");
            a.append(this._nColumns - 1);
            a.append(")");
            throw new IllegalArgumentException(a.toString());
        } else if (i3 >= 0 && i3 < this._nRows) {
            return (i3 * i4) + i2;
        } else {
            StringBuilder a2 = a.a("Specified rowIx (", i3, ") is outside the allowed range (0..");
            a2.append(this._nRows - 1);
            a2.append(")");
            throw new IllegalArgumentException(a2.toString());
        }
    }

    @Override // org.apache.poi.ss.formula.ptg.Ptg
    public boolean isBaseToken() {
        return false;
    }

    @Override // org.apache.poi.ss.formula.ptg.Ptg
    public String toFormulaString() {
        StringBuffer a = a.a("{");
        for (int i2 = 0; i2 < this._nRows; i2++) {
            if (i2 > 0) {
                a.append(";");
            }
            for (int i3 = 0; i3 < this._nColumns; i3++) {
                if (i3 > 0) {
                    a.append(XSSFDataValidationConstraint.LIST_SEPARATOR);
                }
                a.append(getConstantText(this._arrayValues[getValueIndex(i3, i2)]));
            }
        }
        a.append("}");
        return a.toString();
    }

    @Override // org.apache.poi.ss.formula.ptg.Ptg
    public String toString() {
        StringBuffer stringBuffer = new StringBuffer("[ArrayPtg]\n");
        stringBuffer.append("nRows = ");
        stringBuffer.append(getRowCount());
        stringBuffer.append("\n");
        stringBuffer.append("nCols = ");
        stringBuffer.append(getColumnCount());
        stringBuffer.append("\n");
        if (this._arrayValues == null) {
            stringBuffer.append("  #values#uninitialised#\n");
        } else {
            stringBuffer.append(JamPrinter.INDENT);
            stringBuffer.append(toFormulaString());
        }
        return stringBuffer.toString();
    }

    @Override // org.apache.poi.ss.formula.ptg.Ptg
    public void write(LittleEndianOutput littleEndianOutput) {
        littleEndianOutput.writeByte(getPtgClass() + 32);
        littleEndianOutput.writeInt(this._reserved0Int);
        littleEndianOutput.writeShort(this._reserved1Short);
        littleEndianOutput.writeByte(this._reserved2Byte);
    }

    public int writeTokenValueBytes(LittleEndianOutput littleEndianOutput) {
        littleEndianOutput.writeByte(this._nColumns - 1);
        littleEndianOutput.writeShort(this._nRows - 1);
        ConstantValueParser.encode(littleEndianOutput, this._arrayValues);
        return ConstantValueParser.getEncodedSize(this._arrayValues) + 3;
    }

    public ArrayPtg(Object[][] objArr) {
        int length = objArr[0].length;
        int length2 = objArr.length;
        short s = (short) length;
        this._nColumns = s;
        short s2 = (short) length2;
        this._nRows = s2;
        Object[] objArr2 = new Object[(s * s2)];
        for (int i2 = 0; i2 < length2; i2++) {
            Object[] objArr3 = objArr[i2];
            for (int i3 = 0; i3 < length; i3++) {
                objArr2[getValueIndex(i3, i2)] = objArr3[i3];
            }
        }
        this._arrayValues = objArr2;
        this._reserved0Int = 0;
        this._reserved1Short = 0;
        this._reserved2Byte = 0;
    }
}
