package org.apache.poi.ss.usermodel;

import b.b.a.a.a;
import java.util.Calendar;
import java.util.Date;
import java.util.TimeZone;
import java.util.regex.Pattern;
import org.apache.poi.ss.formula.ConditionalFormattingEvaluator;
import org.apache.poi.ss.formula.atp.YearFracCalculator;
import org.apache.poi.util.LocaleUtil;
import org.apache.xmlbeans.impl.piccolo.xml.Piccolo;

public class DateUtil {
    public static final int BAD_DATE = -1;
    public static final long DAY_MILLISECONDS = 86400000;
    public static final int HOURS_PER_DAY = 24;
    public static final int MINUTES_PER_HOUR = 60;
    public static final int SECONDS_PER_DAY = 86400;
    public static final int SECONDS_PER_MINUTE = 60;
    public static final Pattern TIME_SEPARATOR_PATTERN = Pattern.compile(":");
    public static final Pattern date_ptrn1 = Pattern.compile("^\\[\\$\\-.*?\\]");
    public static final Pattern date_ptrn2 = Pattern.compile("^\\[[a-zA-Z]+\\]");
    public static final Pattern date_ptrn3a = Pattern.compile("[yYmMdDhHsS]");
    public static final Pattern date_ptrn3b = Pattern.compile("^[\\[\\]yYmMdDhHsS\\-T/年月日,. :\"\\\\]+0*[ampAMP/]*$");
    public static final Pattern date_ptrn4 = Pattern.compile("^\\[([hH]+|[mM]+|[sS]+)\\]");
    public static final Pattern date_ptrn5 = Pattern.compile("^\\[DBNum(1|2|3)\\]");
    public static ThreadLocal<Boolean> lastCachedResult = new ThreadLocal<>();
    public static ThreadLocal<Integer> lastFormatIndex = new ThreadLocal<Integer>() {
        /* class org.apache.poi.ss.usermodel.DateUtil.AnonymousClass1 */

        @Override // java.lang.ThreadLocal
        public Integer initialValue() {
            return -1;
        }
    };
    public static ThreadLocal<String> lastFormatString = new ThreadLocal<>();

    public static final class FormatException extends Exception {
        public FormatException(String str) {
            super(str);
        }
    }

    public static int absoluteDay(Calendar calendar, boolean z) {
        return daysInPriorYears(calendar.get(1), z) + calendar.get(6);
    }

    public static void cache(String str, int i2, boolean z) {
        lastFormatIndex.set(Integer.valueOf(i2));
        lastFormatString.set(str);
        lastCachedResult.set(Boolean.valueOf(z));
    }

    public static double convertTime(String str) {
        try {
            return convertTimeInternal(str);
        } catch (FormatException e2) {
            StringBuilder d2 = a.d("Bad time format '", str, "' expected 'HH:MM' or 'HH:MM:SS' - ");
            d2.append(e2.getMessage());
            throw new IllegalArgumentException(d2.toString());
        }
    }

    public static double convertTimeInternal(String str) {
        String str2;
        int length = str.length();
        if (length < 4 || length > 8) {
            throw new FormatException("Bad length");
        }
        String[] split = TIME_SEPARATOR_PATTERN.split(str);
        int length2 = split.length;
        if (length2 == 2) {
            str2 = "00";
        } else if (length2 == 3) {
            str2 = split[2];
        } else {
            throw new FormatException(a.a(a.b("Expected 2 or 3 fields but got ("), split.length, ")"));
        }
        String str3 = split[0];
        String str4 = split[1];
        int parseInt = parseInt(str3, "hour", 24);
        return ((double) ((((parseInt * 60) + parseInt(str4, "minute", 60)) * 60) + parseInt(str2, "second", 60))) / 86400.0d;
    }

    public static Calendar dayStart(Calendar calendar) {
        calendar.get(11);
        calendar.set(11, 0);
        calendar.set(12, 0);
        calendar.set(13, 0);
        calendar.set(14, 0);
        calendar.get(11);
        return calendar;
    }

    public static int daysInPriorYears(int i2, boolean z) {
        int i3 = 1900;
        if ((z || i2 >= 1900) && (!z || i2 >= 1904)) {
            int i4 = i2 - 1;
            int i5 = ((i4 / 400) + ((i4 / 4) - (i4 / 100))) - 460;
            if (z) {
                i3 = 1904;
            }
            return ((i2 - i3) * YearFracCalculator.DAYS_PER_NORMAL_YEAR) + i5;
        }
        throw new IllegalArgumentException("'year' must be 1900 or greater");
    }

    public static double getExcelDate(Date date) {
        return getExcelDate(date, false);
    }

    public static Calendar getJavaCalendar(double d2) {
        return getJavaCalendar(d2, false, null, false);
    }

    public static Calendar getJavaCalendarUTC(double d2, boolean z) {
        return getJavaCalendar(d2, z, LocaleUtil.TIMEZONE_UTC, false);
    }

    public static Date getJavaDate(double d2, TimeZone timeZone) {
        return getJavaDate(d2, false, timeZone, false);
    }

    public static double internalGetExcelDate(Calendar calendar, boolean z) {
        if (!z && calendar.get(1) < 1900) {
            return -1.0d;
        }
        if (z && calendar.get(1) < 1904) {
            return -1.0d;
        }
        int i2 = calendar.get(12);
        double absoluteDay = (((double) (calendar.get(14) + ((calendar.get(13) + ((i2 + (calendar.get(11) * 60)) * 60)) * 1000))) / 8.64E7d) + ((double) absoluteDay(dayStart(calendar), z));
        if (z || absoluteDay < 60.0d) {
            return z ? absoluteDay - 1.0d : absoluteDay;
        }
        return absoluteDay + 1.0d;
    }

    public static boolean isADateFormat(ExcelNumberFormat excelNumberFormat) {
        if (excelNumberFormat == null) {
            return false;
        }
        return isADateFormat(excelNumberFormat.getIdx(), excelNumberFormat.getFormat());
    }

    public static boolean isCached(String str, int i2) {
        String str2 = lastFormatString.get();
        return str2 != null && i2 == lastFormatIndex.get().intValue() && str.equals(str2);
    }

    public static boolean isCellDateFormatted(Cell cell) {
        return isCellDateFormatted(cell, null);
    }

    public static boolean isCellInternalDateFormatted(Cell cell) {
        if (cell != null && isValidExcelDate(cell.getNumericCellValue())) {
            return isInternalDateFormat(cell.getCellStyle().getDataFormat());
        }
        return false;
    }

    public static boolean isInternalDateFormat(int i2) {
        switch (i2) {
            case 14:
            case 15:
            case 16:
            case 17:
            case 18:
            case 19:
            case 20:
            case 21:
            case 22:
                return true;
            default:
                switch (i2) {
                    case 45:
                    case 46:
                    case 47:
                        return true;
                    default:
                        return false;
                }
        }
    }

    public static boolean isValidExcelDate(double d2) {
        return d2 > -4.9E-324d;
    }

    public static int parseInt(String str, String str2, int i2) {
        return parseInt(str, str2, 0, i2 - 1);
    }

    public static Date parseYYYYMMDDDate(String str) {
        try {
            return parseYYYYMMDDDateInternal(str);
        } catch (FormatException e2) {
            StringBuilder d2 = a.d("Bad time format ", str, " expected 'YYYY/MM/DD' - ");
            d2.append(e2.getMessage());
            throw new IllegalArgumentException(d2.toString());
        }
    }

    public static Date parseYYYYMMDDDateInternal(String str) {
        if (str.length() == 10) {
            String substring = str.substring(0, 4);
            String substring2 = str.substring(5, 7);
            String substring3 = str.substring(8, 10);
            return LocaleUtil.getLocaleCalendar(parseInt(substring, "year", -32768, 32767), parseInt(substring2, "month", 1, 12) - 1, parseInt(substring3, "day", 1, 31)).getTime();
        }
        throw new FormatException("Bad length");
    }

    public static void setCalendar(Calendar calendar, int i2, int i3, boolean z, boolean z2) {
        int i4;
        int i5;
        if (z) {
            i4 = 1;
            i5 = 1904;
        } else {
            i4 = i2 < 61 ? 0 : -1;
            i5 = 1900;
        }
        calendar.set(i5, 0, i2 + i4, 0, 0, 0);
        calendar.set(14, i3);
        if (calendar.get(14) == 0) {
            calendar.clear(14);
        }
        if (z2) {
            calendar.add(14, Piccolo.YYSTACKSIZE);
            calendar.clear(14);
        }
    }

    public static double getExcelDate(Date date, boolean z) {
        Calendar localeCalendar = LocaleUtil.getLocaleCalendar();
        localeCalendar.setTime(date);
        return internalGetExcelDate(localeCalendar, z);
    }

    public static Calendar getJavaCalendar(double d2, boolean z) {
        return getJavaCalendar(d2, z, null, false);
    }

    public static Date getJavaDate(double d2) {
        return getJavaDate(d2, false, null, false);
    }

    public static boolean isADateFormat(int i2, String str) {
        if (isInternalDateFormat(i2)) {
            cache(str, i2, true);
            return true;
        } else if (str == null || str.length() == 0) {
            return false;
        } else {
            if (isCached(str, i2)) {
                return lastCachedResult.get().booleanValue();
            }
            int length = str.length();
            StringBuilder sb = new StringBuilder(length);
            int i3 = 0;
            while (i3 < length) {
                char charAt = str.charAt(i3);
                if (i3 < length - 1) {
                    int i4 = i3 + 1;
                    char charAt2 = str.charAt(i4);
                    if (charAt == '\\') {
                        if (!(charAt2 == ' ' || charAt2 == '\\')) {
                            switch (charAt2) {
                            }
                        }
                        i3++;
                    } else if (charAt == ';' && charAt2 == '@') {
                        i3 = i4;
                        i3++;
                    }
                }
                sb.append(charAt);
                i3++;
            }
            String sb2 = sb.toString();
            if (date_ptrn4.matcher(sb2).matches()) {
                cache(str, i2, true);
                return true;
            }
            String replaceAll = date_ptrn2.matcher(date_ptrn1.matcher(date_ptrn5.matcher(sb2).replaceAll("")).replaceAll("")).replaceAll("");
            int indexOf = replaceAll.indexOf(59);
            if (indexOf > 0 && indexOf < replaceAll.length() - 1) {
                replaceAll = replaceAll.substring(0, indexOf);
            }
            if (!date_ptrn3a.matcher(replaceAll).find()) {
                return false;
            }
            boolean matches = date_ptrn3b.matcher(replaceAll).matches();
            cache(str, i2, matches);
            return matches;
        }
    }

    public static boolean isCellDateFormatted(Cell cell, ConditionalFormattingEvaluator conditionalFormattingEvaluator) {
        ExcelNumberFormat from;
        if (cell == null || !isValidExcelDate(cell.getNumericCellValue()) || (from = ExcelNumberFormat.from(cell, conditionalFormattingEvaluator)) == null) {
            return false;
        }
        return isADateFormat(from);
    }

    public static int parseInt(String str, String str2, int i2, int i3) {
        try {
            int parseInt = Integer.parseInt(str);
            if (parseInt >= i2 && parseInt <= i3) {
                return parseInt;
            }
            throw new FormatException(str2 + " value (" + parseInt + ") is outside the allowable range(0.." + i3 + ")");
        } catch (NumberFormatException unused) {
            throw new FormatException(a.b("Bad int format '", str, "' for ", str2, " field"));
        }
    }

    public static Calendar getJavaCalendar(double d2, boolean z, TimeZone timeZone) {
        return getJavaCalendar(d2, z, timeZone, false);
    }

    public static Date getJavaDate(double d2, boolean z, TimeZone timeZone) {
        return getJavaDate(d2, z, timeZone, false);
    }

    public static Calendar getJavaCalendar(double d2, boolean z, TimeZone timeZone, boolean z2) {
        Calendar calendar;
        if (!isValidExcelDate(d2)) {
            return null;
        }
        int floor = (int) Math.floor(d2);
        int i2 = (int) (((d2 - ((double) floor)) * 8.64E7d) + 0.5d);
        if (timeZone != null) {
            calendar = LocaleUtil.getLocaleCalendar(timeZone);
        } else {
            calendar = LocaleUtil.getLocaleCalendar();
        }
        setCalendar(calendar, floor, i2, z, z2);
        return calendar;
    }

    public static Date getJavaDate(double d2, boolean z, TimeZone timeZone, boolean z2) {
        Calendar javaCalendar = getJavaCalendar(d2, z, timeZone, z2);
        if (javaCalendar == null) {
            return null;
        }
        return javaCalendar.getTime();
    }

    public static double getExcelDate(Calendar calendar, boolean z) {
        return internalGetExcelDate((Calendar) calendar.clone(), z);
    }

    public static Date getJavaDate(double d2, boolean z) {
        return getJavaDate(d2, z, null, false);
    }
}
