package org.apache.poi.ss.usermodel;

import java.math.BigDecimal;
import java.math.MathContext;
import java.math.RoundingMode;
import java.text.DecimalFormat;
import java.text.DecimalFormatSymbols;
import java.text.FieldPosition;
import java.text.Format;
import java.text.ParsePosition;
import java.util.Locale;
import org.apache.poi.ss.formula.functions.NumericFunction;

public class ExcelGeneralNumberFormat extends Format {
    public static final MathContext TO_10_SF = new MathContext(10, RoundingMode.HALF_UP);
    public static final long serialVersionUID = 1;
    public final DecimalFormat decimalFormat;
    public final DecimalFormatSymbols decimalSymbols;
    public final DecimalFormat integerFormat;
    public final DecimalFormat scientificFormat;

    public ExcelGeneralNumberFormat(Locale locale) {
        this.decimalSymbols = DecimalFormatSymbols.getInstance(locale);
        DecimalFormat decimalFormat2 = new DecimalFormat("0.#####E0", this.decimalSymbols);
        this.scientificFormat = decimalFormat2;
        DataFormatter.setExcelStyleRoundingMode(decimalFormat2);
        DecimalFormat decimalFormat3 = new DecimalFormat(DataFormatter.defaultFractionWholePartFormat, this.decimalSymbols);
        this.integerFormat = decimalFormat3;
        DataFormatter.setExcelStyleRoundingMode(decimalFormat3);
        DecimalFormat decimalFormat4 = new DecimalFormat("#.##########", this.decimalSymbols);
        this.decimalFormat = decimalFormat4;
        DataFormatter.setExcelStyleRoundingMode(decimalFormat4);
    }

    public StringBuffer format(Object obj, StringBuffer stringBuffer, FieldPosition fieldPosition) {
        if (!(obj instanceof Number)) {
            return this.integerFormat.format(obj, stringBuffer, fieldPosition);
        }
        double doubleValue = ((Number) obj).doubleValue();
        if (Double.isInfinite(doubleValue) || Double.isNaN(doubleValue)) {
            return this.integerFormat.format(obj, stringBuffer, fieldPosition);
        }
        double abs = Math.abs(doubleValue);
        if (abs >= 1.0E11d || (abs <= 1.0E-10d && abs > NumericFunction.LOG_10_TO_BASE_e)) {
            return this.scientificFormat.format(obj, stringBuffer, fieldPosition);
        }
        if (Math.floor(doubleValue) == doubleValue || abs >= 1.0E10d) {
            return this.integerFormat.format(obj, stringBuffer, fieldPosition);
        }
        return this.decimalFormat.format(new BigDecimal(doubleValue).round(TO_10_SF).doubleValue(), stringBuffer, fieldPosition);
    }

    public Object parseObject(String str, ParsePosition parsePosition) {
        throw new UnsupportedOperationException();
    }
}
