package org.apache.poi.ss.usermodel;

import java.math.RoundingMode;
import java.text.DateFormatSymbols;
import java.text.DecimalFormat;
import java.text.DecimalFormatSymbols;
import java.text.FieldPosition;
import java.text.SimpleDateFormat;
import java.util.Date;
import java.util.Locale;
import org.apache.poi.util.LocaleUtil;

public class ExcelStyleDateFormatter extends SimpleDateFormat {
    public static final char HH_BRACKET_SYMBOL = 57361;
    public static final char H_BRACKET_SYMBOL = 57360;
    public static final char LL_BRACKET_SYMBOL = 57367;
    public static final char L_BRACKET_SYMBOL = 57366;
    public static final char MMMMM_START_SYMBOL = 57345;
    public static final char MMMMM_TRUNCATE_SYMBOL = 57346;
    public static final char MM_BRACKET_SYMBOL = 57363;
    public static final char M_BRACKET_SYMBOL = 57362;
    public static final char SS_BRACKET_SYMBOL = 57365;
    public static final char S_BRACKET_SYMBOL = 57364;
    public static final DecimalFormat format1digit;
    public static final DecimalFormat format2digits;
    public static final DecimalFormat format3digit;
    public static final DecimalFormat format4digits;
    public double dateToBeFormatted;

    static {
        DecimalFormatSymbols instance = DecimalFormatSymbols.getInstance(Locale.ROOT);
        format1digit = new DecimalFormat("0", instance);
        format2digits = new DecimalFormat("00", instance);
        format3digit = new DecimalFormat("0", instance);
        format4digits = new DecimalFormat("00", instance);
        DataFormatter.setExcelStyleRoundingMode(format1digit, RoundingMode.DOWN);
        DataFormatter.setExcelStyleRoundingMode(format2digits, RoundingMode.DOWN);
        DataFormatter.setExcelStyleRoundingMode(format3digit);
        DataFormatter.setExcelStyleRoundingMode(format4digits);
    }

    public ExcelStyleDateFormatter(String str) {
        super(processFormatPattern(str), LocaleUtil.getUserLocale());
        setTimeZone(LocaleUtil.getUserTimeZone());
    }

    public static String processFormatPattern(String str) {
        return str.replaceAll("MMMMM", "MMM").replaceAll("\\[H]", String.valueOf((char) H_BRACKET_SYMBOL)).replaceAll("\\[HH]", String.valueOf((char) HH_BRACKET_SYMBOL)).replaceAll("\\[m]", String.valueOf((char) M_BRACKET_SYMBOL)).replaceAll("\\[mm]", String.valueOf((char) MM_BRACKET_SYMBOL)).replaceAll("\\[s]", String.valueOf((char) S_BRACKET_SYMBOL)).replaceAll("\\[ss]", String.valueOf((char) SS_BRACKET_SYMBOL)).replaceAll("s.000", "s.SSS").replaceAll("s.00", "s.").replaceAll("s.0", "s.");
    }

    public boolean equals(Object obj) {
        if ((obj instanceof ExcelStyleDateFormatter) && this.dateToBeFormatted == ((ExcelStyleDateFormatter) obj).dateToBeFormatted) {
            return true;
        }
        return false;
    }

    @Override // java.text.SimpleDateFormat, java.text.DateFormat
    public StringBuffer format(Date date, StringBuffer stringBuffer, FieldPosition fieldPosition) {
        String stringBuffer2 = super.format(date, stringBuffer, fieldPosition).toString();
        if (stringBuffer2.indexOf(57345) != -1) {
            stringBuffer2 = stringBuffer2.replaceAll("(\\p{L}|\\p{P})[\\p{L}\\p{P}]+", "$1");
        }
        if (!(stringBuffer2.indexOf(57360) == -1 && stringBuffer2.indexOf(57361) == -1)) {
            double d2 = (double) (((float) this.dateToBeFormatted) * 24.0f);
            stringBuffer2 = stringBuffer2.replaceAll(String.valueOf((char) H_BRACKET_SYMBOL), format1digit.format(d2)).replaceAll(String.valueOf((char) HH_BRACKET_SYMBOL), format2digits.format(d2));
        }
        if (!(stringBuffer2.indexOf(57362) == -1 && stringBuffer2.indexOf(57363) == -1)) {
            double d3 = (double) (((float) this.dateToBeFormatted) * 24.0f * 60.0f);
            stringBuffer2 = stringBuffer2.replaceAll(String.valueOf((char) M_BRACKET_SYMBOL), format1digit.format(d3)).replaceAll(String.valueOf((char) MM_BRACKET_SYMBOL), format2digits.format(d3));
        }
        if (!(stringBuffer2.indexOf(57364) == -1 && stringBuffer2.indexOf(57365) == -1)) {
            double d4 = (double) ((float) (this.dateToBeFormatted * 24.0d * 60.0d * 60.0d));
            stringBuffer2 = stringBuffer2.replaceAll(String.valueOf((char) S_BRACKET_SYMBOL), format1digit.format(d4)).replaceAll(String.valueOf((char) SS_BRACKET_SYMBOL), format2digits.format(d4));
        }
        if (!(stringBuffer2.indexOf(57366) == -1 && stringBuffer2.indexOf(57367) == -1)) {
            double d5 = this.dateToBeFormatted;
            float floor = (float) ((d5 - Math.floor(d5)) * 24.0d * 60.0d * 60.0d);
            float f2 = floor - ((float) ((int) floor));
            stringBuffer2 = stringBuffer2.replaceAll(String.valueOf((char) L_BRACKET_SYMBOL), format3digit.format((double) (10.0f * f2))).replaceAll(String.valueOf((char) LL_BRACKET_SYMBOL), format4digits.format((double) (f2 * 100.0f)));
        }
        return new StringBuffer(stringBuffer2);
    }

    public int hashCode() {
        return new Double(this.dateToBeFormatted).hashCode();
    }

    public void setDateToBeFormatted(double d2) {
        this.dateToBeFormatted = d2;
    }

    public ExcelStyleDateFormatter(String str, DateFormatSymbols dateFormatSymbols) {
        super(processFormatPattern(str), dateFormatSymbols);
        setTimeZone(LocaleUtil.getUserTimeZone());
    }

    public ExcelStyleDateFormatter(String str, Locale locale) {
        super(processFormatPattern(str), locale);
        setTimeZone(LocaleUtil.getUserTimeZone());
    }
}
