package org.apache.poi.ss.usermodel;

import java.awt.Color;
import java.util.Locale;
import org.apache.poi.ss.formula.functions.NumericFunction;
import org.apache.poi.ss.util.SheetUtil;

public abstract class ExtendedColor implements Color {
    public static byte applyTint(int i2, double d2) {
        int i3;
        if (d2 > NumericFunction.LOG_10_TO_BASE_e) {
            double d3 = 1.0d - d2;
            i3 = (int) ((255.0d - (d3 * 255.0d)) + (((double) i2) * d3));
        } else if (d2 >= NumericFunction.LOG_10_TO_BASE_e) {
            return (byte) i2;
        } else {
            i3 = (int) ((d2 + 1.0d) * ((double) i2));
        }
        return (byte) i3;
    }

    public abstract byte[] getARGB();

    public String getARGBHex() {
        byte[] argb = getARGB();
        if (argb == null) {
            return null;
        }
        StringBuilder sb = new StringBuilder();
        for (byte b2 : argb) {
            String hexString = Integer.toHexString(b2 & 255);
            if (hexString.length() == 1) {
                sb.append(SheetUtil.defaultChar);
            }
            sb.append(hexString);
        }
        return sb.toString().toUpperCase(Locale.ROOT);
    }

    public abstract short getIndex();

    public abstract byte[] getIndexedRGB();

    public abstract byte[] getRGB();

    public byte[] getRGBOrARGB() {
        byte[] indexedRGB;
        if (!isIndexed() || getIndex() <= 0 || (indexedRGB = getIndexedRGB()) == null) {
            return getStoredRBG();
        }
        return indexedRGB;
    }

    public byte[] getRGBWithTint() {
        byte[] storedRBG = getStoredRBG();
        if (storedRBG != null) {
            if (storedRBG.length == 4) {
                byte[] bArr = new byte[3];
                System.arraycopy(storedRBG, 1, bArr, 0, 3);
                storedRBG = bArr;
            }
            double tint = getTint();
            for (int i2 = 0; i2 < storedRBG.length; i2++) {
                storedRBG[i2] = applyTint(storedRBG[i2] & 255, tint);
            }
        }
        return storedRBG;
    }

    public abstract byte[] getStoredRBG();

    public abstract int getTheme();

    public abstract double getTint();

    public abstract boolean isAuto();

    public abstract boolean isIndexed();

    public abstract boolean isRGB();

    public abstract boolean isThemed();

    public void setARGBHex(String str) {
        if (str.length() == 6 || str.length() == 8) {
            int length = str.length() / 2;
            byte[] bArr = new byte[length];
            int i2 = 0;
            while (i2 < length) {
                int i3 = i2 + 1;
                bArr[i2] = (byte) Integer.parseInt(str.substring(i2 * 2, i3 * 2), 16);
                i2 = i3;
            }
            setRGB(bArr);
            return;
        }
        throw new IllegalArgumentException("Must be of the form 112233 or FFEEDDCC");
    }

    public void setColor(Color color) {
        setRGB(new byte[]{(byte) color.getRed(), (byte) color.getGreen(), (byte) color.getBlue()});
    }

    public abstract void setRGB(byte[] bArr);

    public abstract void setTint(double d2);
}
