package org.apache.poi.ss.usermodel;

import java.text.FieldPosition;
import java.text.Format;
import java.text.ParsePosition;
import java.util.regex.Matcher;
import java.util.regex.Pattern;
import org.apache.poi.openxml4j.opc.internal.ZipHelper;
import org.apache.poi.ss.format.SimpleFraction;
import org.apache.poi.ss.formula.eval.NotImplementedException;
import org.apache.poi.ss.formula.functions.NumericFunction;
import org.apache.poi.ss.formula.ptg.UnaryMinusPtg;
import org.apache.poi.util.POILogFactory;
import org.apache.poi.util.POILogger;

public class FractionFormat extends Format {
    public static final Pattern DENOM_FORMAT_PATTERN = Pattern.compile("(?:(#+)|(\\d+))");
    public static final POILogger LOGGER = POILogFactory.getLogger(FractionFormat.class);
    public static final int MAX_DENOM_POW = 4;
    public final int exactDenom;
    public final int maxDenom;
    public final String wholePartFormatString;

    public FractionFormat(String str, String str2) {
        int i2;
        this.wholePartFormatString = str;
        Matcher matcher = DENOM_FORMAT_PATTERN.matcher(str2);
        int i3 = 100;
        int i4 = -1;
        if (matcher.find()) {
            if (matcher.group(2) != null) {
                try {
                    int parseInt = Integer.parseInt(matcher.group(2));
                    i4 = parseInt == 0 ? -1 : parseInt;
                } catch (NumberFormatException unused) {
                }
            } else {
                if (matcher.group(1) != null) {
                    int length = matcher.group(1).length();
                    i2 = (int) Math.pow(10.0d, (double) (length > 4 ? 4 : length));
                } else {
                    i2 = -1;
                    i4 = 100;
                }
                this.exactDenom = (i4 > 0 || i2 > 0) ? i4 : i3;
                this.maxDenom = i2;
            }
        }
        i2 = -1;
        this.exactDenom = (i4 > 0 || i2 > 0) ? i4 : i3;
        this.maxDenom = i2;
    }

    public String format(Number number) {
        SimpleFraction simpleFraction;
        double doubleValue = number.doubleValue();
        boolean z = doubleValue < NumericFunction.LOG_10_TO_BASE_e;
        double abs = Math.abs(doubleValue);
        double floor = Math.floor(abs);
        double d2 = abs - floor;
        if (floor + d2 == NumericFunction.LOG_10_TO_BASE_e) {
            return "0";
        }
        if (Double.compare(d2, NumericFunction.LOG_10_TO_BASE_e) == 0) {
            StringBuilder sb = new StringBuilder();
            if (z) {
                sb.append(UnaryMinusPtg.MINUS);
            }
            sb.append((int) floor);
            return sb.toString();
        }
        try {
            if (this.exactDenom > 0) {
                simpleFraction = SimpleFraction.buildFractionExactDenominator(d2, this.exactDenom);
            } else {
                simpleFraction = SimpleFraction.buildFractionMaxDenominator(d2, this.maxDenom);
            }
            StringBuilder sb2 = new StringBuilder();
            if (z) {
                sb2.append(UnaryMinusPtg.MINUS);
            }
            if ("".equals(this.wholePartFormatString)) {
                sb2.append(simpleFraction.getNumerator() + (simpleFraction.getDenominator() * ((int) floor)));
                sb2.append(ZipHelper.FORWARD_SLASH);
                sb2.append(simpleFraction.getDenominator());
                return sb2.toString();
            } else if (simpleFraction.getNumerator() == 0) {
                sb2.append(Integer.toString((int) floor));
                return sb2.toString();
            } else if (simpleFraction.getNumerator() == simpleFraction.getDenominator()) {
                sb2.append(Integer.toString(((int) floor) + 1));
                return sb2.toString();
            } else {
                if (floor > NumericFunction.LOG_10_TO_BASE_e) {
                    sb2.append(Integer.toString((int) floor));
                    sb2.append(" ");
                }
                sb2.append(simpleFraction.getNumerator());
                sb2.append(ZipHelper.FORWARD_SLASH);
                sb2.append(simpleFraction.getDenominator());
                return sb2.toString();
            }
        } catch (RuntimeException e2) {
            LOGGER.log(5, "Can't format fraction", e2);
            return Double.toString(doubleValue);
        }
    }

    public Object parseObject(String str, ParsePosition parsePosition) {
        throw new NotImplementedException("Reverse parsing not supported");
    }

    public StringBuffer format(Object obj, StringBuffer stringBuffer, FieldPosition fieldPosition) {
        stringBuffer.append(format((Number) obj));
        return stringBuffer;
    }
}
