package org.apache.poi.ss.usermodel.helpers;

import java.util.ArrayList;
import java.util.HashSet;
import java.util.Iterator;
import java.util.List;
import org.apache.poi.ss.formula.FormulaShifter;
import org.apache.poi.ss.usermodel.Row;
import org.apache.poi.ss.usermodel.Sheet;
import org.apache.poi.ss.util.CellRangeAddress;
import org.apache.poi.util.Internal;

public abstract class RowShifter {
    public final Sheet sheet;

    public RowShifter(Sheet sheet2) {
        this.sheet = sheet2;
    }

    private boolean removalNeeded(CellRangeAddress cellRangeAddress, int i2, int i3, int i4) {
        CellRangeAddress cellRangeAddress2;
        int i5 = (i3 - i2) + 1;
        if (i4 > 0) {
            int i6 = i3 + 1;
            int i7 = i3 + i4;
            cellRangeAddress2 = new CellRangeAddress(Math.max(i6, i7 - i5), i7, 0, 0);
        } else {
            int i8 = i4 + i2;
            cellRangeAddress2 = new CellRangeAddress(i8, Math.min(i2 - 1, i5 + i8), 0, 0);
        }
        return cellRangeAddress.intersects(cellRangeAddress2);
    }

    public List<CellRangeAddress> shiftMergedRegions(int i2, int i3, int i4) {
        ArrayList arrayList = new ArrayList();
        HashSet hashSet = new HashSet();
        int numMergedRegions = this.sheet.getNumMergedRegions();
        for (int i5 = 0; i5 < numMergedRegions; i5++) {
            CellRangeAddress mergedRegion = this.sheet.getMergedRegion(i5);
            if (removalNeeded(mergedRegion, i2, i3, i4)) {
                hashSet.add(Integer.valueOf(i5));
            } else {
                boolean z = true;
                boolean z2 = mergedRegion.getFirstRow() >= i2 || mergedRegion.getLastRow() >= i2;
                if (mergedRegion.getFirstRow() > i3 && mergedRegion.getLastRow() > i3) {
                    z = false;
                }
                if (z2 && z && !mergedRegion.containsRow(i2 - 1) && !mergedRegion.containsRow(i3 + 1)) {
                    mergedRegion.setFirstRow(mergedRegion.getFirstRow() + i4);
                    mergedRegion.setLastRow(mergedRegion.getLastRow() + i4);
                    arrayList.add(mergedRegion);
                    hashSet.add(Integer.valueOf(i5));
                }
            }
        }
        if (!hashSet.isEmpty()) {
            this.sheet.removeMergedRegions(hashSet);
        }
        Iterator it = arrayList.iterator();
        while (it.hasNext()) {
            this.sheet.addMergedRegion((CellRangeAddress) it.next());
        }
        return arrayList;
    }

    public abstract void updateConditionalFormatting(FormulaShifter formulaShifter);

    public abstract void updateFormulas(FormulaShifter formulaShifter);

    public abstract void updateHyperlinks(FormulaShifter formulaShifter);

    public abstract void updateNamedRanges(FormulaShifter formulaShifter);

    @Internal
    public abstract void updateRowFormulas(Row row, FormulaShifter formulaShifter);
}
