package org.apache.poi.ss.util;

import b.b.a.a.a;
import java.util.EnumSet;
import java.util.Set;
import org.apache.poi.ss.SpreadsheetVersion;
import org.apache.poi.ss.usermodel.Cell;

public abstract class CellRangeAddressBase {
    public int _firstCol;
    public int _firstRow;
    public int _lastCol;
    public int _lastRow;

    public enum CellPosition {
        TOP,
        BOTTOM,
        LEFT,
        RIGHT,
        INSIDE
    }

    public CellRangeAddressBase(int i2, int i3, int i4, int i5) {
        this._firstRow = i2;
        this._lastRow = i3;
        this._firstCol = i4;
        this._lastCol = i5;
    }

    public static void validateColumn(int i2, SpreadsheetVersion spreadsheetVersion) {
        int lastColumnIndex = spreadsheetVersion.getLastColumnIndex();
        if (i2 > lastColumnIndex) {
            throw new IllegalArgumentException(a.c("Maximum column number is ", lastColumnIndex));
        } else if (i2 < 0) {
            throw new IllegalArgumentException("Minimum column number is 0");
        }
    }

    public static void validateRow(int i2, SpreadsheetVersion spreadsheetVersion) {
        int lastRowIndex = spreadsheetVersion.getLastRowIndex();
        if (i2 > lastRowIndex) {
            throw new IllegalArgumentException(a.c("Maximum row number is ", lastRowIndex));
        } else if (i2 < 0) {
            throw new IllegalArgumentException("Minumum row number is 0");
        }
    }

    public boolean containsColumn(int i2) {
        return this._firstCol <= i2 && i2 <= this._lastCol;
    }

    public boolean containsRow(int i2) {
        return this._firstRow <= i2 && i2 <= this._lastRow;
    }

    public boolean equals(Object obj) {
        if (!(obj instanceof CellRangeAddressBase)) {
            return false;
        }
        CellRangeAddressBase cellRangeAddressBase = (CellRangeAddressBase) obj;
        if (getMinRow() == cellRangeAddressBase.getMinRow() && getMaxRow() == cellRangeAddressBase.getMaxRow() && getMinColumn() == cellRangeAddressBase.getMinColumn() && getMaxColumn() == cellRangeAddressBase.getMaxColumn()) {
            return true;
        }
        return false;
    }

    public final int getFirstColumn() {
        return this._firstCol;
    }

    public final int getFirstRow() {
        return this._firstRow;
    }

    public final int getLastColumn() {
        return this._lastCol;
    }

    public final int getLastRow() {
        return this._lastRow;
    }

    public int getMaxColumn() {
        return Math.max(this._firstCol, this._lastCol);
    }

    public int getMaxRow() {
        return Math.max(this._firstRow, this._lastRow);
    }

    public int getMinColumn() {
        return Math.min(this._firstCol, this._lastCol);
    }

    public int getMinRow() {
        return Math.min(this._firstRow, this._lastRow);
    }

    public int getNumberOfCells() {
        return ((this._lastCol - this._firstCol) + 1) * ((this._lastRow - this._firstRow) + 1);
    }

    public Set<CellPosition> getPosition(int i2, int i3) {
        EnumSet noneOf = EnumSet.noneOf(CellPosition.class);
        if (i2 <= getFirstRow() || i2 >= getLastRow() || i3 <= getFirstColumn() || i3 >= getLastColumn()) {
            if (i2 == getFirstRow()) {
                noneOf.add(CellPosition.TOP);
            }
            if (i2 == getLastRow()) {
                noneOf.add(CellPosition.BOTTOM);
            }
            if (i3 == getFirstColumn()) {
                noneOf.add(CellPosition.LEFT);
            }
            if (i3 == getLastColumn()) {
                noneOf.add(CellPosition.RIGHT);
            }
            return noneOf;
        }
        noneOf.add(CellPosition.INSIDE);
        return noneOf;
    }

    public int hashCode() {
        return getMinColumn() + (getMaxColumn() << 8) + (getMinRow() << 16) + (getMaxRow() << 24);
    }

    public boolean intersects(CellRangeAddressBase cellRangeAddressBase) {
        return this._firstRow <= cellRangeAddressBase._lastRow && this._firstCol <= cellRangeAddressBase._lastCol && cellRangeAddressBase._firstRow <= this._lastRow && cellRangeAddressBase._firstCol <= this._lastCol;
    }

    public final boolean isFullColumnRange() {
        return (this._firstRow == 0 && this._lastRow == SpreadsheetVersion.EXCEL97.getLastRowIndex()) || (this._firstRow == -1 && this._lastRow == -1);
    }

    public final boolean isFullRowRange() {
        return (this._firstCol == 0 && this._lastCol == SpreadsheetVersion.EXCEL97.getLastColumnIndex()) || (this._firstCol == -1 && this._lastCol == -1);
    }

    public boolean isInRange(int i2, int i3) {
        return this._firstRow <= i2 && i2 <= this._lastRow && this._firstCol <= i3 && i3 <= this._lastCol;
    }

    public final void setFirstColumn(int i2) {
        this._firstCol = i2;
    }

    public final void setFirstRow(int i2) {
        this._firstRow = i2;
    }

    public final void setLastColumn(int i2) {
        this._lastCol = i2;
    }

    public final void setLastRow(int i2) {
        this._lastRow = i2;
    }

    public final String toString() {
        CellReference cellReference = new CellReference(this._firstRow, this._firstCol);
        CellReference cellReference2 = new CellReference(this._lastRow, this._lastCol);
        return getClass().getName() + " [" + cellReference.formatAsString() + ":" + cellReference2.formatAsString() + "]";
    }

    public void validate(SpreadsheetVersion spreadsheetVersion) {
        validateRow(this._firstRow, spreadsheetVersion);
        validateRow(this._lastRow, spreadsheetVersion);
        validateColumn(this._firstCol, spreadsheetVersion);
        validateColumn(this._lastCol, spreadsheetVersion);
    }

    public boolean isInRange(CellReference cellReference) {
        return isInRange(cellReference.getRow(), cellReference.getCol());
    }

    public boolean isInRange(Cell cell) {
        return isInRange(cell.getRowIndex(), cell.getColumnIndex());
    }
}
