package org.apache.poi.ss.util;

import b.b.a.a.a;
import java.util.ArrayList;
import java.util.List;

public final class CellRangeUtil {
    public static final int ENCLOSES = 4;
    public static final int INSIDE = 3;
    public static final int NO_INTERSECTION = 1;
    public static final int OVERLAP = 2;

    public static boolean contains(CellRangeAddress cellRangeAddress, CellRangeAddress cellRangeAddress2) {
        return le(cellRangeAddress.getFirstRow(), cellRangeAddress2.getFirstRow()) && ge(cellRangeAddress.getLastRow(), cellRangeAddress2.getLastRow()) && le(cellRangeAddress.getFirstColumn(), cellRangeAddress2.getFirstColumn()) && ge(cellRangeAddress.getLastColumn(), cellRangeAddress2.getLastColumn());
    }

    public static CellRangeAddress createEnclosingCellRange(CellRangeAddress cellRangeAddress, CellRangeAddress cellRangeAddress2) {
        if (cellRangeAddress2 == null) {
            return cellRangeAddress.copy();
        }
        return new CellRangeAddress(lt(cellRangeAddress2.getFirstRow(), cellRangeAddress.getFirstRow()) ? cellRangeAddress2.getFirstRow() : cellRangeAddress.getFirstRow(), gt(cellRangeAddress2.getLastRow(), cellRangeAddress.getLastRow()) ? cellRangeAddress2.getLastRow() : cellRangeAddress.getLastRow(), lt(cellRangeAddress2.getFirstColumn(), cellRangeAddress.getFirstColumn()) ? cellRangeAddress2.getFirstColumn() : cellRangeAddress.getFirstColumn(), gt(cellRangeAddress2.getLastColumn(), cellRangeAddress.getLastColumn()) ? cellRangeAddress2.getLastColumn() : cellRangeAddress.getLastColumn());
    }

    public static boolean ge(int i2, int i3) {
        return !lt(i2, i3);
    }

    public static boolean gt(int i2, int i3) {
        return lt(i3, i2);
    }

    public static boolean hasExactSharedBorder(CellRangeAddress cellRangeAddress, CellRangeAddress cellRangeAddress2) {
        int firstRow = cellRangeAddress2.getFirstRow();
        int lastRow = cellRangeAddress2.getLastRow();
        int firstColumn = cellRangeAddress2.getFirstColumn();
        int lastColumn = cellRangeAddress2.getLastColumn();
        if ((cellRangeAddress.getFirstRow() <= 0 || cellRangeAddress.getFirstRow() - 1 != lastRow) && (firstRow <= 0 || firstRow - 1 != cellRangeAddress.getLastRow())) {
            if (((cellRangeAddress.getFirstColumn() > 0 && cellRangeAddress.getFirstColumn() - 1 == lastColumn) || (firstColumn > 0 && cellRangeAddress.getLastColumn() == firstColumn - 1)) && cellRangeAddress.getFirstRow() == firstRow && cellRangeAddress.getLastRow() == lastRow) {
                return true;
            }
            return false;
        } else if (cellRangeAddress.getFirstColumn() == firstColumn && cellRangeAddress.getLastColumn() == lastColumn) {
            return true;
        } else {
            return false;
        }
    }

    public static int intersect(CellRangeAddress cellRangeAddress, CellRangeAddress cellRangeAddress2) {
        int firstRow = cellRangeAddress2.getFirstRow();
        int lastRow = cellRangeAddress2.getLastRow();
        int firstColumn = cellRangeAddress2.getFirstColumn();
        int lastColumn = cellRangeAddress2.getLastColumn();
        if (gt(cellRangeAddress.getFirstRow(), lastRow) || lt(cellRangeAddress.getLastRow(), firstRow) || gt(cellRangeAddress.getFirstColumn(), lastColumn) || lt(cellRangeAddress.getLastColumn(), firstColumn)) {
            return 1;
        }
        if (contains(cellRangeAddress, cellRangeAddress2)) {
            return 3;
        }
        return contains(cellRangeAddress2, cellRangeAddress) ? 4 : 2;
    }

    public static boolean le(int i2, int i3) {
        return i2 == i3 || lt(i2, i3);
    }

    public static boolean lt(int i2, int i3) {
        return i2 != -1 && (i3 == -1 || i2 < i3);
    }

    public static CellRangeAddress[] mergeCellRanges(CellRangeAddress[] cellRangeAddressArr) {
        if (cellRangeAddressArr.length < 1) {
            return new CellRangeAddress[0];
        }
        return toArray(mergeCellRanges(toList(cellRangeAddressArr)));
    }

    public static CellRangeAddress[] mergeRanges(CellRangeAddress cellRangeAddress, CellRangeAddress cellRangeAddress2) {
        int intersect = intersect(cellRangeAddress, cellRangeAddress2);
        if (intersect != 1) {
            if (intersect == 2) {
                return null;
            }
            if (intersect == 3) {
                return new CellRangeAddress[]{cellRangeAddress};
            } else if (intersect == 4) {
                return new CellRangeAddress[]{cellRangeAddress2};
            } else {
                throw new RuntimeException(a.b("unexpected intersection result (", intersect, ")"));
            }
        } else if (!hasExactSharedBorder(cellRangeAddress, cellRangeAddress2)) {
            return null;
        } else {
            return new CellRangeAddress[]{createEnclosingCellRange(cellRangeAddress, cellRangeAddress2)};
        }
    }

    public static CellRangeAddress[] toArray(List<CellRangeAddress> list) {
        CellRangeAddress[] cellRangeAddressArr = new CellRangeAddress[list.size()];
        list.toArray(cellRangeAddressArr);
        return cellRangeAddressArr;
    }

    public static List<CellRangeAddress> toList(CellRangeAddress[] cellRangeAddressArr) {
        ArrayList arrayList = new ArrayList(cellRangeAddressArr.length);
        for (CellRangeAddress cellRangeAddress : cellRangeAddressArr) {
            arrayList.add(cellRangeAddress);
        }
        return arrayList;
    }

    public static List<CellRangeAddress> mergeCellRanges(List<CellRangeAddress> list) {
        while (list.size() > 1) {
            int i2 = 0;
            boolean z = false;
            while (i2 < list.size()) {
                CellRangeAddress cellRangeAddress = list.get(i2);
                int i3 = i2 + 1;
                int i4 = i3;
                while (i4 < list.size()) {
                    CellRangeAddress[] mergeRanges = mergeRanges(cellRangeAddress, list.get(i4));
                    if (mergeRanges != null) {
                        list.set(i2, mergeRanges[0]);
                        list.remove(i4);
                        i4--;
                        for (int i5 = 1; i5 < mergeRanges.length; i5++) {
                            i4++;
                            list.add(i4, mergeRanges[i5]);
                        }
                        z = true;
                    }
                    i4++;
                }
                i2 = i3;
            }
            if (!z) {
                break;
            }
        }
        return list;
    }
}
