package org.apache.poi.ss.util;

import java.math.BigInteger;

public final class ExpandedDouble {
    public static final BigInteger BI_FRAC_MASK = BigInteger.valueOf(IEEEDouble.FRAC_MASK);
    public static final BigInteger BI_IMPLIED_FRAC_MSB = BigInteger.valueOf(IEEEDouble.FRAC_ASSUMED_HIGH_BIT);
    public final int _binaryExponent;
    public final BigInteger _significand;

    public ExpandedDouble(long j) {
        int i2 = (int) (j >> 52);
        if (i2 == 0) {
            BigInteger and = BigInteger.valueOf(j).and(BI_FRAC_MASK);
            int bitLength = 64 - and.bitLength();
            this._significand = and.shiftLeft(bitLength);
            this._binaryExponent = ((i2 & 2047) - 1023) - bitLength;
            return;
        }
        this._significand = getFrac(j);
        this._binaryExponent = (i2 & 2047) - 1023;
    }

    public static ExpandedDouble fromRawBitsAndExponent(long j, int i2) {
        return new ExpandedDouble(getFrac(j), i2);
    }

    public static BigInteger getFrac(long j) {
        return BigInteger.valueOf(j).and(BI_FRAC_MASK).or(BI_IMPLIED_FRAC_MSB).shiftLeft(11);
    }

    public int getBinaryExponent() {
        return this._binaryExponent;
    }

    public BigInteger getSignificand() {
        return this._significand;
    }

    public NormalisedDecimal normaliseBaseTen() {
        return NormalisedDecimal.create(this._significand, this._binaryExponent);
    }

    public ExpandedDouble(BigInteger bigInteger, int i2) {
        if (bigInteger.bitLength() == 64) {
            this._significand = bigInteger;
            this._binaryExponent = i2;
            return;
        }
        throw new IllegalArgumentException("bad bit length");
    }
}
