package org.apache.poi.ss.util;

import java.math.BigInteger;

public final class MutableFPNumber {
    public static final BigInteger BI_MAX_BASE = new BigInteger("0E35FA9319FFFE000", 16);
    public static final BigInteger BI_MIN_BASE = new BigInteger("0B5E620F47FFFE666", 16);
    public static final int C_64 = 64;
    public static final int MIN_PRECISION = 72;
    public int _binaryExponent;
    public BigInteger _significand;

    public static final class Rounder {
        public static final BigInteger[] HALF_BITS;

        static {
            BigInteger[] bigIntegerArr = new BigInteger[33];
            long j = 1;
            for (int i2 = 1; i2 < 33; i2++) {
                bigIntegerArr[i2] = BigInteger.valueOf(j);
                j <<= 1;
            }
            HALF_BITS = bigIntegerArr;
        }

        public static BigInteger round(BigInteger bigInteger, int i2) {
            return i2 < 1 ? bigInteger : bigInteger.add(HALF_BITS[i2]);
        }
    }

    public static final class TenPower {
        public static final BigInteger FIVE = new BigInteger("5");
        public static final TenPower[] _cache = new TenPower[350];
        public final BigInteger _divisor;
        public final int _divisorShift;
        public final BigInteger _multiplicand;
        public final int _multiplierShift;

        public TenPower(int i2) {
            BigInteger pow = FIVE.pow(i2);
            int bitLength = pow.bitLength();
            BigInteger divide = BigInteger.ONE.shiftLeft(bitLength + 80).divide(pow);
            int bitLength2 = divide.bitLength() - 80;
            this._divisor = divide.shiftRight(bitLength2);
            this._divisorShift = -((bitLength - bitLength2) + i2 + 80);
            int bitLength3 = pow.bitLength() - 68;
            if (bitLength3 > 0) {
                this._multiplierShift = i2 + bitLength3;
                this._multiplicand = pow.shiftRight(bitLength3);
                return;
            }
            this._multiplierShift = i2;
            this._multiplicand = pow;
        }

        public static TenPower getInstance(int i2) {
            TenPower tenPower = _cache[i2];
            if (tenPower != null) {
                return tenPower;
            }
            TenPower tenPower2 = new TenPower(i2);
            _cache[i2] = tenPower2;
            return tenPower2;
        }
    }

    public MutableFPNumber(BigInteger bigInteger, int i2) {
        this._significand = bigInteger;
        this._binaryExponent = i2;
    }

    private void mulShift(BigInteger bigInteger, int i2) {
        BigInteger multiply = this._significand.multiply(bigInteger);
        this._significand = multiply;
        this._binaryExponent += i2;
        int bitLength = (multiply.bitLength() - 72) & -32;
        if (bitLength > 0) {
            this._significand = this._significand.shiftRight(bitLength);
            this._binaryExponent += bitLength;
        }
    }

    public MutableFPNumber copy() {
        return new MutableFPNumber(this._significand, this._binaryExponent);
    }

    public ExpandedDouble createExpandedDouble() {
        return new ExpandedDouble(this._significand, this._binaryExponent);
    }

    public NormalisedDecimal createNormalisedDecimal(int i2) {
        int intValue = this._significand.intValue();
        return new NormalisedDecimal(this._significand.shiftRight((64 - this._binaryExponent) - 1).longValue(), (intValue << (this._binaryExponent - 39)) & 16777088, i2);
    }

    public int get64BitNormalisedExponent() {
        return (this._significand.bitLength() + this._binaryExponent) - 64;
    }

    public boolean isAboveMinRep() {
        return this._significand.compareTo(BI_MIN_BASE.shiftLeft(this._significand.bitLength() + -64)) > 0;
    }

    public boolean isBelowMaxRep() {
        return this._significand.compareTo(BI_MAX_BASE.shiftLeft(this._significand.bitLength() + -64)) < 0;
    }

    public void multiplyByPowerOfTen(int i2) {
        TenPower instance = TenPower.getInstance(Math.abs(i2));
        if (i2 < 0) {
            mulShift(instance._divisor, instance._divisorShift);
        } else {
            mulShift(instance._multiplicand, instance._multiplierShift);
        }
    }

    public void normalise64bit() {
        int bitLength = this._significand.bitLength();
        int i2 = bitLength - 64;
        if (i2 != 0) {
            if (i2 >= 0) {
                this._binaryExponent += i2;
                if (i2 > 32) {
                    int i3 = (i2 - 1) & 16777184;
                    this._significand = this._significand.shiftRight(i3);
                    i2 -= i3;
                    bitLength -= i3;
                }
                if (i2 >= 1) {
                    BigInteger round = Rounder.round(this._significand, i2);
                    this._significand = round;
                    if (round.bitLength() > bitLength) {
                        i2++;
                        this._binaryExponent++;
                    }
                    this._significand = this._significand.shiftRight(i2);
                    return;
                }
                throw new IllegalStateException();
            }
            throw new IllegalStateException("Not enough precision");
        }
    }
}
