package org.apache.poi.ss.util;

import org.apache.xmlbeans.impl.common.NameUtil;

public final class NumberToTextConverter {
    public static final long EXCEL_NAN_BITS = -276939487313920L;
    public static final int MAX_TEXT_LEN = 20;

    public static void appendExp(StringBuilder sb, int i2) {
        if (i2 < 10) {
            sb.append(SheetUtil.defaultChar);
            sb.append((char) (i2 + 48));
            return;
        }
        sb.append(i2);
    }

    public static void convertToText(StringBuilder sb, NormalisedDecimal normalisedDecimal) {
        String str;
        NormalisedDecimal roundUnits = normalisedDecimal.roundUnits();
        int decimalExponent = roundUnits.getDecimalExponent();
        if (Math.abs(decimalExponent) > 98) {
            str = roundUnits.getSignificantDecimalDigitsLastDigitRounded();
            if (str.length() == 16) {
                decimalExponent++;
            }
        } else {
            str = roundUnits.getSignificantDecimalDigits();
        }
        int countSignifantDigits = countSignifantDigits(str);
        if (decimalExponent < 0) {
            formatLessThanOne(sb, str, decimalExponent, countSignifantDigits);
        } else {
            formatGreaterThanOne(sb, str, decimalExponent, countSignifantDigits);
        }
    }

    public static int countSignifantDigits(String str) {
        int length = str.length() - 1;
        while (str.charAt(length) == '0') {
            length--;
            if (length < 0) {
                throw new RuntimeException("No non-zero digits found");
            }
        }
        return length + 1;
    }

    public static void formatGreaterThanOne(StringBuilder sb, String str, int i2, int i3) {
        if (i2 > 19) {
            sb.append(str.charAt(0));
            if (i3 > 1) {
                sb.append(NameUtil.PERIOD);
                sb.append(str.subSequence(1, i3));
            }
            sb.append("E+");
            appendExp(sb, i2);
            return;
        }
        int i4 = (i3 - i2) - 1;
        if (i4 > 0) {
            int i5 = i2 + 1;
            sb.append(str.subSequence(0, i5));
            sb.append(NameUtil.PERIOD);
            sb.append(str.subSequence(i5, i3));
            return;
        }
        sb.append(str.subSequence(0, i3));
        for (int i6 = -i4; i6 > 0; i6--) {
            sb.append(SheetUtil.defaultChar);
        }
    }

    public static void formatLessThanOne(StringBuilder sb, String str, int i2, int i3) {
        int i4 = -i2;
        int i5 = i4 - 1;
        if (needsScientificNotation(i5 + 2 + i3)) {
            sb.append(str.charAt(0));
            if (i3 > 1) {
                sb.append(NameUtil.PERIOD);
                sb.append(str.subSequence(1, i3));
            }
            sb.append("E-");
            appendExp(sb, i4);
            return;
        }
        sb.append("0.");
        while (i5 > 0) {
            sb.append(SheetUtil.defaultChar);
            i5--;
        }
        sb.append(str.subSequence(0, i3));
    }

    public static boolean needsScientificNotation(int i2) {
        return i2 > 20;
    }

    public static String rawDoubleBitsToText(long j) {
        boolean z = false;
        boolean z2 = j < 0;
        if (z2) {
            j &= Long.MAX_VALUE;
        }
        if (j == 0) {
            return z2 ? "-0" : "0";
        }
        ExpandedDouble expandedDouble = new ExpandedDouble(j);
        if (expandedDouble.getBinaryExponent() < -1022) {
            return z2 ? "-0" : "0";
        }
        if (expandedDouble.getBinaryExponent() != 1024) {
            z = z2;
        } else if (j == EXCEL_NAN_BITS) {
            return "3.484840871308E+308";
        }
        NormalisedDecimal normaliseBaseTen = expandedDouble.normaliseBaseTen();
        StringBuilder sb = new StringBuilder(21);
        if (z) {
            sb.append(NameUtil.HYPHEN);
        }
        convertToText(sb, normaliseBaseTen);
        return sb.toString();
    }

    public static String toText(double d2) {
        return rawDoubleBitsToText(Double.doubleToLongBits(d2));
    }
}
