package org.apache.poi.ss.util;

import b.b.a.a.a;
import java.lang.reflect.Array;
import java.util.Iterator;
import java.util.List;
import java.util.NoSuchElementException;
import org.apache.poi.ss.usermodel.Cell;
import org.apache.poi.ss.usermodel.CellRange;
import org.apache.poi.util.Internal;

@Internal
public final class SSCellRange<K extends Cell> implements CellRange<K> {
    public final int _firstColumn;
    public final int _firstRow;
    public final K[] _flattenedArray;
    public final int _height;
    public final int _width;

    public static final class ArrayIterator<D> implements Iterator<D> {
        public final D[] _array;
        public int _index = 0;

        public ArrayIterator(D[] dArr) {
            this._array = (D[]) ((Object[]) dArr.clone());
        }

        public boolean hasNext() {
            return this._index < this._array.length;
        }

        @Override // java.util.Iterator
        public D next() {
            int i2 = this._index;
            D[] dArr = this._array;
            if (i2 < dArr.length) {
                this._index = i2 + 1;
                return dArr[i2];
            }
            throw new NoSuchElementException(String.valueOf(this._index));
        }

        public void remove() {
            throw new UnsupportedOperationException("Cannot remove cells from this CellRange.");
        }
    }

    public SSCellRange(int i2, int i3, int i4, int i5, K[] kArr) {
        this._firstRow = i2;
        this._firstColumn = i3;
        this._height = i4;
        this._width = i5;
        this._flattenedArray = (K[]) ((Cell[]) kArr.clone());
    }

    public static <B extends Cell> SSCellRange<B> create(int i2, int i3, int i4, int i5, List<B> list, Class<B> cls) {
        int size = list.size();
        if (i4 * i5 == size) {
            Cell[] cellArr = (Cell[]) Array.newInstance((Class<?>) cls, size);
            list.toArray(cellArr);
            return new SSCellRange<>(i2, i3, i4, i5, cellArr);
        }
        throw new IllegalArgumentException("Array size mismatch.");
    }

    @Override // org.apache.poi.ss.usermodel.CellRange
    public K getCell(int i2, int i3) {
        int i4;
        if (i2 < 0 || i2 >= this._height) {
            StringBuilder a = a.a("Specified row ", i2, " is outside the allowable range (0..");
            a.append(this._height - 1);
            a.append(").");
            throw new ArrayIndexOutOfBoundsException(a.toString());
        } else if (i3 >= 0 && i3 < (i4 = this._width)) {
            return this._flattenedArray[(i4 * i2) + i3];
        } else {
            StringBuilder a2 = a.a("Specified colummn ", i3, " is outside the allowable range (0..");
            a2.append(this._width - 1);
            a2.append(").");
            throw new ArrayIndexOutOfBoundsException(a2.toString());
        }
    }

    @Override // org.apache.poi.ss.usermodel.CellRange
    public K[][] getCells() {
        Class<?> cls = this._flattenedArray.getClass();
        K[][] kArr = (K[][]) ((Cell[][]) Array.newInstance(cls, this._height));
        Class<?> componentType = cls.getComponentType();
        for (int i2 = this._height - 1; i2 >= 0; i2--) {
            int i3 = this._width;
            System.arraycopy(this._flattenedArray, i3 * i2, (Cell[]) Array.newInstance(componentType, this._width), 0, i3);
        }
        return kArr;
    }

    @Override // org.apache.poi.ss.usermodel.CellRange
    public K[] getFlattenedCells() {
        return (K[]) ((Cell[]) this._flattenedArray.clone());
    }

    @Override // org.apache.poi.ss.usermodel.CellRange
    public int getHeight() {
        return this._height;
    }

    @Override // org.apache.poi.ss.usermodel.CellRange
    public String getReferenceText() {
        int i2 = this._firstRow;
        int i3 = this._firstColumn;
        return new CellRangeAddress(i2, (this._height + i2) - 1, i3, (this._width + i3) - 1).formatAsString();
    }

    @Override // org.apache.poi.ss.usermodel.CellRange
    public K getTopLeftCell() {
        return this._flattenedArray[0];
    }

    @Override // org.apache.poi.ss.usermodel.CellRange
    public int getWidth() {
        return this._width;
    }

    @Override // org.apache.poi.ss.usermodel.CellRange, java.lang.Iterable
    public Iterator<K> iterator() {
        return new ArrayIterator(this._flattenedArray);
    }

    @Override // org.apache.poi.ss.usermodel.CellRange
    public int size() {
        return this._height * this._width;
    }
}
