package org.apache.poi.ss.util;

import java.util.Calendar;
import java.util.Date;
import org.apache.poi.ss.usermodel.Cell;
import org.apache.poi.ss.usermodel.Row;
import org.apache.poi.ss.usermodel.Sheet;
import org.apache.poi.ss.usermodel.Workbook;

public class SheetBuilder {
    public final Object[][] cells;
    public String sheetName = null;
    public boolean shouldCreateEmptyCells = false;
    public final Workbook workbook;

    public SheetBuilder(Workbook workbook2, Object[][] objArr) {
        this.workbook = workbook2;
        this.cells = (Object[][]) objArr.clone();
    }

    private String getFormula(Object obj) {
        return ((String) obj).substring(1);
    }

    private boolean isFormulaDefinition(Object obj) {
        if (!(obj instanceof String)) {
            return false;
        }
        String str = (String) obj;
        if (str.length() >= 2 && str.charAt(0) == '=') {
            return true;
        }
        return false;
    }

    private void setCellValue(Cell cell, Object obj) {
        if (obj != null && cell != null) {
            if (obj instanceof Number) {
                cell.setCellValue(((Number) obj).doubleValue());
            } else if (obj instanceof Date) {
                cell.setCellValue((Date) obj);
            } else if (obj instanceof Calendar) {
                cell.setCellValue((Calendar) obj);
            } else if (isFormulaDefinition(obj)) {
                cell.setCellFormula(getFormula(obj));
            } else {
                cell.setCellValue(obj.toString());
            }
        }
    }

    public Sheet build() {
        String str = this.sheetName;
        Sheet createSheet = str == null ? this.workbook.createSheet() : this.workbook.createSheet(str);
        int i2 = 0;
        while (true) {
            Object[][] objArr = this.cells;
            if (i2 >= objArr.length) {
                return createSheet;
            }
            Object[] objArr2 = objArr[i2];
            Row createRow = createSheet.createRow(i2);
            for (int i3 = 0; i3 < objArr2.length; i3++) {
                Object obj = objArr2[i3];
                if (obj != null || this.shouldCreateEmptyCells) {
                    setCellValue(createRow.createCell(i3), obj);
                }
            }
            i2++;
        }
    }

    public boolean getCreateEmptyCells() {
        return this.shouldCreateEmptyCells;
    }

    public SheetBuilder setCreateEmptyCells(boolean z) {
        this.shouldCreateEmptyCells = z;
        return this;
    }

    public SheetBuilder setSheetName(String str) {
        this.sheetName = str;
        return this;
    }
}
