package org.apache.poi.ss.util.cellwalk;

import org.apache.poi.ss.usermodel.Cell;
import org.apache.poi.ss.usermodel.CellType;
import org.apache.poi.ss.usermodel.Row;
import org.apache.poi.ss.usermodel.Sheet;
import org.apache.poi.ss.util.CellRangeAddress;

public class CellWalk {
    public CellRangeAddress range;
    public Sheet sheet;
    public boolean traverseEmptyCells = false;

    public static class SimpleCellWalkContext implements CellWalkContext {
        public int colNumber;
        public long ordinalNumber;
        public int rowNumber;

        public SimpleCellWalkContext() {
            this.ordinalNumber = 0;
            this.rowNumber = 0;
            this.colNumber = 0;
        }

        @Override // org.apache.poi.ss.util.cellwalk.CellWalkContext
        public int getColumnNumber() {
            return this.colNumber;
        }

        @Override // org.apache.poi.ss.util.cellwalk.CellWalkContext
        public long getOrdinalNumber() {
            return this.ordinalNumber;
        }

        @Override // org.apache.poi.ss.util.cellwalk.CellWalkContext
        public int getRowNumber() {
            return this.rowNumber;
        }
    }

    public CellWalk(Sheet sheet2, CellRangeAddress cellRangeAddress) {
        this.sheet = sheet2;
        this.range = cellRangeAddress;
    }

    private boolean isEmpty(Cell cell) {
        return cell.getCellTypeEnum() == CellType.BLANK;
    }

    public boolean isTraverseEmptyCells() {
        return this.traverseEmptyCells;
    }

    public void setTraverseEmptyCells(boolean z) {
        this.traverseEmptyCells = z;
    }

    public void traverse(CellHandler cellHandler) {
        int firstRow = this.range.getFirstRow();
        int lastRow = this.range.getLastRow();
        int firstColumn = this.range.getFirstColumn();
        int lastColumn = this.range.getLastColumn();
        int i2 = (lastColumn - firstColumn) + 1;
        SimpleCellWalkContext simpleCellWalkContext = new SimpleCellWalkContext();
        simpleCellWalkContext.rowNumber = firstRow;
        while (true) {
            int i3 = simpleCellWalkContext.rowNumber;
            if (i3 <= lastRow) {
                Row row = this.sheet.getRow(i3);
                if (row != null) {
                    simpleCellWalkContext.colNumber = firstColumn;
                    while (true) {
                        int i4 = simpleCellWalkContext.colNumber;
                        if (i4 > lastColumn) {
                            break;
                        }
                        Cell cell = row.getCell(i4);
                        if (cell != null && (!isEmpty(cell) || this.traverseEmptyCells)) {
                            simpleCellWalkContext.ordinalNumber = (long) ((simpleCellWalkContext.colNumber - firstColumn) + 1 + ((simpleCellWalkContext.rowNumber - firstRow) * i2));
                            cellHandler.onCell(cell, simpleCellWalkContext);
                        }
                        simpleCellWalkContext.colNumber++;
                    }
                }
                simpleCellWalkContext.rowNumber++;
            } else {
                return;
            }
        }
    }
}
