package org.apache.poi.util;

import java.io.InputStream;
import java.nio.BufferUnderflowException;

public class ByteField implements FixedField {
    public static final byte _default_value = 0;
    public final int _offset;
    public byte _value;

    public ByteField(int i2) {
        this(i2, (byte) 0);
    }

    public byte get() {
        return this._value;
    }

    @Override // org.apache.poi.util.FixedField
    public void readFromBytes(byte[] bArr) {
        this._value = bArr[this._offset];
    }

    @Override // org.apache.poi.util.FixedField
    public void readFromStream(InputStream inputStream) {
        int read = inputStream.read();
        if (read >= 0) {
            this._value = (byte) read;
            return;
        }
        throw new BufferUnderflowException();
    }

    public void set(byte b2) {
        this._value = b2;
    }

    @Override // org.apache.poi.util.FixedField
    public String toString() {
        return String.valueOf((int) this._value);
    }

    @Override // org.apache.poi.util.FixedField
    public void writeToBytes(byte[] bArr) {
        bArr[this._offset] = this._value;
    }

    public ByteField(int i2, byte b2) {
        if (i2 >= 0) {
            this._offset = i2;
            set(b2);
            return;
        }
        throw new ArrayIndexOutOfBoundsException("offset cannot be negative");
    }

    public void set(byte b2, byte[] bArr) {
        set(b2);
        writeToBytes(bArr);
    }

    public ByteField(int i2, byte[] bArr) {
        this(i2);
        readFromBytes(bArr);
    }

    public ByteField(int i2, byte b2, byte[] bArr) {
        this(i2, b2);
        writeToBytes(bArr);
    }
}
