package org.apache.poi.util;

import b.b.a.a.a;
import java.io.UnsupportedEncodingException;
import java.nio.charset.Charset;
import java.util.Collections;
import java.util.Set;
import org.apache.poi.poifs.filesystem.Ole10Native;

public class CodePageUtil {
    public static final int CP_037 = 37;
    public static final int CP_EUC_JP = 51932;
    public static final int CP_EUC_KR = 51949;
    public static final int CP_GB18030 = 54936;
    public static final int CP_GB2312 = 52936;
    public static final int CP_GBK = 936;
    public static final int CP_ISO_2022_JP1 = 50220;
    public static final int CP_ISO_2022_JP2 = 50221;
    public static final int CP_ISO_2022_JP3 = 50222;
    public static final int CP_ISO_2022_KR = 50225;
    public static final int CP_ISO_8859_1 = 28591;
    public static final int CP_ISO_8859_2 = 28592;
    public static final int CP_ISO_8859_3 = 28593;
    public static final int CP_ISO_8859_4 = 28594;
    public static final int CP_ISO_8859_5 = 28595;
    public static final int CP_ISO_8859_6 = 28596;
    public static final int CP_ISO_8859_7 = 28597;
    public static final int CP_ISO_8859_8 = 28598;
    public static final int CP_ISO_8859_9 = 28599;
    public static final int CP_JOHAB = 1361;
    public static final int CP_KOI8_R = 20866;
    public static final int CP_MAC_ARABIC = 10004;
    public static final int CP_MAC_CENTRAL_EUROPE = 10029;
    public static final int CP_MAC_CHINESE_SIMPLE = 10008;
    public static final int CP_MAC_CHINESE_TRADITIONAL = 10002;
    public static final int CP_MAC_CROATIAN = 10082;
    public static final int CP_MAC_CYRILLIC = 10007;
    public static final int CP_MAC_GREEK = 10006;
    public static final int CP_MAC_HEBREW = 10005;
    public static final int CP_MAC_ICELAND = 10079;
    public static final int CP_MAC_JAPAN = 10001;
    public static final int CP_MAC_KOREAN = 10003;
    public static final int CP_MAC_ROMAN = 10000;
    public static final int CP_MAC_ROMANIA = 10010;
    public static final int CP_MAC_ROMAN_BIFF23 = 32768;
    public static final int CP_MAC_THAI = 10021;
    public static final int CP_MAC_TURKISH = 10081;
    public static final int CP_MAC_UKRAINE = 10017;
    public static final int CP_MS949 = 949;
    public static final int CP_SJIS = 932;
    public static final int CP_UNICODE = 1200;
    public static final int CP_US_ACSII = 20127;
    public static final int CP_US_ASCII2 = 65000;
    public static final int CP_UTF16 = 1200;
    public static final int CP_UTF16_BE = 1201;
    public static final int CP_UTF8 = 65001;
    public static final int CP_WINDOWS_1250 = 1250;
    public static final int CP_WINDOWS_1251 = 1251;
    public static final int CP_WINDOWS_1252 = 1252;
    public static final int CP_WINDOWS_1252_BIFF23 = 32769;
    public static final int CP_WINDOWS_1253 = 1253;
    public static final int CP_WINDOWS_1254 = 1254;
    public static final int CP_WINDOWS_1255 = 1255;
    public static final int CP_WINDOWS_1256 = 1256;
    public static final int CP_WINDOWS_1257 = 1257;
    public static final int CP_WINDOWS_1258 = 1258;
    public static final Set<Charset> DOUBLE_BYTE_CHARSETS = Collections.singleton(StringUtil.BIG5);

    public static String codepageToEncoding(int i2) {
        return codepageToEncoding(i2, false);
    }

    public static String cp950ToString(byte[] bArr, int i2, int i3) {
        StringBuilder sb = new StringBuilder();
        LittleEndianCP950Reader littleEndianCP950Reader = new LittleEndianCP950Reader(bArr, i2, i3);
        for (int read = littleEndianCP950Reader.read(); read != -1; read = littleEndianCP950Reader.read()) {
            sb.append((char) read);
        }
        littleEndianCP950Reader.close();
        return sb.toString();
    }

    public static byte[] getBytesInCodePage(String str, int i2) {
        return str.getBytes(codepageToEncoding(i2));
    }

    public static String getStringFromCodePage(byte[] bArr, int i2) {
        return getStringFromCodePage(bArr, 0, bArr.length, i2);
    }

    /* JADX INFO: Can't fix incorrect switch cases order, some code will duplicate */
    public static String codepageToEncoding(int i2, boolean z) {
        if (i2 <= 0) {
            throw new UnsupportedEncodingException(a.c("Codepage number may not be ", i2));
        } else if (i2 == 1200) {
            return "UTF-16LE";
        } else {
            if (i2 == 1201) {
                return "UTF-16BE";
            }
            if (i2 == 10081) {
                return "MacTurkish";
            }
            if (i2 == 10082) {
                return "MacCroatian";
            }
            switch (i2) {
                case 37:
                    return "cp037";
                case CP_SJIS /*{ENCODED_INT: 932}*/:
                    return "SJIS";
                case CP_GBK /*{ENCODED_INT: 936}*/:
                    return "GBK";
                case CP_MS949 /*{ENCODED_INT: 949}*/:
                    return "ms949";
                case CP_JOHAB /*{ENCODED_INT: 1361}*/:
                    return "johab";
                case CP_MAC_ROMANIA /*{ENCODED_INT: 10010}*/:
                    return "MacRomania";
                case CP_MAC_UKRAINE /*{ENCODED_INT: 10017}*/:
                    return "MacUkraine";
                case CP_MAC_THAI /*{ENCODED_INT: 10021}*/:
                    return "MacThai";
                case CP_MAC_CENTRAL_EUROPE /*{ENCODED_INT: 10029}*/:
                    return "MacCentralEurope";
                case CP_MAC_ICELAND /*{ENCODED_INT: 10079}*/:
                    return "MacIceland";
                case CP_US_ACSII /*{ENCODED_INT: 20127}*/:
                    return "US-ASCII";
                case CP_KOI8_R /*{ENCODED_INT: 20866}*/:
                    return "KOI8-R";
                case CP_ISO_2022_KR /*{ENCODED_INT: 50225}*/:
                    return "ISO-2022-KR";
                case CP_EUC_JP /*{ENCODED_INT: 51932}*/:
                    return "EUC-JP";
                case CP_EUC_KR /*{ENCODED_INT: 51949}*/:
                    return "EUC-KR";
                case CP_GB2312 /*{ENCODED_INT: 52936}*/:
                    return "GB2312";
                case CP_GB18030 /*{ENCODED_INT: 54936}*/:
                    return "GB18030";
                default:
                    switch (i2) {
                        case CP_WINDOWS_1250 /*{ENCODED_INT: 1250}*/:
                            return z ? "Cp1250" : "windows-1250";
                        case CP_WINDOWS_1251 /*{ENCODED_INT: 1251}*/:
                            return z ? "Cp1251" : "windows-1251";
                        case 1252:
                            break;
                        case CP_WINDOWS_1253 /*{ENCODED_INT: 1253}*/:
                            return z ? "Cp1253" : "windows-1253";
                        case CP_WINDOWS_1254 /*{ENCODED_INT: 1254}*/:
                            return z ? "Cp1254" : "windows-1254";
                        case CP_WINDOWS_1255 /*{ENCODED_INT: 1255}*/:
                            return z ? "Cp1255" : "windows-1255";
                        case CP_WINDOWS_1256 /*{ENCODED_INT: 1256}*/:
                            return z ? "Cp1255" : "windows-1256";
                        case CP_WINDOWS_1257 /*{ENCODED_INT: 1257}*/:
                            return z ? "Cp1257" : "windows-1257";
                        case CP_WINDOWS_1258 /*{ENCODED_INT: 1258}*/:
                            return z ? "Cp1258" : "windows-1258";
                        default:
                            switch (i2) {
                                case 10000:
                                    return "MacRoman";
                                case CP_MAC_JAPAN /*{ENCODED_INT: 10001}*/:
                                    return "SJIS";
                                case CP_MAC_CHINESE_TRADITIONAL /*{ENCODED_INT: 10002}*/:
                                    return "Big5";
                                case CP_MAC_KOREAN /*{ENCODED_INT: 10003}*/:
                                    return "EUC-KR";
                                case CP_MAC_ARABIC /*{ENCODED_INT: 10004}*/:
                                    return "MacArabic";
                                case CP_MAC_HEBREW /*{ENCODED_INT: 10005}*/:
                                    return "MacHebrew";
                                case CP_MAC_GREEK /*{ENCODED_INT: 10006}*/:
                                    return "MacGreek";
                                case CP_MAC_CYRILLIC /*{ENCODED_INT: 10007}*/:
                                    return "MacCyrillic";
                                case CP_MAC_CHINESE_SIMPLE /*{ENCODED_INT: 10008}*/:
                                    return "EUC_CN";
                                default:
                                    switch (i2) {
                                        case CP_ISO_8859_1 /*{ENCODED_INT: 28591}*/:
                                            return z ? "ISO8859_1" : Ole10Native.ISO1;
                                        case CP_ISO_8859_2 /*{ENCODED_INT: 28592}*/:
                                            return z ? "ISO8859_2" : "ISO-8859-2";
                                        case CP_ISO_8859_3 /*{ENCODED_INT: 28593}*/:
                                            return z ? "ISO8859_3" : "ISO-8859-3";
                                        case CP_ISO_8859_4 /*{ENCODED_INT: 28594}*/:
                                            return z ? "ISO8859_4" : "ISO-8859-4";
                                        case CP_ISO_8859_5 /*{ENCODED_INT: 28595}*/:
                                            return z ? "ISO8859_5" : "ISO-8859-5";
                                        case CP_ISO_8859_6 /*{ENCODED_INT: 28596}*/:
                                            return z ? "ISO8859_6" : "ISO-8859-6";
                                        case CP_ISO_8859_7 /*{ENCODED_INT: 28597}*/:
                                            return z ? "ISO8859_7" : "ISO-8859-7";
                                        case CP_ISO_8859_8 /*{ENCODED_INT: 28598}*/:
                                            return z ? "ISO8859_8" : "ISO-8859-8";
                                        case CP_ISO_8859_9 /*{ENCODED_INT: 28599}*/:
                                            return z ? "ISO8859_9" : "ISO-8859-9";
                                        default:
                                            switch (i2) {
                                                case 32768:
                                                    return "MacRoman";
                                                case CP_WINDOWS_1252_BIFF23 /*{ENCODED_INT: 32769}*/:
                                                    break;
                                                default:
                                                    switch (i2) {
                                                        case CP_ISO_2022_JP1 /*{ENCODED_INT: 50220}*/:
                                                        case CP_ISO_2022_JP2 /*{ENCODED_INT: 50221}*/:
                                                        case CP_ISO_2022_JP3 /*{ENCODED_INT: 50222}*/:
                                                            return "ISO-2022-JP";
                                                        default:
                                                            switch (i2) {
                                                                case CP_US_ASCII2 /*{ENCODED_INT: 65000}*/:
                                                                    return "US-ASCII";
                                                                case CP_UTF8 /*{ENCODED_INT: 65001}*/:
                                                                    return "UTF-8";
                                                                default:
                                                                    return a.c("cp", i2);
                                                            }
                                                    }
                                            }
                                    }
                            }
                    }
                    return z ? "Cp1252" : "windows-1252";
            }
        }
    }

    public static String getStringFromCodePage(byte[] bArr, int i2, int i3, int i4) {
        return new String(bArr, i2, i3, codepageToEncoding(i4));
    }
}
