package org.apache.poi.util;

import b.b.a.a.a;
import java.io.File;
import java.io.IOException;
import java.security.SecureRandom;

public class DefaultTempFileCreationStrategy implements TempFileCreationStrategy {
    public static final String JAVA_IO_TMPDIR = "java.io.tmpdir";
    public static final String KEEP_FILES = "poi.keep.tmp.files";
    public static final String POIFILES = "poifiles";
    public static final SecureRandom random = new SecureRandom();
    public File dir;

    public DefaultTempFileCreationStrategy() {
        this(null);
    }

    private void createPOIFilesDirectory() {
        if (this.dir == null) {
            String property = System.getProperty("java.io.tmpdir");
            if (property != null) {
                this.dir = new File(property, POIFILES);
            } else {
                throw new IOException("Systems temporary directory not defined - set the -Djava.io.tmpdir jvm property!");
            }
        }
        createTempDirectory(this.dir);
    }

    private void createTempDirectory(File file) {
        if (!(file.exists() || file.mkdirs())) {
            throw new IOException("Could not create temporary directory '" + file + "'");
        } else if (!file.isDirectory()) {
            throw new IOException("Could not create temporary directory. '" + file + "' exists but is not a directory.");
        }
    }

    @Override // org.apache.poi.util.TempFileCreationStrategy
    public File createTempFile(String str, String str2) {
        createPOIFilesDirectory();
        File createTempFile = File.createTempFile(str, str2, this.dir);
        if (System.getProperty(KEEP_FILES) == null) {
            createTempFile.deleteOnExit();
        }
        return createTempFile;
    }

    public DefaultTempFileCreationStrategy(File file) {
        this.dir = file;
    }

    @Override // org.apache.poi.util.TempFileCreationStrategy
    public File createTempDirectory(String str) {
        createPOIFilesDirectory();
        long nextLong = random.nextLong();
        File file = this.dir;
        StringBuilder b2 = a.b(str);
        b2.append(Long.toString(nextLong));
        File file2 = new File(file, b2.toString());
        createTempDirectory(file2);
        if (System.getProperty(KEEP_FILES) == null) {
            file2.deleteOnExit();
        }
        return file2;
    }
}
