package org.apache.poi.util;

import b.b.a.a.a;
import java.io.ByteArrayOutputStream;
import java.io.FileInputStream;
import java.io.InputStream;
import java.io.OutputStream;
import java.io.OutputStreamWriter;
import java.io.PrintStream;
import java.nio.charset.Charset;
import org.apache.poi.hpsf.Filetime;
import org.apache.xmlbeans.impl.common.NameUtil;

@Internal
public class HexDump {
    public static final String EOL = System.getProperty("line.separator");
    public static final Charset UTF8 = Charset.forName("UTF-8");

    public static String byteToHex(int i2) {
        StringBuilder sb = new StringBuilder(4);
        writeHex(sb, ((long) i2) & 255, 2, "0x");
        return sb.toString();
    }

    public static void dump(byte[] bArr, long j, OutputStream outputStream, int i2, int i3) {
        if (outputStream != null) {
            OutputStreamWriter outputStreamWriter = new OutputStreamWriter(outputStream, UTF8);
            outputStreamWriter.write(dump(bArr, j, i2, i3));
            outputStreamWriter.flush();
            return;
        }
        throw new IllegalArgumentException("cannot write to nullstream");
    }

    public static String intToHex(int i2) {
        StringBuilder sb = new StringBuilder(10);
        writeHex(sb, ((long) i2) & Filetime.UINT_MASK, 8, "0x");
        return sb.toString();
    }

    public static String longToHex(long j) {
        StringBuilder sb = new StringBuilder(18);
        writeHex(sb, j, 16, "0x");
        return sb.toString();
    }

    public static void main(String[] strArr) {
        FileInputStream fileInputStream = new FileInputStream(strArr[0]);
        byte[] byteArray = IOUtils.toByteArray(fileInputStream);
        fileInputStream.close();
        System.out.println(dump(byteArray, 0, 0));
    }

    public static String shortToHex(int i2) {
        StringBuilder sb = new StringBuilder(6);
        writeHex(sb, ((long) i2) & 65535, 4, "0x");
        return sb.toString();
    }

    public static char toAscii(int i2) {
        char c = (char) (i2 & 255);
        return (Character.isISOControl(c) || c == 221 || c == 255) ? NameUtil.PERIOD : c;
    }

    public static String toHex(byte[] bArr) {
        StringBuilder sb = new StringBuilder();
        sb.append('[');
        if (bArr != null && bArr.length > 0) {
            for (int i2 = 0; i2 < bArr.length; i2++) {
                if (i2 > 0) {
                    sb.append(", ");
                }
                sb.append(toHex(bArr[i2]));
            }
        }
        sb.append(']');
        return sb.toString();
    }

    public static void writeHex(StringBuilder sb, long j, int i2, String str) {
        sb.append(str);
        char[] cArr = new char[i2];
        for (int i3 = i2 - 1; i3 >= 0; i3--) {
            int i4 = (int) (15 & j);
            cArr[i3] = (char) (i4 < 10 ? i4 + 48 : (i4 + 65) - 10);
            j >>>= 4;
        }
        sb.append(cArr);
    }

    public static synchronized void dump(byte[] bArr, long j, OutputStream outputStream, int i2) {
        synchronized (HexDump.class) {
            dump(bArr, j, outputStream, i2, Integer.MAX_VALUE);
        }
    }

    public static String dump(byte[] bArr, long j, int i2) {
        return dump(bArr, j, i2, Integer.MAX_VALUE);
    }

    public static String dump(byte[] bArr, long j, int i2, int i3) {
        int i4;
        if (bArr == null || bArr.length == 0) {
            StringBuilder b2 = a.b("No Data");
            b2.append(EOL);
            return b2.toString();
        }
        int length = (i3 == Integer.MAX_VALUE || i3 < 0 || (i4 = i3 + i2) < 0) ? bArr.length : Math.min(bArr.length, i4);
        if (i2 < 0 || i2 >= bArr.length) {
            StringBuilder a = a.a("illegal index: ", i2, " into array of length ");
            a.append(bArr.length);
            throw new ArrayIndexOutOfBoundsException(a.toString());
        }
        long j2 = j + ((long) i2);
        StringBuilder sb = new StringBuilder(74);
        while (i2 < length) {
            int i5 = length - i2;
            if (i5 > 16) {
                i5 = 16;
            }
            writeHex(sb, j2, 8, "");
            for (int i6 = 0; i6 < 16; i6++) {
                if (i6 < i5) {
                    writeHex(sb, (long) bArr[i6 + i2], 2, " ");
                } else {
                    sb.append("   ");
                }
            }
            sb.append(' ');
            for (int i7 = 0; i7 < i5; i7++) {
                sb.append(toAscii(bArr[i7 + i2]));
            }
            sb.append(EOL);
            j2 += (long) i5;
            i2 += 16;
        }
        return sb.toString();
    }

    public static String toHex(short[] sArr) {
        StringBuilder sb = new StringBuilder();
        sb.append('[');
        for (int i2 = 0; i2 < sArr.length; i2++) {
            if (i2 > 0) {
                sb.append(", ");
            }
            sb.append(toHex(sArr[i2]));
        }
        sb.append(']');
        return sb.toString();
    }

    public static String toHex(byte[] bArr, int i2) {
        if (bArr.length == 0) {
            return ": 0";
        }
        int round = (int) Math.round((Math.log((double) bArr.length) / Math.log(10.0d)) + 0.5d);
        StringBuilder sb = new StringBuilder();
        writeHex(sb, 0, round, "");
        sb.append(": ");
        int i3 = -1;
        for (int i4 = 0; i4 < bArr.length; i4++) {
            i3++;
            if (i3 == i2) {
                sb.append('\n');
                writeHex(sb, (long) i4, round, "");
                sb.append(": ");
                i3 = 0;
            } else if (i4 > 0) {
                sb.append(", ");
            }
            sb.append(toHex(bArr[i4]));
        }
        return sb.toString();
    }

    public static void dump(InputStream inputStream, PrintStream printStream, int i2, int i3) {
        int read;
        ByteArrayOutputStream byteArrayOutputStream = new ByteArrayOutputStream();
        if (i3 != -1) {
            while (true) {
                int i4 = i3 - 1;
                if (i3 <= 0 || (read = inputStream.read()) == -1) {
                    break;
                }
                byteArrayOutputStream.write(read);
                i3 = i4;
            }
        } else {
            int read2 = inputStream.read();
            while (read2 != -1) {
                byteArrayOutputStream.write(read2);
                read2 = inputStream.read();
            }
        }
        byte[] byteArray = byteArrayOutputStream.toByteArray();
        dump(byteArray, 0, printStream, i2, byteArray.length);
    }

    public static String toHex(short s) {
        StringBuilder sb = new StringBuilder(4);
        writeHex(sb, (long) (s & 65535), 4, "");
        return sb.toString();
    }

    public static String toHex(byte b2) {
        StringBuilder sb = new StringBuilder(2);
        writeHex(sb, (long) (b2 & 255), 2, "");
        return sb.toString();
    }

    public static String toHex(int i2) {
        StringBuilder sb = new StringBuilder(8);
        writeHex(sb, ((long) i2) & Filetime.UINT_MASK, 8, "");
        return sb.toString();
    }

    public static String toHex(long j) {
        StringBuilder sb = new StringBuilder(16);
        writeHex(sb, j, 16, "");
        return sb.toString();
    }

    public static String toHex(String str) {
        return (str == null || str.length() == 0) ? "[]" : toHex(str.getBytes(LocaleUtil.CHARSET_1252));
    }
}
