package org.apache.poi.util;

import b.b.a.a.a;
import java.util.Iterator;
import java.util.LinkedList;
import java.util.ListIterator;

public class IdentifierManager {
    public static final long MAX_ID = 9223372036854775806L;
    public static final long MIN_ID = 0;
    public final long lowerbound;
    public LinkedList<Segment> segments;
    public final long upperbound;

    public static class Segment {
        public long end;
        public long start;

        public Segment(long j, long j2) {
            this.start = j;
            this.end = j2;
        }

        public String toString() {
            StringBuilder b2 = a.b("[");
            b2.append(this.start);
            b2.append("; ");
            b2.append(this.end);
            b2.append("]");
            return b2.toString();
        }
    }

    public IdentifierManager(long j, long j2) {
        if (j > j2) {
            throw new IllegalArgumentException("lowerbound must not be greater than upperbound, had " + j + " and " + j2);
        } else if (j < 0) {
            StringBuilder b2 = a.b("lowerbound must be greater than or equal to ");
            b2.append(Long.toString(0));
            throw new IllegalArgumentException(b2.toString());
        } else if (j2 <= MAX_ID) {
            this.lowerbound = j;
            this.upperbound = j2;
            LinkedList<Segment> linkedList = new LinkedList<>();
            this.segments = linkedList;
            linkedList.add(new Segment(j, j2));
        } else {
            StringBuilder b3 = a.b("upperbound must be less than or equal to ");
            b3.append(Long.toString(MAX_ID));
            b3.append(" but had ");
            b3.append(j2);
            throw new IllegalArgumentException(b3.toString());
        }
    }

    private void verifyIdentifiersLeft() {
        if (this.segments.isEmpty()) {
            throw new IllegalStateException("No identifiers left");
        }
    }

    public long getRemainingIdentifiers() {
        Iterator<Segment> it = this.segments.iterator();
        long j = 0;
        while (it.hasNext()) {
            Segment next = it.next();
            j = (j - next.start) + next.end + 1;
        }
        return j;
    }

    public boolean release(long j) {
        long j2 = this.lowerbound;
        if (j >= j2) {
            long j3 = this.upperbound;
            if (j <= j3) {
                if (j == j3) {
                    Segment last = this.segments.getLast();
                    long j4 = last.end;
                    long j5 = this.upperbound;
                    if (j4 == j5 - 1) {
                        last.end = j5;
                        return true;
                    } else if (j4 == j5) {
                        return false;
                    } else {
                        this.segments.add(new Segment(j5, j5));
                        return true;
                    }
                } else if (j == j2) {
                    Segment first = this.segments.getFirst();
                    long j6 = first.start;
                    long j7 = this.lowerbound;
                    if (j6 == 1 + j7) {
                        first.start = j7;
                        return true;
                    } else if (j6 == j7) {
                        return false;
                    } else {
                        this.segments.addFirst(new Segment(j7, j7));
                        return true;
                    }
                } else {
                    long j8 = j + 1;
                    long j9 = j - 1;
                    ListIterator<Segment> listIterator = this.segments.listIterator();
                    while (listIterator.hasNext()) {
                        Segment next = listIterator.next();
                        long j10 = next.end;
                        if (j10 >= j9) {
                            long j11 = next.start;
                            if (j11 > j8) {
                                listIterator.previous();
                                listIterator.add(new Segment(j, j));
                                return true;
                            } else if (j11 == j8) {
                                next.start = j;
                                return true;
                            } else if (j10 != j9) {
                                return false;
                            } else {
                                next.end = j;
                                if (listIterator.hasNext()) {
                                    Segment next2 = listIterator.next();
                                    if (next2.start == next.end + 1) {
                                        next.end = next2.end;
                                        listIterator.remove();
                                    }
                                }
                                return true;
                            }
                        }
                    }
                    return false;
                }
            }
        }
        throw new IllegalArgumentException("Value for parameter 'id' was out of bounds, had " + j + ", but should be within [" + this.lowerbound + ":" + this.upperbound + "]");
    }

    public long reserve(long j) {
        if (j < this.lowerbound || j > this.upperbound) {
            throw new IllegalArgumentException("Value for parameter 'id' was out of bounds, had " + j + ", but should be within [" + this.lowerbound + ":" + this.upperbound + "]");
        }
        verifyIdentifiersLeft();
        if (j == this.upperbound) {
            Segment last = this.segments.getLast();
            long j2 = last.end;
            long j3 = this.upperbound;
            if (j2 != j3) {
                return reserveNew();
            }
            long j4 = j3 - 1;
            last.end = j4;
            if (last.start > j4) {
                this.segments.removeLast();
            }
            return j;
        } else if (j == this.lowerbound) {
            Segment first = this.segments.getFirst();
            long j5 = first.start;
            long j6 = this.lowerbound;
            if (j5 != j6) {
                return reserveNew();
            }
            long j7 = j6 + 1;
            first.start = j7;
            if (first.end < j7) {
                this.segments.removeFirst();
            }
            return j;
        } else {
            ListIterator<Segment> listIterator = this.segments.listIterator();
            while (true) {
                if (!listIterator.hasNext()) {
                    break;
                }
                Segment next = listIterator.next();
                long j8 = next.end;
                if (j8 >= j) {
                    long j9 = next.start;
                    if (j9 <= j) {
                        if (j9 == j) {
                            long j10 = 1 + j;
                            next.start = j10;
                            if (j8 < j10) {
                                listIterator.remove();
                            }
                            return j;
                        } else if (j8 == j) {
                            long j11 = j - 1;
                            next.end = j11;
                            if (j9 > j11) {
                                listIterator.remove();
                            }
                            return j;
                        } else {
                            listIterator.add(new Segment(j + 1, j8));
                            next.end = j - 1;
                            return j;
                        }
                    }
                }
            }
            return reserveNew();
        }
    }

    public long reserveNew() {
        verifyIdentifiersLeft();
        Segment first = this.segments.getFirst();
        long j = first.start;
        long j2 = 1 + j;
        first.start = j2;
        if (j2 > first.end) {
            this.segments.removeFirst();
        }
        return j;
    }
}
