package org.apache.poi.util;

import java.io.InputStream;

public class IntegerField implements FixedField {
    public final int _offset;
    public int _value;

    public IntegerField(int i2) {
        if (i2 >= 0) {
            this._offset = i2;
            return;
        }
        throw new ArrayIndexOutOfBoundsException("negative offset");
    }

    public int get() {
        return this._value;
    }

    @Override // org.apache.poi.util.FixedField
    public void readFromBytes(byte[] bArr) {
        this._value = LittleEndian.getInt(bArr, this._offset);
    }

    @Override // org.apache.poi.util.FixedField
    public void readFromStream(InputStream inputStream) {
        this._value = LittleEndian.readInt(inputStream);
    }

    public void set(int i2) {
        this._value = i2;
    }

    @Override // org.apache.poi.util.FixedField
    public String toString() {
        return String.valueOf(this._value);
    }

    @Override // org.apache.poi.util.FixedField
    public void writeToBytes(byte[] bArr) {
        LittleEndian.putInt(bArr, this._offset, this._value);
    }

    public void set(int i2, byte[] bArr) {
        this._value = i2;
        writeToBytes(bArr);
    }

    public IntegerField(int i2, int i3) {
        this(i2);
        set(i3);
    }

    public IntegerField(int i2, byte[] bArr) {
        this(i2);
        readFromBytes(bArr);
    }

    public IntegerField(int i2, int i3, byte[] bArr) {
        this(i2);
        set(i3, bArr);
    }
}
