package org.apache.poi.util;

import java.io.ByteArrayOutputStream;
import java.io.InputStream;
import java.io.OutputStream;

public abstract class LZWDecompresser {
    public final int codeLengthIncrease;
    public final boolean maskMeansCompressed;
    public final boolean positionIsBigEndian;

    public LZWDecompresser(boolean z, int i2, boolean z2) {
        this.maskMeansCompressed = z;
        this.codeLengthIncrease = i2;
        this.positionIsBigEndian = z2;
    }

    public static int fromByte(byte b2) {
        return b2 >= 0 ? b2 : b2 + 256;
    }

    public static byte fromInt(int i2) {
        return i2 < 128 ? (byte) i2 : (byte) (i2 - 256);
    }

    public abstract int adjustDictionaryOffset(int i2);

    public byte[] decompress(InputStream inputStream) {
        ByteArrayOutputStream byteArrayOutputStream = new ByteArrayOutputStream();
        decompress(inputStream, byteArrayOutputStream);
        return byteArrayOutputStream.toByteArray();
    }

    public abstract int populateDictionary(byte[] bArr);

    public void decompress(InputStream inputStream, OutputStream outputStream) {
        int i2;
        byte[] bArr = new byte[4096];
        int populateDictionary = populateDictionary(bArr);
        byte[] bArr2 = new byte[(this.codeLengthIncrease + 16)];
        while (true) {
            int read = inputStream.read();
            if (read != -1) {
                for (int i3 = 1; i3 < 256; i3 <<= 1) {
                    if (!(((read & i3) > 0) ^ this.maskMeansCompressed)) {
                        int read2 = inputStream.read();
                        int read3 = inputStream.read();
                        if (read2 == -1 || read3 == -1) {
                            break;
                        }
                        int i4 = (read3 & 15) + this.codeLengthIncrease;
                        if (this.positionIsBigEndian) {
                            read2 <<= 4;
                            i2 = read3 >> 4;
                        } else {
                            i2 = (read3 & 240) << 4;
                        }
                        int adjustDictionaryOffset = adjustDictionaryOffset(read2 + i2);
                        for (int i5 = 0; i5 < i4; i5++) {
                            bArr2[i5] = bArr[(adjustDictionaryOffset + i5) & 4095];
                            bArr[(populateDictionary + i5) & 4095] = bArr2[i5];
                        }
                        outputStream.write(bArr2, 0, i4);
                        populateDictionary += i4;
                    } else {
                        int read4 = inputStream.read();
                        if (read4 != -1) {
                            bArr[populateDictionary & 4095] = fromInt(read4);
                            populateDictionary++;
                            outputStream.write(new byte[]{fromInt(read4)});
                        }
                    }
                }
            } else {
                return;
            }
        }
    }
}
