package org.apache.poi.util;

import java.io.IOException;
import java.io.InputStream;
import java.io.OutputStream;
import org.apache.poi.hpsf.Filetime;

public class LittleEndian implements LittleEndianConsts {

    public static final class BufferUnderrunException extends IOException {
        public static final long serialVersionUID = 8736973884877006145L;

        public BufferUnderrunException() {
            super("buffer underrun");
        }
    }

    public static byte[] getByteArray(byte[] bArr, int i2, int i3) {
        byte[] bArr2 = new byte[i3];
        System.arraycopy(bArr, i2, bArr2, 0, i3);
        return bArr2;
    }

    public static double getDouble(byte[] bArr) {
        return Double.longBitsToDouble(getLong(bArr, 0));
    }

    public static float getFloat(byte[] bArr) {
        return getFloat(bArr, 0);
    }

    public static int getInt(byte[] bArr) {
        return getInt(bArr, 0);
    }

    public static long getLong(byte[] bArr) {
        return getLong(bArr, 0);
    }

    public static short getShort(byte[] bArr) {
        return getShort(bArr, 0);
    }

    public static short[] getShortArray(byte[] bArr, int i2, int i3) {
        int i4 = i3 / 2;
        short[] sArr = new short[i4];
        for (int i5 = 0; i5 < i4; i5++) {
            sArr[i5] = getShort(bArr, (i5 * 2) + i2);
        }
        return sArr;
    }

    public static short getUByte(byte[] bArr) {
        return (short) (bArr[0] & 255);
    }

    public static long getUInt(byte[] bArr) {
        return getUInt(bArr, 0);
    }

    public static int getUShort(byte[] bArr) {
        return getUShort(bArr, 0);
    }

    public static void putByte(byte[] bArr, int i2, int i3) {
        bArr[i2] = (byte) i3;
    }

    public static void putDouble(byte[] bArr, int i2, double d2) {
        putLong(bArr, i2, Double.doubleToLongBits(d2));
    }

    public static void putFloat(byte[] bArr, int i2, float f2) {
        putInt(bArr, i2, Float.floatToIntBits(f2));
    }

    public static void putInt(byte[] bArr, int i2, int i3) {
        int i4 = i2 + 1;
        bArr[i2] = (byte) ((i3 >>> 0) & 255);
        int i5 = i4 + 1;
        bArr[i4] = (byte) ((i3 >>> 8) & 255);
        bArr[i5] = (byte) ((i3 >>> 16) & 255);
        bArr[i5 + 1] = (byte) ((i3 >>> 24) & 255);
    }

    public static void putLong(byte[] bArr, int i2, long j) {
        bArr[i2 + 0] = (byte) ((int) ((j >>> 0) & 255));
        bArr[i2 + 1] = (byte) ((int) ((j >>> 8) & 255));
        bArr[i2 + 2] = (byte) ((int) ((j >>> 16) & 255));
        bArr[i2 + 3] = (byte) ((int) ((j >>> 24) & 255));
        bArr[i2 + 4] = (byte) ((int) ((j >>> 32) & 255));
        bArr[i2 + 5] = (byte) ((int) ((j >>> 40) & 255));
        bArr[i2 + 6] = (byte) ((int) ((j >>> 48) & 255));
        bArr[i2 + 7] = (byte) ((int) ((j >>> 56) & 255));
    }

    public static void putShort(byte[] bArr, int i2, short s) {
        bArr[i2] = (byte) ((s >>> 0) & 255);
        bArr[i2 + 1] = (byte) ((s >>> 8) & 255);
    }

    public static void putShortArray(byte[] bArr, int i2, short[] sArr) {
        for (short s : sArr) {
            putShort(bArr, i2, s);
            i2 += 2;
        }
    }

    public static void putUByte(byte[] bArr, int i2, short s) {
        bArr[i2] = (byte) (s & 255);
    }

    public static void putUInt(byte[] bArr, int i2, long j) {
        int i3 = i2 + 1;
        bArr[i2] = (byte) ((int) ((j >>> 0) & 255));
        int i4 = i3 + 1;
        bArr[i3] = (byte) ((int) ((j >>> 8) & 255));
        bArr[i4] = (byte) ((int) ((j >>> 16) & 255));
        bArr[i4 + 1] = (byte) ((int) ((j >>> 24) & 255));
    }

    public static void putUShort(byte[] bArr, int i2, int i3) {
        bArr[i2] = (byte) ((i3 >>> 0) & 255);
        bArr[i2 + 1] = (byte) ((i3 >>> 8) & 255);
    }

    public static int readInt(InputStream inputStream) {
        int read = inputStream.read();
        int read2 = inputStream.read();
        int read3 = inputStream.read();
        int read4 = inputStream.read();
        if ((read | read2 | read3 | read4) >= 0) {
            return (read4 << 24) + (read3 << 16) + (read2 << 8) + (read << 0);
        }
        throw new BufferUnderrunException();
    }

    public static long readLong(InputStream inputStream) {
        int read = inputStream.read();
        int read2 = inputStream.read();
        int read3 = inputStream.read();
        int read4 = inputStream.read();
        int read5 = inputStream.read();
        int read6 = inputStream.read();
        int read7 = inputStream.read();
        int read8 = inputStream.read();
        if ((read | read2 | read3 | read4 | read5 | read6 | read7 | read8) >= 0) {
            return (((long) read8) << 56) + (((long) read7) << 48) + (((long) read6) << 40) + (((long) read5) << 32) + (((long) read4) << 24) + ((long) (read3 << 16)) + ((long) (read2 << 8)) + ((long) (read << 0));
        }
        throw new BufferUnderrunException();
    }

    public static short readShort(InputStream inputStream) {
        return (short) readUShort(inputStream);
    }

    public static long readUInt(InputStream inputStream) {
        return ((long) readInt(inputStream)) & Filetime.UINT_MASK;
    }

    public static int readUShort(InputStream inputStream) {
        int read = inputStream.read();
        int read2 = inputStream.read();
        if ((read | read2) >= 0) {
            return (read2 << 8) + (read << 0);
        }
        throw new BufferUnderrunException();
    }

    public static int ubyteToInt(byte b2) {
        return b2 & 255;
    }

    public static double getDouble(byte[] bArr, int i2) {
        return Double.longBitsToDouble(getLong(bArr, i2));
    }

    public static float getFloat(byte[] bArr, int i2) {
        return Float.intBitsToFloat(getInt(bArr, i2));
    }

    public static int getInt(byte[] bArr, int i2) {
        int i3 = i2 + 1;
        int i4 = i3 + 1;
        return ((bArr[i4 + 1] & 255) << 24) + ((bArr[i4] & 255) << 16) + ((bArr[i3] & 255) << 8) + ((bArr[i2] & 255) << 0);
    }

    public static long getLong(byte[] bArr, int i2) {
        long j = (long) (bArr[i2 + 7] & 255);
        for (int i3 = (i2 + 8) - 1; i3 >= i2; i3--) {
            j = (j << 8) | ((long) (bArr[i3] & 255));
        }
        return j;
    }

    public static short getShort(byte[] bArr, int i2) {
        return (short) (((bArr[i2 + 1] & 255) << 8) + ((bArr[i2] & 255) << 0));
    }

    public static short getUByte(byte[] bArr, int i2) {
        return (short) (bArr[i2] & 255);
    }

    public static long getUInt(byte[] bArr, int i2) {
        return ((long) getInt(bArr, i2)) & Filetime.UINT_MASK;
    }

    public static int getUShort(byte[] bArr, int i2) {
        return ((bArr[i2 + 1] & 255) << 8) + ((bArr[i2] & 255) << 0);
    }

    public static void putDouble(double d2, OutputStream outputStream) {
        putLong(Double.doubleToLongBits(d2), outputStream);
    }

    public static void putFloat(float f2, OutputStream outputStream) {
        putInt(Float.floatToIntBits(f2), outputStream);
    }

    public static void putShort(OutputStream outputStream, short s) {
        outputStream.write((byte) ((s >>> 0) & 255));
        outputStream.write((byte) ((s >>> 8) & 255));
    }

    public static void putUShort(int i2, OutputStream outputStream) {
        outputStream.write((byte) ((i2 >>> 0) & 255));
        outputStream.write((byte) ((i2 >>> 8) & 255));
    }

    public static void putInt(int i2, OutputStream outputStream) {
        outputStream.write((byte) ((i2 >>> 0) & 255));
        outputStream.write((byte) ((i2 >>> 8) & 255));
        outputStream.write((byte) ((i2 >>> 16) & 255));
        outputStream.write((byte) ((i2 >>> 24) & 255));
    }

    public static void putUInt(long j, OutputStream outputStream) {
        outputStream.write((byte) ((int) ((j >>> 0) & 255)));
        outputStream.write((byte) ((int) ((j >>> 8) & 255)));
        outputStream.write((byte) ((int) ((j >>> 16) & 255)));
        outputStream.write((byte) ((int) ((j >>> 24) & 255)));
    }

    public static void putLong(long j, OutputStream outputStream) {
        outputStream.write((byte) ((int) ((j >>> 0) & 255)));
        outputStream.write((byte) ((int) ((j >>> 8) & 255)));
        outputStream.write((byte) ((int) ((j >>> 16) & 255)));
        outputStream.write((byte) ((int) ((j >>> 24) & 255)));
        outputStream.write((byte) ((int) ((j >>> 32) & 255)));
        outputStream.write((byte) ((int) ((j >>> 40) & 255)));
        outputStream.write((byte) ((int) ((j >>> 48) & 255)));
        outputStream.write((byte) ((int) ((j >>> 56) & 255)));
    }
}
