package org.apache.poi.util;

import java.io.StringReader;
import java.util.concurrent.TimeUnit;
import javax.xml.XMLConstants;
import javax.xml.parsers.SAXParserFactory;
import org.xml.sax.EntityResolver;
import org.xml.sax.InputSource;
import org.xml.sax.XMLReader;

public final class SAXHelper {
    public static final EntityResolver IGNORING_ENTITY_RESOLVER = new EntityResolver() {
        /* class org.apache.poi.util.SAXHelper.AnonymousClass1 */

        @Override // org.xml.sax.EntityResolver
        public InputSource resolveEntity(String str, String str2) {
            return new InputSource(new StringReader(""));
        }
    };
    public static long lastLog;
    public static final POILogger logger = POILogFactory.getLogger(SAXHelper.class);
    public static final SAXParserFactory saxFactory;

    static {
        try {
            SAXParserFactory newInstance = SAXParserFactory.newInstance();
            saxFactory = newInstance;
            newInstance.setValidating(false);
            saxFactory.setNamespaceAware(true);
        } catch (RuntimeException e2) {
            logger.log(5, "Failed to create SAXParserFactory", e2);
            throw e2;
        } catch (Exception e3) {
            logger.log(5, "Failed to create SAXParserFactory", e3);
            throw new RuntimeException("Failed to create SAXParserFactory", e3);
        } catch (Error e4) {
            logger.log(5, "Failed to create SAXParserFactory", e4);
            throw e4;
        }
    }

    public static synchronized XMLReader newXMLReader() {
        XMLReader xMLReader;
        synchronized (SAXHelper.class) {
            xMLReader = saxFactory.newSAXParser().getXMLReader();
            xMLReader.setEntityResolver(IGNORING_ENTITY_RESOLVER);
            trySetSAXFeature(xMLReader, XMLConstants.FEATURE_SECURE_PROCESSING);
            trySetXercesSecurityManager(xMLReader);
        }
        return xMLReader;
    }

    public static void trySetSAXFeature(XMLReader xMLReader, String str) {
        try {
            xMLReader.setFeature(str, true);
        } catch (Exception e2) {
            logger.log(5, "SAX Feature unsupported", str, e2);
        } catch (AbstractMethodError e3) {
            logger.log(5, "Cannot set SAX feature because outdated XML parser in classpath", str, e3);
        }
    }

    public static void trySetXercesSecurityManager(XMLReader xMLReader) {
        String[] strArr = {"com.sun.org.apache.xerces.internal.util.SecurityManager", "org.apache.xerces.util.SecurityManager"};
        for (int i2 = 0; i2 < 2; i2++) {
            try {
                Object newInstance = Class.forName(strArr[i2]).newInstance();
                newInstance.getClass().getMethod("setEntityExpansionLimit", Integer.TYPE).invoke(newInstance, 4096);
                xMLReader.setProperty("http://apache.org/xml/properties/security-manager", newInstance);
                return;
            } catch (Throwable th) {
                if (System.currentTimeMillis() > TimeUnit.MINUTES.toMillis(5) + lastLog) {
                    logger.log(5, "SAX Security Manager could not be setup [log suppressed for 5 minutes]", th);
                    lastLog = System.currentTimeMillis();
                }
            }
        }
    }
}
