package org.apache.poi.util;

import b.b.a.a.a;
import java.nio.charset.Charset;
import java.util.HashMap;
import java.util.Iterator;
import java.util.Map;
import org.apache.poi.poifs.filesystem.Ole10Native;

@Internal
public class StringUtil {
    public static final Charset BIG5 = Charset.forName("Big5");
    public static final Charset ISO_8859_1 = Charset.forName(Ole10Native.ISO1);
    public static final Charset UTF16LE = Charset.forName("UTF-16LE");
    public static final Charset UTF8 = Charset.forName("UTF-8");
    public static final Charset WIN_1252 = Charset.forName("cp1252");
    public static final POILogger logger = POILogFactory.getLogger(StringUtil.class);
    public static Map<Integer, Integer> msCodepointToUnicode;
    public static final int[] symbolMap_f020 = {32, 33, 8704, 35, 8707, 37, 38, 8717, 40, 41, 8727, 43, 44, 8722, 46, 47, 48, 49, 50, 51, 52, 53, 54, 55, 56, 57, 58, 59, 60, 61, 62, 63, 8773, 913, 914, 935, 916, 917, 934, 915, 919, 921, 977, 922, 923, 924, 925, 927, 928, 920, 929, 931, CodePageUtil.CP_SJIS, 933, 962, 937, 926, CodePageUtil.CP_GBK, 918, 91, 8765, 93, 8869, 95, 32, 945, 946, 967, 948, CodePageUtil.CP_MS949, 966, 947, 951, 953, 981, 954, 955, 956, 957, 959, 960, 952, 961, 963, 964, 965, 982, 969, 958, 968, 950, 123, 124, 125, 8764, 32};
    public static final int[] symbolMap_f0a0 = {8364, 978, 8242, 8804, 8260, 8734, 402, 9827, 9830, 9829, 9824, 8596, 8591, 8593, 8594, 8595, 176, 177, 8243, 8805, 215, 181, 8706, 8729, 247, 8800, 8801, 8776, 8230, 9168, 9135, 8629, 8501, 8475, 8476, 8472, 8855, 8853, 8709, 8745, 8746, 8835, 8839, 8836, 8834, 8838, 8712, 8713, 8736, 8711, 174, 169, 8482, 8719, 8730, 8901, 172, 8743, 8744, 8660, 8656, 8657, 8658, 8659, 9674, 9001, 174, 169, 8482, 8721, 9115, 9116, 9117, 9121, 9122, 9123, 9127, 9128, 9129, 9130, 32, 9002, 8747, 8992, 9134, 8993, 9118, 9119, 9120, 9124, 9125, 9126, 9131, 9132, 9133, 32};

    public static class StringsIterator implements Iterator<String> {
        public int position = 0;
        public String[] strings = new String[0];

        public StringsIterator(String[] strArr) {
            if (strArr != null) {
                this.strings = (String[]) strArr.clone();
            }
        }

        public boolean hasNext() {
            return this.position < this.strings.length;
        }

        public void remove() {
        }

        @Override // java.util.Iterator
        public String next() {
            int i2 = this.position;
            this.position = i2 + 1;
            String[] strArr = this.strings;
            if (i2 < strArr.length) {
                return strArr[i2];
            }
            throw new ArrayIndexOutOfBoundsException(i2);
        }
    }

    public static int countMatches(CharSequence charSequence, char c) {
        if (charSequence == null) {
            return 0;
        }
        int length = charSequence.length();
        int i2 = 0;
        for (int i3 = 0; i3 < length; i3++) {
            if (charSequence.charAt(i3) == c) {
                i2++;
            }
        }
        return i2;
    }

    public static boolean endsWithIgnoreCase(String str, String str2) {
        int length = str2.length();
        return str.regionMatches(true, str.length() - length, str2, 0, length);
    }

    public static int getEncodedSize(String str) {
        return (str.length() * (hasMultibyte(str) ? 2 : 1)) + 3;
    }

    public static String getFromCompressedUnicode(byte[] bArr, int i2, int i3) {
        return new String(bArr, i2, Math.min(i3, bArr.length - i2), ISO_8859_1);
    }

    public static String getFromUnicodeLE(byte[] bArr, int i2, int i3) {
        if (i2 < 0 || i2 >= bArr.length) {
            throw new ArrayIndexOutOfBoundsException(a.a(a.a("Illegal offset ", i2, " (String data is of length "), bArr.length, ")"));
        } else if (i3 >= 0 && (bArr.length - i2) / 2 >= i3) {
            return new String(bArr, i2, i3 * 2, UTF16LE);
        } else {
            throw new IllegalArgumentException(a.c("Illegal length ", i3));
        }
    }

    public static String getPreferredEncoding() {
        return ISO_8859_1.name();
    }

    public static byte[] getToUnicodeLE(String str) {
        return str.getBytes(UTF16LE);
    }

    public static boolean hasMultibyte(String str) {
        if (str == null) {
            return false;
        }
        for (char c : str.toCharArray()) {
            if (c > 255) {
                return true;
            }
        }
        return false;
    }

    public static synchronized void initMsCodepointMap() {
        synchronized (StringUtil.class) {
            if (msCodepointToUnicode == null) {
                msCodepointToUnicode = new HashMap();
                int i2 = 61472;
                int[] iArr = symbolMap_f020;
                int length = iArr.length;
                int i3 = 0;
                int i4 = 0;
                while (i4 < length) {
                    msCodepointToUnicode.put(Integer.valueOf(i2), Integer.valueOf(iArr[i4]));
                    i4++;
                    i2++;
                }
                int i5 = 61600;
                int[] iArr2 = symbolMap_f0a0;
                int length2 = iArr2.length;
                while (i3 < length2) {
                    msCodepointToUnicode.put(Integer.valueOf(i5), Integer.valueOf(iArr2[i3]));
                    i3++;
                    i5++;
                }
            }
        }
    }

    public static boolean isUnicodeString(String str) {
        return !str.equals(new String(str.getBytes(ISO_8859_1), ISO_8859_1));
    }

    @Internal
    public static String join(Object[] objArr, String str) {
        if (objArr == null || objArr.length == 0) {
            return "";
        }
        StringBuilder sb = new StringBuilder();
        sb.append(objArr[0]);
        for (int i2 = 1; i2 < objArr.length; i2++) {
            sb.append(str);
            sb.append(objArr[i2]);
        }
        return sb.toString();
    }

    public static synchronized void mapMsCodepoint(int i2, int i3) {
        synchronized (StringUtil.class) {
            initMsCodepointMap();
            msCodepointToUnicode.put(Integer.valueOf(i2), Integer.valueOf(i3));
        }
    }

    public static String mapMsCodepointString(String str) {
        if (str == null || "".equals(str)) {
            return str;
        }
        initMsCodepointMap();
        StringBuilder sb = new StringBuilder();
        int length = str.length();
        int i2 = 0;
        while (i2 < length) {
            Integer valueOf = Integer.valueOf(str.codePointAt(i2));
            Integer num = msCodepointToUnicode.get(valueOf);
            if (num == null) {
                num = valueOf;
            }
            sb.appendCodePoint(num.intValue());
            i2 += Character.charCount(valueOf.intValue());
        }
        return sb.toString();
    }

    public static void putCompressedUnicode(String str, byte[] bArr, int i2) {
        byte[] bytes = str.getBytes(ISO_8859_1);
        System.arraycopy(bytes, 0, bArr, i2, bytes.length);
    }

    public static void putUnicodeLE(String str, byte[] bArr, int i2) {
        byte[] bytes = str.getBytes(UTF16LE);
        System.arraycopy(bytes, 0, bArr, i2, bytes.length);
    }

    public static String readCompressedUnicode(LittleEndianInput littleEndianInput, int i2) {
        byte[] bArr = new byte[i2];
        littleEndianInput.readFully(bArr);
        return new String(bArr, ISO_8859_1);
    }

    public static String readUnicodeLE(LittleEndianInput littleEndianInput, int i2) {
        byte[] bArr = new byte[(i2 * 2)];
        littleEndianInput.readFully(bArr);
        return new String(bArr, UTF16LE);
    }

    public static String readUnicodeString(LittleEndianInput littleEndianInput) {
        int readUShort = littleEndianInput.readUShort();
        if ((littleEndianInput.readByte() & 1) == 0) {
            return readCompressedUnicode(littleEndianInput, readUShort);
        }
        return readUnicodeLE(littleEndianInput, readUShort);
    }

    public static boolean startsWithIgnoreCase(String str, String str2) {
        return str.regionMatches(true, 0, str2, 0, str2.length());
    }

    public static void writeUnicodeString(LittleEndianOutput littleEndianOutput, String str) {
        littleEndianOutput.writeShort(str.length());
        boolean hasMultibyte = hasMultibyte(str);
        littleEndianOutput.writeByte(hasMultibyte ? 1 : 0);
        if (hasMultibyte) {
            putUnicodeLE(str, littleEndianOutput);
        } else {
            putCompressedUnicode(str, littleEndianOutput);
        }
    }

    public static void writeUnicodeStringFlagAndData(LittleEndianOutput littleEndianOutput, String str) {
        boolean hasMultibyte = hasMultibyte(str);
        littleEndianOutput.writeByte(hasMultibyte ? 1 : 0);
        if (hasMultibyte) {
            putUnicodeLE(str, littleEndianOutput);
        } else {
            putCompressedUnicode(str, littleEndianOutput);
        }
    }

    public static void putCompressedUnicode(String str, LittleEndianOutput littleEndianOutput) {
        littleEndianOutput.write(str.getBytes(ISO_8859_1));
    }

    public static void putUnicodeLE(String str, LittleEndianOutput littleEndianOutput) {
        littleEndianOutput.write(str.getBytes(UTF16LE));
    }

    public static String readUnicodeString(LittleEndianInput littleEndianInput, int i2) {
        if ((littleEndianInput.readByte() & 1) == 0) {
            return readCompressedUnicode(littleEndianInput, i2);
        }
        return readUnicodeLE(littleEndianInput, i2);
    }

    public static String getFromUnicodeLE(byte[] bArr) {
        if (bArr.length == 0) {
            return "";
        }
        return getFromUnicodeLE(bArr, 0, bArr.length / 2);
    }

    @Internal
    public static String join(Object[] objArr) {
        if (objArr == null) {
            return "";
        }
        StringBuilder sb = new StringBuilder();
        for (Object obj : objArr) {
            sb.append(obj);
        }
        return sb.toString();
    }

    @Internal
    public static String join(String str, Object... objArr) {
        return join(objArr, str);
    }
}
