package org.apache.poi.util;

public class Units {
    public static final float DEFAULT_CHARACTER_WIDTH = 7.0017f;
    public static final int EMU_PER_CENTIMETER = 360000;
    public static final int EMU_PER_CHARACTER = 66691;
    public static final int EMU_PER_PIXEL = 9525;
    public static final int EMU_PER_POINT = 12700;
    public static final int MASTER_DPI = 576;
    public static final int PIXEL_DPI = 96;
    public static final int POINT_DPI = 72;

    public static int TwipsToEMU(short s) {
        return (int) ((((double) s) / 20.0d) * 12700.0d);
    }

    public static int charactersToEMU(double d2) {
        return ((int) d2) * EMU_PER_CHARACTER;
    }

    public static int columnWidthToEMU(int i2) {
        return charactersToEMU(((double) i2) / 256.0d);
    }

    public static int doubleToFixedPoint(double d2) {
        double d3 = d2 % 1.0d;
        return (((int) Math.floor(d2 - d3)) << 16) | (((int) Math.rint(d3 * 65536.0d)) & 65535);
    }

    public static double fixedPointToDouble(int i2) {
        return (((double) (i2 & 65535)) / 65536.0d) + ((double) (i2 >> 16));
    }

    public static double masterToPoints(int i2) {
        return (((double) i2) * 72.0d) / 576.0d;
    }

    public static int pixelToEMU(int i2) {
        return i2 * 9525;
    }

    public static double pixelToPoints(int i2) {
        return (((double) i2) * 72.0d) / 96.0d;
    }

    public static int pointsToMaster(double d2) {
        return (int) Math.rint((d2 * 576.0d) / 72.0d);
    }

    public static int pointsToPixel(double d2) {
        return (int) Math.rint((d2 * 96.0d) / 72.0d);
    }

    public static int toEMU(double d2) {
        return (int) Math.rint(d2 * 12700.0d);
    }

    public static double toPoints(long j) {
        return ((double) j) / 12700.0d;
    }
}
