package org.apache.poi.xdgf.extractor;

import org.apache.poi.POIXMLDocument;
import org.apache.poi.POIXMLTextExtractor;
import org.apache.poi.openxml4j.opc.OPCPackage;
import org.apache.poi.xdgf.usermodel.XDGFPage;
import org.apache.poi.xdgf.usermodel.XmlVisioDocument;
import org.apache.poi.xdgf.usermodel.shape.ShapeTextVisitor;

public class XDGFVisioExtractor extends POIXMLTextExtractor {
    public final XmlVisioDocument document;

    public XDGFVisioExtractor(XmlVisioDocument xmlVisioDocument) {
        super(xmlVisioDocument);
        this.document = xmlVisioDocument;
    }

    public static void main(String[] strArr) {
        if (strArr.length < 1) {
            System.err.println("Use:");
            System.err.println("  XDGFVisioExtractor <filename.vsdx>");
            System.exit(1);
        }
        XDGFVisioExtractor xDGFVisioExtractor = new XDGFVisioExtractor(POIXMLDocument.openPackage(strArr[0]));
        System.out.println(xDGFVisioExtractor.getText());
        xDGFVisioExtractor.close();
    }

    @Override // org.apache.poi.POITextExtractor
    public String getText() {
        ShapeTextVisitor shapeTextVisitor = new ShapeTextVisitor();
        for (XDGFPage xDGFPage : this.document.getPages()) {
            xDGFPage.getContent().visitShapes(shapeTextVisitor);
        }
        return shapeTextVisitor.getText().toString();
    }

    public XDGFVisioExtractor(OPCPackage oPCPackage) {
        this(new XmlVisioDocument(oPCPackage));
    }
}
