package org.apache.poi.xdgf.usermodel;

import b.e.a.a.c.a.a.b;
import b.e.a.a.c.a.a.j;
import b.e.a.a.c.a.a.r;
import java.awt.Graphics2D;
import java.awt.geom.AffineTransform;
import java.util.ArrayList;
import java.util.Collection;
import java.util.Collections;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import org.apache.poi.POIXMLException;
import org.apache.poi.openxml4j.opc.PackagePart;
import org.apache.poi.util.Internal;
import org.apache.poi.xdgf.exceptions.XDGFException;
import org.apache.poi.xdgf.usermodel.shape.ShapeRenderer;
import org.apache.poi.xdgf.usermodel.shape.ShapeVisitor;
import org.apache.poi.xdgf.usermodel.shape.exceptions.StopVisiting;
import org.apache.poi.xdgf.xml.XDGFXMLDocumentPart;

public class XDGFBaseContents extends XDGFXMLDocumentPart {
    public List<XDGFConnection> _connections = new ArrayList();
    public j _pageContents;
    public Map<Long, XDGFShape> _shapes = new HashMap();
    public List<XDGFShape> _toplevelShapes = new ArrayList();

    public XDGFBaseContents(PackagePart packagePart, XDGFDocument xDGFDocument) {
        super(packagePart, xDGFDocument);
    }

    public void addToShapeIndex(XDGFShape xDGFShape) {
        this._shapes.put(Long.valueOf(xDGFShape.getID()), xDGFShape);
        List<XDGFShape> shapes = xDGFShape.getShapes();
        if (shapes != null) {
            for (XDGFShape xDGFShape2 : shapes) {
                addToShapeIndex(xDGFShape2);
            }
        }
    }

    public void draw(Graphics2D graphics2D) {
        visitShapes(new ShapeRenderer(graphics2D));
    }

    public List<XDGFConnection> getConnections() {
        return Collections.unmodifiableList(this._connections);
    }

    public XDGFShape getShapeById(long j) {
        return this._shapes.get(Long.valueOf(j));
    }

    public Collection<XDGFShape> getShapes() {
        return this._shapes.values();
    }

    public Map<Long, XDGFShape> getShapesMap() {
        return Collections.unmodifiableMap(this._shapes);
    }

    public List<XDGFShape> getTopLevelShapes() {
        return Collections.unmodifiableList(this._toplevelShapes);
    }

    @Internal
    public j getXmlObject() {
        return this._pageContents;
    }

    @Override // org.apache.poi.POIXMLDocumentPart
    public void onDocumentRead() {
        if (this._pageContents.e()) {
            for (r rVar : this._pageContents.getShapes().j()) {
                XDGFShape xDGFShape = new XDGFShape(rVar, this, this._document);
                this._toplevelShapes.add(xDGFShape);
                addToShapeIndex(xDGFShape);
            }
        }
        if (this._pageContents.m()) {
            b[] S = this._pageContents.g().S();
            for (b bVar : S) {
                XDGFShape xDGFShape2 = this._shapes.get(Long.valueOf(bVar.s()));
                XDGFShape xDGFShape3 = this._shapes.get(Long.valueOf(bVar.R()));
                if (xDGFShape2 == null) {
                    throw new POIXMLException(this + "; Connect; Invalid from id: " + bVar.s());
                } else if (xDGFShape3 != null) {
                    this._connections.add(new XDGFConnection(bVar, xDGFShape2, xDGFShape3));
                } else {
                    throw new POIXMLException(this + "; Connect; Invalid to id: " + bVar.R());
                }
            }
        }
    }

    @Override // org.apache.poi.POIXMLDocumentPart
    public String toString() {
        return getPackagePart().getPartName().toString();
    }

    public void visitShapes(ShapeVisitor shapeVisitor) {
        try {
            for (XDGFShape xDGFShape : this._toplevelShapes) {
                xDGFShape.visitShapes(shapeVisitor, new AffineTransform(), 0);
            }
        } catch (StopVisiting unused) {
        } catch (POIXMLException e2) {
            throw XDGFException.wrap(this, e2);
        }
    }
}
