package org.apache.poi.xdgf.usermodel;

import b.b.a.a.a;
import b.e.a.a.c.a.a.r;
import b.e.a.a.c.a.a.w;
import java.awt.BasicStroke;
import java.awt.Stroke;
import java.awt.geom.AffineTransform;
import java.awt.geom.Path2D;
import java.awt.geom.Rectangle2D;
import java.util.ArrayList;
import java.util.List;
import java.util.Map;
import java.util.SortedMap;
import org.apache.poi.POIXMLException;
import org.apache.poi.java.awt.Color;
import org.apache.poi.ss.formula.functions.NumericFunction;
import org.apache.poi.util.Internal;
import org.apache.poi.xdgf.exceptions.XDGFException;
import org.apache.poi.xdgf.usermodel.section.CombinedIterable;
import org.apache.poi.xdgf.usermodel.section.GeometrySection;
import org.apache.poi.xdgf.usermodel.section.XDGFSection;
import org.apache.poi.xdgf.usermodel.shape.ShapeVisitor;
import org.apache.poi.xdgf.usermodel.shape.exceptions.StopVisitingThisBranch;

public class XDGFShape extends XDGFSheet {
    public Double _angle;
    public Double _beginX;
    public Double _beginY;
    public Double _endX;
    public Double _endY;
    public Boolean _flipX;
    public Boolean _flipY;
    public Double _height;
    public Double _locPinX;
    public Double _locPinY;
    public XDGFMaster _master;
    public XDGFShape _masterShape;
    public XDGFShape _parent;
    public XDGFBaseContents _parentPage;
    public Double _pinX;
    public Double _pinY;
    public Double _rotationXAngle;
    public Double _rotationYAngle;
    public Double _rotationZAngle;
    public List<XDGFShape> _shapes;
    public XDGFText _text;
    public Double _txtAngle;
    public Double _txtHeight;
    public Double _txtLocPinX;
    public Double _txtLocPinY;
    public Double _txtPinX;
    public Double _txtPinY;
    public Double _txtWidth;
    public Double _width;

    public XDGFShape(r rVar, XDGFBaseContents xDGFBaseContents, XDGFDocument xDGFDocument) {
        this(null, rVar, xDGFBaseContents, xDGFDocument);
    }

    public Double getAngle() {
        XDGFShape xDGFShape;
        if (this._angle != null || (xDGFShape = this._masterShape) == null) {
            return this._angle;
        }
        return xDGFShape.getAngle();
    }

    public Double getBeginX() {
        XDGFShape xDGFShape;
        if (this._beginX != null || (xDGFShape = this._masterShape) == null) {
            return this._beginX;
        }
        return xDGFShape.getBeginX();
    }

    public Double getBeginY() {
        XDGFShape xDGFShape;
        if (this._beginY != null || (xDGFShape = this._masterShape) == null) {
            return this._beginY;
        }
        return xDGFShape.getBeginY();
    }

    public Rectangle2D.Double getBounds() {
        return new Rectangle2D.Double((double) NumericFunction.LOG_10_TO_BASE_e, (double) NumericFunction.LOG_10_TO_BASE_e, getWidth().doubleValue(), getHeight().doubleValue());
    }

    public Path2D.Double getBoundsAsPath() {
        Double width = getWidth();
        Double height = getHeight();
        Path2D.Double r2 = new Path2D.Double();
        r2.moveTo((double) NumericFunction.LOG_10_TO_BASE_e, (double) NumericFunction.LOG_10_TO_BASE_e);
        r2.lineTo(width.doubleValue(), (double) NumericFunction.LOG_10_TO_BASE_e);
        r2.lineTo(width.doubleValue(), height.doubleValue());
        r2.lineTo((double) NumericFunction.LOG_10_TO_BASE_e, height.doubleValue());
        r2.lineTo((double) NumericFunction.LOG_10_TO_BASE_e, (double) NumericFunction.LOG_10_TO_BASE_e);
        return r2;
    }

    @Override // org.apache.poi.xdgf.usermodel.XDGFSheet
    public XDGFCell getCell(String str) {
        XDGFShape xDGFShape;
        XDGFCell cell = super.getCell(str);
        return (cell != null || (xDGFShape = this._masterShape) == null) ? cell : xDGFShape.getCell(str);
    }

    public Double getEndX() {
        XDGFShape xDGFShape;
        if (this._endX != null || (xDGFShape = this._masterShape) == null) {
            return this._endX;
        }
        return xDGFShape.getEndX();
    }

    public Double getEndY() {
        XDGFShape xDGFShape;
        if (this._endY != null || (xDGFShape = this._masterShape) == null) {
            return this._endY;
        }
        return xDGFShape.getEndY();
    }

    public Boolean getFlipX() {
        XDGFShape xDGFShape;
        if (this._flipX != null || (xDGFShape = this._masterShape) == null) {
            return this._flipX;
        }
        return xDGFShape.getFlipX();
    }

    public Boolean getFlipY() {
        XDGFShape xDGFShape;
        if (this._flipY != null || (xDGFShape = this._masterShape) == null) {
            return this._flipY;
        }
        return xDGFShape.getFlipY();
    }

    @Override // org.apache.poi.xdgf.usermodel.XDGFSheet
    public Color getFontColor() {
        Color fontColor = super.getFontColor();
        if (fontColor != null) {
            return fontColor;
        }
        XDGFShape xDGFShape = this._masterShape;
        if (xDGFShape != null) {
            return xDGFShape.getFontColor();
        }
        return this._document.getDefaultTextStyle().getFontColor();
    }

    @Override // org.apache.poi.xdgf.usermodel.XDGFSheet
    public Double getFontSize() {
        Double fontSize = super.getFontSize();
        if (fontSize != null) {
            return fontSize;
        }
        XDGFShape xDGFShape = this._masterShape;
        if (xDGFShape != null) {
            return xDGFShape.getFontSize();
        }
        return this._document.getDefaultTextStyle().getFontSize();
    }

    public GeometrySection getGeometryByIdx(long j) {
        return this._geometry.get(Long.valueOf(j));
    }

    public Iterable<GeometrySection> getGeometrySections() {
        SortedMap<Long, GeometrySection> sortedMap = this._geometry;
        XDGFShape xDGFShape = this._masterShape;
        return new CombinedIterable(sortedMap, xDGFShape != null ? xDGFShape._geometry : null);
    }

    public Double getHeight() {
        XDGFShape xDGFShape;
        if (this._height == null && (xDGFShape = this._masterShape) != null) {
            return xDGFShape.getHeight();
        }
        Double d2 = this._height;
        if (d2 != null) {
            return d2;
        }
        throw XDGFException.error("Height not specified!", this);
    }

    public long getID() {
        return getXmlObject().getID();
    }

    @Override // org.apache.poi.xdgf.usermodel.XDGFSheet
    public Integer getLineCap() {
        Integer lineCap = super.getLineCap();
        if (lineCap != null) {
            return lineCap;
        }
        XDGFShape xDGFShape = this._masterShape;
        if (xDGFShape != null) {
            return xDGFShape.getLineCap();
        }
        return this._document.getDefaultLineStyle().getLineCap();
    }

    @Override // org.apache.poi.xdgf.usermodel.XDGFSheet
    public Color getLineColor() {
        Color lineColor = super.getLineColor();
        if (lineColor != null) {
            return lineColor;
        }
        XDGFShape xDGFShape = this._masterShape;
        if (xDGFShape != null) {
            return xDGFShape.getLineColor();
        }
        return this._document.getDefaultLineStyle().getLineColor();
    }

    @Override // org.apache.poi.xdgf.usermodel.XDGFSheet
    public Integer getLinePattern() {
        Integer linePattern = super.getLinePattern();
        if (linePattern != null) {
            return linePattern;
        }
        XDGFShape xDGFShape = this._masterShape;
        if (xDGFShape != null) {
            return xDGFShape.getLinePattern();
        }
        return this._document.getDefaultLineStyle().getLinePattern();
    }

    @Override // org.apache.poi.xdgf.usermodel.XDGFSheet
    public Double getLineWeight() {
        Double lineWeight = super.getLineWeight();
        if (lineWeight != null) {
            return lineWeight;
        }
        XDGFShape xDGFShape = this._masterShape;
        if (xDGFShape != null) {
            return xDGFShape.getLineWeight();
        }
        return this._document.getDefaultLineStyle().getLineWeight();
    }

    public Double getLocPinX() {
        XDGFShape xDGFShape;
        if (this._locPinX == null && (xDGFShape = this._masterShape) != null) {
            return xDGFShape.getLocPinX();
        }
        Double d2 = this._locPinX;
        if (d2 != null) {
            return d2;
        }
        throw XDGFException.error("LocPinX not specified!", this);
    }

    public Double getLocPinY() {
        XDGFShape xDGFShape;
        if (this._locPinY == null && (xDGFShape = this._masterShape) != null) {
            return xDGFShape.getLocPinY();
        }
        Double d2 = this._locPinY;
        if (d2 != null) {
            return d2;
        }
        throw XDGFException.error("LocPinY not specified!", this);
    }

    public XDGFShape getMasterShape() {
        return this._masterShape;
    }

    public String getName() {
        String name = getXmlObject().getName();
        return name == null ? "" : name;
    }

    public XDGFShape getParentShape() {
        return this._parent;
    }

    public AffineTransform getParentTransform() {
        AffineTransform affineTransform = new AffineTransform();
        Double locPinX = getLocPinX();
        Double locPinY = getLocPinY();
        Boolean flipX = getFlipX();
        Boolean flipY = getFlipY();
        Double angle = getAngle();
        affineTransform.translate(-locPinX.doubleValue(), -locPinY.doubleValue());
        affineTransform.translate(getPinX().doubleValue(), getPinY().doubleValue());
        if (angle != null && Math.abs(angle.doubleValue()) > 0.001d) {
            affineTransform.rotate(angle.doubleValue(), locPinX.doubleValue(), locPinY.doubleValue());
        }
        if (flipX != null && flipX.booleanValue()) {
            affineTransform.scale(-1.0d, 1.0d);
            affineTransform.translate(-getWidth().doubleValue(), (double) NumericFunction.LOG_10_TO_BASE_e);
        }
        if (flipY != null && flipY.booleanValue()) {
            affineTransform.scale(1.0d, -1.0d);
            affineTransform.translate((double) NumericFunction.LOG_10_TO_BASE_e, -getHeight().doubleValue());
        }
        return affineTransform;
    }

    public Path2D.Double getPath() {
        for (GeometrySection geometrySection : getGeometrySections()) {
            if (!geometrySection.getNoShow().booleanValue()) {
                return geometrySection.getPath(this);
            }
        }
        return null;
    }

    public Double getPinX() {
        XDGFShape xDGFShape;
        if (this._pinX == null && (xDGFShape = this._masterShape) != null) {
            return xDGFShape.getPinX();
        }
        Double d2 = this._pinX;
        if (d2 != null) {
            return d2;
        }
        throw XDGFException.error("PinX not set!", this);
    }

    public Double getPinY() {
        XDGFShape xDGFShape;
        if (this._pinY == null && (xDGFShape = this._masterShape) != null) {
            return xDGFShape.getPinY();
        }
        Double d2 = this._pinY;
        if (d2 != null) {
            return d2;
        }
        throw XDGFException.error("PinY not specified!", this);
    }

    public String getShapeType() {
        String type = getXmlObject().getType();
        return type == null ? "" : type;
    }

    public List<XDGFShape> getShapes() {
        return this._shapes;
    }

    public Stroke getStroke() {
        int i2;
        float[] fArr;
        float[] fArr2;
        float floatValue = getLineWeight().floatValue();
        int intValue = getLineCap().intValue();
        if (intValue == 0) {
            i2 = 1;
        } else if (intValue == 1) {
            i2 = 2;
        } else if (intValue == 2) {
            i2 = 0;
        } else {
            throw new POIXMLException("Invalid line cap specified");
        }
        int intValue2 = getLinePattern().intValue();
        if (intValue2 != 254) {
            switch (intValue2) {
                case 0:
                case 1:
                    fArr = null;
                    break;
                case 2:
                    fArr2 = new float[]{5.0f, 3.0f};
                    fArr = fArr2;
                    break;
                case 3:
                    fArr2 = new float[]{1.0f, 4.0f};
                    fArr = fArr2;
                    break;
                case 4:
                    fArr2 = new float[]{6.0f, 3.0f, 1.0f, 3.0f};
                    fArr = fArr2;
                    break;
                case 5:
                    fArr2 = new float[]{6.0f, 3.0f, 1.0f, 3.0f, 1.0f, 3.0f};
                    fArr = fArr2;
                    break;
                case 6:
                    fArr2 = new float[]{1.0f, 3.0f, 6.0f, 3.0f, 6.0f, 3.0f};
                    fArr = fArr2;
                    break;
                case 7:
                    fArr2 = new float[]{15.0f, 3.0f, 6.0f, 3.0f};
                    fArr = fArr2;
                    break;
                case 8:
                    fArr2 = new float[]{6.0f, 3.0f, 6.0f, 3.0f};
                    fArr = fArr2;
                    break;
                case 9:
                    fArr2 = new float[]{3.0f, 2.0f};
                    fArr = fArr2;
                    break;
                case 10:
                    fArr2 = new float[]{1.0f, 2.0f};
                    fArr = fArr2;
                    break;
                case 11:
                    fArr2 = new float[]{3.0f, 2.0f, 1.0f, 2.0f};
                    fArr = fArr2;
                    break;
                case 12:
                    fArr2 = new float[]{3.0f, 2.0f, 1.0f, 2.0f, 1.0f};
                    fArr = fArr2;
                    break;
                case 13:
                    fArr2 = new float[]{1.0f, 2.0f, 3.0f, 2.0f, 3.0f, 2.0f};
                    fArr = fArr2;
                    break;
                case 14:
                    fArr2 = new float[]{3.0f, 2.0f, 7.0f, 2.0f};
                    fArr = fArr2;
                    break;
                case 15:
                    fArr2 = new float[]{7.0f, 2.0f, 3.0f, 2.0f, 3.0f, 2.0f};
                    fArr = fArr2;
                    break;
                case 16:
                    fArr2 = new float[]{12.0f, 6.0f};
                    fArr = fArr2;
                    break;
                case 17:
                    fArr2 = new float[]{1.0f, 6.0f};
                    fArr = fArr2;
                    break;
                case 18:
                    fArr2 = new float[]{1.0f, 6.0f, 12.0f, 6.0f};
                    fArr = fArr2;
                    break;
                case 19:
                    fArr2 = new float[]{1.0f, 6.0f, 1.0f, 6.0f, 12.0f, 6.0f};
                    fArr = fArr2;
                    break;
                case 20:
                    fArr2 = new float[]{1.0f, 6.0f, 12.0f, 6.0f, 12.0f, 6.0f};
                    fArr = fArr2;
                    break;
                case 21:
                    fArr2 = new float[]{30.0f, 6.0f, 12.0f, 6.0f};
                    fArr = fArr2;
                    break;
                case 22:
                    fArr2 = new float[]{30.0f, 6.0f, 12.0f, 6.0f, 12.0f, 6.0f};
                    fArr = fArr2;
                    break;
                case 23:
                    fArr2 = new float[]{1.0f};
                    fArr = fArr2;
                    break;
                default:
                    throw new POIXMLException("Invalid line pattern value");
            }
            if (fArr != null) {
                for (int i3 = 0; i3 < fArr.length; i3++) {
                    fArr[i3] = fArr[i3] * floatValue;
                }
            }
            return new BasicStroke(floatValue, i2, 0, 10.0f, fArr, 0.0f);
        }
        throw new POIXMLException("Unsupported line pattern value");
    }

    public String getSymbolName() {
        String name;
        XDGFMaster xDGFMaster = this._master;
        if (xDGFMaster == null || (name = xDGFMaster.getName()) == null) {
            return "";
        }
        return name;
    }

    public XDGFText getText() {
        XDGFShape xDGFShape;
        if (this._text != null || (xDGFShape = this._masterShape) == null) {
            return this._text;
        }
        return xDGFShape.getText();
    }

    public String getTextAsString() {
        XDGFText text = getText();
        if (text == null) {
            return "";
        }
        return text.getTextContent();
    }

    public XDGFShape getTopmostParentShape() {
        XDGFShape xDGFShape = this._parent;
        if (xDGFShape == null) {
            return null;
        }
        XDGFShape topmostParentShape = xDGFShape.getTopmostParentShape();
        return topmostParentShape == null ? this._parent : topmostParentShape;
    }

    public Double getTxtAngle() {
        XDGFShape xDGFShape;
        if (this._txtAngle != null || (xDGFShape = this._masterShape) == null) {
            return this._txtAngle;
        }
        return xDGFShape.getTxtAngle();
    }

    public Double getTxtHeight() {
        XDGFShape xDGFShape;
        Double d2;
        if (this._txtHeight == null && (xDGFShape = this._masterShape) != null && (d2 = xDGFShape._txtHeight) != null) {
            return d2;
        }
        Double d3 = this._txtHeight;
        return d3 == null ? getHeight() : d3;
    }

    public Double getTxtLocPinX() {
        XDGFShape xDGFShape;
        Double d2;
        if (this._txtLocPinX == null && (xDGFShape = this._masterShape) != null && (d2 = xDGFShape._txtLocPinX) != null) {
            return d2;
        }
        Double d3 = this._txtLocPinX;
        return d3 == null ? Double.valueOf(getTxtWidth().doubleValue() * 0.5d) : d3;
    }

    public Double getTxtLocPinY() {
        XDGFShape xDGFShape;
        Double d2;
        if (this._txtLocPinY == null && (xDGFShape = this._masterShape) != null && (d2 = xDGFShape._txtLocPinY) != null) {
            return d2;
        }
        Double d3 = this._txtLocPinY;
        return d3 == null ? Double.valueOf(getTxtHeight().doubleValue() * 0.5d) : d3;
    }

    public Double getTxtPinX() {
        XDGFShape xDGFShape;
        Double d2;
        if (this._txtPinX == null && (xDGFShape = this._masterShape) != null && (d2 = xDGFShape._txtPinX) != null) {
            return d2;
        }
        Double d3 = this._txtPinX;
        return d3 == null ? Double.valueOf(getWidth().doubleValue() * 0.5d) : d3;
    }

    public Double getTxtPinY() {
        XDGFShape xDGFShape;
        Double d2;
        if (this._txtLocPinY == null && (xDGFShape = this._masterShape) != null && (d2 = xDGFShape._txtLocPinY) != null) {
            return d2;
        }
        Double d3 = this._txtPinY;
        return d3 == null ? Double.valueOf(getHeight().doubleValue() * 0.5d) : d3;
    }

    public Double getTxtWidth() {
        XDGFShape xDGFShape;
        Double d2;
        if (this._txtWidth == null && (xDGFShape = this._masterShape) != null && (d2 = xDGFShape._txtWidth) != null) {
            return d2;
        }
        Double d3 = this._txtWidth;
        return d3 == null ? getWidth() : d3;
    }

    public String getType() {
        return getXmlObject().getType();
    }

    public Double getWidth() {
        XDGFShape xDGFShape;
        if (this._width == null && (xDGFShape = this._masterShape) != null) {
            return xDGFShape.getWidth();
        }
        Double d2 = this._width;
        if (d2 != null) {
            return d2;
        }
        throw XDGFException.error("Width not specified!", this);
    }

    public boolean hasGeometry() {
        for (GeometrySection geometrySection : getGeometrySections()) {
            if (!geometrySection.getNoShow().booleanValue()) {
                return true;
            }
        }
        return false;
    }

    public boolean hasMaster() {
        return this._master != null;
    }

    public boolean hasMasterShape() {
        return this._masterShape != null;
    }

    public boolean hasParent() {
        return this._parent != null;
    }

    public boolean hasShapes() {
        return this._shapes != null;
    }

    public boolean hasText() {
        XDGFShape xDGFShape;
        return (this._text == null && ((xDGFShape = this._masterShape) == null || xDGFShape._text == null)) ? false : true;
    }

    public boolean isDeleted() {
        if (getXmlObject().isSetDel()) {
            return getXmlObject().getDel();
        }
        return false;
    }

    public boolean isShape1D() {
        return getBeginX() != null;
    }

    public boolean isTopmost() {
        return this._parent == null;
    }

    public void readProperties() {
        this._pinX = XDGFCell.maybeGetDouble(this._cells, "PinX");
        this._pinY = XDGFCell.maybeGetDouble(this._cells, "PinY");
        this._width = XDGFCell.maybeGetDouble(this._cells, "Width");
        this._height = XDGFCell.maybeGetDouble(this._cells, "Height");
        this._locPinX = XDGFCell.maybeGetDouble(this._cells, "LocPinX");
        this._locPinY = XDGFCell.maybeGetDouble(this._cells, "LocPinY");
        this._beginX = XDGFCell.maybeGetDouble(this._cells, "BeginX");
        this._beginY = XDGFCell.maybeGetDouble(this._cells, "BeginY");
        this._endX = XDGFCell.maybeGetDouble(this._cells, "EndX");
        this._endY = XDGFCell.maybeGetDouble(this._cells, "EndY");
        this._angle = XDGFCell.maybeGetDouble(this._cells, "Angle");
        this._rotationXAngle = XDGFCell.maybeGetDouble(this._cells, "RotationXAngle");
        this._rotationYAngle = XDGFCell.maybeGetDouble(this._cells, "RotationYAngle");
        this._rotationZAngle = XDGFCell.maybeGetDouble(this._cells, "RotationZAngle");
        this._flipX = XDGFCell.maybeGetBoolean(this._cells, "FlipX");
        this._flipY = XDGFCell.maybeGetBoolean(this._cells, "FlipY");
        this._txtPinX = XDGFCell.maybeGetDouble(this._cells, "TxtPinX");
        this._txtPinY = XDGFCell.maybeGetDouble(this._cells, "TxtPinY");
        this._txtLocPinX = XDGFCell.maybeGetDouble(this._cells, "TxtLocPinX");
        this._txtLocPinY = XDGFCell.maybeGetDouble(this._cells, "TxtLocPinY");
        this._txtWidth = XDGFCell.maybeGetDouble(this._cells, "TxtWidth");
        this._txtHeight = XDGFCell.maybeGetDouble(this._cells, "TxtHeight");
        this._txtAngle = XDGFCell.maybeGetDouble(this._cells, "TxtAngle");
    }

    public void setupMaster(XDGFPageContents xDGFPageContents, XDGFMasterContents xDGFMasterContents) {
        r xmlObject = getXmlObject();
        if (xmlObject.B()) {
            XDGFMaster masterById = xDGFPageContents.getMasterById(xmlObject.p());
            this._master = masterById;
            if (masterById != null) {
                List<XDGFShape> topLevelShapes = masterById.getContent().getTopLevelShapes();
                int size = topLevelShapes.size();
                if (size == 0) {
                    StringBuilder b2 = a.b("Could not retrieve master shape from ");
                    b2.append(this._master);
                    throw XDGFException.error(b2.toString(), this);
                } else if (size == 1) {
                    this._masterShape = topLevelShapes.iterator().next();
                }
            } else {
                StringBuilder b3 = a.b("refers to non-existant master ");
                b3.append(xmlObject.p());
                throw XDGFException.error(b3.toString(), this);
            }
        } else if (xmlObject.X()) {
            XDGFShape shapeById = xDGFMasterContents.getShapeById(xmlObject.M());
            this._masterShape = shapeById;
            if (shapeById == null) {
                StringBuilder b4 = a.b("refers to non-existant master shape ");
                b4.append(xmlObject.M());
                throw XDGFException.error(b4.toString(), this);
            }
        }
        setupSectionMasters();
        List<XDGFShape> list = this._shapes;
        if (list != null) {
            for (XDGFShape xDGFShape : list) {
                XDGFMaster xDGFMaster = this._master;
                xDGFShape.setupMaster(xDGFPageContents, xDGFMaster == null ? xDGFMasterContents : xDGFMaster.getContent());
            }
        }
    }

    public void setupSectionMasters() {
        if (this._masterShape != null) {
            try {
                for (Map.Entry<String, XDGFSection> entry : this._sections.entrySet()) {
                    XDGFSection section = this._masterShape.getSection(entry.getKey());
                    if (section != null) {
                        entry.getValue().setupMaster(section);
                    }
                }
                for (Map.Entry<Long, GeometrySection> entry2 : this._geometry.entrySet()) {
                    GeometrySection geometryByIdx = this._masterShape.getGeometryByIdx(entry2.getKey().longValue());
                    if (geometryByIdx != null) {
                        entry2.getValue().setupMaster(geometryByIdx);
                    }
                }
            } catch (POIXMLException e2) {
                throw XDGFException.wrap(toString(), e2);
            }
        }
    }

    public String toString() {
        if (this._parentPage instanceof XDGFMasterContents) {
            return this._parentPage + ": <Shape ID=\"" + getID() + "\">";
        }
        StringBuilder b2 = a.b("<Shape ID=\"");
        b2.append(getID());
        b2.append("\">");
        return b2.toString();
    }

    public void visitShapes(ShapeVisitor shapeVisitor, AffineTransform affineTransform, int i2) {
        AffineTransform affineTransform2 = (AffineTransform) affineTransform.clone();
        affineTransform2.concatenate(getParentTransform());
        try {
            if (shapeVisitor.accept(this)) {
                shapeVisitor.visit(this, affineTransform2, i2);
            }
            if (this._shapes != null) {
                for (XDGFShape xDGFShape : this._shapes) {
                    xDGFShape.visitShapes(shapeVisitor, affineTransform2, i2 + 1);
                }
            }
        } catch (StopVisitingThisBranch unused) {
        } catch (POIXMLException e2) {
            throw XDGFException.wrap(toString(), e2);
        }
    }

    public XDGFShape(XDGFShape xDGFShape, r rVar, XDGFBaseContents xDGFBaseContents, XDGFDocument xDGFDocument) {
        super(rVar, xDGFDocument);
        this._master = null;
        this._masterShape = null;
        this._text = null;
        this._shapes = null;
        this._pinX = null;
        this._pinY = null;
        this._width = null;
        this._height = null;
        this._locPinX = null;
        this._locPinY = null;
        this._beginX = null;
        this._beginY = null;
        this._endX = null;
        this._endY = null;
        this._angle = null;
        this._rotationXAngle = null;
        this._rotationYAngle = null;
        this._rotationZAngle = null;
        this._flipX = null;
        this._flipY = null;
        this._txtPinX = null;
        this._txtPinY = null;
        this._txtLocPinX = null;
        this._txtLocPinY = null;
        this._txtAngle = null;
        this._txtWidth = null;
        this._txtHeight = null;
        this._parent = xDGFShape;
        this._parentPage = xDGFBaseContents;
        w text = rVar.getText();
        if (text != null) {
            this._text = new XDGFText(text, this);
        }
        if (rVar.e()) {
            this._shapes = new ArrayList();
            for (r rVar2 : rVar.getShapes().j()) {
                this._shapes.add(new XDGFShape(this, rVar2, xDGFBaseContents, xDGFDocument));
            }
        }
        readProperties();
    }

    @Override // org.apache.poi.xdgf.usermodel.XDGFSheet
    @Internal
    public r getXmlObject() {
        return (r) this._sheet;
    }

    public void visitShapes(ShapeVisitor shapeVisitor, int i2) {
        try {
            if (shapeVisitor.accept(this)) {
                shapeVisitor.visit(this, null, i2);
            }
            if (this._shapes != null) {
                for (XDGFShape xDGFShape : this._shapes) {
                    xDGFShape.visitShapes(shapeVisitor, i2 + 1);
                }
            }
        } catch (StopVisitingThisBranch unused) {
        } catch (POIXMLException e2) {
            throw XDGFException.wrap(toString(), e2);
        }
    }
}
