package org.apache.poi.xdgf.usermodel.section;

import java.util.Collections;
import java.util.Iterator;
import java.util.Map;
import java.util.NoSuchElementException;
import java.util.SortedMap;

public class CombinedIterable<T> implements Iterable<T> {
    public final SortedMap<Long, T> _baseItems;
    public final SortedMap<Long, T> _masterItems;

    public CombinedIterable(SortedMap<Long, T> sortedMap, SortedMap<Long, T> sortedMap2) {
        this._baseItems = sortedMap;
        this._masterItems = sortedMap2;
    }

    @Override // java.lang.Iterable
    public Iterator<T> iterator() {
        final Iterator<Map.Entry<Long, T>> it;
        SortedMap<Long, T> sortedMap = this._masterItems;
        if (sortedMap != null) {
            it = sortedMap.entrySet().iterator();
        } else {
            it = Collections.emptySet().iterator();
        }
        return new Iterator<T>() {
            /* class org.apache.poi.xdgf.usermodel.section.CombinedIterable.AnonymousClass1 */
            public Iterator<Map.Entry<Long, T>> baseI = CombinedIterable.this._baseItems.entrySet().iterator();
            public Map.Entry<Long, T> currentBase = null;
            public Map.Entry<Long, T> currentMaster = null;
            public Long lastI = Long.MIN_VALUE;
            public Iterator<Map.Entry<Long, T>> masterI = it;

            public boolean hasNext() {
                return this.currentBase != null || this.currentMaster != null || this.baseI.hasNext() || this.masterI.hasNext();
            }

            @Override // java.util.Iterator
            public T next() {
                long j;
                Map.Entry<Long, T> entry = this.currentBase;
                long j2 = Long.MAX_VALUE;
                if (entry == null) {
                    while (true) {
                        if (!this.baseI.hasNext()) {
                            j = Long.MAX_VALUE;
                            break;
                        }
                        Map.Entry<Long, T> next = this.baseI.next();
                        this.currentBase = next;
                        if (next.getKey().longValue() > this.lastI.longValue()) {
                            j = this.currentBase.getKey().longValue();
                            break;
                        }
                    }
                } else {
                    j = entry.getKey().longValue();
                }
                Map.Entry<Long, T> entry2 = this.currentMaster;
                if (entry2 == null) {
                    while (true) {
                        if (!this.masterI.hasNext()) {
                            break;
                        }
                        Map.Entry<Long, T> next2 = this.masterI.next();
                        this.currentMaster = next2;
                        if (next2.getKey().longValue() > this.lastI.longValue()) {
                            j2 = this.currentMaster.getKey().longValue();
                            break;
                        }
                    }
                } else {
                    j2 = entry2.getKey().longValue();
                }
                if (this.currentBase == null) {
                    Map.Entry<Long, T> entry3 = this.currentMaster;
                    if (entry3 != null) {
                        this.lastI = entry3.getKey();
                        T value = this.currentMaster.getValue();
                        this.currentMaster = null;
                        return value;
                    }
                    throw new NoSuchElementException();
                } else if (j <= j2) {
                    this.lastI = Long.valueOf(j);
                    T value2 = this.currentBase.getValue();
                    if (j2 == j) {
                        this.currentMaster = null;
                    }
                    this.currentBase = null;
                    return value2;
                } else {
                    this.lastI = Long.valueOf(j2);
                    Map.Entry<Long, T> entry4 = this.currentMaster;
                    T value3 = entry4 != null ? entry4.getValue() : null;
                    this.currentMaster = null;
                    return value3;
                }
            }

            public void remove() {
                throw new UnsupportedOperationException();
            }
        };
    }
}
