package org.apache.poi.xdgf.usermodel.section;

import b.b.a.a.a;
import b.e.a.a.c.a.a.p;
import b.e.a.a.c.a.a.q;
import java.awt.geom.Path2D;
import java.util.Iterator;
import java.util.Map;
import java.util.SortedMap;
import java.util.TreeMap;
import org.apache.poi.POIXMLException;
import org.apache.poi.xdgf.geom.SplineCollector;
import org.apache.poi.xdgf.usermodel.XDGFCell;
import org.apache.poi.xdgf.usermodel.XDGFShape;
import org.apache.poi.xdgf.usermodel.XDGFSheet;
import org.apache.poi.xdgf.usermodel.section.geometry.Ellipse;
import org.apache.poi.xdgf.usermodel.section.geometry.GeometryRow;
import org.apache.poi.xdgf.usermodel.section.geometry.GeometryRowFactory;
import org.apache.poi.xdgf.usermodel.section.geometry.InfiniteLine;
import org.apache.poi.xdgf.usermodel.section.geometry.SplineKnot;
import org.apache.poi.xdgf.usermodel.section.geometry.SplineStart;

public class GeometrySection extends XDGFSection {
    public GeometrySection _master = null;
    public SortedMap<Long, GeometryRow> _rows = new TreeMap();

    public GeometrySection(q qVar, XDGFSheet xDGFSheet) {
        super(qVar, xDGFSheet);
        p[] rowArray = qVar.getRowArray();
        for (p pVar : rowArray) {
            if (!this._rows.containsKey(Long.valueOf(pVar.f()))) {
                this._rows.put(Long.valueOf(pVar.f()), GeometryRowFactory.load(pVar));
            } else {
                StringBuilder b2 = a.b("Index element '");
                b2.append(pVar.f());
                b2.append("' already exists");
                throw new POIXMLException(b2.toString());
            }
        }
    }

    public Iterable<GeometryRow> getCombinedRows() {
        SortedMap<Long, GeometryRow> sortedMap = this._rows;
        GeometrySection geometrySection = this._master;
        return new CombinedIterable(sortedMap, geometrySection == null ? null : geometrySection._rows);
    }

    public Boolean getNoShow() {
        Boolean maybeGetBoolean = XDGFCell.maybeGetBoolean(this._cells, "NoShow");
        if (maybeGetBoolean != null) {
            return maybeGetBoolean;
        }
        GeometrySection geometrySection = this._master;
        if (geometrySection != null) {
            return geometrySection.getNoShow();
        }
        return false;
    }

    public Path2D.Double getPath(XDGFShape xDGFShape) {
        GeometryRow geometryRow;
        Iterator<GeometryRow> it = getCombinedRows().iterator();
        GeometryRow next = it.next();
        if (next instanceof Ellipse) {
            return ((Ellipse) next).getPath();
        }
        if (next instanceof InfiniteLine) {
            return ((InfiniteLine) next).getPath();
        }
        if (!(next instanceof SplineStart)) {
            Path2D.Double r2 = new Path2D.Double();
            SplineCollector splineCollector = null;
            while (true) {
                if (next != null) {
                    geometryRow = null;
                } else if (!it.hasNext()) {
                    if (splineCollector != null) {
                        splineCollector.addToPath(r2, xDGFShape);
                    }
                    return r2;
                } else {
                    geometryRow = next;
                    next = it.next();
                }
                if (next instanceof SplineStart) {
                    if (splineCollector == null) {
                        splineCollector = new SplineCollector((SplineStart) next);
                    } else {
                        throw new POIXMLException("SplineStart found multiple times!");
                    }
                } else if (!(next instanceof SplineKnot)) {
                    if (splineCollector != null) {
                        splineCollector.addToPath(r2, xDGFShape);
                        splineCollector = null;
                    }
                    next.addToPath(r2, xDGFShape);
                } else if (splineCollector != null) {
                    splineCollector.addKnot((SplineKnot) next);
                } else {
                    throw new POIXMLException("SplineKnot found without SplineStart!");
                }
                next = geometryRow;
            }
        } else {
            throw new POIXMLException("SplineStart must be preceded by another type");
        }
    }

    @Override // org.apache.poi.xdgf.usermodel.section.XDGFSection
    public void setupMaster(XDGFSection xDGFSection) {
        this._master = (GeometrySection) xDGFSection;
        for (Map.Entry<Long, GeometryRow> entry : this._rows.entrySet()) {
            GeometryRow geometryRow = this._master._rows.get(entry.getKey());
            if (geometryRow != null) {
                try {
                    entry.getValue().setupMaster(geometryRow);
                } catch (ClassCastException unused) {
                }
            }
        }
    }
}
