package org.apache.poi.xdgf.util;

import b.b.a.a.a;
import java.awt.Graphics2D;
import java.awt.RenderingHints;
import java.awt.image.BufferedImage;
import java.io.File;
import java.io.FileInputStream;
import java.io.FileOutputStream;
import java.io.PrintStream;
import javax.imageio.ImageIO;
import org.apache.poi.java.awt.Color;
import org.apache.poi.openxml4j.opc.ContentTypes;
import org.apache.poi.ss.formula.ptg.UnaryMinusPtg;
import org.apache.poi.xdgf.geom.Dimension2dDouble;
import org.apache.poi.xdgf.usermodel.XDGFPage;
import org.apache.poi.xdgf.usermodel.XmlVisioDocument;
import org.apache.poi.xdgf.usermodel.shape.ShapeDebuggerRenderer;
import org.apache.poi.xdgf.usermodel.shape.ShapeRenderer;

public class VsdxToPng {
    public static void main(String[] strArr) {
        if (strArr.length > 2) {
            System.err.println("Usage: [--debug] in.vsdx outdir");
            System.exit(1);
        }
        ShapeRenderer shapeRenderer = new ShapeRenderer();
        String str = strArr[0];
        String str2 = strArr[1];
        if (strArr[0].equals("--debug")) {
            str = strArr[1];
            str2 = strArr[2];
            shapeRenderer = new ShapeDebuggerRenderer();
        }
        renderToPng(new XmlVisioDocument(new FileInputStream(str)), str2, 181.8181818181818d, shapeRenderer);
    }

    public static void renderToPng(XDGFPage xDGFPage, String str, double d2, ShapeRenderer shapeRenderer) {
        renderToPng(xDGFPage, new File(str), d2, shapeRenderer);
    }

    public static void renderToPngDir(XDGFPage xDGFPage, File file, double d2, ShapeRenderer shapeRenderer) {
        StringBuilder b2 = a.b("page");
        b2.append(xDGFPage.getPageNumber());
        b2.append(UnaryMinusPtg.MINUS);
        b2.append(Util.sanitizeFilename(xDGFPage.getName()));
        b2.append(".png");
        File file2 = new File(file, b2.toString());
        PrintStream printStream = System.out;
        printStream.println("** Writing image to " + file2);
        renderToPng(xDGFPage, file2, d2, shapeRenderer);
    }

    public static void renderToPng(XDGFPage xDGFPage, File file, double d2, ShapeRenderer shapeRenderer) {
        Dimension2dDouble pageSize = xDGFPage.getPageSize();
        int width = (int) (pageSize.getWidth() * d2);
        int height = (int) (pageSize.getHeight() * d2);
        BufferedImage bufferedImage = new BufferedImage(width, height, 1);
        Graphics2D createGraphics = bufferedImage.createGraphics();
        createGraphics.setRenderingHint(RenderingHints.KEY_ANTIALIASING, RenderingHints.VALUE_ANTIALIAS_ON);
        createGraphics.setRenderingHint(RenderingHints.KEY_RENDERING, RenderingHints.VALUE_RENDER_QUALITY);
        createGraphics.setRenderingHint(RenderingHints.KEY_INTERPOLATION, RenderingHints.VALUE_INTERPOLATION_BICUBIC);
        createGraphics.setRenderingHint(RenderingHints.KEY_FRACTIONALMETRICS, RenderingHints.VALUE_FRACTIONALMETRICS_ON);
        createGraphics.setColor(Color.black);
        createGraphics.setBackground(Color.white);
        createGraphics.clearRect(0, 0, width, height);
        createGraphics.translate(0, bufferedImage.getHeight());
        createGraphics.scale(d2, -d2);
        shapeRenderer.setGraphics(createGraphics);
        xDGFPage.getContent().visitShapes(shapeRenderer);
        createGraphics.dispose();
        FileOutputStream fileOutputStream = new FileOutputStream(file);
        try {
            ImageIO.write(bufferedImage, ContentTypes.EXTENSION_PNG, fileOutputStream);
        } finally {
            fileOutputStream.close();
        }
    }

    public static void renderToPng(XmlVisioDocument xmlVisioDocument, String str, double d2, ShapeRenderer shapeRenderer) {
        File file = new File(str);
        for (XDGFPage xDGFPage : xmlVisioDocument.getPages()) {
            renderToPngDir(xDGFPage, file, d2, shapeRenderer);
        }
    }
}
