package org.apache.poi.xslf.usermodel;

import b.b.a.a.a;
import java.awt.Dimension;
import java.io.File;
import java.io.FileInputStream;
import java.io.IOException;
import java.io.InputStream;
import java.io.OutputStream;
import java.util.ArrayList;
import java.util.Arrays;
import java.util.Collections;
import java.util.HashMap;
import java.util.Iterator;
import java.util.List;
import java.util.regex.Pattern;
import org.apache.poi.POIXMLDocument;
import org.apache.poi.POIXMLDocumentPart;
import org.apache.poi.POIXMLException;
import org.apache.poi.POIXMLTypeLoader;
import org.apache.poi.openxml4j.opc.OPCPackage;
import org.apache.poi.openxml4j.opc.PackagePart;
import org.apache.poi.sl.usermodel.MasterSheet;
import org.apache.poi.sl.usermodel.PictureData;
import org.apache.poi.sl.usermodel.Resources;
import org.apache.poi.sl.usermodel.Slide;
import org.apache.poi.sl.usermodel.SlideShow;
import org.apache.poi.util.IOUtils;
import org.apache.poi.util.Internal;
import org.apache.poi.util.LittleEndian;
import org.apache.poi.util.POILogFactory;
import org.apache.poi.util.POILogger;
import org.apache.poi.util.PackageHelper;
import org.apache.poi.util.Units;
import org.apache.xmlbeans.XmlException;
import org.apache.xmlbeans.XmlObject;
import org.openxmlformats.schemas.drawingml.x2006.main.CTTextParagraphProperties;
import org.openxmlformats.schemas.presentationml.x2006.main.CTPresentation;
import org.openxmlformats.schemas.presentationml.x2006.main.CTSlideIdList;
import org.openxmlformats.schemas.presentationml.x2006.main.CTSlideIdListEntry;
import org.openxmlformats.schemas.presentationml.x2006.main.CTSlideMasterIdListEntry;
import org.openxmlformats.schemas.presentationml.x2006.main.CTSlideSize;
import org.openxmlformats.schemas.presentationml.x2006.main.PresentationDocument;

public class XMLSlideShow extends POIXMLDocument implements SlideShow<XSLFShape, XSLFTextParagraph> {
    public static final POILogger LOG = POILogFactory.getLogger(XMLSlideShow.class);
    public XSLFCommentAuthors _commentAuthors;
    public List<XSLFSlideMaster> _masters;
    public XSLFNotesMaster _notesMaster;
    public List<XSLFPictureData> _pictures;
    public CTPresentation _presentation;
    public List<XSLFSlide> _slides;
    public XSLFTableStyles _tableStyles;

    public XMLSlideShow() {
        this(empty());
    }

    private XSLFNotes createNotesSlide(XSLFSlide xSLFSlide) {
        if (this._notesMaster == null) {
            createNotesMaster();
        }
        Integer fileNameIndex = XSLFRelation.SLIDE.getFileNameIndex(xSLFSlide);
        while (true) {
            String fileName = XSLFRelation.NOTES.getFileName(fileNameIndex.intValue());
            boolean z = false;
            Iterator<POIXMLDocumentPart> it = getRelations().iterator();
            while (true) {
                if (!it.hasNext()) {
                    break;
                }
                POIXMLDocumentPart next = it.next();
                if (next.getPackagePart() != null && fileName.equals(next.getPackagePart().getPartName().getName())) {
                    z = true;
                    break;
                }
            }
            if (!z && getPackage().getPartsByName(Pattern.compile(Pattern.quote(fileName))).size() > 0) {
                z = true;
            }
            if (!z) {
                XSLFNotes xSLFNotes = (XSLFNotes) createRelationship(XSLFRelation.NOTES, XSLFFactory.getInstance(), fileNameIndex.intValue());
                xSLFSlide.addRelation(null, XSLFRelation.NOTES, xSLFNotes);
                xSLFNotes.addRelation(null, XSLFRelation.NOTES_MASTER, this._notesMaster);
                xSLFNotes.addRelation(null, XSLFRelation.SLIDE, xSLFSlide);
                xSLFNotes.importContent(this._notesMaster);
                return xSLFNotes;
            }
            fileNameIndex = Integer.valueOf(fileNameIndex.intValue() + 1);
        }
    }

    public static OPCPackage empty() {
        InputStream resourceAsStream = XMLSlideShow.class.getResourceAsStream("empty.pptx");
        if (resourceAsStream != null) {
            try {
                OPCPackage open = OPCPackage.open(resourceAsStream);
                IOUtils.closeQuietly(resourceAsStream);
                return open;
            } catch (Exception e2) {
                throw new POIXMLException(e2);
            } catch (Throwable th) {
                IOUtils.closeQuietly(resourceAsStream);
                throw th;
            }
        } else {
            throw new POIXMLException("Missing resource 'empty.pptx'");
        }
    }

    @Override // org.apache.poi.POIXMLDocumentPart
    public void commit() {
        OutputStream outputStream = getPackagePart().getOutputStream();
        this._presentation.save(outputStream, POIXMLTypeLoader.DEFAULT_XML_OPTIONS);
        outputStream.close();
    }

    @Override // org.apache.poi.sl.usermodel.SlideShow
    public MasterSheet<XSLFShape, XSLFTextParagraph> createMasterSheet() {
        throw new UnsupportedOperationException();
    }

    public void createNotesMaster() {
        Integer num = 1;
        POIXMLDocumentPart.RelationPart createRelationship = createRelationship(XSLFRelation.NOTES_MASTER, XSLFFactory.getInstance(), 1, false);
        this._notesMaster = (XSLFNotesMaster) createRelationship.getDocumentPart();
        this._presentation.addNewNotesMasterIdLst().addNewNotesMasterId().setId(createRelationship.getRelationship().getId());
        ArrayList arrayList = new ArrayList();
        for (POIXMLDocumentPart pOIXMLDocumentPart : getRelations()) {
            if (pOIXMLDocumentPart instanceof XSLFTheme) {
                arrayList.add(XSLFRelation.THEME.getFileNameIndex(pOIXMLDocumentPart));
            }
        }
        if (!arrayList.isEmpty()) {
            Boolean bool = false;
            Integer num2 = num;
            while (num.intValue() <= arrayList.size()) {
                if (!arrayList.contains(num)) {
                    bool = true;
                    num2 = num;
                }
                num = Integer.valueOf(num.intValue() + 1);
            }
            num = !bool.booleanValue() ? Integer.valueOf(arrayList.size() + 1) : num2;
        }
        XSLFTheme xSLFTheme = (XSLFTheme) createRelationship(XSLFRelation.THEME, XSLFFactory.getInstance(), num.intValue());
        xSLFTheme.importTheme(((XSLFSlide) getSlides().get(0)).getTheme());
        this._notesMaster.addRelation(null, XSLFRelation.THEME, xSLFTheme);
    }

    public XSLFSlideLayout findLayout(String str) {
        Iterator<? extends MasterSheet<XSLFShape, XSLFTextParagraph>> it = getSlideMasters().iterator();
        while (it.hasNext()) {
            XSLFSlideLayout layout = ((XSLFSlideMaster) it.next()).getLayout(str);
            if (layout != null) {
                return layout;
            }
        }
        return null;
    }

    @Override // org.apache.poi.POIXMLDocument
    public List<PackagePart> getAllEmbedds() {
        return Collections.unmodifiableList(getPackage().getPartsByName(Pattern.compile("/ppt/embeddings/.*?")));
    }

    @Internal
    public CTPresentation getCTPresentation() {
        return this._presentation;
    }

    public XSLFCommentAuthors getCommentAuthors() {
        return this._commentAuthors;
    }

    public CTTextParagraphProperties getDefaultParagraphStyle(int i2) {
        CTPresentation cTPresentation = this._presentation;
        StringBuilder b2 = a.b("declare namespace p='http://schemas.openxmlformats.org/presentationml/2006/main' declare namespace a='http://schemas.openxmlformats.org/drawingml/2006/main' .//p:defaultTextStyle/a:lvl");
        b2.append(i2 + 1);
        b2.append("pPr");
        XmlObject[] selectPath = cTPresentation.selectPath(b2.toString());
        if (selectPath.length == 1) {
            return (CTTextParagraphProperties) selectPath[0];
        }
        return null;
    }

    public XSLFNotesMaster getNotesMaster() {
        return this._notesMaster;
    }

    public XSLFNotes getNotesSlide(XSLFSlide xSLFSlide) {
        XSLFNotes notes = xSLFSlide.getNotes();
        return notes == null ? createNotesSlide(xSLFSlide) : notes;
    }

    @Override // org.apache.poi.sl.usermodel.SlideShow
    public Dimension getPageSize() {
        CTSlideSize sldSz = this._presentation.getSldSz();
        return new Dimension((int) Units.toPoints((long) sldSz.getCx()), (int) Units.toPoints((long) sldSz.getCy()));
    }

    @Override // org.apache.poi.sl.usermodel.SlideShow
    public List<XSLFPictureData> getPictureData() {
        if (this._pictures == null) {
            List<PackagePart> partsByName = getPackage().getPartsByName(Pattern.compile("/ppt/media/.*?"));
            this._pictures = new ArrayList(partsByName.size());
            for (PackagePart packagePart : partsByName) {
                XSLFPictureData xSLFPictureData = new XSLFPictureData(packagePart);
                xSLFPictureData.setIndex(this._pictures.size());
                this._pictures.add(xSLFPictureData);
            }
        }
        return Collections.unmodifiableList(this._pictures);
    }

    @Override // org.apache.poi.sl.usermodel.SlideShow
    public Resources getResources() {
        throw new UnsupportedOperationException();
    }

    /* Return type fixed from 'java.util.List<org.apache.poi.xslf.usermodel.XSLFSlideMaster>' to match base method */
    @Override // org.apache.poi.sl.usermodel.SlideShow
    public List<? extends MasterSheet<XSLFShape, XSLFTextParagraph>> getSlideMasters() {
        return this._masters;
    }

    /* Return type fixed from 'java.util.List<org.apache.poi.xslf.usermodel.XSLFSlide>' to match base method */
    @Override // org.apache.poi.sl.usermodel.SlideShow
    public List<? extends Slide<XSLFShape, XSLFTextParagraph>> getSlides() {
        return this._slides;
    }

    public XSLFTableStyles getTableStyles() {
        return this._tableStyles;
    }

    @Override // org.apache.poi.POIXMLDocumentPart
    public void onDocumentRead() {
        try {
            this._presentation = PresentationDocument.Factory.parse(getCorePart().getInputStream(), POIXMLTypeLoader.DEFAULT_XML_OPTIONS).getPresentation();
            HashMap hashMap = new HashMap();
            HashMap hashMap2 = new HashMap();
            for (POIXMLDocumentPart.RelationPart relationPart : getRelationParts()) {
                POIXMLDocumentPart documentPart = relationPart.getDocumentPart();
                if (documentPart instanceof XSLFSlide) {
                    hashMap2.put(relationPart.getRelationship().getId(), (XSLFSlide) documentPart);
                } else if (documentPart instanceof XSLFSlideMaster) {
                    hashMap.put(getRelationId(documentPart), (XSLFSlideMaster) documentPart);
                } else if (documentPart instanceof XSLFTableStyles) {
                    this._tableStyles = (XSLFTableStyles) documentPart;
                } else if (documentPart instanceof XSLFNotesMaster) {
                    this._notesMaster = (XSLFNotesMaster) documentPart;
                } else if (documentPart instanceof XSLFCommentAuthors) {
                    this._commentAuthors = (XSLFCommentAuthors) documentPart;
                }
            }
            this._masters = new ArrayList(hashMap.size());
            for (CTSlideMasterIdListEntry cTSlideMasterIdListEntry : this._presentation.getSldMasterIdLst().getSldMasterIdList()) {
                this._masters.add((XSLFSlideMaster) hashMap.get(cTSlideMasterIdListEntry.getId2()));
            }
            this._slides = new ArrayList(hashMap2.size());
            if (this._presentation.isSetSldIdLst()) {
                for (CTSlideIdListEntry cTSlideIdListEntry : this._presentation.getSldIdLst().getSldIdList()) {
                    XSLFSlide xSLFSlide = (XSLFSlide) hashMap2.get(cTSlideIdListEntry.getId2());
                    if (xSLFSlide == null) {
                        POILogger pOILogger = LOG;
                        pOILogger.log(5, "Slide with r:id " + cTSlideIdListEntry.getId() + " was defined, but didn't exist in package, skipping");
                    } else {
                        this._slides.add(xSLFSlide);
                    }
                }
            }
        } catch (XmlException e2) {
            throw new POIXMLException(e2);
        }
    }

    public XSLFSlide removeSlide(int i2) {
        XSLFSlide remove = this._slides.remove(i2);
        removeRelation(remove);
        this._presentation.getSldIdLst().removeSldId(i2);
        return remove;
    }

    @Override // org.apache.poi.sl.usermodel.SlideShow
    public void setPageSize(Dimension dimension) {
        CTSlideSize newInstance = CTSlideSize.Factory.newInstance();
        newInstance.setCx(Units.toEMU(dimension.getWidth()));
        newInstance.setCy(Units.toEMU(dimension.getHeight()));
        this._presentation.setSldSz(newInstance);
    }

    public void setSlideOrder(XSLFSlide xSLFSlide, int i2) {
        int indexOf = this._slides.indexOf(xSLFSlide);
        if (indexOf == -1) {
            throw new IllegalArgumentException("Slide not found");
        } else if (indexOf != i2) {
            List<XSLFSlide> list = this._slides;
            list.add(i2, list.remove(indexOf));
            CTSlideIdList sldIdLst = this._presentation.getSldIdLst();
            CTSlideIdListEntry[] sldIdArray = sldIdLst.getSldIdArray();
            CTSlideIdListEntry cTSlideIdListEntry = sldIdArray[indexOf];
            if (indexOf < i2) {
                System.arraycopy(sldIdArray, indexOf + 1, sldIdArray, indexOf, i2 - indexOf);
            } else {
                System.arraycopy(sldIdArray, i2, sldIdArray, i2 + 1, indexOf - i2);
            }
            sldIdArray[i2] = cTSlideIdListEntry;
            sldIdLst.setSldIdArray(sldIdArray);
        }
    }

    public XMLSlideShow(OPCPackage oPCPackage) {
        super(oPCPackage);
        try {
            if (getCorePart().getContentType().equals(XSLFRelation.THEME_MANAGER.getContentType())) {
                rebase(getPackage());
            }
            load(XSLFFactory.getInstance());
        } catch (Exception e2) {
            throw new POIXMLException(e2);
        }
    }

    public XSLFSlide createSlide(XSLFSlideLayout xSLFSlideLayout) {
        CTSlideIdList cTSlideIdList;
        boolean z;
        int i2 = 1;
        int i3 = 256;
        if (!this._presentation.isSetSldIdLst()) {
            cTSlideIdList = this._presentation.addNewSldIdLst();
        } else {
            cTSlideIdList = this._presentation.getSldIdLst();
            int i4 = 1;
            for (CTSlideIdListEntry cTSlideIdListEntry : cTSlideIdList.getSldIdArray()) {
                i3 = (int) Math.max(cTSlideIdListEntry.getId() + 1, (long) i3);
                i4++;
            }
            while (true) {
                String fileName = XSLFRelation.SLIDE.getFileName(i4);
                Iterator<POIXMLDocumentPart> it = getRelations().iterator();
                while (true) {
                    if (!it.hasNext()) {
                        z = false;
                        break;
                    }
                    POIXMLDocumentPart next = it.next();
                    if (next.getPackagePart() != null && fileName.equals(next.getPackagePart().getPartName().getName())) {
                        z = true;
                        break;
                    }
                }
                if (!z && getPackage().getPartsByName(Pattern.compile(Pattern.quote(fileName))).size() > 0) {
                    z = true;
                }
                if (!z) {
                    break;
                }
                i4++;
            }
            i2 = i4;
        }
        POIXMLDocumentPart.RelationPart createRelationship = createRelationship(XSLFRelation.SLIDE, XSLFFactory.getInstance(), i2, false);
        XSLFSlide xSLFSlide = (XSLFSlide) createRelationship.getDocumentPart();
        CTSlideIdListEntry addNewSldId = cTSlideIdList.addNewSldId();
        addNewSldId.setId((long) i3);
        addNewSldId.setId2(createRelationship.getRelationship().getId());
        xSLFSlideLayout.copyLayout(xSLFSlide);
        xSLFSlide.addRelation(null, XSLFRelation.SLIDE_LAYOUT, xSLFSlideLayout);
        this._slides.add(xSLFSlide);
        return xSLFSlide;
    }

    @Override // org.apache.poi.sl.usermodel.SlideShow
    public XSLFPictureData findPictureData(byte[] bArr) {
        long calculateChecksum = IOUtils.calculateChecksum(bArr);
        byte[] bArr2 = new byte[8];
        LittleEndian.putLong(bArr2, 0, calculateChecksum);
        for (XSLFPictureData xSLFPictureData : getPictureData()) {
            if (Arrays.equals(xSLFPictureData.getChecksum(), bArr2)) {
                return xSLFPictureData;
            }
        }
        return null;
    }

    @Override // org.apache.poi.sl.usermodel.SlideShow
    public XSLFPictureData addPicture(byte[] bArr, PictureData.PictureType pictureType) {
        XSLFPictureData findPictureData = findPictureData(bArr);
        if (findPictureData != null) {
            return findPictureData;
        }
        int size = this._pictures.size();
        XSLFRelation relationForType = XSLFPictureData.getRelationForType(pictureType);
        if (relationForType != null) {
            XSLFPictureData xSLFPictureData = (XSLFPictureData) createRelationship(relationForType, XSLFFactory.getInstance(), size + 1, true).getDocumentPart();
            xSLFPictureData.setIndex(size);
            this._pictures.add(xSLFPictureData);
            try {
                OutputStream outputStream = xSLFPictureData.getPackagePart().getOutputStream();
                outputStream.write(bArr);
                outputStream.close();
                return xSLFPictureData;
            } catch (IOException e2) {
                throw new POIXMLException(e2);
            }
        } else {
            throw new IllegalArgumentException("Picture type " + pictureType + " is not supported.");
        }
    }

    public XMLSlideShow(InputStream inputStream) {
        this(PackageHelper.open(inputStream));
    }

    @Override // org.apache.poi.sl.usermodel.SlideShow
    public XSLFPictureData addPicture(InputStream inputStream, PictureData.PictureType pictureType) {
        return addPicture(IOUtils.toByteArray(inputStream), pictureType);
    }

    /* JADX INFO: finally extract failed */
    @Override // org.apache.poi.sl.usermodel.SlideShow
    public XSLFPictureData addPicture(File file, PictureData.PictureType pictureType) {
        byte[] bArr = new byte[((int) file.length())];
        FileInputStream fileInputStream = new FileInputStream(file);
        try {
            IOUtils.readFully(fileInputStream, bArr);
            fileInputStream.close();
            return addPicture(bArr, pictureType);
        } catch (Throwable th) {
            fileInputStream.close();
            throw th;
        }
    }

    /* Return type fixed from 'org.apache.poi.xslf.usermodel.XSLFSlide' to match base method */
    @Override // org.apache.poi.sl.usermodel.SlideShow
    public Slide<XSLFShape, XSLFTextParagraph> createSlide() {
        XSLFSlideMaster xSLFSlideMaster = this._masters.get(0);
        XSLFSlideLayout layout = xSLFSlideMaster.getLayout(SlideLayout.BLANK);
        if (layout == null) {
            LOG.log(5, "Blank layout was not found - defaulting to first slide layout in master");
            XSLFSlideLayout[] slideLayouts = xSLFSlideMaster.getSlideLayouts();
            if (slideLayouts.length != 0) {
                layout = slideLayouts[0];
            } else {
                throw new POIXMLException("SlideMaster must contain a SlideLayout.");
            }
        }
        return createSlide(layout);
    }
}
