package org.apache.poi.xslf.usermodel;

import b.b.a.a.a;
import java.util.ArrayList;
import java.util.Arrays;
import java.util.List;
import org.apache.poi.POIXMLException;
import org.apache.poi.POIXMLTypeLoader;
import org.apache.poi.util.Removal;
import org.apache.xmlbeans.XmlCursor;
import org.apache.xmlbeans.XmlException;
import org.apache.xmlbeans.XmlObject;
import org.apache.xmlbeans.impl.values.XmlAnyTypeImpl;
import org.openxmlformats.schemas.drawingml.x2006.main.CTTable;
import org.openxmlformats.schemas.drawingml.x2006.main.CTTextBody;
import org.openxmlformats.schemas.presentationml.x2006.main.CTApplicationNonVisualDrawingProps;
import org.openxmlformats.schemas.presentationml.x2006.main.CTCommonSlideData;
import org.openxmlformats.schemas.presentationml.x2006.main.CTGraphicalObjectFrame;
import org.openxmlformats.schemas.presentationml.x2006.main.CTGroupShape;
import org.openxmlformats.schemas.presentationml.x2006.main.CTShape;

@Removal(version = "3.18")
public class XSLFCommonSlideData {
    public final CTCommonSlideData data;

    public XSLFCommonSlideData(CTCommonSlideData cTCommonSlideData) {
        this.data = cTCommonSlideData;
    }

    private void processShape(CTGroupShape cTGroupShape, List<DrawingTextBody> list) {
        DrawingTextBody drawingTextBody;
        CTShape[] spArray = cTGroupShape.getSpArray();
        for (CTShape cTShape : spArray) {
            CTTextBody txBody = cTShape.getTxBody();
            if (txBody != null) {
                CTApplicationNonVisualDrawingProps nvPr = cTShape.getNvSpPr().getNvPr();
                if (nvPr.isSetPh()) {
                    drawingTextBody = new DrawingTextPlaceholder(txBody, nvPr.getPh());
                } else {
                    drawingTextBody = new DrawingTextBody(txBody);
                }
                list.add(drawingTextBody);
            }
        }
    }

    public List<DrawingTextBody> getDrawingText() {
        CTGroupShape spTree = this.data.getSpTree();
        ArrayList arrayList = new ArrayList();
        processShape(spTree, arrayList);
        for (CTGroupShape cTGroupShape : spTree.getGrpSpArray()) {
            processShape(cTGroupShape, arrayList);
        }
        for (CTGraphicalObjectFrame cTGraphicalObjectFrame : spTree.getGraphicFrameArray()) {
            XmlCursor newCursor = cTGraphicalObjectFrame.getGraphic().getGraphicData().newCursor();
            StringBuilder b2 = a.b("declare namespace pic='");
            b2.append(CTTable.type.getName().getNamespaceURI());
            b2.append("' .//pic:tbl");
            newCursor.selectPath(b2.toString());
            while (newCursor.toNextSelection()) {
                XmlObject object = newCursor.getObject();
                if (object instanceof XmlAnyTypeImpl) {
                    try {
                        object = CTTable.Factory.parse(object.toString(), POIXMLTypeLoader.DEFAULT_XML_OPTIONS);
                    } catch (XmlException e2) {
                        throw new POIXMLException(e2);
                    }
                }
                if (object instanceof CTTable) {
                    for (DrawingTableRow drawingTableRow : new DrawingTable((CTTable) object).getRows()) {
                        for (DrawingTableCell drawingTableCell : drawingTableRow.getCells()) {
                            arrayList.add(drawingTableCell.getTextBody());
                        }
                    }
                }
            }
            newCursor.dispose();
        }
        return arrayList;
    }

    public List<DrawingParagraph> getText() {
        ArrayList arrayList = new ArrayList();
        for (DrawingTextBody drawingTextBody : getDrawingText()) {
            arrayList.addAll(Arrays.asList(drawingTextBody.getParagraphs()));
        }
        return arrayList;
    }
}
