package org.apache.poi.xslf.usermodel;

import b.b.a.a.a;
import java.awt.Graphics2D;
import java.awt.geom.Rectangle2D;
import java.io.IOException;
import java.io.InputStream;
import java.util.Arrays;
import java.util.Comparator;
import org.apache.poi.openxml4j.exceptions.InvalidFormatException;
import org.apache.poi.openxml4j.opc.PackagePart;
import org.apache.poi.sl.draw.DrawFactory;
import org.apache.poi.sl.draw.DrawPaint;
import org.apache.poi.sl.usermodel.ColorStyle;
import org.apache.poi.sl.usermodel.MasterSheet;
import org.apache.poi.sl.usermodel.PaintStyle;
import org.apache.poi.sl.usermodel.PlaceableShape;
import org.apache.poi.sl.usermodel.Placeholder;
import org.apache.poi.sl.usermodel.Shape;
import org.apache.poi.sl.usermodel.ShapeContainer;
import org.apache.poi.sl.usermodel.Sheet;
import org.apache.poi.ss.formula.functions.NumericFunction;
import org.apache.poi.util.Internal;
import org.apache.poi.xslf.model.PropertyFetcher;
import org.apache.poi.xslf.usermodel.XSLFPropertiesDelegate;
import org.apache.xerces.util.SecurityManager;
import org.apache.xmlbeans.XmlCursor;
import org.apache.xmlbeans.XmlObject;
import org.apache.xmlbeans.XmlTokenSource;
import org.apache.xmlbeans.XmlValidationError;
import org.openxmlformats.schemas.drawingml.x2006.main.CTBlip;
import org.openxmlformats.schemas.drawingml.x2006.main.CTBlipFillProperties;
import org.openxmlformats.schemas.drawingml.x2006.main.CTGradientFillProperties;
import org.openxmlformats.schemas.drawingml.x2006.main.CTGradientStop;
import org.openxmlformats.schemas.drawingml.x2006.main.CTGroupShapeProperties;
import org.openxmlformats.schemas.drawingml.x2006.main.CTNonVisualDrawingProps;
import org.openxmlformats.schemas.drawingml.x2006.main.CTSchemeColor;
import org.openxmlformats.schemas.drawingml.x2006.main.CTShapeProperties;
import org.openxmlformats.schemas.drawingml.x2006.main.CTShapeStyle;
import org.openxmlformats.schemas.drawingml.x2006.main.CTSolidColorFillProperties;
import org.openxmlformats.schemas.drawingml.x2006.main.CTStyleMatrix;
import org.openxmlformats.schemas.drawingml.x2006.main.CTStyleMatrixReference;
import org.openxmlformats.schemas.drawingml.x2006.main.STPathShadeType;
import org.openxmlformats.schemas.presentationml.x2006.main.CTApplicationNonVisualDrawingProps;
import org.openxmlformats.schemas.presentationml.x2006.main.CTBackgroundProperties;
import org.openxmlformats.schemas.presentationml.x2006.main.CTPlaceholder;
import org.openxmlformats.schemas.presentationml.x2006.main.STPlaceholderType;

public abstract class XSLFShape implements Shape<XSLFShape, XSLFTextParagraph> {
    public static final String PML_NS = "http://schemas.openxmlformats.org/presentationml/2006/main";
    public CTNonVisualDrawingProps _nvPr;
    public XSLFShapeContainer _parent;
    public CTPlaceholder _ph;
    public final XmlObject _shape;
    public final XSLFSheet _sheet;
    public CTShapeStyle _spStyle;

    public XSLFShape(XmlObject xmlObject, XSLFSheet xSLFSheet) {
        this._shape = xmlObject;
        this._sheet = xSLFSheet;
    }

    public static int getPlaceholderType(CTPlaceholder cTPlaceholder) {
        if (!cTPlaceholder.isSetType()) {
            return 2;
        }
        int intValue = cTPlaceholder.getType().intValue();
        if (intValue == 1 || intValue == 3) {
            return 1;
        }
        if (intValue == 5 || intValue == 6 || intValue == 7) {
            return cTPlaceholder.getType().intValue();
        }
        return 2;
    }

    public static PaintStyle selectPaint(XSLFPropertiesDelegate.XSLFFillProperties xSLFFillProperties, CTSchemeColor cTSchemeColor, PackagePart packagePart, XSLFTheme xSLFTheme, boolean z) {
        if (xSLFFillProperties != null && !xSLFFillProperties.isSetNoFill()) {
            if (xSLFFillProperties.isSetSolidFill()) {
                return selectPaint(xSLFFillProperties.getSolidFill(), cTSchemeColor, xSLFTheme);
            }
            if (xSLFFillProperties.isSetBlipFill()) {
                return selectPaint(xSLFFillProperties.getBlipFill(), packagePart);
            }
            if (xSLFFillProperties.isSetGradFill()) {
                return selectPaint(xSLFFillProperties.getGradFill(), cTSchemeColor, xSLFTheme);
            }
            if (xSLFFillProperties.isSetMatrixStyle()) {
                return selectPaint(xSLFFillProperties.getMatrixStyle(), xSLFTheme, xSLFFillProperties.isLineStyle(), z);
            }
        }
        return null;
    }

    @Internal
    public void copy(XSLFShape xSLFShape) {
        if (!getClass().isInstance(xSLFShape)) {
            StringBuilder b2 = a.b("Can't copy ");
            b2.append(xSLFShape.getClass().getSimpleName());
            b2.append(" into ");
            b2.append(getClass().getSimpleName());
            throw new IllegalArgumentException(b2.toString());
        } else if (this instanceof PlaceableShape) {
            ((PlaceableShape) this).setAnchor(xSLFShape.getAnchor());
        }
    }

    @Override // org.apache.poi.sl.usermodel.Shape
    public void draw(Graphics2D graphics2D, Rectangle2D rectangle2D) {
        DrawFactory.getInstance(graphics2D).drawShape(graphics2D, this, rectangle2D);
    }

    public boolean fetchShapeProperty(PropertyFetcher<?> propertyFetcher) {
        XSLFSimpleShape placeholderByType;
        if (propertyFetcher.fetch(this)) {
            return true;
        }
        CTPlaceholder cTPlaceholder = getCTPlaceholder();
        if (cTPlaceholder == null) {
            return false;
        }
        MasterSheet<XSLFShape, XSLFTextParagraph> masterSheet = getSheet().getMasterSheet();
        if (masterSheet instanceof XSLFSlideLayout) {
            XSLFSlideLayout xSLFSlideLayout = (XSLFSlideLayout) masterSheet;
            XSLFSimpleShape placeholder = xSLFSlideLayout.getPlaceholder(cTPlaceholder);
            if (placeholder != null && propertyFetcher.fetch(placeholder)) {
                return true;
            }
            masterSheet = xSLFSlideLayout.getMasterSheet();
        }
        if (!(masterSheet instanceof XSLFSlideMaster) || (placeholderByType = ((XSLFSlideMaster) masterSheet).getPlaceholderByType(getPlaceholderType(cTPlaceholder))) == null || !propertyFetcher.fetch(placeholderByType)) {
            return false;
        }
        return true;
    }

    public CTBackgroundProperties getBgPr() {
        return (CTBackgroundProperties) getChild(CTBackgroundProperties.class, PML_NS, "bgPr");
    }

    public CTStyleMatrixReference getBgRef() {
        return (CTStyleMatrixReference) getChild(CTStyleMatrixReference.class, PML_NS, "bgRef");
    }

    public CTNonVisualDrawingProps getCNvPr() {
        if (this._nvPr == null) {
            this._nvPr = (CTNonVisualDrawingProps) selectProperty(CTNonVisualDrawingProps.class, "declare namespace p='http://schemas.openxmlformats.org/presentationml/2006/main' .//*/p:cNvPr");
        }
        return this._nvPr;
    }

    public CTPlaceholder getCTPlaceholder() {
        if (this._ph == null) {
            this._ph = (CTPlaceholder) selectProperty(CTPlaceholder.class, "declare namespace p='http://schemas.openxmlformats.org/presentationml/2006/main' .//*/p:nvPr/p:ph");
        }
        return this._ph;
    }

    public <T extends XmlObject> T getChild(Class<T> cls, String str, String str2) {
        XmlCursor newCursor = getXmlObject().newCursor();
        T t = newCursor.toChild(str, str2) ? (T) newCursor.getObject() : null;
        if (newCursor.toChild("http://schemas.openxmlformats.org/drawingml/2006/main", str2)) {
            t = (T) newCursor.getObject();
        }
        newCursor.dispose();
        return t;
    }

    /* JADX WARN: Type inference failed for: r0v0, types: [org.apache.poi.xslf.usermodel.XSLFSheet] */
    /* JADX WARNING: Unknown variable types count: 1 */
    public PaintStyle getFillPaint() {
        final XSLFTheme theme = getSheet().getTheme();
        final boolean z = getPlaceholder() != null;
        AnonymousClass1 r2 = new PropertyFetcher<PaintStyle>() {
            /* class org.apache.poi.xslf.usermodel.XSLFShape.AnonymousClass1 */

            /* JADX WARN: Type inference failed for: r2v1, types: [org.apache.poi.POIXMLDocumentPart, org.apache.poi.xslf.usermodel.XSLFSheet] */
            /* JADX WARNING: Unknown variable types count: 1 */
            @Override // org.apache.poi.xslf.model.PropertyFetcher
            public boolean fetch(XSLFShape xSLFShape) {
                XSLFPropertiesDelegate.XSLFFillProperties fillDelegate = XSLFPropertiesDelegate.getFillDelegate(xSLFShape.getShapeProperties());
                if (fillDelegate == null) {
                    return false;
                }
                if (fillDelegate.isSetNoFill()) {
                    setValue(null);
                    return true;
                }
                PackagePart packagePart = xSLFShape.getSheet().getPackagePart();
                PaintStyle selectPaint = XSLFShape.selectPaint(fillDelegate, null, packagePart, theme, z);
                if (selectPaint != null) {
                    setValue(selectPaint);
                    return true;
                }
                CTShapeStyle spStyle = xSLFShape.getSpStyle();
                if (spStyle != null) {
                    selectPaint = XSLFShape.selectPaint(XSLFPropertiesDelegate.getFillDelegate(spStyle.getFillRef()), null, packagePart, theme, z);
                }
                if (selectPaint == null) {
                    return false;
                }
                setValue(selectPaint);
                return true;
            }
        };
        fetchShapeProperty(r2);
        return (PaintStyle) r2.getValue();
    }

    public CTGroupShapeProperties getGrpSpPr() {
        return (CTGroupShapeProperties) getChild(CTGroupShapeProperties.class, PML_NS, "grpSpPr");
    }

    public Placeholder getPlaceholder() {
        CTPlaceholder cTPlaceholder = getCTPlaceholder();
        if (cTPlaceholder == null) {
            return null;
        }
        if (cTPlaceholder.isSetType() || cTPlaceholder.isSetIdx()) {
            return Placeholder.lookupOoxml(cTPlaceholder.getType().intValue());
        }
        return null;
    }

    public int getShapeId() {
        return (int) getCNvPr().getId();
    }

    public String getShapeName() {
        return getCNvPr().getName();
    }

    public XmlObject getShapeProperties() {
        return getChild(CTShapeProperties.class, PML_NS, "spPr");
    }

    public CTShapeStyle getSpStyle() {
        if (this._spStyle == null) {
            this._spStyle = (CTShapeStyle) getChild(CTShapeStyle.class, PML_NS, "style");
        }
        return this._spStyle;
    }

    public final XmlObject getXmlObject() {
        return this._shape;
    }

    public <T extends XmlObject> T selectProperty(Class<T> cls, String str) {
        XmlObject[] selectPath = getXmlObject().selectPath(str);
        if (selectPath.length != 0 && cls.isInstance(selectPath[0])) {
            return (T) selectPath[0];
        }
        return null;
    }

    public void setParent(XSLFShapeContainer xSLFShapeContainer) {
        this._parent = xSLFShapeContainer;
    }

    public void setPlaceholder(Placeholder placeholder) {
        CTApplicationNonVisualDrawingProps cTApplicationNonVisualDrawingProps = (CTApplicationNonVisualDrawingProps) selectProperty(CTApplicationNonVisualDrawingProps.class, "declare namespace p='http://schemas.openxmlformats.org/presentationml/2006/main' .//*/p:nvPr");
        if (cTApplicationNonVisualDrawingProps != null) {
            if (placeholder == null) {
                if (cTApplicationNonVisualDrawingProps.isSetPh()) {
                    cTApplicationNonVisualDrawingProps.unsetPh();
                }
                this._ph = null;
                return;
            }
            cTApplicationNonVisualDrawingProps.addNewPh().setType(STPlaceholderType.Enum.forInt(placeholder.ooxmlId));
        }
    }

    /* Return type fixed from 'org.apache.poi.xslf.usermodel.XSLFShapeContainer' to match base method */
    @Override // org.apache.poi.sl.usermodel.Shape
    public ShapeContainer<XSLFShape, XSLFTextParagraph> getParent() {
        return this._parent;
    }

    /* Return type fixed from 'org.apache.poi.xslf.usermodel.XSLFSheet' to match base method */
    @Override // org.apache.poi.sl.usermodel.Shape
    public Sheet<XSLFShape, XSLFTextParagraph> getSheet() {
        return this._sheet;
    }

    public static PaintStyle selectPaint(CTSolidColorFillProperties cTSolidColorFillProperties, CTSchemeColor cTSchemeColor, XSLFTheme xSLFTheme) {
        if (cTSolidColorFillProperties.isSetSchemeClr() && cTSchemeColor == null) {
            cTSchemeColor = cTSolidColorFillProperties.getSchemeClr();
        }
        return DrawPaint.createSolidPaint(new XSLFColor(cTSolidColorFillProperties, xSLFTheme, cTSchemeColor).getColorStyle());
    }

    public static PaintStyle selectPaint(CTBlipFillProperties cTBlipFillProperties, final PackagePart packagePart) {
        final CTBlip blip = cTBlipFillProperties.getBlip();
        return new PaintStyle.TexturePaint() {
            /* class org.apache.poi.xslf.usermodel.XSLFShape.AnonymousClass2 */

            private PackagePart getPart() {
                try {
                    return packagePart.getRelatedPart(packagePart.getRelationship(blip.getEmbed()));
                } catch (InvalidFormatException e2) {
                    throw new RuntimeException(e2);
                }
            }

            @Override // org.apache.poi.sl.usermodel.PaintStyle.TexturePaint
            public int getAlpha() {
                return blip.sizeOfAlphaModFixArray() > 0 ? blip.getAlphaModFixArray(0).getAmt() : SecurityManager.DEFAULT_ENTITY_EXPANSION_LIMIT;
            }

            @Override // org.apache.poi.sl.usermodel.PaintStyle.TexturePaint
            public String getContentType() {
                return getPart().getContentType();
            }

            @Override // org.apache.poi.sl.usermodel.PaintStyle.TexturePaint
            public InputStream getImageData() {
                try {
                    return getPart().getInputStream();
                } catch (IOException e2) {
                    throw new RuntimeException(e2);
                }
            }
        };
    }

    public static PaintStyle selectPaint(final CTGradientFillProperties cTGradientFillProperties, CTSchemeColor cTSchemeColor, XSLFTheme xSLFTheme) {
        CTGradientStop[] gsArray = cTGradientFillProperties.getGsLst().getGsArray();
        Arrays.sort(gsArray, new Comparator<CTGradientStop>() {
            /* class org.apache.poi.xslf.usermodel.XSLFShape.AnonymousClass3 */

            public int compare(CTGradientStop cTGradientStop, CTGradientStop cTGradientStop2) {
                return Integer.valueOf(cTGradientStop.getPos()).compareTo(Integer.valueOf(cTGradientStop2.getPos()));
            }
        });
        final ColorStyle[] colorStyleArr = new ColorStyle[gsArray.length];
        final float[] fArr = new float[gsArray.length];
        int i2 = 0;
        for (CTGradientStop cTGradientStop : gsArray) {
            colorStyleArr[i2] = new XSLFColor(cTGradientStop, xSLFTheme, (cTSchemeColor != null || !cTGradientStop.isSetSchemeClr()) ? cTSchemeColor : cTGradientStop.getSchemeClr()).getColorStyle();
            fArr[i2] = ((float) cTGradientStop.getPos()) / 100000.0f;
            i2++;
        }
        return new PaintStyle.GradientPaint() {
            /* class org.apache.poi.xslf.usermodel.XSLFShape.AnonymousClass4 */

            @Override // org.apache.poi.sl.usermodel.PaintStyle.GradientPaint
            public double getGradientAngle() {
                return cTGradientFillProperties.isSetLin() ? ((double) cTGradientFillProperties.getLin().getAng()) / 60000.0d : NumericFunction.LOG_10_TO_BASE_e;
            }

            @Override // org.apache.poi.sl.usermodel.PaintStyle.GradientPaint
            public ColorStyle[] getGradientColors() {
                return colorStyleArr;
            }

            @Override // org.apache.poi.sl.usermodel.PaintStyle.GradientPaint
            public float[] getGradientFractions() {
                return fArr;
            }

            @Override // org.apache.poi.sl.usermodel.PaintStyle.GradientPaint
            public PaintStyle.GradientPaint.GradientType getGradientType() {
                if (cTGradientFillProperties.isSetLin()) {
                    return PaintStyle.GradientPaint.GradientType.linear;
                }
                if (cTGradientFillProperties.isSetPath()) {
                    STPathShadeType.Enum path = cTGradientFillProperties.getPath().getPath();
                    if (path == STPathShadeType.CIRCLE) {
                        return PaintStyle.GradientPaint.GradientType.circular;
                    }
                    if (path == STPathShadeType.SHAPE) {
                        return PaintStyle.GradientPaint.GradientType.shape;
                    }
                }
                return PaintStyle.GradientPaint.GradientType.linear;
            }

            @Override // org.apache.poi.sl.usermodel.PaintStyle.GradientPaint
            public boolean isRotatedWithShape() {
                return cTGradientFillProperties.getRotWithShape();
            }
        };
    }

    public static PaintStyle selectPaint(CTStyleMatrixReference cTStyleMatrixReference, XSLFTheme xSLFTheme, boolean z, boolean z2) {
        XmlTokenSource xmlTokenSource;
        int i2;
        XSLFPropertiesDelegate.XSLFFillProperties xSLFFillProperties = null;
        PaintStyle paintStyle = null;
        if (cTStyleMatrixReference == null) {
            return null;
        }
        int idx = (int) cTStyleMatrixReference.getIdx();
        CTStyleMatrix fmtScheme = xSLFTheme.getXmlObject().getThemeElements().getFmtScheme();
        if (idx < 1 || idx > 999) {
            if (idx >= 1001) {
                i2 = idx - XmlValidationError.ATTRIBUTE_TYPE_INVALID;
                xmlTokenSource = fmtScheme.getBgFillStyleLst();
            }
            return paintStyle;
        }
        i2 = idx - 1;
        xmlTokenSource = z ? fmtScheme.getLnStyleLst() : fmtScheme.getFillStyleLst();
        XmlCursor newCursor = xmlTokenSource.newCursor();
        if (newCursor.toChild(i2)) {
            xSLFFillProperties = XSLFPropertiesDelegate.getFillDelegate(newCursor.getObject());
        }
        newCursor.dispose();
        CTSchemeColor schemeClr = cTStyleMatrixReference.getSchemeClr();
        paintStyle = selectPaint(xSLFFillProperties, schemeClr, xSLFTheme.getPackagePart(), xSLFTheme, z2);
        if (paintStyle == null && !z2) {
            return DrawPaint.createSolidPaint(new XSLFColor(cTStyleMatrixReference, xSLFTheme, schemeClr).getColorStyle());
        }
        return paintStyle;
    }
}
