package org.apache.poi.xslf.usermodel;

import b.b.a.a.a;
import java.awt.geom.Rectangle2D;
import java.util.ArrayList;
import java.util.Collections;
import java.util.Iterator;
import java.util.List;
import org.apache.poi.javax.xml.namespace.QName;
import org.apache.poi.sl.draw.DrawFactory;
import org.apache.poi.sl.usermodel.TableCell;
import org.apache.poi.sl.usermodel.TableShape;
import org.apache.poi.sl.usermodel.TextShape;
import org.apache.poi.ss.formula.functions.NumericFunction;
import org.apache.poi.util.Internal;
import org.apache.poi.util.Units;
import org.apache.xmlbeans.XmlCursor;
import org.apache.xmlbeans.XmlObject;
import org.apache.xmlbeans.impl.values.XmlAnyTypeImpl;
import org.openxmlformats.schemas.drawingml.x2006.main.CTGraphicalObjectData;
import org.openxmlformats.schemas.drawingml.x2006.main.CTNonVisualDrawingProps;
import org.openxmlformats.schemas.drawingml.x2006.main.CTTable;
import org.openxmlformats.schemas.drawingml.x2006.main.CTTableRow;
import org.openxmlformats.schemas.presentationml.x2006.main.CTGraphicalObjectFrame;
import org.openxmlformats.schemas.presentationml.x2006.main.CTGraphicalObjectFrameNonVisual;

public class XSLFTable extends XSLFGraphicFrame implements Iterable<XSLFTableRow>, TableShape<XSLFShape, XSLFTextParagraph> {
    public static final /* synthetic */ boolean $assertionsDisabled = false;
    public static final String DRAWINGML_URI = "http://schemas.openxmlformats.org/drawingml/2006/main";
    public static final String TABLE_URI = "http://schemas.openxmlformats.org/drawingml/2006/table";
    public List<XSLFTableRow> _rows;
    public CTTable _table;

    public XSLFTable(CTGraphicalObjectFrame cTGraphicalObjectFrame, XSLFSheet xSLFSheet) {
        super(cTGraphicalObjectFrame, xSLFSheet);
        CTGraphicalObjectData graphicData = cTGraphicalObjectFrame.getGraphic().getGraphicData();
        XmlCursor newCursor = graphicData.newCursor();
        if (newCursor.toChild("http://schemas.openxmlformats.org/drawingml/2006/main", "tbl")) {
            XmlObject object = newCursor.getObject();
            if (!(object instanceof XmlAnyTypeImpl)) {
                this._table = (CTTable) object;
                newCursor.dispose();
                this._rows = new ArrayList(this._table.sizeOfTrArray());
                for (CTTableRow cTTableRow : this._table.getTrArray()) {
                    this._rows.add(new XSLFTableRow(cTTableRow, this));
                }
                updateRowColIndexes();
                return;
            }
            throw new IllegalStateException("Schemas (*.xsb) for CTTable can't be loaded - usually this happens when OSGI loading is used and the thread context classloader has no reference to the xmlbeans classes - use POIXMLTypeLoader.setClassLoader() to set the loader, e.g. with CTTable.class.getClassLoader()");
        }
        throw new IllegalStateException("a:tbl element was not found in\n " + graphicData);
    }

    public static CTGraphicalObjectFrame prototype(int i2) {
        CTGraphicalObjectFrame newInstance = CTGraphicalObjectFrame.Factory.newInstance();
        CTGraphicalObjectFrameNonVisual addNewNvGraphicFramePr = newInstance.addNewNvGraphicFramePr();
        CTNonVisualDrawingProps addNewCNvPr = addNewNvGraphicFramePr.addNewCNvPr();
        addNewCNvPr.setName("Table " + i2);
        addNewCNvPr.setId((long) (i2 + 1));
        addNewNvGraphicFramePr.addNewCNvGraphicFramePr().addNewGraphicFrameLocks().setNoGrp(true);
        addNewNvGraphicFramePr.addNewNvPr();
        newInstance.addNewXfrm();
        CTGraphicalObjectData addNewGraphicData = newInstance.addNewGraphic().addNewGraphicData();
        XmlCursor newCursor = addNewGraphicData.newCursor();
        newCursor.toNextToken();
        newCursor.beginElement(new QName("http://schemas.openxmlformats.org/drawingml/2006/main", "tbl"));
        CTTable newInstance2 = CTTable.Factory.newInstance();
        newInstance2.addNewTblPr();
        newInstance2.addNewTblGrid();
        XmlCursor newCursor2 = newInstance2.newCursor();
        newCursor2.moveXmlContents(newCursor);
        newCursor2.dispose();
        newCursor.dispose();
        addNewGraphicData.setUri(TABLE_URI);
        return newInstance;
    }

    public XSLFTableRow addRow() {
        XSLFTableRow xSLFTableRow = new XSLFTableRow(this._table.addNewTr(), this);
        xSLFTableRow.setHeight(20.0d);
        this._rows.add(xSLFTableRow);
        updateRowColIndexes();
        return xSLFTableRow;
    }

    @Internal
    public CTTable getCTTable() {
        return this._table;
    }

    @Override // org.apache.poi.sl.usermodel.TableShape
    public double getColumnWidth(int i2) {
        return Units.toPoints(this._table.getTblGrid().getGridColArray(i2).getW());
    }

    @Override // org.apache.poi.sl.usermodel.TableShape
    public int getNumberOfColumns() {
        return this._table.getTblGrid().sizeOfGridColArray();
    }

    @Override // org.apache.poi.sl.usermodel.TableShape
    public int getNumberOfRows() {
        return this._table.sizeOfTrArray();
    }

    @Override // org.apache.poi.sl.usermodel.TableShape
    public double getRowHeight(int i2) {
        return Units.toPoints(this._table.getTrArray(i2).getH());
    }

    public List<XSLFTableRow> getRows() {
        return Collections.unmodifiableList(this._rows);
    }

    /* JADX WARN: Type inference failed for: r1v3, types: [org.apache.poi.xslf.usermodel.XSLFSheet] */
    /* JADX WARN: Type inference failed for: r1v4, types: [org.apache.poi.xslf.usermodel.XMLSlideShow] */
    /* JADX WARNING: Unknown variable types count: 2 */
    public XSLFTableStyle getTableStyle() {
        CTTable cTTable = getCTTable();
        if (cTTable.isSetTblPr() && cTTable.getTblPr().isSetTableStyleId()) {
            String tableStyleId = cTTable.getTblPr().getTableStyleId();
            for (XSLFTableStyle xSLFTableStyle : getSheet().getSlideShow().getTableStyles().getStyles()) {
                if (xSLFTableStyle.getStyleId().equals(tableStyleId)) {
                    return xSLFTableStyle;
                }
            }
        }
        return null;
    }

    @Override // java.lang.Iterable
    public Iterator<XSLFTableRow> iterator() {
        return this._rows.iterator();
    }

    public void mergeCells(int i2, int i3, int i4, int i5) {
        if (i2 > i3) {
            throw new IllegalArgumentException(a.a("Cannot merge, first row > last row : ", i2, " > ", i3));
        } else if (i4 <= i5) {
            int i6 = (i3 - i2) + 1;
            boolean z = false;
            boolean z2 = i6 > 1;
            int i7 = (i5 - i4) + 1;
            if (i7 > 1) {
                z = true;
            }
            for (int i8 = i2; i8 <= i3; i8++) {
                XSLFTableRow xSLFTableRow = this._rows.get(i8);
                for (int i9 = i4; i9 <= i5; i9++) {
                    XSLFTableCell xSLFTableCell = xSLFTableRow.getCells().get(i9);
                    if (z2) {
                        if (i8 == i2) {
                            xSLFTableCell.setRowSpan(i6);
                        } else {
                            xSLFTableCell.setVMerge(true);
                        }
                    }
                    if (z) {
                        if (i9 == i4) {
                            xSLFTableCell.setGridSpan(i7);
                        } else {
                            xSLFTableCell.setHMerge(true);
                        }
                    }
                }
            }
        } else {
            throw new IllegalArgumentException(a.a("Cannot merge, first column > last column : ", i4, " > ", i5));
        }
    }

    @Override // org.apache.poi.sl.usermodel.TableShape
    public void setColumnWidth(int i2, double d2) {
        this._table.getTblGrid().getGridColArray(i2).setW((long) Units.toEMU(d2));
    }

    @Override // org.apache.poi.sl.usermodel.TableShape
    public void setRowHeight(int i2, double d2) {
        this._table.getTrArray(i2).setH((long) Units.toEMU(d2));
    }

    /* JADX DEBUG: Multi-variable search result rejected for r7v1, resolved type: org.apache.poi.sl.draw.DrawFactory */
    /* JADX WARN: Multi-variable type inference failed */
    /* JADX WARN: Type inference failed for: r5v2, types: [org.apache.poi.xslf.usermodel.XSLFTableCell] */
    /* JADX WARN: Type inference failed for: r8v6, types: [org.apache.poi.xslf.usermodel.XSLFTableCell] */
    /* JADX WARN: Type inference failed for: r8v8, types: [org.apache.poi.xslf.usermodel.XSLFTableCell] */
    /* JADX WARN: Type inference failed for: r15v0, types: [org.apache.poi.xslf.usermodel.XSLFTableCell] */
    /* JADX WARN: Type inference failed for: r14v4, types: [org.apache.poi.sl.usermodel.TextShape, org.apache.poi.xslf.usermodel.XSLFTableCell] */
    /* JADX WARNING: Unknown variable types count: 5 */
    public void updateCellAnchor() {
        int numberOfRows = getNumberOfRows();
        int numberOfColumns = getNumberOfColumns();
        double[] dArr = new double[numberOfColumns];
        double[] dArr2 = new double[numberOfRows];
        for (int i2 = 0; i2 < numberOfRows; i2++) {
            dArr2[i2] = getRowHeight(i2);
        }
        for (int i3 = 0; i3 < numberOfColumns; i3++) {
            dArr[i3] = getColumnWidth(i3);
        }
        Rectangle2D anchor = getAnchor();
        DrawFactory instance = DrawFactory.getInstance(null);
        double y = anchor.getY();
        for (int i4 = 0; i4 < numberOfRows; i4++) {
            double d2 = NumericFunction.LOG_10_TO_BASE_e;
            for (int i5 = 0; i5 < numberOfColumns; i5++) {
                ?? cell = getCell(i4, i5);
                if (cell != 0 && cell.getGridSpan() == 1 && cell.getRowSpan() == 1) {
                    cell.setAnchor(new Rectangle2D.Double((double) NumericFunction.LOG_10_TO_BASE_e, (double) NumericFunction.LOG_10_TO_BASE_e, dArr[i5], (double) NumericFunction.LOG_10_TO_BASE_e));
                    d2 = Math.max(d2, instance.getDrawable((TextShape<?, ?>) cell).getTextHeight());
                }
            }
            dArr2[i4] = Math.max(dArr2[i4], d2);
        }
        for (int i6 = 0; i6 < numberOfRows; i6++) {
            double x = anchor.getX();
            for (int i7 = 0; i7 < numberOfColumns; i7++) {
                Rectangle2D.Double r14 = new Rectangle2D.Double(x, y, dArr[i7], dArr2[i6]);
                ?? cell2 = getCell(i6, i7);
                if (cell2 != 0) {
                    cell2.setAnchor(r14);
                    x = dArr[i7] + 2.0d + x;
                }
            }
            y += dArr2[i6] + 2.0d;
        }
        for (int i8 = 0; i8 < numberOfRows; i8++) {
            for (int i9 = 0; i9 < numberOfColumns; i9++) {
                ?? cell3 = getCell(i8, i9);
                if (cell3 != 0) {
                    Rectangle2D anchor2 = cell3.getAnchor();
                    for (int i10 = i9 + 1; i10 < cell3.getGridSpan() + i9; i10++) {
                        anchor2.add(getCell(i8, i10).getAnchor());
                    }
                    for (int i11 = i8 + 1; i11 < cell3.getRowSpan() + i8; i11++) {
                        anchor2.add(getCell(i11, i9).getAnchor());
                    }
                    cell3.setAnchor(anchor2);
                }
            }
        }
    }

    public void updateRowColIndexes() {
        Iterator<XSLFTableRow> it = iterator();
        int i2 = 0;
        while (it.hasNext()) {
            Iterator<XSLFTableCell> it2 = it.next().iterator();
            int i3 = 0;
            while (it2.hasNext()) {
                it2.next().setRowColIndex(i2, i3);
                i3++;
            }
            i2++;
        }
    }

    /* Return type fixed from 'org.apache.poi.xslf.usermodel.XSLFTableCell' to match base method */
    @Override // org.apache.poi.sl.usermodel.TableShape
    public TableCell<XSLFShape, XSLFTextParagraph> getCell(int i2, int i3) {
        XSLFTableRow xSLFTableRow;
        List<XSLFTableRow> rows = getRows();
        if (i2 < 0 || rows.size() <= i2 || (xSLFTableRow = rows.get(i2)) == null) {
            return null;
        }
        List<XSLFTableCell> cells = xSLFTableRow.getCells();
        if (i3 >= 0 && cells.size() > i3) {
            return cells.get(i3);
        }
        return null;
    }
}
