package org.apache.poi.xslf.usermodel;

import b.b.a.a.a;
import java.util.ArrayList;
import java.util.Collections;
import java.util.Iterator;
import java.util.List;
import org.apache.poi.util.Units;
import org.openxmlformats.schemas.drawingml.x2006.main.CTTableCell;
import org.openxmlformats.schemas.drawingml.x2006.main.CTTableRow;

public class XSLFTableRow implements Iterable<XSLFTableCell> {
    public final List<XSLFTableCell> _cells;
    public final CTTableRow _row;
    public final XSLFTable _table;

    public XSLFTableRow(CTTableRow cTTableRow, XSLFTable xSLFTable) {
        this._row = cTTableRow;
        this._table = xSLFTable;
        CTTableCell[] tcArray = cTTableRow.getTcArray();
        this._cells = new ArrayList(tcArray.length);
        for (CTTableCell cTTableCell : tcArray) {
            this._cells.add(new XSLFTableCell(cTTableCell, xSLFTable));
        }
    }

    public XSLFTableCell addCell() {
        CTTableCell addNewTc = this._row.addNewTc();
        addNewTc.set(XSLFTableCell.prototype());
        XSLFTableCell xSLFTableCell = new XSLFTableCell(addNewTc, this._table);
        this._cells.add(xSLFTableCell);
        if (this._table.getNumberOfColumns() < this._row.sizeOfTcArray()) {
            this._table.getCTTable().getTblGrid().addNewGridCol().setW((long) Units.toEMU(100.0d));
        }
        this._table.updateRowColIndexes();
        return xSLFTableCell;
    }

    public List<XSLFTableCell> getCells() {
        return Collections.unmodifiableList(this._cells);
    }

    public double getHeight() {
        return Units.toPoints(this._row.getH());
    }

    public CTTableRow getXmlObject() {
        return this._row;
    }

    @Override // java.lang.Iterable
    public Iterator<XSLFTableCell> iterator() {
        return this._cells.iterator();
    }

    public void mergeCells(int i2, int i3) {
        if (i2 < i3) {
            this._cells.get(i2).setGridSpan((i3 - i2) + 1);
            for (XSLFTableCell xSLFTableCell : this._cells.subList(i2 + 1, i3 + 1)) {
                xSLFTableCell.setHMerge(true);
            }
            return;
        }
        throw new IllegalArgumentException(a.a("Cannot merge, first column >= last column : ", i2, " >= ", i3));
    }

    public void setHeight(double d2) {
        this._row.setH((long) Units.toEMU(d2));
    }
}
