package org.apache.poi.xssf.binary;

import java.io.InputStream;
import java.util.BitSet;
import org.apache.poi.util.Internal;
import org.apache.poi.util.LittleEndianInputStream;

@Internal
public abstract class XSSFBParser {
    public final LittleEndianInputStream is;
    public final BitSet records;

    public XSSFBParser(InputStream inputStream) {
        this.is = new LittleEndianInputStream(inputStream);
        this.records = null;
    }

    private void readNext(byte b2) {
        int i2 = (b2 >> 7) & 1;
        byte b3 = b2;
        if (i2 == 1) {
            b3 = ((byte) (b2 & -129)) + (((byte) (this.is.readByte() & -129)) << 7);
        }
        long j = 0;
        int i3 = 0;
        boolean z = false;
        while (i3 < 4 && !z) {
            byte readByte = this.is.readByte();
            j += (long) (((byte) (readByte & -129)) << (i3 * 7));
            i3++;
            z = ((readByte >> 7) & 1) == 0;
        }
        BitSet bitSet = this.records;
        if (bitSet == null || bitSet.get(b3)) {
            byte[] bArr = new byte[((int) j)];
            this.is.readFully(bArr);
            handleRecord(b3 == 1 ? 1 : 0, bArr);
            return;
        }
        long skip = this.is.skip(j);
        if (skip != j) {
            throw new XSSFBParseException("End of file reached before expected.\tTried to skip " + j + ", but only skipped " + skip);
        }
    }

    public abstract void handleRecord(int i2, byte[] bArr);

    public void parse() {
        while (true) {
            int read = this.is.read();
            if (read != -1) {
                readNext((byte) read);
            } else {
                return;
            }
        }
    }

    public XSSFBParser(InputStream inputStream, BitSet bitSet) {
        this.is = new LittleEndianInputStream(inputStream);
        this.records = bitSet;
    }
}
