package org.apache.poi.xssf.binary;

import b.b.a.a.a;
import java.nio.charset.Charset;
import org.apache.poi.POIXMLException;
import org.apache.poi.hpsf.Filetime;
import org.apache.poi.util.Internal;
import org.apache.poi.util.LittleEndian;

@Internal
public class XSSFBUtils {
    public static int castToInt(long j) {
        if (j < 2147483647L && j > -2147483648L) {
            return (int) j;
        }
        throw new POIXMLException("val (" + j + ") can't be cast to int");
    }

    public static short castToShort(int i2) {
        if (i2 < 32767 && i2 > -32768) {
            return (short) i2;
        }
        throw new POIXMLException(a.b("val (", i2, ") can't be cast to short"));
    }

    public static int get24BitInt(byte[] bArr, int i2) {
        int i3 = i2 + 1;
        return ((bArr[i3 + 1] & 255) << 16) + ((bArr[i3] & 255) << 8) + (bArr[i2] & 255);
    }

    public static int readXLNullableWideString(byte[] bArr, int i2, StringBuilder sb) {
        long uInt = LittleEndian.getUInt(bArr, i2);
        if (uInt >= 0) {
            int i3 = (uInt > Filetime.UINT_MASK ? 1 : (uInt == Filetime.UINT_MASK ? 0 : -1));
            if (i3 == 0) {
                return 0;
            }
            if (i3 <= 0) {
                int i4 = ((int) uInt) * 2;
                int i5 = i2 + 4;
                if (i5 + i4 <= bArr.length) {
                    sb.append(new String(bArr, i5, i4, Charset.forName("UTF-16LE")));
                    return i4 + 4;
                }
                StringBuilder a = a.a("trying to read beyond data length:offset=", i5, ", numBytes=", i4, ", data.length=");
                a.append(bArr.length);
                throw new XSSFBParseException(a.toString());
            }
            throw new XSSFBParseException("too many chars to read");
        }
        throw new XSSFBParseException("too few chars to read");
    }

    public static int readXLWideString(byte[] bArr, int i2, StringBuilder sb) {
        long uInt = LittleEndian.getUInt(bArr, i2);
        if (uInt < 0) {
            throw new XSSFBParseException("too few chars to read");
        } else if (uInt <= Filetime.UINT_MASK) {
            int i3 = ((int) uInt) * 2;
            int i4 = i2 + 4;
            if (i4 + i3 <= bArr.length) {
                sb.append(new String(bArr, i4, i3, Charset.forName("UTF-16LE")));
                return i3 + 4;
            }
            throw new XSSFBParseException("trying to read beyond data length");
        } else {
            throw new XSSFBParseException("too many chars to read");
        }
    }
}
