package org.apache.poi.xssf.eventusermodel;

import b.b.a.a.a;
import java.io.InputStream;
import java.io.PushbackInputStream;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import javax.xml.parsers.ParserConfigurationException;
import org.apache.poi.openxml4j.opc.OPCPackage;
import org.apache.poi.openxml4j.opc.PackagePart;
import org.apache.poi.util.SAXHelper;
import org.apache.poi.xssf.usermodel.XSSFRelation;
import org.xml.sax.Attributes;
import org.xml.sax.InputSource;
import org.xml.sax.XMLReader;
import org.xml.sax.helpers.DefaultHandler;

public class ReadOnlySharedStringsTable extends DefaultHandler {
    public StringBuffer characters;
    public int count;
    public boolean inRPh;
    public final boolean includePhoneticRuns;
    public Map<Integer, String> phoneticStrings;
    public List<String> strings;
    public boolean tIsOpen;
    public int uniqueCount;

    public ReadOnlySharedStringsTable(OPCPackage oPCPackage) {
        this(oPCPackage, true);
    }

    @Override // org.xml.sax.helpers.DefaultHandler, org.xml.sax.ContentHandler
    public void characters(char[] cArr, int i2, int i3) {
        if (!this.tIsOpen) {
            return;
        }
        if (this.inRPh && this.includePhoneticRuns) {
            this.characters.append(cArr, i2, i3);
        } else if (!this.inRPh) {
            this.characters.append(cArr, i2, i3);
        }
    }

    @Override // org.xml.sax.helpers.DefaultHandler, org.xml.sax.ContentHandler
    public void endElement(String str, String str2, String str3) {
        if (str != null && !str.equals(XSSFRelation.NS_SPREADSHEETML)) {
            return;
        }
        if ("si".equals(str2)) {
            this.strings.add(this.characters.toString());
        } else if ("t".equals(str2)) {
            this.tIsOpen = false;
        } else if ("rPh".equals(str2)) {
            this.inRPh = false;
        }
    }

    public int getCount() {
        return this.count;
    }

    public String getEntryAt(int i2) {
        return this.strings.get(i2);
    }

    public List<String> getItems() {
        return this.strings;
    }

    public int getUniqueCount() {
        return this.uniqueCount;
    }

    public void readFrom(InputStream inputStream) {
        PushbackInputStream pushbackInputStream = new PushbackInputStream(inputStream, 1);
        int read = pushbackInputStream.read();
        if (read > -1) {
            pushbackInputStream.unread(read);
            InputSource inputSource = new InputSource(pushbackInputStream);
            try {
                XMLReader newXMLReader = SAXHelper.newXMLReader();
                newXMLReader.setContentHandler(this);
                newXMLReader.parse(inputSource);
            } catch (ParserConfigurationException e2) {
                StringBuilder b2 = a.b("SAX parser appears to be broken - ");
                b2.append(e2.getMessage());
                throw new RuntimeException(b2.toString());
            }
        }
    }

    @Override // org.xml.sax.helpers.DefaultHandler, org.xml.sax.ContentHandler
    public void startElement(String str, String str2, String str3, Attributes attributes) {
        if (str != null && !str.equals(XSSFRelation.NS_SPREADSHEETML)) {
            return;
        }
        if ("sst".equals(str2)) {
            String value = attributes.getValue("count");
            if (value != null) {
                this.count = Integer.parseInt(value);
            }
            String value2 = attributes.getValue("uniqueCount");
            if (value2 != null) {
                this.uniqueCount = Integer.parseInt(value2);
            }
            this.strings = new ArrayList(this.uniqueCount);
            this.phoneticStrings = new HashMap();
            this.characters = new StringBuffer();
        } else if ("si".equals(str2)) {
            this.characters.setLength(0);
        } else if ("t".equals(str2)) {
            this.tIsOpen = true;
        } else if ("rPh".equals(str2)) {
            this.inRPh = true;
            if (this.includePhoneticRuns && this.characters.length() > 0) {
                this.characters.append(" ");
            }
        }
    }

    public ReadOnlySharedStringsTable(OPCPackage oPCPackage, boolean z) {
        this.includePhoneticRuns = z;
        ArrayList<PackagePart> partsByContentType = oPCPackage.getPartsByContentType(XSSFRelation.SHARED_STRINGS.getContentType());
        if (partsByContentType.size() > 0) {
            readFrom(partsByContentType.get(0).getInputStream());
        }
    }

    public ReadOnlySharedStringsTable(PackagePart packagePart) {
        this(packagePart, true);
    }

    public ReadOnlySharedStringsTable(PackagePart packagePart, boolean z) {
        this.includePhoneticRuns = z;
        readFrom(packagePart.getInputStream());
    }
}
