package org.apache.poi.xssf.extractor;

import b.b.a.a.a;
import java.io.IOException;
import java.io.InputStream;
import java.util.HashMap;
import java.util.List;
import java.util.Locale;
import java.util.Map;
import javax.xml.parsers.ParserConfigurationException;
import org.apache.poi.POIXMLProperties;
import org.apache.poi.POIXMLTextExtractor;
import org.apache.poi.openxml4j.exceptions.OpenXML4JException;
import org.apache.poi.openxml4j.opc.OPCPackage;
import org.apache.poi.ss.extractor.ExcelExtractor;
import org.apache.poi.ss.usermodel.DataFormatter;
import org.apache.poi.util.POILogFactory;
import org.apache.poi.util.POILogger;
import org.apache.poi.util.SAXHelper;
import org.apache.poi.xssf.eventusermodel.ReadOnlySharedStringsTable;
import org.apache.poi.xssf.eventusermodel.XSSFReader;
import org.apache.poi.xssf.eventusermodel.XSSFSheetXMLHandler;
import org.apache.poi.xssf.model.CommentsTable;
import org.apache.poi.xssf.model.StylesTable;
import org.apache.poi.xssf.usermodel.XSSFComment;
import org.apache.poi.xssf.usermodel.XSSFShape;
import org.apache.poi.xssf.usermodel.XSSFSimpleShape;
import org.apache.poi.xssf.usermodel.helpers.HeaderFooterHelper;
import org.xml.sax.InputSource;
import org.xml.sax.SAXException;
import org.xml.sax.XMLReader;

public class XSSFEventBasedExcelExtractor extends POIXMLTextExtractor implements ExcelExtractor {
    public static final POILogger LOGGER = POILogFactory.getLogger(XSSFEventBasedExcelExtractor.class);
    public boolean concatenatePhoneticRuns;
    public OPCPackage container;
    public boolean formulasNotResults;
    public boolean includeCellComments;
    public boolean includeHeadersFooters;
    public boolean includeSheetNames;
    public boolean includeTextBoxes;
    public Locale locale;
    public POIXMLProperties properties;

    public class SheetTextExtractor implements XSSFSheetXMLHandler.SheetContentsHandler {
        public boolean firstCellOfRow = true;
        public final Map<String, String> headerFooterMap;
        public final StringBuffer output = new StringBuffer();

        public SheetTextExtractor() {
            this.headerFooterMap = XSSFEventBasedExcelExtractor.this.includeHeadersFooters ? new HashMap() : null;
        }

        private void appendHeaderFooterText(StringBuffer stringBuffer, String str) {
            String str2 = this.headerFooterMap.get(str);
            if (str2 != null && str2.length() > 0) {
                stringBuffer.append(handleHeaderFooterDelimiter(handleHeaderFooterDelimiter(handleHeaderFooterDelimiter(str2, HeaderFooterHelper.HeaderFooterEntity_L), HeaderFooterHelper.HeaderFooterEntity_C), HeaderFooterHelper.HeaderFooterEntity_R));
                stringBuffer.append('\n');
            }
        }

        private String handleHeaderFooterDelimiter(String str, String str2) {
            int indexOf = str.indexOf(str2);
            if (indexOf == 0) {
                return str.substring(2);
            }
            if (indexOf <= 0) {
                return str;
            }
            return str.substring(0, indexOf) + "\t" + str.substring(indexOf + 2);
        }

        public void appendCellText(StringBuffer stringBuffer) {
            XSSFEventBasedExcelExtractor.this.checkMaxTextSize(stringBuffer, this.output.toString());
            stringBuffer.append(this.output);
        }

        public void appendFooterText(StringBuffer stringBuffer) {
            appendHeaderFooterText(stringBuffer, "firstFooter");
            appendHeaderFooterText(stringBuffer, "oddFooter");
            appendHeaderFooterText(stringBuffer, "evenFooter");
        }

        public void appendHeaderText(StringBuffer stringBuffer) {
            appendHeaderFooterText(stringBuffer, "firstHeader");
            appendHeaderFooterText(stringBuffer, "oddHeader");
            appendHeaderFooterText(stringBuffer, "evenHeader");
        }

        @Override // org.apache.poi.xssf.eventusermodel.XSSFSheetXMLHandler.SheetContentsHandler
        public void cell(String str, String str2, XSSFComment xSSFComment) {
            if (this.firstCellOfRow) {
                this.firstCellOfRow = false;
            } else {
                this.output.append('\t');
            }
            if (str2 != null) {
                XSSFEventBasedExcelExtractor.this.checkMaxTextSize(this.output, str2);
                this.output.append(str2);
            }
            if (XSSFEventBasedExcelExtractor.this.includeCellComments && xSSFComment != null) {
                String replace = xSSFComment.getString().getString().replace('\n', ' ');
                this.output.append(str2 != null ? " Comment by " : "Comment by ");
                XSSFEventBasedExcelExtractor.this.checkMaxTextSize(this.output, replace);
                if (replace.startsWith(xSSFComment.getAuthor() + ": ")) {
                    this.output.append(replace);
                    return;
                }
                StringBuffer stringBuffer = this.output;
                stringBuffer.append(xSSFComment.getAuthor());
                stringBuffer.append(": ");
                stringBuffer.append(replace);
            }
        }

        @Override // org.apache.poi.xssf.eventusermodel.XSSFSheetXMLHandler.SheetContentsHandler
        public void endRow(int i2) {
            this.output.append('\n');
        }

        @Override // org.apache.poi.xssf.eventusermodel.XSSFSheetXMLHandler.SheetContentsHandler
        public void headerFooter(String str, boolean z, String str2) {
            Map<String, String> map = this.headerFooterMap;
            if (map != null) {
                map.put(str2, str);
            }
        }

        public void reset() {
            this.output.setLength(0);
            this.firstCellOfRow = true;
            Map<String, String> map = this.headerFooterMap;
            if (map != null) {
                map.clear();
            }
        }

        @Override // org.apache.poi.xssf.eventusermodel.XSSFSheetXMLHandler.SheetContentsHandler
        public void startRow(int i2) {
            this.firstCellOfRow = true;
        }
    }

    public XSSFEventBasedExcelExtractor(String str) {
        this(OPCPackage.open(str));
    }

    public static void main(String[] strArr) {
        if (strArr.length < 1) {
            System.err.println("Use:");
            System.err.println("  XSSFEventBasedExcelExtractor <filename.xlsx>");
            System.exit(1);
        }
        XSSFEventBasedExcelExtractor xSSFEventBasedExcelExtractor = new XSSFEventBasedExcelExtractor(strArr[0]);
        System.out.println(xSSFEventBasedExcelExtractor.getText());
        xSSFEventBasedExcelExtractor.close();
    }

    @Override // org.apache.poi.POIXMLTextExtractor, org.apache.poi.POITextExtractor, java.io.Closeable, java.lang.AutoCloseable
    public void close() {
        OPCPackage oPCPackage = this.container;
        if (oPCPackage != null) {
            oPCPackage.close();
            this.container = null;
        }
        super.close();
    }

    @Override // org.apache.poi.POIXMLTextExtractor
    public POIXMLProperties.CoreProperties getCoreProperties() {
        return this.properties.getCoreProperties();
    }

    @Override // org.apache.poi.POIXMLTextExtractor
    public POIXMLProperties.CustomProperties getCustomProperties() {
        return this.properties.getCustomProperties();
    }

    @Override // org.apache.poi.POIXMLTextExtractor
    public POIXMLProperties.ExtendedProperties getExtendedProperties() {
        return this.properties.getExtendedProperties();
    }

    public boolean getFormulasNotResults() {
        return this.formulasNotResults;
    }

    public boolean getIncludeCellComments() {
        return this.includeCellComments;
    }

    public boolean getIncludeHeadersFooters() {
        return this.includeHeadersFooters;
    }

    public boolean getIncludeSheetNames() {
        return this.includeSheetNames;
    }

    public boolean getIncludeTextBoxes() {
        return this.includeTextBoxes;
    }

    public Locale getLocale() {
        return this.locale;
    }

    @Override // org.apache.poi.POIXMLTextExtractor
    public OPCPackage getPackage() {
        return this.container;
    }

    @Override // org.apache.poi.ss.extractor.ExcelExtractor, org.apache.poi.POITextExtractor
    public String getText() {
        try {
            ReadOnlySharedStringsTable readOnlySharedStringsTable = new ReadOnlySharedStringsTable(this.container, this.concatenatePhoneticRuns);
            XSSFReader xSSFReader = new XSSFReader(this.container);
            StylesTable stylesTable = xSSFReader.getStylesTable();
            XSSFReader.SheetIterator sheetIterator = (XSSFReader.SheetIterator) xSSFReader.getSheetsData();
            StringBuffer stringBuffer = new StringBuffer();
            SheetTextExtractor sheetTextExtractor = new SheetTextExtractor();
            while (sheetIterator.hasNext()) {
                InputStream next = sheetIterator.next();
                if (this.includeSheetNames) {
                    stringBuffer.append(sheetIterator.getSheetName());
                    stringBuffer.append('\n');
                }
                processSheet(sheetTextExtractor, stylesTable, this.includeCellComments ? sheetIterator.getSheetComments() : null, readOnlySharedStringsTable, next);
                if (this.includeHeadersFooters) {
                    sheetTextExtractor.appendHeaderText(stringBuffer);
                }
                sheetTextExtractor.appendCellText(stringBuffer);
                if (this.includeTextBoxes) {
                    processShapes(sheetIterator.getShapes(), stringBuffer);
                }
                if (this.includeHeadersFooters) {
                    sheetTextExtractor.appendFooterText(stringBuffer);
                }
                sheetTextExtractor.reset();
                next.close();
            }
            return stringBuffer.toString();
        } catch (IOException e2) {
            LOGGER.log(5, e2);
            return null;
        } catch (SAXException e3) {
            LOGGER.log(5, e3);
            return null;
        } catch (OpenXML4JException e4) {
            LOGGER.log(5, e4);
            return null;
        }
    }

    public void processShapes(List<XSSFShape> list, StringBuffer stringBuffer) {
        String text;
        if (list != null) {
            for (XSSFShape xSSFShape : list) {
                if ((xSSFShape instanceof XSSFSimpleShape) && (text = ((XSSFSimpleShape) xSSFShape).getText()) != null && text.length() > 0) {
                    stringBuffer.append(text);
                    stringBuffer.append('\n');
                }
            }
        }
    }

    public void processSheet(XSSFSheetXMLHandler.SheetContentsHandler sheetContentsHandler, StylesTable stylesTable, CommentsTable commentsTable, ReadOnlySharedStringsTable readOnlySharedStringsTable, InputStream inputStream) {
        DataFormatter dataFormatter;
        if (this.locale == null) {
            dataFormatter = new DataFormatter();
        } else {
            dataFormatter = new DataFormatter(this.locale);
        }
        InputSource inputSource = new InputSource(inputStream);
        try {
            XMLReader newXMLReader = SAXHelper.newXMLReader();
            newXMLReader.setContentHandler(new XSSFSheetXMLHandler(stylesTable, commentsTable, readOnlySharedStringsTable, sheetContentsHandler, dataFormatter, this.formulasNotResults));
            newXMLReader.parse(inputSource);
        } catch (ParserConfigurationException e2) {
            StringBuilder b2 = a.b("SAX parser appears to be broken - ");
            b2.append(e2.getMessage());
            throw new RuntimeException(b2.toString());
        }
    }

    public void setConcatenatePhoneticRuns(boolean z) {
        this.concatenatePhoneticRuns = z;
    }

    @Override // org.apache.poi.ss.extractor.ExcelExtractor
    public void setFormulasNotResults(boolean z) {
        this.formulasNotResults = z;
    }

    @Override // org.apache.poi.ss.extractor.ExcelExtractor
    public void setIncludeCellComments(boolean z) {
        this.includeCellComments = z;
    }

    @Override // org.apache.poi.ss.extractor.ExcelExtractor
    public void setIncludeHeadersFooters(boolean z) {
        this.includeHeadersFooters = z;
    }

    @Override // org.apache.poi.ss.extractor.ExcelExtractor
    public void setIncludeSheetNames(boolean z) {
        this.includeSheetNames = z;
    }

    public void setIncludeTextBoxes(boolean z) {
        this.includeTextBoxes = z;
    }

    public void setLocale(Locale locale2) {
        this.locale = locale2;
    }

    public XSSFEventBasedExcelExtractor(OPCPackage oPCPackage) {
        super(null);
        this.includeTextBoxes = true;
        this.includeSheetNames = true;
        this.includeCellComments = false;
        this.includeHeadersFooters = true;
        this.formulasNotResults = false;
        this.concatenatePhoneticRuns = true;
        this.container = oPCPackage;
        this.properties = new POIXMLProperties(oPCPackage);
    }
}
