package org.apache.poi.xssf.model;

import b.b.a.a.a;
import java.io.IOException;
import java.io.InputStream;
import java.io.OutputStream;
import java.util.ArrayList;
import java.util.Arrays;
import java.util.Collections;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import java.util.Set;
import java.util.SortedMap;
import java.util.TreeMap;
import org.apache.poi.POIXMLDocumentPart;
import org.apache.poi.POIXMLTypeLoader;
import org.apache.poi.openxml4j.opc.PackagePart;
import org.apache.poi.ss.SpreadsheetVersion;
import org.apache.poi.ss.usermodel.FontFamily;
import org.apache.poi.ss.usermodel.FontScheme;
import org.apache.poi.ss.usermodel.TableStyle;
import org.apache.poi.util.Internal;
import org.apache.poi.xssf.usermodel.CustomIndexedColorMap;
import org.apache.poi.xssf.usermodel.DefaultIndexedColorMap;
import org.apache.poi.xssf.usermodel.IndexedColorMap;
import org.apache.poi.xssf.usermodel.XSSFBuiltinTableStyle;
import org.apache.poi.xssf.usermodel.XSSFCellStyle;
import org.apache.poi.xssf.usermodel.XSSFFactory;
import org.apache.poi.xssf.usermodel.XSSFFont;
import org.apache.poi.xssf.usermodel.XSSFRelation;
import org.apache.poi.xssf.usermodel.XSSFTableStyle;
import org.apache.poi.xssf.usermodel.XSSFWorkbook;
import org.apache.poi.xssf.usermodel.extensions.XSSFCellBorder;
import org.apache.poi.xssf.usermodel.extensions.XSSFCellFill;
import org.apache.xmlbeans.XmlException;
import org.openxmlformats.schemas.spreadsheetml.x2006.main.CTBorder;
import org.openxmlformats.schemas.spreadsheetml.x2006.main.CTBorders;
import org.openxmlformats.schemas.spreadsheetml.x2006.main.CTCellStyleXfs;
import org.openxmlformats.schemas.spreadsheetml.x2006.main.CTCellXfs;
import org.openxmlformats.schemas.spreadsheetml.x2006.main.CTDxf;
import org.openxmlformats.schemas.spreadsheetml.x2006.main.CTDxfs;
import org.openxmlformats.schemas.spreadsheetml.x2006.main.CTFill;
import org.openxmlformats.schemas.spreadsheetml.x2006.main.CTFills;
import org.openxmlformats.schemas.spreadsheetml.x2006.main.CTFont;
import org.openxmlformats.schemas.spreadsheetml.x2006.main.CTFonts;
import org.openxmlformats.schemas.spreadsheetml.x2006.main.CTNumFmt;
import org.openxmlformats.schemas.spreadsheetml.x2006.main.CTNumFmts;
import org.openxmlformats.schemas.spreadsheetml.x2006.main.CTStylesheet;
import org.openxmlformats.schemas.spreadsheetml.x2006.main.CTTableStyle;
import org.openxmlformats.schemas.spreadsheetml.x2006.main.CTTableStyles;
import org.openxmlformats.schemas.spreadsheetml.x2006.main.CTXf;
import org.openxmlformats.schemas.spreadsheetml.x2006.main.STPatternType;
import org.openxmlformats.schemas.spreadsheetml.x2006.main.StyleSheetDocument;

public class StylesTable extends POIXMLDocumentPart {
    public static final int FIRST_CUSTOM_STYLE_ID = 165;
    public static final short FIRST_USER_DEFINED_NUMBER_FORMAT_ID = 164;
    public static final int MAXIMUM_STYLE_ID = SpreadsheetVersion.EXCEL2007.getMaxCellStyles();
    public int MAXIMUM_NUMBER_OF_DATA_FORMATS = 250;
    public final List<XSSFCellBorder> borders = new ArrayList();
    public StyleSheetDocument doc;
    public final List<CTDxf> dxfs = new ArrayList();
    public final List<XSSFCellFill> fills = new ArrayList();
    public final List<XSSFFont> fonts = new ArrayList();
    public IndexedColorMap indexedColors = new DefaultIndexedColorMap();
    public final SortedMap<Short, String> numberFormats = new TreeMap();
    public final List<CTXf> styleXfs = new ArrayList();
    public final Map<String, TableStyle> tableStyles = new HashMap();
    public ThemesTable theme;
    public XSSFWorkbook workbook;
    public final List<CTXf> xfs = new ArrayList();

    public StylesTable() {
        StyleSheetDocument newInstance = StyleSheetDocument.Factory.newInstance();
        this.doc = newInstance;
        newInstance.addNewStyleSheet();
        initialize();
    }

    public static CTBorder createDefaultBorder() {
        CTBorder newInstance = CTBorder.Factory.newInstance();
        newInstance.addNewBottom();
        newInstance.addNewTop();
        newInstance.addNewLeft();
        newInstance.addNewRight();
        newInstance.addNewDiagonal();
        return newInstance;
    }

    public static CTFill[] createDefaultFills() {
        CTFill[] cTFillArr = {CTFill.Factory.newInstance(), CTFill.Factory.newInstance()};
        cTFillArr[0].addNewPatternFill().setPatternType(STPatternType.NONE);
        cTFillArr[1].addNewPatternFill().setPatternType(STPatternType.DARK_GRAY);
        return cTFillArr;
    }

    public static XSSFFont createDefaultFont() {
        XSSFFont xSSFFont = new XSSFFont(CTFont.Factory.newInstance(), 0, null);
        xSSFFont.setFontHeightInPoints(11);
        xSSFFont.setColor(XSSFFont.DEFAULT_FONT_COLOR);
        xSSFFont.setFontName(XSSFFont.DEFAULT_FONT_NAME);
        xSSFFont.setFamily(FontFamily.SWISS);
        xSSFFont.setScheme(FontScheme.MINOR);
        return xSSFFont;
    }

    public static CTXf createDefaultXf() {
        CTXf newInstance = CTXf.Factory.newInstance();
        newInstance.setNumFmtId(0);
        newInstance.setFontId(0);
        newInstance.setFillId(0);
        newInstance.setBorderId(0);
        return newInstance;
    }

    private short getNumberFormatId(String str) {
        for (Map.Entry<Short, String> entry : this.numberFormats.entrySet()) {
            if (entry.getValue().equals(str)) {
                return entry.getKey().shortValue();
            }
        }
        throw new IllegalStateException(a.b("Number format not in style table: ", str));
    }

    private void initialize() {
        this.fonts.add(createDefaultFont());
        CTFill[] createDefaultFills = createDefaultFills();
        this.fills.add(new XSSFCellFill(createDefaultFills[0], this.indexedColors));
        this.fills.add(new XSSFCellFill(createDefaultFills[1], this.indexedColors));
        this.borders.add(new XSSFCellBorder(createDefaultBorder()));
        this.styleXfs.add(createDefaultXf());
        CTXf createDefaultXf = createDefaultXf();
        createDefaultXf.setXfId(0);
        this.xfs.add(createDefaultXf);
    }

    @Internal
    public int _getDXfsSize() {
        return this.dxfs.size();
    }

    @Internal
    public int _getNumberFormatSize() {
        return getNumDataFormats();
    }

    @Internal
    public int _getStyleXfsSize() {
        return this.styleXfs.size();
    }

    @Internal
    public int _getXfsSize() {
        return this.xfs.size();
    }

    @Override // org.apache.poi.POIXMLDocumentPart
    public void commit() {
        OutputStream outputStream = getPackagePart().getOutputStream();
        writeTo(outputStream);
        outputStream.close();
    }

    public XSSFCellStyle createCellStyle() {
        if (getNumCellStyles() <= MAXIMUM_STYLE_ID) {
            int size = this.styleXfs.size();
            CTXf newInstance = CTXf.Factory.newInstance();
            newInstance.setNumFmtId(0);
            newInstance.setFontId(0);
            newInstance.setFillId(0);
            newInstance.setBorderId(0);
            newInstance.setXfId(0);
            return new XSSFCellStyle(putCellXf(newInstance) - 1, size - 1, this, this.theme);
        }
        throw new IllegalStateException(a.a(a.b("The maximum number of Cell Styles was exceeded. You can define up to "), MAXIMUM_STYLE_ID, " style in a .xlsx Workbook"));
    }

    public void ensureThemesTable() {
        if (this.theme == null) {
            setTheme((ThemesTable) this.workbook.createRelationship(XSSFRelation.THEME, XSSFFactory.getInstance()));
        }
    }

    public XSSFFont findFont(short s, short s2, short s3, String str, boolean z, boolean z2, short s4, byte b2) {
        for (XSSFFont xSSFFont : this.fonts) {
            if (xSSFFont.getBoldweight() == s && xSSFFont.getColor() == s2 && xSSFFont.getFontHeight() == s3 && xSSFFont.getFontName().equals(str) && xSSFFont.getItalic() == z && xSSFFont.getStrikeout() == z2 && xSSFFont.getTypeOffset() == s4 && xSSFFont.getUnderline() == b2) {
                return xSSFFont;
            }
        }
        return null;
    }

    public XSSFCellBorder getBorderAt(int i2) {
        return this.borders.get(i2);
    }

    public List<XSSFCellBorder> getBorders() {
        return Collections.unmodifiableList(this.borders);
    }

    @Internal
    public CTStylesheet getCTStylesheet() {
        return this.doc.getStyleSheet();
    }

    @Internal
    public CTXf getCellStyleXfAt(int i2) {
        try {
            return this.styleXfs.get(i2);
        } catch (IndexOutOfBoundsException unused) {
            return null;
        }
    }

    @Internal
    public CTXf getCellXfAt(int i2) {
        return this.xfs.get(i2);
    }

    @Internal
    public CTDxf getDxfAt(int i2) {
        return this.dxfs.get(i2);
    }

    public TableStyle getExplicitTableStyle(String str) {
        return this.tableStyles.get(str);
    }

    public Set<String> getExplicitTableStyleNames() {
        return this.tableStyles.keySet();
    }

    public XSSFCellFill getFillAt(int i2) {
        return this.fills.get(i2);
    }

    public List<XSSFCellFill> getFills() {
        return Collections.unmodifiableList(this.fills);
    }

    public XSSFFont getFontAt(int i2) {
        return this.fonts.get(i2);
    }

    public List<XSSFFont> getFonts() {
        return Collections.unmodifiableList(this.fonts);
    }

    public IndexedColorMap getIndexedColors() {
        return this.indexedColors;
    }

    public int getMaxNumberOfDataFormats() {
        return this.MAXIMUM_NUMBER_OF_DATA_FORMATS;
    }

    public int getNumCellStyles() {
        return this.xfs.size();
    }

    public int getNumDataFormats() {
        return this.numberFormats.size();
    }

    public String getNumberFormatAt(short s) {
        return this.numberFormats.get(Short.valueOf(s));
    }

    public Map<Short, String> getNumberFormats() {
        return Collections.unmodifiableMap(this.numberFormats);
    }

    public XSSFCellStyle getStyleAt(int i2) {
        if (i2 < 0 || i2 >= this.xfs.size()) {
            return null;
        }
        return new XSSFCellStyle(i2, this.xfs.get(i2).getXfId() > 0 ? (int) this.xfs.get(i2).getXfId() : 0, this, this.theme);
    }

    public TableStyle getTableStyle(String str) {
        if (str == null) {
            return null;
        }
        try {
            return XSSFBuiltinTableStyle.valueOf(str).getStyle();
        } catch (IllegalArgumentException unused) {
            return getExplicitTableStyle(str);
        }
    }

    public ThemesTable getTheme() {
        return this.theme;
    }

    public int putBorder(XSSFCellBorder xSSFCellBorder) {
        int indexOf = this.borders.indexOf(xSSFCellBorder);
        if (indexOf != -1) {
            return indexOf;
        }
        this.borders.add(xSSFCellBorder);
        xSSFCellBorder.setThemesTable(this.theme);
        return this.borders.size() - 1;
    }

    @Internal
    public int putCellStyleXf(CTXf cTXf) {
        this.styleXfs.add(cTXf);
        return this.styleXfs.size();
    }

    @Internal
    public int putCellXf(CTXf cTXf) {
        this.xfs.add(cTXf);
        return this.xfs.size();
    }

    @Internal
    public int putDxf(CTDxf cTDxf) {
        this.dxfs.add(cTDxf);
        return this.dxfs.size();
    }

    public int putFill(XSSFCellFill xSSFCellFill) {
        int indexOf = this.fills.indexOf(xSSFCellFill);
        if (indexOf != -1) {
            return indexOf;
        }
        this.fills.add(xSSFCellFill);
        return this.fills.size() - 1;
    }

    public int putFont(XSSFFont xSSFFont, boolean z) {
        int indexOf = !z ? this.fonts.indexOf(xSSFFont) : -1;
        if (indexOf != -1) {
            return indexOf;
        }
        int size = this.fonts.size();
        this.fonts.add(xSSFFont);
        return size;
    }

    public int putNumberFormat(String str) {
        if (this.numberFormats.containsValue(str)) {
            try {
                return getNumberFormatId(str);
            } catch (IllegalStateException unused) {
                throw new IllegalStateException("Found the format, but couldn't figure out where - should never happen!");
            }
        } else if (this.numberFormats.size() < this.MAXIMUM_NUMBER_OF_DATA_FORMATS) {
            short s = 164;
            if (!this.numberFormats.isEmpty()) {
                short shortValue = (short) (this.numberFormats.lastKey().shortValue() + 1);
                if (shortValue >= 0) {
                    s = (short) Math.max((int) shortValue, 164);
                } else {
                    throw new IllegalStateException("Cowardly avoiding creating a number format with a negative id.This is probably due to arithmetic overflow.");
                }
            }
            this.numberFormats.put(Short.valueOf(s), str);
            return s;
        } else {
            throw new IllegalStateException(a.a(a.b("The maximum number of Data Formats was exceeded. You can define up to "), this.MAXIMUM_NUMBER_OF_DATA_FORMATS, " formats in a .xlsx Workbook."));
        }
    }

    public int putStyle(XSSFCellStyle xSSFCellStyle) {
        CTXf coreXf = xSSFCellStyle.getCoreXf();
        if (!this.xfs.contains(coreXf)) {
            this.xfs.add(coreXf);
        }
        return this.xfs.indexOf(coreXf);
    }

    public void readFrom(InputStream inputStream) {
        try {
            StyleSheetDocument parse = StyleSheetDocument.Factory.parse(inputStream, POIXMLTypeLoader.DEFAULT_XML_OPTIONS);
            this.doc = parse;
            CTStylesheet styleSheet = parse.getStyleSheet();
            CustomIndexedColorMap fromColors = CustomIndexedColorMap.fromColors(styleSheet.getColors());
            if (fromColors != null) {
                this.indexedColors = fromColors;
            }
            CTNumFmts numFmts = styleSheet.getNumFmts();
            int i2 = 0;
            if (numFmts != null) {
                CTNumFmt[] numFmtArray = numFmts.getNumFmtArray();
                for (CTNumFmt cTNumFmt : numFmtArray) {
                    this.numberFormats.put(Short.valueOf((short) ((int) cTNumFmt.getNumFmtId())), cTNumFmt.getFormatCode());
                }
            }
            CTFonts fonts2 = styleSheet.getFonts();
            if (fonts2 != null) {
                int i3 = 0;
                for (CTFont cTFont : fonts2.getFontArray()) {
                    this.fonts.add(new XSSFFont(cTFont, i3, this.indexedColors));
                    i3++;
                }
            }
            CTFills fills2 = styleSheet.getFills();
            if (fills2 != null) {
                for (CTFill cTFill : fills2.getFillArray()) {
                    this.fills.add(new XSSFCellFill(cTFill, this.indexedColors));
                }
            }
            CTBorders borders2 = styleSheet.getBorders();
            if (borders2 != null) {
                for (CTBorder cTBorder : borders2.getBorderArray()) {
                    this.borders.add(new XSSFCellBorder(cTBorder, this.indexedColors));
                }
            }
            CTCellXfs cellXfs = styleSheet.getCellXfs();
            if (cellXfs != null) {
                this.xfs.addAll(Arrays.asList(cellXfs.getXfArray()));
            }
            CTCellStyleXfs cellStyleXfs = styleSheet.getCellStyleXfs();
            if (cellStyleXfs != null) {
                this.styleXfs.addAll(Arrays.asList(cellStyleXfs.getXfArray()));
            }
            CTDxfs dxfs2 = styleSheet.getDxfs();
            if (dxfs2 != null) {
                this.dxfs.addAll(Arrays.asList(dxfs2.getDxfArray()));
            }
            CTTableStyles tableStyles2 = styleSheet.getTableStyles();
            if (tableStyles2 != null) {
                for (CTTableStyle cTTableStyle : Arrays.asList(tableStyles2.getTableStyleArray())) {
                    this.tableStyles.put(cTTableStyle.getName(), new XSSFTableStyle(i2, dxfs2, cTTableStyle, this.indexedColors));
                    i2++;
                }
            }
        } catch (XmlException e2) {
            throw new IOException(e2.getLocalizedMessage());
        }
    }

    public boolean removeNumberFormat(short s) {
        boolean z = this.numberFormats.remove(Short.valueOf(s)) != null;
        if (z) {
            for (CTXf cTXf : this.xfs) {
                if (cTXf.isSetNumFmtId() && cTXf.getNumFmtId() == ((long) s)) {
                    cTXf.unsetApplyNumberFormat();
                    cTXf.unsetNumFmtId();
                }
            }
        }
        return z;
    }

    @Internal
    public void replaceCellStyleXfAt(int i2, CTXf cTXf) {
        this.styleXfs.set(i2, cTXf);
    }

    @Internal
    public void replaceCellXfAt(int i2, CTXf cTXf) {
        this.xfs.set(i2, cTXf);
    }

    public void setMaxNumberOfDataFormats(int i2) {
        if (i2 >= getNumDataFormats()) {
            this.MAXIMUM_NUMBER_OF_DATA_FORMATS = i2;
        } else if (i2 < 0) {
            throw new IllegalArgumentException("Maximum Number of Data Formats must be greater than or equal to 0");
        } else {
            throw new IllegalStateException("Cannot set the maximum number of data formats less than the current quantity.Data formats must be explicitly removed (via StylesTable.removeNumberFormat) before the limit can be decreased.");
        }
    }

    public void setTheme(ThemesTable themesTable) {
        this.theme = themesTable;
        if (themesTable != null) {
            themesTable.setColorMap(getIndexedColors());
        }
        for (XSSFFont xSSFFont : this.fonts) {
            xSSFFont.setThemesTable(themesTable);
        }
        for (XSSFCellBorder xSSFCellBorder : this.borders) {
            xSSFCellBorder.setThemesTable(themesTable);
        }
    }

    public void setWorkbook(XSSFWorkbook xSSFWorkbook) {
        this.workbook = xSSFWorkbook;
    }

    public void writeTo(OutputStream outputStream) {
        CTStylesheet styleSheet = this.doc.getStyleSheet();
        CTNumFmts newInstance = CTNumFmts.Factory.newInstance();
        newInstance.setCount((long) this.numberFormats.size());
        for (Map.Entry<Short, String> entry : this.numberFormats.entrySet()) {
            CTNumFmt addNewNumFmt = newInstance.addNewNumFmt();
            addNewNumFmt.setNumFmtId((long) entry.getKey().shortValue());
            addNewNumFmt.setFormatCode(entry.getValue());
        }
        styleSheet.setNumFmts(newInstance);
        CTFonts fonts2 = styleSheet.getFonts();
        if (fonts2 == null) {
            fonts2 = CTFonts.Factory.newInstance();
        }
        fonts2.setCount((long) this.fonts.size());
        CTFont[] cTFontArr = new CTFont[this.fonts.size()];
        int i2 = 0;
        int i3 = 0;
        for (XSSFFont xSSFFont : this.fonts) {
            cTFontArr[i3] = xSSFFont.getCTFont();
            i3++;
        }
        fonts2.setFontArray(cTFontArr);
        styleSheet.setFonts(fonts2);
        CTFills fills2 = styleSheet.getFills();
        if (fills2 == null) {
            fills2 = CTFills.Factory.newInstance();
        }
        fills2.setCount((long) this.fills.size());
        CTFill[] cTFillArr = new CTFill[this.fills.size()];
        int i4 = 0;
        for (XSSFCellFill xSSFCellFill : this.fills) {
            cTFillArr[i4] = xSSFCellFill.getCTFill();
            i4++;
        }
        fills2.setFillArray(cTFillArr);
        styleSheet.setFills(fills2);
        CTBorders borders2 = styleSheet.getBorders();
        if (borders2 == null) {
            borders2 = CTBorders.Factory.newInstance();
        }
        borders2.setCount((long) this.borders.size());
        CTBorder[] cTBorderArr = new CTBorder[this.borders.size()];
        for (XSSFCellBorder xSSFCellBorder : this.borders) {
            cTBorderArr[i2] = xSSFCellBorder.getCTBorder();
            i2++;
        }
        borders2.setBorderArray(cTBorderArr);
        styleSheet.setBorders(borders2);
        if (this.xfs.size() > 0) {
            CTCellXfs cellXfs = styleSheet.getCellXfs();
            if (cellXfs == null) {
                cellXfs = CTCellXfs.Factory.newInstance();
            }
            cellXfs.setCount((long) this.xfs.size());
            List<CTXf> list = this.xfs;
            cellXfs.setXfArray((CTXf[]) list.toArray(new CTXf[list.size()]));
            styleSheet.setCellXfs(cellXfs);
        }
        if (this.styleXfs.size() > 0) {
            CTCellStyleXfs cellStyleXfs = styleSheet.getCellStyleXfs();
            if (cellStyleXfs == null) {
                cellStyleXfs = CTCellStyleXfs.Factory.newInstance();
            }
            cellStyleXfs.setCount((long) this.styleXfs.size());
            List<CTXf> list2 = this.styleXfs;
            cellStyleXfs.setXfArray((CTXf[]) list2.toArray(new CTXf[list2.size()]));
            styleSheet.setCellStyleXfs(cellStyleXfs);
        }
        if (this.dxfs.size() > 0) {
            CTDxfs dxfs2 = styleSheet.getDxfs();
            if (dxfs2 == null) {
                dxfs2 = CTDxfs.Factory.newInstance();
            }
            dxfs2.setCount((long) this.dxfs.size());
            List<CTDxf> list3 = this.dxfs;
            dxfs2.setDxfArray((CTDxf[]) list3.toArray(new CTDxf[list3.size()]));
            styleSheet.setDxfs(dxfs2);
        }
        this.doc.save(outputStream, POIXMLTypeLoader.DEFAULT_XML_OPTIONS);
    }

    public XSSFFont findFont(boolean z, short s, short s2, String str, boolean z2, boolean z3, short s3, byte b2) {
        for (XSSFFont xSSFFont : this.fonts) {
            if (xSSFFont.getBold() == z && xSSFFont.getColor() == s && xSSFFont.getFontHeight() == s2 && xSSFFont.getFontName().equals(str) && xSSFFont.getItalic() == z2 && xSSFFont.getStrikeout() == z3 && xSSFFont.getTypeOffset() == s3 && xSSFFont.getUnderline() == b2) {
                return xSSFFont;
            }
        }
        return null;
    }

    public int putFont(XSSFFont xSSFFont) {
        return putFont(xSSFFont, false);
    }

    public boolean removeNumberFormat(String str) {
        return removeNumberFormat(getNumberFormatId(str));
    }

    public void putNumberFormat(short s, String str) {
        this.numberFormats.put(Short.valueOf(s), str);
    }

    public StylesTable(PackagePart packagePart) {
        super(packagePart);
        readFrom(packagePart.getInputStream());
    }
}
