package org.apache.poi.xssf.usermodel;

import java.lang.reflect.Array;
import java.util.List;
import org.openxmlformats.schemas.spreadsheetml.x2006.main.CTColors;
import org.openxmlformats.schemas.spreadsheetml.x2006.main.CTRgbColor;

public class CustomIndexedColorMap implements IndexedColorMap {
    public final byte[][] colorIndex;

    public CustomIndexedColorMap(byte[][] bArr) {
        this.colorIndex = bArr;
    }

    public static CustomIndexedColorMap fromColors(CTColors cTColors) {
        if (cTColors == null || !cTColors.isSetIndexedColors()) {
            return null;
        }
        List<CTRgbColor> rgbColorList = cTColors.getIndexedColors().getRgbColorList();
        int size = rgbColorList.size();
        int[] iArr = new int[2];
        iArr[1] = 3;
        iArr[0] = size;
        byte[][] bArr = (byte[][]) Array.newInstance(byte.class, iArr);
        for (int i2 = 0; i2 < rgbColorList.size(); i2++) {
            bArr[i2] = rgbColorList.get(i2).getRgb();
        }
        return new CustomIndexedColorMap(bArr);
    }

    @Override // org.apache.poi.xssf.usermodel.IndexedColorMap
    public byte[] getRGB(int i2) {
        byte[][] bArr = this.colorIndex;
        if (bArr == null || i2 < 0 || i2 >= bArr.length) {
            return null;
        }
        return bArr[i2];
    }
}
