package org.apache.poi.xssf.usermodel;

import org.apache.poi.util.Internal;
import org.openxmlformats.schemas.drawingml.x2006.main.CTPoint2D;
import org.openxmlformats.schemas.drawingml.x2006.main.CTPositiveSize2D;
import org.openxmlformats.schemas.drawingml.x2006.main.CTTransform2D;

public final class XSSFChildAnchor extends XSSFAnchor {
    public CTTransform2D t2d;

    public XSSFChildAnchor(int i2, int i3, int i4, int i5) {
        CTTransform2D newInstance = CTTransform2D.Factory.newInstance();
        this.t2d = newInstance;
        CTPoint2D addNewOff = newInstance.addNewOff();
        CTPositiveSize2D addNewExt = this.t2d.addNewExt();
        addNewOff.setX((long) i2);
        addNewOff.setY((long) i3);
        addNewExt.setCx((long) Math.abs(i4 - i2));
        addNewExt.setCy((long) Math.abs(i5 - i3));
        if (i2 > i4) {
            this.t2d.setFlipH(true);
        }
        if (i3 > i5) {
            this.t2d.setFlipV(true);
        }
    }

    @Internal
    public CTTransform2D getCTTransform2D() {
        return this.t2d;
    }

    @Override // org.apache.poi.ss.usermodel.ChildAnchor
    public int getDx1() {
        return (int) this.t2d.getOff().getX();
    }

    @Override // org.apache.poi.ss.usermodel.ChildAnchor
    public int getDx2() {
        return (int) (this.t2d.getExt().getCx() + ((long) getDx1()));
    }

    @Override // org.apache.poi.ss.usermodel.ChildAnchor
    public int getDy1() {
        return (int) this.t2d.getOff().getY();
    }

    @Override // org.apache.poi.ss.usermodel.ChildAnchor
    public int getDy2() {
        return (int) (this.t2d.getExt().getCy() + ((long) getDy1()));
    }

    @Override // org.apache.poi.ss.usermodel.ChildAnchor
    public void setDx1(int i2) {
        this.t2d.getOff().setX((long) i2);
    }

    @Override // org.apache.poi.ss.usermodel.ChildAnchor
    public void setDx2(int i2) {
        this.t2d.getExt().setCx((long) (i2 - getDx1()));
    }

    @Override // org.apache.poi.ss.usermodel.ChildAnchor
    public void setDy1(int i2) {
        this.t2d.getOff().setY((long) i2);
    }

    @Override // org.apache.poi.ss.usermodel.ChildAnchor
    public void setDy2(int i2) {
        this.t2d.getExt().setCy((long) (i2 - getDy1()));
    }

    public XSSFChildAnchor(CTTransform2D cTTransform2D) {
        this.t2d = cTTransform2D;
    }
}
