package org.apache.poi.xssf.usermodel;

import b.b.a.a.a;
import org.apache.poi.Version;
import org.apache.poi.ss.usermodel.ClientAnchor;
import org.apache.poi.util.Internal;
import org.apache.poi.util.Removal;
import org.apache.poi.util.Units;
import org.openxmlformats.schemas.drawingml.x2006.main.CTPoint2D;
import org.openxmlformats.schemas.drawingml.x2006.main.CTPositiveSize2D;
import org.openxmlformats.schemas.drawingml.x2006.spreadsheetDrawing.CTMarker;

public class XSSFClientAnchor extends XSSFAnchor implements ClientAnchor {
    public static final /* synthetic */ boolean $assertionsDisabled = false;
    public static final CTMarker EMPTY_MARKER = CTMarker.Factory.newInstance();
    public ClientAnchor.AnchorType anchorType;
    public CTMarker cell1;
    public CTMarker cell2;
    public CTPoint2D position;
    public XSSFSheet sheet;
    public CTPositiveSize2D size;

    public XSSFClientAnchor() {
        this(0, 0, 0, 0, 0, 0, 0, 0);
    }

    private CTMarker calcCell(CTMarker cTMarker, long j, long j2) {
        CTMarker newInstance = CTMarker.Factory.newInstance();
        int row = cTMarker.getRow();
        int col = cTMarker.getCol();
        int columnWidthToEMU = Units.columnWidthToEMU(this.sheet.getColumnWidth(col));
        long colOff = ((long) columnWidthToEMU) - cTMarker.getColOff();
        while (colOff < j) {
            col++;
            columnWidthToEMU = Units.columnWidthToEMU(this.sheet.getColumnWidth(col));
            colOff += (long) columnWidthToEMU;
        }
        newInstance.setCol(col);
        newInstance.setColOff(((long) columnWidthToEMU) - (colOff - j));
        int emu = Units.toEMU((double) getRowHeight(this.sheet, row));
        long rowOff = ((long) emu) - cTMarker.getRowOff();
        while (rowOff < j2) {
            row++;
            emu = Units.toEMU((double) getRowHeight(this.sheet, row));
            rowOff += (long) emu;
        }
        newInstance.setRow(row);
        newInstance.setRowOff(((long) emu) - (rowOff - j2));
        return newInstance;
    }

    private CTMarker getCell1() {
        CTMarker cTMarker = this.cell1;
        return cTMarker != null ? cTMarker : calcCell(EMPTY_MARKER, this.position.getX(), this.position.getY());
    }

    private CTMarker getCell2() {
        CTMarker cTMarker = this.cell2;
        return cTMarker != null ? cTMarker : calcCell(getCell1(), this.size.getCx(), this.size.getCy());
    }

    public static float getRowHeight(XSSFSheet xSSFSheet, int i2) {
        XSSFRow row = xSSFSheet.getRow(i2);
        return row == null ? xSSFSheet.getDefaultRowHeightInPoints() : row.getHeightInPoints();
    }

    public boolean equals(Object obj) {
        if (obj == null || !(obj instanceof XSSFClientAnchor)) {
            return false;
        }
        XSSFClientAnchor xSSFClientAnchor = (XSSFClientAnchor) obj;
        if (getDx1() == xSSFClientAnchor.getDx1() && getDx2() == xSSFClientAnchor.getDx2() && getDy1() == xSSFClientAnchor.getDy1() && getDy2() == xSSFClientAnchor.getDy2() && getCol1() == xSSFClientAnchor.getCol1() && getCol2() == xSSFClientAnchor.getCol2() && getRow1() == xSSFClientAnchor.getRow1() && getRow2() == xSSFClientAnchor.getRow2()) {
            return true;
        }
        return false;
    }

    @Override // org.apache.poi.ss.usermodel.ClientAnchor
    public ClientAnchor.AnchorType getAnchorType() {
        return this.anchorType;
    }

    @Override // org.apache.poi.ss.usermodel.ClientAnchor
    public short getCol1() {
        return (short) getCell1().getCol();
    }

    @Override // org.apache.poi.ss.usermodel.ClientAnchor
    public short getCol2() {
        return (short) getCell2().getCol();
    }

    @Override // org.apache.poi.ss.usermodel.ClientAnchor, org.apache.poi.ss.usermodel.ChildAnchor
    public int getDx1() {
        return (int) getCell1().getColOff();
    }

    @Override // org.apache.poi.ss.usermodel.ClientAnchor, org.apache.poi.ss.usermodel.ChildAnchor
    public int getDx2() {
        return (int) getCell2().getColOff();
    }

    @Override // org.apache.poi.ss.usermodel.ClientAnchor, org.apache.poi.ss.usermodel.ChildAnchor
    public int getDy1() {
        return (int) getCell1().getRowOff();
    }

    @Override // org.apache.poi.ss.usermodel.ClientAnchor, org.apache.poi.ss.usermodel.ChildAnchor
    public int getDy2() {
        return (int) getCell2().getRowOff();
    }

    @Internal
    public CTMarker getFrom() {
        return getCell1();
    }

    public CTPoint2D getPosition() {
        return this.position;
    }

    @Override // org.apache.poi.ss.usermodel.ClientAnchor
    public int getRow1() {
        return getCell1().getRow();
    }

    @Override // org.apache.poi.ss.usermodel.ClientAnchor
    public int getRow2() {
        return getCell2().getRow();
    }

    public CTPositiveSize2D getSize() {
        return this.size;
    }

    @Internal
    public CTMarker getTo() {
        return getCell2();
    }

    public int hashCode() {
        return 42;
    }

    public boolean isSet() {
        CTMarker cell12 = getCell1();
        CTMarker cell22 = getCell2();
        return (cell12.getCol() == 0 && cell22.getCol() == 0 && cell12.getRow() == 0 && cell22.getRow() == 0) ? false : true;
    }

    @Override // org.apache.poi.ss.usermodel.ClientAnchor
    public void setAnchorType(ClientAnchor.AnchorType anchorType2) {
        this.anchorType = anchorType2;
    }

    @Override // org.apache.poi.ss.usermodel.ClientAnchor
    public void setCol1(int i2) {
        this.cell1.setCol(i2);
    }

    @Override // org.apache.poi.ss.usermodel.ClientAnchor
    public void setCol2(int i2) {
        this.cell2.setCol(i2);
    }

    @Override // org.apache.poi.ss.usermodel.ClientAnchor, org.apache.poi.ss.usermodel.ChildAnchor
    public void setDx1(int i2) {
        this.cell1.setColOff((long) i2);
    }

    @Override // org.apache.poi.ss.usermodel.ClientAnchor, org.apache.poi.ss.usermodel.ChildAnchor
    public void setDx2(int i2) {
        this.cell2.setColOff((long) i2);
    }

    @Override // org.apache.poi.ss.usermodel.ClientAnchor, org.apache.poi.ss.usermodel.ChildAnchor
    public void setDy1(int i2) {
        this.cell1.setRowOff((long) i2);
    }

    @Override // org.apache.poi.ss.usermodel.ClientAnchor, org.apache.poi.ss.usermodel.ChildAnchor
    public void setDy2(int i2) {
        this.cell2.setRowOff((long) i2);
    }

    public void setFrom(CTMarker cTMarker) {
        this.cell1 = cTMarker;
    }

    public void setPosition(CTPoint2D cTPoint2D) {
        this.position = cTPoint2D;
    }

    @Override // org.apache.poi.ss.usermodel.ClientAnchor
    public void setRow1(int i2) {
        this.cell1.setRow(i2);
    }

    @Override // org.apache.poi.ss.usermodel.ClientAnchor
    public void setRow2(int i2) {
        this.cell2.setRow(i2);
    }

    public void setSize(CTPositiveSize2D cTPositiveSize2D) {
        this.size = cTPositiveSize2D;
    }

    public void setTo(CTMarker cTMarker) {
        this.cell2 = cTMarker;
    }

    public String toString() {
        StringBuilder b2 = a.b("from : ");
        b2.append(getCell1());
        b2.append("; to: ");
        b2.append(getCell2());
        return b2.toString();
    }

    public XSSFClientAnchor(int i2, int i3, int i4, int i5, int i6, int i7, int i8, int i9) {
        this.anchorType = ClientAnchor.AnchorType.MOVE_AND_RESIZE;
        CTMarker newInstance = CTMarker.Factory.newInstance();
        this.cell1 = newInstance;
        newInstance.setCol(i6);
        this.cell1.setColOff((long) i2);
        this.cell1.setRow(i7);
        this.cell1.setRowOff((long) i3);
        CTMarker newInstance2 = CTMarker.Factory.newInstance();
        this.cell2 = newInstance2;
        newInstance2.setCol(i8);
        this.cell2.setColOff((long) i4);
        this.cell2.setRow(i9);
        this.cell2.setRowOff((long) i5);
    }

    @Removal(version = Version.VERSION_STRING)
    public void setAnchorType(int i2) {
        this.anchorType = ClientAnchor.AnchorType.byId(i2);
    }

    public XSSFClientAnchor(CTMarker cTMarker, CTMarker cTMarker2) {
        this.anchorType = ClientAnchor.AnchorType.MOVE_AND_RESIZE;
        this.cell1 = cTMarker;
        this.cell2 = cTMarker2;
    }

    public XSSFClientAnchor(XSSFSheet xSSFSheet, CTMarker cTMarker, CTPositiveSize2D cTPositiveSize2D) {
        this.anchorType = ClientAnchor.AnchorType.MOVE_DONT_RESIZE;
        this.sheet = xSSFSheet;
        this.size = cTPositiveSize2D;
        this.cell1 = cTMarker;
    }

    public XSSFClientAnchor(XSSFSheet xSSFSheet, CTPoint2D cTPoint2D, CTPositiveSize2D cTPositiveSize2D) {
        this.anchorType = ClientAnchor.AnchorType.DONT_MOVE_AND_RESIZE;
        this.sheet = xSSFSheet;
        this.position = cTPoint2D;
        this.size = cTPositiveSize2D;
    }
}
