package org.apache.poi.xssf.usermodel;

import b.e.a.a.a.a;
import b.e.a.b.i;
import java.math.BigInteger;
import org.apache.poi.ss.usermodel.ClientAnchor;
import org.apache.poi.ss.usermodel.Comment;
import org.apache.poi.ss.usermodel.RichTextString;
import org.apache.poi.ss.util.CellAddress;
import org.apache.poi.ss.util.CellReference;
import org.apache.poi.xssf.model.CommentsTable;
import org.openxmlformats.schemas.spreadsheetml.x2006.main.CTComment;

public class XSSFComment implements Comment {
    public final CTComment _comment;
    public final CommentsTable _comments;
    public XSSFRichTextString _str;
    public final i _vmlShape;

    public XSSFComment(CommentsTable commentsTable, CTComment cTComment, i iVar) {
        this._comment = cTComment;
        this._comments = commentsTable;
        this._vmlShape = iVar;
        if (iVar != null && iVar.x() > 0) {
            CellReference cellReference = new CellReference(cTComment.getRef());
            a a = iVar.a(0);
            a.a(0, new BigInteger(String.valueOf(cellReference.getRow())));
            a.b(0, new BigInteger(String.valueOf((int) cellReference.getCol())));
            avoidXmlbeansCorruptPointer(iVar);
        }
    }

    public static void avoidXmlbeansCorruptPointer(i iVar) {
        iVar.W().toString();
    }

    public boolean equals(Object obj) {
        if (!(obj instanceof XSSFComment)) {
            return false;
        }
        XSSFComment xSSFComment = (XSSFComment) obj;
        if (getCTComment() == xSSFComment.getCTComment() && getCTShape() == xSSFComment.getCTShape()) {
            return true;
        }
        return false;
    }

    @Override // org.apache.poi.ss.usermodel.Comment
    public CellAddress getAddress() {
        return new CellAddress(this._comment.getRef());
    }

    @Override // org.apache.poi.ss.usermodel.Comment
    public String getAuthor() {
        return this._comments.getAuthor((long) ((int) this._comment.getAuthorId()));
    }

    public CTComment getCTComment() {
        return this._comment;
    }

    public i getCTShape() {
        return this._vmlShape;
    }

    @Override // org.apache.poi.ss.usermodel.Comment
    public ClientAnchor getClientAnchor() {
        int[] iArr = new int[8];
        String[] split = this._vmlShape.a(0).getAnchorArray(0).split(XSSFDataValidationConstraint.LIST_SEPARATOR);
        int length = split.length;
        int i2 = 0;
        int i3 = 0;
        while (i2 < length) {
            iArr[i3] = Integer.parseInt(split[i2].trim());
            i2++;
            i3++;
        }
        return new XSSFClientAnchor(iArr[1] * 9525, iArr[3] * 9525, iArr[5] * 9525, iArr[7] * 9525, iArr[0], iArr[2], iArr[4], iArr[6]);
    }

    @Override // org.apache.poi.ss.usermodel.Comment
    public int getColumn() {
        return getAddress().getColumn();
    }

    @Override // org.apache.poi.ss.usermodel.Comment
    public int getRow() {
        return getAddress().getRow();
    }

    public int hashCode() {
        return (getColumn() + (getRow() * 17)) * 31;
    }

    @Override // org.apache.poi.ss.usermodel.Comment
    public boolean isVisible() {
        String style;
        i iVar = this._vmlShape;
        if (iVar == null || (style = iVar.getStyle()) == null || !style.contains("visibility:visible")) {
            return false;
        }
        return true;
    }

    @Override // org.apache.poi.ss.usermodel.Comment
    public void setAddress(int i2, int i3) {
        setAddress(new CellAddress(i2, i3));
    }

    @Override // org.apache.poi.ss.usermodel.Comment
    public void setAuthor(String str) {
        this._comment.setAuthorId((long) this._comments.findAuthor(str));
    }

    @Override // org.apache.poi.ss.usermodel.Comment
    public void setColumn(int i2) {
        setAddress(getRow(), i2);
    }

    @Override // org.apache.poi.ss.usermodel.Comment
    public void setRow(int i2) {
        setAddress(i2, getColumn());
    }

    @Override // org.apache.poi.ss.usermodel.Comment
    public void setString(RichTextString richTextString) {
        if (richTextString instanceof XSSFRichTextString) {
            XSSFRichTextString xSSFRichTextString = (XSSFRichTextString) richTextString;
            this._str = xSSFRichTextString;
            this._comment.setText(xSSFRichTextString.getCTRst());
            return;
        }
        throw new IllegalArgumentException("Only XSSFRichTextString argument is supported");
    }

    @Override // org.apache.poi.ss.usermodel.Comment
    public void setVisible(boolean z) {
        if (this._vmlShape != null) {
            this._vmlShape.a(z ? "position:absolute;visibility:visible" : "position:absolute;visibility:hidden");
        }
    }

    @Override // org.apache.poi.ss.usermodel.Comment
    public XSSFRichTextString getString() {
        if (this._str == null && this._comment.getText() != null) {
            this._str = new XSSFRichTextString(this._comment.getText());
        }
        return this._str;
    }

    @Override // org.apache.poi.ss.usermodel.Comment
    public void setAddress(CellAddress cellAddress) {
        CellAddress cellAddress2 = new CellAddress(this._comment.getRef());
        if (!cellAddress.equals(cellAddress2)) {
            this._comment.setRef(cellAddress.formatAsString());
            this._comments.referenceUpdated(cellAddress2, this._comment);
            i iVar = this._vmlShape;
            if (iVar != null) {
                a a = iVar.a(0);
                a.a(0, new BigInteger(String.valueOf(cellAddress.getRow())));
                a.b(0, new BigInteger(String.valueOf(cellAddress.getColumn())));
                avoidXmlbeansCorruptPointer(this._vmlShape);
            }
        }
    }

    public void setString(String str) {
        setString(new XSSFRichTextString(str));
    }
}
