package org.apache.poi.xssf.usermodel;

import java.util.ArrayList;
import java.util.Collections;
import org.apache.poi.ss.usermodel.ConditionalFormatting;
import org.apache.poi.ss.usermodel.ConditionalFormattingRule;
import org.apache.poi.ss.util.CellRangeAddress;
import org.openxmlformats.schemas.spreadsheetml.x2006.main.CTConditionalFormatting;

public class XSSFConditionalFormatting implements ConditionalFormatting {
    public final CTConditionalFormatting _cf;
    public final XSSFSheet _sh;

    public XSSFConditionalFormatting(XSSFSheet xSSFSheet) {
        this._cf = CTConditionalFormatting.Factory.newInstance();
        this._sh = xSSFSheet;
    }

    @Override // org.apache.poi.ss.usermodel.ConditionalFormatting
    public void addRule(ConditionalFormattingRule conditionalFormattingRule) {
        this._cf.addNewCfRule().set(((XSSFConditionalFormattingRule) conditionalFormattingRule).getCTCfRule());
    }

    public CTConditionalFormatting getCTConditionalFormatting() {
        return this._cf;
    }

    @Override // org.apache.poi.ss.usermodel.ConditionalFormatting
    public CellRangeAddress[] getFormattingRanges() {
        ArrayList arrayList = new ArrayList();
        for (Object obj : this._cf.getSqref()) {
            for (String str : obj.toString().split(" ")) {
                arrayList.add(CellRangeAddress.valueOf(str));
            }
        }
        return (CellRangeAddress[]) arrayList.toArray(new CellRangeAddress[arrayList.size()]);
    }

    @Override // org.apache.poi.ss.usermodel.ConditionalFormatting
    public int getNumberOfRules() {
        return this._cf.sizeOfCfRuleArray();
    }

    @Override // org.apache.poi.ss.usermodel.ConditionalFormatting
    public void setFormattingRanges(CellRangeAddress[] cellRangeAddressArr) {
        if (cellRangeAddressArr != null) {
            StringBuilder sb = new StringBuilder();
            boolean z = true;
            for (CellRangeAddress cellRangeAddress : cellRangeAddressArr) {
                if (!z) {
                    sb.append(" ");
                } else {
                    z = false;
                }
                sb.append(cellRangeAddress.formatAsString());
            }
            this._cf.setSqref(Collections.singletonList(sb.toString()));
            return;
        }
        throw new IllegalArgumentException("cellRanges must not be null");
    }

    @Override // org.apache.poi.ss.usermodel.ConditionalFormatting
    public void setRule(int i2, ConditionalFormattingRule conditionalFormattingRule) {
        this._cf.getCfRuleArray(i2).set(((XSSFConditionalFormattingRule) conditionalFormattingRule).getCTCfRule());
    }

    public String toString() {
        return this._cf.toString();
    }

    @Override // org.apache.poi.ss.usermodel.ConditionalFormatting
    public XSSFConditionalFormattingRule getRule(int i2) {
        return new XSSFConditionalFormattingRule(this._sh, this._cf.getCfRuleArray(i2));
    }

    public XSSFConditionalFormatting(XSSFSheet xSSFSheet, CTConditionalFormatting cTConditionalFormatting) {
        this._cf = cTConditionalFormatting;
        this._sh = xSSFSheet;
    }
}
