package org.apache.poi.xssf.usermodel;

import java.util.HashMap;
import java.util.Iterator;
import java.util.Map;
import org.apache.poi.ss.formula.EvaluationCell;
import org.apache.poi.ss.formula.EvaluationSheet;
import org.apache.poi.ss.usermodel.Cell;
import org.apache.poi.ss.usermodel.Row;
import org.apache.poi.util.Internal;

@Internal
public final class XSSFEvaluationSheet implements EvaluationSheet {
    public Map<CellKey, EvaluationCell> _cellCache;
    public final XSSFSheet _xs;

    public static class CellKey {
        public final int _col;
        public int _hash = -1;
        public final int _row;

        public CellKey(int i2, int i3) {
            this._row = i2;
            this._col = i3;
        }

        public boolean equals(Object obj) {
            if (!(obj instanceof CellKey)) {
                return false;
            }
            CellKey cellKey = (CellKey) obj;
            if (this._row == cellKey._row && this._col == cellKey._col) {
                return true;
            }
            return false;
        }

        public int hashCode() {
            if (this._hash == -1) {
                this._hash = ((this._row + 629) * 37) + this._col;
            }
            return this._hash;
        }
    }

    public XSSFEvaluationSheet(XSSFSheet xSSFSheet) {
        this._xs = xSSFSheet;
    }

    @Override // org.apache.poi.ss.formula.EvaluationSheet
    public void clearAllCachedResultValues() {
        this._cellCache = null;
    }

    @Override // org.apache.poi.ss.formula.EvaluationSheet
    public EvaluationCell getCell(int i2, int i3) {
        XSSFCell cell;
        if (this._cellCache == null) {
            this._cellCache = new HashMap(this._xs.getLastRowNum() * 3);
            Iterator<Row> it = this._xs.iterator();
            while (it.hasNext()) {
                Row<Cell> next = it.next();
                int rowNum = next.getRowNum();
                for (Cell cell2 : next) {
                    this._cellCache.put(new CellKey(rowNum, cell2.getColumnIndex()), new XSSFEvaluationCell((XSSFCell) cell2, this));
                }
            }
        }
        CellKey cellKey = new CellKey(i2, i3);
        EvaluationCell evaluationCell = this._cellCache.get(cellKey);
        if (evaluationCell != null) {
            return evaluationCell;
        }
        XSSFRow row = this._xs.getRow(i2);
        if (row == null || (cell = row.getCell(i3)) == null) {
            return null;
        }
        XSSFEvaluationCell xSSFEvaluationCell = new XSSFEvaluationCell(cell, this);
        this._cellCache.put(cellKey, xSSFEvaluationCell);
        return xSSFEvaluationCell;
    }

    public XSSFSheet getXSSFSheet() {
        return this._xs;
    }
}
