package org.apache.poi.xssf.usermodel;

import java.io.IOException;
import org.apache.poi.POIXMLDocumentPart;
import org.apache.poi.POIXMLException;
import org.apache.poi.POIXMLRelation;
import org.apache.poi.openxml4j.opc.PackagePart;
import org.apache.poi.ss.usermodel.PictureData;
import org.apache.poi.util.IOUtils;

public class XSSFPictureData extends POIXMLDocumentPart implements PictureData {
    public static final POIXMLRelation[] RELATIONS;

    static {
        POIXMLRelation[] pOIXMLRelationArr = new POIXMLRelation[13];
        RELATIONS = pOIXMLRelationArr;
        pOIXMLRelationArr[2] = XSSFRelation.IMAGE_EMF;
        RELATIONS[3] = XSSFRelation.IMAGE_WMF;
        RELATIONS[4] = XSSFRelation.IMAGE_PICT;
        RELATIONS[5] = XSSFRelation.IMAGE_JPEG;
        RELATIONS[6] = XSSFRelation.IMAGE_PNG;
        RELATIONS[7] = XSSFRelation.IMAGE_DIB;
        RELATIONS[8] = XSSFRelation.IMAGE_GIF;
        RELATIONS[9] = XSSFRelation.IMAGE_TIFF;
        RELATIONS[10] = XSSFRelation.IMAGE_EPS;
        RELATIONS[11] = XSSFRelation.IMAGE_BMP;
        RELATIONS[12] = XSSFRelation.IMAGE_WPG;
    }

    public XSSFPictureData() {
    }

    @Override // org.apache.poi.ss.usermodel.PictureData
    public byte[] getData() {
        try {
            return IOUtils.toByteArray(getPackagePart().getInputStream());
        } catch (IOException e2) {
            throw new POIXMLException(e2);
        }
    }

    @Override // org.apache.poi.ss.usermodel.PictureData
    public String getMimeType() {
        return getPackagePart().getContentType();
    }

    @Override // org.apache.poi.ss.usermodel.PictureData
    public int getPictureType() {
        String contentType = getPackagePart().getContentType();
        int i2 = 0;
        while (true) {
            POIXMLRelation[] pOIXMLRelationArr = RELATIONS;
            if (i2 >= pOIXMLRelationArr.length) {
                return 0;
            }
            if (pOIXMLRelationArr[i2] != null && pOIXMLRelationArr[i2].getContentType().equals(contentType)) {
                return i2;
            }
            i2++;
        }
    }

    @Override // org.apache.poi.POIXMLDocumentPart
    public void prepareForCommit() {
    }

    @Override // org.apache.poi.ss.usermodel.PictureData
    public String suggestFileExtension() {
        return getPackagePart().getPartName().getExtension();
    }

    public XSSFPictureData(PackagePart packagePart) {
        super(packagePart);
    }
}
