package org.apache.poi.xssf.usermodel;

import b.b.a.a.a;
import java.io.IOException;
import java.io.InputStream;
import java.io.OutputStream;
import java.util.Date;
import org.apache.poi.POIXMLDocument;
import org.apache.poi.POIXMLDocumentPart;
import org.apache.poi.POIXMLTypeLoader;
import org.apache.poi.javax.xml.namespace.QName;
import org.apache.poi.openxml4j.opc.PackagePart;
import org.apache.poi.ss.SpreadsheetVersion;
import org.apache.poi.ss.usermodel.CellType;
import org.apache.poi.ss.usermodel.Name;
import org.apache.poi.ss.usermodel.Row;
import org.apache.poi.ss.usermodel.Sheet;
import org.apache.poi.ss.usermodel.Workbook;
import org.apache.poi.ss.util.AreaReference;
import org.apache.poi.ss.util.CellReference;
import org.apache.poi.util.Internal;
import org.apache.xmlbeans.XmlException;
import org.apache.xmlbeans.XmlOptions;
import org.openxmlformats.schemas.spreadsheetml.x2006.main.CTCacheField;
import org.openxmlformats.schemas.spreadsheetml.x2006.main.CTCacheFields;
import org.openxmlformats.schemas.spreadsheetml.x2006.main.CTPivotCacheDefinition;
import org.openxmlformats.schemas.spreadsheetml.x2006.main.CTWorksheetSource;

public class XSSFPivotCacheDefinition extends POIXMLDocumentPart {
    public static final /* synthetic */ boolean $assertionsDisabled = false;
    public CTPivotCacheDefinition ctPivotCacheDefinition;

    public XSSFPivotCacheDefinition() {
        this.ctPivotCacheDefinition = CTPivotCacheDefinition.Factory.newInstance();
        createDefaultValues();
    }

    private void createDefaultValues() {
        this.ctPivotCacheDefinition.setCreatedVersion(3);
        this.ctPivotCacheDefinition.setMinRefreshableVersion(3);
        this.ctPivotCacheDefinition.setRefreshedVersion(3);
        this.ctPivotCacheDefinition.setRefreshedBy(POIXMLDocument.DOCUMENT_CREATOR);
        this.ctPivotCacheDefinition.setRefreshedDate((double) new Date().getTime());
        this.ctPivotCacheDefinition.setRefreshOnLoad(true);
    }

    @Override // org.apache.poi.POIXMLDocumentPart
    public void commit() {
        OutputStream outputStream = getPackagePart().getOutputStream();
        XmlOptions xmlOptions = new XmlOptions(POIXMLTypeLoader.DEFAULT_XML_OPTIONS);
        xmlOptions.setSaveSyntheticDocumentElement(new QName(CTPivotCacheDefinition.type.getName().getNamespaceURI(), "pivotCacheDefinition"));
        this.ctPivotCacheDefinition.save(outputStream, xmlOptions);
        outputStream.close();
    }

    public void createCacheFields(Sheet sheet) {
        CTCacheFields cTCacheFields;
        AreaReference pivotArea = getPivotArea(sheet.getWorkbook());
        CellReference firstCell = pivotArea.getFirstCell();
        CellReference lastCell = pivotArea.getLastCell();
        short col = lastCell.getCol();
        Row row = sheet.getRow(firstCell.getRow());
        if (this.ctPivotCacheDefinition.getCacheFields() != null) {
            cTCacheFields = this.ctPivotCacheDefinition.getCacheFields();
        } else {
            cTCacheFields = this.ctPivotCacheDefinition.addNewCacheFields();
        }
        for (int col2 = firstCell.getCol(); col2 <= col; col2++) {
            CTCacheField addNewCacheField = cTCacheFields.addNewCacheField();
            if (col2 == col) {
                cTCacheFields.setCount((long) cTCacheFields.sizeOfCacheFieldArray());
            }
            addNewCacheField.setNumFmtId(0);
            row.getCell(col2).setCellType(CellType.STRING);
            addNewCacheField.setName(row.getCell(col2).getStringCellValue());
            addNewCacheField.addNewSharedItems();
        }
    }

    @Internal
    public CTPivotCacheDefinition getCTPivotCacheDefinition() {
        return this.ctPivotCacheDefinition;
    }

    public AreaReference getPivotArea(Workbook workbook) {
        CTWorksheetSource worksheetSource = this.ctPivotCacheDefinition.getCacheSource().getWorksheetSource();
        String ref = worksheetSource.getRef();
        String name = worksheetSource.getName();
        if (ref == null && name == null) {
            throw new IllegalArgumentException("Pivot cache must reference an area, named range, or table.");
        } else if (ref != null) {
            return new AreaReference(ref, SpreadsheetVersion.EXCEL2007);
        } else {
            Name name2 = workbook.getName(name);
            if (name2 != null) {
                return new AreaReference(name2.getRefersToFormula(), SpreadsheetVersion.EXCEL2007);
            }
            for (XSSFTable xSSFTable : ((XSSFSheet) workbook.getSheet(worksheetSource.getSheet())).getTables()) {
                if (name.equals(xSSFTable.getName())) {
                    return new AreaReference(xSSFTable.getStartCellReference(), xSSFTable.getEndCellReference());
                }
            }
            throw new IllegalArgumentException(a.b("Name '", name, "' was not found."));
        }
    }

    public void readFrom(InputStream inputStream) {
        try {
            XmlOptions xmlOptions = new XmlOptions(POIXMLTypeLoader.DEFAULT_XML_OPTIONS);
            xmlOptions.setLoadReplaceDocumentElement(null);
            this.ctPivotCacheDefinition = CTPivotCacheDefinition.Factory.parse(inputStream, xmlOptions);
        } catch (XmlException e2) {
            throw new IOException(e2.getLocalizedMessage(), e2);
        }
    }

    public XSSFPivotCacheDefinition(PackagePart packagePart) {
        super(packagePart);
        readFrom(packagePart.getInputStream());
    }
}
