package org.apache.poi.xssf.usermodel;

import b.b.a.a.a;
import java.io.IOException;
import java.io.InputStream;
import java.io.OutputStream;
import java.util.ArrayList;
import java.util.Collections;
import java.util.List;
import org.apache.poi.POIXMLDocumentPart;
import org.apache.poi.POIXMLTypeLoader;
import org.apache.poi.javax.xml.namespace.QName;
import org.apache.poi.openxml4j.opc.PackagePart;
import org.apache.poi.ss.usermodel.CellType;
import org.apache.poi.ss.usermodel.DataConsolidateFunction;
import org.apache.poi.ss.usermodel.Sheet;
import org.apache.poi.ss.util.AreaReference;
import org.apache.poi.ss.util.CellReference;
import org.apache.poi.util.Internal;
import org.apache.xmlbeans.XmlException;
import org.apache.xmlbeans.XmlOptions;
import org.openxmlformats.schemas.spreadsheetml.x2006.main.CTCacheSource;
import org.openxmlformats.schemas.spreadsheetml.x2006.main.CTColFields;
import org.openxmlformats.schemas.spreadsheetml.x2006.main.CTDataField;
import org.openxmlformats.schemas.spreadsheetml.x2006.main.CTDataFields;
import org.openxmlformats.schemas.spreadsheetml.x2006.main.CTField;
import org.openxmlformats.schemas.spreadsheetml.x2006.main.CTItems;
import org.openxmlformats.schemas.spreadsheetml.x2006.main.CTLocation;
import org.openxmlformats.schemas.spreadsheetml.x2006.main.CTPageField;
import org.openxmlformats.schemas.spreadsheetml.x2006.main.CTPageFields;
import org.openxmlformats.schemas.spreadsheetml.x2006.main.CTPivotField;
import org.openxmlformats.schemas.spreadsheetml.x2006.main.CTPivotFields;
import org.openxmlformats.schemas.spreadsheetml.x2006.main.CTPivotTableDefinition;
import org.openxmlformats.schemas.spreadsheetml.x2006.main.CTPivotTableStyle;
import org.openxmlformats.schemas.spreadsheetml.x2006.main.CTRowFields;
import org.openxmlformats.schemas.spreadsheetml.x2006.main.CTWorksheetSource;
import org.openxmlformats.schemas.spreadsheetml.x2006.main.STAxis;
import org.openxmlformats.schemas.spreadsheetml.x2006.main.STDataConsolidateFunction;
import org.openxmlformats.schemas.spreadsheetml.x2006.main.STItemType;
import org.openxmlformats.schemas.spreadsheetml.x2006.main.STSourceType;

public class XSSFPivotTable extends POIXMLDocumentPart {
    public static final short CREATED_VERSION = 3;
    public static final short MIN_REFRESHABLE_VERSION = 3;
    public static final short UPDATED_VERSION = 3;
    public Sheet dataSheet;
    public Sheet parentSheet;
    public XSSFPivotCache pivotCache;
    public XSSFPivotCacheDefinition pivotCacheDefinition;
    public XSSFPivotCacheRecords pivotCacheRecords;
    public CTPivotTableDefinition pivotTableDefinition;

    public interface PivotTableReferenceConfigurator {
        void configureReference(CTWorksheetSource cTWorksheetSource);
    }

    public XSSFPivotTable() {
        this.pivotTableDefinition = CTPivotTableDefinition.Factory.newInstance();
        this.pivotCache = new XSSFPivotCache();
        this.pivotCacheDefinition = new XSSFPivotCacheDefinition();
        this.pivotCacheRecords = new XSSFPivotCacheRecords();
    }

    private void addDataField(DataConsolidateFunction dataConsolidateFunction, int i2, String str) {
        CTDataFields cTDataFields;
        checkColumnIndex(i2);
        AreaReference pivotArea = getPivotArea();
        if (this.pivotTableDefinition.getDataFields() != null) {
            cTDataFields = this.pivotTableDefinition.getDataFields();
        } else {
            cTDataFields = this.pivotTableDefinition.addNewDataFields();
        }
        CTDataField addNewDataField = cTDataFields.addNewDataField();
        addNewDataField.setSubtotal(STDataConsolidateFunction.Enum.forInt(dataConsolidateFunction.getValue()));
        getDataSheet().getRow(pivotArea.getFirstCell().getRow()).getCell(pivotArea.getFirstCell().getCol() + i2).setCellType(CellType.STRING);
        addNewDataField.setName(str);
        addNewDataField.setFld((long) i2);
        cTDataFields.setCount((long) cTDataFields.sizeOfDataFieldArray());
    }

    private void checkColumnIndex(int i2) {
        AreaReference pivotArea = getPivotArea();
        int col = (pivotArea.getLastCell().getCol() - pivotArea.getFirstCell().getCol()) + 1;
        if (i2 < 0 || i2 >= col) {
            throw new IndexOutOfBoundsException(a.a("Column Index: ", i2, ", Size: ", col));
        }
    }

    private void setDataSheet(Sheet sheet) {
        this.dataSheet = sheet;
    }

    public void addColumnLabel(DataConsolidateFunction dataConsolidateFunction, int i2, String str) {
        CTColFields cTColFields;
        checkColumnIndex(i2);
        addDataColumn(i2, true);
        addDataField(dataConsolidateFunction, i2, str);
        if (this.pivotTableDefinition.getDataFields().getCount() == 2) {
            if (this.pivotTableDefinition.getColFields() != null) {
                cTColFields = this.pivotTableDefinition.getColFields();
            } else {
                cTColFields = this.pivotTableDefinition.addNewColFields();
            }
            cTColFields.addNewField().setX(-2);
            cTColFields.setCount((long) cTColFields.sizeOfFieldArray());
        }
    }

    public void addDataColumn(int i2, boolean z) {
        checkColumnIndex(i2);
        CTPivotFields pivotFields = this.pivotTableDefinition.getPivotFields();
        CTPivotField newInstance = CTPivotField.Factory.newInstance();
        newInstance.setDataField(z);
        newInstance.setShowAll(false);
        pivotFields.setPivotFieldArray(i2, newInstance);
    }

    public void addReportFilter(int i2) {
        CTPageFields cTPageFields;
        checkColumnIndex(i2);
        AreaReference pivotArea = getPivotArea();
        int row = pivotArea.getLastCell().getRow() - pivotArea.getFirstCell().getRow();
        CTPivotFields pivotFields = this.pivotTableDefinition.getPivotFields();
        CTPivotField newInstance = CTPivotField.Factory.newInstance();
        CTItems addNewItems = newInstance.addNewItems();
        newInstance.setAxis(STAxis.AXIS_PAGE);
        newInstance.setShowAll(false);
        for (int i3 = 0; i3 <= row; i3++) {
            addNewItems.addNewItem().setT(STItemType.DEFAULT);
        }
        addNewItems.setCount((long) addNewItems.sizeOfItemArray());
        pivotFields.setPivotFieldArray(i2, newInstance);
        if (this.pivotTableDefinition.getPageFields() != null) {
            cTPageFields = this.pivotTableDefinition.getPageFields();
            this.pivotTableDefinition.setMultipleFieldFilters(true);
        } else {
            cTPageFields = this.pivotTableDefinition.addNewPageFields();
        }
        CTPageField addNewPageField = cTPageFields.addNewPageField();
        addNewPageField.setHier(-1);
        addNewPageField.setFld(i2);
        cTPageFields.setCount((long) cTPageFields.sizeOfPageFieldArray());
        this.pivotTableDefinition.getLocation().setColPageCount(cTPageFields.getCount());
    }

    public void addRowLabel(int i2) {
        CTRowFields cTRowFields;
        checkColumnIndex(i2);
        AreaReference pivotArea = getPivotArea();
        int row = pivotArea.getLastCell().getRow() - pivotArea.getFirstCell().getRow();
        CTPivotFields pivotFields = this.pivotTableDefinition.getPivotFields();
        CTPivotField newInstance = CTPivotField.Factory.newInstance();
        CTItems addNewItems = newInstance.addNewItems();
        newInstance.setAxis(STAxis.AXIS_ROW);
        newInstance.setShowAll(false);
        for (int i3 = 0; i3 <= row; i3++) {
            addNewItems.addNewItem().setT(STItemType.DEFAULT);
        }
        addNewItems.setCount((long) addNewItems.sizeOfItemArray());
        pivotFields.setPivotFieldArray(i2, newInstance);
        if (this.pivotTableDefinition.getRowFields() != null) {
            cTRowFields = this.pivotTableDefinition.getRowFields();
        } else {
            cTRowFields = this.pivotTableDefinition.addNewRowFields();
        }
        cTRowFields.addNewField().setX(i2);
        cTRowFields.setCount((long) cTRowFields.sizeOfFieldArray());
    }

    @Override // org.apache.poi.POIXMLDocumentPart
    public void commit() {
        XmlOptions xmlOptions = new XmlOptions(POIXMLTypeLoader.DEFAULT_XML_OPTIONS);
        xmlOptions.setSaveSyntheticDocumentElement(new QName(CTPivotTableDefinition.type.getName().getNamespaceURI(), "pivotTableDefinition"));
        OutputStream outputStream = getPackagePart().getOutputStream();
        this.pivotTableDefinition.save(outputStream, xmlOptions);
        outputStream.close();
    }

    public void createDefaultDataColumns() {
        CTPivotFields cTPivotFields;
        if (this.pivotTableDefinition.getPivotFields() != null) {
            cTPivotFields = this.pivotTableDefinition.getPivotFields();
        } else {
            cTPivotFields = this.pivotTableDefinition.addNewPivotFields();
        }
        AreaReference pivotArea = getPivotArea();
        short col = pivotArea.getLastCell().getCol();
        for (int col2 = pivotArea.getFirstCell().getCol(); col2 <= col; col2++) {
            CTPivotField addNewPivotField = cTPivotFields.addNewPivotField();
            addNewPivotField.setDataField(false);
            addNewPivotField.setShowAll(false);
        }
        cTPivotFields.setCount((long) cTPivotFields.sizeOfPivotFieldArray());
    }

    public void createSourceReferences(CellReference cellReference, Sheet sheet, PivotTableReferenceConfigurator pivotTableReferenceConfigurator) {
        CTLocation cTLocation;
        AreaReference areaReference = new AreaReference(cellReference, new CellReference(cellReference.getRow() + 1, cellReference.getCol() + 1));
        if (this.pivotTableDefinition.getLocation() == null) {
            cTLocation = this.pivotTableDefinition.addNewLocation();
            cTLocation.setFirstDataCol(1);
            cTLocation.setFirstDataRow(1);
            cTLocation.setFirstHeaderRow(1);
        } else {
            cTLocation = this.pivotTableDefinition.getLocation();
        }
        cTLocation.setRef(areaReference.formatAsString());
        this.pivotTableDefinition.setLocation(cTLocation);
        CTCacheSource addNewCacheSource = getPivotCacheDefinition().getCTPivotCacheDefinition().addNewCacheSource();
        addNewCacheSource.setType(STSourceType.WORKSHEET);
        CTWorksheetSource addNewWorksheetSource = addNewCacheSource.addNewWorksheetSource();
        addNewWorksheetSource.setSheet(sheet.getSheetName());
        setDataSheet(sheet);
        pivotTableReferenceConfigurator.configureReference(addNewWorksheetSource);
        if (addNewWorksheetSource.getName() == null && addNewWorksheetSource.getRef() == null) {
            throw new IllegalArgumentException("Pivot table source area reference or name must be specified.");
        }
    }

    @Internal
    public CTPivotTableDefinition getCTPivotTableDefinition() {
        return this.pivotTableDefinition;
    }

    public Sheet getDataSheet() {
        return this.dataSheet;
    }

    public Sheet getParentSheet() {
        return this.parentSheet;
    }

    public AreaReference getPivotArea() {
        return getPivotCacheDefinition().getPivotArea(getDataSheet().getWorkbook());
    }

    public XSSFPivotCache getPivotCache() {
        return this.pivotCache;
    }

    public XSSFPivotCacheDefinition getPivotCacheDefinition() {
        return this.pivotCacheDefinition;
    }

    public XSSFPivotCacheRecords getPivotCacheRecords() {
        return this.pivotCacheRecords;
    }

    public List<Integer> getRowLabelColumns() {
        if (this.pivotTableDefinition.getRowFields() == null) {
            return Collections.emptyList();
        }
        ArrayList arrayList = new ArrayList();
        for (CTField cTField : this.pivotTableDefinition.getRowFields().getFieldArray()) {
            arrayList.add(Integer.valueOf(cTField.getX()));
        }
        return arrayList;
    }

    public void readFrom(InputStream inputStream) {
        try {
            XmlOptions xmlOptions = new XmlOptions(POIXMLTypeLoader.DEFAULT_XML_OPTIONS);
            xmlOptions.setLoadReplaceDocumentElement(null);
            this.pivotTableDefinition = CTPivotTableDefinition.Factory.parse(inputStream, xmlOptions);
        } catch (XmlException e2) {
            throw new IOException(e2.getLocalizedMessage());
        }
    }

    @Internal
    public void setCTPivotTableDefinition(CTPivotTableDefinition cTPivotTableDefinition) {
        this.pivotTableDefinition = cTPivotTableDefinition;
    }

    public void setDefaultPivotTableDefinition() {
        this.pivotTableDefinition.setMultipleFieldFilters(false);
        this.pivotTableDefinition.setIndent(0);
        this.pivotTableDefinition.setCreatedVersion(3);
        this.pivotTableDefinition.setMinRefreshableVersion(3);
        this.pivotTableDefinition.setUpdatedVersion(3);
        this.pivotTableDefinition.setItemPrintTitles(true);
        this.pivotTableDefinition.setUseAutoFormatting(true);
        this.pivotTableDefinition.setApplyNumberFormats(false);
        this.pivotTableDefinition.setApplyWidthHeightFormats(true);
        this.pivotTableDefinition.setApplyAlignmentFormats(false);
        this.pivotTableDefinition.setApplyPatternFormats(false);
        this.pivotTableDefinition.setApplyFontFormats(false);
        this.pivotTableDefinition.setApplyBorderFormats(false);
        this.pivotTableDefinition.setCacheId(this.pivotCache.getCTPivotCache().getCacheId());
        CTPivotTableDefinition cTPivotTableDefinition = this.pivotTableDefinition;
        StringBuilder b2 = a.b("PivotTable");
        b2.append(this.pivotTableDefinition.getCacheId());
        cTPivotTableDefinition.setName(b2.toString());
        this.pivotTableDefinition.setDataCaption("Values");
        CTPivotTableStyle addNewPivotTableStyleInfo = this.pivotTableDefinition.addNewPivotTableStyleInfo();
        addNewPivotTableStyleInfo.setName("PivotStyleLight16");
        addNewPivotTableStyleInfo.setShowLastColumn(true);
        addNewPivotTableStyleInfo.setShowColStripes(false);
        addNewPivotTableStyleInfo.setShowRowStripes(false);
        addNewPivotTableStyleInfo.setShowColHeaders(true);
        addNewPivotTableStyleInfo.setShowRowHeaders(true);
    }

    public void setParentSheet(XSSFSheet xSSFSheet) {
        this.parentSheet = xSSFSheet;
    }

    public void setPivotCache(XSSFPivotCache xSSFPivotCache) {
        this.pivotCache = xSSFPivotCache;
    }

    public void setPivotCacheDefinition(XSSFPivotCacheDefinition xSSFPivotCacheDefinition) {
        this.pivotCacheDefinition = xSSFPivotCacheDefinition;
    }

    public void setPivotCacheRecords(XSSFPivotCacheRecords xSSFPivotCacheRecords) {
        this.pivotCacheRecords = xSSFPivotCacheRecords;
    }

    public XSSFPivotTable(PackagePart packagePart) {
        super(packagePart);
        readFrom(packagePart.getInputStream());
    }

    public void addColumnLabel(DataConsolidateFunction dataConsolidateFunction, int i2) {
        addColumnLabel(dataConsolidateFunction, i2, dataConsolidateFunction.getName());
    }
}
