package org.apache.poi.xssf.usermodel;

import b.b.a.a.a;
import java.util.Iterator;
import java.util.Map;
import java.util.SortedMap;
import java.util.TreeMap;
import java.util.regex.Matcher;
import java.util.regex.Pattern;
import org.apache.poi.javax.xml.namespace.QName;
import org.apache.poi.ss.usermodel.DataFormatter;
import org.apache.poi.ss.usermodel.Font;
import org.apache.poi.ss.usermodel.RichTextString;
import org.apache.poi.util.Internal;
import org.apache.poi.xssf.model.StylesTable;
import org.apache.poi.xssf.model.ThemesTable;
import org.apache.xerces.impl.xs.SchemaSymbols;
import org.apache.xmlbeans.XmlCursor;
import org.openxmlformats.schemas.spreadsheetml.x2006.main.CTColor;
import org.openxmlformats.schemas.spreadsheetml.x2006.main.CTFont;
import org.openxmlformats.schemas.spreadsheetml.x2006.main.CTRElt;
import org.openxmlformats.schemas.spreadsheetml.x2006.main.CTRPrElt;
import org.openxmlformats.schemas.spreadsheetml.x2006.main.CTRst;
import org.openxmlformats.schemas.spreadsheetml.x2006.main.STXstring;

public class XSSFRichTextString implements RichTextString {
    public static final Pattern utfPtrn = Pattern.compile("_x([0-9A-Fa-f]{4})_");
    public CTRst st;
    public StylesTable styles;

    public XSSFRichTextString(String str) {
        CTRst newInstance = CTRst.Factory.newInstance();
        this.st = newInstance;
        newInstance.setT(str);
        preserveSpaces(this.st.xgetT());
    }

    private ThemesTable getThemesTable() {
        StylesTable stylesTable = this.styles;
        if (stylesTable == null) {
            return null;
        }
        return stylesTable.getTheme();
    }

    public static void preserveSpaces(STXstring sTXstring) {
        String stringValue = sTXstring.getStringValue();
        if (stringValue != null && stringValue.length() > 0) {
            char charAt = stringValue.charAt(0);
            char charAt2 = stringValue.charAt(stringValue.length() - 1);
            if (Character.isWhitespace(charAt) || Character.isWhitespace(charAt2)) {
                XmlCursor newCursor = sTXstring.newCursor();
                newCursor.toNextToken();
                newCursor.insertAttributeWithValue(new QName("http://www.w3.org/XML/1998/namespace", "space"), SchemaSymbols.ATTVAL_PRESERVE);
                newCursor.dispose();
            }
        }
    }

    private void setRunAttributes(CTFont cTFont, CTRPrElt cTRPrElt) {
        if (cTFont.sizeOfBArray() > 0) {
            cTRPrElt.addNewB().setVal(cTFont.getBArray(0).getVal());
        }
        if (cTFont.sizeOfUArray() > 0) {
            cTRPrElt.addNewU().setVal(cTFont.getUArray(0).getVal());
        }
        if (cTFont.sizeOfIArray() > 0) {
            cTRPrElt.addNewI().setVal(cTFont.getIArray(0).getVal());
        }
        if (cTFont.sizeOfColorArray() > 0) {
            CTColor colorArray = cTFont.getColorArray(0);
            CTColor addNewColor = cTRPrElt.addNewColor();
            if (colorArray.isSetAuto()) {
                addNewColor.setAuto(colorArray.getAuto());
            }
            if (colorArray.isSetIndexed()) {
                addNewColor.setIndexed(colorArray.getIndexed());
            }
            if (colorArray.isSetRgb()) {
                addNewColor.setRgb(colorArray.getRgb());
            }
            if (colorArray.isSetTheme()) {
                addNewColor.setTheme(colorArray.getTheme());
            }
            if (colorArray.isSetTint()) {
                addNewColor.setTint(colorArray.getTint());
            }
        }
        if (cTFont.sizeOfSzArray() > 0) {
            cTRPrElt.addNewSz().setVal(cTFont.getSzArray(0).getVal());
        }
        if (cTFont.sizeOfNameArray() > 0) {
            cTRPrElt.addNewRFont().setVal(cTFont.getNameArray(0).getVal());
        }
        if (cTFont.sizeOfFamilyArray() > 0) {
            cTRPrElt.addNewFamily().setVal(cTFont.getFamilyArray(0).getVal());
        }
        if (cTFont.sizeOfSchemeArray() > 0) {
            cTRPrElt.addNewScheme().setVal(cTFont.getSchemeArray(0).getVal());
        }
        if (cTFont.sizeOfCharsetArray() > 0) {
            cTRPrElt.addNewCharset().setVal(cTFont.getCharsetArray(0).getVal());
        }
        if (cTFont.sizeOfCondenseArray() > 0) {
            cTRPrElt.addNewCondense().setVal(cTFont.getCondenseArray(0).getVal());
        }
        if (cTFont.sizeOfExtendArray() > 0) {
            cTRPrElt.addNewExtend().setVal(cTFont.getExtendArray(0).getVal());
        }
        if (cTFont.sizeOfVertAlignArray() > 0) {
            cTRPrElt.addNewVertAlign().setVal(cTFont.getVertAlignArray(0).getVal());
        }
        if (cTFont.sizeOfOutlineArray() > 0) {
            cTRPrElt.addNewOutline().setVal(cTFont.getOutlineArray(0).getVal());
        }
        if (cTFont.sizeOfShadowArray() > 0) {
            cTRPrElt.addNewShadow().setVal(cTFont.getShadowArray(0).getVal());
        }
        if (cTFont.sizeOfStrikeArray() > 0) {
            cTRPrElt.addNewStrike().setVal(cTFont.getStrikeArray(0).getVal());
        }
    }

    public static CTFont toCTFont(CTRPrElt cTRPrElt) {
        CTFont newInstance = CTFont.Factory.newInstance();
        if (cTRPrElt == null) {
            return newInstance;
        }
        if (cTRPrElt.sizeOfBArray() > 0) {
            newInstance.addNewB().setVal(cTRPrElt.getBArray(0).getVal());
        }
        if (cTRPrElt.sizeOfUArray() > 0) {
            newInstance.addNewU().setVal(cTRPrElt.getUArray(0).getVal());
        }
        if (cTRPrElt.sizeOfIArray() > 0) {
            newInstance.addNewI().setVal(cTRPrElt.getIArray(0).getVal());
        }
        if (cTRPrElt.sizeOfColorArray() > 0) {
            CTColor colorArray = cTRPrElt.getColorArray(0);
            CTColor addNewColor = newInstance.addNewColor();
            if (colorArray.isSetAuto()) {
                addNewColor.setAuto(colorArray.getAuto());
            }
            if (colorArray.isSetIndexed()) {
                addNewColor.setIndexed(colorArray.getIndexed());
            }
            if (colorArray.isSetRgb()) {
                addNewColor.setRgb(colorArray.getRgb());
            }
            if (colorArray.isSetTheme()) {
                addNewColor.setTheme(colorArray.getTheme());
            }
            if (colorArray.isSetTint()) {
                addNewColor.setTint(colorArray.getTint());
            }
        }
        if (cTRPrElt.sizeOfSzArray() > 0) {
            newInstance.addNewSz().setVal(cTRPrElt.getSzArray(0).getVal());
        }
        if (cTRPrElt.sizeOfRFontArray() > 0) {
            newInstance.addNewName().setVal(cTRPrElt.getRFontArray(0).getVal());
        }
        if (cTRPrElt.sizeOfFamilyArray() > 0) {
            newInstance.addNewFamily().setVal(cTRPrElt.getFamilyArray(0).getVal());
        }
        if (cTRPrElt.sizeOfSchemeArray() > 0) {
            newInstance.addNewScheme().setVal(cTRPrElt.getSchemeArray(0).getVal());
        }
        if (cTRPrElt.sizeOfCharsetArray() > 0) {
            newInstance.addNewCharset().setVal(cTRPrElt.getCharsetArray(0).getVal());
        }
        if (cTRPrElt.sizeOfCondenseArray() > 0) {
            newInstance.addNewCondense().setVal(cTRPrElt.getCondenseArray(0).getVal());
        }
        if (cTRPrElt.sizeOfExtendArray() > 0) {
            newInstance.addNewExtend().setVal(cTRPrElt.getExtendArray(0).getVal());
        }
        if (cTRPrElt.sizeOfVertAlignArray() > 0) {
            newInstance.addNewVertAlign().setVal(cTRPrElt.getVertAlignArray(0).getVal());
        }
        if (cTRPrElt.sizeOfOutlineArray() > 0) {
            newInstance.addNewOutline().setVal(cTRPrElt.getOutlineArray(0).getVal());
        }
        if (cTRPrElt.sizeOfShadowArray() > 0) {
            newInstance.addNewShadow().setVal(cTRPrElt.getShadowArray(0).getVal());
        }
        if (cTRPrElt.sizeOfStrikeArray() > 0) {
            newInstance.addNewStrike().setVal(cTRPrElt.getStrikeArray(0).getVal());
        }
        return newInstance;
    }

    public static String utfDecode(String str) {
        if (str == null || !str.contains("_x")) {
            return str;
        }
        StringBuilder sb = new StringBuilder();
        Matcher matcher = utfPtrn.matcher(str);
        int i2 = 0;
        while (matcher.find()) {
            int start = matcher.start();
            if (start > i2) {
                sb.append(str.substring(i2, start));
            }
            String group = matcher.group(1);
            sb.append((char) Integer.decode("0x" + group).intValue());
            i2 = matcher.end();
        }
        if (i2 == 0) {
            return str;
        }
        sb.append(str.substring(i2));
        return sb.toString();
    }

    public void append(String str, XSSFFont xSSFFont) {
        if (this.st.sizeOfRArray() == 0 && this.st.isSetT()) {
            CTRElt addNewR = this.st.addNewR();
            addNewR.setT(this.st.getT());
            preserveSpaces(addNewR.xgetT());
            this.st.unsetT();
        }
        CTRElt addNewR2 = this.st.addNewR();
        addNewR2.setT(str);
        preserveSpaces(addNewR2.xgetT());
        if (xSSFFont != null) {
            setRunAttributes(xSSFFont.getCTFont(), addNewR2.addNewRPr());
        }
    }

    @Override // org.apache.poi.ss.usermodel.RichTextString
    public void applyFont(int i2, int i3, short s) {
        XSSFFont xSSFFont;
        StylesTable stylesTable = this.styles;
        if (stylesTable == null) {
            xSSFFont = new XSSFFont();
            xSSFFont.setFontName(DataFormatter.defaultFractionWholePartFormat + ((int) s));
        } else {
            xSSFFont = stylesTable.getFontAt(s);
        }
        applyFont(i2, i3, xSSFFont);
    }

    public CTRst buildCTRst(String str, TreeMap<Integer, CTRPrElt> treeMap) {
        if (str.length() == treeMap.lastKey().intValue()) {
            CTRst newInstance = CTRst.Factory.newInstance();
            int i2 = 0;
            for (Map.Entry<Integer, CTRPrElt> entry : treeMap.entrySet()) {
                int intValue = entry.getKey().intValue();
                CTRElt addNewR = newInstance.addNewR();
                addNewR.setT(str.substring(i2, intValue));
                preserveSpaces(addNewR.xgetT());
                CTRPrElt value = entry.getValue();
                if (value != null) {
                    addNewR.setRPr(value);
                }
                i2 = intValue;
            }
            return newInstance;
        }
        StringBuilder b2 = a.b("Text length was ");
        b2.append(str.length());
        b2.append(" but the last format index was ");
        b2.append(treeMap.lastKey());
        throw new IllegalArgumentException(b2.toString());
    }

    @Override // org.apache.poi.ss.usermodel.RichTextString
    public void clearFormatting() {
        String string = getString();
        this.st.setRArray(null);
        this.st.setT(string);
    }

    @Internal
    public CTRst getCTRst() {
        return this.st;
    }

    public XSSFFont getFontAtIndex(int i2) {
        ThemesTable themesTable = getThemesTable();
        CTRElt[] rArray = this.st.getRArray();
        int i3 = 0;
        for (CTRElt cTRElt : rArray) {
            int length = cTRElt.getT().length();
            if (i2 < i3 || i2 >= i3 + length) {
                i3 += length;
            } else {
                XSSFFont xSSFFont = new XSSFFont(toCTFont(cTRElt.getRPr()));
                xSSFFont.setThemesTable(themesTable);
                return xSSFFont;
            }
        }
        return null;
    }

    public XSSFFont getFontOfFormattingRun(int i2) {
        if (this.st.sizeOfRArray() != 0 && i2 < this.st.sizeOfRArray()) {
            CTRElt rArray = this.st.getRArray(i2);
            if (rArray.getRPr() != null) {
                XSSFFont xSSFFont = new XSSFFont(toCTFont(rArray.getRPr()));
                xSSFFont.setThemesTable(getThemesTable());
                return xSSFFont;
            }
        }
        return null;
    }

    public TreeMap<Integer, CTRPrElt> getFormatMap(CTRst cTRst) {
        TreeMap<Integer, CTRPrElt> treeMap = new TreeMap<>();
        CTRElt[] rArray = cTRst.getRArray();
        int i2 = 0;
        for (CTRElt cTRElt : rArray) {
            String t = cTRElt.getT();
            CTRPrElt rPr = cTRElt.getRPr();
            i2 += t.length();
            treeMap.put(Integer.valueOf(i2), rPr);
        }
        return treeMap;
    }

    @Override // org.apache.poi.ss.usermodel.RichTextString
    public int getIndexOfFormattingRun(int i2) {
        if (this.st.sizeOfRArray() == 0) {
            return 0;
        }
        int i3 = 0;
        for (int i4 = 0; i4 < this.st.sizeOfRArray(); i4++) {
            CTRElt rArray = this.st.getRArray(i4);
            if (i4 == i2) {
                return i3;
            }
            i3 += rArray.getT().length();
        }
        return -1;
    }

    public int getLengthOfFormattingRun(int i2) {
        if (this.st.sizeOfRArray() == 0 || i2 >= this.st.sizeOfRArray()) {
            return -1;
        }
        return this.st.getRArray(i2).getT().length();
    }

    @Override // org.apache.poi.ss.usermodel.RichTextString
    public String getString() {
        if (this.st.sizeOfRArray() == 0) {
            return utfDecode(this.st.getT());
        }
        StringBuilder sb = new StringBuilder();
        for (CTRElt cTRElt : this.st.getRArray()) {
            sb.append(cTRElt.getT());
        }
        return utfDecode(sb.toString());
    }

    public boolean hasFormatting() {
        CTRElt[] rArray = this.st.getRArray();
        if (!(rArray == null || rArray.length == 0)) {
            for (CTRElt cTRElt : rArray) {
                if (cTRElt.isSetRPr()) {
                    return true;
                }
            }
        }
        return false;
    }

    @Override // org.apache.poi.ss.usermodel.RichTextString
    public int length() {
        return getString().length();
    }

    @Override // org.apache.poi.ss.usermodel.RichTextString
    public int numFormattingRuns() {
        return this.st.sizeOfRArray();
    }

    public void setString(String str) {
        clearFormatting();
        this.st.setT(str);
        preserveSpaces(this.st.xgetT());
    }

    public void setStylesTableReference(StylesTable stylesTable) {
        this.styles = stylesTable;
        if (this.st.sizeOfRArray() > 0) {
            for (CTRElt cTRElt : this.st.getRArray()) {
                CTRPrElt rPr = cTRElt.getRPr();
                if (rPr != null && rPr.sizeOfRFontArray() > 0) {
                    String val = rPr.getRFontArray(0).getVal();
                    if (val.startsWith(DataFormatter.defaultFractionWholePartFormat)) {
                        XSSFFont fontAt = this.styles.getFontAt(Integer.parseInt(val.substring(1)));
                        rPr.removeRFont(0);
                        setRunAttributes(fontAt.getCTFont(), rPr);
                    }
                }
            }
        }
    }

    public String toString() {
        return getString();
    }

    public XSSFRichTextString() {
        this.st = CTRst.Factory.newInstance();
    }

    @Override // org.apache.poi.ss.usermodel.RichTextString
    public void applyFont(int i2, int i3, Font font) {
        if (i2 > i3) {
            throw new IllegalArgumentException(a.a("Start index must be less than end index, but had ", i2, " and ", i3));
        } else if (i2 < 0 || i3 > length()) {
            throw new IllegalArgumentException(a.a("Start and end index not in range, but had ", i2, " and ", i3));
        } else if (i2 != i3) {
            if (this.st.sizeOfRArray() == 0 && this.st.isSetT()) {
                this.st.addNewR().setT(this.st.getT());
                this.st.unsetT();
            }
            String string = getString();
            TreeMap<Integer, CTRPrElt> formatMap = getFormatMap(this.st);
            CTRPrElt newInstance = CTRPrElt.Factory.newInstance();
            setRunAttributes(((XSSFFont) font).getCTFont(), newInstance);
            applyFont(formatMap, i2, i3, newInstance);
            this.st.set(buildCTRst(string, formatMap));
        }
    }

    public XSSFRichTextString(CTRst cTRst) {
        this.st = cTRst;
    }

    public void append(String str) {
        append(str, null);
    }

    @Override // org.apache.poi.ss.usermodel.RichTextString
    public void applyFont(Font font) {
        applyFont(0, getString().length(), font);
    }

    @Override // org.apache.poi.ss.usermodel.RichTextString
    public void applyFont(short s) {
        XSSFFont xSSFFont;
        StylesTable stylesTable = this.styles;
        if (stylesTable == null) {
            xSSFFont = new XSSFFont();
            xSSFFont.setFontName(DataFormatter.defaultFractionWholePartFormat + ((int) s));
        } else {
            xSSFFont = stylesTable.getFontAt(s);
        }
        applyFont(0, getString().length(), xSSFFont);
    }

    public void applyFont(TreeMap<Integer, CTRPrElt> treeMap, int i2, int i3, CTRPrElt cTRPrElt) {
        Iterator<Integer> it = treeMap.keySet().iterator();
        int i4 = 0;
        while (it.hasNext()) {
            int intValue = it.next().intValue();
            if (i4 >= i2 && intValue < i3) {
                it.remove();
            }
            i4 = intValue;
        }
        if (i2 > 0 && !treeMap.containsKey(Integer.valueOf(i2))) {
            Iterator<Map.Entry<Integer, CTRPrElt>> it2 = treeMap.entrySet().iterator();
            while (true) {
                if (!it2.hasNext()) {
                    break;
                }
                Map.Entry<Integer, CTRPrElt> next = it2.next();
                if (next.getKey().intValue() > i2) {
                    treeMap.put(Integer.valueOf(i2), next.getValue());
                    break;
                }
            }
        }
        treeMap.put(Integer.valueOf(i3), cTRPrElt);
        SortedMap<Integer, CTRPrElt> subMap = treeMap.subMap(Integer.valueOf(i2), Integer.valueOf(i3));
        while (subMap.size() > 1) {
            subMap.remove(subMap.lastKey());
        }
    }
}
