package org.apache.poi.xssf.usermodel;

import b.b.a.a.a;
import b.e.a.b.i;
import java.io.IOException;
import java.io.InputStream;
import java.io.OutputStream;
import java.util.ArrayList;
import java.util.Arrays;
import java.util.Collection;
import java.util.Collections;
import java.util.Comparator;
import java.util.HashMap;
import java.util.Iterator;
import java.util.LinkedHashMap;
import java.util.LinkedHashSet;
import java.util.List;
import java.util.Map;
import java.util.Set;
import java.util.SortedMap;
import java.util.TreeMap;
import org.apache.poi.POIXMLDocumentPart;
import org.apache.poi.POIXMLException;
import org.apache.poi.POIXMLTypeLoader;
import org.apache.poi.Version;
import org.apache.poi.javax.xml.namespace.QName;
import org.apache.poi.javax.xml.stream.XMLStreamException;
import org.apache.poi.javax.xml.stream.XMLStreamReader;
import org.apache.poi.openxml4j.exceptions.InvalidFormatException;
import org.apache.poi.openxml4j.exceptions.PartAlreadyExistsException;
import org.apache.poi.openxml4j.opc.PackagePart;
import org.apache.poi.openxml4j.opc.PackageRelationship;
import org.apache.poi.openxml4j.opc.PackageRelationshipCollection;
import org.apache.poi.openxml4j.opc.TargetMode;
import org.apache.poi.poifs.crypt.HashAlgorithm;
import org.apache.poi.ss.SpreadsheetVersion;
import org.apache.poi.ss.formula.FormulaShifter;
import org.apache.poi.ss.formula.SheetNameFormatter;
import org.apache.poi.ss.formula.functions.NumericFunction;
import org.apache.poi.ss.usermodel.Cell;
import org.apache.poi.ss.usermodel.CellCopyPolicy;
import org.apache.poi.ss.usermodel.CellRange;
import org.apache.poi.ss.usermodel.CellStyle;
import org.apache.poi.ss.usermodel.CellType;
import org.apache.poi.ss.usermodel.DataValidation;
import org.apache.poi.ss.usermodel.DataValidationHelper;
import org.apache.poi.ss.usermodel.Footer;
import org.apache.poi.ss.usermodel.Header;
import org.apache.poi.ss.usermodel.IgnoredErrorType;
import org.apache.poi.ss.usermodel.IndexedColors;
import org.apache.poi.ss.usermodel.Name;
import org.apache.poi.ss.usermodel.Row;
import org.apache.poi.ss.usermodel.Sheet;
import org.apache.poi.ss.usermodel.Table;
import org.apache.poi.ss.util.AreaReference;
import org.apache.poi.ss.util.CellAddress;
import org.apache.poi.ss.util.CellRangeAddress;
import org.apache.poi.ss.util.CellRangeAddressList;
import org.apache.poi.ss.util.CellReference;
import org.apache.poi.ss.util.PaneInformation;
import org.apache.poi.ss.util.SSCellRange;
import org.apache.poi.ss.util.SheetUtil;
import org.apache.poi.util.Internal;
import org.apache.poi.util.POILogFactory;
import org.apache.poi.util.POILogger;
import org.apache.poi.util.Removal;
import org.apache.poi.xssf.model.CommentsTable;
import org.apache.poi.xssf.usermodel.XSSFPivotTable;
import org.apache.poi.xssf.usermodel.helpers.ColumnHelper;
import org.apache.poi.xssf.usermodel.helpers.XSSFIgnoredErrorHelper;
import org.apache.poi.xssf.usermodel.helpers.XSSFPasswordHelper;
import org.apache.poi.xssf.usermodel.helpers.XSSFRowShifter;
import org.apache.xmlbeans.XmlCursor;
import org.apache.xmlbeans.XmlException;
import org.apache.xmlbeans.XmlObject;
import org.apache.xmlbeans.XmlOptions;
import org.openxmlformats.schemas.spreadsheetml.x2006.main.CTAutoFilter;
import org.openxmlformats.schemas.spreadsheetml.x2006.main.CTBreak;
import org.openxmlformats.schemas.spreadsheetml.x2006.main.CTCalcPr;
import org.openxmlformats.schemas.spreadsheetml.x2006.main.CTCellFormula;
import org.openxmlformats.schemas.spreadsheetml.x2006.main.CTCol;
import org.openxmlformats.schemas.spreadsheetml.x2006.main.CTCols;
import org.openxmlformats.schemas.spreadsheetml.x2006.main.CTComment;
import org.openxmlformats.schemas.spreadsheetml.x2006.main.CTDataValidation;
import org.openxmlformats.schemas.spreadsheetml.x2006.main.CTDataValidations;
import org.openxmlformats.schemas.spreadsheetml.x2006.main.CTDrawing;
import org.openxmlformats.schemas.spreadsheetml.x2006.main.CTHeaderFooter;
import org.openxmlformats.schemas.spreadsheetml.x2006.main.CTHyperlink;
import org.openxmlformats.schemas.spreadsheetml.x2006.main.CTIgnoredError;
import org.openxmlformats.schemas.spreadsheetml.x2006.main.CTLegacyDrawing;
import org.openxmlformats.schemas.spreadsheetml.x2006.main.CTMergeCell;
import org.openxmlformats.schemas.spreadsheetml.x2006.main.CTMergeCells;
import org.openxmlformats.schemas.spreadsheetml.x2006.main.CTOleObject;
import org.openxmlformats.schemas.spreadsheetml.x2006.main.CTOleObjects;
import org.openxmlformats.schemas.spreadsheetml.x2006.main.CTOutlinePr;
import org.openxmlformats.schemas.spreadsheetml.x2006.main.CTPageBreak;
import org.openxmlformats.schemas.spreadsheetml.x2006.main.CTPageMargins;
import org.openxmlformats.schemas.spreadsheetml.x2006.main.CTPageSetUpPr;
import org.openxmlformats.schemas.spreadsheetml.x2006.main.CTPane;
import org.openxmlformats.schemas.spreadsheetml.x2006.main.CTPrintOptions;
import org.openxmlformats.schemas.spreadsheetml.x2006.main.CTRow;
import org.openxmlformats.schemas.spreadsheetml.x2006.main.CTSelection;
import org.openxmlformats.schemas.spreadsheetml.x2006.main.CTSheet;
import org.openxmlformats.schemas.spreadsheetml.x2006.main.CTSheetFormatPr;
import org.openxmlformats.schemas.spreadsheetml.x2006.main.CTSheetPr;
import org.openxmlformats.schemas.spreadsheetml.x2006.main.CTSheetProtection;
import org.openxmlformats.schemas.spreadsheetml.x2006.main.CTSheetView;
import org.openxmlformats.schemas.spreadsheetml.x2006.main.CTSheetViews;
import org.openxmlformats.schemas.spreadsheetml.x2006.main.CTTablePart;
import org.openxmlformats.schemas.spreadsheetml.x2006.main.CTWorksheet;
import org.openxmlformats.schemas.spreadsheetml.x2006.main.CTWorksheetSource;
import org.openxmlformats.schemas.spreadsheetml.x2006.main.STCalcMode;
import org.openxmlformats.schemas.spreadsheetml.x2006.main.STCellFormulaType;
import org.openxmlformats.schemas.spreadsheetml.x2006.main.STPane;
import org.openxmlformats.schemas.spreadsheetml.x2006.main.STPaneState;
import org.openxmlformats.schemas.spreadsheetml.x2006.main.WorksheetDocument;

public class XSSFSheet extends POIXMLDocumentPart implements Sheet {
    public static final /* synthetic */ boolean $assertionsDisabled = false;
    public static final double DEFAULT_MARGIN_BOTTOM = 0.75d;
    public static final double DEFAULT_MARGIN_FOOTER = 0.3d;
    public static final double DEFAULT_MARGIN_HEADER = 0.3d;
    public static final double DEFAULT_MARGIN_LEFT = 0.7d;
    public static final double DEFAULT_MARGIN_RIGHT = 0.7d;
    public static final double DEFAULT_MARGIN_TOP = 0.75d;
    public static final double DEFAULT_ROW_HEIGHT = 15.0d;
    public static final int TWIPS_PER_POINT = 20;
    public static final POILogger logger = POILogFactory.getLogger(XSSFSheet.class);
    public final SortedMap<Integer, XSSFRow> _rows = new TreeMap();
    public List<CellRangeAddress> arrayFormulas;
    public ColumnHelper columnHelper;
    public XSSFDataValidationHelper dataValidationHelper = new XSSFDataValidationHelper(this);
    public List<XSSFHyperlink> hyperlinks;
    public Map<Integer, CTCellFormula> sharedFormulas;
    public CTSheet sheet;
    public CommentsTable sheetComments;
    public SortedMap<String, XSSFTable> tables;
    public CTWorksheet worksheet;

    public XSSFSheet() {
        onDocumentCreate();
    }

    private void checkForIntersectingMergedRegions() {
        List<CellRangeAddress> mergedRegions = getMergedRegions();
        int size = mergedRegions.size();
        int i2 = 0;
        while (i2 < size) {
            CellRangeAddress cellRangeAddress = mergedRegions.get(i2);
            i2++;
            Iterator<CellRangeAddress> it = mergedRegions.subList(i2, mergedRegions.size()).iterator();
            while (true) {
                if (it.hasNext()) {
                    CellRangeAddress next = it.next();
                    if (cellRangeAddress.intersects(next)) {
                        StringBuilder b2 = a.b("The range ");
                        b2.append(cellRangeAddress.formatAsString());
                        b2.append(" intersects with another merged region ");
                        b2.append(next.formatAsString());
                        b2.append(" in this sheet");
                        throw new IllegalStateException(b2.toString());
                    }
                }
            }
        }
    }

    private void checkForMergedRegionsIntersectingArrayFormulas() {
        for (CellRangeAddress cellRangeAddress : getMergedRegions()) {
            validateArrayFormulas(cellRangeAddress);
        }
    }

    private void collapseColumn(int i2) {
        CTCols colsArray = this.worksheet.getColsArray(0);
        int indexOfColumn = this.columnHelper.getIndexOfColumn(colsArray, this.columnHelper.getColumn((long) i2, false));
        if (indexOfColumn != -1) {
            int findStartOfColumnOutlineGroup = findStartOfColumnOutlineGroup(indexOfColumn);
            setColumn(setGroupHidden(findStartOfColumnOutlineGroup, colsArray.getColArray(findStartOfColumnOutlineGroup).getOutlineLevel(), true) + 1, 0, null, null, Boolean.TRUE);
        }
    }

    private void collapseRow(int i2) {
        XSSFRow row = getRow(i2);
        if (row != null) {
            int writeHidden = writeHidden(row, findStartOfRowOutlineGroup(i2), true);
            if (getRow(writeHidden) != null) {
                getRow(writeHidden).getCTRow().setCollapsed(true);
            } else {
                createRow(writeHidden).getCTRow().setCollapsed(true);
            }
        }
    }

    private boolean containsColumn(CTCol cTCol, int i2) {
        long j = (long) i2;
        return cTCol.getMin() <= j && j <= cTCol.getMax();
    }

    private XSSFPivotTable createPivotTable() {
        XSSFWorkbook workbook = getWorkbook();
        List<XSSFPivotTable> pivotTables = workbook.getPivotTables();
        int size = getWorkbook().getPivotTables().size() + 1;
        XSSFPivotTable xSSFPivotTable = (XSSFPivotTable) createRelationship(XSSFRelation.PIVOT_TABLE, XSSFFactory.getInstance(), size);
        xSSFPivotTable.setParentSheet(this);
        pivotTables.add(xSSFPivotTable);
        XSSFWorkbook workbook2 = getWorkbook();
        XSSFPivotCacheDefinition xSSFPivotCacheDefinition = (XSSFPivotCacheDefinition) workbook2.createRelationship(XSSFRelation.PIVOT_CACHE_DEFINITION, XSSFFactory.getInstance(), size);
        String relationId = workbook2.getRelationId(xSSFPivotCacheDefinition);
        xSSFPivotTable.getPackagePart().addRelationship(xSSFPivotCacheDefinition.getPackagePart().getPartName(), TargetMode.INTERNAL, XSSFRelation.PIVOT_CACHE_DEFINITION.getRelation());
        xSSFPivotTable.setPivotCacheDefinition(xSSFPivotCacheDefinition);
        xSSFPivotTable.setPivotCache(new XSSFPivotCache(workbook2.addPivotCache(relationId)));
        xSSFPivotTable.getPivotCacheDefinition().getCTPivotCacheDefinition().setId(xSSFPivotCacheDefinition.getRelationId((XSSFPivotCacheRecords) xSSFPivotCacheDefinition.createRelationship(XSSFRelation.PIVOT_CACHE_RECORDS, XSSFFactory.getInstance(), size)));
        workbook.setPivotTables(pivotTables);
        return xSSFPivotTable;
    }

    private CTOutlinePr ensureOutlinePr() {
        CTSheetPr sheetPr = this.worksheet.isSetSheetPr() ? this.worksheet.getSheetPr() : this.worksheet.addNewSheetPr();
        return sheetPr.isSetOutlinePr() ? sheetPr.getOutlinePr() : sheetPr.addNewOutlinePr();
    }

    private void expandColumn(int i2) {
        CTCols colsArray = this.worksheet.getColsArray(0);
        CTCol column = this.columnHelper.getColumn((long) i2, false);
        int findColInfoIdx = findColInfoIdx((int) column.getMax(), this.columnHelper.getIndexOfColumn(colsArray, column));
        if (findColInfoIdx != -1 && isColumnGroupCollapsed(findColInfoIdx)) {
            int findEndOfColumnOutlineGroup = findEndOfColumnOutlineGroup(findColInfoIdx);
            CTCol[] colArray = colsArray.getColArray();
            CTCol cTCol = colArray[findEndOfColumnOutlineGroup];
            if (!isColumnGroupHiddenByParent(findColInfoIdx)) {
                short outlineLevel = cTCol.getOutlineLevel();
                boolean z = false;
                for (int findStartOfColumnOutlineGroup = findStartOfColumnOutlineGroup(findColInfoIdx); findStartOfColumnOutlineGroup <= findEndOfColumnOutlineGroup; findStartOfColumnOutlineGroup++) {
                    CTCol cTCol2 = colArray[findStartOfColumnOutlineGroup];
                    if (outlineLevel == cTCol2.getOutlineLevel()) {
                        cTCol2.unsetHidden();
                        if (z) {
                            cTCol2.setCollapsed(true);
                            z = false;
                        }
                    } else {
                        z = true;
                    }
                }
            }
            Boolean bool = Boolean.FALSE;
            setColumn(((int) cTCol.getMax()) + 1, null, null, bool, bool);
        }
    }

    private void expandRow(int i2) {
        if (i2 != -1) {
            XSSFRow row = getRow(i2);
            if (row.getCTRow().isSetHidden()) {
                int findEndOfRowOutlineGroup = findEndOfRowOutlineGroup(i2);
                short outlineLevel = row.getCTRow().getOutlineLevel();
                if (!isRowGroupHiddenByParent(i2)) {
                    for (int findStartOfRowOutlineGroup = findStartOfRowOutlineGroup(i2); findStartOfRowOutlineGroup < findEndOfRowOutlineGroup; findStartOfRowOutlineGroup++) {
                        if (outlineLevel == getRow(findStartOfRowOutlineGroup).getCTRow().getOutlineLevel()) {
                            getRow(findStartOfRowOutlineGroup).getCTRow().unsetHidden();
                        } else if (!isRowGroupCollapsed(findStartOfRowOutlineGroup)) {
                            getRow(findStartOfRowOutlineGroup).getCTRow().unsetHidden();
                        }
                    }
                }
                CTRow cTRow = getRow(findEndOfRowOutlineGroup).getCTRow();
                if (cTRow.getCollapsed()) {
                    cTRow.unsetCollapsed();
                }
            }
        }
    }

    private int findColInfoIdx(int i2, int i3) {
        CTCols colsArray = this.worksheet.getColsArray(0);
        if (i2 < 0) {
            throw new IllegalArgumentException(a.c("column parameter out of range: ", i2));
        } else if (i3 >= 0) {
            CTCol[] colArray = colsArray.getColArray();
            for (int i4 = i3; i4 < colArray.length; i4++) {
                CTCol cTCol = colArray[i4];
                if (containsColumn(cTCol, i2)) {
                    return i4;
                }
                if (cTCol.getMin() > ((long) i3)) {
                    return -1;
                }
            }
            return -1;
        } else {
            throw new IllegalArgumentException(a.c("fromIdx parameter out of range: ", i3));
        }
    }

    private int findEndOfColumnOutlineGroup(int i2) {
        CTCol[] colArray = this.worksheet.getColsArray(0).getColArray();
        CTCol cTCol = colArray[i2];
        short outlineLevel = cTCol.getOutlineLevel();
        int length = colArray.length - 1;
        while (i2 < length) {
            int i3 = i2 + 1;
            CTCol cTCol2 = colArray[i3];
            if (!isAdjacentBefore(cTCol, cTCol2) || cTCol2.getOutlineLevel() < outlineLevel) {
                break;
            }
            i2 = i3;
            cTCol = cTCol2;
        }
        return i2;
    }

    private int findStartOfColumnOutlineGroup(int i2) {
        CTCol[] colArray = this.worksheet.getColsArray(0).getColArray();
        CTCol cTCol = colArray[i2];
        short outlineLevel = cTCol.getOutlineLevel();
        while (i2 != 0) {
            CTCol cTCol2 = colArray[i2 - 1];
            if (!isAdjacentBefore(cTCol2, cTCol) || cTCol2.getOutlineLevel() < outlineLevel) {
                break;
            }
            i2--;
            cTCol = cTCol2;
        }
        return i2;
    }

    private int findStartOfRowOutlineGroup(int i2) {
        short outlineLevel = getRow(i2).getCTRow().getOutlineLevel();
        while (getRow(i2) != null) {
            if (getRow(i2).getCTRow().getOutlineLevel() < outlineLevel) {
                return i2 + 1;
            }
            i2--;
        }
        return i2;
    }

    private int[] getBreaks(CTPageBreak cTPageBreak) {
        CTBreak[] brkArray = cTPageBreak.getBrkArray();
        int[] iArr = new int[brkArray.length];
        for (int i2 = 0; i2 < brkArray.length; i2++) {
            iArr[i2] = ((int) brkArray[i2].getId()) - 1;
        }
        return iArr;
    }

    private CellRange<XSSFCell> getCellRange(CellRangeAddress cellRangeAddress) {
        int firstRow = cellRangeAddress.getFirstRow();
        int firstColumn = cellRangeAddress.getFirstColumn();
        int lastRow = cellRangeAddress.getLastRow();
        int lastColumn = cellRangeAddress.getLastColumn();
        int i2 = (lastRow - firstRow) + 1;
        int i3 = (lastColumn - firstColumn) + 1;
        ArrayList arrayList = new ArrayList(i2 * i3);
        for (int i4 = firstRow; i4 <= lastRow; i4++) {
            for (int i5 = firstColumn; i5 <= lastColumn; i5++) {
                XSSFRow row = getRow(i4);
                if (row == null) {
                    row = createRow(i4);
                }
                XSSFCell cell = row.getCell(i5);
                if (cell == null) {
                    cell = row.createCell(i5);
                }
                arrayList.add(cell);
            }
        }
        return SSCellRange.create(firstRow, firstColumn, i2, i3, arrayList, XSSFCell.class);
    }

    private CTSheetView getDefaultSheetView() {
        int sizeOfSheetViewArray;
        CTSheetViews sheetTypeSheetViews = getSheetTypeSheetViews();
        if (sheetTypeSheetViews == null || (sizeOfSheetViewArray = sheetTypeSheetViews.sizeOfSheetViewArray()) == 0) {
            return null;
        }
        return sheetTypeSheetViews.getSheetViewArray(sizeOfSheetViewArray - 1);
    }

    private short getMaxOutlineLevelCols() {
        int i2 = 0;
        for (CTCol cTCol : this.worksheet.getColsArray(0).getColArray()) {
            i2 = Math.max(i2, (int) cTCol.getOutlineLevel());
        }
        return (short) i2;
    }

    private short getMaxOutlineLevelRows() {
        int i2 = 0;
        for (XSSFRow xSSFRow : this._rows.values()) {
            i2 = Math.max(i2, (int) xSSFRow.getCTRow().getOutlineLevel());
        }
        return (short) i2;
    }

    private CTPane getPane() {
        if (getDefaultSheetView().getPane() == null) {
            getDefaultSheetView().addNewPane();
        }
        return getDefaultSheetView().getPane();
    }

    public static String getReferenceBuiltInRecord(String str, int i2, int i3, int i4, int i5) {
        int i6;
        String str2;
        CellReference cellReference = new CellReference(str, 0, i2, true, true);
        CellReference cellReference2 = new CellReference(str, 0, i3, true, true);
        CellReference cellReference3 = new CellReference(str, i4, 0, true, true);
        CellReference cellReference4 = new CellReference(str, i5, 0, true, true);
        String format = SheetNameFormatter.format(str);
        String str3 = "";
        if (i2 == -1 && i3 == -1) {
            i6 = i4;
            str2 = str3;
        } else {
            str2 = a.b(format, "!$", cellReference.getCellRefParts()[2], ":$", cellReference2.getCellRefParts()[2]);
            i6 = i4;
        }
        if (!(i6 == -1 && i5 == -1)) {
            String str4 = cellReference3.getCellRefParts()[1];
            String str5 = cellReference4.getCellRefParts()[1];
            if (!str4.equals("0") && !str5.equals("0")) {
                str3 = a.b(format, "!$", str4, ":$", str5);
            }
        }
        StringBuilder b2 = a.b(str2);
        if (b2.length() > 0 && str3.length() > 0) {
            b2.append(',');
        }
        b2.append(str3);
        return b2.toString();
    }

    private CellRangeAddress getRepeatingRowsOrColums(boolean z) {
        String refersToFormula;
        XSSFName builtInName = getWorkbook().getBuiltInName(XSSFName.BUILTIN_PRINT_TITLE, getWorkbook().getSheetIndex(this));
        if (builtInName == null || (refersToFormula = builtInName.getRefersToFormula()) == null) {
            return null;
        }
        String[] split = refersToFormula.split(XSSFDataValidationConstraint.LIST_SEPARATOR);
        int lastRowIndex = SpreadsheetVersion.EXCEL2007.getLastRowIndex();
        int lastColumnIndex = SpreadsheetVersion.EXCEL2007.getLastColumnIndex();
        for (String str : split) {
            CellRangeAddress valueOf = CellRangeAddress.valueOf(str);
            if ((valueOf.getFirstColumn() == 0 && valueOf.getLastColumn() == lastColumnIndex) || (valueOf.getFirstColumn() == -1 && valueOf.getLastColumn() == -1)) {
                if (z) {
                    return valueOf;
                }
            } else if (((valueOf.getFirstRow() == 0 && valueOf.getLastRow() == lastRowIndex) || (valueOf.getFirstRow() == -1 && valueOf.getLastRow() == -1)) && !z) {
                return valueOf;
            }
        }
        return null;
    }

    private List<XSSFRow> getRows(int i2, int i3, boolean z) {
        if (i2 <= i3) {
            ArrayList arrayList = new ArrayList();
            if (z) {
                while (i2 <= i3) {
                    XSSFRow row = getRow(i2);
                    if (row == null) {
                        row = createRow(i2);
                    }
                    arrayList.add(row);
                    i2++;
                }
            } else {
                arrayList.addAll(this._rows.subMap(new Integer(i2), new Integer(i3 + 1)).values());
            }
            return arrayList;
        }
        throw new IllegalArgumentException("getRows: startRowNum must be less than or equal to endRowNum");
    }

    private CTHeaderFooter getSheetTypeHeaderFooter() {
        if (this.worksheet.getHeaderFooter() == null) {
            this.worksheet.setHeaderFooter(CTHeaderFooter.Factory.newInstance());
        }
        return this.worksheet.getHeaderFooter();
    }

    private CTPageSetUpPr getSheetTypePageSetUpPr() {
        CTSheetPr sheetTypeSheetPr = getSheetTypeSheetPr();
        return sheetTypeSheetPr.isSetPageSetUpPr() ? sheetTypeSheetPr.getPageSetUpPr() : sheetTypeSheetPr.addNewPageSetUpPr();
    }

    private CTSelection getSheetTypeSelection() {
        if (getSheetTypeSheetView().sizeOfSelectionArray() == 0) {
            getSheetTypeSheetView().insertNewSelection(0);
        }
        return getSheetTypeSheetView().getSelectionArray(0);
    }

    private CTSheetFormatPr getSheetTypeSheetFormatPr() {
        return this.worksheet.isSetSheetFormatPr() ? this.worksheet.getSheetFormatPr() : this.worksheet.addNewSheetFormatPr();
    }

    private CTSheetPr getSheetTypeSheetPr() {
        if (this.worksheet.getSheetPr() == null) {
            this.worksheet.setSheetPr(CTSheetPr.Factory.newInstance());
        }
        return this.worksheet.getSheetPr();
    }

    private CTSheetView getSheetTypeSheetView() {
        if (getDefaultSheetView() == null) {
            getSheetTypeSheetViews().setSheetViewArray(0, CTSheetView.Factory.newInstance());
        }
        return getDefaultSheetView();
    }

    private CTSheetViews getSheetTypeSheetViews() {
        if (this.worksheet.getSheetViews() == null) {
            this.worksheet.setSheetViews(CTSheetViews.Factory.newInstance());
            this.worksheet.getSheetViews().addNewSheetView();
        }
        return this.worksheet.getSheetViews();
    }

    private void groupColumn1Based(int i2, int i3) {
        CTCols colsArray = this.worksheet.getColsArray(0);
        CTCol newInstance = CTCol.Factory.newInstance();
        long j = (long) i3;
        CTCol column1Based = this.columnHelper.getColumn1Based(j, false);
        if (column1Based != null) {
            column1Based = (CTCol) column1Based.copy();
        }
        newInstance.setMin((long) i2);
        newInstance.setMax(j);
        this.columnHelper.addCleanColIntoCols(colsArray, newInstance);
        CTCol column1Based2 = this.columnHelper.getColumn1Based(j, false);
        if (!(column1Based == null || column1Based2 == null)) {
            this.columnHelper.setColumnAttributes(column1Based, column1Based2);
        }
        while (i2 <= i3) {
            CTCol column1Based3 = this.columnHelper.getColumn1Based((long) i2, false);
            column1Based3.setOutlineLevel((short) (column1Based3.getOutlineLevel() + 1));
            i2 = ((int) column1Based3.getMax()) + 1;
        }
        this.worksheet.setColsArray(0, colsArray);
        setSheetFormatPrOutlineLevelCol();
    }

    private void initHyperlinks() {
        this.hyperlinks = new ArrayList();
        if (this.worksheet.isSetHyperlinks()) {
            try {
                PackageRelationshipCollection relationshipsByType = getPackagePart().getRelationshipsByType(XSSFRelation.SHEET_HYPERLINKS.getRelation());
                CTHyperlink[] hyperlinkArray = this.worksheet.getHyperlinks().getHyperlinkArray();
                for (CTHyperlink cTHyperlink : hyperlinkArray) {
                    PackageRelationship packageRelationship = null;
                    if (cTHyperlink.getId() != null) {
                        packageRelationship = relationshipsByType.getRelationshipByID(cTHyperlink.getId());
                    }
                    this.hyperlinks.add(new XSSFHyperlink(cTHyperlink, packageRelationship));
                }
            } catch (InvalidFormatException e2) {
                throw new POIXMLException(e2);
            }
        }
    }

    private void initRows(CTWorksheet cTWorksheet) {
        this._rows.clear();
        this.tables = new TreeMap();
        this.sharedFormulas = new HashMap();
        this.arrayFormulas = new ArrayList();
        for (CTRow cTRow : cTWorksheet.getSheetData().getRowArray()) {
            XSSFRow xSSFRow = new XSSFRow(cTRow, this);
            this._rows.put(new Integer(xSSFRow.getRowNum()), xSSFRow);
        }
    }

    private boolean isAdjacentBefore(CTCol cTCol, CTCol cTCol2) {
        return cTCol.getMax() == cTCol2.getMin() - 1;
    }

    private boolean isColumnGroupCollapsed(int i2) {
        CTCol[] colArray = this.worksheet.getColsArray(0).getColArray();
        int findEndOfColumnOutlineGroup = findEndOfColumnOutlineGroup(i2);
        int i3 = findEndOfColumnOutlineGroup + 1;
        if (i3 >= colArray.length) {
            return false;
        }
        CTCol cTCol = colArray[i3];
        if (!isAdjacentBefore(colArray[findEndOfColumnOutlineGroup], cTCol)) {
            return false;
        }
        return cTCol.getCollapsed();
    }

    /* JADX WARNING: Removed duplicated region for block: B:13:0x0047 A[RETURN] */
    /* JADX WARNING: Removed duplicated region for block: B:14:0x0048 A[RETURN] */
    /* JADX WARNING: Removed duplicated region for block: B:8:0x002f  */
    private boolean isColumnGroupHiddenByParent(int i2) {
        boolean z;
        short s;
        int findStartOfColumnOutlineGroup;
        boolean z2;
        short s2 = 0;
        CTCols colsArray = this.worksheet.getColsArray(0);
        int findEndOfColumnOutlineGroup = findEndOfColumnOutlineGroup(i2);
        CTCol[] colArray = colsArray.getColArray();
        if (findEndOfColumnOutlineGroup < colArray.length) {
            CTCol cTCol = colArray[findEndOfColumnOutlineGroup + 1];
            if (isAdjacentBefore(colArray[findEndOfColumnOutlineGroup], cTCol)) {
                s = cTCol.getOutlineLevel();
                z = cTCol.getHidden();
                findStartOfColumnOutlineGroup = findStartOfColumnOutlineGroup(i2);
                if (findStartOfColumnOutlineGroup > 0) {
                    CTCol cTCol2 = colArray[findStartOfColumnOutlineGroup - 1];
                    if (isAdjacentBefore(cTCol2, colArray[findStartOfColumnOutlineGroup])) {
                        s2 = cTCol2.getOutlineLevel();
                        z2 = cTCol2.getHidden();
                        return s > s2 ? z : z2;
                    }
                }
                z2 = false;
                if (s > s2) {
                }
            }
        }
        s = 0;
        z = false;
        findStartOfColumnOutlineGroup = findStartOfColumnOutlineGroup(i2);
        if (findStartOfColumnOutlineGroup > 0) {
        }
        z2 = false;
        if (s > s2) {
        }
    }

    private boolean isRowGroupCollapsed(int i2) {
        int findEndOfRowOutlineGroup = findEndOfRowOutlineGroup(i2) + 1;
        if (getRow(findEndOfRowOutlineGroup) == null) {
            return false;
        }
        return getRow(findEndOfRowOutlineGroup).getCTRow().getCollapsed();
    }

    private boolean isRowGroupHiddenByParent(int i2) {
        short s;
        boolean z;
        boolean z2;
        int findEndOfRowOutlineGroup = findEndOfRowOutlineGroup(i2);
        short s2 = 0;
        if (getRow(findEndOfRowOutlineGroup) == null) {
            z = false;
            s = 0;
        } else {
            s = getRow(findEndOfRowOutlineGroup).getCTRow().getOutlineLevel();
            z = getRow(findEndOfRowOutlineGroup).getCTRow().getHidden();
        }
        int findStartOfRowOutlineGroup = findStartOfRowOutlineGroup(i2);
        if (findStartOfRowOutlineGroup < 0 || getRow(findStartOfRowOutlineGroup) == null) {
            z2 = false;
        } else {
            s2 = getRow(findStartOfRowOutlineGroup).getCTRow().getOutlineLevel();
            z2 = getRow(findStartOfRowOutlineGroup).getCTRow().getHidden();
        }
        return s > s2 ? z : z2;
    }

    public static CTWorksheet newSheet() {
        CTWorksheet newInstance = CTWorksheet.Factory.newInstance();
        newInstance.addNewSheetFormatPr().setDefaultRowHeight(15.0d);
        newInstance.addNewSheetViews().addNewSheetView().setWorkbookViewId(0);
        newInstance.addNewDimension().setRef("A1");
        newInstance.addNewSheetData();
        CTPageMargins addNewPageMargins = newInstance.addNewPageMargins();
        addNewPageMargins.setBottom(0.75d);
        addNewPageMargins.setFooter(0.3d);
        addNewPageMargins.setHeader(0.3d);
        addNewPageMargins.setLeft(0.7d);
        addNewPageMargins.setRight(0.7d);
        addNewPageMargins.setTop(0.75d);
        return newInstance;
    }

    private void removeBreak(int i2, CTPageBreak cTPageBreak) {
        int i3 = i2 + 1;
        CTBreak[] brkArray = cTPageBreak.getBrkArray();
        for (int i4 = 0; i4 < brkArray.length; i4++) {
            if (brkArray[i4].getId() == ((long) i3)) {
                cTPageBreak.removeBrk(i4);
            }
        }
    }

    private CTSheetProtection safeGetProtectionField() {
        if (!isSheetProtectionEnabled()) {
            return this.worksheet.addNewSheetProtection();
        }
        return this.worksheet.getSheetProtection();
    }

    private void setBreak(int i2, CTPageBreak cTPageBreak, int i3) {
        CTBreak addNewBrk = cTPageBreak.addNewBrk();
        addNewBrk.setId((long) (i2 + 1));
        addNewBrk.setMan(true);
        addNewBrk.setMax((long) i3);
        long sizeOfBrkArray = (long) cTPageBreak.sizeOfBrkArray();
        cTPageBreak.setCount(sizeOfBrkArray);
        cTPageBreak.setManualBreakCount(sizeOfBrkArray);
    }

    private void setColWidthAttribute(CTCols cTCols) {
        CTCol[] colArray = cTCols.getColArray();
        for (CTCol cTCol : colArray) {
            if (!cTCol.isSetWidth()) {
                cTCol.setWidth((double) getDefaultColumnWidth());
                cTCol.setCustomWidth(false);
            }
        }
    }

    private void setColumn(int i2, Integer num, Integer num2, Boolean bool, Boolean bool2) {
        CTCol cTCol;
        boolean z = false;
        CTCols colsArray = this.worksheet.getColsArray(0);
        CTCol[] colArray = colsArray.getColArray();
        int length = colArray.length;
        int i3 = 0;
        while (true) {
            if (i3 >= length) {
                break;
            }
            cTCol = colArray[i3];
            long min = cTCol.getMin();
            long max = cTCol.getMax();
            long j = (long) i2;
            int i4 = (min > j ? 1 : (min == j ? 0 : -1));
            if (i4 >= 0 && max <= j) {
                break;
            } else if (i4 > 0) {
                break;
            } else {
                i3++;
            }
        }
        cTCol = null;
        if (cTCol == null) {
            CTCol newInstance = CTCol.Factory.newInstance();
            long j2 = (long) i2;
            newInstance.setMin(j2);
            newInstance.setMax(j2);
            unsetCollapsed(bool2.booleanValue(), newInstance);
            this.columnHelper.addCleanColIntoCols(colsArray, newInstance);
            return;
        }
        boolean z2 = (num == null || cTCol.getStyle() == ((long) num.intValue())) ? false : true;
        boolean z3 = (num2 == null || cTCol.getOutlineLevel() == num2.intValue()) ? false : true;
        boolean z4 = (bool == null || cTCol.getHidden() == bool.booleanValue()) ? false : true;
        boolean z5 = (bool2 == null || cTCol.getCollapsed() == bool2.booleanValue()) ? false : true;
        if (z3 || z4 || z5 || z2) {
            z = true;
        }
        if (z) {
            long min2 = cTCol.getMin();
            long max2 = cTCol.getMax();
            long j3 = (long) i2;
            int i5 = (min2 > j3 ? 1 : (min2 == j3 ? 0 : -1));
            if (i5 == 0 && max2 == j3) {
                unsetCollapsed(bool2.booleanValue(), cTCol);
            } else if (i5 == 0 || max2 == j3) {
                if (i5 == 0) {
                    cTCol.setMin((long) (i2 + 1));
                } else {
                    cTCol.setMax((long) (i2 - 1));
                }
                CTCol cloneCol = this.columnHelper.cloneCol(colsArray, cTCol);
                cloneCol.setMin(j3);
                unsetCollapsed(bool2.booleanValue(), cloneCol);
                this.columnHelper.addCleanColIntoCols(colsArray, cloneCol);
            } else {
                CTCol cloneCol2 = this.columnHelper.cloneCol(colsArray, cTCol);
                CTCol cloneCol3 = this.columnHelper.cloneCol(colsArray, cTCol);
                cTCol.setMax((long) (i2 - 1));
                cloneCol2.setMin(j3);
                cloneCol2.setMax(j3);
                unsetCollapsed(bool2.booleanValue(), cloneCol2);
                this.columnHelper.addCleanColIntoCols(colsArray, cloneCol2);
                cloneCol3.setMin((long) (i2 + 1));
                cloneCol3.setMax((long) ((int) max2));
                this.columnHelper.addCleanColIntoCols(colsArray, cloneCol3);
            }
        }
    }

    private int setGroupHidden(int i2, int i3, boolean z) {
        CTCol[] colArray = this.worksheet.getColsArray(0).getColArray();
        CTCol cTCol = colArray[i2];
        while (i2 < colArray.length) {
            cTCol.setHidden(z);
            i2++;
            if (i2 < colArray.length) {
                CTCol cTCol2 = colArray[i2];
                if (!isAdjacentBefore(cTCol, cTCol2) || cTCol2.getOutlineLevel() < i3) {
                    break;
                }
                cTCol = cTCol2;
            }
        }
        return (int) cTCol.getMax();
    }

    private void setRepeatingRowsAndColumns(CellRangeAddress cellRangeAddress, CellRangeAddress cellRangeAddress2) {
        int i2;
        int i3;
        int i4;
        int i5 = -1;
        if (cellRangeAddress != null) {
            i3 = cellRangeAddress.getFirstRow();
            i2 = cellRangeAddress.getLastRow();
            if ((i3 == -1 && i2 != -1) || i3 < -1 || i2 < -1 || i3 > i2) {
                throw new IllegalArgumentException("Invalid row range specification");
            }
        } else {
            i3 = -1;
            i2 = -1;
        }
        if (cellRangeAddress2 != null) {
            int firstColumn = cellRangeAddress2.getFirstColumn();
            i4 = cellRangeAddress2.getLastColumn();
            if ((firstColumn != -1 || i4 == -1) && firstColumn >= -1 && i4 >= -1 && firstColumn <= i4) {
                i5 = firstColumn;
            } else {
                throw new IllegalArgumentException("Invalid column range specification");
            }
        } else {
            i4 = -1;
        }
        int sheetIndex = getWorkbook().getSheetIndex(this);
        boolean z = cellRangeAddress == null && cellRangeAddress2 == null;
        XSSFName builtInName = getWorkbook().getBuiltInName(XSSFName.BUILTIN_PRINT_TITLE, sheetIndex);
        if (!z) {
            if (builtInName == null) {
                builtInName = getWorkbook().createBuiltInName(XSSFName.BUILTIN_PRINT_TITLE, sheetIndex);
            }
            builtInName.setRefersToFormula(getReferenceBuiltInRecord(builtInName.getSheetName(), i5, i4, i3, i2));
            if (!this.worksheet.isSetPageSetup() || !this.worksheet.isSetPageMargins()) {
                getPrintSetup().setValidSettings(false);
            }
        } else if (builtInName != null) {
            getWorkbook().removeName(builtInName);
        }
    }

    private void setSheetFormatPrOutlineLevelCol() {
        getSheetTypeSheetFormatPr().setOutlineLevelCol(getMaxOutlineLevelCols());
    }

    private void setSheetFormatPrOutlineLevelRow() {
        getSheetTypeSheetFormatPr().setOutlineLevelRow(getMaxOutlineLevelRows());
    }

    private int shiftedRowNum(int i2, int i3, int i4, int i5) {
        return (i5 >= i2 || (i4 <= 0 && i2 - i5 <= i4)) ? (i5 <= i3 || (i4 >= 0 && i5 - i3 <= i4)) ? i5 < i2 ? (i3 - i2) + i5 : i5 > i3 ? i5 - (i3 - i2) : i5 + i4 : i5 : i5;
    }

    public static boolean shouldRemoveRow(int i2, int i3, int i4, int i5) {
        if (i5 < i2 + i4 || i5 > i3 + i4) {
            return false;
        }
        if (i4 <= 0 || i5 <= i3) {
            return i4 < 0 && i5 < i2;
        }
        return true;
    }

    private void unsetCollapsed(boolean z, CTCol cTCol) {
        if (z) {
            cTCol.setCollapsed(z);
        } else {
            cTCol.unsetCollapsed();
        }
    }

    private void validateArrayFormulas(CellRangeAddress cellRangeAddress) {
        int firstColumn = cellRangeAddress.getFirstColumn();
        int lastRow = cellRangeAddress.getLastRow();
        int lastColumn = cellRangeAddress.getLastColumn();
        for (int firstRow = cellRangeAddress.getFirstRow(); firstRow <= lastRow; firstRow++) {
            XSSFRow row = getRow(firstRow);
            if (row != null) {
                for (int i2 = firstColumn; i2 <= lastColumn; i2++) {
                    XSSFCell cell = row.getCell(i2);
                    if (cell != null && cell.isPartOfArrayFormulaGroup()) {
                        CellRangeAddress arrayFormulaRange = cell.getArrayFormulaRange();
                        if (arrayFormulaRange.getNumberOfCells() > 1 && cellRangeAddress.intersects(arrayFormulaRange)) {
                            StringBuilder b2 = a.b("The range ");
                            b2.append(cellRangeAddress.formatAsString());
                            b2.append(" intersects with a multi-cell array formula. ");
                            b2.append("You cannot merge cells of an array.");
                            throw new IllegalStateException(b2.toString());
                        }
                    }
                }
                continue;
            }
        }
    }

    private void validateMergedRegions(CellRangeAddress cellRangeAddress) {
        for (CellRangeAddress cellRangeAddress2 : getMergedRegions()) {
            if (cellRangeAddress2.intersects(cellRangeAddress)) {
                StringBuilder b2 = a.b("Cannot add merged region ");
                b2.append(cellRangeAddress.formatAsString());
                b2.append(" to sheet because it overlaps with an existing merged region (");
                b2.append(cellRangeAddress2.formatAsString());
                b2.append(").");
                throw new IllegalStateException(b2.toString());
            }
        }
    }

    private int writeHidden(XSSFRow xSSFRow, int i2, boolean z) {
        short outlineLevel = xSSFRow.getCTRow().getOutlineLevel();
        Iterator<Row> rowIterator = rowIterator();
        while (rowIterator.hasNext()) {
            XSSFRow xSSFRow2 = (XSSFRow) rowIterator.next();
            if (xSSFRow2.getRowNum() >= i2 && xSSFRow2.getCTRow().getOutlineLevel() >= outlineLevel) {
                xSSFRow2.getCTRow().setHidden(z);
                i2++;
            }
        }
        return i2;
    }

    @Internal
    public void addHyperlink(XSSFHyperlink xSSFHyperlink) {
        this.hyperlinks.add(xSSFHyperlink);
    }

    public void addIgnoredErrors(CellReference cellReference, IgnoredErrorType... ignoredErrorTypeArr) {
        addIgnoredErrors(cellReference.formatAsString(), ignoredErrorTypeArr);
    }

    @Override // org.apache.poi.ss.usermodel.Sheet
    public int addMergedRegion(CellRangeAddress cellRangeAddress) {
        return addMergedRegion(cellRangeAddress, true);
    }

    @Override // org.apache.poi.ss.usermodel.Sheet
    public int addMergedRegionUnsafe(CellRangeAddress cellRangeAddress) {
        return addMergedRegion(cellRangeAddress, false);
    }

    @Override // org.apache.poi.ss.usermodel.Sheet
    public void addValidationData(DataValidation dataValidation) {
        XSSFDataValidation xSSFDataValidation = (XSSFDataValidation) dataValidation;
        CTDataValidations dataValidations = this.worksheet.getDataValidations();
        if (dataValidations == null) {
            dataValidations = this.worksheet.addNewDataValidations();
        }
        int sizeOfDataValidationArray = dataValidations.sizeOfDataValidationArray();
        dataValidations.addNewDataValidation().set(xSSFDataValidation.getCtDdataValidation());
        dataValidations.setCount((long) (sizeOfDataValidationArray + 1));
    }

    @Override // org.apache.poi.ss.usermodel.Sheet
    public void autoSizeColumn(int i2) {
        autoSizeColumn(i2, false);
    }

    @Override // org.apache.poi.POIXMLDocumentPart
    public void commit() {
        OutputStream outputStream = getPackagePart().getOutputStream();
        write(outputStream);
        outputStream.close();
    }

    public void copyRows(List<? extends Row> list, int i2, CellCopyPolicy cellCopyPolicy) {
        int i3;
        if (list == null || list.size() == 0) {
            throw new IllegalArgumentException("No rows to copy");
        }
        Row row = (Row) list.get(0);
        Row row2 = (Row) list.get(list.size() - 1);
        if (row != null) {
            int rowNum = row.getRowNum();
            int rowNum2 = row2.getRowNum();
            int size = list.size();
            for (int i4 = 1; i4 < size; i4++) {
                Row row3 = (Row) list.get(i4);
                if (row3 == null) {
                    throw new IllegalArgumentException(a.b("srcRows may not contain null rows. Found null row at index ", i4, "."));
                } else if (row.getSheet().getWorkbook() != row3.getSheet().getWorkbook()) {
                    StringBuilder b2 = a.b("All rows in srcRows must belong to the same sheet in the same workbook.Expected all rows from same workbook (");
                    b2.append(row.getSheet().getWorkbook());
                    b2.append("). ");
                    b2.append("Got srcRows[");
                    b2.append(i4);
                    b2.append("] from different workbook (");
                    b2.append(row3.getSheet().getWorkbook());
                    b2.append(").");
                    throw new IllegalArgumentException(b2.toString());
                } else if (row.getSheet() != row3.getSheet()) {
                    StringBuilder b3 = a.b("All rows in srcRows must belong to the same sheet. Expected all rows from ");
                    b3.append(row.getSheet().getSheetName());
                    b3.append(". ");
                    b3.append("Got srcRows[");
                    b3.append(i4);
                    b3.append("] from ");
                    b3.append(row3.getSheet().getSheetName());
                    throw new IllegalArgumentException(b3.toString());
                }
            }
            CellCopyPolicy cellCopyPolicy2 = new CellCopyPolicy(cellCopyPolicy);
            cellCopyPolicy2.setCopyMergedRegions(false);
            int i5 = i2;
            for (Row row4 : list) {
                if (cellCopyPolicy.isCondenseRows()) {
                    i3 = i5 + 1;
                } else {
                    i3 = i5;
                    i5 = (row4.getRowNum() - rowNum) + i2;
                }
                createRow(i5).copyRowFrom(row4, cellCopyPolicy2);
                i5 = i3;
            }
            if (cellCopyPolicy.isCopyMergedRegions()) {
                int i6 = i2 - rowNum;
                for (CellRangeAddress cellRangeAddress : row.getSheet().getMergedRegions()) {
                    if (rowNum <= cellRangeAddress.getFirstRow() && cellRangeAddress.getLastRow() <= rowNum2) {
                        CellRangeAddress copy = cellRangeAddress.copy();
                        copy.setFirstRow(copy.getFirstRow() + i6);
                        copy.setLastRow(copy.getLastRow() + i6);
                        addMergedRegion(copy);
                    }
                }
                return;
            }
            return;
        }
        throw new IllegalArgumentException("copyRows: First row cannot be null");
    }

    @Override // org.apache.poi.ss.usermodel.Sheet
    public void createFreezePane(int i2, int i3) {
        createFreezePane(i2, i3, i2, i3);
    }

    @Override // org.apache.poi.ss.usermodel.Sheet
    public void createSplitPane(int i2, int i3, int i4, int i5, int i6) {
        createFreezePane(i2, i3, i4, i5);
        getPane().setState(STPaneState.SPLIT);
        getPane().setActivePane(STPane.Enum.forInt(i6));
    }

    public XSSFTable createTable() {
        if (!this.worksheet.isSetTableParts()) {
            this.worksheet.addNewTableParts();
        }
        CTTablePart addNewTablePart = this.worksheet.getTableParts().addNewTablePart();
        int size = getPackagePart().getPackage().getPartsByContentType(XSSFRelation.TABLE.getContentType()).size() + 1;
        POIXMLDocumentPart.RelationPart createRelationship = createRelationship(XSSFRelation.TABLE, XSSFFactory.getInstance(), size, false);
        XSSFTable xSSFTable = (XSSFTable) createRelationship.getDocumentPart();
        addNewTablePart.setId(createRelationship.getRelationship().getId());
        xSSFTable.getCTTable().setId((long) size);
        this.tables.put(addNewTablePart.getId(), xSSFTable);
        return xSSFTable;
    }

    public void disableLocking() {
        safeGetProtectionField().setSheet(false);
    }

    public void enableLocking() {
        safeGetProtectionField().setSheet(true);
    }

    public int findEndOfRowOutlineGroup(int i2) {
        short outlineLevel = getRow(i2).getCTRow().getOutlineLevel();
        int lastRowNum = getLastRowNum();
        while (i2 < lastRowNum && getRow(i2) != null && getRow(i2).getCTRow().getOutlineLevel() >= outlineLevel) {
            i2++;
        }
        return i2;
    }

    @Override // org.apache.poi.ss.usermodel.Sheet
    public CellAddress getActiveCell() {
        String activeCell = getSheetTypeSelection().getActiveCell();
        if (activeCell == null) {
            return null;
        }
        return new CellAddress(activeCell);
    }

    @Override // org.apache.poi.ss.usermodel.Sheet
    public boolean getAutobreaks() {
        CTSheetPr sheetTypeSheetPr = getSheetTypeSheetPr();
        return ((sheetTypeSheetPr == null || !sheetTypeSheetPr.isSetPageSetUpPr()) ? CTPageSetUpPr.Factory.newInstance() : sheetTypeSheetPr.getPageSetUpPr()).getAutoPageBreaks();
    }

    public CTDrawing getCTDrawing() {
        return this.worksheet.getDrawing();
    }

    public CTLegacyDrawing getCTLegacyDrawing() {
        return this.worksheet.getLegacyDrawing();
    }

    @Internal
    public CTWorksheet getCTWorksheet() {
        return this.worksheet;
    }

    @Override // org.apache.poi.ss.usermodel.Sheet
    public Map<CellAddress, XSSFComment> getCellComments() {
        CommentsTable commentsTable = this.sheetComments;
        if (commentsTable == null) {
            return Collections.emptyMap();
        }
        return commentsTable.getCellComments();
    }

    @Override // org.apache.poi.ss.usermodel.Sheet
    public int[] getColumnBreaks() {
        return this.worksheet.isSetColBreaks() ? getBreaks(this.worksheet.getColBreaks()) : new int[0];
    }

    public ColumnHelper getColumnHelper() {
        return this.columnHelper;
    }

    @Override // org.apache.poi.ss.usermodel.Sheet
    public int getColumnOutlineLevel(int i2) {
        CTCol column = this.columnHelper.getColumn((long) i2, false);
        if (column == null) {
            return 0;
        }
        return column.getOutlineLevel();
    }

    @Override // org.apache.poi.ss.usermodel.Sheet
    public CellStyle getColumnStyle(int i2) {
        int colDefaultStyle = this.columnHelper.getColDefaultStyle((long) i2);
        XSSFWorkbook workbook = getWorkbook();
        if (colDefaultStyle == -1) {
            colDefaultStyle = 0;
        }
        return workbook.getCellStyleAt((int) ((short) colDefaultStyle));
    }

    @Override // org.apache.poi.ss.usermodel.Sheet
    public int getColumnWidth(int i2) {
        CTCol column = this.columnHelper.getColumn((long) i2, false);
        return (int) (((column == null || !column.isSetWidth()) ? (double) getDefaultColumnWidth() : column.getWidth()) * 256.0d);
    }

    @Override // org.apache.poi.ss.usermodel.Sheet
    public float getColumnWidthInPixels(int i2) {
        return (float) ((((double) ((float) getColumnWidth(i2))) / 256.0d) * 7.001699924468994d);
    }

    public CommentsTable getCommentsTable(boolean z) {
        if (this.sheetComments == null && z) {
            try {
                this.sheetComments = (CommentsTable) createRelationship(XSSFRelation.SHEET_COMMENTS, XSSFFactory.getInstance(), (int) this.sheet.getSheetId());
            } catch (PartAlreadyExistsException unused) {
                this.sheetComments = (CommentsTable) createRelationship(XSSFRelation.SHEET_COMMENTS, XSSFFactory.getInstance(), -1);
            }
        }
        return this.sheetComments;
    }

    @Override // org.apache.poi.ss.usermodel.Sheet
    public DataValidationHelper getDataValidationHelper() {
        return this.dataValidationHelper;
    }

    @Override // org.apache.poi.ss.usermodel.Sheet
    public List<XSSFDataValidation> getDataValidations() {
        ArrayList arrayList = new ArrayList();
        CTDataValidations dataValidations = this.worksheet.getDataValidations();
        if (dataValidations != null && dataValidations.getCount() > 0) {
            CTDataValidation[] dataValidationArray = dataValidations.getDataValidationArray();
            int length = dataValidationArray.length;
            char c = 0;
            int i2 = 0;
            while (i2 < length) {
                CTDataValidation cTDataValidation = dataValidationArray[i2];
                CellRangeAddressList cellRangeAddressList = new CellRangeAddressList();
                for (String str : cTDataValidation.getSqref()) {
                    String[] split = str.split(" ");
                    int length2 = split.length;
                    int i3 = 0;
                    while (i3 < length2) {
                        String[] split2 = split[i3].split(":");
                        CellReference cellReference = new CellReference(split2[c]);
                        CellReference cellReference2 = split2.length > 1 ? new CellReference(split2[1]) : cellReference;
                        cellRangeAddressList.addCellRangeAddress(new CellRangeAddress(cellReference.getRow(), cellReference2.getRow(), cellReference.getCol(), cellReference2.getCol()));
                        i3++;
                        c = 0;
                    }
                }
                arrayList.add(new XSSFDataValidation(cellRangeAddressList, cTDataValidation));
                i2++;
                c = 0;
            }
        }
        return arrayList;
    }

    @Override // org.apache.poi.ss.usermodel.Sheet
    public int getDefaultColumnWidth() {
        CTSheetFormatPr sheetFormatPr = this.worksheet.getSheetFormatPr();
        if (sheetFormatPr == null) {
            return 8;
        }
        return (int) sheetFormatPr.getBaseColWidth();
    }

    @Override // org.apache.poi.ss.usermodel.Sheet
    public short getDefaultRowHeight() {
        return (short) ((int) (getDefaultRowHeightInPoints() * 20.0f));
    }

    @Override // org.apache.poi.ss.usermodel.Sheet
    public float getDefaultRowHeightInPoints() {
        double d2;
        CTSheetFormatPr sheetFormatPr = this.worksheet.getSheetFormatPr();
        if (sheetFormatPr == null) {
            d2 = NumericFunction.LOG_10_TO_BASE_e;
        } else {
            d2 = sheetFormatPr.getDefaultRowHeight();
        }
        return (float) d2;
    }

    @Override // org.apache.poi.ss.usermodel.Sheet
    public boolean getDisplayGuts() {
        CTSheetPr sheetTypeSheetPr = getSheetTypeSheetPr();
        return (sheetTypeSheetPr.getOutlinePr() == null ? CTOutlinePr.Factory.newInstance() : sheetTypeSheetPr.getOutlinePr()).getShowOutlineSymbols();
    }

    public Footer getEvenFooter() {
        return new XSSFEvenFooter(getSheetTypeHeaderFooter());
    }

    public Header getEvenHeader() {
        return new XSSFEvenHeader(getSheetTypeHeaderFooter());
    }

    public XSSFCell getFirstCellInArrayFormula(XSSFCell xSSFCell) {
        for (CellRangeAddress cellRangeAddress : this.arrayFormulas) {
            if (cellRangeAddress.isInRange(xSSFCell.getRowIndex(), xSSFCell.getColumnIndex())) {
                return getRow(cellRangeAddress.getFirstRow()).getCell(cellRangeAddress.getFirstColumn());
            }
        }
        return null;
    }

    public Footer getFirstFooter() {
        return new XSSFFirstFooter(getSheetTypeHeaderFooter());
    }

    public Header getFirstHeader() {
        return new XSSFFirstHeader(getSheetTypeHeaderFooter());
    }

    @Override // org.apache.poi.ss.usermodel.Sheet
    public int getFirstRowNum() {
        if (this._rows.isEmpty()) {
            return 0;
        }
        return this._rows.firstKey().intValue();
    }

    @Override // org.apache.poi.ss.usermodel.Sheet
    public boolean getFitToPage() {
        CTSheetPr sheetTypeSheetPr = getSheetTypeSheetPr();
        return ((sheetTypeSheetPr == null || !sheetTypeSheetPr.isSetPageSetUpPr()) ? CTPageSetUpPr.Factory.newInstance() : sheetTypeSheetPr.getPageSetUpPr()).getFitToPage();
    }

    @Override // org.apache.poi.ss.usermodel.Sheet
    public Footer getFooter() {
        return getOddFooter();
    }

    @Override // org.apache.poi.ss.usermodel.Sheet
    public boolean getForceFormulaRecalculation() {
        if (this.worksheet.isSetSheetCalcPr()) {
            return this.worksheet.getSheetCalcPr().getFullCalcOnLoad();
        }
        return false;
    }

    @Override // org.apache.poi.ss.usermodel.Sheet
    public Header getHeader() {
        return getOddHeader();
    }

    @Override // org.apache.poi.ss.usermodel.Sheet
    public boolean getHorizontallyCenter() {
        CTPrintOptions printOptions = this.worksheet.getPrintOptions();
        return printOptions != null && printOptions.getHorizontalCentered();
    }

    @Override // org.apache.poi.ss.usermodel.Sheet
    public List<XSSFHyperlink> getHyperlinkList() {
        return Collections.unmodifiableList(this.hyperlinks);
    }

    public Map<IgnoredErrorType, Set<CellRangeAddress>> getIgnoredErrors() {
        LinkedHashMap linkedHashMap = new LinkedHashMap();
        if (this.worksheet.isSetIgnoredErrors()) {
            for (CTIgnoredError cTIgnoredError : this.worksheet.getIgnoredErrors().getIgnoredErrorList()) {
                for (IgnoredErrorType ignoredErrorType : XSSFIgnoredErrorHelper.getErrorTypes(cTIgnoredError)) {
                    if (!linkedHashMap.containsKey(ignoredErrorType)) {
                        linkedHashMap.put(ignoredErrorType, new LinkedHashSet());
                    }
                    for (Object obj : cTIgnoredError.getSqref()) {
                        ((Set) linkedHashMap.get(ignoredErrorType)).add(CellRangeAddress.valueOf(obj.toString()));
                    }
                }
            }
        }
        return linkedHashMap;
    }

    @Override // org.apache.poi.ss.usermodel.Sheet
    public int getLastRowNum() {
        if (this._rows.isEmpty()) {
            return 0;
        }
        return this._rows.lastKey().intValue();
    }

    @Override // org.apache.poi.ss.usermodel.Sheet
    public short getLeftCol() {
        String topLeftCell = this.worksheet.getSheetViews().getSheetViewArray(0).getTopLeftCell();
        if (topLeftCell == null) {
            return 0;
        }
        return new CellReference(topLeftCell).getCol();
    }

    @Override // org.apache.poi.ss.usermodel.Sheet
    public double getMargin(short s) {
        if (!this.worksheet.isSetPageMargins()) {
            return NumericFunction.LOG_10_TO_BASE_e;
        }
        CTPageMargins pageMargins = this.worksheet.getPageMargins();
        if (s == 0) {
            return pageMargins.getLeft();
        }
        if (s == 1) {
            return pageMargins.getRight();
        }
        if (s == 2) {
            return pageMargins.getTop();
        }
        if (s == 3) {
            return pageMargins.getBottom();
        }
        if (s == 4) {
            return pageMargins.getHeader();
        }
        if (s == 5) {
            return pageMargins.getFooter();
        }
        throw new IllegalArgumentException(a.c("Unknown margin constant:  ", s));
    }

    @Override // org.apache.poi.ss.usermodel.Sheet
    public CellRangeAddress getMergedRegion(int i2) {
        CTMergeCells mergeCells = this.worksheet.getMergeCells();
        if (mergeCells != null) {
            return CellRangeAddress.valueOf(mergeCells.getMergeCellArray(i2).getRef());
        }
        throw new IllegalStateException("This worksheet does not contain merged regions");
    }

    @Override // org.apache.poi.ss.usermodel.Sheet
    public List<CellRangeAddress> getMergedRegions() {
        ArrayList arrayList = new ArrayList();
        CTMergeCells mergeCells = this.worksheet.getMergeCells();
        if (mergeCells == null) {
            return arrayList;
        }
        for (CTMergeCell cTMergeCell : mergeCells.getMergeCellArray()) {
            arrayList.add(CellRangeAddress.valueOf(cTMergeCell.getRef()));
        }
        return arrayList;
    }

    public int getNumHyperlinks() {
        return this.hyperlinks.size();
    }

    @Override // org.apache.poi.ss.usermodel.Sheet
    public int getNumMergedRegions() {
        CTMergeCells mergeCells = this.worksheet.getMergeCells();
        if (mergeCells == null) {
            return 0;
        }
        return mergeCells.sizeOfMergeCellArray();
    }

    public int getNumberOfComments() {
        CommentsTable commentsTable = this.sheetComments;
        if (commentsTable == null) {
            return 0;
        }
        return commentsTable.getNumberOfComments();
    }

    public Footer getOddFooter() {
        return new XSSFOddFooter(getSheetTypeHeaderFooter());
    }

    public Header getOddHeader() {
        return new XSSFOddHeader(getSheetTypeHeaderFooter());
    }

    @Override // org.apache.poi.ss.usermodel.Sheet
    public PaneInformation getPaneInformation() {
        CTPane pane = getDefaultSheetView().getPane();
        CellReference cellReference = null;
        if (pane == null) {
            return null;
        }
        if (pane.isSetTopLeftCell()) {
            cellReference = new CellReference(pane.getTopLeftCell());
        }
        return new PaneInformation((short) ((int) pane.getXSplit()), (short) ((int) pane.getYSplit()), (short) (cellReference == null ? 0 : cellReference.getRow()), cellReference == null ? 0 : cellReference.getCol(), (byte) (pane.getActivePane().intValue() - 1), pane.getState() == STPaneState.FROZEN);
    }

    @Override // org.apache.poi.ss.usermodel.Sheet
    public int getPhysicalNumberOfRows() {
        return this._rows.size();
    }

    public List<XSSFPivotTable> getPivotTables() {
        ArrayList arrayList = new ArrayList();
        for (XSSFPivotTable xSSFPivotTable : getWorkbook().getPivotTables()) {
            if (xSSFPivotTable.getParent() == this) {
                arrayList.add(xSSFPivotTable);
            }
        }
        return arrayList;
    }

    @Override // org.apache.poi.ss.usermodel.Sheet
    public boolean getProtect() {
        return isSheetLocked();
    }

    @Override // org.apache.poi.ss.usermodel.Sheet
    public CellRangeAddress getRepeatingColumns() {
        return getRepeatingRowsOrColums(false);
    }

    @Override // org.apache.poi.ss.usermodel.Sheet
    public CellRangeAddress getRepeatingRows() {
        return getRepeatingRowsOrColums(true);
    }

    @Override // org.apache.poi.ss.usermodel.Sheet
    public int[] getRowBreaks() {
        return this.worksheet.isSetRowBreaks() ? getBreaks(this.worksheet.getRowBreaks()) : new int[0];
    }

    @Override // org.apache.poi.ss.usermodel.Sheet
    public boolean getRowSumsBelow() {
        CTSheetPr sheetPr = this.worksheet.getSheetPr();
        CTOutlinePr outlinePr = (sheetPr == null || !sheetPr.isSetOutlinePr()) ? null : sheetPr.getOutlinePr();
        return outlinePr == null || outlinePr.getSummaryBelow();
    }

    @Override // org.apache.poi.ss.usermodel.Sheet
    public boolean getRowSumsRight() {
        CTSheetPr sheetPr = this.worksheet.getSheetPr();
        return ((sheetPr == null || !sheetPr.isSetOutlinePr()) ? CTOutlinePr.Factory.newInstance() : sheetPr.getOutlinePr()).getSummaryRight();
    }

    @Override // org.apache.poi.ss.usermodel.Sheet
    public boolean getScenarioProtect() {
        return this.worksheet.isSetSheetProtection() && this.worksheet.getSheetProtection().getScenarios();
    }

    @Internal
    public CTCellFormula getSharedFormula(int i2) {
        return this.sharedFormulas.get(Integer.valueOf(i2));
    }

    @Override // org.apache.poi.ss.usermodel.Sheet
    public String getSheetName() {
        return this.sheet.getName();
    }

    public XSSFColor getTabColor() {
        CTSheetPr sheetPr = this.worksheet.getSheetPr();
        if (sheetPr == null) {
            sheetPr = this.worksheet.addNewSheetPr();
        }
        if (!sheetPr.isSetTabColor()) {
            return null;
        }
        return new XSSFColor(sheetPr.getTabColor(), getWorkbook().getStylesSource().getIndexedColors());
    }

    public List<XSSFTable> getTables() {
        return new ArrayList(this.tables.values());
    }

    @Override // org.apache.poi.ss.usermodel.Sheet
    public short getTopRow() {
        String topLeftCell = getSheetTypeSheetView().getTopLeftCell();
        if (topLeftCell == null) {
            return 0;
        }
        return (short) new CellReference(topLeftCell).getRow();
    }

    public XSSFVMLDrawing getVMLDrawing(boolean z) {
        CTLegacyDrawing cTLegacyDrawing = getCTLegacyDrawing();
        XSSFVMLDrawing xSSFVMLDrawing = null;
        if (cTLegacyDrawing != null) {
            String id = cTLegacyDrawing.getId();
            Iterator<POIXMLDocumentPart.RelationPart> it = getRelationParts().iterator();
            while (true) {
                if (!it.hasNext()) {
                    break;
                }
                POIXMLDocumentPart.RelationPart next = it.next();
                POIXMLDocumentPart documentPart = next.getDocumentPart();
                if (documentPart instanceof XSSFVMLDrawing) {
                    XSSFVMLDrawing xSSFVMLDrawing2 = (XSSFVMLDrawing) documentPart;
                    if (next.getRelationship().getId().equals(id)) {
                        xSSFVMLDrawing = xSSFVMLDrawing2;
                        break;
                    }
                }
            }
            if (xSSFVMLDrawing != null) {
                return xSSFVMLDrawing;
            }
            logger.log(7, a.b("Can't find VML drawing with id=", id, " in the list of the sheet's relationships"));
            return xSSFVMLDrawing;
        } else if (!z) {
            return null;
        } else {
            POIXMLDocumentPart.RelationPart createRelationship = createRelationship(XSSFRelation.VML_DRAWINGS, XSSFFactory.getInstance(), getPackagePart().getPackage().getPartsByContentType(XSSFRelation.VML_DRAWINGS.getContentType()).size() + 1, false);
            XSSFVMLDrawing xSSFVMLDrawing3 = (XSSFVMLDrawing) createRelationship.getDocumentPart();
            this.worksheet.addNewLegacyDrawing().setId(createRelationship.getRelationship().getId());
            return xSSFVMLDrawing3;
        }
    }

    @Override // org.apache.poi.ss.usermodel.Sheet
    public boolean getVerticallyCenter() {
        CTPrintOptions printOptions = this.worksheet.getPrintOptions();
        return printOptions != null && printOptions.getVerticalCentered();
    }

    @Override // org.apache.poi.ss.usermodel.Sheet
    public void groupColumn(int i2, int i3) {
        groupColumn1Based(i2 + 1, i3 + 1);
    }

    @Override // org.apache.poi.ss.usermodel.Sheet
    public void groupRow(int i2, int i3) {
        while (i2 <= i3) {
            XSSFRow row = getRow(i2);
            if (row == null) {
                row = createRow(i2);
            }
            CTRow cTRow = row.getCTRow();
            cTRow.setOutlineLevel((short) (cTRow.getOutlineLevel() + 1));
            i2++;
        }
        setSheetFormatPrOutlineLevelRow();
    }

    public boolean hasComments() {
        CommentsTable commentsTable = this.sheetComments;
        return commentsTable != null && commentsTable.getNumberOfComments() > 0;
    }

    public boolean isAutoFilterLocked() {
        return isSheetLocked() && safeGetProtectionField().getAutoFilter();
    }

    public boolean isCellInArrayFormulaContext(XSSFCell xSSFCell) {
        for (CellRangeAddress cellRangeAddress : this.arrayFormulas) {
            if (cellRangeAddress.isInRange(xSSFCell.getRowIndex(), xSSFCell.getColumnIndex())) {
                return true;
            }
        }
        return false;
    }

    @Override // org.apache.poi.ss.usermodel.Sheet
    public boolean isColumnBroken(int i2) {
        for (int i3 : getColumnBreaks()) {
            if (i3 == i2) {
                return true;
            }
        }
        return false;
    }

    @Override // org.apache.poi.ss.usermodel.Sheet
    public boolean isColumnHidden(int i2) {
        CTCol column = this.columnHelper.getColumn((long) i2, false);
        if (column == null || !column.getHidden()) {
            return false;
        }
        return true;
    }

    public boolean isDeleteColumnsLocked() {
        return isSheetLocked() && safeGetProtectionField().getDeleteColumns();
    }

    public boolean isDeleteRowsLocked() {
        return isSheetLocked() && safeGetProtectionField().getDeleteRows();
    }

    @Override // org.apache.poi.ss.usermodel.Sheet
    public boolean isDisplayFormulas() {
        return getSheetTypeSheetView().getShowFormulas();
    }

    @Override // org.apache.poi.ss.usermodel.Sheet
    public boolean isDisplayGridlines() {
        return getSheetTypeSheetView().getShowGridLines();
    }

    @Override // org.apache.poi.ss.usermodel.Sheet
    public boolean isDisplayRowColHeadings() {
        return getSheetTypeSheetView().getShowRowColHeaders();
    }

    @Override // org.apache.poi.ss.usermodel.Sheet
    public boolean isDisplayZeros() {
        CTSheetView defaultSheetView = getDefaultSheetView();
        return defaultSheetView == null || defaultSheetView.getShowZeros();
    }

    public boolean isFormatCellsLocked() {
        return isSheetLocked() && safeGetProtectionField().getFormatCells();
    }

    public boolean isFormatColumnsLocked() {
        return isSheetLocked() && safeGetProtectionField().getFormatColumns();
    }

    public boolean isFormatRowsLocked() {
        return isSheetLocked() && safeGetProtectionField().getFormatRows();
    }

    public boolean isInsertColumnsLocked() {
        return isSheetLocked() && safeGetProtectionField().getInsertColumns();
    }

    public boolean isInsertHyperlinksLocked() {
        return isSheetLocked() && safeGetProtectionField().getInsertHyperlinks();
    }

    public boolean isInsertRowsLocked() {
        return isSheetLocked() && safeGetProtectionField().getInsertRows();
    }

    public boolean isObjectsLocked() {
        return isSheetLocked() && safeGetProtectionField().getObjects();
    }

    public boolean isPivotTablesLocked() {
        return isSheetLocked() && safeGetProtectionField().getPivotTables();
    }

    @Override // org.apache.poi.ss.usermodel.Sheet
    public boolean isPrintGridlines() {
        CTPrintOptions printOptions = this.worksheet.getPrintOptions();
        return printOptions != null && printOptions.getGridLines();
    }

    @Override // org.apache.poi.ss.usermodel.Sheet
    public boolean isPrintRowAndColumnHeadings() {
        CTPrintOptions printOptions = this.worksheet.getPrintOptions();
        return printOptions != null && printOptions.getHeadings();
    }

    @Override // org.apache.poi.ss.usermodel.Sheet
    public boolean isRightToLeft() {
        CTSheetView defaultSheetView = getDefaultSheetView();
        return defaultSheetView != null && defaultSheetView.getRightToLeft();
    }

    @Override // org.apache.poi.ss.usermodel.Sheet
    public boolean isRowBroken(int i2) {
        for (int i3 : getRowBreaks()) {
            if (i3 == i2) {
                return true;
            }
        }
        return false;
    }

    public boolean isScenariosLocked() {
        return isSheetLocked() && safeGetProtectionField().getScenarios();
    }

    public boolean isSelectLockedCellsLocked() {
        return isSheetLocked() && safeGetProtectionField().getSelectLockedCells();
    }

    public boolean isSelectUnlockedCellsLocked() {
        return isSheetLocked() && safeGetProtectionField().getSelectUnlockedCells();
    }

    @Override // org.apache.poi.ss.usermodel.Sheet
    public boolean isSelected() {
        CTSheetView defaultSheetView = getDefaultSheetView();
        return defaultSheetView != null && defaultSheetView.getTabSelected();
    }

    public boolean isSheetLocked() {
        return this.worksheet.isSetSheetProtection() && safeGetProtectionField().getSheet();
    }

    public boolean isSheetProtectionEnabled() {
        return this.worksheet.isSetSheetProtection();
    }

    public boolean isSortLocked() {
        return isSheetLocked() && safeGetProtectionField().getSort();
    }

    @Override // java.lang.Iterable
    public Iterator<Row> iterator() {
        return rowIterator();
    }

    public void lockAutoFilter(boolean z) {
        safeGetProtectionField().setAutoFilter(z);
    }

    public void lockDeleteColumns(boolean z) {
        safeGetProtectionField().setDeleteColumns(z);
    }

    public void lockDeleteRows(boolean z) {
        safeGetProtectionField().setDeleteRows(z);
    }

    public void lockFormatCells(boolean z) {
        safeGetProtectionField().setFormatCells(z);
    }

    public void lockFormatColumns(boolean z) {
        safeGetProtectionField().setFormatColumns(z);
    }

    public void lockFormatRows(boolean z) {
        safeGetProtectionField().setFormatRows(z);
    }

    public void lockInsertColumns(boolean z) {
        safeGetProtectionField().setInsertColumns(z);
    }

    public void lockInsertHyperlinks(boolean z) {
        safeGetProtectionField().setInsertHyperlinks(z);
    }

    public void lockInsertRows(boolean z) {
        safeGetProtectionField().setInsertRows(z);
    }

    public void lockObjects(boolean z) {
        safeGetProtectionField().setObjects(z);
    }

    public void lockPivotTables(boolean z) {
        safeGetProtectionField().setPivotTables(z);
    }

    public void lockScenarios(boolean z) {
        safeGetProtectionField().setScenarios(z);
    }

    public void lockSelectLockedCells(boolean z) {
        safeGetProtectionField().setSelectLockedCells(z);
    }

    public void lockSelectUnlockedCells(boolean z) {
        safeGetProtectionField().setSelectUnlockedCells(z);
    }

    public void lockSort(boolean z) {
        safeGetProtectionField().setSort(z);
    }

    @Override // org.apache.poi.POIXMLDocumentPart
    public void onDocumentCreate() {
        CTWorksheet newSheet = newSheet();
        this.worksheet = newSheet;
        initRows(newSheet);
        this.columnHelper = new ColumnHelper(this.worksheet);
        this.hyperlinks = new ArrayList();
    }

    @Override // org.apache.poi.POIXMLDocumentPart
    public void onDocumentRead() {
        try {
            read(getPackagePart().getInputStream());
        } catch (IOException e2) {
            throw new POIXMLException(e2);
        }
    }

    public void onReadCell(XSSFCell xSSFCell) {
        CTCellFormula f2 = xSSFCell.getCTCell().getF();
        if (f2 != null && f2.getT() == STCellFormulaType.SHARED && f2.isSetRef() && f2.getStringValue() != null) {
            CTCellFormula cTCellFormula = (CTCellFormula) f2.copy();
            CellRangeAddress valueOf = CellRangeAddress.valueOf(cTCellFormula.getRef());
            CellReference cellReference = new CellReference(xSSFCell);
            if (cellReference.getCol() > valueOf.getFirstColumn() || cellReference.getRow() > valueOf.getFirstRow()) {
                cTCellFormula.setRef(new CellRangeAddress(Math.max(cellReference.getRow(), valueOf.getFirstRow()), valueOf.getLastRow(), Math.max((int) cellReference.getCol(), valueOf.getFirstColumn()), valueOf.getLastColumn()).formatAsString());
            }
            this.sharedFormulas.put(Integer.valueOf((int) f2.getSi()), cTCellFormula);
        }
        if (f2 != null && f2.getT() == STCellFormulaType.ARRAY && f2.getRef() != null) {
            this.arrayFormulas.add(CellRangeAddress.valueOf(f2.getRef()));
        }
    }

    @Override // org.apache.poi.ss.usermodel.Sheet
    public void protectSheet(String str) {
        if (str != null) {
            CTSheetProtection safeGetProtectionField = safeGetProtectionField();
            setSheetPassword(str, null);
            safeGetProtectionField.setSheet(true);
            safeGetProtectionField.setScenarios(true);
            safeGetProtectionField.setObjects(true);
            return;
        }
        this.worksheet.unsetSheetProtection();
    }

    public void read(InputStream inputStream) {
        try {
            CTWorksheet worksheet2 = WorksheetDocument.Factory.parse(inputStream, POIXMLTypeLoader.DEFAULT_XML_OPTIONS).getWorksheet();
            this.worksheet = worksheet2;
            initRows(worksheet2);
            this.columnHelper = new ColumnHelper(this.worksheet);
            for (POIXMLDocumentPart.RelationPart relationPart : getRelationParts()) {
                POIXMLDocumentPart documentPart = relationPart.getDocumentPart();
                if (documentPart instanceof CommentsTable) {
                    this.sheetComments = (CommentsTable) documentPart;
                }
                if (documentPart instanceof XSSFTable) {
                    this.tables.put(relationPart.getRelationship().getId(), (XSSFTable) documentPart);
                }
                if (documentPart instanceof XSSFPivotTable) {
                    getWorkbook().getPivotTables().add((XSSFPivotTable) documentPart);
                }
            }
            initHyperlinks();
        } catch (XmlException e2) {
            throw new POIXMLException(e2);
        }
    }

    public CTOleObject readOleObject(long j) {
        CTOleObject cTOleObject = null;
        if (!getCTWorksheet().isSetOleObjects()) {
            return null;
        }
        XmlCursor newCursor = getCTWorksheet().getOleObjects().newCursor();
        try {
            newCursor.selectPath("declare namespace p='http://schemas.openxmlformats.org/spreadsheetml/2006/main' .//p:oleObject");
            CTOleObject cTOleObject2 = null;
            while (newCursor.toNextSelection()) {
                String attributeText = newCursor.getAttributeText(new QName(null, "shapeId"));
                if (attributeText != null) {
                    if (Long.parseLong(attributeText) == j) {
                        XmlObject object = newCursor.getObject();
                        if (object instanceof CTOleObject) {
                            cTOleObject2 = (CTOleObject) object;
                        } else {
                            XMLStreamReader newXMLStreamReader = newCursor.newXMLStreamReader();
                            try {
                                CTOleObjects parse = CTOleObjects.Factory.parse(newXMLStreamReader);
                                if (parse.sizeOfOleObjectArray() == 0) {
                                    try {
                                        newXMLStreamReader.close();
                                    } catch (XMLStreamException e2) {
                                        logger.log(3, "can't close reader", e2);
                                    }
                                } else {
                                    cTOleObject2 = parse.getOleObjectArray(0);
                                    try {
                                        newXMLStreamReader.close();
                                    } catch (XMLStreamException e3) {
                                        logger.log(3, "can't close reader", e3);
                                    }
                                }
                            } catch (XmlException e4) {
                                logger.log(3, "can't parse CTOleObjects", e4);
                                try {
                                    newXMLStreamReader.close();
                                } catch (XMLStreamException e5) {
                                    logger.log(3, "can't close reader", e5);
                                }
                            } catch (Throwable th) {
                                try {
                                    newXMLStreamReader.close();
                                } catch (XMLStreamException e6) {
                                    logger.log(3, "can't close reader", e6);
                                }
                                throw th;
                            }
                        }
                        if (newCursor.toChild(XSSFRelation.NS_SPREADSHEETML, "objectPr")) {
                            break;
                        }
                    }
                }
            }
            if (cTOleObject2 != null) {
                cTOleObject = cTOleObject2;
            }
            return cTOleObject;
        } finally {
            newCursor.dispose();
        }
    }

    @Override // org.apache.poi.ss.usermodel.Sheet
    public CellRange<XSSFCell> removeArrayFormula(Cell cell) {
        if (cell.getSheet() == this) {
            for (CellRangeAddress cellRangeAddress : this.arrayFormulas) {
                if (cellRangeAddress.isInRange(cell)) {
                    this.arrayFormulas.remove(cellRangeAddress);
                    CellRange<XSSFCell> cellRange = getCellRange(cellRangeAddress);
                    for (XSSFCell xSSFCell : cellRange) {
                        xSSFCell.setCellType(CellType.BLANK);
                    }
                    return cellRange;
                }
            }
            throw new IllegalArgumentException(a.b("Cell ", ((XSSFCell) cell).getCTCell().getR(), " is not part of an array formula."));
        }
        throw new IllegalArgumentException("Specified cell does not belong to this sheet.");
    }

    @Override // org.apache.poi.ss.usermodel.Sheet
    public void removeColumnBreak(int i2) {
        if (this.worksheet.isSetColBreaks()) {
            removeBreak(i2, this.worksheet.getColBreaks());
        }
    }

    @Internal
    public void removeHyperlink(int i2, int i3) {
        String formatAsString = new CellReference(i2, i3).formatAsString();
        Iterator<XSSFHyperlink> it = this.hyperlinks.iterator();
        while (it.hasNext()) {
            if (it.next().getCellRef().equals(formatAsString)) {
                it.remove();
                return;
            }
        }
    }

    @Override // org.apache.poi.ss.usermodel.Sheet
    public void removeMergedRegion(int i2) {
        if (this.worksheet.isSetMergeCells()) {
            CTMergeCells mergeCells = this.worksheet.getMergeCells();
            if (mergeCells.sizeOfMergeCellArray() > 1) {
                mergeCells.removeMergeCell(i2);
            } else {
                this.worksheet.unsetMergeCells();
            }
        }
    }

    @Override // org.apache.poi.ss.usermodel.Sheet
    public void removeMergedRegions(Collection<Integer> collection) {
        if (this.worksheet.isSetMergeCells()) {
            CTMergeCells mergeCells = this.worksheet.getMergeCells();
            ArrayList arrayList = new ArrayList(mergeCells.sizeOfMergeCellArray());
            CTMergeCell[] mergeCellArray = mergeCells.getMergeCellArray();
            int length = mergeCellArray.length;
            int i2 = 0;
            int i3 = 0;
            while (i2 < length) {
                CTMergeCell cTMergeCell = mergeCellArray[i2];
                int i4 = i3 + 1;
                if (!collection.contains(Integer.valueOf(i3))) {
                    arrayList.add(cTMergeCell);
                }
                i2++;
                i3 = i4;
            }
            if (arrayList.isEmpty()) {
                this.worksheet.unsetMergeCells();
            } else {
                mergeCells.setMergeCellArray((CTMergeCell[]) arrayList.toArray(new CTMergeCell[arrayList.size()]));
            }
        }
    }

    @Override // org.apache.poi.ss.usermodel.Sheet
    public void removeRow(Row row) {
        if (row.getSheet() == this) {
            ArrayList arrayList = new ArrayList();
            Iterator it = row.iterator();
            while (it.hasNext()) {
                arrayList.add((XSSFCell) ((Cell) it.next()));
            }
            Iterator it2 = arrayList.iterator();
            while (it2.hasNext()) {
                row.removeCell((XSSFCell) it2.next());
            }
            int rowNum = row.getRowNum();
            Integer num = new Integer(rowNum);
            int size = this._rows.headMap(num).size();
            this._rows.remove(num);
            this.worksheet.getSheetData().removeRow(size);
            if (this.sheetComments != null) {
                for (CellAddress cellAddress : getCellComments().keySet()) {
                    if (cellAddress.getRow() == rowNum) {
                        this.sheetComments.removeComment(cellAddress);
                    }
                }
                return;
            }
            return;
        }
        throw new IllegalArgumentException("Specified row does not belong to this sheet");
    }

    @Override // org.apache.poi.ss.usermodel.Sheet
    public void removeRowBreak(int i2) {
        if (this.worksheet.isSetRowBreaks()) {
            removeBreak(i2, this.worksheet.getRowBreaks());
        }
    }

    @Override // org.apache.poi.ss.usermodel.Sheet
    public Iterator<Row> rowIterator() {
        return this._rows.values().iterator();
    }

    @Removal(version = "3.16")
    @Deprecated
    public void setActiveCell(String str) {
        CTSelection sheetTypeSelection = getSheetTypeSelection();
        sheetTypeSelection.setActiveCell(str);
        sheetTypeSelection.setSqref(Arrays.asList(str));
    }

    @Override // org.apache.poi.ss.usermodel.Sheet
    public CellRange<XSSFCell> setArrayFormula(String str, CellRangeAddress cellRangeAddress) {
        CellRange<XSSFCell> cellRange = getCellRange(cellRangeAddress);
        cellRange.getTopLeftCell().setCellArrayFormula(str, cellRangeAddress);
        this.arrayFormulas.add(cellRangeAddress);
        return cellRange;
    }

    @Override // org.apache.poi.ss.usermodel.Sheet
    public void setAutobreaks(boolean z) {
        CTSheetPr sheetTypeSheetPr = getSheetTypeSheetPr();
        (sheetTypeSheetPr.isSetPageSetUpPr() ? sheetTypeSheetPr.getPageSetUpPr() : sheetTypeSheetPr.addNewPageSetUpPr()).setAutoPageBreaks(z);
    }

    @Override // org.apache.poi.ss.usermodel.Sheet
    public void setColumnBreak(int i2) {
        if (!isColumnBroken(i2)) {
            setBreak(i2, this.worksheet.isSetColBreaks() ? this.worksheet.getColBreaks() : this.worksheet.addNewColBreaks(), SpreadsheetVersion.EXCEL2007.getLastRowIndex());
        }
    }

    @Override // org.apache.poi.ss.usermodel.Sheet
    public void setColumnGroupCollapsed(int i2, boolean z) {
        if (z) {
            collapseColumn(i2);
        } else {
            expandColumn(i2);
        }
    }

    @Override // org.apache.poi.ss.usermodel.Sheet
    public void setColumnHidden(int i2, boolean z) {
        this.columnHelper.setColHidden((long) i2, z);
    }

    @Override // org.apache.poi.ss.usermodel.Sheet
    public void setColumnWidth(int i2, int i3) {
        if (i3 <= 65280) {
            long j = (long) i2;
            this.columnHelper.setColWidth(j, ((double) i3) / 256.0d);
            this.columnHelper.setCustomWidth(j, true);
            return;
        }
        throw new IllegalArgumentException("The maximum column width for an individual cell is 255 characters.");
    }

    @Override // org.apache.poi.ss.usermodel.Sheet
    public void setDefaultColumnStyle(int i2, CellStyle cellStyle) {
        this.columnHelper.setColDefaultStyle((long) i2, cellStyle);
    }

    @Override // org.apache.poi.ss.usermodel.Sheet
    public void setDefaultColumnWidth(int i2) {
        getSheetTypeSheetFormatPr().setBaseColWidth((long) i2);
    }

    @Override // org.apache.poi.ss.usermodel.Sheet
    public void setDefaultRowHeight(short s) {
        setDefaultRowHeightInPoints(((float) s) / 20.0f);
    }

    @Override // org.apache.poi.ss.usermodel.Sheet
    public void setDefaultRowHeightInPoints(float f2) {
        CTSheetFormatPr sheetTypeSheetFormatPr = getSheetTypeSheetFormatPr();
        sheetTypeSheetFormatPr.setDefaultRowHeight((double) f2);
        sheetTypeSheetFormatPr.setCustomHeight(true);
    }

    @Override // org.apache.poi.ss.usermodel.Sheet
    public void setDisplayFormulas(boolean z) {
        getSheetTypeSheetView().setShowFormulas(z);
    }

    @Override // org.apache.poi.ss.usermodel.Sheet
    public void setDisplayGridlines(boolean z) {
        getSheetTypeSheetView().setShowGridLines(z);
    }

    @Override // org.apache.poi.ss.usermodel.Sheet
    public void setDisplayGuts(boolean z) {
        CTSheetPr sheetTypeSheetPr = getSheetTypeSheetPr();
        (sheetTypeSheetPr.getOutlinePr() == null ? sheetTypeSheetPr.addNewOutlinePr() : sheetTypeSheetPr.getOutlinePr()).setShowOutlineSymbols(z);
    }

    @Override // org.apache.poi.ss.usermodel.Sheet
    public void setDisplayRowColHeadings(boolean z) {
        getSheetTypeSheetView().setShowRowColHeaders(z);
    }

    @Override // org.apache.poi.ss.usermodel.Sheet
    public void setDisplayZeros(boolean z) {
        getSheetTypeSheetView().setShowZeros(z);
    }

    @Override // org.apache.poi.ss.usermodel.Sheet
    public void setFitToPage(boolean z) {
        getSheetTypePageSetUpPr().setFitToPage(z);
    }

    @Override // org.apache.poi.ss.usermodel.Sheet
    public void setForceFormulaRecalculation(boolean z) {
        CTCalcPr calcPr = getWorkbook().getCTWorkbook().getCalcPr();
        if (this.worksheet.isSetSheetCalcPr()) {
            this.worksheet.getSheetCalcPr().setFullCalcOnLoad(z);
        } else if (z) {
            this.worksheet.addNewSheetCalcPr().setFullCalcOnLoad(z);
        }
        if (z && calcPr != null && calcPr.getCalcMode() == STCalcMode.MANUAL) {
            calcPr.setCalcMode(STCalcMode.AUTO);
        }
    }

    @Override // org.apache.poi.ss.usermodel.Sheet
    public void setHorizontallyCenter(boolean z) {
        (this.worksheet.isSetPrintOptions() ? this.worksheet.getPrintOptions() : this.worksheet.addNewPrintOptions()).setHorizontalCentered(z);
    }

    @Override // org.apache.poi.ss.usermodel.Sheet
    public void setMargin(short s, double d2) {
        CTPageMargins pageMargins = this.worksheet.isSetPageMargins() ? this.worksheet.getPageMargins() : this.worksheet.addNewPageMargins();
        if (s == 0) {
            pageMargins.setLeft(d2);
        } else if (s == 1) {
            pageMargins.setRight(d2);
        } else if (s == 2) {
            pageMargins.setTop(d2);
        } else if (s == 3) {
            pageMargins.setBottom(d2);
        } else if (s == 4) {
            pageMargins.setHeader(d2);
        } else if (s == 5) {
            pageMargins.setFooter(d2);
        } else {
            throw new IllegalArgumentException(a.c("Unknown margin constant:  ", s));
        }
    }

    @Override // org.apache.poi.ss.usermodel.Sheet
    public void setPrintGridlines(boolean z) {
        (this.worksheet.isSetPrintOptions() ? this.worksheet.getPrintOptions() : this.worksheet.addNewPrintOptions()).setGridLines(z);
    }

    @Override // org.apache.poi.ss.usermodel.Sheet
    public void setPrintRowAndColumnHeadings(boolean z) {
        (this.worksheet.isSetPrintOptions() ? this.worksheet.getPrintOptions() : this.worksheet.addNewPrintOptions()).setHeadings(z);
    }

    @Override // org.apache.poi.ss.usermodel.Sheet
    public void setRepeatingColumns(CellRangeAddress cellRangeAddress) {
        setRepeatingRowsAndColumns(getRepeatingRows(), cellRangeAddress);
    }

    @Override // org.apache.poi.ss.usermodel.Sheet
    public void setRepeatingRows(CellRangeAddress cellRangeAddress) {
        setRepeatingRowsAndColumns(cellRangeAddress, getRepeatingColumns());
    }

    @Override // org.apache.poi.ss.usermodel.Sheet
    public void setRightToLeft(boolean z) {
        getDefaultSheetView().setRightToLeft(z);
    }

    @Override // org.apache.poi.ss.usermodel.Sheet
    public void setRowBreak(int i2) {
        if (!isRowBroken(i2)) {
            setBreak(i2, this.worksheet.isSetRowBreaks() ? this.worksheet.getRowBreaks() : this.worksheet.addNewRowBreaks(), SpreadsheetVersion.EXCEL2007.getLastColumnIndex());
        }
    }

    @Override // org.apache.poi.ss.usermodel.Sheet
    public void setRowGroupCollapsed(int i2, boolean z) {
        if (z) {
            collapseRow(i2);
        } else {
            expandRow(i2);
        }
    }

    @Override // org.apache.poi.ss.usermodel.Sheet
    public void setRowSumsBelow(boolean z) {
        ensureOutlinePr().setSummaryBelow(z);
    }

    @Override // org.apache.poi.ss.usermodel.Sheet
    public void setRowSumsRight(boolean z) {
        ensureOutlinePr().setSummaryRight(z);
    }

    @Override // org.apache.poi.ss.usermodel.Sheet
    public void setSelected(boolean z) {
        for (CTSheetView cTSheetView : getSheetTypeSheetViews().getSheetViewArray()) {
            cTSheetView.setTabSelected(z);
        }
    }

    public void setSheetPassword(String str, HashAlgorithm hashAlgorithm) {
        if (str != null || isSheetProtectionEnabled()) {
            XSSFPasswordHelper.setPassword(safeGetProtectionField(), str, hashAlgorithm, null);
        }
    }

    @Removal(version = Version.VERSION_STRING)
    @Deprecated
    public void setTabColor(int i2) {
        setTabColor(new XSSFColor(IndexedColors.fromInt(i2), getWorkbook().getStylesSource().getIndexedColors()));
    }

    @Override // org.apache.poi.ss.usermodel.Sheet
    public void setVerticallyCenter(boolean z) {
        (this.worksheet.isSetPrintOptions() ? this.worksheet.getPrintOptions() : this.worksheet.addNewPrintOptions()).setVerticalCentered(z);
    }

    @Removal(version = "3.16")
    @Deprecated
    public void setZoom(int i2, int i3) {
        setZoom((i2 * 100) / i3);
    }

    @Override // org.apache.poi.ss.usermodel.Sheet
    public void shiftRows(int i2, int i3, int i4) {
        shiftRows(i2, i3, i4, false, false);
    }

    @Override // org.apache.poi.ss.usermodel.Sheet
    public void showInPane(int i2, int i3) {
        getPane().setTopLeftCell(new CellReference(i2, i3).formatAsString());
    }

    @Override // org.apache.poi.ss.usermodel.Sheet
    public void ungroupColumn(int i2, int i3) {
        CTCols colsArray = this.worksheet.getColsArray(0);
        while (i2 <= i3) {
            CTCol column = this.columnHelper.getColumn((long) i2, false);
            if (column != null) {
                column.setOutlineLevel((short) (column.getOutlineLevel() - 1));
                i2 = (int) column.getMax();
                if (column.getOutlineLevel() <= 0) {
                    this.worksheet.getColsArray(0).removeCol(this.columnHelper.getIndexOfColumn(colsArray, column));
                }
            }
            i2++;
        }
        this.worksheet.setColsArray(0, colsArray);
        setSheetFormatPrOutlineLevelCol();
    }

    @Override // org.apache.poi.ss.usermodel.Sheet
    public void ungroupRow(int i2, int i3) {
        while (i2 <= i3) {
            XSSFRow row = getRow(i2);
            if (row != null) {
                CTRow cTRow = row.getCTRow();
                short outlineLevel = cTRow.getOutlineLevel();
                cTRow.setOutlineLevel((short) (outlineLevel - 1));
                if (outlineLevel == 1 && row.getFirstCellNum() == -1) {
                    removeRow(row);
                }
            }
            i2++;
        }
        setSheetFormatPrOutlineLevelRow();
    }

    public boolean validateSheetPassword(String str) {
        if (!isSheetProtectionEnabled()) {
            return str == null;
        }
        return XSSFPasswordHelper.validatePassword(safeGetProtectionField(), str, null);
    }

    /* JADX WARNING: Removed duplicated region for block: B:16:0x0063  */
    /* JADX WARNING: Removed duplicated region for block: B:25:0x00a1  */
    /* JADX WARNING: Removed duplicated region for block: B:32:0x00ca  */
    /* JADX WARNING: Removed duplicated region for block: B:38:0x0119  */
    /* JADX WARNING: Removed duplicated region for block: B:46:? A[RETURN, SYNTHETIC] */
    /* JADX WARNING: Removed duplicated region for block: B:9:0x002a  */
    public void write(OutputStream outputStream) {
        boolean z;
        int i2;
        if (this.worksheet.sizeOfColsArray() == 1) {
            CTCols colsArray = this.worksheet.getColsArray(0);
            if (colsArray.sizeOfColArray() == 0) {
                this.worksheet.setColsArray(null);
                z = true;
                if (this.hyperlinks.size() <= 0) {
                    if (this.worksheet.getHyperlinks() == null) {
                        this.worksheet.addNewHyperlinks();
                    }
                    int size = this.hyperlinks.size();
                    CTHyperlink[] cTHyperlinkArr = new CTHyperlink[size];
                    for (int i3 = 0; i3 < size; i3++) {
                        XSSFHyperlink xSSFHyperlink = this.hyperlinks.get(i3);
                        xSSFHyperlink.generateRelationIfNeeded(getPackagePart());
                        cTHyperlinkArr[i3] = xSSFHyperlink.getCTHyperlink();
                    }
                    this.worksheet.getHyperlinks().setHyperlinkArray(cTHyperlinkArr);
                } else if (this.worksheet.getHyperlinks() != null) {
                    for (int sizeOfHyperlinkArray = this.worksheet.getHyperlinks().sizeOfHyperlinkArray() - 1; sizeOfHyperlinkArray >= 0; sizeOfHyperlinkArray--) {
                        this.worksheet.getHyperlinks().removeHyperlink(sizeOfHyperlinkArray);
                    }
                    this.worksheet.unsetHyperlinks();
                }
                int i4 = Integer.MIN_VALUE;
                i2 = Integer.MAX_VALUE;
                for (XSSFRow xSSFRow : this._rows.values()) {
                    xSSFRow.onDocumentWrite();
                    if (xSSFRow.getFirstCellNum() != -1) {
                        i2 = Math.min(i2, (int) xSSFRow.getFirstCellNum());
                    }
                    if (xSSFRow.getLastCellNum() != -1) {
                        i4 = Math.max(i4, (int) xSSFRow.getLastCellNum());
                    }
                }
                if (i2 != Integer.MAX_VALUE) {
                    String formatAsString = new CellRangeAddress(getFirstRowNum(), getLastRowNum(), i2, i4).formatAsString();
                    if (this.worksheet.isSetDimension()) {
                        this.worksheet.getDimension().setRef(formatAsString);
                    } else {
                        this.worksheet.addNewDimension().setRef(formatAsString);
                    }
                }
                XmlOptions xmlOptions = new XmlOptions(POIXMLTypeLoader.DEFAULT_XML_OPTIONS);
                xmlOptions.setSaveSyntheticDocumentElement(new QName(CTWorksheet.type.getName().getNamespaceURI(), "worksheet"));
                this.worksheet.save(outputStream, xmlOptions);
                if (!z) {
                    this.worksheet.addNewCols();
                    return;
                }
                return;
            }
            setColWidthAttribute(colsArray);
        }
        z = false;
        if (this.hyperlinks.size() <= 0) {
        }
        int i42 = Integer.MIN_VALUE;
        i2 = Integer.MAX_VALUE;
        while (r2.hasNext()) {
        }
        if (i2 != Integer.MAX_VALUE) {
        }
        XmlOptions xmlOptions2 = new XmlOptions(POIXMLTypeLoader.DEFAULT_XML_OPTIONS);
        xmlOptions2.setSaveSyntheticDocumentElement(new QName(CTWorksheet.type.getName().getNamespaceURI(), "worksheet"));
        this.worksheet.save(outputStream, xmlOptions2);
        if (!z) {
        }
    }

    private int addMergedRegion(CellRangeAddress cellRangeAddress, boolean z) {
        if (cellRangeAddress.getNumberOfCells() >= 2) {
            cellRangeAddress.validate(SpreadsheetVersion.EXCEL2007);
            if (z) {
                validateArrayFormulas(cellRangeAddress);
                validateMergedRegions(cellRangeAddress);
            }
            CTMergeCells mergeCells = this.worksheet.isSetMergeCells() ? this.worksheet.getMergeCells() : this.worksheet.addNewMergeCells();
            mergeCells.addNewMergeCell().setRef(cellRangeAddress.formatAsString());
            return mergeCells.sizeOfMergeCellArray();
        }
        StringBuilder b2 = a.b("Merged region ");
        b2.append(cellRangeAddress.formatAsString());
        b2.append(" must contain 2 or more cells");
        throw new IllegalArgumentException(b2.toString());
    }

    public void addIgnoredErrors(CellRangeAddress cellRangeAddress, IgnoredErrorType... ignoredErrorTypeArr) {
        cellRangeAddress.validate(SpreadsheetVersion.EXCEL2007);
        addIgnoredErrors(cellRangeAddress.formatAsString(), ignoredErrorTypeArr);
    }

    @Override // org.apache.poi.ss.usermodel.Sheet
    public void autoSizeColumn(int i2, boolean z) {
        double columnWidth = SheetUtil.getColumnWidth(this, i2, z);
        if (columnWidth != -1.0d) {
            double d2 = columnWidth * 256.0d;
            double d3 = (double) 65280;
            if (d2 > d3) {
                d2 = d3;
            }
            setColumnWidth(i2, (int) d2);
            this.columnHelper.setColBestFit((long) i2, true);
        }
    }

    @Override // org.apache.poi.ss.usermodel.Sheet
    public XSSFDrawing createDrawingPatriarch() {
        if (getCTDrawing() != null) {
            return getDrawingPatriarch();
        }
        POIXMLDocumentPart.RelationPart createRelationship = createRelationship(XSSFRelation.DRAWINGS, XSSFFactory.getInstance(), getNextPartNumber(XSSFRelation.DRAWINGS, getPackagePart().getPackage().getPartsByContentType(XSSFRelation.DRAWINGS.getContentType()).size() + 1), false);
        XSSFDrawing xSSFDrawing = (XSSFDrawing) createRelationship.getDocumentPart();
        this.worksheet.addNewDrawing().setId(createRelationship.getRelationship().getId());
        return xSSFDrawing;
    }

    @Override // org.apache.poi.ss.usermodel.Sheet
    public void createFreezePane(int i2, int i3, int i4, int i5) {
        CTSheetView defaultSheetView = getDefaultSheetView();
        if (i2 == 0 && i3 == 0) {
            if (defaultSheetView.isSetPane()) {
                defaultSheetView.unsetPane();
            }
            defaultSheetView.setSelectionArray(null);
            return;
        }
        if (!defaultSheetView.isSetPane()) {
            defaultSheetView.addNewPane();
        }
        CTPane pane = defaultSheetView.getPane();
        if (i2 > 0) {
            pane.setXSplit((double) i2);
        } else if (pane.isSetXSplit()) {
            pane.unsetXSplit();
        }
        if (i3 > 0) {
            pane.setYSplit((double) i3);
        } else if (pane.isSetYSplit()) {
            pane.unsetYSplit();
        }
        pane.setState(STPaneState.FROZEN);
        if (i3 == 0) {
            pane.setTopLeftCell(new CellReference(0, i4).formatAsString());
            pane.setActivePane(STPane.TOP_RIGHT);
        } else if (i2 == 0) {
            pane.setTopLeftCell(new CellReference(i5, 0).formatAsString());
            pane.setActivePane(STPane.BOTTOM_LEFT);
        } else {
            pane.setTopLeftCell(new CellReference(i5, i4).formatAsString());
            pane.setActivePane(STPane.BOTTOM_RIGHT);
        }
        defaultSheetView.setSelectionArray(null);
        defaultSheetView.addNewSelection().setPane(pane.getActivePane());
    }

    @Override // org.apache.poi.ss.usermodel.Sheet
    public XSSFRow createRow(int i2) {
        CTRow cTRow;
        Integer num = new Integer(i2);
        XSSFRow xSSFRow = this._rows.get(num);
        if (xSSFRow != null) {
            while (xSSFRow.getFirstCellNum() != -1) {
                xSSFRow.removeCell(xSSFRow.getCell((int) xSSFRow.getFirstCellNum()));
            }
            cTRow = xSSFRow.getCTRow();
            cTRow.set(CTRow.Factory.newInstance());
        } else if (this._rows.isEmpty() || i2 > this._rows.lastKey().intValue()) {
            cTRow = this.worksheet.getSheetData().addNewRow();
        } else {
            cTRow = this.worksheet.getSheetData().insertNewRow(this._rows.headMap(num).size());
        }
        XSSFRow xSSFRow2 = new XSSFRow(cTRow, this);
        xSSFRow2.setRowNum(i2);
        this._rows.put(num, xSSFRow2);
        return xSSFRow2;
    }

    @Override // org.apache.poi.ss.usermodel.Sheet
    public XSSFDrawing getDrawingPatriarch() {
        CTDrawing cTDrawing = getCTDrawing();
        if (cTDrawing == null) {
            return null;
        }
        Iterator<POIXMLDocumentPart.RelationPart> it = getRelationParts().iterator();
        while (true) {
            if (!it.hasNext()) {
                break;
            }
            POIXMLDocumentPart.RelationPart next = it.next();
            POIXMLDocumentPart documentPart = next.getDocumentPart();
            if (documentPart instanceof XSSFDrawing) {
                XSSFDrawing xSSFDrawing = (XSSFDrawing) documentPart;
                if (next.getRelationship().getId().equals(cTDrawing.getId())) {
                    return xSSFDrawing;
                }
            }
        }
        POILogger pOILogger = logger;
        StringBuilder b2 = a.b("Can't find drawing with id=");
        b2.append(cTDrawing.getId());
        b2.append(" in the list of the sheet's relationships");
        pOILogger.log(7, b2.toString());
        return null;
    }

    @Override // org.apache.poi.ss.usermodel.Sheet
    public XSSFPrintSetup getPrintSetup() {
        return new XSSFPrintSetup(this.worksheet);
    }

    @Override // org.apache.poi.ss.usermodel.Sheet
    public XSSFRow getRow(int i2) {
        return this._rows.get(new Integer(i2));
    }

    @Override // org.apache.poi.ss.usermodel.Sheet
    public XSSFSheetConditionalFormatting getSheetConditionalFormatting() {
        return new XSSFSheetConditionalFormatting(this);
    }

    @Override // org.apache.poi.ss.usermodel.Sheet
    public XSSFWorkbook getWorkbook() {
        return (XSSFWorkbook) getParent();
    }

    @Override // org.apache.poi.ss.usermodel.Sheet
    public XSSFAutoFilter setAutoFilter(CellRangeAddress cellRangeAddress) {
        CTAutoFilter autoFilter = this.worksheet.getAutoFilter();
        if (autoFilter == null) {
            autoFilter = this.worksheet.addNewAutoFilter();
        }
        autoFilter.setRef(new CellRangeAddress(cellRangeAddress.getFirstRow(), cellRangeAddress.getLastRow(), cellRangeAddress.getFirstColumn(), cellRangeAddress.getLastColumn()).formatAsString());
        XSSFWorkbook workbook = getWorkbook();
        int sheetIndex = getWorkbook().getSheetIndex(this);
        XSSFName builtInName = workbook.getBuiltInName(XSSFName.BUILTIN_FILTER_DB, sheetIndex);
        if (builtInName == null) {
            builtInName = workbook.createBuiltInName(XSSFName.BUILTIN_FILTER_DB, sheetIndex);
        }
        builtInName.getCTName().setHidden(true);
        CellReference cellReference = new CellReference(getSheetName(), cellRangeAddress.getFirstRow(), cellRangeAddress.getFirstColumn(), true, true);
        CellReference cellReference2 = new CellReference(null, cellRangeAddress.getLastRow(), cellRangeAddress.getLastColumn(), true, true);
        builtInName.setRefersToFormula(cellReference.formatAsString() + ":" + cellReference2.formatAsString());
        return new XSSFAutoFilter(this);
    }

    @Override // org.apache.poi.ss.usermodel.Sheet
    public void shiftRows(int i2, int i3, final int i4, boolean z, boolean z2) {
        int shiftedRowNum;
        Iterator<Row> it;
        XSSFVMLDrawing vMLDrawing = getVMLDrawing(false);
        Iterator<Row> rowIterator = rowIterator();
        while (rowIterator.hasNext()) {
            XSSFRow xSSFRow = (XSSFRow) rowIterator.next();
            int rowNum = xSSFRow.getRowNum();
            if (shouldRemoveRow(i2, i3, i4, rowNum)) {
                this.worksheet.getSheetData().removeRow(this._rows.headMap(new Integer(xSSFRow.getRowNum())).size());
                rowIterator.remove();
                CommentsTable commentsTable = this.sheetComments;
                if (commentsTable != null) {
                    for (CTComment cTComment : commentsTable.getCTComments().getCommentList().getCommentArray()) {
                        CellAddress cellAddress = new CellAddress(cTComment.getRef());
                        if (cellAddress.getRow() == rowNum) {
                            this.sheetComments.removeComment(cellAddress);
                            vMLDrawing.removeCommentShape(cellAddress.getRow(), cellAddress.getColumn());
                        }
                    }
                }
                if (this.hyperlinks != null) {
                    Iterator it2 = new ArrayList(this.hyperlinks).iterator();
                    while (it2.hasNext()) {
                        XSSFHyperlink xSSFHyperlink = (XSSFHyperlink) it2.next();
                        if (new CellReference(xSSFHyperlink.getCellRef()).getRow() == rowNum) {
                            this.hyperlinks.remove(xSSFHyperlink);
                        }
                    }
                }
            }
        }
        TreeMap treeMap = new TreeMap(new Comparator<XSSFComment>() {
            /* class org.apache.poi.xssf.usermodel.XSSFSheet.AnonymousClass1 */

            public int compare(XSSFComment xSSFComment, XSSFComment xSSFComment2) {
                int row = xSSFComment.getRow();
                int row2 = xSSFComment2.getRow();
                if (row == row2) {
                    return xSSFComment.hashCode() - xSSFComment2.hashCode();
                }
                return i4 > 0 ? row < row2 ? 1 : -1 : row > row2 ? 1 : -1;
            }
        });
        Iterator<Row> rowIterator2 = rowIterator();
        while (rowIterator2.hasNext()) {
            XSSFRow xSSFRow2 = (XSSFRow) rowIterator2.next();
            int rowNum2 = xSSFRow2.getRowNum();
            if (!(this.sheetComments == null || (shiftedRowNum = shiftedRowNum(i2, i3, i4, rowNum2)) == rowNum2)) {
                CTComment[] commentArray = this.sheetComments.getCTComments().getCommentList().getCommentArray();
                int length = commentArray.length;
                int i5 = 0;
                while (i5 < length) {
                    CTComment cTComment2 = commentArray[i5];
                    CellReference cellReference = new CellReference(cTComment2.getRef());
                    if (cellReference.getRow() == rowNum2) {
                        it = rowIterator2;
                        treeMap.put(new XSSFComment(this.sheetComments, cTComment2, vMLDrawing == null ? null : vMLDrawing.findCommentShape(rowNum2, cellReference.getCol())), Integer.valueOf(shiftedRowNum));
                    } else {
                        it = rowIterator2;
                    }
                    i5++;
                    rowIterator2 = it;
                }
            }
            if (rowNum2 >= i2 && rowNum2 <= i3) {
                if (!z) {
                    xSSFRow2.setHeight(-1);
                }
                xSSFRow2.shift(i4);
            }
            rowIterator2 = rowIterator2;
        }
        for (Map.Entry entry : treeMap.entrySet()) {
            ((XSSFComment) entry.getKey()).setRow(((Integer) entry.getValue()).intValue());
        }
        XSSFRowShifter xSSFRowShifter = new XSSFRowShifter(this);
        int sheetIndex = getWorkbook().getSheetIndex(this);
        FormulaShifter createForRowShift = FormulaShifter.createForRowShift(sheetIndex, getWorkbook().getSheetName(sheetIndex), i2, i3, i4, SpreadsheetVersion.EXCEL2007);
        xSSFRowShifter.updateNamedRanges(createForRowShift);
        xSSFRowShifter.updateFormulas(createForRowShift);
        xSSFRowShifter.shiftMergedRegions(i2, i3, i4);
        xSSFRowShifter.updateConditionalFormatting(createForRowShift);
        xSSFRowShifter.updateHyperlinks(createForRowShift);
        HashMap hashMap = new HashMap();
        for (XSSFRow xSSFRow3 : this._rows.values()) {
            hashMap.put(new Integer(xSSFRow3.getRowNum()), xSSFRow3);
        }
        this._rows.clear();
        this._rows.putAll(hashMap);
    }

    @Removal(version = "3.16")
    @Deprecated
    public XSSFComment getCellComment(int i2, int i3) {
        return getCellComment(new CellAddress(i2, i3));
    }

    @Override // org.apache.poi.ss.usermodel.Sheet
    public XSSFHyperlink getHyperlink(int i2, int i3) {
        return getHyperlink(new CellAddress(i2, i3));
    }

    @Override // org.apache.poi.ss.usermodel.Sheet
    public void setZoom(int i2) {
        if (i2 < 10 || i2 > 400) {
            throw new IllegalArgumentException("Valid scale values range from 10 to 400");
        }
        getSheetTypeSheetView().setZoomScale((long) i2);
    }

    private void addIgnoredErrors(String str, IgnoredErrorType... ignoredErrorTypeArr) {
        XSSFIgnoredErrorHelper.addIgnoredErrors((this.worksheet.isSetIgnoredErrors() ? this.worksheet.getIgnoredErrors() : this.worksheet.addNewIgnoredErrors()).addNewIgnoredError(), str, ignoredErrorTypeArr);
    }

    @Override // org.apache.poi.ss.usermodel.Sheet
    public XSSFComment getCellComment(CellAddress cellAddress) {
        i iVar = null;
        if (this.sheetComments == null) {
            return null;
        }
        int row = cellAddress.getRow();
        int column = cellAddress.getColumn();
        CTComment cTComment = this.sheetComments.getCTComment(new CellAddress(row, column));
        if (cTComment == null) {
            return null;
        }
        XSSFVMLDrawing vMLDrawing = getVMLDrawing(false);
        CommentsTable commentsTable = this.sheetComments;
        if (vMLDrawing != null) {
            iVar = vMLDrawing.findCommentShape(row, column);
        }
        return new XSSFComment(commentsTable, cTComment, iVar);
    }

    @Override // org.apache.poi.ss.usermodel.Sheet
    public XSSFHyperlink getHyperlink(CellAddress cellAddress) {
        String formatAsString = cellAddress.formatAsString();
        for (XSSFHyperlink xSSFHyperlink : this.hyperlinks) {
            if (xSSFHyperlink.getCellRef().equals(formatAsString)) {
                return xSSFHyperlink;
            }
        }
        return null;
    }

    @Override // org.apache.poi.ss.usermodel.Sheet
    public void setActiveCell(CellAddress cellAddress) {
        String formatAsString = cellAddress.formatAsString();
        CTSelection sheetTypeSelection = getSheetTypeSelection();
        sheetTypeSelection.setActiveCell(formatAsString);
        sheetTypeSelection.setSqref(Arrays.asList(formatAsString));
    }

    public void setTabColor(XSSFColor xSSFColor) {
        CTSheetPr sheetPr = this.worksheet.getSheetPr();
        if (sheetPr == null) {
            sheetPr = this.worksheet.addNewSheetPr();
        }
        sheetPr.setTabColor(xSSFColor.getCTColor());
    }

    @Override // org.apache.poi.ss.usermodel.Sheet
    public void validateMergedRegions() {
        checkForMergedRegionsIntersectingArrayFormulas();
        checkForIntersectingMergedRegions();
    }

    public XSSFSheet(PackagePart packagePart) {
        super(packagePart);
    }

    public XSSFPivotTable createPivotTable(final AreaReference areaReference, CellReference cellReference, Sheet sheet2) {
        String sheetName = areaReference.getFirstCell().getSheetName();
        if (sheetName == null || sheetName.equalsIgnoreCase(sheet2.getSheetName())) {
            return createPivotTable(cellReference, sheet2, new XSSFPivotTable.PivotTableReferenceConfigurator() {
                /* class org.apache.poi.xssf.usermodel.XSSFSheet.AnonymousClass2 */

                @Override // org.apache.poi.xssf.usermodel.XSSFPivotTable.PivotTableReferenceConfigurator
                public void configureReference(CTWorksheetSource cTWorksheetSource) {
                    String[] cellRefParts = areaReference.getFirstCell().getCellRefParts();
                    String str = cellRefParts[1];
                    String str2 = cellRefParts[2];
                    String[] cellRefParts2 = areaReference.getLastCell().getCellRefParts();
                    String str3 = cellRefParts2[1];
                    String str4 = cellRefParts2[2];
                    cTWorksheetSource.setRef(str2 + str + ':' + str4 + str3);
                }
            });
        }
        StringBuilder b2 = a.b("The area is referenced in another sheet than the defined source sheet ");
        b2.append(sheet2.getSheetName());
        b2.append(".");
        throw new IllegalArgumentException(b2.toString());
    }

    private XSSFPivotTable createPivotTable(CellReference cellReference, Sheet sheet2, XSSFPivotTable.PivotTableReferenceConfigurator pivotTableReferenceConfigurator) {
        XSSFPivotTable createPivotTable = createPivotTable();
        createPivotTable.setDefaultPivotTableDefinition();
        createPivotTable.createSourceReferences(cellReference, sheet2, pivotTableReferenceConfigurator);
        createPivotTable.getPivotCacheDefinition().createCacheFields(sheet2);
        createPivotTable.createDefaultDataColumns();
        return createPivotTable;
    }

    public XSSFPivotTable createPivotTable(AreaReference areaReference, CellReference cellReference) {
        String sheetName = areaReference.getFirstCell().getSheetName();
        if (sheetName == null || sheetName.equalsIgnoreCase(getSheetName())) {
            return createPivotTable(areaReference, cellReference, this);
        }
        return createPivotTable(areaReference, cellReference, getWorkbook().getSheet(sheetName));
    }

    public void copyRows(int i2, int i3, int i4, CellCopyPolicy cellCopyPolicy) {
        copyRows(getRows(i2, i3, false), i4, cellCopyPolicy);
    }

    public XSSFPivotTable createPivotTable(final Name name, CellReference cellReference, Sheet sheet2) {
        if (name.getSheetName() == null || name.getSheetName().equals(sheet2.getSheetName())) {
            return createPivotTable(cellReference, sheet2, new XSSFPivotTable.PivotTableReferenceConfigurator() {
                /* class org.apache.poi.xssf.usermodel.XSSFSheet.AnonymousClass3 */

                @Override // org.apache.poi.xssf.usermodel.XSSFPivotTable.PivotTableReferenceConfigurator
                public void configureReference(CTWorksheetSource cTWorksheetSource) {
                    cTWorksheetSource.setName(name.getNameName());
                }
            });
        }
        StringBuilder b2 = a.b("The named range references another sheet than the defined source sheet ");
        b2.append(sheet2.getSheetName());
        b2.append(".");
        throw new IllegalArgumentException(b2.toString());
    }

    public XSSFPivotTable createPivotTable(Name name, CellReference cellReference) {
        return createPivotTable(name, cellReference, getWorkbook().getSheet(name.getSheetName()));
    }

    public XSSFPivotTable createPivotTable(final Table table, CellReference cellReference) {
        return createPivotTable(cellReference, getWorkbook().getSheet(table.getSheetName()), new XSSFPivotTable.PivotTableReferenceConfigurator() {
            /* class org.apache.poi.xssf.usermodel.XSSFSheet.AnonymousClass4 */

            @Override // org.apache.poi.xssf.usermodel.XSSFPivotTable.PivotTableReferenceConfigurator
            public void configureReference(CTWorksheetSource cTWorksheetSource) {
                cTWorksheetSource.setName(table.getName());
            }
        });
    }
}
