package org.apache.poi.xssf.usermodel;

import b.b.a.a.a;
import java.util.ArrayList;
import org.apache.poi.ss.SpreadsheetVersion;
import org.apache.poi.ss.usermodel.ConditionalFormatting;
import org.apache.poi.ss.usermodel.ConditionalFormattingRule;
import org.apache.poi.ss.usermodel.ExtendedColor;
import org.apache.poi.ss.usermodel.IconMultiStateFormatting;
import org.apache.poi.ss.usermodel.SheetConditionalFormatting;
import org.apache.poi.ss.util.CellRangeAddress;
import org.apache.poi.ss.util.CellRangeUtil;
import org.openxmlformats.schemas.spreadsheetml.x2006.main.CTCfRule;
import org.openxmlformats.schemas.spreadsheetml.x2006.main.CTConditionalFormatting;
import org.openxmlformats.schemas.spreadsheetml.x2006.main.CTWorksheet;
import org.openxmlformats.schemas.spreadsheetml.x2006.main.STCfType;
import org.openxmlformats.schemas.spreadsheetml.x2006.main.STConditionalFormattingOperator;

public class XSSFSheetConditionalFormatting implements SheetConditionalFormatting {
    public static final String CF_EXT_2009_NS_X14 = "http://schemas.microsoft.com/office/spreadsheetml/2009/9/main";
    public final XSSFSheet _sheet;

    public XSSFSheetConditionalFormatting(XSSFSheet xSSFSheet) {
        this._sheet = xSSFSheet;
    }

    private void checkIndex(int i2) {
        int numConditionalFormattings = getNumConditionalFormattings();
        if (i2 < 0 || i2 >= numConditionalFormattings) {
            StringBuilder a = a.a("Specified CF index ", i2, " is outside the allowable range (0..");
            a.append(numConditionalFormattings - 1);
            a.append(")");
            throw new IllegalArgumentException(a.toString());
        }
    }

    @Override // org.apache.poi.ss.usermodel.SheetConditionalFormatting
    public int addConditionalFormatting(CellRangeAddress[] cellRangeAddressArr, ConditionalFormattingRule[] conditionalFormattingRuleArr) {
        if (cellRangeAddressArr != null) {
            int i2 = 0;
            for (CellRangeAddress cellRangeAddress : cellRangeAddressArr) {
                cellRangeAddress.validate(SpreadsheetVersion.EXCEL2007);
            }
            if (conditionalFormattingRuleArr == null) {
                throw new IllegalArgumentException("cfRules must not be null");
            } else if (conditionalFormattingRuleArr.length == 0) {
                throw new IllegalArgumentException("cfRules must not be empty");
            } else if (conditionalFormattingRuleArr.length <= 3) {
                CellRangeAddress[] mergeCellRanges = CellRangeUtil.mergeCellRanges(cellRangeAddressArr);
                CTConditionalFormatting addNewConditionalFormatting = this._sheet.getCTWorksheet().addNewConditionalFormatting();
                ArrayList arrayList = new ArrayList();
                for (CellRangeAddress cellRangeAddress2 : mergeCellRanges) {
                    arrayList.add(cellRangeAddress2.formatAsString());
                }
                addNewConditionalFormatting.setSqref(arrayList);
                int i3 = 1;
                for (CTConditionalFormatting cTConditionalFormatting : this._sheet.getCTWorksheet().getConditionalFormattingArray()) {
                    i3 += cTConditionalFormatting.sizeOfCfRuleArray();
                }
                int length = conditionalFormattingRuleArr.length;
                while (i2 < length) {
                    XSSFConditionalFormattingRule xSSFConditionalFormattingRule = (XSSFConditionalFormattingRule) conditionalFormattingRuleArr[i2];
                    xSSFConditionalFormattingRule.getCTCfRule().setPriority(i3);
                    addNewConditionalFormatting.addNewCfRule().set(xSSFConditionalFormattingRule.getCTCfRule());
                    i2++;
                    i3++;
                }
                return this._sheet.getCTWorksheet().sizeOfConditionalFormattingArray() - 1;
            } else {
                throw new IllegalArgumentException("Number of rules must not exceed 3");
            }
        } else {
            throw new IllegalArgumentException("regions must not be null");
        }
    }

    @Override // org.apache.poi.ss.usermodel.SheetConditionalFormatting
    public int getNumConditionalFormattings() {
        return this._sheet.getCTWorksheet().sizeOfConditionalFormattingArray();
    }

    @Override // org.apache.poi.ss.usermodel.SheetConditionalFormatting
    public void removeConditionalFormatting(int i2) {
        checkIndex(i2);
        this._sheet.getCTWorksheet().removeConditionalFormatting(i2);
    }

    @Override // org.apache.poi.ss.usermodel.SheetConditionalFormatting
    public XSSFConditionalFormattingRule createConditionalFormattingColorScaleRule() {
        XSSFConditionalFormattingRule xSSFConditionalFormattingRule = new XSSFConditionalFormattingRule(this._sheet);
        xSSFConditionalFormattingRule.createColorScaleFormatting();
        return xSSFConditionalFormattingRule;
    }

    @Override // org.apache.poi.ss.usermodel.SheetConditionalFormatting
    public XSSFConditionalFormatting getConditionalFormattingAt(int i2) {
        checkIndex(i2);
        return new XSSFConditionalFormatting(this._sheet, this._sheet.getCTWorksheet().getConditionalFormattingArray(i2));
    }

    @Override // org.apache.poi.ss.usermodel.SheetConditionalFormatting
    public XSSFConditionalFormattingRule createConditionalFormattingRule(byte b2, String str, String str2) {
        STConditionalFormattingOperator.Enum r3;
        XSSFConditionalFormattingRule xSSFConditionalFormattingRule = new XSSFConditionalFormattingRule(this._sheet);
        CTCfRule cTCfRule = xSSFConditionalFormattingRule.getCTCfRule();
        cTCfRule.addFormula(str);
        if (str2 != null) {
            cTCfRule.addFormula(str2);
        }
        cTCfRule.setType(STCfType.CELL_IS);
        switch (b2) {
            case 1:
                r3 = STConditionalFormattingOperator.BETWEEN;
                break;
            case 2:
                r3 = STConditionalFormattingOperator.NOT_BETWEEN;
                break;
            case 3:
                r3 = STConditionalFormattingOperator.EQUAL;
                break;
            case 4:
                r3 = STConditionalFormattingOperator.NOT_EQUAL;
                break;
            case 5:
                r3 = STConditionalFormattingOperator.GREATER_THAN;
                break;
            case 6:
                r3 = STConditionalFormattingOperator.LESS_THAN;
                break;
            case 7:
                r3 = STConditionalFormattingOperator.GREATER_THAN_OR_EQUAL;
                break;
            case 8:
                r3 = STConditionalFormattingOperator.LESS_THAN_OR_EQUAL;
                break;
            default:
                throw new IllegalArgumentException(a.c("Unknown comparison operator: ", b2));
        }
        cTCfRule.setOperator(r3);
        return xSSFConditionalFormattingRule;
    }

    @Override // org.apache.poi.ss.usermodel.SheetConditionalFormatting
    public int addConditionalFormatting(CellRangeAddress[] cellRangeAddressArr, ConditionalFormattingRule conditionalFormattingRule) {
        XSSFConditionalFormattingRule[] xSSFConditionalFormattingRuleArr;
        if (conditionalFormattingRule == null) {
            xSSFConditionalFormattingRuleArr = null;
        } else {
            xSSFConditionalFormattingRuleArr = new XSSFConditionalFormattingRule[]{(XSSFConditionalFormattingRule) conditionalFormattingRule};
        }
        return addConditionalFormatting(cellRangeAddressArr, xSSFConditionalFormattingRuleArr);
    }

    @Override // org.apache.poi.ss.usermodel.SheetConditionalFormatting
    public int addConditionalFormatting(CellRangeAddress[] cellRangeAddressArr, ConditionalFormattingRule conditionalFormattingRule, ConditionalFormattingRule conditionalFormattingRule2) {
        XSSFConditionalFormattingRule[] xSSFConditionalFormattingRuleArr;
        if (conditionalFormattingRule == null) {
            xSSFConditionalFormattingRuleArr = null;
        } else {
            xSSFConditionalFormattingRuleArr = new XSSFConditionalFormattingRule[]{(XSSFConditionalFormattingRule) conditionalFormattingRule, (XSSFConditionalFormattingRule) conditionalFormattingRule2};
        }
        return addConditionalFormatting(cellRangeAddressArr, xSSFConditionalFormattingRuleArr);
    }

    @Override // org.apache.poi.ss.usermodel.SheetConditionalFormatting
    public XSSFConditionalFormattingRule createConditionalFormattingRule(byte b2, String str) {
        return createConditionalFormattingRule(b2, str, (String) null);
    }

    @Override // org.apache.poi.ss.usermodel.SheetConditionalFormatting
    public int addConditionalFormatting(ConditionalFormatting conditionalFormatting) {
        CTWorksheet cTWorksheet = this._sheet.getCTWorksheet();
        cTWorksheet.addNewConditionalFormatting().set(((XSSFConditionalFormatting) conditionalFormatting).getCTConditionalFormatting().copy());
        return cTWorksheet.sizeOfConditionalFormattingArray() - 1;
    }

    @Override // org.apache.poi.ss.usermodel.SheetConditionalFormatting
    public XSSFConditionalFormattingRule createConditionalFormattingRule(String str) {
        XSSFConditionalFormattingRule xSSFConditionalFormattingRule = new XSSFConditionalFormattingRule(this._sheet);
        CTCfRule cTCfRule = xSSFConditionalFormattingRule.getCTCfRule();
        cTCfRule.addFormula(str);
        cTCfRule.setType(STCfType.EXPRESSION);
        return xSSFConditionalFormattingRule;
    }

    public XSSFConditionalFormattingRule createConditionalFormattingRule(XSSFColor xSSFColor) {
        XSSFConditionalFormattingRule xSSFConditionalFormattingRule = new XSSFConditionalFormattingRule(this._sheet);
        xSSFConditionalFormattingRule.createDataBarFormatting(xSSFColor);
        return xSSFConditionalFormattingRule;
    }

    @Override // org.apache.poi.ss.usermodel.SheetConditionalFormatting
    public XSSFConditionalFormattingRule createConditionalFormattingRule(ExtendedColor extendedColor) {
        return createConditionalFormattingRule((XSSFColor) extendedColor);
    }

    @Override // org.apache.poi.ss.usermodel.SheetConditionalFormatting
    public XSSFConditionalFormattingRule createConditionalFormattingRule(IconMultiStateFormatting.IconSet iconSet) {
        XSSFConditionalFormattingRule xSSFConditionalFormattingRule = new XSSFConditionalFormattingRule(this._sheet);
        xSSFConditionalFormattingRule.createMultiStateFormatting(iconSet);
        return xSSFConditionalFormattingRule;
    }
}
