package org.apache.poi.xssf.usermodel;

import org.apache.poi.ss.usermodel.TableStyle;
import org.apache.poi.ss.usermodel.TableStyleInfo;
import org.apache.poi.xssf.model.StylesTable;
import org.openxmlformats.schemas.spreadsheetml.x2006.main.CTTableStyleInfo;

public class XSSFTableStyleInfo implements TableStyleInfo {
    public boolean columnStripes;
    public boolean firstColumn;
    public boolean lastColumn;
    public boolean rowStripes;
    public TableStyle style;
    public final CTTableStyleInfo styleInfo;
    public final StylesTable stylesTable;

    public XSSFTableStyleInfo(StylesTable stylesTable2, CTTableStyleInfo cTTableStyleInfo) {
        this.columnStripes = cTTableStyleInfo.getShowColumnStripes();
        this.rowStripes = cTTableStyleInfo.getShowRowStripes();
        this.firstColumn = cTTableStyleInfo.getShowFirstColumn();
        this.lastColumn = cTTableStyleInfo.getShowLastColumn();
        this.style = stylesTable2.getTableStyle(cTTableStyleInfo.getName());
        this.stylesTable = stylesTable2;
        this.styleInfo = cTTableStyleInfo;
    }

    @Override // org.apache.poi.ss.usermodel.TableStyleInfo
    public String getName() {
        return this.style.getName();
    }

    @Override // org.apache.poi.ss.usermodel.TableStyleInfo
    public TableStyle getStyle() {
        return this.style;
    }

    @Override // org.apache.poi.ss.usermodel.TableStyleInfo
    public boolean isShowColumnStripes() {
        return this.columnStripes;
    }

    @Override // org.apache.poi.ss.usermodel.TableStyleInfo
    public boolean isShowFirstColumn() {
        return this.firstColumn;
    }

    @Override // org.apache.poi.ss.usermodel.TableStyleInfo
    public boolean isShowLastColumn() {
        return this.lastColumn;
    }

    @Override // org.apache.poi.ss.usermodel.TableStyleInfo
    public boolean isShowRowStripes() {
        return this.rowStripes;
    }

    public void setFirstColumn(boolean z) {
        this.firstColumn = z;
        this.styleInfo.setShowFirstColumn(z);
    }

    public void setLastColumn(boolean z) {
        this.lastColumn = z;
        this.styleInfo.setShowLastColumn(z);
    }

    public void setName(String str) {
        this.styleInfo.setName(str);
        this.style = this.stylesTable.getTableStyle(str);
    }

    public void setShowColumnStripes(boolean z) {
        this.columnStripes = z;
        this.styleInfo.setShowColumnStripes(z);
    }

    public void setShowRowStripes(boolean z) {
        this.rowStripes = z;
        this.styleInfo.setShowRowStripes(z);
    }
}
