package org.apache.poi.xssf.usermodel;

import java.util.ArrayList;
import java.util.Iterator;
import java.util.List;
import org.apache.poi.hssf.usermodel.HSSFFont;
import org.apache.poi.java.awt.Color;
import org.apache.poi.ss.formula.functions.NumericFunction;
import org.apache.poi.util.Internal;
import org.apache.poi.util.Units;
import org.apache.poi.xssf.model.ParagraphPropertyFetcher;
import org.apache.xmlbeans.XmlObject;
import org.openxmlformats.schemas.drawingml.x2006.main.CTColor;
import org.openxmlformats.schemas.drawingml.x2006.main.CTRegularTextRun;
import org.openxmlformats.schemas.drawingml.x2006.main.CTTextAutonumberBullet;
import org.openxmlformats.schemas.drawingml.x2006.main.CTTextCharacterProperties;
import org.openxmlformats.schemas.drawingml.x2006.main.CTTextField;
import org.openxmlformats.schemas.drawingml.x2006.main.CTTextLineBreak;
import org.openxmlformats.schemas.drawingml.x2006.main.CTTextNormalAutofit;
import org.openxmlformats.schemas.drawingml.x2006.main.CTTextParagraph;
import org.openxmlformats.schemas.drawingml.x2006.main.CTTextParagraphProperties;
import org.openxmlformats.schemas.drawingml.x2006.main.CTTextSpacing;
import org.openxmlformats.schemas.drawingml.x2006.main.CTTextTabStopList;
import org.openxmlformats.schemas.drawingml.x2006.main.STTextAlignType;
import org.openxmlformats.schemas.drawingml.x2006.main.STTextAutonumberScheme;
import org.openxmlformats.schemas.drawingml.x2006.main.STTextFontAlignType;
import org.openxmlformats.schemas.drawingml.x2006.spreadsheetDrawing.CTShape;

public class XSSFTextParagraph implements Iterable<XSSFTextRun> {
    public final CTTextParagraph _p;
    public final List<XSSFTextRun> _runs = new ArrayList();
    public final CTShape _shape;

    public XSSFTextParagraph(CTTextParagraph cTTextParagraph, CTShape cTShape) {
        this._p = cTTextParagraph;
        this._shape = cTShape;
        XmlObject[] selectPath = this._p.selectPath("*");
        for (XmlObject xmlObject : selectPath) {
            if (xmlObject instanceof CTRegularTextRun) {
                this._runs.add(new XSSFTextRun((CTRegularTextRun) xmlObject, this));
            } else if (xmlObject instanceof CTTextLineBreak) {
                CTRegularTextRun newInstance = CTRegularTextRun.Factory.newInstance();
                newInstance.setRPr(((CTTextLineBreak) xmlObject).getRPr());
                newInstance.setT("\n");
                this._runs.add(new XSSFTextRun(newInstance, this));
            } else if (xmlObject instanceof CTTextField) {
                CTTextField cTTextField = (CTTextField) xmlObject;
                CTRegularTextRun newInstance2 = CTRegularTextRun.Factory.newInstance();
                newInstance2.setRPr(cTTextField.getRPr());
                newInstance2.setT(cTTextField.getT());
                this._runs.add(new XSSFTextRun(newInstance2, this));
            }
        }
    }

    private boolean fetchParagraphProperty(ParagraphPropertyFetcher paragraphPropertyFetcher) {
        boolean fetch = this._p.isSetPPr() ? paragraphPropertyFetcher.fetch(this._p.getPPr()) : false;
        return !fetch ? paragraphPropertyFetcher.fetch(this._shape) : fetch;
    }

    public XSSFTextRun addLineBreak() {
        CTTextCharacterProperties addNewRPr = this._p.addNewBr().addNewRPr();
        if (this._runs.size() > 0) {
            List<XSSFTextRun> list = this._runs;
            addNewRPr.set(list.get(list.size() - 1).getRPr());
        }
        CTRegularTextRun newInstance = CTRegularTextRun.Factory.newInstance();
        newInstance.setRPr(addNewRPr);
        newInstance.setT("\n");
        XSSFLineBreak xSSFLineBreak = new XSSFLineBreak(newInstance, this, addNewRPr);
        this._runs.add(xSSFLineBreak);
        return xSSFLineBreak;
    }

    public XSSFTextRun addNewTextRun() {
        CTRegularTextRun addNewR = this._p.addNewR();
        addNewR.addNewRPr().setLang("en-US");
        XSSFTextRun xSSFTextRun = new XSSFTextRun(addNewR, this);
        this._runs.add(xSSFTextRun);
        return xSSFTextRun;
    }

    public void addTabStop(double d2) {
        CTTextParagraphProperties pPr = this._p.isSetPPr() ? this._p.getPPr() : this._p.addNewPPr();
        (pPr.isSetTabLst() ? pPr.getTabLst() : pPr.addNewTabLst()).addNewTab().setPos(Units.toEMU(d2));
    }

    public ListAutoNumber getBulletAutoNumberScheme() {
        AnonymousClass18 r0 = new ParagraphPropertyFetcher<ListAutoNumber>(getLevel()) {
            /* class org.apache.poi.xssf.usermodel.XSSFTextParagraph.AnonymousClass18 */

            @Override // org.apache.poi.xssf.model.ParagraphPropertyFetcher
            public boolean fetch(CTTextParagraphProperties cTTextParagraphProperties) {
                if (!cTTextParagraphProperties.isSetBuAutoNum()) {
                    return false;
                }
                setValue(ListAutoNumber.values()[cTTextParagraphProperties.getBuAutoNum().getType().intValue() - 1]);
                return true;
            }
        };
        fetchParagraphProperty(r0);
        return r0.getValue() == null ? ListAutoNumber.ARABIC_PLAIN : (ListAutoNumber) r0.getValue();
    }

    public int getBulletAutoNumberStart() {
        AnonymousClass17 r0 = new ParagraphPropertyFetcher<Integer>(getLevel()) {
            /* class org.apache.poi.xssf.usermodel.XSSFTextParagraph.AnonymousClass17 */

            @Override // org.apache.poi.xssf.model.ParagraphPropertyFetcher
            public boolean fetch(CTTextParagraphProperties cTTextParagraphProperties) {
                if (!cTTextParagraphProperties.isSetBuAutoNum() || !cTTextParagraphProperties.getBuAutoNum().isSetStartAt()) {
                    return false;
                }
                setValue(Integer.valueOf(cTTextParagraphProperties.getBuAutoNum().getStartAt()));
                return true;
            }
        };
        fetchParagraphProperty(r0);
        if (r0.getValue() == null) {
            return 0;
        }
        return ((Integer) r0.getValue()).intValue();
    }

    public String getBulletCharacter() {
        AnonymousClass4 r0 = new ParagraphPropertyFetcher<String>(getLevel()) {
            /* class org.apache.poi.xssf.usermodel.XSSFTextParagraph.AnonymousClass4 */

            @Override // org.apache.poi.xssf.model.ParagraphPropertyFetcher
            public boolean fetch(CTTextParagraphProperties cTTextParagraphProperties) {
                if (!cTTextParagraphProperties.isSetBuChar()) {
                    return false;
                }
                setValue(cTTextParagraphProperties.getBuChar().getChar());
                return true;
            }
        };
        fetchParagraphProperty(r0);
        return (String) r0.getValue();
    }

    public String getBulletFont() {
        AnonymousClass3 r0 = new ParagraphPropertyFetcher<String>(getLevel()) {
            /* class org.apache.poi.xssf.usermodel.XSSFTextParagraph.AnonymousClass3 */

            @Override // org.apache.poi.xssf.model.ParagraphPropertyFetcher
            public boolean fetch(CTTextParagraphProperties cTTextParagraphProperties) {
                if (!cTTextParagraphProperties.isSetBuFont()) {
                    return false;
                }
                setValue(cTTextParagraphProperties.getBuFont().getTypeface());
                return true;
            }
        };
        fetchParagraphProperty(r0);
        return (String) r0.getValue();
    }

    public Color getBulletFontColor() {
        AnonymousClass5 r0 = new ParagraphPropertyFetcher<Color>(getLevel()) {
            /* class org.apache.poi.xssf.usermodel.XSSFTextParagraph.AnonymousClass5 */

            @Override // org.apache.poi.xssf.model.ParagraphPropertyFetcher
            public boolean fetch(CTTextParagraphProperties cTTextParagraphProperties) {
                if (!cTTextParagraphProperties.isSetBuClr() || !cTTextParagraphProperties.getBuClr().isSetSrgbClr()) {
                    return false;
                }
                byte[] val = cTTextParagraphProperties.getBuClr().getSrgbClr().getVal();
                setValue(new Color(val[0] & 255, val[1] & 255, val[2] & 255));
                return true;
            }
        };
        fetchParagraphProperty(r0);
        return (Color) r0.getValue();
    }

    public double getBulletFontSize() {
        AnonymousClass6 r0 = new ParagraphPropertyFetcher<Double>(getLevel()) {
            /* class org.apache.poi.xssf.usermodel.XSSFTextParagraph.AnonymousClass6 */

            @Override // org.apache.poi.xssf.model.ParagraphPropertyFetcher
            public boolean fetch(CTTextParagraphProperties cTTextParagraphProperties) {
                if (cTTextParagraphProperties.isSetBuSzPct()) {
                    setValue(Double.valueOf(((double) cTTextParagraphProperties.getBuSzPct().getVal()) * 0.001d));
                    return true;
                } else if (!cTTextParagraphProperties.isSetBuSzPts()) {
                    return false;
                } else {
                    setValue(Double.valueOf(((double) (-cTTextParagraphProperties.getBuSzPts().getVal())) * 0.01d));
                    return true;
                }
            }
        };
        fetchParagraphProperty(r0);
        if (r0.getValue() == null) {
            return 100.0d;
        }
        return ((Double) r0.getValue()).doubleValue();
    }

    public double getDefaultTabSize() {
        AnonymousClass10 r0 = new ParagraphPropertyFetcher<Double>(getLevel()) {
            /* class org.apache.poi.xssf.usermodel.XSSFTextParagraph.AnonymousClass10 */

            @Override // org.apache.poi.xssf.model.ParagraphPropertyFetcher
            public boolean fetch(CTTextParagraphProperties cTTextParagraphProperties) {
                if (!cTTextParagraphProperties.isSetDefTabSz()) {
                    return false;
                }
                setValue(Double.valueOf(Units.toPoints((long) cTTextParagraphProperties.getDefTabSz())));
                return true;
            }
        };
        fetchParagraphProperty(r0);
        return r0.getValue() == null ? NumericFunction.LOG_10_TO_BASE_e : ((Double) r0.getValue()).doubleValue();
    }

    public double getIndent() {
        AnonymousClass7 r0 = new ParagraphPropertyFetcher<Double>(getLevel()) {
            /* class org.apache.poi.xssf.usermodel.XSSFTextParagraph.AnonymousClass7 */

            @Override // org.apache.poi.xssf.model.ParagraphPropertyFetcher
            public boolean fetch(CTTextParagraphProperties cTTextParagraphProperties) {
                if (!cTTextParagraphProperties.isSetIndent()) {
                    return false;
                }
                setValue(Double.valueOf(Units.toPoints((long) cTTextParagraphProperties.getIndent())));
                return true;
            }
        };
        fetchParagraphProperty(r0);
        return r0.getValue() == null ? NumericFunction.LOG_10_TO_BASE_e : ((Double) r0.getValue()).doubleValue();
    }

    public double getLeftMargin() {
        AnonymousClass8 r0 = new ParagraphPropertyFetcher<Double>(getLevel()) {
            /* class org.apache.poi.xssf.usermodel.XSSFTextParagraph.AnonymousClass8 */

            @Override // org.apache.poi.xssf.model.ParagraphPropertyFetcher
            public boolean fetch(CTTextParagraphProperties cTTextParagraphProperties) {
                if (!cTTextParagraphProperties.isSetMarL()) {
                    return false;
                }
                setValue(Double.valueOf(Units.toPoints((long) cTTextParagraphProperties.getMarL())));
                return true;
            }
        };
        fetchParagraphProperty(r0);
        return r0.getValue() == null ? NumericFunction.LOG_10_TO_BASE_e : ((Double) r0.getValue()).doubleValue();
    }

    public int getLevel() {
        CTTextParagraphProperties pPr = this._p.getPPr();
        if (pPr == null) {
            return 0;
        }
        return pPr.getLvl();
    }

    public double getLineSpacing() {
        CTTextNormalAutofit normAutofit;
        AnonymousClass12 r0 = new ParagraphPropertyFetcher<Double>(getLevel()) {
            /* class org.apache.poi.xssf.usermodel.XSSFTextParagraph.AnonymousClass12 */

            @Override // org.apache.poi.xssf.model.ParagraphPropertyFetcher
            public boolean fetch(CTTextParagraphProperties cTTextParagraphProperties) {
                if (!cTTextParagraphProperties.isSetLnSpc()) {
                    return false;
                }
                CTTextSpacing lnSpc = cTTextParagraphProperties.getLnSpc();
                if (lnSpc.isSetSpcPct()) {
                    setValue(Double.valueOf(((double) lnSpc.getSpcPct().getVal()) * 0.001d));
                    return true;
                } else if (!lnSpc.isSetSpcPts()) {
                    return true;
                } else {
                    setValue(Double.valueOf(((double) (-lnSpc.getSpcPts().getVal())) * 0.01d));
                    return true;
                }
            }
        };
        fetchParagraphProperty(r0);
        double doubleValue = r0.getValue() == null ? 100.0d : ((Double) r0.getValue()).doubleValue();
        return (doubleValue <= NumericFunction.LOG_10_TO_BASE_e || (normAutofit = this._shape.getTxBody().getBodyPr().getNormAutofit()) == null) ? doubleValue : doubleValue * (1.0d - (((double) normAutofit.getLnSpcReduction()) / 100000.0d));
    }

    @Internal
    public CTShape getParentShape() {
        return this._shape;
    }

    public double getRightMargin() {
        AnonymousClass9 r0 = new ParagraphPropertyFetcher<Double>(getLevel()) {
            /* class org.apache.poi.xssf.usermodel.XSSFTextParagraph.AnonymousClass9 */

            @Override // org.apache.poi.xssf.model.ParagraphPropertyFetcher
            public boolean fetch(CTTextParagraphProperties cTTextParagraphProperties) {
                if (!cTTextParagraphProperties.isSetMarR()) {
                    return false;
                }
                setValue(Double.valueOf(Units.toPoints((long) cTTextParagraphProperties.getMarR())));
                return true;
            }
        };
        fetchParagraphProperty(r0);
        return r0.getValue() == null ? NumericFunction.LOG_10_TO_BASE_e : ((Double) r0.getValue()).doubleValue();
    }

    public double getSpaceAfter() {
        AnonymousClass14 r0 = new ParagraphPropertyFetcher<Double>(getLevel()) {
            /* class org.apache.poi.xssf.usermodel.XSSFTextParagraph.AnonymousClass14 */

            @Override // org.apache.poi.xssf.model.ParagraphPropertyFetcher
            public boolean fetch(CTTextParagraphProperties cTTextParagraphProperties) {
                if (!cTTextParagraphProperties.isSetSpcAft()) {
                    return false;
                }
                CTTextSpacing spcAft = cTTextParagraphProperties.getSpcAft();
                if (spcAft.isSetSpcPct()) {
                    setValue(Double.valueOf(((double) spcAft.getSpcPct().getVal()) * 0.001d));
                    return true;
                } else if (!spcAft.isSetSpcPts()) {
                    return true;
                } else {
                    setValue(Double.valueOf(((double) (-spcAft.getSpcPts().getVal())) * 0.01d));
                    return true;
                }
            }
        };
        fetchParagraphProperty(r0);
        return r0.getValue() == null ? NumericFunction.LOG_10_TO_BASE_e : ((Double) r0.getValue()).doubleValue();
    }

    public double getSpaceBefore() {
        AnonymousClass13 r0 = new ParagraphPropertyFetcher<Double>(getLevel()) {
            /* class org.apache.poi.xssf.usermodel.XSSFTextParagraph.AnonymousClass13 */

            @Override // org.apache.poi.xssf.model.ParagraphPropertyFetcher
            public boolean fetch(CTTextParagraphProperties cTTextParagraphProperties) {
                if (!cTTextParagraphProperties.isSetSpcBef()) {
                    return false;
                }
                CTTextSpacing spcBef = cTTextParagraphProperties.getSpcBef();
                if (spcBef.isSetSpcPct()) {
                    setValue(Double.valueOf(((double) spcBef.getSpcPct().getVal()) * 0.001d));
                    return true;
                } else if (!spcBef.isSetSpcPts()) {
                    return true;
                } else {
                    setValue(Double.valueOf(((double) (-spcBef.getSpcPts().getVal())) * 0.01d));
                    return true;
                }
            }
        };
        fetchParagraphProperty(r0);
        return r0.getValue() == null ? NumericFunction.LOG_10_TO_BASE_e : ((Double) r0.getValue()).doubleValue();
    }

    public double getTabStop(final int i2) {
        AnonymousClass11 r0 = new ParagraphPropertyFetcher<Double>(getLevel()) {
            /* class org.apache.poi.xssf.usermodel.XSSFTextParagraph.AnonymousClass11 */

            @Override // org.apache.poi.xssf.model.ParagraphPropertyFetcher
            public boolean fetch(CTTextParagraphProperties cTTextParagraphProperties) {
                if (!cTTextParagraphProperties.isSetTabLst()) {
                    return false;
                }
                CTTextTabStopList tabLst = cTTextParagraphProperties.getTabLst();
                if (i2 >= tabLst.sizeOfTabArray()) {
                    return false;
                }
                setValue(Double.valueOf(Units.toPoints((long) tabLst.getTabArray(i2).getPos())));
                return true;
            }
        };
        fetchParagraphProperty(r0);
        return r0.getValue() == null ? NumericFunction.LOG_10_TO_BASE_e : ((Double) r0.getValue()).doubleValue();
    }

    public String getText() {
        StringBuilder sb = new StringBuilder();
        for (XSSFTextRun xSSFTextRun : this._runs) {
            sb.append(xSSFTextRun.getText());
        }
        return sb.toString();
    }

    public TextAlign getTextAlign() {
        AnonymousClass1 r0 = new ParagraphPropertyFetcher<TextAlign>(getLevel()) {
            /* class org.apache.poi.xssf.usermodel.XSSFTextParagraph.AnonymousClass1 */

            @Override // org.apache.poi.xssf.model.ParagraphPropertyFetcher
            public boolean fetch(CTTextParagraphProperties cTTextParagraphProperties) {
                if (!cTTextParagraphProperties.isSetAlgn()) {
                    return false;
                }
                setValue(TextAlign.values()[cTTextParagraphProperties.getAlgn().intValue() - 1]);
                return true;
            }
        };
        fetchParagraphProperty(r0);
        return r0.getValue() == null ? TextAlign.LEFT : (TextAlign) r0.getValue();
    }

    public TextFontAlign getTextFontAlign() {
        AnonymousClass2 r0 = new ParagraphPropertyFetcher<TextFontAlign>(getLevel()) {
            /* class org.apache.poi.xssf.usermodel.XSSFTextParagraph.AnonymousClass2 */

            @Override // org.apache.poi.xssf.model.ParagraphPropertyFetcher
            public boolean fetch(CTTextParagraphProperties cTTextParagraphProperties) {
                if (!cTTextParagraphProperties.isSetFontAlgn()) {
                    return false;
                }
                setValue(TextFontAlign.values()[cTTextParagraphProperties.getFontAlgn().intValue() - 1]);
                return true;
            }
        };
        fetchParagraphProperty(r0);
        return r0.getValue() == null ? TextFontAlign.BASELINE : (TextFontAlign) r0.getValue();
    }

    public List<XSSFTextRun> getTextRuns() {
        return this._runs;
    }

    @Internal
    public CTTextParagraph getXmlObject() {
        return this._p;
    }

    public boolean isBullet() {
        AnonymousClass15 r0 = new ParagraphPropertyFetcher<Boolean>(getLevel()) {
            /* class org.apache.poi.xssf.usermodel.XSSFTextParagraph.AnonymousClass15 */

            @Override // org.apache.poi.xssf.model.ParagraphPropertyFetcher
            public boolean fetch(CTTextParagraphProperties cTTextParagraphProperties) {
                if (cTTextParagraphProperties.isSetBuNone()) {
                    setValue(false);
                    return true;
                } else if (!cTTextParagraphProperties.isSetBuFont() || (!cTTextParagraphProperties.isSetBuChar() && !cTTextParagraphProperties.isSetBuAutoNum())) {
                    return false;
                } else {
                    setValue(true);
                    return true;
                }
            }
        };
        fetchParagraphProperty(r0);
        if (r0.getValue() == null) {
            return false;
        }
        return ((Boolean) r0.getValue()).booleanValue();
    }

    public boolean isBulletAutoNumber() {
        AnonymousClass16 r0 = new ParagraphPropertyFetcher<Boolean>(getLevel()) {
            /* class org.apache.poi.xssf.usermodel.XSSFTextParagraph.AnonymousClass16 */

            @Override // org.apache.poi.xssf.model.ParagraphPropertyFetcher
            public boolean fetch(CTTextParagraphProperties cTTextParagraphProperties) {
                if (!cTTextParagraphProperties.isSetBuAutoNum()) {
                    return false;
                }
                setValue(true);
                return true;
            }
        };
        fetchParagraphProperty(r0);
        if (r0.getValue() == null) {
            return false;
        }
        return ((Boolean) r0.getValue()).booleanValue();
    }

    @Override // java.lang.Iterable
    public Iterator<XSSFTextRun> iterator() {
        return this._runs.iterator();
    }

    public void setBullet(boolean z) {
        if (isBullet() != z) {
            CTTextParagraphProperties pPr = this._p.isSetPPr() ? this._p.getPPr() : this._p.addNewPPr();
            if (!z) {
                pPr.addNewBuNone();
                if (pPr.isSetBuAutoNum()) {
                    pPr.unsetBuAutoNum();
                }
                if (pPr.isSetBuBlip()) {
                    pPr.unsetBuBlip();
                }
                if (pPr.isSetBuChar()) {
                    pPr.unsetBuChar();
                }
                if (pPr.isSetBuClr()) {
                    pPr.unsetBuClr();
                }
                if (pPr.isSetBuClrTx()) {
                    pPr.unsetBuClrTx();
                }
                if (pPr.isSetBuFont()) {
                    pPr.unsetBuFont();
                }
                if (pPr.isSetBuFontTx()) {
                    pPr.unsetBuFontTx();
                }
                if (pPr.isSetBuSzPct()) {
                    pPr.unsetBuSzPct();
                }
                if (pPr.isSetBuSzPts()) {
                    pPr.unsetBuSzPts();
                }
                if (pPr.isSetBuSzTx()) {
                    pPr.unsetBuSzTx();
                    return;
                }
                return;
            }
            if (pPr.isSetBuNone()) {
                pPr.unsetBuNone();
            }
            if (!pPr.isSetBuFont()) {
                pPr.addNewBuFont().setTypeface(HSSFFont.FONT_ARIAL);
            }
            if (!pPr.isSetBuAutoNum()) {
                pPr.addNewBuChar().setChar("•");
            }
        }
    }

    public void setBulletCharacter(String str) {
        CTTextParagraphProperties pPr = this._p.isSetPPr() ? this._p.getPPr() : this._p.addNewPPr();
        (pPr.isSetBuChar() ? pPr.getBuChar() : pPr.addNewBuChar()).setChar(str);
    }

    public void setBulletFont(String str) {
        CTTextParagraphProperties pPr = this._p.isSetPPr() ? this._p.getPPr() : this._p.addNewPPr();
        (pPr.isSetBuFont() ? pPr.getBuFont() : pPr.addNewBuFont()).setTypeface(str);
    }

    public void setBulletFontColor(Color color) {
        CTTextParagraphProperties pPr = this._p.isSetPPr() ? this._p.getPPr() : this._p.addNewPPr();
        CTColor buClr = pPr.isSetBuClr() ? pPr.getBuClr() : pPr.addNewBuClr();
        (buClr.isSetSrgbClr() ? buClr.getSrgbClr() : buClr.addNewSrgbClr()).setVal(new byte[]{(byte) color.getRed(), (byte) color.getGreen(), (byte) color.getBlue()});
    }

    public void setBulletFontSize(double d2) {
        CTTextParagraphProperties pPr = this._p.isSetPPr() ? this._p.getPPr() : this._p.addNewPPr();
        if (d2 >= NumericFunction.LOG_10_TO_BASE_e) {
            (pPr.isSetBuSzPct() ? pPr.getBuSzPct() : pPr.addNewBuSzPct()).setVal((int) (d2 * 1000.0d));
            if (pPr.isSetBuSzPts()) {
                pPr.unsetBuSzPts();
                return;
            }
            return;
        }
        (pPr.isSetBuSzPts() ? pPr.getBuSzPts() : pPr.addNewBuSzPts()).setVal((int) ((-d2) * 100.0d));
        if (pPr.isSetBuSzPct()) {
            pPr.unsetBuSzPct();
        }
    }

    public void setIndent(double d2) {
        CTTextParagraphProperties pPr = this._p.isSetPPr() ? this._p.getPPr() : this._p.addNewPPr();
        if (d2 != -1.0d) {
            pPr.setIndent(Units.toEMU(d2));
        } else if (pPr.isSetIndent()) {
            pPr.unsetIndent();
        }
    }

    public void setLeftMargin(double d2) {
        CTTextParagraphProperties pPr = this._p.isSetPPr() ? this._p.getPPr() : this._p.addNewPPr();
        if (d2 != -1.0d) {
            pPr.setMarL(Units.toEMU(d2));
        } else if (pPr.isSetMarL()) {
            pPr.unsetMarL();
        }
    }

    public void setLevel(int i2) {
        (this._p.isSetPPr() ? this._p.getPPr() : this._p.addNewPPr()).setLvl(i2);
    }

    public void setLineSpacing(double d2) {
        CTTextParagraphProperties pPr = this._p.isSetPPr() ? this._p.getPPr() : this._p.addNewPPr();
        CTTextSpacing newInstance = CTTextSpacing.Factory.newInstance();
        if (d2 >= NumericFunction.LOG_10_TO_BASE_e) {
            newInstance.addNewSpcPct().setVal((int) (d2 * 1000.0d));
        } else {
            newInstance.addNewSpcPts().setVal((int) ((-d2) * 100.0d));
        }
        pPr.setLnSpc(newInstance);
    }

    public void setRightMargin(double d2) {
        CTTextParagraphProperties pPr = this._p.isSetPPr() ? this._p.getPPr() : this._p.addNewPPr();
        if (d2 != -1.0d) {
            pPr.setMarR(Units.toEMU(d2));
        } else if (pPr.isSetMarR()) {
            pPr.unsetMarR();
        }
    }

    public void setSpaceAfter(double d2) {
        CTTextParagraphProperties pPr = this._p.isSetPPr() ? this._p.getPPr() : this._p.addNewPPr();
        CTTextSpacing newInstance = CTTextSpacing.Factory.newInstance();
        if (d2 >= NumericFunction.LOG_10_TO_BASE_e) {
            newInstance.addNewSpcPct().setVal((int) (d2 * 1000.0d));
        } else {
            newInstance.addNewSpcPts().setVal((int) ((-d2) * 100.0d));
        }
        pPr.setSpcAft(newInstance);
    }

    public void setSpaceBefore(double d2) {
        CTTextParagraphProperties pPr = this._p.isSetPPr() ? this._p.getPPr() : this._p.addNewPPr();
        CTTextSpacing newInstance = CTTextSpacing.Factory.newInstance();
        if (d2 >= NumericFunction.LOG_10_TO_BASE_e) {
            newInstance.addNewSpcPct().setVal((int) (d2 * 1000.0d));
        } else {
            newInstance.addNewSpcPts().setVal((int) ((-d2) * 100.0d));
        }
        pPr.setSpcBef(newInstance);
    }

    public void setTextAlign(TextAlign textAlign) {
        CTTextParagraphProperties pPr = this._p.isSetPPr() ? this._p.getPPr() : this._p.addNewPPr();
        if (textAlign != null) {
            pPr.setAlgn(STTextAlignType.Enum.forInt(textAlign.ordinal() + 1));
        } else if (pPr.isSetAlgn()) {
            pPr.unsetAlgn();
        }
    }

    public void setTextFontAlign(TextFontAlign textFontAlign) {
        CTTextParagraphProperties pPr = this._p.isSetPPr() ? this._p.getPPr() : this._p.addNewPPr();
        if (textFontAlign != null) {
            pPr.setFontAlgn(STTextFontAlignType.Enum.forInt(textFontAlign.ordinal() + 1));
        } else if (pPr.isSetFontAlgn()) {
            pPr.unsetFontAlgn();
        }
    }

    public String toString() {
        return "[" + XSSFTextParagraph.class + "]" + getText();
    }

    public void setBullet(ListAutoNumber listAutoNumber, int i2) {
        if (i2 >= 1) {
            CTTextParagraphProperties pPr = this._p.isSetPPr() ? this._p.getPPr() : this._p.addNewPPr();
            CTTextAutonumberBullet buAutoNum = pPr.isSetBuAutoNum() ? pPr.getBuAutoNum() : pPr.addNewBuAutoNum();
            buAutoNum.setType(STTextAutonumberScheme.Enum.forInt(listAutoNumber.ordinal() + 1));
            buAutoNum.setStartAt(i2);
            if (!pPr.isSetBuFont()) {
                pPr.addNewBuFont().setTypeface(HSSFFont.FONT_ARIAL);
            }
            if (pPr.isSetBuNone()) {
                pPr.unsetBuNone();
            }
            if (pPr.isSetBuBlip()) {
                pPr.unsetBuBlip();
            }
            if (pPr.isSetBuChar()) {
                pPr.unsetBuChar();
                return;
            }
            return;
        }
        throw new IllegalArgumentException("Start Number must be greater or equal that 1");
    }

    public void setBullet(ListAutoNumber listAutoNumber) {
        CTTextParagraphProperties pPr = this._p.isSetPPr() ? this._p.getPPr() : this._p.addNewPPr();
        (pPr.isSetBuAutoNum() ? pPr.getBuAutoNum() : pPr.addNewBuAutoNum()).setType(STTextAutonumberScheme.Enum.forInt(listAutoNumber.ordinal() + 1));
        if (!pPr.isSetBuFont()) {
            pPr.addNewBuFont().setTypeface(HSSFFont.FONT_ARIAL);
        }
        if (pPr.isSetBuNone()) {
            pPr.unsetBuNone();
        }
        if (pPr.isSetBuBlip()) {
            pPr.unsetBuBlip();
        }
        if (pPr.isSetBuChar()) {
            pPr.unsetBuChar();
        }
    }
}
