package org.apache.poi.xssf.usermodel;

import b.b.a.a.a;
import org.apache.poi.java.awt.Color;
import org.apache.poi.ss.formula.functions.NumericFunction;
import org.openxmlformats.schemas.drawingml.x2006.main.CTRegularTextRun;
import org.openxmlformats.schemas.drawingml.x2006.main.CTSolidColorFillProperties;
import org.openxmlformats.schemas.drawingml.x2006.main.CTTextCharacterProperties;
import org.openxmlformats.schemas.drawingml.x2006.main.CTTextFont;
import org.openxmlformats.schemas.drawingml.x2006.main.CTTextNormalAutofit;
import org.openxmlformats.schemas.drawingml.x2006.main.STTextStrikeType;
import org.openxmlformats.schemas.drawingml.x2006.main.STTextUnderlineType;

public class XSSFTextRun {
    public final XSSFTextParagraph _p;
    public final CTRegularTextRun _r;

    public XSSFTextRun(CTRegularTextRun cTRegularTextRun, XSSFTextParagraph xSSFTextParagraph) {
        this._r = cTRegularTextRun;
        this._p = xSSFTextParagraph;
    }

    public double getCharacterSpacing() {
        CTTextCharacterProperties rPr = getRPr();
        return rPr.isSetSpc() ? ((double) rPr.getSpc()) * 0.01d : NumericFunction.LOG_10_TO_BASE_e;
    }

    public Color getFontColor() {
        CTTextCharacterProperties rPr = getRPr();
        if (rPr.isSetSolidFill()) {
            CTSolidColorFillProperties solidFill = rPr.getSolidFill();
            if (solidFill.isSetSrgbClr()) {
                byte[] val = solidFill.getSrgbClr().getVal();
                return new Color(val[0] & 255, val[1] & 255, val[2] & 255);
            }
        }
        return new Color(0, 0, 0);
    }

    public String getFontFamily() {
        CTTextFont latin = getRPr().getLatin();
        return latin != null ? latin.getTypeface() : XSSFFont.DEFAULT_FONT_NAME;
    }

    public double getFontSize() {
        CTTextNormalAutofit normAutofit = getParentParagraph().getParentShape().getTxBody().getBodyPr().getNormAutofit();
        double fontScale = normAutofit != null ? ((double) normAutofit.getFontScale()) / 100000.0d : 1.0d;
        CTTextCharacterProperties rPr = getRPr();
        return (rPr.isSetSz() ? ((double) rPr.getSz()) * 0.01d : 11.0d) * fontScale;
    }

    public XSSFTextParagraph getParentParagraph() {
        return this._p;
    }

    public byte getPitchAndFamily() {
        CTTextFont latin = getRPr().getLatin();
        if (latin != null) {
            return latin.getPitchFamily();
        }
        return 0;
    }

    public CTTextCharacterProperties getRPr() {
        return this._r.isSetRPr() ? this._r.getRPr() : this._r.addNewRPr();
    }

    public String getText() {
        return this._r.getT();
    }

    public TextCap getTextCap() {
        CTTextCharacterProperties rPr = getRPr();
        if (rPr.isSetCap()) {
            return TextCap.values()[rPr.getCap().intValue() - 1];
        }
        return TextCap.NONE;
    }

    public CTRegularTextRun getXmlObject() {
        return this._r;
    }

    public boolean isBold() {
        CTTextCharacterProperties rPr = getRPr();
        if (rPr.isSetB()) {
            return rPr.getB();
        }
        return false;
    }

    public boolean isItalic() {
        CTTextCharacterProperties rPr = getRPr();
        if (rPr.isSetI()) {
            return rPr.getI();
        }
        return false;
    }

    public boolean isStrikethrough() {
        CTTextCharacterProperties rPr = getRPr();
        if (!rPr.isSetStrike() || rPr.getStrike() == STTextStrikeType.NO_STRIKE) {
            return false;
        }
        return true;
    }

    public boolean isSubscript() {
        CTTextCharacterProperties rPr = getRPr();
        if (!rPr.isSetBaseline() || rPr.getBaseline() >= 0) {
            return false;
        }
        return true;
    }

    public boolean isSuperscript() {
        CTTextCharacterProperties rPr = getRPr();
        if (!rPr.isSetBaseline() || rPr.getBaseline() <= 0) {
            return false;
        }
        return true;
    }

    public boolean isUnderline() {
        CTTextCharacterProperties rPr = getRPr();
        if (!rPr.isSetU() || rPr.getU() == STTextUnderlineType.NONE) {
            return false;
        }
        return true;
    }

    public void setBaselineOffset(double d2) {
        getRPr().setBaseline(((int) d2) * 1000);
    }

    public void setBold(boolean z) {
        getRPr().setB(z);
    }

    public void setCharacterSpacing(double d2) {
        CTTextCharacterProperties rPr = getRPr();
        if (d2 != NumericFunction.LOG_10_TO_BASE_e) {
            rPr.setSpc((int) (d2 * 100.0d));
        } else if (rPr.isSetSpc()) {
            rPr.unsetSpc();
        }
    }

    public void setFont(String str) {
        setFontFamily(str, (byte) -1, (byte) -1, false);
    }

    public void setFontColor(Color color) {
        CTTextCharacterProperties rPr = getRPr();
        CTSolidColorFillProperties solidFill = rPr.isSetSolidFill() ? rPr.getSolidFill() : rPr.addNewSolidFill();
        (solidFill.isSetSrgbClr() ? solidFill.getSrgbClr() : solidFill.addNewSrgbClr()).setVal(new byte[]{(byte) color.getRed(), (byte) color.getGreen(), (byte) color.getBlue()});
        if (solidFill.isSetHslClr()) {
            solidFill.unsetHslClr();
        }
        if (solidFill.isSetPrstClr()) {
            solidFill.unsetPrstClr();
        }
        if (solidFill.isSetSchemeClr()) {
            solidFill.unsetSchemeClr();
        }
        if (solidFill.isSetScrgbClr()) {
            solidFill.unsetScrgbClr();
        }
        if (solidFill.isSetSysClr()) {
            solidFill.unsetSysClr();
        }
    }

    public void setFontFamily(String str, byte b2, byte b3, boolean z) {
        CTTextCharacterProperties rPr = getRPr();
        if (str == null) {
            if (rPr.isSetLatin()) {
                rPr.unsetLatin();
            }
            if (rPr.isSetCs()) {
                rPr.unsetCs();
            }
            if (rPr.isSetSym()) {
                rPr.unsetSym();
            }
        } else if (z) {
            (rPr.isSetSym() ? rPr.getSym() : rPr.addNewSym()).setTypeface(str);
        } else {
            CTTextFont latin = rPr.isSetLatin() ? rPr.getLatin() : rPr.addNewLatin();
            latin.setTypeface(str);
            if (b2 != -1) {
                latin.setCharset(b2);
            }
            if (b3 != -1) {
                latin.setPitchFamily(b3);
            }
        }
    }

    public void setFontSize(double d2) {
        CTTextCharacterProperties rPr = getRPr();
        if (d2 == -1.0d) {
            if (rPr.isSetSz()) {
                rPr.unsetSz();
            }
        } else if (d2 >= 1.0d) {
            rPr.setSz((int) (d2 * 100.0d));
        } else {
            throw new IllegalArgumentException("Minimum font size is 1pt but was " + d2);
        }
    }

    public void setItalic(boolean z) {
        getRPr().setI(z);
    }

    public void setStrikethrough(boolean z) {
        getRPr().setStrike(z ? STTextStrikeType.SNG_STRIKE : STTextStrikeType.NO_STRIKE);
    }

    public void setSubscript(boolean z) {
        setBaselineOffset(z ? -25.0d : NumericFunction.LOG_10_TO_BASE_e);
    }

    public void setSuperscript(boolean z) {
        setBaselineOffset(z ? 30.0d : NumericFunction.LOG_10_TO_BASE_e);
    }

    public void setText(String str) {
        this._r.setT(str);
    }

    public void setUnderline(boolean z) {
        getRPr().setU(z ? STTextUnderlineType.SNG : STTextUnderlineType.NONE);
    }

    public String toString() {
        StringBuilder b2 = a.b("[");
        b2.append(getClass());
        b2.append("]");
        b2.append(getText());
        return b2.toString();
    }
}
