package org.apache.poi.xssf.usermodel;

import b.b.a.a.a;
import i.a.a.a.d;
import i.a.a.a.q.a;
import i.a.a.a.q.c;
import java.io.ByteArrayInputStream;
import java.io.ByteArrayOutputStream;
import java.io.File;
import java.io.IOException;
import java.io.InputStream;
import java.io.OutputStream;
import java.util.ArrayList;
import java.util.Collection;
import java.util.Collections;
import java.util.HashMap;
import java.util.Iterator;
import java.util.LinkedList;
import java.util.List;
import java.util.Locale;
import java.util.Map;
import java.util.regex.Pattern;
import org.apache.poi.POIXMLDocument;
import org.apache.poi.POIXMLDocumentPart;
import org.apache.poi.POIXMLException;
import org.apache.poi.POIXMLTypeLoader;
import org.apache.poi.hpsf.ClassID;
import org.apache.poi.javax.xml.namespace.QName;
import org.apache.poi.openxml4j.exceptions.InvalidFormatException;
import org.apache.poi.openxml4j.opc.OPCPackage;
import org.apache.poi.openxml4j.opc.PackageAccess;
import org.apache.poi.openxml4j.opc.PackagePart;
import org.apache.poi.openxml4j.opc.PackagePartName;
import org.apache.poi.openxml4j.opc.PackageRelationship;
import org.apache.poi.openxml4j.opc.PackagingURIHelper;
import org.apache.poi.openxml4j.opc.TargetMode;
import org.apache.poi.poifs.crypt.HashAlgorithm;
import org.apache.poi.poifs.filesystem.DirectoryNode;
import org.apache.poi.poifs.filesystem.Ole10Native;
import org.apache.poi.poifs.filesystem.POIFSFileSystem;
import org.apache.poi.ss.SpreadsheetVersion;
import org.apache.poi.ss.formula.SheetNameFormatter;
import org.apache.poi.ss.formula.udf.AggregatingUDFFinder;
import org.apache.poi.ss.formula.udf.IndexedUDFFinder;
import org.apache.poi.ss.formula.udf.UDFFinder;
import org.apache.poi.ss.usermodel.Name;
import org.apache.poi.ss.usermodel.Row;
import org.apache.poi.ss.usermodel.Sheet;
import org.apache.poi.ss.usermodel.SheetVisibility;
import org.apache.poi.ss.usermodel.Workbook;
import org.apache.poi.ss.util.CellReference;
import org.apache.poi.ss.util.WorkbookUtil;
import org.apache.poi.util.IOUtils;
import org.apache.poi.util.Internal;
import org.apache.poi.util.NotImplemented;
import org.apache.poi.util.POILogFactory;
import org.apache.poi.util.POILogger;
import org.apache.poi.util.PackageHelper;
import org.apache.poi.util.Removal;
import org.apache.poi.xssf.XLSBUnsupportedException;
import org.apache.poi.xssf.model.CalculationChain;
import org.apache.poi.xssf.model.ExternalLinksTable;
import org.apache.poi.xssf.model.MapInfo;
import org.apache.poi.xssf.model.SharedStringsTable;
import org.apache.poi.xssf.model.StylesTable;
import org.apache.poi.xssf.model.ThemesTable;
import org.apache.poi.xssf.usermodel.helpers.XSSFFormulaUtils;
import org.apache.poi.xssf.usermodel.helpers.XSSFPasswordHelper;
import org.apache.xmlbeans.XmlException;
import org.apache.xmlbeans.XmlObject;
import org.apache.xmlbeans.XmlOptions;
import org.apache.xmlbeans.impl.piccolo.xml.Piccolo;
import org.openxmlformats.schemas.spreadsheetml.x2006.main.CTBookView;
import org.openxmlformats.schemas.spreadsheetml.x2006.main.CTCalcPr;
import org.openxmlformats.schemas.spreadsheetml.x2006.main.CTDefinedName;
import org.openxmlformats.schemas.spreadsheetml.x2006.main.CTDefinedNames;
import org.openxmlformats.schemas.spreadsheetml.x2006.main.CTDialogsheet;
import org.openxmlformats.schemas.spreadsheetml.x2006.main.CTExternalReference;
import org.openxmlformats.schemas.spreadsheetml.x2006.main.CTPivotCache;
import org.openxmlformats.schemas.spreadsheetml.x2006.main.CTPivotCaches;
import org.openxmlformats.schemas.spreadsheetml.x2006.main.CTSheet;
import org.openxmlformats.schemas.spreadsheetml.x2006.main.CTSheets;
import org.openxmlformats.schemas.spreadsheetml.x2006.main.CTWorkbook;
import org.openxmlformats.schemas.spreadsheetml.x2006.main.CTWorkbookPr;
import org.openxmlformats.schemas.spreadsheetml.x2006.main.CTWorkbookProtection;
import org.openxmlformats.schemas.spreadsheetml.x2006.main.CTWorksheet;
import org.openxmlformats.schemas.spreadsheetml.x2006.main.STCalcMode;
import org.openxmlformats.schemas.spreadsheetml.x2006.main.STSheetState;
import org.openxmlformats.schemas.spreadsheetml.x2006.main.WorkbookDocument;

public class XSSFWorkbook extends POIXMLDocument implements Workbook {
    public static final Pattern COMMA_PATTERN = Pattern.compile(XSSFDataValidationConstraint.LIST_SEPARATOR);
    @Removal(version = "3.19")
    public static final float DEFAULT_CHARACTER_WIDTH = 7.0017f;
    public static final int MAX_SENSITIVE_SHEET_NAME_LEN = 31;
    public static final int PICTURE_TYPE_BMP = 11;
    public static final int PICTURE_TYPE_EPS = 10;
    public static final int PICTURE_TYPE_GIF = 8;
    public static final int PICTURE_TYPE_TIFF = 9;
    public static final int PICTURE_TYPE_WPG = 12;
    public static POILogger logger = POILogFactory.getLogger(XSSFWorkbook.class);
    public XSSFCreationHelper _creationHelper;
    public Row.MissingCellPolicy _missingCellPolicy;
    public IndexedUDFFinder _udfFinder;
    public CalculationChain calcChain;
    public List<ExternalLinksTable> externalLinks;
    public XSSFDataFormat formatter;
    public MapInfo mapInfo;
    public List<XSSFName> namedRanges;
    public d<String, XSSFName> namedRangesByName;
    public List<XSSFPictureData> pictures;
    public List<CTPivotCache> pivotCaches;
    public List<XSSFPivotTable> pivotTables;
    public SharedStringsTable sharedStringSource;
    public List<XSSFSheet> sheets;
    public StylesTable stylesSource;
    public CTWorkbook workbook;

    /* renamed from: org.apache.poi.xssf.usermodel.XSSFWorkbook$1  reason: invalid class name */
    public static /* synthetic */ class AnonymousClass1 {
        public static final /* synthetic */ int[] $SwitchMap$org$apache$poi$ss$usermodel$SheetVisibility;

        /* JADX WARNING: Can't wrap try/catch for region: R(8:0|(2:1|2)|3|5|6|7|8|10) */
        /* JADX WARNING: Code restructure failed: missing block: B:11:?, code lost:
            return;
         */
        /* JADX WARNING: Failed to process nested try/catch */
        /* JADX WARNING: Missing exception handler attribute for start block: B:7:0x0016 */
        static {
            int[] iArr = new int[SheetVisibility.values().length];
            $SwitchMap$org$apache$poi$ss$usermodel$SheetVisibility = iArr;
            try {
                SheetVisibility sheetVisibility = SheetVisibility.VISIBLE;
                iArr[0] = 1;
            } catch (NoSuchFieldError unused) {
            }
            int[] iArr2 = $SwitchMap$org$apache$poi$ss$usermodel$SheetVisibility;
            SheetVisibility sheetVisibility2 = SheetVisibility.HIDDEN;
            iArr2[1] = 2;
            int[] iArr3 = $SwitchMap$org$apache$poi$ss$usermodel$SheetVisibility;
            SheetVisibility sheetVisibility3 = SheetVisibility.VERY_HIDDEN;
            iArr3[2] = 3;
        }
    }

    public final class SheetIterator<T extends Sheet> implements Iterator<T> {
        public final Iterator<T> it;

        public SheetIterator() {
            this.it = XSSFWorkbook.this.sheets.iterator();
        }

        public boolean hasNext() {
            return this.it.hasNext();
        }

        public void remove() {
            throw new UnsupportedOperationException("remove method not supported on XSSFWorkbook.iterator(). Use Sheet.removeSheetAt(int) instead.");
        }

        @Override // java.util.Iterator
        public T next() {
            return this.it.next();
        }
    }

    public XSSFWorkbook() {
        this(XSSFWorkbookType.XLSX);
    }

    public static void addRelation(POIXMLDocumentPart.RelationPart relationPart, POIXMLDocumentPart pOIXMLDocumentPart) {
        PackageRelationship relationship = relationPart.getRelationship();
        if (relationship.getTargetMode() == TargetMode.EXTERNAL) {
            pOIXMLDocumentPart.getPackagePart().addRelationship(relationship.getTargetURI(), relationship.getTargetMode(), relationship.getRelationshipType(), relationship.getId());
            return;
        }
        XSSFRelation instance = XSSFRelation.getInstance(relationship.getRelationshipType());
        if (instance != null) {
            pOIXMLDocumentPart.addRelation(relationship.getId(), instance, relationPart.getDocumentPart());
            return;
        }
        StringBuilder b2 = a.b("Can't clone sheet - unknown relation type found: ");
        b2.append(relationship.getRelationshipType());
        throw new POIXMLException(b2.toString());
    }

    private CTSheet addSheet(String str) {
        CTSheet addNewSheet = this.workbook.getSheets().addNewSheet();
        addNewSheet.setName(str);
        return addNewSheet;
    }

    private boolean containsSheet(String str, int i2) {
        CTSheet[] sheetArray = this.workbook.getSheets().getSheetArray();
        if (str.length() > 31) {
            str = str.substring(0, 31);
        }
        for (int i3 = 0; i3 < sheetArray.length; i3++) {
            String name = sheetArray[i3].getName();
            if (name.length() > 31) {
                name = name.substring(0, 31);
            }
            if (i2 != i3 && str.equalsIgnoreCase(name)) {
                return true;
            }
        }
        return false;
    }

    private XSSFName createAndStoreName(CTDefinedName cTDefinedName) {
        XSSFName xSSFName = new XSSFName(cTDefinedName, this);
        this.namedRanges.add(xSSFName);
        this.namedRangesByName.put(cTDefinedName.getName().toLowerCase(Locale.ENGLISH), xSSFName);
        return xSSFName;
    }

    public static String getReferencePrintArea(String str, int i2, int i3, int i4, int i5) {
        CellReference cellReference = new CellReference(str, i4, i2, true, true);
        CellReference cellReference2 = new CellReference(str, i5, i3, true, true);
        StringBuilder b2 = a.b("$");
        b2.append(cellReference.getCellRefParts()[2]);
        b2.append("$");
        b2.append(cellReference.getCellRefParts()[1]);
        b2.append(":$");
        b2.append(cellReference2.getCellRefParts()[2]);
        b2.append("$");
        b2.append(cellReference2.getCellRefParts()[1]);
        return b2.toString();
    }

    /* JADX WARNING: Removed duplicated region for block: B:15:0x0048  */
    /* JADX WARNING: Removed duplicated region for block: B:16:0x0060  */
    /* JADX WARNING: Removed duplicated region for block: B:20:0x0084 A[LOOP:0: B:13:0x0033->B:20:0x0084, LOOP_END] */
    /* JADX WARNING: Removed duplicated region for block: B:21:0x0083 A[SYNTHETIC] */
    private String getUniqueSheetName(String str) {
        int i2;
        String num;
        String str2;
        int lastIndexOf = str.lastIndexOf(40);
        if (lastIndexOf > 0 && str.endsWith(")")) {
            try {
                i2 = Integer.parseInt(str.substring(lastIndexOf + 1, str.length() - 1).trim()) + 1;
                try {
                    str = str.substring(0, lastIndexOf).trim();
                } catch (NumberFormatException unused) {
                }
            } catch (NumberFormatException unused2) {
            }
            while (true) {
                int i3 = i2 + 1;
                num = Integer.toString(i2);
                if (num.length() + str.length() + 2 >= 31) {
                    str2 = str + " (" + num + ")";
                } else {
                    StringBuilder sb = new StringBuilder();
                    sb.append(str.substring(0, (31 - num.length()) - 2));
                    sb.append("(");
                    str2 = a.a(sb, num, ")");
                }
                if (getSheetIndex(str2) != -1) {
                    return str2;
                }
                i2 = i3;
            }
        }
        i2 = 2;
        while (true) {
            int i32 = i2 + 1;
            num = Integer.toString(i2);
            if (num.length() + str.length() + 2 >= 31) {
            }
            if (getSheetIndex(str2) != -1) {
            }
            i2 = i32;
        }
    }

    public static OPCPackage newPackage(XSSFWorkbookType xSSFWorkbookType) {
        try {
            OPCPackage create = OPCPackage.create(new ByteArrayOutputStream());
            PackagePartName createPartName = PackagingURIHelper.createPartName(XSSFRelation.WORKBOOK.getDefaultFileName());
            create.addRelationship(createPartName, TargetMode.INTERNAL, "http://schemas.openxmlformats.org/officeDocument/2006/relationships/officeDocument");
            create.createPart(createPartName, xSSFWorkbookType.getContentType());
            create.getPackageProperties().setCreatorProperty(POIXMLDocument.DOCUMENT_CREATOR);
            return create;
        } catch (Exception e2) {
            throw new POIXMLException(e2);
        }
    }

    private void onSheetDelete(int i2) {
        this.workbook.getSheets().removeSheet(i2);
        CalculationChain calculationChain = this.calcChain;
        if (calculationChain != null) {
            removeRelation(calculationChain);
            this.calcChain = null;
        }
        ArrayList arrayList = new ArrayList();
        for (XSSFName xSSFName : this.namedRanges) {
            CTDefinedName cTName = xSSFName.getCTName();
            if (cTName.isSetLocalSheetId()) {
                long j = (long) i2;
                if (cTName.getLocalSheetId() == j) {
                    arrayList.add(xSSFName);
                } else if (cTName.getLocalSheetId() > j) {
                    cTName.setLocalSheetId(cTName.getLocalSheetId() - 1);
                }
            }
        }
        Iterator it = arrayList.iterator();
        while (it.hasNext()) {
            removeName((XSSFName) it.next());
        }
    }

    private void onWorkbookCreate() {
        CTWorkbook newInstance = CTWorkbook.Factory.newInstance();
        this.workbook = newInstance;
        newInstance.addNewWorkbookPr().setDate1904(false);
        this.workbook.addNewBookViews().addNewWorkbookView().setActiveTab(0);
        this.workbook.addNewSheets();
        getProperties().getExtendedProperties().getUnderlyingProperties().setApplication(POIXMLDocument.DOCUMENT_CREATOR);
        this.sharedStringSource = (SharedStringsTable) createRelationship(XSSFRelation.SHARED_STRINGS, XSSFFactory.getInstance());
        StylesTable stylesTable = (StylesTable) createRelationship(XSSFRelation.STYLES, XSSFFactory.getInstance());
        this.stylesSource = stylesTable;
        stylesTable.setWorkbook(this);
        this.namedRanges = new ArrayList();
        this.namedRangesByName = new c();
        this.sheets = new ArrayList();
        this.pivotTables = new ArrayList();
    }

    private void reprocessNamedRanges() {
        this.namedRangesByName = new c();
        this.namedRanges = new ArrayList();
        if (this.workbook.isSetDefinedNames()) {
            for (CTDefinedName cTDefinedName : this.workbook.getDefinedNames().getDefinedNameArray()) {
                createAndStoreName(cTDefinedName);
            }
        }
    }

    private CTWorkbookProtection safeGetWorkbookProtection() {
        if (!workbookProtectionPresent()) {
            return this.workbook.addNewWorkbookProtection();
        }
        return this.workbook.getWorkbookProtection();
    }

    private void saveCalculationChain() {
        CalculationChain calculationChain = this.calcChain;
        if (calculationChain != null && calculationChain.getCTCalcChain().sizeOfCArray() == 0) {
            removeRelation(this.calcChain);
            this.calcChain = null;
        }
    }

    private void saveNamedRanges() {
        if (this.namedRanges.size() > 0) {
            CTDefinedNames newInstance = CTDefinedNames.Factory.newInstance();
            CTDefinedName[] cTDefinedNameArr = new CTDefinedName[this.namedRanges.size()];
            int i2 = 0;
            for (XSSFName xSSFName : this.namedRanges) {
                cTDefinedNameArr[i2] = xSSFName.getCTName();
                i2++;
            }
            newInstance.setDefinedNameArray(cTDefinedNameArr);
            if (this.workbook.isSetDefinedNames()) {
                this.workbook.unsetDefinedNames();
            }
            this.workbook.setDefinedNames(newInstance);
            reprocessNamedRanges();
        } else if (this.workbook.isSetDefinedNames()) {
            this.workbook.unsetDefinedNames();
        }
    }

    private void updateActiveSheetAfterSheetReorder(int i2, int i3) {
        int activeSheetIndex = getActiveSheetIndex();
        if (activeSheetIndex == i2) {
            setActiveSheet(i3);
        } else if (activeSheetIndex < i2 && activeSheetIndex < i3) {
        } else {
            if (activeSheetIndex > i2 && activeSheetIndex > i3) {
                return;
            }
            if (i3 > i2) {
                setActiveSheet(activeSheetIndex - 1);
            } else {
                setActiveSheet(activeSheetIndex + 1);
            }
        }
    }

    private void updateNamedRangesAfterSheetReorder(int i2, int i3) {
        for (XSSFName xSSFName : this.namedRanges) {
            int sheetIndex = xSSFName.getSheetIndex();
            if (sheetIndex != -1) {
                if (sheetIndex == i2) {
                    xSSFName.setSheetIndex(i3);
                } else if (i3 <= sheetIndex && sheetIndex < i2) {
                    xSSFName.setSheetIndex(sheetIndex + 1);
                } else if (i2 < sheetIndex && sheetIndex <= i3) {
                    xSSFName.setSheetIndex(sheetIndex - 1);
                }
            }
        }
    }

    private void validateSheetIndex(int i2) {
        int size = this.sheets.size() - 1;
        if (i2 < 0 || i2 > size) {
            String b2 = a.b("(0..", size, ")");
            if (size == -1) {
                b2 = "(no sheets)";
            }
            throw new IllegalArgumentException("Sheet index (" + i2 + ") is out of range " + b2);
        }
    }

    private void validateSheetName(String str) {
        if (containsSheet(str, this.sheets.size())) {
            throw new IllegalArgumentException(a.b("The workbook already contains a sheet named '", str, "'"));
        }
    }

    private boolean workbookProtectionPresent() {
        return this.workbook.isSetWorkbookProtection();
    }

    @Override // org.apache.poi.ss.usermodel.Workbook
    public int addOlePackage(byte[] bArr, String str, String str2, String str3) {
        PackagePartName createPartName;
        OPCPackage oPCPackage = getPackage();
        int i2 = 0;
        do {
            try {
                StringBuilder sb = new StringBuilder();
                sb.append("/xl/embeddings/oleObject");
                i2++;
                sb.append(i2);
                sb.append(".bin");
                createPartName = PackagingURIHelper.createPartName(sb.toString());
            } catch (InvalidFormatException e2) {
                throw new IOException("ole object name not recognized", e2);
            }
        } while (oPCPackage.containPart(createPartName));
        PackagePart createPart = oPCPackage.createPart(createPartName, "application/vnd.openxmlformats-officedocument.oleObject");
        Ole10Native ole10Native = new Ole10Native(str, str2, str3, bArr);
        ByteArrayOutputStream byteArrayOutputStream = new ByteArrayOutputStream(bArr.length + Piccolo.YYSTACKSIZE);
        ole10Native.writeOut(byteArrayOutputStream);
        POIFSFileSystem pOIFSFileSystem = new POIFSFileSystem();
        DirectoryNode root = pOIFSFileSystem.getRoot();
        root.createDocument(Ole10Native.OLE10_NATIVE, new ByteArrayInputStream(byteArrayOutputStream.toByteArray()));
        root.setStorageClsid(ClassID.OLE10_PACKAGE);
        OutputStream outputStream = createPart.getOutputStream();
        pOIFSFileSystem.writeFilesystem(outputStream);
        outputStream.close();
        pOIFSFileSystem.close();
        return i2;
    }

    @Override // org.apache.poi.ss.usermodel.Workbook
    public int addPicture(byte[] bArr, int i2) {
        int size = getAllPictures().size() + 1;
        XSSFPictureData xSSFPictureData = (XSSFPictureData) createRelationship(XSSFPictureData.RELATIONS[i2], XSSFFactory.getInstance(), size, true).getDocumentPart();
        try {
            OutputStream outputStream = xSSFPictureData.getPackagePart().getOutputStream();
            outputStream.write(bArr);
            outputStream.close();
            this.pictures.add(xSSFPictureData);
            return size - 1;
        } catch (IOException e2) {
            throw new POIXMLException(e2);
        }
    }

    public CTPivotCache addPivotCache(String str) {
        CTPivotCaches cTPivotCaches;
        CTWorkbook cTWorkbook = getCTWorkbook();
        if (cTWorkbook.isSetPivotCaches()) {
            cTPivotCaches = cTWorkbook.getPivotCaches();
        } else {
            cTPivotCaches = cTWorkbook.addNewPivotCaches();
        }
        CTPivotCache addNewPivotCache = cTPivotCaches.addNewPivotCache();
        addNewPivotCache.setCacheId((long) (getPivotTables().size() + 1));
        addNewPivotCache.setId(str);
        if (this.pivotCaches == null) {
            this.pivotCaches = new ArrayList();
        }
        this.pivotCaches.add(addNewPivotCache);
        return addNewPivotCache;
    }

    @Override // org.apache.poi.ss.usermodel.Workbook
    public void addToolPack(UDFFinder uDFFinder) {
        this._udfFinder.add(uDFFinder);
    }

    public void beforeDocumentRead() {
        if (!getCorePart().getContentType().equals(XSSFRelation.XLSB_BINARY_WORKBOOK.getContentType())) {
            this.pivotTables = new ArrayList();
            this.pivotCaches = new ArrayList();
            return;
        }
        throw new XLSBUnsupportedException();
    }

    @Override // org.apache.poi.POIXMLDocumentPart
    public void commit() {
        saveNamedRanges();
        saveCalculationChain();
        XmlOptions xmlOptions = new XmlOptions(POIXMLTypeLoader.DEFAULT_XML_OPTIONS);
        xmlOptions.setSaveSyntheticDocumentElement(new QName(CTWorkbook.type.getName().getNamespaceURI(), "workbook"));
        OutputStream outputStream = getPackagePart().getOutputStream();
        this.workbook.save(outputStream, xmlOptions);
        outputStream.close();
    }

    public XSSFName createBuiltInName(String str, int i2) {
        validateSheetIndex(i2);
        CTDefinedName addNewDefinedName = (this.workbook.getDefinedNames() == null ? this.workbook.addNewDefinedNames() : this.workbook.getDefinedNames()).addNewDefinedName();
        addNewDefinedName.setName(str);
        addNewDefinedName.setLocalSheetId((long) i2);
        if (getBuiltInName(str, i2) == null) {
            return createAndStoreName(addNewDefinedName);
        }
        throw new POIXMLException("Builtin (" + str + ") already exists for sheet (" + i2 + ")");
    }

    public XSSFDialogsheet createDialogsheet(String str, CTDialogsheet cTDialogsheet) {
        return new XSSFDialogsheet(createSheet(str));
    }

    @Override // org.apache.poi.ss.usermodel.Workbook
    public int getActiveSheetIndex() {
        return (int) this.workbook.getBookViews().getWorkbookViewArray(0).getActiveTab();
    }

    @Override // org.apache.poi.POIXMLDocument
    public List<PackagePart> getAllEmbedds() {
        LinkedList linkedList = new LinkedList();
        for (XSSFSheet xSSFSheet : this.sheets) {
            Iterator<PackageRelationship> it = xSSFSheet.getPackagePart().getRelationshipsByType(XSSFRelation.OLEEMBEDDINGS.getRelation()).iterator();
            while (it.hasNext()) {
                linkedList.add(xSSFSheet.getPackagePart().getRelatedPart(it.next()));
            }
            Iterator<PackageRelationship> it2 = xSSFSheet.getPackagePart().getRelationshipsByType(XSSFRelation.PACKEMBEDDINGS.getRelation()).iterator();
            while (it2.hasNext()) {
                linkedList.add(xSSFSheet.getPackagePart().getRelatedPart(it2.next()));
            }
        }
        return linkedList;
    }

    @Override // org.apache.poi.ss.usermodel.Workbook
    public List<XSSFName> getAllNames() {
        return Collections.unmodifiableList(this.namedRanges);
    }

    @Override // org.apache.poi.ss.usermodel.Workbook
    public List<XSSFPictureData> getAllPictures() {
        if (this.pictures == null) {
            List<PackagePart> partsByName = getPackage().getPartsByName(Pattern.compile("/xl/media/.*?"));
            this.pictures = new ArrayList(partsByName.size());
            for (PackagePart packagePart : partsByName) {
                this.pictures.add(new XSSFPictureData(packagePart));
            }
        }
        return this.pictures;
    }

    public XSSFName getBuiltInName(String str, int i2) {
        d<String, XSSFName> dVar = this.namedRangesByName;
        String lowerCase = str.toLowerCase(Locale.ENGLISH);
        i.a.a.a.q.a aVar = (i.a.a.a.q.a) dVar;
        if (aVar != null) {
            Iterator it = new a.b(lowerCase).iterator();
            while (it.hasNext()) {
                XSSFName xSSFName = (XSSFName) it.next();
                if (xSSFName.getSheetIndex() == i2) {
                    return xSSFName;
                }
            }
            return null;
        }
        throw null;
    }

    @Internal
    public CTWorkbook getCTWorkbook() {
        return this.workbook;
    }

    @Internal
    public CalculationChain getCalculationChain() {
        return this.calcChain;
    }

    public Collection<XSSFMap> getCustomXMLMappings() {
        MapInfo mapInfo2 = this.mapInfo;
        return mapInfo2 == null ? new ArrayList() : mapInfo2.getAllXSSFMaps();
    }

    @Internal
    public List<ExternalLinksTable> getExternalLinksTable() {
        return this.externalLinks;
    }

    @Override // org.apache.poi.ss.usermodel.Workbook
    public int getFirstVisibleTab() {
        return (short) ((int) this.workbook.getBookViews().getWorkbookViewArray(0).getFirstSheet());
    }

    @Override // org.apache.poi.ss.usermodel.Workbook
    public boolean getForceFormulaRecalculation() {
        CTCalcPr calcPr = getCTWorkbook().getCalcPr();
        return (calcPr == null || calcPr.getCalcId() == 0) ? false : true;
    }

    @Internal
    public MapInfo getMapInfo() {
        return this.mapInfo;
    }

    @Override // org.apache.poi.ss.usermodel.Workbook
    public Row.MissingCellPolicy getMissingCellPolicy() {
        return this._missingCellPolicy;
    }

    @Override // org.apache.poi.ss.usermodel.Workbook
    @Deprecated
    public int getNameIndex(String str) {
        XSSFName name = getName(str);
        if (name != null) {
            return this.namedRanges.indexOf(name);
        }
        return -1;
    }

    @Override // org.apache.poi.ss.usermodel.Workbook
    public List<XSSFName> getNames(String str) {
        d<String, XSSFName> dVar = this.namedRangesByName;
        String lowerCase = str.toLowerCase(Locale.ENGLISH);
        i.a.a.a.q.a aVar = (i.a.a.a.q.a) dVar;
        if (aVar != null) {
            return Collections.unmodifiableList(new a.b(lowerCase));
        }
        throw null;
    }

    @Override // org.apache.poi.ss.usermodel.Workbook
    public int getNumCellStyles() {
        return this.stylesSource.getNumCellStyles();
    }

    @Override // org.apache.poi.ss.usermodel.Workbook
    public short getNumberOfFonts() {
        return (short) this.stylesSource.getFonts().size();
    }

    @Override // org.apache.poi.ss.usermodel.Workbook
    public int getNumberOfNames() {
        return this.namedRanges.size();
    }

    @Override // org.apache.poi.ss.usermodel.Workbook
    public int getNumberOfSheets() {
        return this.sheets.size();
    }

    public List<XSSFPivotTable> getPivotTables() {
        return this.pivotTables;
    }

    @Override // org.apache.poi.ss.usermodel.Workbook
    public String getPrintArea(int i2) {
        XSSFName builtInName = getBuiltInName(XSSFName.BUILTIN_PRINT_AREA, i2);
        if (builtInName == null) {
            return null;
        }
        return builtInName.getRefersToFormula();
    }

    @Internal
    public SharedStringsTable getSharedStringSource() {
        return this.sharedStringSource;
    }

    @Override // org.apache.poi.ss.usermodel.Workbook
    public int getSheetIndex(String str) {
        int i2 = 0;
        for (XSSFSheet xSSFSheet : this.sheets) {
            if (str.equalsIgnoreCase(xSSFSheet.getSheetName())) {
                return i2;
            }
            i2++;
        }
        return -1;
    }

    @Override // org.apache.poi.ss.usermodel.Workbook
    public String getSheetName(int i2) {
        validateSheetIndex(i2);
        return this.sheets.get(i2).getSheetName();
    }

    @Override // org.apache.poi.ss.usermodel.Workbook
    public SheetVisibility getSheetVisibility(int i2) {
        validateSheetIndex(i2);
        STSheetState.Enum state = this.sheets.get(i2).sheet.getState();
        if (state == STSheetState.VISIBLE) {
            return SheetVisibility.VISIBLE;
        }
        if (state == STSheetState.HIDDEN) {
            return SheetVisibility.HIDDEN;
        }
        if (state == STSheetState.VERY_HIDDEN) {
            return SheetVisibility.VERY_HIDDEN;
        }
        throw new IllegalArgumentException("This should never happen");
    }

    @Override // org.apache.poi.ss.usermodel.Workbook
    public SpreadsheetVersion getSpreadsheetVersion() {
        return SpreadsheetVersion.EXCEL2007;
    }

    public StylesTable getStylesSource() {
        return this.stylesSource;
    }

    public XSSFTable getTable(String str) {
        List<XSSFSheet> list;
        if (str == null || (list = this.sheets) == null) {
            return null;
        }
        for (XSSFSheet xSSFSheet : list) {
            Iterator<XSSFTable> it = xSSFSheet.getTables().iterator();
            while (true) {
                if (it.hasNext()) {
                    XSSFTable next = it.next();
                    if (str.equalsIgnoreCase(next.getName())) {
                        return next;
                    }
                }
            }
        }
        return null;
    }

    public ThemesTable getTheme() {
        StylesTable stylesTable = this.stylesSource;
        if (stylesTable == null) {
            return null;
        }
        return stylesTable.getTheme();
    }

    public UDFFinder getUDFFinder() {
        return this._udfFinder;
    }

    public XSSFWorkbookType getWorkbookType() {
        return isMacroEnabled() ? XSSFWorkbookType.XLSM : XSSFWorkbookType.XLSX;
    }

    @Internal
    public boolean isDate1904() {
        CTWorkbookPr workbookPr = this.workbook.getWorkbookPr();
        return workbookPr != null && workbookPr.getDate1904();
    }

    @Override // org.apache.poi.ss.usermodel.Workbook
    @NotImplemented
    public boolean isHidden() {
        throw new RuntimeException("Not implemented yet");
    }

    public boolean isMacroEnabled() {
        return getPackagePart().getContentType().equals(XSSFRelation.MACROS_WORKBOOK.getContentType());
    }

    public boolean isRevisionLocked() {
        return workbookProtectionPresent() && this.workbook.getWorkbookProtection().getLockRevision();
    }

    @Override // org.apache.poi.ss.usermodel.Workbook
    public boolean isSheetHidden(int i2) {
        validateSheetIndex(i2);
        return this.sheets.get(i2).sheet.getState() == STSheetState.HIDDEN;
    }

    @Override // org.apache.poi.ss.usermodel.Workbook
    public boolean isSheetVeryHidden(int i2) {
        validateSheetIndex(i2);
        return this.sheets.get(i2).sheet.getState() == STSheetState.VERY_HIDDEN;
    }

    public boolean isStructureLocked() {
        return workbookProtectionPresent() && this.workbook.getWorkbookProtection().getLockStructure();
    }

    public boolean isWindowsLocked() {
        return workbookProtectionPresent() && this.workbook.getWorkbookProtection().getLockWindows();
    }

    @Override // java.lang.Iterable
    public Iterator<Sheet> iterator() {
        return sheetIterator();
    }

    @Override // org.apache.poi.ss.usermodel.Workbook
    @NotImplemented
    public int linkExternalWorkbook(String str, Workbook workbook2) {
        throw new RuntimeException("Not Implemented - see bug #57184");
    }

    public void lockRevision() {
        safeGetWorkbookProtection().setLockRevision(true);
    }

    public void lockStructure() {
        safeGetWorkbookProtection().setLockStructure(true);
    }

    public void lockWindows() {
        safeGetWorkbookProtection().setLockWindows(true);
    }

    public void onDeleteFormula(XSSFCell xSSFCell) {
        if (this.calcChain != null) {
            this.calcChain.removeItem((int) xSSFCell.getSheet().sheet.getSheetId(), xSSFCell.getReference());
        }
    }

    @Override // org.apache.poi.POIXMLDocumentPart
    public void onDocumentRead() {
        try {
            this.workbook = WorkbookDocument.Factory.parse(getPackagePart().getInputStream(), POIXMLTypeLoader.DEFAULT_XML_OPTIONS).getWorkbook();
            ThemesTable themesTable = null;
            HashMap hashMap = new HashMap();
            HashMap hashMap2 = new HashMap();
            for (POIXMLDocumentPart.RelationPart relationPart : getRelationParts()) {
                POIXMLDocumentPart documentPart = relationPart.getDocumentPart();
                if (documentPart instanceof SharedStringsTable) {
                    this.sharedStringSource = (SharedStringsTable) documentPart;
                } else if (documentPart instanceof StylesTable) {
                    this.stylesSource = (StylesTable) documentPart;
                } else if (documentPart instanceof ThemesTable) {
                    themesTable = (ThemesTable) documentPart;
                } else if (documentPart instanceof CalculationChain) {
                    this.calcChain = (CalculationChain) documentPart;
                } else if (documentPart instanceof MapInfo) {
                    this.mapInfo = (MapInfo) documentPart;
                } else if (documentPart instanceof XSSFSheet) {
                    hashMap.put(relationPart.getRelationship().getId(), (XSSFSheet) documentPart);
                } else if (documentPart instanceof ExternalLinksTable) {
                    hashMap2.put(relationPart.getRelationship().getId(), (ExternalLinksTable) documentPart);
                }
            }
            boolean z = getPackage().getPackageAccess() == PackageAccess.READ;
            if (this.stylesSource == null) {
                if (z) {
                    this.stylesSource = new StylesTable();
                } else {
                    this.stylesSource = (StylesTable) createRelationship(XSSFRelation.STYLES, XSSFFactory.getInstance());
                }
            }
            this.stylesSource.setWorkbook(this);
            this.stylesSource.setTheme(themesTable);
            if (this.sharedStringSource == null) {
                if (z) {
                    this.sharedStringSource = new SharedStringsTable();
                } else {
                    this.sharedStringSource = (SharedStringsTable) createRelationship(XSSFRelation.SHARED_STRINGS, XSSFFactory.getInstance());
                }
            }
            this.sheets = new ArrayList(hashMap.size());
            for (CTSheet cTSheet : this.workbook.getSheets().getSheetArray()) {
                parseSheet(hashMap, cTSheet);
            }
            this.externalLinks = new ArrayList(hashMap2.size());
            if (this.workbook.isSetExternalReferences()) {
                CTExternalReference[] externalReferenceArray = this.workbook.getExternalReferences().getExternalReferenceArray();
                for (CTExternalReference cTExternalReference : externalReferenceArray) {
                    ExternalLinksTable externalLinksTable = (ExternalLinksTable) hashMap2.get(cTExternalReference.getId());
                    if (externalLinksTable == null) {
                        logger.log(5, "ExternalLinksTable with r:id " + cTExternalReference.getId() + " was defined, but didn't exist in package, skipping");
                    } else {
                        this.externalLinks.add(externalLinksTable);
                    }
                }
            }
            reprocessNamedRanges();
        } catch (XmlException e2) {
            throw new POIXMLException(e2);
        }
    }

    public void parseSheet(Map<String, XSSFSheet> map, CTSheet cTSheet) {
        XSSFSheet xSSFSheet = map.get(cTSheet.getId());
        if (xSSFSheet == null) {
            POILogger pOILogger = logger;
            StringBuilder b2 = b.b.a.a.a.b("Sheet with name ");
            b2.append(cTSheet.getName());
            b2.append(" and r:id ");
            b2.append(cTSheet.getId());
            b2.append(" was defined, but didn't exist in package, skipping");
            pOILogger.log(5, b2.toString());
            return;
        }
        xSSFSheet.sheet = cTSheet;
        xSSFSheet.onDocumentRead();
        this.sheets.add(xSSFSheet);
    }

    @Override // org.apache.poi.ss.usermodel.Workbook
    @Deprecated
    public void removeName(int i2) {
        removeName(getNameAt(i2));
    }

    @Override // org.apache.poi.ss.usermodel.Workbook
    public void removePrintArea(int i2) {
        XSSFName builtInName = getBuiltInName(XSSFName.BUILTIN_PRINT_AREA, i2);
        if (builtInName != null) {
            removeName(builtInName);
        }
    }

    @Override // org.apache.poi.ss.usermodel.Workbook
    public void removeSheetAt(int i2) {
        validateSheetIndex(i2);
        onSheetDelete(i2);
        removeRelation(getSheetAt(i2));
        this.sheets.remove(i2);
        if (this.sheets.size() != 0) {
            int size = i2 >= this.sheets.size() ? this.sheets.size() - 1 : i2;
            int activeSheetIndex = getActiveSheetIndex();
            if (activeSheetIndex == i2) {
                setActiveSheet(size);
            } else if (activeSheetIndex > i2) {
                setActiveSheet(activeSheetIndex - 1);
            }
        }
    }

    @Override // org.apache.poi.ss.usermodel.Workbook
    public void setActiveSheet(int i2) {
        validateSheetIndex(i2);
        for (CTBookView cTBookView : this.workbook.getBookViews().getWorkbookViewArray()) {
            cTBookView.setActiveTab((long) i2);
        }
    }

    @Override // org.apache.poi.ss.usermodel.Workbook
    public void setFirstVisibleTab(int i2) {
        this.workbook.getBookViews().getWorkbookViewArray(0).setFirstSheet((long) i2);
    }

    @Override // org.apache.poi.ss.usermodel.Workbook
    public void setForceFormulaRecalculation(boolean z) {
        CTWorkbook cTWorkbook = getCTWorkbook();
        CTCalcPr calcPr = cTWorkbook.isSetCalcPr() ? cTWorkbook.getCalcPr() : cTWorkbook.addNewCalcPr();
        calcPr.setCalcId(0);
        if (z && calcPr.getCalcMode() == STCalcMode.MANUAL) {
            calcPr.setCalcMode(STCalcMode.AUTO);
        }
    }

    @Override // org.apache.poi.ss.usermodel.Workbook
    @NotImplemented
    public void setHidden(boolean z) {
        throw new RuntimeException("Not implemented yet");
    }

    @Override // org.apache.poi.ss.usermodel.Workbook
    public void setMissingCellPolicy(Row.MissingCellPolicy missingCellPolicy) {
        this._missingCellPolicy = missingCellPolicy;
    }

    public void setPivotTables(List<XSSFPivotTable> list) {
        this.pivotTables = list;
    }

    @Override // org.apache.poi.ss.usermodel.Workbook
    public void setPrintArea(int i2, String str) {
        XSSFName builtInName = getBuiltInName(XSSFName.BUILTIN_PRINT_AREA, i2);
        if (builtInName == null) {
            builtInName = createBuiltInName(XSSFName.BUILTIN_PRINT_AREA, i2);
        }
        String[] split = COMMA_PATTERN.split(str);
        StringBuffer stringBuffer = new StringBuffer(32);
        for (int i3 = 0; i3 < split.length; i3++) {
            if (i3 > 0) {
                stringBuffer.append(XSSFDataValidationConstraint.LIST_SEPARATOR);
            }
            SheetNameFormatter.appendFormat(stringBuffer, getSheetName(i2));
            stringBuffer.append("!");
            stringBuffer.append(split[i3]);
        }
        builtInName.setRefersToFormula(stringBuffer.toString());
    }

    public void setRevisionsPassword(String str, HashAlgorithm hashAlgorithm) {
        if (str != null || workbookProtectionPresent()) {
            XSSFPasswordHelper.setPassword(safeGetWorkbookProtection(), str, hashAlgorithm, "revisions");
        }
    }

    @Override // org.apache.poi.ss.usermodel.Workbook
    public void setSelectedTab(int i2) {
        int i3 = 0;
        for (XSSFSheet xSSFSheet : this.sheets) {
            xSSFSheet.setSelected(i3 == i2);
            i3++;
        }
    }

    @Override // org.apache.poi.ss.usermodel.Workbook
    public void setSheetHidden(int i2, boolean z) {
        setSheetVisibility(i2, z ? SheetVisibility.HIDDEN : SheetVisibility.VISIBLE);
    }

    @Override // org.apache.poi.ss.usermodel.Workbook
    public void setSheetName(int i2, String str) {
        if (str != null) {
            validateSheetIndex(i2);
            String sheetName = getSheetName(i2);
            if (str.length() > 31) {
                str = str.substring(0, 31);
            }
            WorkbookUtil.validateSheetName(str);
            if (!str.equals(sheetName)) {
                if (!containsSheet(str, i2)) {
                    new XSSFFormulaUtils(this).updateSheetName(i2, sheetName, str);
                    this.workbook.getSheets().getSheetArray(i2).setName(str);
                    return;
                }
                throw new IllegalArgumentException("The workbook already contains a sheet of this name");
            }
            return;
        }
        throw new IllegalArgumentException("sheetName must not be null");
    }

    @Override // org.apache.poi.ss.usermodel.Workbook
    public void setSheetOrder(String str, int i2) {
        int sheetIndex = getSheetIndex(str);
        List<XSSFSheet> list = this.sheets;
        list.add(i2, list.remove(sheetIndex));
        CTSheets sheets2 = this.workbook.getSheets();
        XmlObject copy = sheets2.getSheetArray(sheetIndex).copy();
        this.workbook.getSheets().removeSheet(sheetIndex);
        sheets2.insertNewSheet(i2).set(copy);
        CTSheet[] sheetArray = sheets2.getSheetArray();
        for (int i3 = 0; i3 < sheetArray.length; i3++) {
            this.sheets.get(i3).sheet = sheetArray[i3];
        }
        updateNamedRangesAfterSheetReorder(sheetIndex, i2);
        updateActiveSheetAfterSheetReorder(sheetIndex, i2);
    }

    @Override // org.apache.poi.ss.usermodel.Workbook
    public void setSheetVisibility(int i2, SheetVisibility sheetVisibility) {
        validateSheetIndex(i2);
        CTSheet cTSheet = this.sheets.get(i2).sheet;
        int ordinal = sheetVisibility.ordinal();
        if (ordinal == 0) {
            cTSheet.setState(STSheetState.VISIBLE);
        } else if (ordinal == 1) {
            cTSheet.setState(STSheetState.HIDDEN);
        } else if (ordinal == 2) {
            cTSheet.setState(STSheetState.VERY_HIDDEN);
        } else {
            throw new IllegalArgumentException("This should never happen");
        }
    }

    public void setVBAProject(InputStream inputStream) {
        OutputStream outputStream;
        if (!isMacroEnabled()) {
            setWorkbookType(XSSFWorkbookType.XLSM);
        }
        try {
            PackagePartName createPartName = PackagingURIHelper.createPartName(XSSFRelation.VBA_MACROS.getDefaultFileName());
            OPCPackage oPCPackage = getPackage();
            if (!oPCPackage.containPart(createPartName)) {
                outputStream = createRelationship(XSSFRelation.VBA_MACROS, XSSFFactory.getInstance()).getPackagePart().getOutputStream();
            } else {
                outputStream = oPCPackage.getPart(createPartName).getOutputStream();
            }
            try {
                IOUtils.copy(inputStream, outputStream);
            } finally {
                IOUtils.closeQuietly(outputStream);
            }
        } catch (InvalidFormatException e2) {
            throw new POIXMLException(e2);
        }
    }

    public void setWorkbookPassword(String str, HashAlgorithm hashAlgorithm) {
        if (str != null || workbookProtectionPresent()) {
            XSSFPasswordHelper.setPassword(safeGetWorkbookProtection(), str, hashAlgorithm, "workbook");
        }
    }

    public void setWorkbookType(XSSFWorkbookType xSSFWorkbookType) {
        try {
            getPackagePart().setContentType(xSSFWorkbookType.getContentType());
        } catch (InvalidFormatException e2) {
            throw new POIXMLException(e2);
        }
    }

    @Override // org.apache.poi.ss.usermodel.Workbook
    public Iterator<Sheet> sheetIterator() {
        return new SheetIterator();
    }

    public void unLock() {
        if (workbookProtectionPresent()) {
            this.workbook.unsetWorkbookProtection();
        }
    }

    public void unLockRevision() {
        safeGetWorkbookProtection().setLockRevision(false);
    }

    public void unLockStructure() {
        safeGetWorkbookProtection().setLockStructure(false);
    }

    public void unLockWindows() {
        safeGetWorkbookProtection().setLockWindows(false);
    }

    public void updateName(XSSFName xSSFName, String str) {
        if (this.namedRangesByName.a(str.toLowerCase(Locale.ENGLISH), xSSFName)) {
            this.namedRangesByName.put(xSSFName.getNameName().toLowerCase(Locale.ENGLISH), xSSFName);
            return;
        }
        throw new IllegalArgumentException("Name was not found: " + xSSFName);
    }

    public boolean validateRevisionsPassword(String str) {
        if (!workbookProtectionPresent()) {
            return str == null;
        }
        return XSSFPasswordHelper.validatePassword(safeGetWorkbookProtection(), str, "revisions");
    }

    public boolean validateWorkbookPassword(String str) {
        if (!workbookProtectionPresent()) {
            return str == null;
        }
        return XSSFPasswordHelper.validatePassword(safeGetWorkbookProtection(), str, "workbook");
    }

    @Deprecated
    public Iterator<XSSFSheet> xssfSheetIterator() {
        return new SheetIterator();
    }

    public XSSFWorkbook(XSSFWorkbookType xSSFWorkbookType) {
        super(newPackage(xSSFWorkbookType));
        this._udfFinder = new IndexedUDFFinder(AggregatingUDFFinder.DEFAULT);
        this._missingCellPolicy = Row.MissingCellPolicy.RETURN_NULL_AND_BLANK;
        onWorkbookCreate();
    }

    @Override // org.apache.poi.ss.usermodel.Workbook
    public XSSFSheet cloneSheet(int i2) {
        return cloneSheet(i2, null);
    }

    @Override // org.apache.poi.ss.usermodel.Workbook
    public XSSFCellStyle createCellStyle() {
        return this.stylesSource.createCellStyle();
    }

    @Override // org.apache.poi.ss.usermodel.Workbook
    public XSSFDataFormat createDataFormat() {
        if (this.formatter == null) {
            this.formatter = new XSSFDataFormat(this.stylesSource);
        }
        return this.formatter;
    }

    @Override // org.apache.poi.ss.usermodel.Workbook
    public XSSFFont createFont() {
        XSSFFont xSSFFont = new XSSFFont();
        xSSFFont.registerTo(this.stylesSource);
        return xSSFFont;
    }

    @Override // org.apache.poi.ss.usermodel.Workbook
    public XSSFName createName() {
        CTDefinedName newInstance = CTDefinedName.Factory.newInstance();
        newInstance.setName("");
        return createAndStoreName(newInstance);
    }

    @Override // org.apache.poi.ss.usermodel.Workbook
    public XSSFCellStyle getCellStyleAt(int i2) {
        return this.stylesSource.getStyleAt(i2);
    }

    @Override // org.apache.poi.ss.usermodel.Workbook
    public XSSFCreationHelper getCreationHelper() {
        if (this._creationHelper == null) {
            this._creationHelper = new XSSFCreationHelper(this);
        }
        return this._creationHelper;
    }

    @Override // org.apache.poi.ss.usermodel.Workbook
    public XSSFFont getFontAt(short s) {
        return this.stylesSource.getFontAt(s);
    }

    @Override // org.apache.poi.ss.usermodel.Workbook
    public XSSFName getName(String str) {
        List<XSSFName> names = getNames(str);
        if (names.isEmpty()) {
            return null;
        }
        return names.iterator().next();
    }

    @Override // org.apache.poi.ss.usermodel.Workbook
    @Deprecated
    public XSSFName getNameAt(int i2) {
        int size = this.namedRanges.size();
        if (size < 1) {
            throw new IllegalStateException("There are no defined names in this workbook");
        } else if (i2 >= 0 && i2 <= size) {
            return this.namedRanges.get(i2);
        } else {
            StringBuilder a = b.b.a.a.a.a("Specified name index ", i2, " is outside the allowable range (0..");
            a.append(size - 1);
            a.append(").");
            throw new IllegalArgumentException(a.toString());
        }
    }

    @Override // org.apache.poi.ss.usermodel.Workbook
    public XSSFSheet getSheet(String str) {
        for (XSSFSheet xSSFSheet : this.sheets) {
            if (str.equalsIgnoreCase(xSSFSheet.getSheetName())) {
                return xSSFSheet;
            }
        }
        return null;
    }

    @Override // org.apache.poi.ss.usermodel.Workbook
    public XSSFSheet getSheetAt(int i2) {
        validateSheetIndex(i2);
        return this.sheets.get(i2);
    }

    @Override // org.apache.poi.ss.usermodel.Workbook
    @Deprecated
    public void removeName(String str) {
        d<String, XSSFName> dVar = this.namedRangesByName;
        String lowerCase = str.toLowerCase(Locale.ENGLISH);
        i.a.a.a.q.a aVar = (i.a.a.a.q.a) dVar;
        if (aVar != null) {
            a.b bVar = new a.b(lowerCase);
            if (!bVar.isEmpty()) {
                removeName((Name) bVar.get(0));
                return;
            }
            throw new IllegalArgumentException(b.b.a.a.a.b("Named range was not found: ", str));
        }
        throw null;
    }

    @Override // org.apache.poi.ss.usermodel.Workbook
    @Removal(version = "3.18")
    @Deprecated
    public void setSheetHidden(int i2, int i3) {
        WorkbookUtil.validateSheetState(i3);
        setSheetVisibility(i2, SheetVisibility.values()[i3]);
    }

    public XSSFSheet cloneSheet(int i2, String str) {
        validateSheetIndex(i2);
        XSSFSheet xSSFSheet = this.sheets.get(i2);
        if (str == null) {
            str = getUniqueSheetName(xSSFSheet.getSheetName());
        } else {
            validateSheetName(str);
        }
        XSSFSheet createSheet = createSheet(str);
        XSSFDrawing xSSFDrawing = null;
        for (POIXMLDocumentPart.RelationPart relationPart : xSSFSheet.getRelationParts()) {
            POIXMLDocumentPart documentPart = relationPart.getDocumentPart();
            if (documentPart instanceof XSSFDrawing) {
                xSSFDrawing = (XSSFDrawing) documentPart;
            } else {
                addRelation(relationPart, createSheet);
            }
        }
        try {
            Iterator<PackageRelationship> it = xSSFSheet.getPackagePart().getRelationships().iterator();
            while (it.hasNext()) {
                PackageRelationship next = it.next();
                if (next.getTargetMode() == TargetMode.EXTERNAL) {
                    createSheet.getPackagePart().addExternalRelationship(next.getTargetURI().toASCIIString(), next.getRelationshipType(), next.getId());
                }
            }
            try {
                ByteArrayOutputStream byteArrayOutputStream = new ByteArrayOutputStream();
                xSSFSheet.write(byteArrayOutputStream);
                createSheet.read(new ByteArrayInputStream(byteArrayOutputStream.toByteArray()));
                CTWorksheet cTWorksheet = createSheet.getCTWorksheet();
                if (cTWorksheet.isSetLegacyDrawing()) {
                    logger.log(5, "Cloning sheets with comments is not yet supported.");
                    cTWorksheet.unsetLegacyDrawing();
                }
                if (cTWorksheet.isSetPageSetup()) {
                    logger.log(5, "Cloning sheets with page setup is not yet supported.");
                    cTWorksheet.unsetPageSetup();
                }
                createSheet.setSelected(false);
                if (xSSFDrawing != null) {
                    if (cTWorksheet.isSetDrawing()) {
                        cTWorksheet.unsetDrawing();
                    }
                    createSheet.createDrawingPatriarch().getCTDrawing().set(xSSFDrawing.getCTDrawing());
                    XSSFDrawing createDrawingPatriarch = createSheet.createDrawingPatriarch();
                    for (POIXMLDocumentPart.RelationPart relationPart2 : xSSFSheet.createDrawingPatriarch().getRelationParts()) {
                        addRelation(relationPart2, createDrawingPatriarch);
                    }
                }
                return createSheet;
            } catch (IOException e2) {
                throw new POIXMLException("Failed to clone sheet", e2);
            }
        } catch (InvalidFormatException e3) {
            throw new POIXMLException("Failed to clone sheet", e3);
        }
    }

    @Override // org.apache.poi.ss.usermodel.Workbook
    public XSSFSheet createSheet() {
        StringBuilder b2 = b.b.a.a.a.b("Sheet");
        b2.append(this.sheets.size());
        String sb = b2.toString();
        int i2 = 0;
        while (getSheet(sb) != null) {
            sb = b.b.a.a.a.c("Sheet", i2);
            i2++;
        }
        return createSheet(sb);
    }

    @Deprecated
    public XSSFFont findFont(short s, short s2, short s3, String str, boolean z, boolean z2, short s4, byte b2) {
        return this.stylesSource.findFont(s, s2, s3, str, z, z2, s4, b2);
    }

    @Override // org.apache.poi.ss.usermodel.Workbook
    public int getSheetIndex(Sheet sheet) {
        int i2 = 0;
        for (XSSFSheet xSSFSheet : this.sheets) {
            if (xSSFSheet == sheet) {
                return i2;
            }
            i2++;
        }
        return -1;
    }

    @Override // org.apache.poi.ss.usermodel.Workbook
    public XSSFFont findFont(boolean z, short s, short s2, String str, boolean z2, boolean z3, short s3, byte b2) {
        return this.stylesSource.findFont(z, s, s2, str, z2, z3, s3, b2);
    }

    public XSSFWorkbook(OPCPackage oPCPackage) {
        super(oPCPackage);
        this._udfFinder = new IndexedUDFFinder(AggregatingUDFFinder.DEFAULT);
        this._missingCellPolicy = Row.MissingCellPolicy.RETURN_NULL_AND_BLANK;
        beforeDocumentRead();
        load(XSSFFactory.getInstance());
        if (!this.workbook.isSetBookViews()) {
            this.workbook.addNewBookViews().addNewWorkbookView().setActiveTab(0);
        }
    }

    @Override // org.apache.poi.ss.usermodel.Workbook
    public XSSFSheet createSheet(String str) {
        if (str != null) {
            validateSheetName(str);
            if (str.length() > 31) {
                str = str.substring(0, 31);
            }
            WorkbookUtil.validateSheetName(str);
            CTSheet addSheet = addSheet(str);
            int i2 = 1;
            loop0:
            while (true) {
                for (XSSFSheet xSSFSheet : this.sheets) {
                    i2 = (int) Math.max(xSSFSheet.sheet.getSheetId() + 1, (long) i2);
                }
                String fileName = XSSFRelation.WORKSHEET.getFileName(i2);
                for (POIXMLDocumentPart pOIXMLDocumentPart : getRelations()) {
                    if (pOIXMLDocumentPart.getPackagePart() != null && fileName.equals(pOIXMLDocumentPart.getPackagePart().getPartName().getName())) {
                        i2++;
                    }
                }
                break loop0;
            }
            POIXMLDocumentPart.RelationPart createRelationship = createRelationship(XSSFRelation.WORKSHEET, XSSFFactory.getInstance(), i2, false);
            XSSFSheet xSSFSheet2 = (XSSFSheet) createRelationship.getDocumentPart();
            xSSFSheet2.sheet = addSheet;
            addSheet.setId(createRelationship.getRelationship().getId());
            addSheet.setSheetId((long) i2);
            if (this.sheets.isEmpty()) {
                xSSFSheet2.setSelected(true);
            }
            this.sheets.add(xSSFSheet2);
            return xSSFSheet2;
        }
        throw new IllegalArgumentException("sheetName must not be null");
    }

    public int addPicture(InputStream inputStream, int i2) {
        int size = getAllPictures().size() + 1;
        XSSFPictureData xSSFPictureData = (XSSFPictureData) createRelationship(XSSFPictureData.RELATIONS[i2], XSSFFactory.getInstance(), size, true).getDocumentPart();
        OutputStream outputStream = xSSFPictureData.getPackagePart().getOutputStream();
        IOUtils.copy(inputStream, outputStream);
        outputStream.close();
        this.pictures.add(xSSFPictureData);
        return size - 1;
    }

    @Override // org.apache.poi.ss.usermodel.Workbook
    public void removeName(Name name) {
        if (!this.namedRangesByName.a(name.getNameName().toLowerCase(Locale.ENGLISH), name) || !this.namedRanges.remove(name)) {
            throw new IllegalArgumentException("Name was not found: " + name);
        }
    }

    @Override // org.apache.poi.ss.usermodel.Workbook
    public void setPrintArea(int i2, int i3, int i4, int i5, int i6) {
        setPrintArea(i2, getReferencePrintArea(getSheetName(i2), i3, i4, i5, i6));
    }

    public void setVBAProject(XSSFWorkbook xSSFWorkbook) {
        InputStream contents;
        if (xSSFWorkbook.isMacroEnabled() && (contents = XSSFRelation.VBA_MACROS.getContents(xSSFWorkbook.getCorePart())) != null) {
            setVBAProject(contents);
        }
    }

    public XSSFWorkbook(InputStream inputStream) {
        super(PackageHelper.open(inputStream));
        this._udfFinder = new IndexedUDFFinder(AggregatingUDFFinder.DEFAULT);
        this._missingCellPolicy = Row.MissingCellPolicy.RETURN_NULL_AND_BLANK;
        beforeDocumentRead();
        load(XSSFFactory.getInstance());
        if (!this.workbook.isSetBookViews()) {
            this.workbook.addNewBookViews().addNewWorkbookView().setActiveTab(0);
        }
    }

    public XSSFWorkbook(File file) {
        this(OPCPackage.open(file));
    }

    public XSSFWorkbook(String str) {
        this(POIXMLDocument.openPackage(str));
    }
}
