package org.apache.poi.xssf.usermodel.charts;

import java.util.ArrayList;
import java.util.List;
import org.apache.poi.ss.usermodel.Chart;
import org.apache.poi.ss.usermodel.charts.ChartAxis;
import org.apache.poi.ss.usermodel.charts.ChartDataSource;
import org.apache.poi.ss.usermodel.charts.LineChartData;
import org.apache.poi.ss.usermodel.charts.LineChartSeries;
import org.apache.poi.xssf.usermodel.XSSFChart;
import org.openxmlformats.schemas.drawingml.x2006.chart.CTLineChart;
import org.openxmlformats.schemas.drawingml.x2006.chart.CTLineSer;
import org.openxmlformats.schemas.drawingml.x2006.chart.STMarkerStyle;

public class XSSFLineChartData implements LineChartData {
    public List<Series> series = new ArrayList();

    public static class Series extends AbstractXSSFChartSeries implements LineChartSeries {
        public ChartDataSource<?> categories;
        public int id;
        public int order;
        public ChartDataSource<? extends Number> values;

        public Series(int i2, int i3, ChartDataSource<?> chartDataSource, ChartDataSource<? extends Number> chartDataSource2) {
            this.id = i2;
            this.order = i3;
            this.categories = chartDataSource;
            this.values = chartDataSource2;
        }

        public void addToChart(CTLineChart cTLineChart) {
            CTLineSer addNewSer = cTLineChart.addNewSer();
            addNewSer.addNewIdx().setVal((long) this.id);
            addNewSer.addNewOrder().setVal((long) this.order);
            addNewSer.addNewMarker().addNewSymbol().setVal(STMarkerStyle.NONE);
            XSSFChartUtil.buildAxDataSource(addNewSer.addNewCat(), this.categories);
            XSSFChartUtil.buildNumDataSource(addNewSer.addNewVal(), this.values);
            if (isTitleSet()) {
                addNewSer.setTx(getCTSerTx());
            }
        }

        @Override // org.apache.poi.ss.usermodel.charts.LineChartSeries
        public ChartDataSource<?> getCategoryAxisData() {
            return this.categories;
        }

        @Override // org.apache.poi.ss.usermodel.charts.LineChartSeries
        public ChartDataSource<? extends Number> getValues() {
            return this.values;
        }
    }

    @Override // org.apache.poi.ss.usermodel.charts.LineChartData
    public LineChartSeries addSeries(ChartDataSource<?> chartDataSource, ChartDataSource<? extends Number> chartDataSource2) {
        if (chartDataSource2.isNumeric()) {
            int size = this.series.size();
            Series series2 = new Series(size, size, chartDataSource, chartDataSource2);
            this.series.add(series2);
            return series2;
        }
        throw new IllegalArgumentException("Value data source must be numeric.");
    }

    @Override // org.apache.poi.ss.usermodel.charts.ChartData
    public void fillChart(Chart chart, ChartAxis... chartAxisArr) {
        if (chart instanceof XSSFChart) {
            CTLineChart addNewLineChart = ((XSSFChart) chart).getCTChart().getPlotArea().addNewLineChart();
            addNewLineChart.addNewVaryColors().setVal(false);
            for (Series series2 : this.series) {
                series2.addToChart(addNewLineChart);
            }
            for (ChartAxis chartAxis : chartAxisArr) {
                addNewLineChart.addNewAxId().setVal(chartAxis.getId());
            }
            return;
        }
        throw new IllegalArgumentException("Chart must be instance of XSSFChart");
    }

    @Override // org.apache.poi.ss.usermodel.charts.LineChartData
    public List<? extends LineChartSeries> getSeries() {
        return this.series;
    }
}
