package org.apache.poi.xssf.usermodel.charts;

import java.util.ArrayList;
import java.util.List;
import org.apache.poi.ss.usermodel.Chart;
import org.apache.poi.ss.usermodel.charts.ChartAxis;
import org.apache.poi.ss.usermodel.charts.ChartDataSource;
import org.apache.poi.ss.usermodel.charts.ScatterChartData;
import org.apache.poi.ss.usermodel.charts.ScatterChartSeries;
import org.apache.poi.xssf.usermodel.XSSFChart;
import org.openxmlformats.schemas.drawingml.x2006.chart.CTScatterChart;
import org.openxmlformats.schemas.drawingml.x2006.chart.CTScatterSer;
import org.openxmlformats.schemas.drawingml.x2006.chart.STScatterStyle;

public class XSSFScatterChartData implements ScatterChartData {
    public List<Series> series = new ArrayList();

    public static class Series extends AbstractXSSFChartSeries implements ScatterChartSeries {
        public int id;
        public int order;
        public ChartDataSource<?> xs;
        public ChartDataSource<? extends Number> ys;

        public Series(int i2, int i3, ChartDataSource<?> chartDataSource, ChartDataSource<? extends Number> chartDataSource2) {
            this.id = i2;
            this.order = i3;
            this.xs = chartDataSource;
            this.ys = chartDataSource2;
        }

        public void addToChart(CTScatterChart cTScatterChart) {
            CTScatterSer addNewSer = cTScatterChart.addNewSer();
            addNewSer.addNewIdx().setVal((long) this.id);
            addNewSer.addNewOrder().setVal((long) this.order);
            XSSFChartUtil.buildAxDataSource(addNewSer.addNewXVal(), this.xs);
            XSSFChartUtil.buildNumDataSource(addNewSer.addNewYVal(), this.ys);
            if (isTitleSet()) {
                addNewSer.setTx(getCTSerTx());
            }
        }

        @Override // org.apache.poi.ss.usermodel.charts.ScatterChartSeries
        public ChartDataSource<?> getXValues() {
            return this.xs;
        }

        @Override // org.apache.poi.ss.usermodel.charts.ScatterChartSeries
        public ChartDataSource<? extends Number> getYValues() {
            return this.ys;
        }
    }

    private void addStyle(CTScatterChart cTScatterChart) {
        cTScatterChart.addNewScatterStyle().setVal(STScatterStyle.LINE_MARKER);
    }

    @Override // org.apache.poi.ss.usermodel.charts.ScatterChartData
    public ScatterChartSeries addSerie(ChartDataSource<?> chartDataSource, ChartDataSource<? extends Number> chartDataSource2) {
        if (chartDataSource2.isNumeric()) {
            int size = this.series.size();
            Series series2 = new Series(size, size, chartDataSource, chartDataSource2);
            this.series.add(series2);
            return series2;
        }
        throw new IllegalArgumentException("Y axis data source must be numeric.");
    }

    @Override // org.apache.poi.ss.usermodel.charts.ChartData
    public void fillChart(Chart chart, ChartAxis... chartAxisArr) {
        if (chart instanceof XSSFChart) {
            CTScatterChart addNewScatterChart = ((XSSFChart) chart).getCTChart().getPlotArea().addNewScatterChart();
            addStyle(addNewScatterChart);
            for (Series series2 : this.series) {
                series2.addToChart(addNewScatterChart);
            }
            for (ChartAxis chartAxis : chartAxisArr) {
                addNewScatterChart.addNewAxId().setVal(chartAxis.getId());
            }
            return;
        }
        throw new IllegalArgumentException("Chart must be instance of XSSFChart");
    }

    @Override // org.apache.poi.ss.usermodel.charts.ScatterChartData
    public List<? extends Series> getSeries() {
        return this.series;
    }
}
