package org.apache.poi.xssf.usermodel.extensions;

import org.apache.poi.util.Internal;
import org.apache.poi.xssf.usermodel.IndexedColorMap;
import org.apache.poi.xssf.usermodel.XSSFColor;
import org.openxmlformats.schemas.spreadsheetml.x2006.main.CTColor;
import org.openxmlformats.schemas.spreadsheetml.x2006.main.CTFill;
import org.openxmlformats.schemas.spreadsheetml.x2006.main.CTPatternFill;
import org.openxmlformats.schemas.spreadsheetml.x2006.main.STPatternType;

public final class XSSFCellFill {
    public CTFill _fill;
    public IndexedColorMap _indexedColorMap;

    public XSSFCellFill(CTFill cTFill, IndexedColorMap indexedColorMap) {
        this._fill = cTFill;
        this._indexedColorMap = indexedColorMap;
    }

    private CTPatternFill ensureCTPatternFill() {
        CTPatternFill patternFill = this._fill.getPatternFill();
        return patternFill == null ? this._fill.addNewPatternFill() : patternFill;
    }

    public boolean equals(Object obj) {
        if (!(obj instanceof XSSFCellFill)) {
            return false;
        }
        return this._fill.toString().equals(((XSSFCellFill) obj).getCTFill().toString());
    }

    @Internal
    public CTFill getCTFill() {
        return this._fill;
    }

    public XSSFColor getFillBackgroundColor() {
        CTColor bgColor;
        CTPatternFill patternFill = this._fill.getPatternFill();
        if (patternFill == null || (bgColor = patternFill.getBgColor()) == null) {
            return null;
        }
        return new XSSFColor(bgColor, this._indexedColorMap);
    }

    public XSSFColor getFillForegroundColor() {
        CTColor fgColor;
        CTPatternFill patternFill = this._fill.getPatternFill();
        if (patternFill == null || (fgColor = patternFill.getFgColor()) == null) {
            return null;
        }
        return new XSSFColor(fgColor, this._indexedColorMap);
    }

    public STPatternType.Enum getPatternType() {
        CTPatternFill patternFill = this._fill.getPatternFill();
        if (patternFill == null) {
            return null;
        }
        return patternFill.getPatternType();
    }

    public int hashCode() {
        return this._fill.toString().hashCode();
    }

    public void setFillBackgroundColor(int i2) {
        CTPatternFill ensureCTPatternFill = ensureCTPatternFill();
        (ensureCTPatternFill.isSetBgColor() ? ensureCTPatternFill.getBgColor() : ensureCTPatternFill.addNewBgColor()).setIndexed((long) i2);
    }

    public void setFillForegroundColor(int i2) {
        CTPatternFill ensureCTPatternFill = ensureCTPatternFill();
        (ensureCTPatternFill.isSetFgColor() ? ensureCTPatternFill.getFgColor() : ensureCTPatternFill.addNewFgColor()).setIndexed((long) i2);
    }

    public void setPatternType(STPatternType.Enum r2) {
        ensureCTPatternFill().setPatternType(r2);
    }

    public XSSFCellFill() {
        this._fill = CTFill.Factory.newInstance();
    }

    public void setFillBackgroundColor(XSSFColor xSSFColor) {
        ensureCTPatternFill().setBgColor(xSSFColor.getCTColor());
    }

    public void setFillForegroundColor(XSSFColor xSSFColor) {
        ensureCTPatternFill().setFgColor(xSSFColor.getCTColor());
    }
}
