package org.apache.poi.xssf.usermodel.helpers;

import b.b.a.a.a;
import java.security.SecureRandom;
import java.util.Arrays;
import java.util.Locale;
import javax.xml.bind.DatatypeConverter;
import org.apache.poi.javax.xml.namespace.QName;
import org.apache.poi.poifs.crypt.CryptoFunctions;
import org.apache.poi.poifs.crypt.HashAlgorithm;
import org.apache.poi.util.Internal;
import org.apache.xerces.util.SecurityManager;
import org.apache.xmlbeans.XmlCursor;
import org.apache.xmlbeans.XmlObject;

@Internal(since = "3.15 beta 3")
public final class XSSFPasswordHelper {
    public static QName getAttrName(String str, String str2) {
        if (str == null || "".equals(str)) {
            return new QName(str2);
        }
        StringBuilder b2 = a.b(str);
        b2.append(Character.toUpperCase(str2.charAt(0)));
        b2.append(str2.substring(1));
        return new QName(b2.toString());
    }

    public static void setPassword(XmlObject xmlObject, String str, HashAlgorithm hashAlgorithm, String str2) {
        XmlCursor newCursor = xmlObject.newCursor();
        if (str == null) {
            newCursor.removeAttribute(getAttrName(str2, "password"));
            newCursor.removeAttribute(getAttrName(str2, "algorithmName"));
            newCursor.removeAttribute(getAttrName(str2, "hashValue"));
            newCursor.removeAttribute(getAttrName(str2, "saltValue"));
            newCursor.removeAttribute(getAttrName(str2, "spinCount"));
            return;
        }
        newCursor.toFirstContentToken();
        if (hashAlgorithm == null) {
            int createXorVerifier1 = CryptoFunctions.createXorVerifier1(str);
            newCursor.insertAttributeWithValue(getAttrName(str2, "password"), String.format(Locale.ROOT, "%04X", Integer.valueOf(createXorVerifier1)).toUpperCase(Locale.ROOT));
        } else {
            byte[] generateSeed = new SecureRandom().generateSeed(16);
            byte[] hashPassword = CryptoFunctions.hashPassword(str, hashAlgorithm, generateSeed, SecurityManager.DEFAULT_ENTITY_EXPANSION_LIMIT, false);
            newCursor.insertAttributeWithValue(getAttrName(str2, "algorithmName"), hashAlgorithm.jceId);
            newCursor.insertAttributeWithValue(getAttrName(str2, "hashValue"), DatatypeConverter.printBase64Binary(hashPassword));
            newCursor.insertAttributeWithValue(getAttrName(str2, "saltValue"), DatatypeConverter.printBase64Binary(generateSeed));
            newCursor.insertAttributeWithValue(getAttrName(str2, "spinCount"), "100000");
        }
        newCursor.dispose();
    }

    public static boolean validatePassword(XmlObject xmlObject, String str, String str2) {
        if (str == null) {
            return false;
        }
        XmlCursor newCursor = xmlObject.newCursor();
        String attributeText = newCursor.getAttributeText(getAttrName(str2, "password"));
        String attributeText2 = newCursor.getAttributeText(getAttrName(str2, "algorithmName"));
        String attributeText3 = newCursor.getAttributeText(getAttrName(str2, "hashValue"));
        String attributeText4 = newCursor.getAttributeText(getAttrName(str2, "saltValue"));
        String attributeText5 = newCursor.getAttributeText(getAttrName(str2, "spinCount"));
        newCursor.dispose();
        if (attributeText != null) {
            if (Integer.parseInt(attributeText, 16) == CryptoFunctions.createXorVerifier1(str)) {
                return true;
            }
            return false;
        } else if (attributeText3 == null || attributeText2 == null || attributeText4 == null || attributeText5 == null) {
            return false;
        } else {
            return Arrays.equals(DatatypeConverter.parseBase64Binary(attributeText3), CryptoFunctions.hashPassword(str, HashAlgorithm.fromString(attributeText2), DatatypeConverter.parseBase64Binary(attributeText4), Integer.parseInt(attributeText5), false));
        }
    }
}
