package org.apache.poi.xssf.usermodel.helpers;

import b.b.a.a.a;
import java.util.ArrayList;
import java.util.Iterator;
import java.util.List;
import org.apache.poi.ss.formula.FormulaParseException;
import org.apache.poi.ss.formula.FormulaParser;
import org.apache.poi.ss.formula.FormulaRenderer;
import org.apache.poi.ss.formula.FormulaShifter;
import org.apache.poi.ss.formula.FormulaType;
import org.apache.poi.ss.formula.ptg.AreaErrPtg;
import org.apache.poi.ss.formula.ptg.AreaPtg;
import org.apache.poi.ss.formula.ptg.Ptg;
import org.apache.poi.ss.usermodel.Cell;
import org.apache.poi.ss.usermodel.Hyperlink;
import org.apache.poi.ss.usermodel.Name;
import org.apache.poi.ss.usermodel.Row;
import org.apache.poi.ss.usermodel.Sheet;
import org.apache.poi.ss.usermodel.Workbook;
import org.apache.poi.ss.usermodel.helpers.RowShifter;
import org.apache.poi.ss.util.CellRangeAddress;
import org.apache.poi.util.Internal;
import org.apache.poi.util.POILogFactory;
import org.apache.poi.util.POILogger;
import org.apache.poi.xssf.usermodel.XSSFCell;
import org.apache.poi.xssf.usermodel.XSSFEvaluationWorkbook;
import org.apache.poi.xssf.usermodel.XSSFHyperlink;
import org.apache.poi.xssf.usermodel.XSSFRow;
import org.apache.poi.xssf.usermodel.XSSFSheet;
import org.apache.poi.xssf.usermodel.XSSFWorkbook;
import org.openxmlformats.schemas.spreadsheetml.x2006.main.CTCell;
import org.openxmlformats.schemas.spreadsheetml.x2006.main.CTCellFormula;
import org.openxmlformats.schemas.spreadsheetml.x2006.main.CTCfRule;
import org.openxmlformats.schemas.spreadsheetml.x2006.main.CTConditionalFormatting;
import org.openxmlformats.schemas.spreadsheetml.x2006.main.CTWorksheet;
import org.openxmlformats.schemas.spreadsheetml.x2006.main.STCellFormulaType;

public final class XSSFRowShifter extends RowShifter {
    public static final POILogger logger = POILogFactory.getLogger(XSSFRowShifter.class);

    public XSSFRowShifter(XSSFSheet xSSFSheet) {
        super(xSSFSheet);
    }

    public static String shiftFormula(Row row, String str, FormulaShifter formulaShifter) {
        Sheet sheet = row.getSheet();
        Workbook workbook = sheet.getWorkbook();
        int sheetIndex = workbook.getSheetIndex(sheet);
        int rowNum = row.getRowNum();
        XSSFEvaluationWorkbook create = XSSFEvaluationWorkbook.create((XSSFWorkbook) workbook);
        try {
            Ptg[] parse = FormulaParser.parse(str, create, FormulaType.CELL, sheetIndex, rowNum);
            if (formulaShifter.adjustFormula(parse, sheetIndex)) {
                return FormulaRenderer.toFormulaString(create, parse);
            }
            return null;
        } catch (FormulaParseException e2) {
            logger.log(5, "Error shifting formula on row ", Integer.valueOf(row.getRowNum()), e2);
            return str;
        }
    }

    public static CellRangeAddress shiftRange(FormulaShifter formulaShifter, CellRangeAddress cellRangeAddress, int i2) {
        Ptg[] ptgArr = {new AreaPtg(cellRangeAddress.getFirstRow(), cellRangeAddress.getLastRow(), cellRangeAddress.getFirstColumn(), cellRangeAddress.getLastColumn(), false, false, false, false)};
        if (!formulaShifter.adjustFormula(ptgArr, i2)) {
            return cellRangeAddress;
        }
        Ptg ptg = ptgArr[0];
        if (ptg instanceof AreaPtg) {
            AreaPtg areaPtg = (AreaPtg) ptg;
            return new CellRangeAddress(areaPtg.getFirstRow(), areaPtg.getLastRow(), areaPtg.getFirstColumn(), areaPtg.getLastColumn());
        } else if (ptg instanceof AreaErrPtg) {
            return null;
        } else {
            StringBuilder b2 = a.b("Unexpected shifted ptg class (");
            b2.append(ptg.getClass().getName());
            b2.append(")");
            throw new IllegalStateException(b2.toString());
        }
    }

    private void updateRefInCTCellFormula(Row row, FormulaShifter formulaShifter, CTCellFormula cTCellFormula) {
        String shiftFormula;
        if (cTCellFormula.isSetRef() && (shiftFormula = shiftFormula(row, cTCellFormula.getRef(), formulaShifter)) != null) {
            cTCellFormula.setRef(shiftFormula);
        }
    }

    private void updateSheetFormulas(Sheet sheet, FormulaShifter formulaShifter) {
        Iterator it = sheet.iterator();
        while (it.hasNext()) {
            updateRowFormulas((XSSFRow) ((Row) it.next()), formulaShifter);
        }
    }

    public List<CellRangeAddress> shiftMerged(int i2, int i3, int i4) {
        return shiftMergedRegions(i2, i3, i4);
    }

    @Override // org.apache.poi.ss.usermodel.helpers.RowShifter
    public void updateConditionalFormatting(FormulaShifter formulaShifter) {
        XSSFSheet xSSFSheet = (XSSFSheet) this.sheet;
        XSSFWorkbook workbook = xSSFSheet.getWorkbook();
        int sheetIndex = workbook.getSheetIndex(this.sheet);
        XSSFEvaluationWorkbook create = XSSFEvaluationWorkbook.create(workbook);
        CTWorksheet cTWorksheet = xSSFSheet.getCTWorksheet();
        CTConditionalFormatting[] conditionalFormattingArray = cTWorksheet.getConditionalFormattingArray();
        for (int length = conditionalFormattingArray.length - 1; length >= 0; length--) {
            CTConditionalFormatting cTConditionalFormatting = conditionalFormattingArray[length];
            ArrayList arrayList = new ArrayList();
            for (Object obj : cTConditionalFormatting.getSqref()) {
                for (String str : obj.toString().split(" ")) {
                    arrayList.add(CellRangeAddress.valueOf(str));
                }
            }
            ArrayList arrayList2 = new ArrayList();
            Iterator it = arrayList.iterator();
            boolean z = false;
            while (it.hasNext()) {
                CellRangeAddress cellRangeAddress = (CellRangeAddress) it.next();
                CellRangeAddress shiftRange = shiftRange(formulaShifter, cellRangeAddress, sheetIndex);
                if (shiftRange != null) {
                    arrayList2.add(shiftRange);
                    if (shiftRange == cellRangeAddress) {
                    }
                }
                z = true;
            }
            if (z) {
                if (arrayList2.size() == 0) {
                    cTWorksheet.removeConditionalFormatting(length);
                } else {
                    ArrayList arrayList3 = new ArrayList();
                    Iterator it2 = arrayList2.iterator();
                    while (it2.hasNext()) {
                        arrayList3.add(((CellRangeAddress) it2.next()).formatAsString());
                    }
                    cTConditionalFormatting.setSqref(arrayList3);
                }
            }
            CTCfRule[] cfRuleArray = cTConditionalFormatting.getCfRuleArray();
            for (CTCfRule cTCfRule : cfRuleArray) {
                String[] formulaArray = cTCfRule.getFormulaArray();
                for (int i2 = 0; i2 < formulaArray.length; i2++) {
                    Ptg[] parse = FormulaParser.parse(formulaArray[i2], create, FormulaType.CELL, sheetIndex, -1);
                    if (formulaShifter.adjustFormula(parse, sheetIndex)) {
                        cTCfRule.setFormulaArray(i2, FormulaRenderer.toFormulaString(create, parse));
                    }
                }
            }
        }
    }

    @Override // org.apache.poi.ss.usermodel.helpers.RowShifter
    public void updateFormulas(FormulaShifter formulaShifter) {
        updateSheetFormulas(this.sheet, formulaShifter);
        for (Sheet sheet : this.sheet.getWorkbook()) {
            if (this.sheet != sheet) {
                updateSheetFormulas(sheet, formulaShifter);
            }
        }
    }

    @Override // org.apache.poi.ss.usermodel.helpers.RowShifter
    public void updateHyperlinks(FormulaShifter formulaShifter) {
        int sheetIndex = this.sheet.getWorkbook().getSheetIndex(this.sheet);
        for (Hyperlink hyperlink : this.sheet.getHyperlinkList()) {
            XSSFHyperlink xSSFHyperlink = (XSSFHyperlink) hyperlink;
            CellRangeAddress valueOf = CellRangeAddress.valueOf(xSSFHyperlink.getCellRef());
            CellRangeAddress shiftRange = shiftRange(formulaShifter, valueOf, sheetIndex);
            if (!(shiftRange == null || shiftRange == valueOf)) {
                xSSFHyperlink.setCellReference(shiftRange.formatAsString());
            }
        }
    }

    @Override // org.apache.poi.ss.usermodel.helpers.RowShifter
    public void updateNamedRanges(FormulaShifter formulaShifter) {
        Workbook workbook = this.sheet.getWorkbook();
        XSSFEvaluationWorkbook create = XSSFEvaluationWorkbook.create((XSSFWorkbook) workbook);
        for (Name name : workbook.getAllNames()) {
            String refersToFormula = name.getRefersToFormula();
            int sheetIndex = name.getSheetIndex();
            Ptg[] parse = FormulaParser.parse(refersToFormula, create, FormulaType.NAMEDRANGE, sheetIndex, -1);
            if (formulaShifter.adjustFormula(parse, sheetIndex)) {
                name.setRefersToFormula(FormulaRenderer.toFormulaString(create, parse));
            }
        }
    }

    @Override // org.apache.poi.ss.usermodel.helpers.RowShifter
    @Internal
    public void updateRowFormulas(Row row, FormulaShifter formulaShifter) {
        String shiftFormula;
        XSSFSheet xSSFSheet = (XSSFSheet) row.getSheet();
        Iterator it = row.iterator();
        while (it.hasNext()) {
            CTCell cTCell = ((XSSFCell) ((Cell) it.next())).getCTCell();
            if (cTCell.isSetF()) {
                CTCellFormula f2 = cTCell.getF();
                String stringValue = f2.getStringValue();
                if (stringValue.length() > 0 && (shiftFormula = shiftFormula(row, stringValue, formulaShifter)) != null) {
                    f2.setStringValue(shiftFormula);
                    if (f2.getT() == STCellFormulaType.SHARED) {
                        CTCellFormula sharedFormula = xSSFSheet.getSharedFormula((int) f2.getSi());
                        sharedFormula.setStringValue(shiftFormula);
                        updateRefInCTCellFormula(row, formulaShifter, sharedFormula);
                    }
                }
                updateRefInCTCellFormula(row, formulaShifter, f2);
            }
        }
    }
}
