package org.apache.poi.xwpf.usermodel;

import org.apache.poi.POIXMLDocumentPart;
import org.openxmlformats.schemas.wordprocessingml.x2006.main.CTSdtPr;
import org.openxmlformats.schemas.wordprocessingml.x2006.main.CTString;

public abstract class AbstractXWPFSDT implements ISDTContents {
    public final IBody part;
    public final String tag;
    public final String title;

    public AbstractXWPFSDT(CTSdtPr cTSdtPr, IBody iBody) {
        if (cTSdtPr == null) {
            this.title = "";
            this.tag = "";
        } else {
            CTString[] aliasArray = cTSdtPr.getAliasArray();
            if (aliasArray == null || aliasArray.length <= 0) {
                this.title = "";
            } else {
                this.title = aliasArray[0].getVal();
            }
            CTString[] tagArray = cTSdtPr.getTagArray();
            if (tagArray == null || tagArray.length <= 0) {
                this.tag = "";
            } else {
                this.tag = tagArray[0].getVal();
            }
        }
        this.part = iBody;
    }

    public IBody getBody() {
        return null;
    }

    public abstract ISDTContent getContent();

    public XWPFDocument getDocument() {
        return this.part.getXWPFDocument();
    }

    public BodyElementType getElementType() {
        return BodyElementType.CONTENTCONTROL;
    }

    public POIXMLDocumentPart getPart() {
        return this.part.getPart();
    }

    public BodyType getPartType() {
        return BodyType.CONTENTCONTROL;
    }

    public String getTag() {
        return this.tag;
    }

    public String getTitle() {
        return this.title;
    }
}
