package org.apache.poi.xwpf.usermodel;

import java.io.IOException;
import java.io.InputStream;
import java.util.Arrays;
import org.apache.poi.POIXMLDocumentPart;
import org.apache.poi.POIXMLException;
import org.apache.poi.POIXMLRelation;
import org.apache.poi.openxml4j.opc.OPCPackage;
import org.apache.poi.openxml4j.opc.PackagePart;
import org.apache.poi.util.IOUtils;

public class XWPFPictureData extends POIXMLDocumentPart {
    public static final POIXMLRelation[] RELATIONS;
    public Long checksum;

    static {
        POIXMLRelation[] pOIXMLRelationArr = new POIXMLRelation[13];
        RELATIONS = pOIXMLRelationArr;
        pOIXMLRelationArr[2] = XWPFRelation.IMAGE_EMF;
        RELATIONS[3] = XWPFRelation.IMAGE_WMF;
        RELATIONS[4] = XWPFRelation.IMAGE_PICT;
        RELATIONS[5] = XWPFRelation.IMAGE_JPEG;
        RELATIONS[6] = XWPFRelation.IMAGE_PNG;
        RELATIONS[7] = XWPFRelation.IMAGE_DIB;
        RELATIONS[8] = XWPFRelation.IMAGE_GIF;
        RELATIONS[9] = XWPFRelation.IMAGE_TIFF;
        RELATIONS[10] = XWPFRelation.IMAGE_EPS;
        RELATIONS[11] = XWPFRelation.IMAGE_BMP;
        RELATIONS[12] = XWPFRelation.IMAGE_WPG;
    }

    public XWPFPictureData() {
    }

    public boolean equals(Object obj) {
        if (obj == this) {
            return true;
        }
        if (obj == null || !(obj instanceof XWPFPictureData)) {
            return false;
        }
        XWPFPictureData xWPFPictureData = (XWPFPictureData) obj;
        PackagePart packagePart = xWPFPictureData.getPackagePart();
        PackagePart packagePart2 = getPackagePart();
        if ((packagePart != null && packagePart2 == null) || (packagePart == null && packagePart2 != null)) {
            return false;
        }
        if (packagePart2 != null) {
            OPCPackage oPCPackage = packagePart.getPackage();
            OPCPackage oPCPackage2 = packagePart2.getPackage();
            if ((oPCPackage != null && oPCPackage2 == null) || (oPCPackage == null && oPCPackage2 != null)) {
                return false;
            }
            if (oPCPackage2 != null && !oPCPackage2.equals(oPCPackage)) {
                return false;
            }
        }
        if (!getChecksum().equals(xWPFPictureData.getChecksum())) {
            return false;
        }
        return Arrays.equals(getData(), xWPFPictureData.getData());
    }

    public Long getChecksum() {
        if (this.checksum == null) {
            InputStream inputStream = null;
            try {
                inputStream = getPackagePart().getInputStream();
                byte[] byteArray = IOUtils.toByteArray(inputStream);
                IOUtils.closeQuietly(inputStream);
                this.checksum = Long.valueOf(IOUtils.calculateChecksum(byteArray));
            } catch (IOException e2) {
                throw new POIXMLException(e2);
            } catch (Throwable th) {
                IOUtils.closeQuietly(inputStream);
                throw th;
            }
        }
        return this.checksum;
    }

    public byte[] getData() {
        try {
            return IOUtils.toByteArray(getPackagePart().getInputStream());
        } catch (IOException e2) {
            throw new POIXMLException(e2);
        }
    }

    public String getFileName() {
        String name = getPackagePart().getPartName().getName();
        return name.substring(name.lastIndexOf(47) + 1);
    }

    public int getPictureType() {
        String contentType = getPackagePart().getContentType();
        int i2 = 0;
        while (true) {
            POIXMLRelation[] pOIXMLRelationArr = RELATIONS;
            if (i2 >= pOIXMLRelationArr.length) {
                return 0;
            }
            if (pOIXMLRelationArr[i2] != null && pOIXMLRelationArr[i2].getContentType().equals(contentType)) {
                return i2;
            }
            i2++;
        }
    }

    public int hashCode() {
        return getChecksum().hashCode();
    }

    @Override // org.apache.poi.POIXMLDocumentPart
    public void onDocumentRead() {
        super.onDocumentRead();
    }

    @Override // org.apache.poi.POIXMLDocumentPart
    public void prepareForCommit() {
    }

    public String suggestFileExtension() {
        return getPackagePart().getPartName().getExtension();
    }

    public XWPFPictureData(PackagePart packagePart) {
        super(packagePart);
    }
}
