package org.apache.poi.xwpf.usermodel;

import java.util.ArrayList;
import java.util.List;
import org.apache.xmlbeans.XmlCursor;
import org.apache.xmlbeans.XmlObject;
import org.openxmlformats.schemas.wordprocessingml.x2006.main.CTP;
import org.openxmlformats.schemas.wordprocessingml.x2006.main.CTR;
import org.openxmlformats.schemas.wordprocessingml.x2006.main.CTSdtBlock;
import org.openxmlformats.schemas.wordprocessingml.x2006.main.CTSdtContentBlock;
import org.openxmlformats.schemas.wordprocessingml.x2006.main.CTSdtContentRun;
import org.openxmlformats.schemas.wordprocessingml.x2006.main.CTTbl;

public class XWPFSDTContent implements ISDTContent {
    public List<ISDTContents> bodyElements = new ArrayList();
    public List<XWPFSDT> contentControls = new ArrayList();
    public List<XWPFParagraph> paragraphs = new ArrayList();
    public List<XWPFRun> runs = new ArrayList();
    public List<XWPFTable> tables = new ArrayList();

    public XWPFSDTContent(CTSdtContentRun cTSdtContentRun, IBody iBody, IRunBody iRunBody) {
        for (CTR ctr : cTSdtContentRun.getRArray()) {
            XWPFRun xWPFRun = new XWPFRun(ctr, iRunBody);
            this.runs.add(xWPFRun);
            this.bodyElements.add(xWPFRun);
        }
    }

    private void appendParagraph(XWPFParagraph xWPFParagraph, StringBuilder sb) {
        for (XWPFRun xWPFRun : xWPFParagraph.getRuns()) {
            sb.append(xWPFRun);
        }
    }

    private void appendTable(XWPFTable xWPFTable, StringBuilder sb) {
        for (XWPFTableRow xWPFTableRow : xWPFTable.getRows()) {
            List<ICell> tableICells = xWPFTableRow.getTableICells();
            for (int i2 = 0; i2 < tableICells.size(); i2++) {
                ICell iCell = tableICells.get(i2);
                if (iCell instanceof XWPFTableCell) {
                    sb.append(((XWPFTableCell) iCell).getTextRecursively());
                } else if (iCell instanceof XWPFSDTCell) {
                    sb.append(((XWPFSDTCell) iCell).getContent().getText());
                }
                if (i2 < tableICells.size() - 1) {
                    sb.append("\t");
                }
            }
            sb.append('\n');
        }
    }

    @Override // org.apache.poi.xwpf.usermodel.ISDTContent
    public String getText() {
        StringBuilder sb = new StringBuilder();
        boolean z = false;
        for (int i2 = 0; i2 < this.bodyElements.size(); i2++) {
            ISDTContents iSDTContents = this.bodyElements.get(i2);
            if (iSDTContents instanceof XWPFParagraph) {
                appendParagraph((XWPFParagraph) iSDTContents, sb);
            } else if (iSDTContents instanceof XWPFTable) {
                appendTable((XWPFTable) iSDTContents, sb);
            } else if (iSDTContents instanceof XWPFSDT) {
                sb.append(((XWPFSDT) iSDTContents).getContent().getText());
            } else {
                if (iSDTContents instanceof XWPFRun) {
                    sb.append((XWPFRun) iSDTContents);
                    z = false;
                }
                if (z && i2 < this.bodyElements.size() - 1) {
                    sb.append("\n");
                }
            }
            z = true;
            sb.append("\n");
        }
        return sb.toString();
    }

    @Override // org.apache.poi.xwpf.usermodel.ISDTContent
    public String toString() {
        return getText();
    }

    public XWPFSDTContent(CTSdtContentBlock cTSdtContentBlock, IBody iBody, IRunBody iRunBody) {
        XmlCursor newCursor = cTSdtContentBlock.newCursor();
        newCursor.selectPath("./*");
        while (newCursor.toNextSelection()) {
            XmlObject object = newCursor.getObject();
            if (object instanceof CTP) {
                XWPFParagraph xWPFParagraph = new XWPFParagraph((CTP) object, iBody);
                this.bodyElements.add(xWPFParagraph);
                this.paragraphs.add(xWPFParagraph);
            } else if (object instanceof CTTbl) {
                XWPFTable xWPFTable = new XWPFTable((CTTbl) object, iBody);
                this.bodyElements.add(xWPFTable);
                this.tables.add(xWPFTable);
            } else if (object instanceof CTSdtBlock) {
                XWPFSDT xwpfsdt = new XWPFSDT((CTSdtBlock) object, iBody);
                this.bodyElements.add(xwpfsdt);
                this.contentControls.add(xwpfsdt);
            } else if (object instanceof CTR) {
                XWPFRun xWPFRun = new XWPFRun((CTR) object, iRunBody);
                this.runs.add(xWPFRun);
                this.bodyElements.add(xWPFRun);
            }
        }
        newCursor.dispose();
    }
}
