package org.apache.poi.xwpf.usermodel;

import b.b.a.a.a;
import java.math.BigInteger;
import java.util.ArrayList;
import java.util.EnumMap;
import java.util.HashMap;
import java.util.List;
import org.apache.poi.POIXMLDocumentPart;
import org.apache.poi.util.Internal;
import org.openxmlformats.schemas.wordprocessingml.x2006.main.CTBorder;
import org.openxmlformats.schemas.wordprocessingml.x2006.main.CTP;
import org.openxmlformats.schemas.wordprocessingml.x2006.main.CTRow;
import org.openxmlformats.schemas.wordprocessingml.x2006.main.CTString;
import org.openxmlformats.schemas.wordprocessingml.x2006.main.CTTbl;
import org.openxmlformats.schemas.wordprocessingml.x2006.main.CTTblBorders;
import org.openxmlformats.schemas.wordprocessingml.x2006.main.CTTblCellMar;
import org.openxmlformats.schemas.wordprocessingml.x2006.main.CTTblPr;
import org.openxmlformats.schemas.wordprocessingml.x2006.main.CTTblWidth;
import org.openxmlformats.schemas.wordprocessingml.x2006.main.CTTc;
import org.openxmlformats.schemas.wordprocessingml.x2006.main.STBorder;
import org.openxmlformats.schemas.wordprocessingml.x2006.main.STTblWidth;

public class XWPFTable implements IBodyElement, ISDTContents {
    public static HashMap<Integer, XWPFBorderType> stBorderTypeMap;
    public static EnumMap<XWPFBorderType, STBorder.Enum> xwpfBorderTypeMap;
    public CTTbl ctTbl;
    public IBody part;
    public List<XWPFTableRow> tableRows;
    public StringBuffer text;

    public enum XWPFBorderType {
        NIL,
        NONE,
        SINGLE,
        THICK,
        DOUBLE,
        DOTTED,
        DASHED,
        DOT_DASH
    }

    static {
        EnumMap<XWPFBorderType, STBorder.Enum> enumMap = new EnumMap<>(XWPFBorderType.class);
        xwpfBorderTypeMap = enumMap;
        enumMap.put(XWPFBorderType.NIL, STBorder.Enum.forInt(1));
        xwpfBorderTypeMap.put(XWPFBorderType.NONE, STBorder.Enum.forInt(2));
        xwpfBorderTypeMap.put(XWPFBorderType.SINGLE, STBorder.Enum.forInt(3));
        xwpfBorderTypeMap.put(XWPFBorderType.THICK, STBorder.Enum.forInt(4));
        xwpfBorderTypeMap.put(XWPFBorderType.DOUBLE, STBorder.Enum.forInt(5));
        xwpfBorderTypeMap.put(XWPFBorderType.DOTTED, STBorder.Enum.forInt(6));
        xwpfBorderTypeMap.put(XWPFBorderType.DASHED, STBorder.Enum.forInt(7));
        xwpfBorderTypeMap.put(XWPFBorderType.DOT_DASH, STBorder.Enum.forInt(8));
        HashMap<Integer, XWPFBorderType> hashMap = new HashMap<>();
        stBorderTypeMap = hashMap;
        hashMap.put(1, XWPFBorderType.NIL);
        stBorderTypeMap.put(2, XWPFBorderType.NONE);
        stBorderTypeMap.put(3, XWPFBorderType.SINGLE);
        stBorderTypeMap.put(4, XWPFBorderType.THICK);
        stBorderTypeMap.put(5, XWPFBorderType.DOUBLE);
        stBorderTypeMap.put(6, XWPFBorderType.DOTTED);
        stBorderTypeMap.put(7, XWPFBorderType.DASHED);
        stBorderTypeMap.put(8, XWPFBorderType.DOT_DASH);
    }

    public XWPFTable(CTTbl cTTbl, IBody iBody, int i2, int i3) {
        this(cTTbl, iBody);
        for (int i4 = 0; i4 < i2; i4++) {
            XWPFTableRow createRow = getRow(i4) == null ? createRow() : getRow(i4);
            for (int i5 = 0; i5 < i3; i5++) {
                if (createRow.getCell(i5) == null) {
                    createRow.createCell();
                }
            }
        }
    }

    private void addColumn(XWPFTableRow xWPFTableRow, int i2) {
        if (i2 > 0) {
            for (int i3 = 0; i3 < i2; i3++) {
                xWPFTableRow.createCell();
            }
        }
    }

    private void createEmptyTable(CTTbl cTTbl) {
        cTTbl.addNewTr().addNewTc().addNewP();
        CTTblPr addNewTblPr = cTTbl.addNewTblPr();
        addNewTblPr.addNewTblW().setW(new BigInteger("0"));
        addNewTblPr.getTblW().setType(STTblWidth.AUTO);
        CTTblBorders addNewTblBorders = addNewTblPr.addNewTblBorders();
        addNewTblBorders.addNewBottom().setVal(STBorder.SINGLE);
        addNewTblBorders.addNewInsideH().setVal(STBorder.SINGLE);
        addNewTblBorders.addNewInsideV().setVal(STBorder.SINGLE);
        addNewTblBorders.addNewLeft().setVal(STBorder.SINGLE);
        addNewTblBorders.addNewRight().setVal(STBorder.SINGLE);
        addNewTblBorders.addNewTop().setVal(STBorder.SINGLE);
        getRows();
    }

    private CTTblPr getTrPr() {
        return this.ctTbl.getTblPr() != null ? this.ctTbl.getTblPr() : this.ctTbl.addNewTblPr();
    }

    public void addNewCol() {
        if (this.ctTbl.sizeOfTrArray() == 0) {
            createRow();
        }
        for (int i2 = 0; i2 < this.ctTbl.sizeOfTrArray(); i2++) {
            new XWPFTableRow(this.ctTbl.getTrArray(i2), this).createCell();
        }
    }

    public void addNewRowBetween(int i2, int i3) {
    }

    public void addRow(XWPFTableRow xWPFTableRow) {
        this.ctTbl.addNewTr();
        this.ctTbl.setTrArray(getNumberOfRows() - 1, xWPFTableRow.getCtRow());
        this.tableRows.add(xWPFTableRow);
    }

    public XWPFTableRow createRow() {
        int i2 = 0;
        if (this.ctTbl.sizeOfTrArray() > 0) {
            i2 = this.ctTbl.getTrArray(0).sizeOfTcArray();
        }
        XWPFTableRow xWPFTableRow = new XWPFTableRow(this.ctTbl.addNewTr(), this);
        addColumn(xWPFTableRow, i2);
        this.tableRows.add(xWPFTableRow);
        return xWPFTableRow;
    }

    @Override // org.apache.poi.xwpf.usermodel.IBodyElement
    public IBody getBody() {
        return this.part;
    }

    @Internal
    public CTTbl getCTTbl() {
        return this.ctTbl;
    }

    public int getCellMarginBottom() {
        CTTblWidth bottom;
        CTTblCellMar tblCellMar = getTrPr().getTblCellMar();
        if (tblCellMar == null || (bottom = tblCellMar.getBottom()) == null) {
            return 0;
        }
        return bottom.getW().intValue();
    }

    public int getCellMarginLeft() {
        CTTblWidth left;
        CTTblCellMar tblCellMar = getTrPr().getTblCellMar();
        if (tblCellMar == null || (left = tblCellMar.getLeft()) == null) {
            return 0;
        }
        return left.getW().intValue();
    }

    public int getCellMarginRight() {
        CTTblWidth right;
        CTTblCellMar tblCellMar = getTrPr().getTblCellMar();
        if (tblCellMar == null || (right = tblCellMar.getRight()) == null) {
            return 0;
        }
        return right.getW().intValue();
    }

    public int getCellMarginTop() {
        CTTblWidth top;
        CTTblCellMar tblCellMar = getTrPr().getTblCellMar();
        if (tblCellMar == null || (top = tblCellMar.getTop()) == null) {
            return 0;
        }
        return top.getW().intValue();
    }

    public int getColBandSize() {
        CTTblPr trPr = getTrPr();
        if (trPr.isSetTblStyleColBandSize()) {
            return trPr.getTblStyleColBandSize().getVal().intValue();
        }
        return 0;
    }

    @Override // org.apache.poi.xwpf.usermodel.IBodyElement
    public BodyElementType getElementType() {
        return BodyElementType.TABLE;
    }

    public String getInsideHBorderColor() {
        CTTblPr trPr = getTrPr();
        if (trPr.isSetTblBorders()) {
            CTTblBorders tblBorders = trPr.getTblBorders();
            if (tblBorders.isSetInsideH()) {
                return tblBorders.getInsideH().xgetColor().getStringValue();
            }
        }
        return null;
    }

    public int getInsideHBorderSize() {
        CTTblPr trPr = getTrPr();
        if (trPr.isSetTblBorders()) {
            CTTblBorders tblBorders = trPr.getTblBorders();
            if (tblBorders.isSetInsideH()) {
                return tblBorders.getInsideH().getSz().intValue();
            }
        }
        return -1;
    }

    public int getInsideHBorderSpace() {
        CTTblPr trPr = getTrPr();
        if (trPr.isSetTblBorders()) {
            CTTblBorders tblBorders = trPr.getTblBorders();
            if (tblBorders.isSetInsideH()) {
                return tblBorders.getInsideH().getSpace().intValue();
            }
        }
        return -1;
    }

    public XWPFBorderType getInsideHBorderType() {
        CTTblPr trPr = getTrPr();
        if (trPr.isSetTblBorders()) {
            CTTblBorders tblBorders = trPr.getTblBorders();
            if (tblBorders.isSetInsideH()) {
                return stBorderTypeMap.get(Integer.valueOf(tblBorders.getInsideH().getVal().intValue()));
            }
        }
        return null;
    }

    public String getInsideVBorderColor() {
        CTTblPr trPr = getTrPr();
        if (trPr.isSetTblBorders()) {
            CTTblBorders tblBorders = trPr.getTblBorders();
            if (tblBorders.isSetInsideV()) {
                return tblBorders.getInsideV().xgetColor().getStringValue();
            }
        }
        return null;
    }

    public int getInsideVBorderSize() {
        CTTblPr trPr = getTrPr();
        if (trPr.isSetTblBorders()) {
            CTTblBorders tblBorders = trPr.getTblBorders();
            if (tblBorders.isSetInsideV()) {
                return tblBorders.getInsideV().getSz().intValue();
            }
        }
        return -1;
    }

    public int getInsideVBorderSpace() {
        CTTblPr trPr = getTrPr();
        if (trPr.isSetTblBorders()) {
            CTTblBorders tblBorders = trPr.getTblBorders();
            if (tblBorders.isSetInsideV()) {
                return tblBorders.getInsideV().getSpace().intValue();
            }
        }
        return -1;
    }

    public XWPFBorderType getInsideVBorderType() {
        CTTblPr trPr = getTrPr();
        if (trPr.isSetTblBorders()) {
            CTTblBorders tblBorders = trPr.getTblBorders();
            if (tblBorders.isSetInsideV()) {
                return stBorderTypeMap.get(Integer.valueOf(tblBorders.getInsideV().getVal().intValue()));
            }
        }
        return null;
    }

    public int getNumberOfRows() {
        return this.ctTbl.sizeOfTrArray();
    }

    @Override // org.apache.poi.xwpf.usermodel.IBodyElement
    public POIXMLDocumentPart getPart() {
        IBody iBody = this.part;
        if (iBody != null) {
            return iBody.getPart();
        }
        return null;
    }

    @Override // org.apache.poi.xwpf.usermodel.IBodyElement
    public BodyType getPartType() {
        return this.part.getPartType();
    }

    public XWPFTableRow getRow(int i2) {
        if (i2 < 0 || i2 >= this.ctTbl.sizeOfTrArray()) {
            return null;
        }
        return getRows().get(i2);
    }

    public int getRowBandSize() {
        CTTblPr trPr = getTrPr();
        if (trPr.isSetTblStyleRowBandSize()) {
            return trPr.getTblStyleRowBandSize().getVal().intValue();
        }
        return 0;
    }

    public List<XWPFTableRow> getRows() {
        return this.tableRows;
    }

    public String getStyleID() {
        CTString tblStyle;
        CTTblPr tblPr = this.ctTbl.getTblPr();
        if (tblPr == null || (tblStyle = tblPr.getTblStyle()) == null) {
            return null;
        }
        return tblStyle.getVal();
    }

    public String getText() {
        return this.text.toString();
    }

    public int getWidth() {
        CTTblPr trPr = getTrPr();
        if (trPr.isSetTblW()) {
            return trPr.getTblW().getW().intValue();
        }
        return -1;
    }

    public XWPFTableRow insertNewTableRow(int i2) {
        if (i2 < 0 || i2 > this.tableRows.size()) {
            return null;
        }
        XWPFTableRow xWPFTableRow = new XWPFTableRow(this.ctTbl.insertNewTr(i2), this);
        this.tableRows.add(i2, xWPFTableRow);
        return xWPFTableRow;
    }

    public boolean removeRow(int i2) {
        if (i2 < 0 || i2 >= this.tableRows.size()) {
            return false;
        }
        if (this.ctTbl.sizeOfTrArray() > 0) {
            this.ctTbl.removeTr(i2);
        }
        this.tableRows.remove(i2);
        return true;
    }

    public void setCellMargins(int i2, int i3, int i4, int i5) {
        CTTblPr trPr = getTrPr();
        CTTblCellMar tblCellMar = trPr.isSetTblCellMar() ? trPr.getTblCellMar() : trPr.addNewTblCellMar();
        CTTblWidth left = tblCellMar.isSetLeft() ? tblCellMar.getLeft() : tblCellMar.addNewLeft();
        left.setType(STTblWidth.DXA);
        left.setW(BigInteger.valueOf((long) i3));
        CTTblWidth top = tblCellMar.isSetTop() ? tblCellMar.getTop() : tblCellMar.addNewTop();
        top.setType(STTblWidth.DXA);
        top.setW(BigInteger.valueOf((long) i2));
        CTTblWidth bottom = tblCellMar.isSetBottom() ? tblCellMar.getBottom() : tblCellMar.addNewBottom();
        bottom.setType(STTblWidth.DXA);
        bottom.setW(BigInteger.valueOf((long) i4));
        CTTblWidth right = tblCellMar.isSetRight() ? tblCellMar.getRight() : tblCellMar.addNewRight();
        right.setType(STTblWidth.DXA);
        right.setW(BigInteger.valueOf((long) i5));
    }

    public void setColBandSize(int i2) {
        CTTblPr trPr = getTrPr();
        (trPr.isSetTblStyleColBandSize() ? trPr.getTblStyleColBandSize() : trPr.addNewTblStyleColBandSize()).setVal(BigInteger.valueOf((long) i2));
    }

    public void setInsideHBorder(XWPFBorderType xWPFBorderType, int i2, int i3, String str) {
        CTTblPr trPr = getTrPr();
        CTTblBorders tblBorders = trPr.isSetTblBorders() ? trPr.getTblBorders() : trPr.addNewTblBorders();
        CTBorder insideH = tblBorders.isSetInsideH() ? tblBorders.getInsideH() : tblBorders.addNewInsideH();
        insideH.setVal(xwpfBorderTypeMap.get(xWPFBorderType));
        insideH.setSz(BigInteger.valueOf((long) i2));
        insideH.setSpace(BigInteger.valueOf((long) i3));
        insideH.setColor(str);
    }

    public void setInsideVBorder(XWPFBorderType xWPFBorderType, int i2, int i3, String str) {
        CTTblPr trPr = getTrPr();
        CTTblBorders tblBorders = trPr.isSetTblBorders() ? trPr.getTblBorders() : trPr.addNewTblBorders();
        CTBorder insideV = tblBorders.isSetInsideV() ? tblBorders.getInsideV() : tblBorders.addNewInsideV();
        insideV.setVal(xwpfBorderTypeMap.get(xWPFBorderType));
        insideV.setSz(BigInteger.valueOf((long) i2));
        insideV.setSpace(BigInteger.valueOf((long) i3));
        insideV.setColor(str);
    }

    public void setRowBandSize(int i2) {
        CTTblPr trPr = getTrPr();
        (trPr.isSetTblStyleRowBandSize() ? trPr.getTblStyleRowBandSize() : trPr.addNewTblStyleRowBandSize()).setVal(BigInteger.valueOf((long) i2));
    }

    public void setStyleID(String str) {
        CTTblPr trPr = getTrPr();
        CTString tblStyle = trPr.getTblStyle();
        if (tblStyle == null) {
            tblStyle = trPr.addNewTblStyle();
        }
        tblStyle.setVal(str);
    }

    public void setWidth(int i2) {
        CTTblPr trPr = getTrPr();
        (trPr.isSetTblW() ? trPr.getTblW() : trPr.addNewTblW()).setW(new BigInteger(a.c("", i2)));
    }

    public XWPFTableRow getRow(CTRow cTRow) {
        for (int i2 = 0; i2 < getRows().size(); i2++) {
            if (getRows().get(i2).getCtRow() == cTRow) {
                return getRow(i2);
            }
        }
        return null;
    }

    public boolean addRow(XWPFTableRow xWPFTableRow, int i2) {
        if (i2 < 0 || i2 > this.tableRows.size()) {
            return false;
        }
        this.ctTbl.insertNewTr(i2);
        this.ctTbl.setTrArray(i2, xWPFTableRow.getCtRow());
        this.tableRows.add(i2, xWPFTableRow);
        return true;
    }

    public XWPFTable(CTTbl cTTbl, IBody iBody) {
        this.text = new StringBuffer();
        this.part = iBody;
        this.ctTbl = cTTbl;
        this.tableRows = new ArrayList();
        if (cTTbl.sizeOfTrArray() == 0) {
            createEmptyTable(cTTbl);
        }
        CTRow[] trArray = cTTbl.getTrArray();
        for (CTRow cTRow : trArray) {
            StringBuilder sb = new StringBuilder();
            this.tableRows.add(new XWPFTableRow(cTRow, this));
            for (CTTc cTTc : cTRow.getTcArray()) {
                for (CTP ctp : cTTc.getPArray()) {
                    XWPFParagraph xWPFParagraph = new XWPFParagraph(ctp, iBody);
                    if (sb.length() > 0) {
                        sb.append('\t');
                    }
                    sb.append(xWPFParagraph.getText());
                }
            }
            if (sb.length() > 0) {
                this.text.append((CharSequence) sb);
                this.text.append('\n');
            }
        }
    }
}
