package org.apache.xerces.dom;

import java.io.ObjectInputStream;
import java.io.ObjectOutputStream;
import org.w3c.dom.Attr;
import org.w3c.dom.DOMException;
import org.w3c.dom.Element;
import org.w3c.dom.Node;
import org.w3c.dom.NodeList;
import org.w3c.dom.Text;
import org.w3c.dom.TypeInfo;

public class AttrImpl extends NodeImpl implements Attr, TypeInfo {
    public static final String DTD_URI = "http://www.w3.org/TR/REC-xml";
    public static final long serialVersionUID = 7277707688218972102L;
    public String name;
    public transient Object type;
    public Object value = null;

    public AttrImpl() {
    }

    public AttrImpl(CoreDocumentImpl coreDocumentImpl, String str) {
        super(coreDocumentImpl);
        this.name = str;
        isSpecified(true);
        hasStringValue(true);
    }

    private void readObject(ObjectInputStream objectInputStream) {
        objectInputStream.defaultReadObject();
        needsSyncChildren(false);
    }

    private void writeObject(ObjectOutputStream objectOutputStream) {
        if (needsSyncChildren()) {
            synchronizeChildren();
        }
        objectOutputStream.defaultWriteObject();
    }

    public void checkNormalizationAfterInsert(ChildNode childNode) {
        if (childNode.getNodeType() == 3) {
            ChildNode previousSibling = childNode.previousSibling();
            ChildNode childNode2 = childNode.nextSibling;
            if ((previousSibling == null || previousSibling.getNodeType() != 3) && (childNode2 == null || childNode2.getNodeType() != 3)) {
                return;
            }
        } else if (childNode.isNormalized()) {
            return;
        }
        isNormalized(false);
    }

    public void checkNormalizationAfterRemove(ChildNode childNode) {
        ChildNode childNode2;
        if (childNode != null && childNode.getNodeType() == 3 && (childNode2 = childNode.nextSibling) != null && childNode2.getNodeType() == 3) {
            isNormalized(false);
        }
    }

    @Override // org.apache.xerces.dom.NodeImpl, org.w3c.dom.Node
    public Node cloneNode(boolean z) {
        if (needsSyncChildren()) {
            synchronizeChildren();
        }
        AttrImpl attrImpl = (AttrImpl) super.cloneNode(z);
        if (!attrImpl.hasStringValue()) {
            attrImpl.value = null;
            for (Node node = (Node) this.value; node != null; node = node.getNextSibling()) {
                attrImpl.appendChild(node.cloneNode(true));
            }
        }
        attrImpl.isSpecified(true);
        return attrImpl;
    }

    @Override // org.apache.xerces.dom.NodeImpl, org.w3c.dom.Node
    public NodeList getChildNodes() {
        if (needsSyncChildren()) {
            synchronizeChildren();
        }
        return this;
    }

    public Element getElement() {
        return (Element) (isOwned() ? this.ownerNode : null);
    }

    @Override // org.apache.xerces.dom.NodeImpl, org.w3c.dom.Node
    public Node getFirstChild() {
        if (needsSyncChildren()) {
            synchronizeChildren();
        }
        makeChildNode();
        return (Node) this.value;
    }

    @Override // org.apache.xerces.dom.NodeImpl, org.w3c.dom.Node
    public Node getLastChild() {
        if (needsSyncChildren()) {
            synchronizeChildren();
        }
        return lastChild();
    }

    @Override // org.apache.xerces.dom.NodeImpl, org.w3c.dom.NodeList
    public int getLength() {
        if (hasStringValue()) {
            return 1;
        }
        int i2 = 0;
        for (ChildNode childNode = (ChildNode) this.value; childNode != null; childNode = childNode.nextSibling) {
            i2++;
        }
        return i2;
    }

    @Override // org.w3c.dom.Attr
    public String getName() {
        if (needsSyncData()) {
            synchronizeData();
        }
        return this.name;
    }

    @Override // org.apache.xerces.dom.NodeImpl, org.w3c.dom.Node
    public String getNodeName() {
        if (needsSyncData()) {
            synchronizeData();
        }
        return this.name;
    }

    @Override // org.apache.xerces.dom.NodeImpl, org.w3c.dom.Node
    public short getNodeType() {
        return 2;
    }

    @Override // org.apache.xerces.dom.NodeImpl, org.w3c.dom.Node
    public String getNodeValue() {
        return getValue();
    }

    @Override // org.w3c.dom.Attr
    public Element getOwnerElement() {
        return (Element) (isOwned() ? this.ownerNode : null);
    }

    @Override // org.w3c.dom.Attr
    public TypeInfo getSchemaTypeInfo() {
        return this;
    }

    @Override // org.w3c.dom.Attr
    public boolean getSpecified() {
        if (needsSyncData()) {
            synchronizeData();
        }
        return isSpecified();
    }

    @Override // org.w3c.dom.TypeInfo
    public String getTypeName() {
        return (String) this.type;
    }

    @Override // org.w3c.dom.TypeInfo
    public String getTypeNamespace() {
        if (this.type != null) {
            return "http://www.w3.org/TR/REC-xml";
        }
        return null;
    }

    @Override // org.w3c.dom.Attr
    public String getValue() {
        String str;
        if (needsSyncData()) {
            synchronizeData();
        }
        if (needsSyncChildren()) {
            synchronizeChildren();
        }
        if (this.value == null) {
            return "";
        }
        if (hasStringValue()) {
            return (String) this.value;
        }
        ChildNode childNode = (ChildNode) this.value;
        String entityRefValue = childNode.getNodeType() == 5 ? ((EntityReferenceImpl) childNode).getEntityRefValue() : childNode.getNodeValue();
        ChildNode childNode2 = childNode.nextSibling;
        if (childNode2 == null || entityRefValue == null) {
            return entityRefValue == null ? "" : entityRefValue;
        }
        StringBuffer stringBuffer = new StringBuffer(entityRefValue);
        while (childNode2 != null) {
            if (childNode2.getNodeType() == 5) {
                str = ((EntityReferenceImpl) childNode2).getEntityRefValue();
                if (str == null) {
                    return "";
                }
            } else {
                str = childNode2.getNodeValue();
            }
            stringBuffer.append(str);
            childNode2 = childNode2.nextSibling;
        }
        return stringBuffer.toString();
    }

    @Override // org.apache.xerces.dom.NodeImpl, org.w3c.dom.Node
    public boolean hasChildNodes() {
        if (needsSyncChildren()) {
            synchronizeChildren();
        }
        return this.value != null;
    }

    @Override // org.apache.xerces.dom.NodeImpl, org.w3c.dom.Node
    public Node insertBefore(Node node, Node node2) {
        return internalInsertBefore(node, node2, false);
    }

    public Node internalInsertBefore(Node node, Node node2, boolean z) {
        CoreDocumentImpl ownerDocument = ownerDocument();
        boolean z2 = ownerDocument.errorChecking;
        if (node.getNodeType() == 11) {
            if (z2) {
                for (Node firstChild = node.getFirstChild(); firstChild != null; firstChild = firstChild.getNextSibling()) {
                    if (!ownerDocument.isKidOK(this, firstChild)) {
                        throw new DOMException(3, DOMMessageFormatter.formatMessage(DOMMessageFormatter.DOM_DOMAIN, "HIERARCHY_REQUEST_ERR", null));
                    }
                }
            }
            while (node.hasChildNodes()) {
                insertBefore(node.getFirstChild(), node2);
            }
            return node;
        } else if (node == node2) {
            Node nextSibling = node2.getNextSibling();
            removeChild(node);
            insertBefore(node, nextSibling);
            return node;
        } else {
            if (needsSyncChildren()) {
                synchronizeChildren();
            }
            if (z2) {
                if (isReadOnly()) {
                    throw new DOMException(7, DOMMessageFormatter.formatMessage(DOMMessageFormatter.DOM_DOMAIN, "NO_MODIFICATION_ALLOWED_ERR", null));
                } else if (node.getOwnerDocument() != ownerDocument) {
                    throw new DOMException(4, DOMMessageFormatter.formatMessage(DOMMessageFormatter.DOM_DOMAIN, "WRONG_DOCUMENT_ERR", null));
                } else if (!ownerDocument.isKidOK(this, node)) {
                    throw new DOMException(3, DOMMessageFormatter.formatMessage(DOMMessageFormatter.DOM_DOMAIN, "HIERARCHY_REQUEST_ERR", null));
                } else if (node2 == null || node2.getParentNode() == this) {
                    NodeImpl nodeImpl = this;
                    boolean z3 = true;
                    while (z3 && nodeImpl != null) {
                        z3 = node != nodeImpl;
                        nodeImpl = nodeImpl.parentNode();
                    }
                    if (!z3) {
                        throw new DOMException(3, DOMMessageFormatter.formatMessage(DOMMessageFormatter.DOM_DOMAIN, "HIERARCHY_REQUEST_ERR", null));
                    }
                } else {
                    throw new DOMException(8, DOMMessageFormatter.formatMessage(DOMMessageFormatter.DOM_DOMAIN, "NOT_FOUND_ERR", null));
                }
            }
            makeChildNode();
            ownerDocument.insertingNode(this, z);
            ChildNode childNode = (ChildNode) node;
            NodeImpl parentNode = childNode.parentNode();
            if (parentNode != null) {
                parentNode.removeChild(childNode);
            }
            ChildNode childNode2 = (ChildNode) node2;
            childNode.ownerNode = this;
            childNode.isOwned(true);
            ChildNode childNode3 = (ChildNode) this.value;
            if (childNode3 == null) {
                this.value = childNode;
                childNode.isFirstChild(true);
                childNode.previousSibling = childNode;
            } else if (childNode2 == null) {
                ChildNode childNode4 = childNode3.previousSibling;
                childNode4.nextSibling = childNode;
                childNode.previousSibling = childNode4;
                childNode3.previousSibling = childNode;
            } else if (node2 == childNode3) {
                childNode3.isFirstChild(false);
                childNode.nextSibling = childNode3;
                childNode.previousSibling = childNode3.previousSibling;
                childNode3.previousSibling = childNode;
                this.value = childNode;
                childNode.isFirstChild(true);
            } else {
                ChildNode childNode5 = childNode2.previousSibling;
                childNode.nextSibling = childNode2;
                childNode5.nextSibling = childNode;
                childNode2.previousSibling = childNode;
                childNode.previousSibling = childNode5;
            }
            changed();
            ownerDocument.insertedNode(this, childNode, z);
            checkNormalizationAfterInsert(childNode);
            return node;
        }
    }

    public Node internalRemoveChild(Node node, boolean z) {
        ChildNode childNode;
        ChildNode childNode2;
        CoreDocumentImpl ownerDocument = ownerDocument();
        if (ownerDocument.errorChecking) {
            if (isReadOnly()) {
                throw new DOMException(7, DOMMessageFormatter.formatMessage(DOMMessageFormatter.DOM_DOMAIN, "NO_MODIFICATION_ALLOWED_ERR", null));
            } else if (!(node == null || node.getParentNode() == this)) {
                throw new DOMException(8, DOMMessageFormatter.formatMessage(DOMMessageFormatter.DOM_DOMAIN, "NOT_FOUND_ERR", null));
            }
        }
        ChildNode childNode3 = (ChildNode) node;
        ownerDocument.removingNode(this, childNode3, z);
        Object obj = this.value;
        if (childNode3 == obj) {
            childNode3.isFirstChild(false);
            ChildNode childNode4 = childNode3.nextSibling;
            this.value = childNode4;
            childNode2 = childNode4;
            if (childNode2 != null) {
                childNode2.isFirstChild(true);
                childNode = childNode3.previousSibling;
            }
            ChildNode previousSibling = childNode3.previousSibling();
            childNode3.ownerNode = ownerDocument;
            childNode3.isOwned(false);
            childNode3.nextSibling = null;
            childNode3.previousSibling = null;
            changed();
            ownerDocument.removedNode(this, z);
            checkNormalizationAfterRemove(previousSibling);
            return childNode3;
        }
        childNode = childNode3.previousSibling;
        ChildNode childNode5 = childNode3.nextSibling;
        childNode.nextSibling = childNode5;
        if (childNode5 == null) {
            childNode2 = (ChildNode) obj;
        } else {
            childNode5.previousSibling = childNode;
            ChildNode previousSibling2 = childNode3.previousSibling();
            childNode3.ownerNode = ownerDocument;
            childNode3.isOwned(false);
            childNode3.nextSibling = null;
            childNode3.previousSibling = null;
            changed();
            ownerDocument.removedNode(this, z);
            checkNormalizationAfterRemove(previousSibling2);
            return childNode3;
        }
        childNode2.previousSibling = childNode;
        ChildNode previousSibling22 = childNode3.previousSibling();
        childNode3.ownerNode = ownerDocument;
        childNode3.isOwned(false);
        childNode3.nextSibling = null;
        childNode3.previousSibling = null;
        changed();
        ownerDocument.removedNode(this, z);
        checkNormalizationAfterRemove(previousSibling22);
        return childNode3;
    }

    @Override // org.w3c.dom.TypeInfo
    public boolean isDerivedFrom(String str, String str2, int i2) {
        return false;
    }

    @Override // org.apache.xerces.dom.NodeImpl, org.w3c.dom.Node
    public boolean isEqualNode(Node node) {
        return super.isEqualNode(node);
    }

    @Override // org.w3c.dom.Attr
    public boolean isId() {
        return isIdAttribute();
    }

    @Override // org.apache.xerces.dom.NodeImpl, org.w3c.dom.NodeList
    public Node item(int i2) {
        if (hasStringValue()) {
            if (i2 != 0 || this.value == null) {
                return null;
            }
            makeChildNode();
            return (Node) this.value;
        } else if (i2 < 0) {
            return null;
        } else {
            ChildNode childNode = (ChildNode) this.value;
            for (int i3 = 0; i3 < i2 && childNode != null; i3++) {
                childNode = childNode.nextSibling;
            }
            return childNode;
        }
    }

    public final ChildNode lastChild() {
        makeChildNode();
        Object obj = this.value;
        if (obj != null) {
            return ((ChildNode) obj).previousSibling;
        }
        return null;
    }

    public final void lastChild(ChildNode childNode) {
        Object obj = this.value;
        if (obj != null) {
            ((ChildNode) obj).previousSibling = childNode;
        }
    }

    public void makeChildNode() {
        if (hasStringValue()) {
            if (this.value != null) {
                TextImpl textImpl = (TextImpl) ownerDocument().createTextNode((String) this.value);
                this.value = textImpl;
                textImpl.isFirstChild(true);
                textImpl.previousSibling = textImpl;
                textImpl.ownerNode = this;
                textImpl.isOwned(true);
            }
            hasStringValue(false);
        }
    }

    @Override // org.apache.xerces.dom.NodeImpl, org.w3c.dom.Node
    public void normalize() {
        if (!isNormalized() && !hasStringValue()) {
            Node node = (ChildNode) this.value;
            while (node != null) {
                Node nextSibling = node.getNextSibling();
                if (node.getNodeType() == 3) {
                    if (nextSibling != null && nextSibling.getNodeType() == 3) {
                        ((Text) node).appendData(nextSibling.getNodeValue());
                        removeChild(nextSibling);
                    } else if (node.getNodeValue() == null || node.getNodeValue().length() == 0) {
                        removeChild(node);
                    }
                }
                node = nextSibling;
            }
            isNormalized(true);
        }
    }

    @Override // org.apache.xerces.dom.NodeImpl, org.w3c.dom.Node
    public Node removeChild(Node node) {
        if (!hasStringValue()) {
            return internalRemoveChild(node, false);
        }
        throw new DOMException(8, DOMMessageFormatter.formatMessage(DOMMessageFormatter.DOM_DOMAIN, "NOT_FOUND_ERR", null));
    }

    public void rename(String str) {
        if (needsSyncData()) {
            synchronizeData();
        }
        this.name = str;
    }

    @Override // org.apache.xerces.dom.NodeImpl, org.w3c.dom.Node
    public Node replaceChild(Node node, Node node2) {
        makeChildNode();
        CoreDocumentImpl ownerDocument = ownerDocument();
        ownerDocument.replacingNode(this);
        internalInsertBefore(node, node2, true);
        if (node != node2) {
            internalRemoveChild(node2, true);
        }
        ownerDocument.replacedNode(this);
        return node2;
    }

    public void setIdAttribute(boolean z) {
        if (needsSyncData()) {
            synchronizeData();
        }
        isIdAttribute(z);
    }

    @Override // org.apache.xerces.dom.NodeImpl, org.w3c.dom.Node
    public void setNodeValue(String str) {
        setValue(str);
    }

    @Override // org.apache.xerces.dom.NodeImpl
    public void setOwnerDocument(CoreDocumentImpl coreDocumentImpl) {
        if (needsSyncChildren()) {
            synchronizeChildren();
        }
        super.setOwnerDocument(coreDocumentImpl);
        if (!hasStringValue()) {
            for (ChildNode childNode = (ChildNode) this.value; childNode != null; childNode = childNode.nextSibling) {
                childNode.setOwnerDocument(coreDocumentImpl);
            }
        }
    }

    @Override // org.apache.xerces.dom.NodeImpl
    public void setReadOnly(boolean z, boolean z2) {
        super.setReadOnly(z, z2);
        if (z2) {
            if (needsSyncChildren()) {
                synchronizeChildren();
            }
            if (!hasStringValue()) {
                for (ChildNode childNode = (ChildNode) this.value; childNode != null; childNode = childNode.nextSibling) {
                    if (childNode.getNodeType() != 5) {
                        childNode.setReadOnly(z, true);
                    }
                }
            }
        }
    }

    public void setSpecified(boolean z) {
        if (needsSyncData()) {
            synchronizeData();
        }
        isSpecified(z);
    }

    public void setType(Object obj) {
        this.type = obj;
    }

    @Override // org.w3c.dom.Attr
    public void setValue(String str) {
        String str2;
        TextImpl textImpl;
        String str3;
        CoreDocumentImpl ownerDocument = ownerDocument();
        if (!ownerDocument.errorChecking || !isReadOnly()) {
            Element ownerElement = getOwnerElement();
            if (needsSyncData()) {
                synchronizeData();
            }
            if (needsSyncChildren()) {
                synchronizeChildren();
            }
            if (this.value != null) {
                if (!ownerDocument.getMutationEvents()) {
                    if (hasStringValue()) {
                        str3 = (String) this.value;
                    } else {
                        str3 = getValue();
                        ChildNode childNode = (ChildNode) this.value;
                        childNode.previousSibling = null;
                        childNode.isFirstChild(false);
                        childNode.ownerNode = ownerDocument;
                    }
                    str2 = str3;
                    this.value = null;
                    needsSyncChildren(false);
                } else if (hasStringValue()) {
                    Object obj = this.value;
                    str2 = (String) obj;
                    textImpl = (TextImpl) ownerDocument.createTextNode((String) obj);
                    this.value = textImpl;
                    textImpl.isFirstChild(true);
                    textImpl.previousSibling = textImpl;
                    textImpl.ownerNode = this;
                    textImpl.isOwned(true);
                    hasStringValue(false);
                    internalRemoveChild(textImpl, true);
                    if (isIdAttribute() && ownerElement != null) {
                        ownerDocument.removeIdentifier(str2);
                    }
                } else {
                    str2 = getValue();
                    while (true) {
                        Object obj2 = this.value;
                        if (obj2 == null) {
                            break;
                        }
                        internalRemoveChild((Node) obj2, true);
                    }
                }
                textImpl = null;
                ownerDocument.removeIdentifier(str2);
            } else {
                str2 = "";
                textImpl = null;
            }
            isSpecified(true);
            if (ownerDocument.getMutationEvents()) {
                if (textImpl == null) {
                    textImpl = (TextImpl) ownerDocument.createTextNode(str);
                } else {
                    textImpl.data = str;
                }
                internalInsertBefore(textImpl, null, true);
                hasStringValue(false);
                ownerDocument.modifiedAttrValue(this, str2);
            } else {
                this.value = str;
                hasStringValue(true);
                changed();
            }
            if (isIdAttribute() && ownerElement != null) {
                ownerDocument.putIdentifier(str, ownerElement);
                return;
            }
            return;
        }
        throw new DOMException(7, DOMMessageFormatter.formatMessage(DOMMessageFormatter.DOM_DOMAIN, "NO_MODIFICATION_ALLOWED_ERR", null));
    }

    public void synchronizeChildren() {
        needsSyncChildren(false);
    }

    @Override // org.apache.xerces.dom.NodeImpl
    public String toString() {
        StringBuffer stringBuffer = new StringBuffer();
        stringBuffer.append(getName());
        stringBuffer.append("=");
        stringBuffer.append("\"");
        stringBuffer.append(getValue());
        stringBuffer.append("\"");
        return stringBuffer.toString();
    }
}
