package org.apache.xerces.dom;

import java.util.ArrayList;
import java.util.List;
import org.w3c.dom.DOMException;
import org.w3c.dom.Node;

public class AttributeMap extends NamedNodeMapImpl {
    public static final long serialVersionUID = 8872606282138665383L;

    public AttributeMap(ElementImpl elementImpl, NamedNodeMapImpl namedNodeMapImpl) {
        super(elementImpl);
        if (namedNodeMapImpl != null) {
            cloneContent(namedNodeMapImpl);
            if (this.nodes != null) {
                hasDefaults(true);
            }
        }
    }

    private final Node remove(AttrImpl attrImpl, int i2, boolean z) {
        NamedNodeMapImpl defaultAttributes;
        Node namedItem;
        CoreDocumentImpl ownerDocument = this.ownerNode.ownerDocument();
        String nodeName = attrImpl.getNodeName();
        if (attrImpl.isIdAttribute()) {
            ownerDocument.removeIdentifier(attrImpl.getValue());
        }
        if (!hasDefaults() || !z || (defaultAttributes = ((ElementImpl) this.ownerNode).getDefaultAttributes()) == null || (namedItem = defaultAttributes.getNamedItem(nodeName)) == null || findNamePoint(nodeName, i2 + 1) >= 0) {
            this.nodes.remove(i2);
        } else {
            NodeImpl nodeImpl = (NodeImpl) namedItem.cloneNode(true);
            if (namedItem.getLocalName() != null) {
                ((AttrNSImpl) nodeImpl).namespaceURI = attrImpl.getNamespaceURI();
            }
            nodeImpl.ownerNode = this.ownerNode;
            nodeImpl.isOwned(true);
            nodeImpl.isSpecified(false);
            this.nodes.set(i2, nodeImpl);
            if (attrImpl.isIdAttribute()) {
                ownerDocument.putIdentifier(nodeImpl.getNodeValue(), (ElementImpl) this.ownerNode);
            }
        }
        attrImpl.ownerNode = ownerDocument;
        attrImpl.isOwned(false);
        attrImpl.isSpecified(true);
        attrImpl.isIdAttribute(false);
        ownerDocument.removedAttrNode(attrImpl, this.ownerNode, nodeName);
        return attrImpl;
    }

    @Override // org.apache.xerces.dom.NamedNodeMapImpl
    public final int addItem(Node node) {
        AttrImpl attrImpl = (AttrImpl) node;
        attrImpl.ownerNode = this.ownerNode;
        attrImpl.isOwned(true);
        int findNamePoint = findNamePoint(attrImpl.getNamespaceURI(), attrImpl.getLocalName());
        if (findNamePoint >= 0) {
            this.nodes.set(findNamePoint, node);
        } else {
            findNamePoint = findNamePoint(attrImpl.getNodeName(), 0);
            if (findNamePoint < 0) {
                findNamePoint = -1 - findNamePoint;
                if (this.nodes == null) {
                    this.nodes = new ArrayList(5);
                }
            }
            this.nodes.add(findNamePoint, node);
        }
        this.ownerNode.ownerDocument().setAttrNode(attrImpl, null);
        return findNamePoint;
    }

    @Override // org.apache.xerces.dom.NamedNodeMapImpl
    public void cloneContent(NamedNodeMapImpl namedNodeMapImpl) {
        int size;
        List list = namedNodeMapImpl.nodes;
        if (!(list == null || (size = list.size()) == 0)) {
            List list2 = this.nodes;
            if (list2 == null) {
                this.nodes = new ArrayList(size);
            } else {
                list2.clear();
            }
            for (int i2 = 0; i2 < size; i2++) {
                NodeImpl nodeImpl = (NodeImpl) list.get(i2);
                NodeImpl nodeImpl2 = (NodeImpl) nodeImpl.cloneNode(true);
                nodeImpl2.isSpecified(nodeImpl.isSpecified());
                this.nodes.add(nodeImpl2);
                nodeImpl2.ownerNode = this.ownerNode;
                nodeImpl2.isOwned(true);
            }
        }
    }

    @Override // org.apache.xerces.dom.NamedNodeMapImpl
    public NamedNodeMapImpl cloneMap(NodeImpl nodeImpl) {
        AttributeMap attributeMap = new AttributeMap((ElementImpl) nodeImpl, null);
        attributeMap.hasDefaults(hasDefaults());
        attributeMap.cloneContent(this);
        return attributeMap;
    }

    public final Node internalRemoveNamedItem(String str, boolean z) {
        if (!isReadOnly()) {
            int findNamePoint = findNamePoint(str, 0);
            if (findNamePoint >= 0) {
                return remove((AttrImpl) this.nodes.get(findNamePoint), findNamePoint, true);
            }
            if (!z) {
                return null;
            }
            throw new DOMException(8, DOMMessageFormatter.formatMessage(DOMMessageFormatter.DOM_DOMAIN, "NOT_FOUND_ERR", null));
        }
        throw new DOMException(7, DOMMessageFormatter.formatMessage(DOMMessageFormatter.DOM_DOMAIN, "NO_MODIFICATION_ALLOWED_ERR", null));
    }

    public final Node internalRemoveNamedItemNS(String str, String str2, boolean z) {
        NamedNodeMapImpl defaultAttributes;
        Node namedItem;
        int findNamePoint;
        CoreDocumentImpl ownerDocument = this.ownerNode.ownerDocument();
        if (!ownerDocument.errorChecking || !isReadOnly()) {
            int findNamePoint2 = findNamePoint(str, str2);
            if (findNamePoint2 >= 0) {
                AttrImpl attrImpl = (AttrImpl) this.nodes.get(findNamePoint2);
                if (attrImpl.isIdAttribute()) {
                    ownerDocument.removeIdentifier(attrImpl.getValue());
                }
                String nodeName = attrImpl.getNodeName();
                if (!hasDefaults() || (defaultAttributes = ((ElementImpl) this.ownerNode).getDefaultAttributes()) == null || (namedItem = defaultAttributes.getNamedItem(nodeName)) == null || (findNamePoint = findNamePoint(nodeName, 0)) < 0 || findNamePoint(nodeName, findNamePoint + 1) >= 0) {
                    this.nodes.remove(findNamePoint2);
                } else {
                    NodeImpl nodeImpl = (NodeImpl) namedItem.cloneNode(true);
                    nodeImpl.ownerNode = this.ownerNode;
                    if (namedItem.getLocalName() != null) {
                        ((AttrNSImpl) nodeImpl).namespaceURI = str;
                    }
                    nodeImpl.isOwned(true);
                    nodeImpl.isSpecified(false);
                    this.nodes.set(findNamePoint2, nodeImpl);
                    if (nodeImpl.isIdAttribute()) {
                        ownerDocument.putIdentifier(nodeImpl.getNodeValue(), (ElementImpl) this.ownerNode);
                    }
                }
                attrImpl.ownerNode = ownerDocument;
                attrImpl.isOwned(false);
                attrImpl.isSpecified(true);
                attrImpl.isIdAttribute(false);
                ownerDocument.removedAttrNode(attrImpl, this.ownerNode, str2);
                return attrImpl;
            } else if (!z) {
                return null;
            } else {
                throw new DOMException(8, DOMMessageFormatter.formatMessage(DOMMessageFormatter.DOM_DOMAIN, "NOT_FOUND_ERR", null));
            }
        } else {
            throw new DOMException(7, DOMMessageFormatter.formatMessage(DOMMessageFormatter.DOM_DOMAIN, "NO_MODIFICATION_ALLOWED_ERR", null));
        }
    }

    public void moveSpecifiedAttributes(AttributeMap attributeMap) {
        List list = attributeMap.nodes;
        for (int size = (list != null ? list.size() : 0) - 1; size >= 0; size--) {
            AttrImpl attrImpl = (AttrImpl) attributeMap.nodes.get(size);
            if (attrImpl.isSpecified()) {
                attributeMap.remove(attrImpl, size, false);
                if (attrImpl.getLocalName() != null) {
                    setNamedItem(attrImpl);
                } else {
                    setNamedItemNS(attrImpl);
                }
            }
        }
    }

    public void reconcileDefaults(NamedNodeMapImpl namedNodeMapImpl) {
        List list = this.nodes;
        for (int size = (list != null ? list.size() : 0) - 1; size >= 0; size--) {
            AttrImpl attrImpl = (AttrImpl) this.nodes.get(size);
            if (!attrImpl.isSpecified()) {
                remove(attrImpl, size, false);
            }
        }
        if (namedNodeMapImpl != null) {
            List list2 = this.nodes;
            if (list2 == null || list2.size() == 0) {
                cloneContent(namedNodeMapImpl);
                return;
            }
            int size2 = namedNodeMapImpl.nodes.size();
            for (int i2 = 0; i2 < size2; i2++) {
                AttrImpl attrImpl2 = (AttrImpl) namedNodeMapImpl.nodes.get(i2);
                int findNamePoint = findNamePoint(attrImpl2.getNodeName(), 0);
                if (findNamePoint < 0) {
                    NodeImpl nodeImpl = (NodeImpl) attrImpl2.cloneNode(true);
                    nodeImpl.ownerNode = this.ownerNode;
                    nodeImpl.isOwned(true);
                    nodeImpl.isSpecified(false);
                    this.nodes.add(-1 - findNamePoint, nodeImpl);
                }
            }
        }
    }

    public Node removeItem(Node node, boolean z) {
        int i2;
        List list = this.nodes;
        if (list != null) {
            int size = list.size();
            i2 = 0;
            while (true) {
                if (i2 >= size) {
                    break;
                } else if (this.nodes.get(i2) == node) {
                    break;
                } else {
                    i2++;
                }
            }
        }
        i2 = -1;
        if (i2 >= 0) {
            return remove((AttrImpl) node, i2, z);
        }
        throw new DOMException(8, DOMMessageFormatter.formatMessage(DOMMessageFormatter.DOM_DOMAIN, "NOT_FOUND_ERR", null));
    }

    @Override // org.apache.xerces.dom.NamedNodeMapImpl, org.w3c.dom.NamedNodeMap
    public Node removeNamedItem(String str) {
        return internalRemoveNamedItem(str, true);
    }

    @Override // org.apache.xerces.dom.NamedNodeMapImpl, org.w3c.dom.NamedNodeMap
    public Node removeNamedItemNS(String str, String str2) {
        return internalRemoveNamedItemNS(str, str2, true);
    }

    public Node safeRemoveNamedItem(String str) {
        return internalRemoveNamedItem(str, false);
    }

    public Node safeRemoveNamedItemNS(String str, String str2) {
        return internalRemoveNamedItemNS(str, str2, false);
    }

    @Override // org.apache.xerces.dom.NamedNodeMapImpl, org.w3c.dom.NamedNodeMap
    public Node setNamedItem(Node node) {
        boolean z = this.ownerNode.ownerDocument().errorChecking;
        AttrImpl attrImpl = null;
        if (z) {
            if (isReadOnly()) {
                throw new DOMException(7, DOMMessageFormatter.formatMessage(DOMMessageFormatter.DOM_DOMAIN, "NO_MODIFICATION_ALLOWED_ERR", null));
            } else if (node.getOwnerDocument() != this.ownerNode.ownerDocument()) {
                throw new DOMException(4, DOMMessageFormatter.formatMessage(DOMMessageFormatter.DOM_DOMAIN, "WRONG_DOCUMENT_ERR", null));
            } else if (node.getNodeType() != 2) {
                throw new DOMException(3, DOMMessageFormatter.formatMessage(DOMMessageFormatter.DOM_DOMAIN, "HIERARCHY_REQUEST_ERR", null));
            }
        }
        AttrImpl attrImpl2 = (AttrImpl) node;
        if (!attrImpl2.isOwned()) {
            attrImpl2.ownerNode = this.ownerNode;
            attrImpl2.isOwned(true);
            int findNamePoint = findNamePoint(attrImpl2.getNodeName(), 0);
            if (findNamePoint >= 0) {
                attrImpl = (AttrImpl) this.nodes.get(findNamePoint);
                this.nodes.set(findNamePoint, node);
                attrImpl.ownerNode = this.ownerNode.ownerDocument();
                attrImpl.isOwned(false);
                attrImpl.isSpecified(true);
            } else {
                int i2 = -1 - findNamePoint;
                if (this.nodes == null) {
                    this.nodes = new ArrayList(5);
                }
                this.nodes.add(i2, node);
            }
            this.ownerNode.ownerDocument().setAttrNode(attrImpl2, attrImpl);
            if (!attrImpl2.isNormalized()) {
                this.ownerNode.isNormalized(false);
            }
            return attrImpl;
        } else if (!z || attrImpl2.getOwnerElement() == this.ownerNode) {
            return node;
        } else {
            throw new DOMException(10, DOMMessageFormatter.formatMessage(DOMMessageFormatter.DOM_DOMAIN, "INUSE_ATTRIBUTE_ERR", null));
        }
    }

    @Override // org.apache.xerces.dom.NamedNodeMapImpl, org.w3c.dom.NamedNodeMap
    public Node setNamedItemNS(Node node) {
        boolean z = this.ownerNode.ownerDocument().errorChecking;
        AttrImpl attrImpl = null;
        if (z) {
            if (isReadOnly()) {
                throw new DOMException(7, DOMMessageFormatter.formatMessage(DOMMessageFormatter.DOM_DOMAIN, "NO_MODIFICATION_ALLOWED_ERR", null));
            } else if (node.getOwnerDocument() != this.ownerNode.ownerDocument()) {
                throw new DOMException(4, DOMMessageFormatter.formatMessage(DOMMessageFormatter.DOM_DOMAIN, "WRONG_DOCUMENT_ERR", null));
            } else if (node.getNodeType() != 2) {
                throw new DOMException(3, DOMMessageFormatter.formatMessage(DOMMessageFormatter.DOM_DOMAIN, "HIERARCHY_REQUEST_ERR", null));
            }
        }
        AttrImpl attrImpl2 = (AttrImpl) node;
        if (!attrImpl2.isOwned()) {
            attrImpl2.ownerNode = this.ownerNode;
            attrImpl2.isOwned(true);
            int findNamePoint = findNamePoint(attrImpl2.getNamespaceURI(), attrImpl2.getLocalName());
            if (findNamePoint >= 0) {
                attrImpl = (AttrImpl) this.nodes.get(findNamePoint);
                this.nodes.set(findNamePoint, node);
                attrImpl.ownerNode = this.ownerNode.ownerDocument();
                attrImpl.isOwned(false);
                attrImpl.isSpecified(true);
            } else {
                int findNamePoint2 = findNamePoint(node.getNodeName(), 0);
                if (findNamePoint2 >= 0) {
                    attrImpl = (AttrImpl) this.nodes.get(findNamePoint2);
                } else {
                    findNamePoint2 = -1 - findNamePoint2;
                    if (this.nodes == null) {
                        this.nodes = new ArrayList(5);
                    }
                }
                this.nodes.add(findNamePoint2, node);
            }
            this.ownerNode.ownerDocument().setAttrNode(attrImpl2, attrImpl);
            if (!attrImpl2.isNormalized()) {
                this.ownerNode.isNormalized(false);
            }
            return attrImpl;
        } else if (!z || attrImpl2.getOwnerElement() == this.ownerNode) {
            return node;
        } else {
            throw new DOMException(10, DOMMessageFormatter.formatMessage(DOMMessageFormatter.DOM_DOMAIN, "INUSE_ATTRIBUTE_ERR", null));
        }
    }
}
