package org.apache.xerces.dom;

import org.w3c.dom.DOMException;
import org.w3c.dom.Node;
import org.w3c.dom.NodeList;

public abstract class CharacterDataImpl extends ChildNode {
    public static final long serialVersionUID = 7931170150428474230L;
    public static transient NodeList singletonNodeList = new NodeList() {
        /* class org.apache.xerces.dom.CharacterDataImpl.AnonymousClass1 */

        @Override // org.w3c.dom.NodeList
        public int getLength() {
            return 0;
        }

        @Override // org.w3c.dom.NodeList
        public Node item(int i2) {
            return null;
        }
    };
    public String data;

    public CharacterDataImpl() {
    }

    public CharacterDataImpl(CoreDocumentImpl coreDocumentImpl, String str) {
        super(coreDocumentImpl);
        this.data = str;
    }

    public void appendData(String str) {
        if (isReadOnly()) {
            throw new DOMException(7, DOMMessageFormatter.formatMessage(DOMMessageFormatter.DOM_DOMAIN, "NO_MODIFICATION_ALLOWED_ERR", null));
        } else if (str != null) {
            if (needsSyncData()) {
                synchronizeData();
            }
            StringBuffer stringBuffer = new StringBuffer();
            stringBuffer.append(this.data);
            stringBuffer.append(str);
            setNodeValue(stringBuffer.toString());
        }
    }

    public void deleteData(int i2, int i3) {
        internalDeleteData(i2, i3, false);
    }

    @Override // org.apache.xerces.dom.NodeImpl, org.w3c.dom.Node
    public NodeList getChildNodes() {
        return singletonNodeList;
    }

    public String getData() {
        if (needsSyncData()) {
            synchronizeData();
        }
        return this.data;
    }

    @Override // org.apache.xerces.dom.NodeImpl, org.w3c.dom.NodeList
    public int getLength() {
        if (needsSyncData()) {
            synchronizeData();
        }
        return this.data.length();
    }

    @Override // org.apache.xerces.dom.NodeImpl, org.w3c.dom.Node
    public String getNodeValue() {
        if (needsSyncData()) {
            synchronizeData();
        }
        return this.data;
    }

    public void insertData(int i2, String str) {
        internalInsertData(i2, str, false);
    }

    public void internalDeleteData(int i2, int i3, boolean z) {
        String str;
        CoreDocumentImpl ownerDocument = ownerDocument();
        if (ownerDocument.errorChecking) {
            if (isReadOnly()) {
                throw new DOMException(7, DOMMessageFormatter.formatMessage(DOMMessageFormatter.DOM_DOMAIN, "NO_MODIFICATION_ALLOWED_ERR", null));
            } else if (i3 < 0) {
                throw new DOMException(1, DOMMessageFormatter.formatMessage(DOMMessageFormatter.DOM_DOMAIN, "INDEX_SIZE_ERR", null));
            }
        }
        if (needsSyncData()) {
            synchronizeData();
        }
        int max = Math.max((this.data.length() - i3) - i2, 0);
        try {
            StringBuffer stringBuffer = new StringBuffer();
            stringBuffer.append(this.data.substring(0, i2));
            if (max > 0) {
                int i4 = i2 + i3;
                str = this.data.substring(i4, max + i4);
            } else {
                str = "";
            }
            stringBuffer.append(str);
            setNodeValueInternal(stringBuffer.toString(), z);
            ownerDocument.deletedText(this, i2, i3);
        } catch (StringIndexOutOfBoundsException unused) {
            throw new DOMException(1, DOMMessageFormatter.formatMessage(DOMMessageFormatter.DOM_DOMAIN, "INDEX_SIZE_ERR", null));
        }
    }

    public void internalInsertData(int i2, String str, boolean z) {
        CoreDocumentImpl ownerDocument = ownerDocument();
        if (!ownerDocument.errorChecking || !isReadOnly()) {
            if (needsSyncData()) {
                synchronizeData();
            }
            try {
                setNodeValueInternal(new StringBuffer(this.data).insert(i2, str).toString(), z);
                ownerDocument.insertedText(this, i2, str.length());
            } catch (StringIndexOutOfBoundsException unused) {
                throw new DOMException(1, DOMMessageFormatter.formatMessage(DOMMessageFormatter.DOM_DOMAIN, "INDEX_SIZE_ERR", null));
            }
        } else {
            throw new DOMException(7, DOMMessageFormatter.formatMessage(DOMMessageFormatter.DOM_DOMAIN, "NO_MODIFICATION_ALLOWED_ERR", null));
        }
    }

    public void replaceData(int i2, int i3, String str) {
        CoreDocumentImpl ownerDocument = ownerDocument();
        if (!ownerDocument.errorChecking || !isReadOnly()) {
            if (needsSyncData()) {
                synchronizeData();
            }
            ownerDocument.replacingData(this);
            String str2 = this.data;
            internalDeleteData(i2, i3, true);
            internalInsertData(i2, str, true);
            ownerDocument.replacedCharacterData(this, str2, this.data);
            return;
        }
        throw new DOMException(7, DOMMessageFormatter.formatMessage(DOMMessageFormatter.DOM_DOMAIN, "NO_MODIFICATION_ALLOWED_ERR", null));
    }

    public void setData(String str) {
        setNodeValue(str);
    }

    @Override // org.apache.xerces.dom.NodeImpl, org.w3c.dom.Node
    public void setNodeValue(String str) {
        setNodeValueInternal(str);
        ownerDocument().replacedText(this);
    }

    public void setNodeValueInternal(String str) {
        setNodeValueInternal(str, false);
    }

    public void setNodeValueInternal(String str, boolean z) {
        CoreDocumentImpl ownerDocument = ownerDocument();
        if (!ownerDocument.errorChecking || !isReadOnly()) {
            if (needsSyncData()) {
                synchronizeData();
            }
            String str2 = this.data;
            ownerDocument.modifyingCharacterData(this, z);
            this.data = str;
            ownerDocument.modifiedCharacterData(this, str2, str, z);
            return;
        }
        throw new DOMException(7, DOMMessageFormatter.formatMessage(DOMMessageFormatter.DOM_DOMAIN, "NO_MODIFICATION_ALLOWED_ERR", null));
    }

    public String substringData(int i2, int i3) {
        if (needsSyncData()) {
            synchronizeData();
        }
        int length = this.data.length();
        if (i3 < 0 || i2 < 0 || i2 > length - 1) {
            throw new DOMException(1, DOMMessageFormatter.formatMessage(DOMMessageFormatter.DOM_DOMAIN, "INDEX_SIZE_ERR", null));
        }
        return this.data.substring(i2, Math.min(i3 + i2, length));
    }
}
