package org.apache.xerces.dom;

import i.a.c.a.b;
import java.lang.ref.SoftReference;
import org.apache.xerces.impl.RevalidationHandler;
import org.apache.xerces.impl.dtd.XMLDTDLoader;
import org.apache.xerces.parsers.DOMParserImpl;
import org.apache.xerces.util.XMLChar;
import org.w3c.dom.DOMException;
import org.w3c.dom.DOMImplementation;
import org.w3c.dom.Document;
import org.w3c.dom.DocumentType;
import org.w3c.dom.ls.DOMImplementationLS;
import org.w3c.dom.ls.LSInput;
import org.w3c.dom.ls.LSOutput;
import org.w3c.dom.ls.LSParser;
import org.w3c.dom.ls.LSSerializer;

public class CoreDOMImplementationImpl implements DOMImplementation, DOMImplementationLS {
    public static final int SIZE = 2;
    public static final CoreDOMImplementationImpl singleton = new CoreDOMImplementationImpl();
    public int docAndDoctypeCounter = 0;
    public int freeSchemaValidatorIndex = -1;
    public int freeXML10DTDLoaderIndex = -1;
    public int freeXML10DTDValidatorIndex = -1;
    public int freeXML11DTDLoaderIndex = -1;
    public int freeXML11DTDValidatorIndex = -1;
    public SoftReference[] schemaValidators = new SoftReference[2];
    public int schemaValidatorsCurrentSize = 2;
    public int xml10DTDLoaderCurrentSize = 2;
    public SoftReference[] xml10DTDLoaders = new SoftReference[2];
    public SoftReference[] xml10DTDValidators = new SoftReference[2];
    public int xml10DTDValidatorsCurrentSize = 2;
    public int xml11DTDLoaderCurrentSize = 2;
    public SoftReference[] xml11DTDLoaders = new SoftReference[2];
    public SoftReference[] xml11DTDValidators = new SoftReference[2];
    public int xml11DTDValidatorsCurrentSize = 2;

    public static final class RevalidationHandlerHolder {
        public RevalidationHandler handler;

        public RevalidationHandlerHolder(RevalidationHandler revalidationHandler) {
            this.handler = revalidationHandler;
        }
    }

    public static final class XMLDTDLoaderHolder {
        public XMLDTDLoader loader;

        public XMLDTDLoaderHolder(XMLDTDLoader xMLDTDLoader) {
            this.loader = xMLDTDLoader;
        }
    }

    public static DOMImplementation getDOMImplementation() {
        return singleton;
    }

    public synchronized int assignDocTypeNumber() {
        int i2;
        i2 = this.docAndDoctypeCounter + 1;
        this.docAndDoctypeCounter = i2;
        return i2;
    }

    public synchronized int assignDocumentNumber() {
        int i2;
        i2 = this.docAndDoctypeCounter + 1;
        this.docAndDoctypeCounter = i2;
        return i2;
    }

    public final void checkQName(String str) {
        int indexOf = str.indexOf(58);
        int lastIndexOf = str.lastIndexOf(58);
        int length = str.length();
        if (indexOf == 0 || indexOf == length - 1 || lastIndexOf != indexOf) {
            throw new DOMException(14, DOMMessageFormatter.formatMessage(DOMMessageFormatter.DOM_DOMAIN, "NAMESPACE_ERR", null));
        }
        int i2 = 0;
        if (indexOf > 0) {
            if (XMLChar.isNCNameStart(str.charAt(0))) {
                for (int i3 = 1; i3 < indexOf; i3++) {
                    if (!XMLChar.isNCName(str.charAt(i3))) {
                        throw new DOMException(5, DOMMessageFormatter.formatMessage(DOMMessageFormatter.DOM_DOMAIN, "INVALID_CHARACTER_ERR", null));
                    }
                }
                i2 = indexOf + 1;
            } else {
                throw new DOMException(5, DOMMessageFormatter.formatMessage(DOMMessageFormatter.DOM_DOMAIN, "INVALID_CHARACTER_ERR", null));
            }
        }
        if (XMLChar.isNCNameStart(str.charAt(i2))) {
            for (int i4 = i2 + 1; i4 < length; i4++) {
                if (!XMLChar.isNCName(str.charAt(i4))) {
                    throw new DOMException(5, DOMMessageFormatter.formatMessage(DOMMessageFormatter.DOM_DOMAIN, "INVALID_CHARACTER_ERR", null));
                }
            }
            return;
        }
        throw new DOMException(5, DOMMessageFormatter.formatMessage(DOMMessageFormatter.DOM_DOMAIN, "INVALID_CHARACTER_ERR", null));
    }

    public CoreDocumentImpl createDocument(DocumentType documentType) {
        return new CoreDocumentImpl(documentType);
    }

    @Override // org.w3c.dom.DOMImplementation
    public Document createDocument(String str, String str2, DocumentType documentType) {
        if (documentType == null || documentType.getOwnerDocument() == null) {
            CoreDocumentImpl createDocument = createDocument(documentType);
            if (!(str2 == null && str == null)) {
                createDocument.appendChild(createDocument.createElementNS(str, str2));
            }
            return createDocument;
        }
        throw new DOMException(4, DOMMessageFormatter.formatMessage(DOMMessageFormatter.DOM_DOMAIN, "WRONG_DOCUMENT_ERR", null));
    }

    @Override // org.w3c.dom.DOMImplementation
    public DocumentType createDocumentType(String str, String str2, String str3) {
        checkQName(str);
        return new DocumentTypeImpl(null, str, str2, str3);
    }

    @Override // org.w3c.dom.ls.DOMImplementationLS
    public LSInput createLSInput() {
        return new DOMInputImpl();
    }

    @Override // org.w3c.dom.ls.DOMImplementationLS
    public LSOutput createLSOutput() {
        return new DOMOutputImpl();
    }

    @Override // org.w3c.dom.ls.DOMImplementationLS
    public LSParser createLSParser(short s, String str) {
        if (s == 1 && (str == null || "http://www.w3.org/2001/XMLSchema".equals(str) || "http://www.w3.org/TR/REC-xml".equals(str))) {
            return (str == null || !str.equals("http://www.w3.org/TR/REC-xml")) ? new DOMParserImpl("org.apache.xerces.parsers.XIncludeAwareParserConfiguration", str) : new DOMParserImpl("org.apache.xerces.parsers.DTDConfiguration", str);
        }
        throw new DOMException(9, DOMMessageFormatter.formatMessage(DOMMessageFormatter.DOM_DOMAIN, "NOT_SUPPORTED_ERR", null));
    }

    @Override // org.w3c.dom.ls.DOMImplementationLS
    public LSSerializer createLSSerializer() {
        try {
            return (LSSerializer) ObjectFactory.findProviderClass("org.apache.xml.serializer.dom3.LSSerializerImpl", ObjectFactory.findClassLoader(), true).newInstance();
        } catch (Exception unused) {
            return new b();
        }
    }

    public final synchronized XMLDTDLoader getDTDLoader(String str) {
        if ("1.1".equals(str)) {
            while (this.freeXML11DTDLoaderIndex >= 0) {
                XMLDTDLoaderHolder xMLDTDLoaderHolder = (XMLDTDLoaderHolder) this.xml11DTDLoaders[this.freeXML11DTDLoaderIndex].get();
                if (xMLDTDLoaderHolder == null || xMLDTDLoaderHolder.loader == null) {
                    SoftReference[] softReferenceArr = this.xml11DTDLoaders;
                    int i2 = this.freeXML11DTDLoaderIndex;
                    this.freeXML11DTDLoaderIndex = i2 - 1;
                    softReferenceArr[i2] = null;
                } else {
                    XMLDTDLoader xMLDTDLoader = xMLDTDLoaderHolder.loader;
                    xMLDTDLoaderHolder.loader = null;
                    this.freeXML11DTDLoaderIndex--;
                    return xMLDTDLoader;
                }
            }
            return (XMLDTDLoader) ObjectFactory.newInstance("org.apache.xerces.impl.dtd.XML11DTDProcessor", ObjectFactory.findClassLoader(), true);
        }
        while (this.freeXML10DTDLoaderIndex >= 0) {
            XMLDTDLoaderHolder xMLDTDLoaderHolder2 = (XMLDTDLoaderHolder) this.xml10DTDLoaders[this.freeXML10DTDLoaderIndex].get();
            if (xMLDTDLoaderHolder2 == null || xMLDTDLoaderHolder2.loader == null) {
                SoftReference[] softReferenceArr2 = this.xml10DTDLoaders;
                int i3 = this.freeXML10DTDLoaderIndex;
                this.freeXML10DTDLoaderIndex = i3 - 1;
                softReferenceArr2[i3] = null;
            } else {
                XMLDTDLoader xMLDTDLoader2 = xMLDTDLoaderHolder2.loader;
                xMLDTDLoaderHolder2.loader = null;
                this.freeXML10DTDLoaderIndex--;
                return xMLDTDLoader2;
            }
        }
        return new XMLDTDLoader();
    }

    @Override // org.w3c.dom.DOMImplementation
    public Object getFeature(String str, String str2) {
        Class<?>[] interfaces;
        if (singleton.hasFeature(str, str2)) {
            if (!str.equalsIgnoreCase("+XPath")) {
                return singleton;
            }
            try {
                Class findProviderClass = ObjectFactory.findProviderClass("org.apache.xpath.domapi.XPathEvaluatorImpl", ObjectFactory.findClassLoader(), true);
                for (Class<?> cls : findProviderClass.getInterfaces()) {
                    if (cls.getName().equals("org.w3c.dom.xpath.XPathEvaluator")) {
                        return findProviderClass.newInstance();
                    }
                }
            } catch (Exception unused) {
                return null;
            }
        }
        return null;
    }

    public synchronized RevalidationHandler getValidator(String str, String str2) {
        if (str == "http://www.w3.org/2001/XMLSchema") {
            while (this.freeSchemaValidatorIndex >= 0) {
                RevalidationHandlerHolder revalidationHandlerHolder = (RevalidationHandlerHolder) this.schemaValidators[this.freeSchemaValidatorIndex].get();
                if (revalidationHandlerHolder == null || revalidationHandlerHolder.handler == null) {
                    SoftReference[] softReferenceArr = this.schemaValidators;
                    int i2 = this.freeSchemaValidatorIndex;
                    this.freeSchemaValidatorIndex = i2 - 1;
                    softReferenceArr[i2] = null;
                } else {
                    RevalidationHandler revalidationHandler = revalidationHandlerHolder.handler;
                    revalidationHandlerHolder.handler = null;
                    this.freeSchemaValidatorIndex--;
                    return revalidationHandler;
                }
            }
            return (RevalidationHandler) ObjectFactory.newInstance("org.apache.xerces.impl.xs.XMLSchemaValidator", ObjectFactory.findClassLoader(), true);
        } else if (str != "http://www.w3.org/TR/REC-xml") {
            return null;
        } else {
            if ("1.1".equals(str2)) {
                while (this.freeXML11DTDValidatorIndex >= 0) {
                    RevalidationHandlerHolder revalidationHandlerHolder2 = (RevalidationHandlerHolder) this.xml11DTDValidators[this.freeXML11DTDValidatorIndex].get();
                    if (revalidationHandlerHolder2 == null || revalidationHandlerHolder2.handler == null) {
                        SoftReference[] softReferenceArr2 = this.xml11DTDValidators;
                        int i3 = this.freeXML11DTDValidatorIndex;
                        this.freeXML11DTDValidatorIndex = i3 - 1;
                        softReferenceArr2[i3] = null;
                    } else {
                        RevalidationHandler revalidationHandler2 = revalidationHandlerHolder2.handler;
                        revalidationHandlerHolder2.handler = null;
                        this.freeXML11DTDValidatorIndex--;
                        return revalidationHandler2;
                    }
                }
                return (RevalidationHandler) ObjectFactory.newInstance("org.apache.xerces.impl.dtd.XML11DTDValidator", ObjectFactory.findClassLoader(), true);
            }
            while (this.freeXML10DTDValidatorIndex >= 0) {
                RevalidationHandlerHolder revalidationHandlerHolder3 = (RevalidationHandlerHolder) this.xml10DTDValidators[this.freeXML10DTDValidatorIndex].get();
                if (revalidationHandlerHolder3 == null || revalidationHandlerHolder3.handler == null) {
                    SoftReference[] softReferenceArr3 = this.xml10DTDValidators;
                    int i4 = this.freeXML10DTDValidatorIndex;
                    this.freeXML10DTDValidatorIndex = i4 - 1;
                    softReferenceArr3[i4] = null;
                } else {
                    RevalidationHandler revalidationHandler3 = revalidationHandlerHolder3.handler;
                    revalidationHandlerHolder3.handler = null;
                    this.freeXML10DTDValidatorIndex--;
                    return revalidationHandler3;
                }
            }
            return (RevalidationHandler) ObjectFactory.newInstance("org.apache.xerces.impl.dtd.XMLDTDValidator", ObjectFactory.findClassLoader(), true);
        }
    }

    @Override // org.w3c.dom.DOMImplementation
    public boolean hasFeature(String str, String str2) {
        boolean z = str2 == null || str2.length() == 0;
        if (!str.equalsIgnoreCase("+XPath") || (!z && !str2.equals("3.0"))) {
            if (str.startsWith("+")) {
                str = str.substring(1);
            }
            if ((!str.equalsIgnoreCase("Core") || (!z && !str2.equals("1.0") && !str2.equals("2.0") && !str2.equals("3.0"))) && ((!str.equalsIgnoreCase("XML") || (!z && !str2.equals("1.0") && !str2.equals("2.0") && !str2.equals("3.0"))) && ((!str.equalsIgnoreCase("XMLVersion") || (!z && !str2.equals("1.0") && !str2.equals("1.1"))) && (!str.equalsIgnoreCase("LS") || (!z && !str2.equals("3.0")))))) {
                if (str.equalsIgnoreCase("ElementTraversal")) {
                    return z || str2.equals("1.0");
                }
                return false;
            }
        }
        try {
            Class<?>[] interfaces = ObjectFactory.findProviderClass("org.apache.xpath.domapi.XPathEvaluatorImpl", ObjectFactory.findClassLoader(), true).getInterfaces();
            int i2 = 0;
            while (i2 < interfaces.length && !interfaces[i2].getName().equals("org.w3c.dom.xpath.XPathEvaluator")) {
                i2++;
            }
            return true;
        } catch (Exception unused) {
            return false;
        }
    }

    public final synchronized void releaseDTDLoader(String str, XMLDTDLoader xMLDTDLoader) {
        XMLDTDLoaderHolder xMLDTDLoaderHolder;
        XMLDTDLoaderHolder xMLDTDLoaderHolder2;
        if ("1.1".equals(str)) {
            int i2 = this.freeXML11DTDLoaderIndex + 1;
            this.freeXML11DTDLoaderIndex = i2;
            if (this.xml11DTDLoaders.length == i2) {
                int i3 = this.xml11DTDLoaderCurrentSize + 2;
                this.xml11DTDLoaderCurrentSize = i3;
                SoftReference[] softReferenceArr = new SoftReference[i3];
                System.arraycopy(this.xml11DTDLoaders, 0, softReferenceArr, 0, this.xml11DTDLoaders.length);
                this.xml11DTDLoaders = softReferenceArr;
            }
            SoftReference softReference = this.xml11DTDLoaders[this.freeXML11DTDLoaderIndex];
            if (softReference == null || (xMLDTDLoaderHolder2 = (XMLDTDLoaderHolder) softReference.get()) == null) {
                this.xml11DTDLoaders[this.freeXML11DTDLoaderIndex] = new SoftReference(new XMLDTDLoaderHolder(xMLDTDLoader));
            } else {
                xMLDTDLoaderHolder2.loader = xMLDTDLoader;
            }
        } else {
            int i4 = this.freeXML10DTDLoaderIndex + 1;
            this.freeXML10DTDLoaderIndex = i4;
            if (this.xml10DTDLoaders.length == i4) {
                int i5 = this.xml10DTDLoaderCurrentSize + 2;
                this.xml10DTDLoaderCurrentSize = i5;
                SoftReference[] softReferenceArr2 = new SoftReference[i5];
                System.arraycopy(this.xml10DTDLoaders, 0, softReferenceArr2, 0, this.xml10DTDLoaders.length);
                this.xml10DTDLoaders = softReferenceArr2;
            }
            SoftReference softReference2 = this.xml10DTDLoaders[this.freeXML10DTDLoaderIndex];
            if (softReference2 == null || (xMLDTDLoaderHolder = (XMLDTDLoaderHolder) softReference2.get()) == null) {
                this.xml10DTDLoaders[this.freeXML10DTDLoaderIndex] = new SoftReference(new XMLDTDLoaderHolder(xMLDTDLoader));
            } else {
                xMLDTDLoaderHolder.loader = xMLDTDLoader;
            }
        }
    }

    public synchronized void releaseValidator(String str, String str2, RevalidationHandler revalidationHandler) {
        RevalidationHandlerHolder revalidationHandlerHolder;
        RevalidationHandlerHolder revalidationHandlerHolder2;
        RevalidationHandlerHolder revalidationHandlerHolder3;
        if (str == "http://www.w3.org/2001/XMLSchema") {
            int i2 = this.freeSchemaValidatorIndex + 1;
            this.freeSchemaValidatorIndex = i2;
            if (this.schemaValidators.length == i2) {
                int i3 = this.schemaValidatorsCurrentSize + 2;
                this.schemaValidatorsCurrentSize = i3;
                SoftReference[] softReferenceArr = new SoftReference[i3];
                System.arraycopy(this.schemaValidators, 0, softReferenceArr, 0, this.schemaValidators.length);
                this.schemaValidators = softReferenceArr;
            }
            SoftReference softReference = this.schemaValidators[this.freeSchemaValidatorIndex];
            if (softReference == null || (revalidationHandlerHolder3 = (RevalidationHandlerHolder) softReference.get()) == null) {
                this.schemaValidators[this.freeSchemaValidatorIndex] = new SoftReference(new RevalidationHandlerHolder(revalidationHandler));
            } else {
                revalidationHandlerHolder3.handler = revalidationHandler;
            }
        } else if (str == "http://www.w3.org/TR/REC-xml") {
            if ("1.1".equals(str2)) {
                int i4 = this.freeXML11DTDValidatorIndex + 1;
                this.freeXML11DTDValidatorIndex = i4;
                if (this.xml11DTDValidators.length == i4) {
                    int i5 = this.xml11DTDValidatorsCurrentSize + 2;
                    this.xml11DTDValidatorsCurrentSize = i5;
                    SoftReference[] softReferenceArr2 = new SoftReference[i5];
                    System.arraycopy(this.xml11DTDValidators, 0, softReferenceArr2, 0, this.xml11DTDValidators.length);
                    this.xml11DTDValidators = softReferenceArr2;
                }
                SoftReference softReference2 = this.xml11DTDValidators[this.freeXML11DTDValidatorIndex];
                if (softReference2 == null || (revalidationHandlerHolder2 = (RevalidationHandlerHolder) softReference2.get()) == null) {
                    this.xml11DTDValidators[this.freeXML11DTDValidatorIndex] = new SoftReference(new RevalidationHandlerHolder(revalidationHandler));
                } else {
                    revalidationHandlerHolder2.handler = revalidationHandler;
                }
            } else {
                int i6 = this.freeXML10DTDValidatorIndex + 1;
                this.freeXML10DTDValidatorIndex = i6;
                if (this.xml10DTDValidators.length == i6) {
                    int i7 = this.xml10DTDValidatorsCurrentSize + 2;
                    this.xml10DTDValidatorsCurrentSize = i7;
                    SoftReference[] softReferenceArr3 = new SoftReference[i7];
                    System.arraycopy(this.xml10DTDValidators, 0, softReferenceArr3, 0, this.xml10DTDValidators.length);
                    this.xml10DTDValidators = softReferenceArr3;
                }
                SoftReference softReference3 = this.xml10DTDValidators[this.freeXML10DTDValidatorIndex];
                if (softReference3 == null || (revalidationHandlerHolder = (RevalidationHandlerHolder) softReference3.get()) == null) {
                    this.xml10DTDValidators[this.freeXML10DTDValidatorIndex] = new SoftReference(new RevalidationHandlerHolder(revalidationHandler));
                } else {
                    revalidationHandlerHolder.handler = revalidationHandler;
                }
            }
        }
    }
}
