package org.apache.xerces.dom;

import b.b.a.a.a;
import java.io.IOException;
import java.util.ArrayList;
import java.util.Vector;
import org.apache.xerces.impl.Constants;
import org.apache.xerces.impl.RevalidationHandler;
import org.apache.xerces.impl.dtd.XMLDTDLoader;
import org.apache.xerces.impl.dtd.XMLDTDValidator;
import org.apache.xerces.impl.dv.XSSimpleType;
import org.apache.xerces.impl.xs.SchemaSymbols;
import org.apache.xerces.impl.xs.util.SimpleLocator;
import org.apache.xerces.util.AugmentationsImpl;
import org.apache.xerces.util.NamespaceSupport;
import org.apache.xerces.util.SymbolTable;
import org.apache.xerces.util.XML11Char;
import org.apache.xerces.util.XMLChar;
import org.apache.xerces.util.XMLSymbols;
import org.apache.xerces.xni.Augmentations;
import org.apache.xerces.xni.NamespaceContext;
import org.apache.xerces.xni.QName;
import org.apache.xerces.xni.XMLAttributes;
import org.apache.xerces.xni.XMLDocumentHandler;
import org.apache.xerces.xni.XMLLocator;
import org.apache.xerces.xni.XMLResourceIdentifier;
import org.apache.xerces.xni.XMLString;
import org.apache.xerces.xni.parser.XMLComponent;
import org.apache.xerces.xni.parser.XMLDocumentSource;
import org.apache.xerces.xs.AttributePSVI;
import org.apache.xerces.xs.ElementPSVI;
import org.apache.xerces.xs.XSTypeDefinition;
import org.apache.xmlbeans.impl.common.Sax2Dom;
import org.w3c.dom.Attr;
import org.w3c.dom.Comment;
import org.w3c.dom.DOMErrorHandler;
import org.w3c.dom.Document;
import org.w3c.dom.DocumentType;
import org.w3c.dom.Element;
import org.w3c.dom.Entity;
import org.w3c.dom.NamedNodeMap;
import org.w3c.dom.Node;
import org.w3c.dom.NodeList;
import org.w3c.dom.ProcessingInstruction;
import org.w3c.dom.Text;

public class DOMNormalizer implements XMLDocumentHandler {
    public static final boolean DEBUG = false;
    public static final boolean DEBUG_EVENTS = false;
    public static final boolean DEBUG_ND = false;
    public static final XMLString EMPTY_STRING = new XMLString();
    public static final String PREFIX = "NS";
    public static final RuntimeException abort = new RuntimeException();
    public boolean fAllWhitespace = false;
    public final XMLAttributesProxy fAttrProxy = new XMLAttributesProxy();
    public final QName fAttrQName = new QName();
    public final ArrayList fAttributeList = new ArrayList(5);
    public DOMConfigurationImpl fConfiguration = null;
    public Node fCurrentNode = null;
    public CoreDocumentImpl fDocument = null;
    public final DOMErrorImpl fError = new DOMErrorImpl();
    public DOMErrorHandler fErrorHandler;
    public final NamespaceContext fLocalNSBinder = new NamespaceSupport();
    public final DOMLocatorImpl fLocator = new DOMLocatorImpl();
    public final NamespaceContext fNamespaceContext = new NamespaceSupport();
    public boolean fNamespaceValidation = false;
    public final XMLString fNormalizedValue = new XMLString(new char[16], 0, 0);
    public boolean fPSVI = false;
    public final QName fQName = new QName();
    public SymbolTable fSymbolTable;
    public RevalidationHandler fValidationHandler;

    public final class XMLAttributesProxy implements XMLAttributes {
        public AttributeMap fAttributes;
        public final Vector fAugmentations = new Vector(5);
        public final Vector fDTDTypes = new Vector(5);
        public CoreDocumentImpl fDocument;
        public ElementImpl fElement;

        public XMLAttributesProxy() {
        }

        private String getReportableType(String str) {
            return str.charAt(0) == '(' ? "NMTOKEN" : str;
        }

        @Override // org.apache.xerces.xni.XMLAttributes
        public int addAttribute(QName qName, String str, String str2) {
            int xercesAttribute = this.fElement.getXercesAttribute(qName.uri, qName.localpart);
            if (xercesAttribute >= 0) {
                return xercesAttribute;
            }
            AttrImpl attrImpl = (AttrImpl) ((CoreDocumentImpl) this.fElement.getOwnerDocument()).createAttributeNS(qName.uri, qName.rawname, qName.localpart);
            attrImpl.setNodeValue(str2);
            int xercesAttributeNode = this.fElement.setXercesAttributeNode(attrImpl);
            this.fDTDTypes.insertElementAt(str, xercesAttributeNode);
            this.fAugmentations.insertElementAt(new AugmentationsImpl(), xercesAttributeNode);
            attrImpl.setSpecified(false);
            return xercesAttributeNode;
        }

        @Override // org.apache.xerces.xni.XMLAttributes
        public Augmentations getAugmentations(int i2) {
            return (Augmentations) this.fAugmentations.elementAt(i2);
        }

        @Override // org.apache.xerces.xni.XMLAttributes
        public Augmentations getAugmentations(String str) {
            return null;
        }

        @Override // org.apache.xerces.xni.XMLAttributes
        public Augmentations getAugmentations(String str, String str2) {
            return null;
        }

        @Override // org.apache.xerces.xni.XMLAttributes
        public int getIndex(String str) {
            return -1;
        }

        @Override // org.apache.xerces.xni.XMLAttributes
        public int getIndex(String str, String str2) {
            return -1;
        }

        @Override // org.apache.xerces.xni.XMLAttributes
        public int getLength() {
            AttributeMap attributeMap = this.fAttributes;
            if (attributeMap != null) {
                return attributeMap.getLength();
            }
            return 0;
        }

        @Override // org.apache.xerces.xni.XMLAttributes
        public String getLocalName(int i2) {
            String localName;
            AttributeMap attributeMap = this.fAttributes;
            if (attributeMap == null || (localName = ((Node) attributeMap.getItem(i2)).getLocalName()) == null) {
                return null;
            }
            return DOMNormalizer.this.fSymbolTable.addSymbol(localName);
        }

        @Override // org.apache.xerces.xni.XMLAttributes
        public void getName(int i2, QName qName) {
            AttributeMap attributeMap = this.fAttributes;
            if (attributeMap != null) {
                DOMNormalizer.this.updateQName((Node) attributeMap.getItem(i2), qName);
            }
        }

        @Override // org.apache.xerces.xni.XMLAttributes
        public String getNonNormalizedValue(int i2) {
            return null;
        }

        @Override // org.apache.xerces.xni.XMLAttributes
        public String getPrefix(int i2) {
            String prefix;
            AttributeMap attributeMap = this.fAttributes;
            if (attributeMap == null || (prefix = ((Node) attributeMap.getItem(i2)).getPrefix()) == null || prefix.length() == 0) {
                return null;
            }
            return DOMNormalizer.this.fSymbolTable.addSymbol(prefix);
        }

        @Override // org.apache.xerces.xni.XMLAttributes
        public String getQName(int i2) {
            AttributeMap attributeMap = this.fAttributes;
            if (attributeMap != null) {
                return DOMNormalizer.this.fSymbolTable.addSymbol(((Node) attributeMap.getItem(i2)).getNodeName());
            }
            return null;
        }

        @Override // org.apache.xerces.xni.XMLAttributes
        public String getType(int i2) {
            String str = (String) this.fDTDTypes.elementAt(i2);
            return str != null ? getReportableType(str) : "CDATA";
        }

        @Override // org.apache.xerces.xni.XMLAttributes
        public String getType(String str) {
            return "CDATA";
        }

        @Override // org.apache.xerces.xni.XMLAttributes
        public String getType(String str, String str2) {
            return "CDATA";
        }

        @Override // org.apache.xerces.xni.XMLAttributes
        public String getURI(int i2) {
            String namespaceURI;
            AttributeMap attributeMap = this.fAttributes;
            if (attributeMap == null || (namespaceURI = ((Node) attributeMap.getItem(i2)).getNamespaceURI()) == null) {
                return null;
            }
            return DOMNormalizer.this.fSymbolTable.addSymbol(namespaceURI);
        }

        @Override // org.apache.xerces.xni.XMLAttributes
        public String getValue(int i2) {
            AttributeMap attributeMap = this.fAttributes;
            return attributeMap != null ? attributeMap.item(i2).getNodeValue() : "";
        }

        @Override // org.apache.xerces.xni.XMLAttributes
        public String getValue(String str) {
            return null;
        }

        @Override // org.apache.xerces.xni.XMLAttributes
        public String getValue(String str, String str2) {
            Node namedItemNS;
            AttributeMap attributeMap = this.fAttributes;
            if (attributeMap == null || (namedItemNS = attributeMap.getNamedItemNS(str, str2)) == null) {
                return null;
            }
            return namedItemNS.getNodeValue();
        }

        @Override // org.apache.xerces.xni.XMLAttributes
        public boolean isSpecified(int i2) {
            return ((Attr) this.fAttributes.getItem(i2)).getSpecified();
        }

        @Override // org.apache.xerces.xni.XMLAttributes
        public void removeAllAttributes() {
        }

        @Override // org.apache.xerces.xni.XMLAttributes
        public void removeAttributeAt(int i2) {
        }

        public void setAttributes(AttributeMap attributeMap, CoreDocumentImpl coreDocumentImpl, ElementImpl elementImpl) {
            this.fDocument = coreDocumentImpl;
            this.fAttributes = attributeMap;
            this.fElement = elementImpl;
            if (attributeMap != null) {
                int length = attributeMap.getLength();
                this.fDTDTypes.setSize(length);
                this.fAugmentations.setSize(length);
                for (int i2 = 0; i2 < length; i2++) {
                    this.fAugmentations.setElementAt(new AugmentationsImpl(), i2);
                }
                return;
            }
            this.fDTDTypes.setSize(0);
            this.fAugmentations.setSize(0);
        }

        @Override // org.apache.xerces.xni.XMLAttributes
        public void setAugmentations(int i2, Augmentations augmentations) {
            this.fAugmentations.setElementAt(augmentations, i2);
        }

        @Override // org.apache.xerces.xni.XMLAttributes
        public void setName(int i2, QName qName) {
        }

        @Override // org.apache.xerces.xni.XMLAttributes
        public void setNonNormalizedValue(int i2, String str) {
        }

        @Override // org.apache.xerces.xni.XMLAttributes
        public void setSpecified(int i2, boolean z) {
            ((AttrImpl) this.fAttributes.getItem(i2)).setSpecified(z);
        }

        @Override // org.apache.xerces.xni.XMLAttributes
        public void setType(int i2, String str) {
            this.fDTDTypes.setElementAt(str, i2);
        }

        @Override // org.apache.xerces.xni.XMLAttributes
        public void setValue(int i2, String str) {
            AttributeMap attributeMap = this.fAttributes;
            if (attributeMap != null) {
                AttrImpl attrImpl = (AttrImpl) attributeMap.getItem(i2);
                boolean specified = attrImpl.getSpecified();
                attrImpl.setValue(str);
                attrImpl.setSpecified(specified);
            }
        }
    }

    public static final void isAttrValueWF(DOMErrorHandler dOMErrorHandler, DOMErrorImpl dOMErrorImpl, DOMLocatorImpl dOMLocatorImpl, NamedNodeMap namedNodeMap, Attr attr, String str, boolean z) {
        DocumentType doctype;
        if (!(attr instanceof AttrImpl) || !((AttrImpl) attr).hasStringValue()) {
            NodeList childNodes = attr.getChildNodes();
            for (int i2 = 0; i2 < childNodes.getLength(); i2++) {
                Node item = childNodes.item(i2);
                if (item.getNodeType() == 5) {
                    Document ownerDocument = attr.getOwnerDocument();
                    Entity entity = null;
                    if (!(ownerDocument == null || (doctype = ownerDocument.getDoctype()) == null)) {
                        entity = (Entity) doctype.getEntities().getNamedItemNS("*", item.getNodeName());
                    }
                    if (entity == null) {
                        reportDOMError(dOMErrorHandler, dOMErrorImpl, dOMLocatorImpl, DOMMessageFormatter.formatMessage(DOMMessageFormatter.DOM_DOMAIN, "UndeclaredEntRefInAttrValue", new Object[]{attr.getNodeName()}), 2, "UndeclaredEntRefInAttrValue");
                    }
                } else {
                    isXMLCharWF(dOMErrorHandler, dOMErrorImpl, dOMLocatorImpl, item.getNodeValue(), z);
                }
            }
            return;
        }
        isXMLCharWF(dOMErrorHandler, dOMErrorImpl, dOMLocatorImpl, str, z);
    }

    public static final void isCDataWF(DOMErrorHandler dOMErrorHandler, DOMErrorImpl dOMErrorImpl, DOMLocatorImpl dOMLocatorImpl, String str, boolean z) {
        if (str != null && str.length() != 0) {
            char[] charArray = str.toCharArray();
            int length = charArray.length;
            int i2 = 0;
            if (z) {
                while (i2 < length) {
                    int i3 = i2 + 1;
                    char c = charArray[i2];
                    if (XML11Char.isXML11Invalid(c)) {
                        if (XMLChar.isHighSurrogate(c) && i3 < length) {
                            int i4 = i3 + 1;
                            char c2 = charArray[i3];
                            if (!XMLChar.isLowSurrogate(c2) || !XMLChar.isSupplemental(XMLChar.supplemental(c, c2))) {
                                i3 = i4;
                            } else {
                                i2 = i4;
                            }
                        }
                        reportDOMError(dOMErrorHandler, dOMErrorImpl, dOMLocatorImpl, DOMMessageFormatter.formatMessage("http://www.w3.org/TR/1998/REC-xml-19980210", "InvalidCharInCDSect", new Object[]{Integer.toString(c, 16)}), 2, "wf-invalid-character");
                    } else if (c == ']' && i3 < length && charArray[i3] == ']') {
                        int i5 = i3;
                        do {
                            i5++;
                            if (i5 >= length) {
                                break;
                            }
                        } while (charArray[i5] == ']');
                        if (i5 < length && charArray[i5] == '>') {
                            reportDOMError(dOMErrorHandler, dOMErrorImpl, dOMLocatorImpl, DOMMessageFormatter.formatMessage("http://www.w3.org/TR/1998/REC-xml-19980210", "CDEndInContent", null), 2, "wf-invalid-character");
                        }
                    }
                    i2 = i3;
                }
                return;
            }
            while (i2 < length) {
                int i6 = i2 + 1;
                char c3 = charArray[i2];
                if (XMLChar.isInvalid(c3)) {
                    if (XMLChar.isHighSurrogate(c3) && i6 < length) {
                        int i7 = i6 + 1;
                        char c4 = charArray[i6];
                        if (!XMLChar.isLowSurrogate(c4) || !XMLChar.isSupplemental(XMLChar.supplemental(c3, c4))) {
                            i6 = i7;
                        } else {
                            i2 = i7;
                        }
                    }
                    reportDOMError(dOMErrorHandler, dOMErrorImpl, dOMLocatorImpl, DOMMessageFormatter.formatMessage("http://www.w3.org/TR/1998/REC-xml-19980210", "InvalidCharInCDSect", new Object[]{Integer.toString(c3, 16)}), 2, "wf-invalid-character");
                } else if (c3 == ']' && i6 < length && charArray[i6] == ']') {
                    int i8 = i6;
                    do {
                        i8++;
                        if (i8 >= length) {
                            break;
                        }
                    } while (charArray[i8] == ']');
                    if (i8 < length && charArray[i8] == '>') {
                        reportDOMError(dOMErrorHandler, dOMErrorImpl, dOMLocatorImpl, DOMMessageFormatter.formatMessage("http://www.w3.org/TR/1998/REC-xml-19980210", "CDEndInContent", null), 2, "wf-invalid-character");
                    }
                }
                i2 = i6;
            }
        }
    }

    public static final void isCommentWF(DOMErrorHandler dOMErrorHandler, DOMErrorImpl dOMErrorImpl, DOMLocatorImpl dOMLocatorImpl, String str, boolean z) {
        if (str != null && str.length() != 0) {
            char[] charArray = str.toCharArray();
            int length = charArray.length;
            int i2 = 0;
            if (z) {
                while (i2 < length) {
                    int i3 = i2 + 1;
                    char c = charArray[i2];
                    if (XML11Char.isXML11Invalid(c)) {
                        if (!XMLChar.isHighSurrogate(c) || i3 >= length) {
                            i2 = i3;
                        } else {
                            int i4 = i3 + 1;
                            char c2 = charArray[i3];
                            if (!XMLChar.isLowSurrogate(c2) || !XMLChar.isSupplemental(XMLChar.supplemental(c, c2))) {
                                i2 = i4;
                            } else {
                                i2 = i4;
                            }
                        }
                        reportDOMError(dOMErrorHandler, dOMErrorImpl, dOMLocatorImpl, DOMMessageFormatter.formatMessage("http://www.w3.org/TR/1998/REC-xml-19980210", "InvalidCharInComment", new Object[]{Integer.toString(charArray[i2 - 1], 16)}), 2, "wf-invalid-character");
                    } else {
                        if (c == '-' && i3 < length && charArray[i3] == '-') {
                            reportDOMError(dOMErrorHandler, dOMErrorImpl, dOMLocatorImpl, DOMMessageFormatter.formatMessage("http://www.w3.org/TR/1998/REC-xml-19980210", "DashDashInComment", null), 2, "wf-invalid-character");
                        }
                        i2 = i3;
                    }
                }
                return;
            }
            while (i2 < length) {
                int i5 = i2 + 1;
                char c3 = charArray[i2];
                if (XMLChar.isInvalid(c3)) {
                    if (!XMLChar.isHighSurrogate(c3) || i5 >= length) {
                        i2 = i5;
                    } else {
                        int i6 = i5 + 1;
                        char c4 = charArray[i5];
                        if (!XMLChar.isLowSurrogate(c4) || !XMLChar.isSupplemental(XMLChar.supplemental(c3, c4))) {
                            i2 = i6;
                        } else {
                            i2 = i6;
                        }
                    }
                    reportDOMError(dOMErrorHandler, dOMErrorImpl, dOMLocatorImpl, DOMMessageFormatter.formatMessage("http://www.w3.org/TR/1998/REC-xml-19980210", "InvalidCharInComment", new Object[]{Integer.toString(charArray[i2 - 1], 16)}), 2, "wf-invalid-character");
                } else {
                    if (c3 == '-' && i5 < length && charArray[i5] == '-') {
                        reportDOMError(dOMErrorHandler, dOMErrorImpl, dOMLocatorImpl, DOMMessageFormatter.formatMessage("http://www.w3.org/TR/1998/REC-xml-19980210", "DashDashInComment", null), 2, "wf-invalid-character");
                    }
                    i2 = i5;
                }
            }
        }
    }

    public static final void isXMLCharWF(DOMErrorHandler dOMErrorHandler, DOMErrorImpl dOMErrorImpl, DOMLocatorImpl dOMLocatorImpl, String str, boolean z) {
        if (str != null && str.length() != 0) {
            char[] charArray = str.toCharArray();
            int length = charArray.length;
            int i2 = 0;
            if (z) {
                while (i2 < length) {
                    int i3 = i2 + 1;
                    if (XML11Char.isXML11Invalid(charArray[i2])) {
                        char c = charArray[i3 - 1];
                        if (!XMLChar.isHighSurrogate(c) || i3 >= length) {
                            i2 = i3;
                        } else {
                            int i4 = i3 + 1;
                            char c2 = charArray[i3];
                            if (!XMLChar.isLowSurrogate(c2) || !XMLChar.isSupplemental(XMLChar.supplemental(c, c2))) {
                                i2 = i4;
                            } else {
                                i2 = i4;
                            }
                        }
                        reportDOMError(dOMErrorHandler, dOMErrorImpl, dOMLocatorImpl, DOMMessageFormatter.formatMessage(DOMMessageFormatter.DOM_DOMAIN, "InvalidXMLCharInDOM", new Object[]{Integer.toString(charArray[i2 - 1], 16)}), 2, "wf-invalid-character");
                    } else {
                        i2 = i3;
                    }
                }
                return;
            }
            while (i2 < length) {
                int i5 = i2 + 1;
                if (XMLChar.isInvalid(charArray[i2])) {
                    char c3 = charArray[i5 - 1];
                    if (!XMLChar.isHighSurrogate(c3) || i5 >= length) {
                        i2 = i5;
                    } else {
                        int i6 = i5 + 1;
                        char c4 = charArray[i5];
                        if (!XMLChar.isLowSurrogate(c4) || !XMLChar.isSupplemental(XMLChar.supplemental(c3, c4))) {
                            i2 = i6;
                        } else {
                            i2 = i6;
                        }
                    }
                    reportDOMError(dOMErrorHandler, dOMErrorImpl, dOMLocatorImpl, DOMMessageFormatter.formatMessage(DOMMessageFormatter.DOM_DOMAIN, "InvalidXMLCharInDOM", new Object[]{Integer.toString(charArray[i2 - 1], 16)}), 2, "wf-invalid-character");
                } else {
                    i2 = i5;
                }
            }
        }
    }

    /* JADX WARNING: Removed duplicated region for block: B:28:0x0081  */
    /* JADX WARNING: Removed duplicated region for block: B:32:0x0089  */
    /* JADX WARNING: Removed duplicated region for block: B:36:? A[RETURN, SYNTHETIC] */
    private void processDTD(String str, String str2) {
        String str3;
        String str4;
        String str5;
        String str6;
        Throwable th;
        String documentURI = this.fDocument.getDocumentURI();
        DocumentType doctype = this.fDocument.getDoctype();
        XMLDTDLoader xMLDTDLoader = null;
        if (doctype != null) {
            String name = doctype.getName();
            String publicId = doctype.getPublicId();
            if (str2 == null || str2.length() == 0) {
                str2 = doctype.getSystemId();
            }
            str4 = str2;
            str3 = doctype.getInternalSubset();
            str5 = publicId;
            str6 = name;
        } else {
            Element documentElement = this.fDocument.getDocumentElement();
            if (documentElement != null) {
                String nodeName = documentElement.getNodeName();
                if (str2 != null && str2.length() != 0) {
                    str4 = str2;
                    str6 = nodeName;
                    str5 = null;
                    str3 = null;
                } else {
                    return;
                }
            } else {
                return;
            }
        }
        try {
            this.fValidationHandler.doctypeDecl(str6, str5, str4, null);
            XMLDTDLoader dTDLoader = CoreDOMImplementationImpl.singleton.getDTDLoader(str);
            try {
                dTDLoader.setFeature("http://xml.org/sax/features/validation", true);
                dTDLoader.setEntityResolver(this.fConfiguration.getEntityResolver());
                dTDLoader.setErrorHandler(this.fConfiguration.getErrorHandler());
                dTDLoader.loadGrammarWithContext((XMLDTDValidator) this.fValidationHandler, str6, str5, str4, documentURI, str3);
                CoreDOMImplementationImpl.singleton.releaseDTDLoader(str, dTDLoader);
            } catch (IOException unused) {
                xMLDTDLoader = dTDLoader;
                if (xMLDTDLoader == null) {
                }
            } catch (Throwable th2) {
                th = th2;
                xMLDTDLoader = dTDLoader;
                if (xMLDTDLoader != null) {
                }
                throw th;
            }
        } catch (IOException unused2) {
            if (xMLDTDLoader == null) {
                CoreDOMImplementationImpl.singleton.releaseDTDLoader(str, xMLDTDLoader);
            }
        } catch (Throwable th3) {
            th = th3;
            if (xMLDTDLoader != null) {
                CoreDOMImplementationImpl.singleton.releaseDTDLoader(str, xMLDTDLoader);
            }
            throw th;
        }
    }

    public static final void reportDOMError(DOMErrorHandler dOMErrorHandler, DOMErrorImpl dOMErrorImpl, DOMLocatorImpl dOMLocatorImpl, String str, short s, String str2) {
        if (dOMErrorHandler != null) {
            dOMErrorImpl.reset();
            dOMErrorImpl.fMessage = str;
            dOMErrorImpl.fSeverity = s;
            dOMErrorImpl.fLocator = dOMLocatorImpl;
            dOMErrorImpl.fType = str2;
            dOMErrorImpl.fRelatedData = dOMLocatorImpl.fRelatedNode;
            if (!dOMErrorHandler.handleError(dOMErrorImpl)) {
                throw abort;
            }
        }
        if (s == 3) {
            throw abort;
        }
    }

    public final void addNamespaceDecl(String str, String str2, ElementImpl elementImpl) {
        if (str == XMLSymbols.EMPTY_STRING) {
            elementImpl.setAttributeNS(NamespaceContext.XMLNS_URI, XMLSymbols.PREFIX_XMLNS, str2);
            return;
        }
        String str3 = NamespaceContext.XMLNS_URI;
        StringBuffer stringBuffer = new StringBuffer();
        stringBuffer.append(Sax2Dom.XMLNS_STRING);
        stringBuffer.append(str);
        elementImpl.setAttributeNS(str3, stringBuffer.toString(), str2);
    }

    @Override // org.apache.xerces.xni.XMLDocumentHandler
    public void characters(XMLString xMLString, Augmentations augmentations) {
    }

    @Override // org.apache.xerces.xni.XMLDocumentHandler
    public void comment(XMLString xMLString, Augmentations augmentations) {
    }

    @Override // org.apache.xerces.xni.XMLDocumentHandler
    public void doctypeDecl(String str, String str2, String str3, Augmentations augmentations) {
    }

    @Override // org.apache.xerces.xni.XMLDocumentHandler
    public void emptyElement(QName qName, XMLAttributes xMLAttributes, Augmentations augmentations) {
        startElement(qName, xMLAttributes, augmentations);
        endElement(qName, augmentations);
    }

    @Override // org.apache.xerces.xni.XMLDocumentHandler
    public void endCDATA(Augmentations augmentations) {
    }

    @Override // org.apache.xerces.xni.XMLDocumentHandler
    public void endDocument(Augmentations augmentations) {
    }

    @Override // org.apache.xerces.xni.XMLDocumentHandler
    public void endElement(QName qName, Augmentations augmentations) {
        ElementPSVI elementPSVI;
        if (augmentations == null || (elementPSVI = (ElementPSVI) augmentations.getItem(Constants.ELEMENT_PSVI)) == null) {
            Node node = this.fCurrentNode;
            if (node instanceof ElementNSImpl) {
                ((ElementNSImpl) node).setType(null);
                return;
            }
            return;
        }
        Node node2 = this.fCurrentNode;
        ElementImpl elementImpl = (ElementImpl) node2;
        if (this.fPSVI) {
            ((PSVIElementNSImpl) node2).setPSVI(elementPSVI);
        }
        if (elementImpl instanceof ElementNSImpl) {
            XSTypeDefinition memberTypeDefinition = elementPSVI.getMemberTypeDefinition();
            if (memberTypeDefinition == null) {
                memberTypeDefinition = elementPSVI.getTypeDefinition();
            }
            ((ElementNSImpl) elementImpl).setType(memberTypeDefinition);
        }
        String schemaNormalizedValue = elementPSVI.getSchemaNormalizedValue();
        if ((this.fConfiguration.features & 2) != 0) {
            if (schemaNormalizedValue == null) {
                return;
            }
        } else if (elementImpl.getTextContent().length() != 0 || schemaNormalizedValue == null) {
            return;
        }
        elementImpl.setTextContent(schemaNormalizedValue);
    }

    @Override // org.apache.xerces.xni.XMLDocumentHandler
    public void endGeneralEntity(String str, Augmentations augmentations) {
    }

    public final void expandEntityRef(Node node, Node node2) {
        Node firstChild = node2.getFirstChild();
        while (firstChild != null) {
            Node nextSibling = firstChild.getNextSibling();
            node.insertBefore(firstChild, node2);
            firstChild = nextSibling;
        }
    }

    @Override // org.apache.xerces.xni.XMLDocumentHandler
    public XMLDocumentSource getDocumentSource() {
        return null;
    }

    @Override // org.apache.xerces.xni.XMLDocumentHandler
    public void ignorableWhitespace(XMLString xMLString, Augmentations augmentations) {
        this.fAllWhitespace = true;
    }

    public final void namespaceFixUp(ElementImpl elementImpl, AttributeMap attributeMap) {
        short s;
        String str;
        DOMLocatorImpl dOMLocatorImpl;
        DOMErrorImpl dOMErrorImpl;
        DOMErrorHandler dOMErrorHandler;
        if (attributeMap != null) {
            for (int i2 = 0; i2 < attributeMap.getLength(); i2++) {
                Attr attr = (Attr) attributeMap.getItem(i2);
                String namespaceURI = attr.getNamespaceURI();
                if (namespaceURI != null && namespaceURI.equals(NamespaceContext.XMLNS_URI)) {
                    String nodeValue = attr.getNodeValue();
                    if (nodeValue == null) {
                        nodeValue = XMLSymbols.EMPTY_STRING;
                    }
                    if (!this.fDocument.errorChecking || !nodeValue.equals(NamespaceContext.XMLNS_URI)) {
                        String prefix = attr.getPrefix();
                        String addSymbol = (prefix == null || prefix.length() == 0) ? XMLSymbols.EMPTY_STRING : this.fSymbolTable.addSymbol(prefix);
                        String addSymbol2 = this.fSymbolTable.addSymbol(attr.getLocalName());
                        if (addSymbol == XMLSymbols.PREFIX_XMLNS) {
                            String addSymbol3 = this.fSymbolTable.addSymbol(nodeValue);
                            if (addSymbol3.length() != 0) {
                                this.fNamespaceContext.declarePrefix(addSymbol2, addSymbol3);
                            }
                        } else {
                            String addSymbol4 = this.fSymbolTable.addSymbol(nodeValue);
                            NamespaceContext namespaceContext = this.fNamespaceContext;
                            String str2 = XMLSymbols.EMPTY_STRING;
                            if (addSymbol4.length() == 0) {
                                addSymbol4 = null;
                            }
                            namespaceContext.declarePrefix(str2, addSymbol4);
                        }
                    } else {
                        this.fLocator.fRelatedNode = attr;
                        reportDOMError(this.fErrorHandler, this.fError, this.fLocator, DOMMessageFormatter.formatMessage("http://www.w3.org/TR/1998/REC-xml-19980210", "CantBindXMLNS", null), 2, "CantBindXMLNS");
                    }
                }
            }
        }
        String namespaceURI2 = elementImpl.getNamespaceURI();
        String prefix2 = elementImpl.getPrefix();
        if (namespaceURI2 != null) {
            String addSymbol5 = this.fSymbolTable.addSymbol(namespaceURI2);
            String addSymbol6 = (prefix2 == null || prefix2.length() == 0) ? XMLSymbols.EMPTY_STRING : this.fSymbolTable.addSymbol(prefix2);
            if (this.fNamespaceContext.getURI(addSymbol6) != addSymbol5) {
                addNamespaceDecl(addSymbol6, addSymbol5, elementImpl);
                this.fLocalNSBinder.declarePrefix(addSymbol6, addSymbol5);
                this.fNamespaceContext.declarePrefix(addSymbol6, addSymbol5);
            }
        } else if (elementImpl.getLocalName() == null) {
            if (this.fNamespaceValidation) {
                str = DOMMessageFormatter.formatMessage(DOMMessageFormatter.DOM_DOMAIN, "NullLocalElementName", new Object[]{elementImpl.getNodeName()});
                dOMErrorHandler = this.fErrorHandler;
                dOMErrorImpl = this.fError;
                dOMLocatorImpl = this.fLocator;
                s = 3;
            } else {
                str = DOMMessageFormatter.formatMessage(DOMMessageFormatter.DOM_DOMAIN, "NullLocalElementName", new Object[]{elementImpl.getNodeName()});
                dOMErrorHandler = this.fErrorHandler;
                dOMErrorImpl = this.fError;
                dOMLocatorImpl = this.fLocator;
                s = 2;
            }
            reportDOMError(dOMErrorHandler, dOMErrorImpl, dOMLocatorImpl, str, s, "NullLocalElementName");
        } else {
            String uri = this.fNamespaceContext.getURI(XMLSymbols.EMPTY_STRING);
            if (uri != null && uri.length() > 0) {
                String str3 = XMLSymbols.EMPTY_STRING;
                addNamespaceDecl(str3, str3, elementImpl);
                this.fLocalNSBinder.declarePrefix(XMLSymbols.EMPTY_STRING, null);
                this.fNamespaceContext.declarePrefix(XMLSymbols.EMPTY_STRING, null);
            }
        }
        if (attributeMap != null) {
            attributeMap.cloneMap(this.fAttributeList);
            for (int i3 = 0; i3 < this.fAttributeList.size(); i3++) {
                Attr attr2 = (Attr) this.fAttributeList.get(i3);
                this.fLocator.fRelatedNode = attr2;
                attr2.normalize();
                String value = attr2.getValue();
                String namespaceURI3 = attr2.getNamespaceURI();
                if (value == null) {
                    value = XMLSymbols.EMPTY_STRING;
                }
                CoreDocumentImpl coreDocumentImpl = this.fDocument;
                if (coreDocumentImpl.errorChecking && (this.fConfiguration.features & 256) != 0) {
                    isAttrValueWF(this.fErrorHandler, this.fError, this.fLocator, attributeMap, attr2, value, coreDocumentImpl.isXML11Version());
                    if (this.fDocument.isXMLVersionChanged()) {
                        if (!(this.fNamespaceValidation ? CoreDocumentImpl.isValidQName(attr2.getPrefix(), attr2.getLocalName(), this.fDocument.isXML11Version()) : CoreDocumentImpl.isXMLName(attr2.getNodeName(), this.fDocument.isXML11Version()))) {
                            reportDOMError(this.fErrorHandler, this.fError, this.fLocator, DOMMessageFormatter.formatMessage(DOMMessageFormatter.DOM_DOMAIN, "wf-invalid-character-in-node-name", new Object[]{"Attr", attr2.getNodeName()}), 2, "wf-invalid-character-in-node-name");
                        }
                    }
                }
                if (namespaceURI3 != null) {
                    String prefix3 = attr2.getPrefix();
                    String addSymbol7 = (prefix3 == null || prefix3.length() == 0) ? XMLSymbols.EMPTY_STRING : this.fSymbolTable.addSymbol(prefix3);
                    this.fSymbolTable.addSymbol(attr2.getLocalName());
                    if (!namespaceURI3.equals(NamespaceContext.XMLNS_URI)) {
                        ((AttrImpl) attr2).setIdAttribute(false);
                        String addSymbol8 = this.fSymbolTable.addSymbol(namespaceURI3);
                        String uri2 = this.fNamespaceContext.getURI(addSymbol7);
                        if (addSymbol7 == XMLSymbols.EMPTY_STRING || uri2 != addSymbol8) {
                            String prefix4 = this.fNamespaceContext.getPrefix(addSymbol8);
                            if (prefix4 == null || prefix4 == XMLSymbols.EMPTY_STRING) {
                                if (addSymbol7 == XMLSymbols.EMPTY_STRING || this.fLocalNSBinder.getURI(addSymbol7) != null) {
                                    addSymbol7 = this.fSymbolTable.addSymbol("NS1");
                                    int i4 = 2;
                                    while (this.fLocalNSBinder.getURI(addSymbol7) != null) {
                                        SymbolTable symbolTable = this.fSymbolTable;
                                        StringBuffer a = a.a(PREFIX);
                                        a.append(i4);
                                        addSymbol7 = symbolTable.addSymbol(a.toString());
                                        i4++;
                                    }
                                }
                                addNamespaceDecl(addSymbol7, addSymbol8, elementImpl);
                                this.fLocalNSBinder.declarePrefix(addSymbol7, this.fSymbolTable.addSymbol(value));
                                this.fNamespaceContext.declarePrefix(addSymbol7, addSymbol8);
                                prefix4 = addSymbol7;
                            }
                            attr2.setPrefix(prefix4);
                        }
                    }
                } else {
                    ((AttrImpl) attr2).setIdAttribute(false);
                    if (attr2.getLocalName() == null) {
                        if (this.fNamespaceValidation) {
                            reportDOMError(this.fErrorHandler, this.fError, this.fLocator, DOMMessageFormatter.formatMessage(DOMMessageFormatter.DOM_DOMAIN, "NullLocalAttrName", new Object[]{attr2.getNodeName()}), 3, "NullLocalAttrName");
                        } else {
                            reportDOMError(this.fErrorHandler, this.fError, this.fLocator, DOMMessageFormatter.formatMessage(DOMMessageFormatter.DOM_DOMAIN, "NullLocalAttrName", new Object[]{attr2.getNodeName()}), 2, "NullLocalAttrName");
                        }
                    }
                }
            }
        }
    }

    public final String normalizeAttributeValue(String str, Attr attr) {
        if (!attr.getSpecified()) {
            return str;
        }
        int length = str.length();
        XMLString xMLString = this.fNormalizedValue;
        if (xMLString.ch.length < length) {
            xMLString.ch = new char[length];
        }
        int i2 = 0;
        this.fNormalizedValue.length = 0;
        boolean z = false;
        while (i2 < length) {
            char charAt = str.charAt(i2);
            if (charAt == '\t' || charAt == '\n') {
                XMLString xMLString2 = this.fNormalizedValue;
                char[] cArr = xMLString2.ch;
                int i3 = xMLString2.length;
                xMLString2.length = i3 + 1;
                cArr[i3] = ' ';
            } else if (charAt == '\r') {
                XMLString xMLString3 = this.fNormalizedValue;
                char[] cArr2 = xMLString3.ch;
                int i4 = xMLString3.length;
                xMLString3.length = i4 + 1;
                cArr2[i4] = ' ';
                int i5 = i2 + 1;
                if (i5 < length && str.charAt(i5) == '\n') {
                    i2 = i5;
                }
            } else {
                XMLString xMLString4 = this.fNormalizedValue;
                char[] cArr3 = xMLString4.ch;
                int i6 = xMLString4.length;
                xMLString4.length = i6 + 1;
                cArr3[i6] = charAt;
                i2++;
            }
            z = true;
            i2++;
        }
        if (!z) {
            return str;
        }
        String xMLString5 = this.fNormalizedValue.toString();
        attr.setValue(xMLString5);
        return xMLString5;
    }

    public void normalizeDocument(CoreDocumentImpl coreDocumentImpl, DOMConfigurationImpl dOMConfigurationImpl) {
        String[] strArr;
        String str;
        String str2;
        this.fDocument = coreDocumentImpl;
        this.fConfiguration = dOMConfigurationImpl;
        this.fAllWhitespace = false;
        this.fNamespaceValidation = false;
        String xmlVersion = coreDocumentImpl.getXmlVersion();
        this.fSymbolTable = (SymbolTable) this.fConfiguration.getProperty("http://apache.org/xml/properties/internal/symbol-table");
        this.fNamespaceContext.reset();
        this.fNamespaceContext.declarePrefix(XMLSymbols.EMPTY_STRING, null);
        DOMConfigurationImpl dOMConfigurationImpl2 = this.fConfiguration;
        if ((dOMConfigurationImpl2.features & 64) != 0) {
            String str3 = (String) dOMConfigurationImpl2.getProperty("http://java.sun.com/xml/jaxp/properties/schemaLanguage");
            if (str3 == null || !str3.equals(Constants.NS_XMLSCHEMA)) {
                String[] strArr2 = str3 != null ? (String[]) this.fConfiguration.getProperty("http://java.sun.com/xml/jaxp/properties/schemaSource") : null;
                this.fConfiguration.setDTDValidatorFactory(xmlVersion);
                this.fValidationHandler = CoreDOMImplementationImpl.singleton.getValidator("http://www.w3.org/TR/REC-xml", xmlVersion);
                this.fPSVI = false;
                strArr = strArr2;
                str = "http://www.w3.org/TR/REC-xml";
            } else {
                str = "http://www.w3.org/2001/XMLSchema";
                this.fValidationHandler = CoreDOMImplementationImpl.singleton.getValidator(str, xmlVersion);
                this.fConfiguration.setFeature("http://apache.org/xml/features/validation/schema", true);
                this.fConfiguration.setFeature("http://apache.org/xml/features/validation/schema-full-checking", true);
                this.fNamespaceValidation = true;
                this.fPSVI = (this.fConfiguration.features & 128) != 0;
                strArr = null;
            }
            this.fConfiguration.setFeature("http://xml.org/sax/features/validation", true);
            this.fDocument.clearIdentifiers();
            RevalidationHandler revalidationHandler = this.fValidationHandler;
            if (revalidationHandler != null) {
                ((XMLComponent) revalidationHandler).reset(this.fConfiguration);
            }
        } else {
            this.fValidationHandler = null;
            str = null;
            strArr = null;
        }
        this.fErrorHandler = (DOMErrorHandler) this.fConfiguration.getParameter(Constants.DOM_ERROR_HANDLER);
        RevalidationHandler revalidationHandler2 = this.fValidationHandler;
        if (revalidationHandler2 != null) {
            revalidationHandler2.setDocumentHandler(this);
            RevalidationHandler revalidationHandler3 = this.fValidationHandler;
            String str4 = this.fDocument.fDocumentURI;
            revalidationHandler3.startDocument(new SimpleLocator(str4, str4, -1, -1), this.fDocument.encoding, this.fNamespaceContext, null);
            this.fValidationHandler.xmlDecl(this.fDocument.getXmlVersion(), this.fDocument.getXmlEncoding(), this.fDocument.getXmlStandalone() ? "yes" : "no", null);
        }
        if (str == "http://www.w3.org/TR/REC-xml") {
            if (strArr != null) {
                try {
                    str2 = strArr[0];
                } catch (RuntimeException e2) {
                    RevalidationHandler revalidationHandler4 = this.fValidationHandler;
                    if (revalidationHandler4 != null) {
                        revalidationHandler4.setDocumentHandler(null);
                        CoreDOMImplementationImpl.singleton.releaseValidator(str, xmlVersion, this.fValidationHandler);
                        this.fValidationHandler = null;
                    }
                    if (e2 != abort) {
                        throw e2;
                    }
                    return;
                }
            } else {
                str2 = null;
            }
            processDTD(xmlVersion, str2);
        }
        Node firstChild = this.fDocument.getFirstChild();
        while (firstChild != null) {
            Node nextSibling = firstChild.getNextSibling();
            firstChild = normalizeNode(firstChild);
            if (firstChild == null) {
                firstChild = nextSibling;
            }
        }
        if (this.fValidationHandler != null) {
            this.fValidationHandler.endDocument(null);
            this.fValidationHandler.setDocumentHandler(null);
            CoreDOMImplementationImpl.singleton.releaseValidator(str, xmlVersion, this.fValidationHandler);
            this.fValidationHandler = null;
        }
    }

    public Node normalizeNode(Node node) {
        int i2;
        Node nextSibling;
        Node parentNode;
        Node node2 = node;
        short nodeType = node.getNodeType();
        this.fLocator.fRelatedNode = node2;
        int i3 = 0;
        if (nodeType != 1) {
            if (nodeType == 3) {
                nextSibling = node.getNextSibling();
                if (nextSibling != null && nextSibling.getNodeType() == 3) {
                    ((Text) node2).appendData(nextSibling.getNodeValue());
                    parentNode = node.getParentNode();
                } else if (node.getNodeValue().length() == 0) {
                    node.getParentNode().removeChild(node2);
                } else {
                    short nodeType2 = nextSibling != null ? nextSibling.getNodeType() : -1;
                    if (nodeType2 == -1 || !(((this.fConfiguration.features & 4) == 0 && nodeType2 == 6) || (((this.fConfiguration.features & 32) == 0 && nodeType2 == 8) || ((this.fConfiguration.features & 8) == 0 && nodeType2 == 4)))) {
                        if (this.fDocument.errorChecking && (this.fConfiguration.features & 256) != 0) {
                            isXMLCharWF(this.fErrorHandler, this.fError, this.fLocator, node.getNodeValue(), this.fDocument.isXML11Version());
                        }
                        RevalidationHandler revalidationHandler = this.fValidationHandler;
                        if (revalidationHandler != null) {
                            this.fConfiguration.fErrorHandlerWrapper.fCurrentNode = node2;
                            this.fCurrentNode = node2;
                            revalidationHandler.characterData(node.getNodeValue(), null);
                            if (!this.fNamespaceValidation) {
                                if (this.fAllWhitespace) {
                                    this.fAllWhitespace = false;
                                    ((TextImpl) node2).setIgnorableWhitespace(true);
                                } else {
                                    ((TextImpl) node2).setIgnorableWhitespace(false);
                                }
                            }
                        }
                    }
                }
            } else if (nodeType == 4) {
                DOMConfigurationImpl dOMConfigurationImpl = this.fConfiguration;
                if ((dOMConfigurationImpl.features & 8) == 0) {
                    Node previousSibling = node.getPreviousSibling();
                    if (previousSibling == null || previousSibling.getNodeType() != 3) {
                        Node createTextNode = this.fDocument.createTextNode(node.getNodeValue());
                        node.getParentNode().replaceChild(createTextNode, node2);
                        return createTextNode;
                    }
                    ((Text) previousSibling).appendData(node.getNodeValue());
                    node.getParentNode().removeChild(node2);
                    return previousSibling;
                }
                RevalidationHandler revalidationHandler2 = this.fValidationHandler;
                if (revalidationHandler2 != null) {
                    dOMConfigurationImpl.fErrorHandlerWrapper.fCurrentNode = node2;
                    this.fCurrentNode = node2;
                    revalidationHandler2.startCDATA(null);
                    this.fValidationHandler.characterData(node.getNodeValue(), null);
                    this.fValidationHandler.endCDATA(null);
                }
                String nodeValue = node.getNodeValue();
                if ((this.fConfiguration.features & 16) != 0) {
                    Node parentNode2 = node.getParentNode();
                    if (this.fDocument.errorChecking) {
                        isXMLCharWF(this.fErrorHandler, this.fError, this.fLocator, node.getNodeValue(), this.fDocument.isXML11Version());
                    }
                    while (true) {
                        int indexOf = nodeValue.indexOf("]]>");
                        if (indexOf < 0) {
                            break;
                        }
                        int i4 = indexOf + 2;
                        node2.setNodeValue(nodeValue.substring(0, i4));
                        nodeValue = nodeValue.substring(i4);
                        Node createCDATASection = this.fDocument.createCDATASection(nodeValue);
                        parentNode2.insertBefore(createCDATASection, node2.getNextSibling());
                        this.fLocator.fRelatedNode = node2;
                        reportDOMError(this.fErrorHandler, this.fError, this.fLocator, DOMMessageFormatter.formatMessage(DOMMessageFormatter.DOM_DOMAIN, "cdata-sections-splitted", null), 1, "cdata-sections-splitted");
                        node2 = createCDATASection;
                    }
                } else {
                    CoreDocumentImpl coreDocumentImpl = this.fDocument;
                    if (coreDocumentImpl.errorChecking) {
                        isCDataWF(this.fErrorHandler, this.fError, this.fLocator, nodeValue, coreDocumentImpl.isXML11Version());
                    }
                }
            } else if (nodeType == 5) {
                short s = this.fConfiguration.features;
                if ((s & 4) == 0) {
                    Node previousSibling2 = node.getPreviousSibling();
                    Node parentNode3 = node.getParentNode();
                    ((EntityReferenceImpl) node2).setReadOnly(false, true);
                    expandEntityRef(parentNode3, node2);
                    parentNode3.removeChild(node2);
                    Node nextSibling2 = previousSibling2 != null ? previousSibling2.getNextSibling() : parentNode3.getFirstChild();
                    return (previousSibling2 == null || nextSibling2 == null || previousSibling2.getNodeType() != 3 || nextSibling2.getNodeType() != 3) ? nextSibling2 : previousSibling2;
                }
                CoreDocumentImpl coreDocumentImpl2 = this.fDocument;
                if (coreDocumentImpl2.errorChecking && (s & 256) != 0 && coreDocumentImpl2.isXMLVersionChanged()) {
                    CoreDocumentImpl.isXMLName(node.getNodeName(), this.fDocument.isXML11Version());
                }
            } else if (nodeType == 7) {
                if (this.fDocument.errorChecking && (this.fConfiguration.features & 256) != 0) {
                    ProcessingInstruction processingInstruction = (ProcessingInstruction) node2;
                    String target = processingInstruction.getTarget();
                    if (!(this.fDocument.isXML11Version() ? XML11Char.isXML11ValidName(target) : XMLChar.isValidName(target))) {
                        reportDOMError(this.fErrorHandler, this.fError, this.fLocator, DOMMessageFormatter.formatMessage(DOMMessageFormatter.DOM_DOMAIN, "wf-invalid-character-in-node-name", new Object[]{"Element", node.getNodeName()}), 2, "wf-invalid-character-in-node-name");
                    }
                    isXMLCharWF(this.fErrorHandler, this.fError, this.fLocator, processingInstruction.getData(), this.fDocument.isXML11Version());
                }
                RevalidationHandler revalidationHandler3 = this.fValidationHandler;
                if (revalidationHandler3 != null) {
                    revalidationHandler3.processingInstruction(((ProcessingInstruction) node2).getTarget(), EMPTY_STRING, null);
                }
            } else if (nodeType == 8) {
                short s2 = this.fConfiguration.features;
                if ((s2 & 32) == 0) {
                    nextSibling = node.getPreviousSibling();
                    parentNode = node.getParentNode();
                    parentNode.removeChild(node2);
                    if (nextSibling != null && nextSibling.getNodeType() == 3 && (node2 = nextSibling.getNextSibling()) != null && node2.getNodeType() == 3) {
                        ((TextImpl) node2).insertData(0, nextSibling.getNodeValue());
                    }
                } else {
                    if (this.fDocument.errorChecking && (s2 & 256) != 0) {
                        isCommentWF(this.fErrorHandler, this.fError, this.fLocator, ((Comment) node2).getData(), this.fDocument.isXML11Version());
                    }
                    RevalidationHandler revalidationHandler4 = this.fValidationHandler;
                    if (revalidationHandler4 != null) {
                        revalidationHandler4.comment(EMPTY_STRING, null);
                    }
                }
            }
            parentNode.removeChild(nextSibling);
            return node2;
        }
        CoreDocumentImpl coreDocumentImpl3 = this.fDocument;
        if (coreDocumentImpl3.errorChecking && (this.fConfiguration.features & 256) != 0 && coreDocumentImpl3.isXMLVersionChanged()) {
            if (!(this.fNamespaceValidation ? CoreDocumentImpl.isValidQName(node.getPrefix(), node.getLocalName(), this.fDocument.isXML11Version()) : CoreDocumentImpl.isXMLName(node.getNodeName(), this.fDocument.isXML11Version()))) {
                reportDOMError(this.fErrorHandler, this.fError, this.fLocator, DOMMessageFormatter.formatMessage(DOMMessageFormatter.DOM_DOMAIN, "wf-invalid-character-in-node-name", new Object[]{"Element", node.getNodeName()}), 2, "wf-invalid-character-in-node-name");
            }
        }
        this.fNamespaceContext.pushContext();
        this.fLocalNSBinder.reset();
        ElementImpl elementImpl = (ElementImpl) node2;
        if (elementImpl.needsSyncChildren()) {
            elementImpl.synchronizeChildren();
        }
        AttributeMap attributeMap = elementImpl.hasAttributes() ? (AttributeMap) elementImpl.getAttributes() : null;
        if ((this.fConfiguration.features & 1) != 0) {
            namespaceFixUp(elementImpl, attributeMap);
            if ((this.fConfiguration.features & 512) == 0 && attributeMap != null) {
                while (i3 < attributeMap.getLength()) {
                    Attr attr = (Attr) attributeMap.getItem(i3);
                    if (XMLSymbols.PREFIX_XMLNS.equals(attr.getPrefix()) || XMLSymbols.PREFIX_XMLNS.equals(attr.getName())) {
                        elementImpl.removeAttributeNode(attr);
                        i3--;
                    }
                    i3++;
                }
            }
        } else if (attributeMap != null) {
            int i5 = 0;
            while (i5 < attributeMap.getLength()) {
                Attr attr2 = (Attr) attributeMap.item(i5);
                attr2.normalize();
                if (!this.fDocument.errorChecking || (this.fConfiguration.features & 256) == 0) {
                    i2 = i5;
                } else {
                    i2 = i5;
                    isAttrValueWF(this.fErrorHandler, this.fError, this.fLocator, attributeMap, attr2, attr2.getValue(), this.fDocument.isXML11Version());
                    if (this.fDocument.isXMLVersionChanged()) {
                        if (!(this.fNamespaceValidation ? CoreDocumentImpl.isValidQName(node.getPrefix(), node.getLocalName(), this.fDocument.isXML11Version()) : CoreDocumentImpl.isXMLName(node.getNodeName(), this.fDocument.isXML11Version()))) {
                            reportDOMError(this.fErrorHandler, this.fError, this.fLocator, DOMMessageFormatter.formatMessage(DOMMessageFormatter.DOM_DOMAIN, "wf-invalid-character-in-node-name", new Object[]{"Attr", node.getNodeName()}), 2, "wf-invalid-character-in-node-name");
                        }
                    }
                }
                i5 = i2 + 1;
            }
        }
        if (this.fValidationHandler != null) {
            this.fAttrProxy.setAttributes(attributeMap, this.fDocument, elementImpl);
            updateQName(elementImpl, this.fQName);
            this.fConfiguration.fErrorHandlerWrapper.fCurrentNode = node2;
            this.fCurrentNode = node2;
            this.fValidationHandler.startElement(this.fQName, this.fAttrProxy, null);
        }
        Node firstChild = elementImpl.getFirstChild();
        while (firstChild != null) {
            Node nextSibling3 = firstChild.getNextSibling();
            firstChild = normalizeNode(firstChild);
            if (firstChild == null) {
                firstChild = nextSibling3;
            }
        }
        if (this.fValidationHandler != null) {
            updateQName(elementImpl, this.fQName);
            this.fConfiguration.fErrorHandlerWrapper.fCurrentNode = node2;
            this.fCurrentNode = node2;
            this.fValidationHandler.endElement(this.fQName, null);
        }
        this.fNamespaceContext.popContext();
        return null;
    }

    @Override // org.apache.xerces.xni.XMLDocumentHandler
    public void processingInstruction(String str, XMLString xMLString, Augmentations augmentations) {
    }

    @Override // org.apache.xerces.xni.XMLDocumentHandler
    public void setDocumentSource(XMLDocumentSource xMLDocumentSource) {
    }

    @Override // org.apache.xerces.xni.XMLDocumentHandler
    public void startCDATA(Augmentations augmentations) {
    }

    @Override // org.apache.xerces.xni.XMLDocumentHandler
    public void startDocument(XMLLocator xMLLocator, String str, NamespaceContext namespaceContext, Augmentations augmentations) {
    }

    @Override // org.apache.xerces.xni.XMLDocumentHandler
    public void startElement(QName qName, XMLAttributes xMLAttributes, Augmentations augmentations) {
        String schemaNormalizedValue;
        Element element = (Element) this.fCurrentNode;
        int length = xMLAttributes.getLength();
        for (int i2 = 0; i2 < length; i2++) {
            xMLAttributes.getName(i2, this.fAttrQName);
            QName qName2 = this.fAttrQName;
            Attr attributeNodeNS = element.getAttributeNodeNS(qName2.uri, qName2.localpart);
            if (attributeNodeNS == null) {
                attributeNodeNS = element.getAttributeNode(this.fAttrQName.rawname);
            }
            AttributePSVI attributePSVI = (AttributePSVI) xMLAttributes.getAugmentations(i2).getItem(Constants.ATTRIBUTE_PSVI);
            if (attributePSVI != null) {
                XSTypeDefinition memberTypeDefinition = attributePSVI.getMemberTypeDefinition();
                if ((memberTypeDefinition == null && (memberTypeDefinition = attributePSVI.getTypeDefinition()) == null) ? false : ((XSSimpleType) memberTypeDefinition).isIDType()) {
                    ((ElementImpl) element).setIdAttributeNode(attributeNodeNS, true);
                }
                if (this.fPSVI) {
                    ((PSVIAttrNSImpl) attributeNodeNS).setPSVI(attributePSVI);
                }
                ((AttrImpl) attributeNodeNS).setType(memberTypeDefinition);
                if (!((this.fConfiguration.features & 2) == 0 || (schemaNormalizedValue = attributePSVI.getSchemaNormalizedValue()) == null)) {
                    boolean specified = attributeNodeNS.getSpecified();
                    attributeNodeNS.setValue(schemaNormalizedValue);
                    if (!specified) {
                        ((AttrImpl) attributeNodeNS).setSpecified(specified);
                    }
                }
            } else {
                String str = null;
                if (Boolean.TRUE.equals(xMLAttributes.getAugmentations(i2).getItem(Constants.ATTRIBUTE_DECLARED))) {
                    str = xMLAttributes.getType(i2);
                    if (SchemaSymbols.ATTVAL_ID.equals(str)) {
                        ((ElementImpl) element).setIdAttributeNode(attributeNodeNS, true);
                    }
                }
                ((AttrImpl) attributeNodeNS).setType(str);
            }
        }
    }

    @Override // org.apache.xerces.xni.XMLDocumentHandler
    public void startGeneralEntity(String str, XMLResourceIdentifier xMLResourceIdentifier, String str2, Augmentations augmentations) {
    }

    @Override // org.apache.xerces.xni.XMLDocumentHandler
    public void textDecl(String str, String str2, Augmentations augmentations) {
    }

    public final void updateQName(Node node, QName qName) {
        String prefix = node.getPrefix();
        String namespaceURI = node.getNamespaceURI();
        String localName = node.getLocalName();
        String str = null;
        qName.prefix = (prefix == null || prefix.length() == 0) ? null : this.fSymbolTable.addSymbol(prefix);
        qName.localpart = localName != null ? this.fSymbolTable.addSymbol(localName) : null;
        qName.rawname = this.fSymbolTable.addSymbol(node.getNodeName());
        if (namespaceURI != null) {
            str = this.fSymbolTable.addSymbol(namespaceURI);
        }
        qName.uri = str;
    }

    @Override // org.apache.xerces.xni.XMLDocumentHandler
    public void xmlDecl(String str, String str2, String str3, Augmentations augmentations) {
    }
}
