package org.apache.xerces.dom;

import java.util.ArrayList;
import org.w3c.dom.Node;
import org.w3c.dom.NodeList;

public class DeepNodeListImpl implements NodeList {
    public int changes;
    public boolean enableNS;
    public ArrayList nodes;
    public String nsName;
    public NodeImpl rootNode;
    public String tagName;

    public DeepNodeListImpl(NodeImpl nodeImpl, String str) {
        this.changes = 0;
        this.enableNS = false;
        this.rootNode = nodeImpl;
        this.tagName = str;
        this.nodes = new ArrayList();
    }

    public DeepNodeListImpl(NodeImpl nodeImpl, String str, String str2) {
        this(nodeImpl, str2);
        this.nsName = (str == null || str.length() == 0) ? null : str;
        this.enableNS = true;
    }

    @Override // org.w3c.dom.NodeList
    public int getLength() {
        item(Integer.MAX_VALUE);
        return this.nodes.size();
    }

    @Override // org.w3c.dom.NodeList
    public Node item(int i2) {
        if (this.rootNode.changes() != this.changes) {
            this.nodes = new ArrayList();
            this.changes = this.rootNode.changes();
        }
        int size = this.nodes.size();
        if (i2 < size) {
            return (Node) this.nodes.get(i2);
        }
        Node node = size == 0 ? this.rootNode : (NodeImpl) this.nodes.get(size - 1);
        while (node != null && i2 >= this.nodes.size()) {
            node = nextMatchingElementAfter(node);
            if (node != null) {
                this.nodes.add(node);
            }
        }
        return node;
    }

    public Node nextMatchingElementAfter(Node node) {
        String str;
        String str2;
        Node nextSibling;
        while (true) {
            Node node2 = null;
            if (node == null) {
                return null;
            }
            if (node.hasChildNodes()) {
                node = node.getFirstChild();
            } else if (node == this.rootNode || (nextSibling = node.getNextSibling()) == null) {
                while (node != this.rootNode && (node2 = node.getNextSibling()) == null) {
                    node = node.getParentNode();
                }
                node = node2;
            } else {
                node = nextSibling;
            }
            if (!(node == this.rootNode || node == null || node.getNodeType() != 1)) {
                if (!this.enableNS) {
                    if (this.tagName.equals("*") || ((ElementImpl) node).getTagName().equals(this.tagName)) {
                        return node;
                    }
                } else if (this.tagName.equals("*")) {
                    String str3 = this.nsName;
                    if (str3 != null && str3.equals("*")) {
                        return node;
                    }
                    ElementImpl elementImpl = (ElementImpl) node;
                    if ((this.nsName == null && elementImpl.getNamespaceURI() == null) || ((str2 = this.nsName) != null && str2.equals(elementImpl.getNamespaceURI()))) {
                        return node;
                    }
                } else {
                    ElementImpl elementImpl2 = (ElementImpl) node;
                    if (elementImpl2.getLocalName() != null && elementImpl2.getLocalName().equals(this.tagName)) {
                        String str4 = this.nsName;
                        if (str4 != null && str4.equals("*")) {
                            return node;
                        }
                        if ((this.nsName == null && elementImpl2.getNamespaceURI() == null) || ((str = this.nsName) != null && str.equals(elementImpl2.getNamespaceURI()))) {
                            return node;
                        }
                    }
                }
            }
        }
        return node;
    }
}
