package org.apache.xerces.dom;

import java.io.Serializable;
import java.lang.ref.Reference;
import java.lang.ref.ReferenceQueue;
import java.lang.ref.WeakReference;
import java.util.ArrayList;
import java.util.Hashtable;
import java.util.Iterator;
import java.util.LinkedList;
import java.util.List;
import java.util.Vector;
import org.apache.xerces.dom.events.EventImpl;
import org.apache.xerces.dom.events.MouseEventImpl;
import org.apache.xerces.dom.events.MutationEventImpl;
import org.apache.xerces.dom.events.UIEventImpl;
import org.w3c.dom.Attr;
import org.w3c.dom.DOMException;
import org.w3c.dom.DOMImplementation;
import org.w3c.dom.DocumentType;
import org.w3c.dom.Element;
import org.w3c.dom.NamedNodeMap;
import org.w3c.dom.Node;
import org.w3c.dom.events.DocumentEvent;
import org.w3c.dom.events.Event;
import org.w3c.dom.events.EventException;
import org.w3c.dom.events.EventListener;
import org.w3c.dom.ranges.DocumentRange;
import org.w3c.dom.ranges.Range;
import org.w3c.dom.traversal.DocumentTraversal;
import org.w3c.dom.traversal.NodeFilter;
import org.w3c.dom.traversal.NodeIterator;
import org.w3c.dom.traversal.TreeWalker;

public class DocumentImpl extends CoreDocumentImpl implements DocumentTraversal, DocumentEvent, DocumentRange {
    public static final long serialVersionUID = 515687835542616694L;
    public Hashtable eventListeners;
    public transient ReferenceQueue iteratorReferenceQueue;
    public transient List iterators;
    public boolean mutationEvents = false;
    public transient ReferenceQueue rangeReferenceQueue;
    public transient List ranges;
    public EnclosingAttr savedEnclosingAttr;

    public class EnclosingAttr implements Serializable {
        public static final long serialVersionUID = 5208387723391647216L;
        public AttrImpl node;
        public String oldvalue;

        public EnclosingAttr() {
        }
    }

    public class LEntry implements Serializable {
        public static final long serialVersionUID = -8426757059492421631L;
        public EventListener listener;
        public String type;
        public boolean useCapture;

        public LEntry(String str, EventListener eventListener, boolean z) {
            this.type = str;
            this.listener = eventListener;
            this.useCapture = z;
        }
    }

    public DocumentImpl() {
    }

    public DocumentImpl(DocumentType documentType) {
        super(documentType);
    }

    public DocumentImpl(DocumentType documentType, boolean z) {
        super(documentType, z);
    }

    public DocumentImpl(boolean z) {
        super(z);
    }

    private void mutationEventsInsertedNode(NodeImpl nodeImpl, NodeImpl nodeImpl2, boolean z) {
        if (LCount.lookup(MutationEventImpl.DOM_NODE_INSERTED).total > 0) {
            MutationEventImpl mutationEventImpl = new MutationEventImpl();
            mutationEventImpl.initMutationEvent(MutationEventImpl.DOM_NODE_INSERTED, true, false, nodeImpl, null, null, null, 0);
            dispatchEvent(nodeImpl2, mutationEventImpl);
        }
        if (LCount.lookup(MutationEventImpl.DOM_NODE_INSERTED_INTO_DOCUMENT).total > 0) {
            EnclosingAttr enclosingAttr = this.savedEnclosingAttr;
            NodeImpl nodeImpl3 = enclosingAttr != null ? (NodeImpl) enclosingAttr.node.getOwnerElement() : nodeImpl;
            if (nodeImpl3 != null) {
                NodeImpl nodeImpl4 = nodeImpl3;
                while (nodeImpl3 != null) {
                    nodeImpl4 = nodeImpl3;
                    nodeImpl3 = nodeImpl3.getNodeType() == 2 ? (NodeImpl) ((AttrImpl) nodeImpl3).getOwnerElement() : nodeImpl3.parentNode();
                }
                if (nodeImpl4.getNodeType() == 9) {
                    MutationEventImpl mutationEventImpl2 = new MutationEventImpl();
                    mutationEventImpl2.initMutationEvent(MutationEventImpl.DOM_NODE_INSERTED_INTO_DOCUMENT, false, false, null, null, null, null, 0);
                    dispatchEventToSubtree(nodeImpl2, mutationEventImpl2);
                }
            }
        }
        if (!z) {
            dispatchAggregateEvents(nodeImpl, this.savedEnclosingAttr);
        }
    }

    private void mutationEventsModifiedCharacterData(NodeImpl nodeImpl, String str, String str2, boolean z) {
        if (!z) {
            if (LCount.lookup(MutationEventImpl.DOM_CHARACTER_DATA_MODIFIED).total > 0) {
                MutationEventImpl mutationEventImpl = new MutationEventImpl();
                mutationEventImpl.initMutationEvent(MutationEventImpl.DOM_CHARACTER_DATA_MODIFIED, true, false, null, str, str2, null, 0);
                dispatchEvent(nodeImpl, mutationEventImpl);
            }
            dispatchAggregateEvents(nodeImpl, this.savedEnclosingAttr);
        }
    }

    private void mutationEventsRemovedAttrNode(AttrImpl attrImpl, NodeImpl nodeImpl, String str) {
        if (LCount.lookup(MutationEventImpl.DOM_ATTR_MODIFIED).total > 0) {
            MutationEventImpl mutationEventImpl = new MutationEventImpl();
            mutationEventImpl.initMutationEvent(MutationEventImpl.DOM_ATTR_MODIFIED, true, false, attrImpl, attrImpl.getNodeValue(), null, str, 3);
            dispatchEvent(nodeImpl, mutationEventImpl);
        }
        dispatchAggregateEvents(nodeImpl, null, null, 0);
    }

    private void mutationEventsRemovingNode(NodeImpl nodeImpl, NodeImpl nodeImpl2, boolean z) {
        if (!z) {
            saveEnclosingAttr(nodeImpl);
        }
        if (LCount.lookup(MutationEventImpl.DOM_NODE_REMOVED).total > 0) {
            MutationEventImpl mutationEventImpl = new MutationEventImpl();
            mutationEventImpl.initMutationEvent(MutationEventImpl.DOM_NODE_REMOVED, true, false, nodeImpl, null, null, null, 0);
            dispatchEvent(nodeImpl2, mutationEventImpl);
        }
        if (LCount.lookup(MutationEventImpl.DOM_NODE_REMOVED_FROM_DOCUMENT).total > 0) {
            EnclosingAttr enclosingAttr = this.savedEnclosingAttr;
            NodeImpl nodeImpl3 = enclosingAttr != null ? (NodeImpl) enclosingAttr.node.getOwnerElement() : this;
            if (nodeImpl3 != null) {
                do {
                    nodeImpl3 = nodeImpl3.parentNode();
                } while (nodeImpl3 != null);
                if (nodeImpl3.getNodeType() == 9) {
                    MutationEventImpl mutationEventImpl2 = new MutationEventImpl();
                    mutationEventImpl2.initMutationEvent(MutationEventImpl.DOM_NODE_REMOVED_FROM_DOCUMENT, false, false, null, null, null, null, 0);
                    dispatchEventToSubtree(nodeImpl2, mutationEventImpl2);
                }
            }
        }
    }

    private void notifyIteratorsRemovingNode(NodeImpl nodeImpl) {
        removeStaleIteratorReferences();
        Iterator it = this.iterators.iterator();
        while (it.hasNext()) {
            NodeIteratorImpl nodeIteratorImpl = (NodeIteratorImpl) ((Reference) it.next()).get();
            if (nodeIteratorImpl != null) {
                nodeIteratorImpl.removeNode(nodeImpl);
            } else {
                it.remove();
            }
        }
    }

    private void notifyRangesDeletedText(CharacterDataImpl characterDataImpl, int i2, int i3) {
        removeStaleRangeReferences();
        Iterator it = this.ranges.iterator();
        while (it.hasNext()) {
            RangeImpl rangeImpl = (RangeImpl) ((Reference) it.next()).get();
            if (rangeImpl != null) {
                rangeImpl.receiveDeletedText(characterDataImpl, i2, i3);
            } else {
                it.remove();
            }
        }
    }

    private void notifyRangesInsertedNode(NodeImpl nodeImpl) {
        removeStaleRangeReferences();
        Iterator it = this.ranges.iterator();
        while (it.hasNext()) {
            RangeImpl rangeImpl = (RangeImpl) ((Reference) it.next()).get();
            if (rangeImpl != null) {
                rangeImpl.insertedNodeFromDOM(nodeImpl);
            } else {
                it.remove();
            }
        }
    }

    private void notifyRangesInsertedText(CharacterDataImpl characterDataImpl, int i2, int i3) {
        removeStaleRangeReferences();
        Iterator it = this.ranges.iterator();
        while (it.hasNext()) {
            RangeImpl rangeImpl = (RangeImpl) ((Reference) it.next()).get();
            if (rangeImpl != null) {
                rangeImpl.receiveInsertedText(characterDataImpl, i2, i3);
            } else {
                it.remove();
            }
        }
    }

    private void notifyRangesRemovingNode(NodeImpl nodeImpl) {
        removeStaleRangeReferences();
        Iterator it = this.ranges.iterator();
        while (it.hasNext()) {
            RangeImpl rangeImpl = (RangeImpl) ((Reference) it.next()).get();
            if (rangeImpl != null) {
                rangeImpl.removeNode(nodeImpl);
            } else {
                it.remove();
            }
        }
    }

    private void notifyRangesReplacedText(CharacterDataImpl characterDataImpl) {
        removeStaleRangeReferences();
        Iterator it = this.ranges.iterator();
        while (it.hasNext()) {
            RangeImpl rangeImpl = (RangeImpl) ((Reference) it.next()).get();
            if (rangeImpl != null) {
                rangeImpl.receiveReplacedText(characterDataImpl);
            } else {
                it.remove();
            }
        }
    }

    private void notifyRangesSplitData(Node node, Node node2, int i2) {
        removeStaleRangeReferences();
        Iterator it = this.ranges.iterator();
        while (it.hasNext()) {
            RangeImpl rangeImpl = (RangeImpl) ((Reference) it.next()).get();
            if (rangeImpl != null) {
                rangeImpl.receiveSplitData(node, node2, i2);
            } else {
                it.remove();
            }
        }
    }

    private void removeStaleIteratorReferences() {
        removeStaleReferences(this.iteratorReferenceQueue, this.iterators);
    }

    private void removeStaleRangeReferences() {
        removeStaleReferences(this.rangeReferenceQueue, this.ranges);
    }

    private void removeStaleReferences(ReferenceQueue referenceQueue, List list) {
        Reference poll = referenceQueue.poll();
        int i2 = 0;
        while (poll != null) {
            i2++;
            poll = referenceQueue.poll();
        }
        if (i2 > 0) {
            Iterator it = list.iterator();
            while (it.hasNext()) {
                if (((Reference) it.next()).get() == null) {
                    it.remove();
                    i2--;
                    if (i2 <= 0) {
                        return;
                    }
                }
            }
        }
    }

    @Override // org.apache.xerces.dom.CoreDocumentImpl
    public void addEventListener(NodeImpl nodeImpl, String str, EventListener eventListener, boolean z) {
        if (str != null && str.length() != 0 && eventListener != null) {
            removeEventListener(nodeImpl, str, eventListener, z);
            Vector eventListeners2 = getEventListeners(nodeImpl);
            if (eventListeners2 == null) {
                eventListeners2 = new Vector();
                setEventListeners(nodeImpl, eventListeners2);
            }
            eventListeners2.addElement(new LEntry(str, eventListener, z));
            LCount lookup = LCount.lookup(str);
            if (z) {
                lookup.captures++;
            } else {
                lookup.bubbles++;
            }
            lookup.total++;
        }
    }

    @Override // org.apache.xerces.dom.NodeImpl, org.apache.xerces.dom.CoreDocumentImpl, org.apache.xerces.dom.ParentNode, org.w3c.dom.Node, org.apache.xerces.dom.ChildNode
    public Node cloneNode(boolean z) {
        DocumentImpl documentImpl = new DocumentImpl();
        callUserDataHandlers(this, documentImpl, 1);
        cloneNode(documentImpl, z);
        documentImpl.mutationEvents = this.mutationEvents;
        return documentImpl;
    }

    @Override // org.apache.xerces.dom.CoreDocumentImpl
    public void copyEventListeners(NodeImpl nodeImpl, NodeImpl nodeImpl2) {
        Vector eventListeners2 = getEventListeners(nodeImpl);
        if (eventListeners2 != null) {
            setEventListeners(nodeImpl2, (Vector) eventListeners2.clone());
        }
    }

    @Override // org.w3c.dom.events.DocumentEvent
    public Event createEvent(String str) {
        if (str.equalsIgnoreCase("Events") || "Event".equals(str)) {
            return new EventImpl();
        }
        if (str.equalsIgnoreCase("MutationEvents") || "MutationEvent".equals(str)) {
            return new MutationEventImpl();
        }
        if (str.equalsIgnoreCase("UIEvents") || "UIEvent".equals(str)) {
            return new UIEventImpl();
        }
        if (str.equalsIgnoreCase("MouseEvents") || "MouseEvent".equals(str)) {
            return new MouseEventImpl();
        }
        throw new DOMException(9, DOMMessageFormatter.formatMessage(DOMMessageFormatter.DOM_DOMAIN, "NOT_SUPPORTED_ERR", null));
    }

    @Override // org.w3c.dom.traversal.DocumentTraversal
    public NodeIterator createNodeIterator(Node node, int i2, NodeFilter nodeFilter, boolean z) {
        if (node != null) {
            NodeIteratorImpl nodeIteratorImpl = new NodeIteratorImpl(this, node, i2, nodeFilter, z);
            if (this.iterators == null) {
                this.iterators = new LinkedList();
                this.iteratorReferenceQueue = new ReferenceQueue();
            }
            removeStaleIteratorReferences();
            this.iterators.add(new WeakReference(nodeIteratorImpl, this.iteratorReferenceQueue));
            return nodeIteratorImpl;
        }
        throw new DOMException(9, DOMMessageFormatter.formatMessage(DOMMessageFormatter.DOM_DOMAIN, "NOT_SUPPORTED_ERR", null));
    }

    public NodeIterator createNodeIterator(Node node, short s, NodeFilter nodeFilter) {
        return createNodeIterator(node, s, nodeFilter, true);
    }

    @Override // org.w3c.dom.ranges.DocumentRange
    public Range createRange() {
        if (this.ranges == null) {
            this.ranges = new LinkedList();
            this.rangeReferenceQueue = new ReferenceQueue();
        }
        RangeImpl rangeImpl = new RangeImpl(this);
        removeStaleRangeReferences();
        this.ranges.add(new WeakReference(rangeImpl, this.rangeReferenceQueue));
        return rangeImpl;
    }

    @Override // org.w3c.dom.traversal.DocumentTraversal
    public TreeWalker createTreeWalker(Node node, int i2, NodeFilter nodeFilter, boolean z) {
        if (node != null) {
            return new TreeWalkerImpl(node, i2, nodeFilter, z);
        }
        throw new DOMException(9, DOMMessageFormatter.formatMessage(DOMMessageFormatter.DOM_DOMAIN, "NOT_SUPPORTED_ERR", null));
    }

    public TreeWalker createTreeWalker(Node node, short s, NodeFilter nodeFilter) {
        return createTreeWalker(node, s, nodeFilter, true);
    }

    @Override // org.apache.xerces.dom.CoreDocumentImpl
    public void deletedText(CharacterDataImpl characterDataImpl, int i2, int i3) {
        if (this.ranges != null) {
            notifyRangesDeletedText(characterDataImpl, i2, i3);
        }
    }

    public void dispatchAggregateEvents(NodeImpl nodeImpl, AttrImpl attrImpl, String str, short s) {
        NodeImpl nodeImpl2;
        if (attrImpl != null) {
            LCount lookup = LCount.lookup(MutationEventImpl.DOM_ATTR_MODIFIED);
            nodeImpl2 = (NodeImpl) attrImpl.getOwnerElement();
            if (lookup.total > 0 && nodeImpl2 != null) {
                MutationEventImpl mutationEventImpl = new MutationEventImpl();
                mutationEventImpl.initMutationEvent(MutationEventImpl.DOM_ATTR_MODIFIED, true, false, attrImpl, str, attrImpl.getNodeValue(), attrImpl.getNodeName(), s);
                nodeImpl2.dispatchEvent(mutationEventImpl);
            }
        } else {
            nodeImpl2 = null;
        }
        if (LCount.lookup(MutationEventImpl.DOM_SUBTREE_MODIFIED).total > 0) {
            MutationEventImpl mutationEventImpl2 = new MutationEventImpl();
            mutationEventImpl2.initMutationEvent(MutationEventImpl.DOM_SUBTREE_MODIFIED, true, false, null, null, null, null, 0);
            if (attrImpl != null) {
                dispatchEvent(attrImpl, mutationEventImpl2);
                if (nodeImpl2 != null) {
                    dispatchEvent(nodeImpl2, mutationEventImpl2);
                    return;
                }
                return;
            }
            dispatchEvent(nodeImpl, mutationEventImpl2);
        }
    }

    public void dispatchAggregateEvents(NodeImpl nodeImpl, EnclosingAttr enclosingAttr) {
        if (enclosingAttr != null) {
            dispatchAggregateEvents(nodeImpl, enclosingAttr.node, enclosingAttr.oldvalue, 1);
        } else {
            dispatchAggregateEvents(nodeImpl, null, null, 0);
        }
    }

    @Override // org.apache.xerces.dom.CoreDocumentImpl
    public boolean dispatchEvent(NodeImpl nodeImpl, Event event) {
        String str;
        if (event == null) {
            return false;
        }
        EventImpl eventImpl = (EventImpl) event;
        if (!eventImpl.initialized || (str = eventImpl.type) == null || str.length() == 0) {
            throw new EventException(0, DOMMessageFormatter.formatMessage(DOMMessageFormatter.DOM_DOMAIN, "UNSPECIFIED_EVENT_TYPE_ERR", null));
        }
        LCount lookup = LCount.lookup(eventImpl.getType());
        if (lookup.total == 0) {
            return eventImpl.preventDefault;
        }
        eventImpl.target = nodeImpl;
        eventImpl.stopPropagation = false;
        eventImpl.preventDefault = false;
        ArrayList arrayList = new ArrayList(10);
        for (Node parentNode = nodeImpl.getParentNode(); parentNode != null; parentNode = parentNode.getParentNode()) {
            arrayList.add(parentNode);
        }
        if (lookup.captures > 0) {
            eventImpl.eventPhase = 1;
            for (int size = arrayList.size() - 1; size >= 0 && !eventImpl.stopPropagation; size--) {
                NodeImpl nodeImpl2 = (NodeImpl) arrayList.get(size);
                eventImpl.currentTarget = nodeImpl2;
                Vector eventListeners2 = getEventListeners(nodeImpl2);
                if (eventListeners2 != null) {
                    Vector vector = (Vector) eventListeners2.clone();
                    int size2 = vector.size();
                    for (int i2 = 0; i2 < size2; i2++) {
                        LEntry lEntry = (LEntry) vector.elementAt(i2);
                        if (lEntry.useCapture && lEntry.type.equals(eventImpl.type) && eventListeners2.contains(lEntry)) {
                            try {
                                lEntry.listener.handleEvent(eventImpl);
                            } catch (Exception unused) {
                            }
                        }
                    }
                }
            }
        }
        if (lookup.bubbles > 0) {
            eventImpl.eventPhase = 2;
            eventImpl.currentTarget = nodeImpl;
            Vector eventListeners3 = getEventListeners(nodeImpl);
            if (!eventImpl.stopPropagation && eventListeners3 != null) {
                Vector vector2 = (Vector) eventListeners3.clone();
                int size3 = vector2.size();
                for (int i3 = 0; i3 < size3; i3++) {
                    LEntry lEntry2 = (LEntry) vector2.elementAt(i3);
                    if (!lEntry2.useCapture && lEntry2.type.equals(eventImpl.type) && eventListeners3.contains(lEntry2)) {
                        try {
                            lEntry2.listener.handleEvent(eventImpl);
                        } catch (Exception unused2) {
                        }
                    }
                }
            }
            if (eventImpl.bubbles) {
                eventImpl.eventPhase = 3;
                int size4 = arrayList.size();
                for (int i4 = 0; i4 < size4 && !eventImpl.stopPropagation; i4++) {
                    NodeImpl nodeImpl3 = (NodeImpl) arrayList.get(i4);
                    eventImpl.currentTarget = nodeImpl3;
                    Vector eventListeners4 = getEventListeners(nodeImpl3);
                    if (eventListeners4 != null) {
                        Vector vector3 = (Vector) eventListeners4.clone();
                        int size5 = vector3.size();
                        for (int i5 = 0; i5 < size5; i5++) {
                            LEntry lEntry3 = (LEntry) vector3.elementAt(i5);
                            if (!lEntry3.useCapture && lEntry3.type.equals(eventImpl.type) && eventListeners4.contains(lEntry3)) {
                                try {
                                    lEntry3.listener.handleEvent(eventImpl);
                                } catch (Exception unused3) {
                                }
                            }
                        }
                    }
                }
            }
        }
        if (lookup.defaults > 0) {
            boolean z = eventImpl.cancelable;
        }
        return eventImpl.preventDefault;
    }

    public void dispatchEventToSubtree(Node node, Event event) {
        ((NodeImpl) node).dispatchEvent(event);
        if (node.getNodeType() == 1) {
            NamedNodeMap attributes = node.getAttributes();
            for (int length = attributes.getLength() - 1; length >= 0; length--) {
                dispatchingEventToSubtree(attributes.item(length), event);
            }
        }
        dispatchingEventToSubtree(node.getFirstChild(), event);
    }

    public void dispatchingEventToSubtree(Node node, Event event) {
        if (node != null) {
            ((NodeImpl) node).dispatchEvent(event);
            if (node.getNodeType() == 1) {
                NamedNodeMap attributes = node.getAttributes();
                for (int length = attributes.getLength() - 1; length >= 0; length--) {
                    dispatchingEventToSubtree(attributes.item(length), event);
                }
            }
            dispatchingEventToSubtree(node.getFirstChild(), event);
            dispatchingEventToSubtree(node.getNextSibling(), event);
        }
    }

    public Vector getEventListeners(NodeImpl nodeImpl) {
        Hashtable hashtable = this.eventListeners;
        if (hashtable == null) {
            return null;
        }
        return (Vector) hashtable.get(nodeImpl);
    }

    @Override // org.apache.xerces.dom.CoreDocumentImpl, org.w3c.dom.Document
    public DOMImplementation getImplementation() {
        return DOMImplementationImpl.getDOMImplementation();
    }

    @Override // org.apache.xerces.dom.CoreDocumentImpl
    public boolean getMutationEvents() {
        return this.mutationEvents;
    }

    @Override // org.apache.xerces.dom.CoreDocumentImpl
    public void insertedNode(NodeImpl nodeImpl, NodeImpl nodeImpl2, boolean z) {
        if (this.mutationEvents) {
            mutationEventsInsertedNode(nodeImpl, nodeImpl2, z);
        }
        if (this.ranges != null) {
            notifyRangesInsertedNode(nodeImpl2);
        }
    }

    @Override // org.apache.xerces.dom.CoreDocumentImpl
    public void insertedText(CharacterDataImpl characterDataImpl, int i2, int i3) {
        if (this.ranges != null) {
            notifyRangesInsertedText(characterDataImpl, i2, i3);
        }
    }

    @Override // org.apache.xerces.dom.CoreDocumentImpl
    public void insertingNode(NodeImpl nodeImpl, boolean z) {
        if (this.mutationEvents && !z) {
            saveEnclosingAttr(nodeImpl);
        }
    }

    @Override // org.apache.xerces.dom.CoreDocumentImpl
    public void modifiedAttrValue(AttrImpl attrImpl, String str) {
        if (this.mutationEvents) {
            dispatchAggregateEvents(attrImpl, attrImpl, str, 1);
        }
    }

    @Override // org.apache.xerces.dom.CoreDocumentImpl
    public void modifiedCharacterData(NodeImpl nodeImpl, String str, String str2, boolean z) {
        if (this.mutationEvents) {
            mutationEventsModifiedCharacterData(nodeImpl, str, str2, z);
        }
    }

    @Override // org.apache.xerces.dom.CoreDocumentImpl
    public void modifyingCharacterData(NodeImpl nodeImpl, boolean z) {
        if (this.mutationEvents && !z) {
            saveEnclosingAttr(nodeImpl);
        }
    }

    @Override // org.apache.xerces.dom.CoreDocumentImpl
    public void removeEventListener(NodeImpl nodeImpl, String str, EventListener eventListener, boolean z) {
        Vector eventListeners2;
        if (!(str == null || str.length() == 0 || eventListener == null || (eventListeners2 = getEventListeners(nodeImpl)) == null)) {
            for (int size = eventListeners2.size() - 1; size >= 0; size--) {
                LEntry lEntry = (LEntry) eventListeners2.elementAt(size);
                if (lEntry.useCapture == z && lEntry.listener == eventListener && lEntry.type.equals(str)) {
                    eventListeners2.removeElementAt(size);
                    if (eventListeners2.size() == 0) {
                        setEventListeners(nodeImpl, null);
                    }
                    LCount lookup = LCount.lookup(str);
                    if (z) {
                        lookup.captures--;
                    } else {
                        lookup.bubbles--;
                    }
                    lookup.total--;
                    return;
                }
            }
        }
    }

    public void removeNodeIterator(NodeIterator nodeIterator) {
        if (nodeIterator != null && this.iterators != null) {
            removeStaleIteratorReferences();
            Iterator it = this.iterators.iterator();
            while (it.hasNext()) {
                Object obj = ((Reference) it.next()).get();
                if (obj == nodeIterator) {
                    it.remove();
                    return;
                } else if (obj == null) {
                    it.remove();
                }
            }
        }
    }

    public void removeRange(Range range) {
        if (range != null && this.ranges != null) {
            removeStaleRangeReferences();
            Iterator it = this.ranges.iterator();
            while (it.hasNext()) {
                Object obj = ((Reference) it.next()).get();
                if (obj == range) {
                    it.remove();
                    return;
                } else if (obj == null) {
                    it.remove();
                }
            }
        }
    }

    @Override // org.apache.xerces.dom.CoreDocumentImpl
    public void removedAttrNode(AttrImpl attrImpl, NodeImpl nodeImpl, String str) {
        if (this.mutationEvents) {
            mutationEventsRemovedAttrNode(attrImpl, nodeImpl, str);
        }
    }

    @Override // org.apache.xerces.dom.CoreDocumentImpl
    public void removedNode(NodeImpl nodeImpl, boolean z) {
        if (this.mutationEvents && !z) {
            dispatchAggregateEvents(nodeImpl, this.savedEnclosingAttr);
        }
    }

    @Override // org.apache.xerces.dom.CoreDocumentImpl
    public void removingNode(NodeImpl nodeImpl, NodeImpl nodeImpl2, boolean z) {
        if (this.iterators != null) {
            notifyIteratorsRemovingNode(nodeImpl2);
        }
        if (this.ranges != null) {
            notifyRangesRemovingNode(nodeImpl2);
        }
        if (this.mutationEvents) {
            mutationEventsRemovingNode(nodeImpl, nodeImpl2, z);
        }
    }

    @Override // org.apache.xerces.dom.CoreDocumentImpl
    public void renamedAttrNode(Attr attr, Attr attr2) {
    }

    @Override // org.apache.xerces.dom.CoreDocumentImpl
    public void renamedElement(Element element, Element element2) {
    }

    @Override // org.apache.xerces.dom.CoreDocumentImpl
    public void replacedCharacterData(NodeImpl nodeImpl, String str, String str2) {
        modifiedCharacterData(nodeImpl, str, str2, false);
    }

    @Override // org.apache.xerces.dom.CoreDocumentImpl
    public void replacedNode(NodeImpl nodeImpl) {
        if (this.mutationEvents) {
            dispatchAggregateEvents(nodeImpl, this.savedEnclosingAttr);
        }
    }

    @Override // org.apache.xerces.dom.CoreDocumentImpl
    public void replacedText(CharacterDataImpl characterDataImpl) {
        if (this.ranges != null) {
            notifyRangesReplacedText(characterDataImpl);
        }
    }

    @Override // org.apache.xerces.dom.CoreDocumentImpl
    public void replacingData(NodeImpl nodeImpl) {
        if (this.mutationEvents) {
            saveEnclosingAttr(nodeImpl);
        }
    }

    @Override // org.apache.xerces.dom.CoreDocumentImpl
    public void replacingNode(NodeImpl nodeImpl) {
        if (this.mutationEvents) {
            saveEnclosingAttr(nodeImpl);
        }
    }

    public void saveEnclosingAttr(NodeImpl nodeImpl) {
        this.savedEnclosingAttr = null;
        if (LCount.lookup(MutationEventImpl.DOM_ATTR_MODIFIED).total > 0) {
            while (nodeImpl != null) {
                short nodeType = nodeImpl.getNodeType();
                if (nodeType == 2) {
                    EnclosingAttr enclosingAttr = new EnclosingAttr();
                    AttrImpl attrImpl = (AttrImpl) nodeImpl;
                    enclosingAttr.node = attrImpl;
                    enclosingAttr.oldvalue = attrImpl.getNodeValue();
                    this.savedEnclosingAttr = enclosingAttr;
                    return;
                } else if (nodeType == 5 || nodeType == 3) {
                    nodeImpl = nodeImpl.parentNode();
                } else {
                    return;
                }
            }
        }
    }

    @Override // org.apache.xerces.dom.CoreDocumentImpl
    public void setAttrNode(AttrImpl attrImpl, AttrImpl attrImpl2) {
        if (!this.mutationEvents) {
            return;
        }
        if (attrImpl2 == null) {
            dispatchAggregateEvents(attrImpl.ownerNode, attrImpl, null, 2);
        } else {
            dispatchAggregateEvents(attrImpl.ownerNode, attrImpl, attrImpl2.getNodeValue(), 1);
        }
    }

    public void setEventListeners(NodeImpl nodeImpl, Vector vector) {
        boolean z;
        if (this.eventListeners == null) {
            this.eventListeners = new Hashtable();
        }
        if (vector == null) {
            this.eventListeners.remove(nodeImpl);
            if (this.eventListeners.isEmpty()) {
                z = false;
            } else {
                return;
            }
        } else {
            this.eventListeners.put(nodeImpl, vector);
            z = true;
        }
        this.mutationEvents = z;
    }

    @Override // org.apache.xerces.dom.CoreDocumentImpl
    public void setMutationEvents(boolean z) {
        this.mutationEvents = z;
    }

    public void splitData(Node node, Node node2, int i2) {
        if (this.ranges != null) {
            notifyRangesSplitData(node, node2, i2);
        }
    }
}
