package org.apache.xerces.dom;

import b.b.a.a.a;
import org.apache.xerces.util.URI;
import org.w3c.dom.Attr;
import org.w3c.dom.DOMException;
import org.w3c.dom.Element;
import org.w3c.dom.ElementTraversal;
import org.w3c.dom.NamedNodeMap;
import org.w3c.dom.Node;
import org.w3c.dom.NodeList;
import org.w3c.dom.Text;
import org.w3c.dom.TypeInfo;

public class ElementImpl extends ParentNode implements Element, ElementTraversal, TypeInfo {
    public static final long serialVersionUID = 3717253516652722278L;
    public AttributeMap attributes;
    public String name;

    public ElementImpl() {
    }

    public ElementImpl(CoreDocumentImpl coreDocumentImpl, String str) {
        super(coreDocumentImpl);
        this.name = str;
        needsSyncData(true);
    }

    private Element getFirstElementChild(Node node) {
        Node node2 = node;
        while (node2 != null) {
            if (node2.getNodeType() == 1) {
                return (Element) node2;
            }
            Node node3 = node2;
            node2 = node2.getFirstChild();
            while (node2 == null && node != node3) {
                node2 = node3.getNextSibling();
                if (node2 == null && ((node3 = node3.getParentNode()) == null || node == node3)) {
                    return null;
                }
            }
        }
        return null;
    }

    private Element getLastElementChild(Node node) {
        Node node2 = node;
        while (node2 != null) {
            if (node2.getNodeType() == 1) {
                return (Element) node2;
            }
            Node node3 = node2;
            node2 = node2.getLastChild();
            while (node2 == null && node != node3) {
                node2 = node3.getPreviousSibling();
                if (node2 == null && ((node3 = node3.getParentNode()) == null || node == node3)) {
                    return null;
                }
            }
        }
        return null;
    }

    private Node getNextLogicalSibling(Node node) {
        Node nextSibling = node.getNextSibling();
        if (nextSibling == null) {
            do {
                node = node.getParentNode();
                if (node == null || node.getNodeType() != 5) {
                    break;
                }
                nextSibling = node.getNextSibling();
            } while (nextSibling == null);
        }
        return nextSibling;
    }

    private Node getPreviousLogicalSibling(Node node) {
        Node previousSibling = node.getPreviousSibling();
        if (previousSibling == null) {
            do {
                node = node.getParentNode();
                if (node == null || node.getNodeType() != 5) {
                    break;
                }
                previousSibling = node.getPreviousSibling();
            } while (previousSibling == null);
        }
        return previousSibling;
    }

    @Override // org.apache.xerces.dom.NodeImpl, org.w3c.dom.Node, org.apache.xerces.dom.ParentNode, org.apache.xerces.dom.ChildNode
    public Node cloneNode(boolean z) {
        ElementImpl elementImpl = (ElementImpl) super.cloneNode(z);
        AttributeMap attributeMap = this.attributes;
        if (attributeMap != null) {
            elementImpl.attributes = (AttributeMap) attributeMap.cloneMap(elementImpl);
        }
        return elementImpl;
    }

    @Override // org.w3c.dom.Element
    public String getAttribute(String str) {
        Attr attr;
        if (needsSyncData()) {
            synchronizeData();
        }
        AttributeMap attributeMap = this.attributes;
        return (attributeMap == null || (attr = (Attr) attributeMap.getNamedItem(str)) == null) ? "" : attr.getValue();
    }

    @Override // org.w3c.dom.Element
    public String getAttributeNS(String str, String str2) {
        Attr attr;
        if (needsSyncData()) {
            synchronizeData();
        }
        AttributeMap attributeMap = this.attributes;
        return (attributeMap == null || (attr = (Attr) attributeMap.getNamedItemNS(str, str2)) == null) ? "" : attr.getValue();
    }

    @Override // org.w3c.dom.Element
    public Attr getAttributeNode(String str) {
        if (needsSyncData()) {
            synchronizeData();
        }
        AttributeMap attributeMap = this.attributes;
        if (attributeMap == null) {
            return null;
        }
        return (Attr) attributeMap.getNamedItem(str);
    }

    @Override // org.w3c.dom.Element
    public Attr getAttributeNodeNS(String str, String str2) {
        if (needsSyncData()) {
            synchronizeData();
        }
        AttributeMap attributeMap = this.attributes;
        if (attributeMap == null) {
            return null;
        }
        return (Attr) attributeMap.getNamedItemNS(str, str2);
    }

    @Override // org.apache.xerces.dom.NodeImpl, org.w3c.dom.Node
    public NamedNodeMap getAttributes() {
        if (needsSyncData()) {
            synchronizeData();
        }
        if (this.attributes == null) {
            this.attributes = new AttributeMap(this, null);
        }
        return this.attributes;
    }

    @Override // org.apache.xerces.dom.NodeImpl, org.w3c.dom.Node
    public String getBaseURI() {
        Attr xMLBaseAttribute;
        if (needsSyncData()) {
            synchronizeData();
        }
        if (!(this.attributes == null || (xMLBaseAttribute = getXMLBaseAttribute()) == null)) {
            String nodeValue = xMLBaseAttribute.getNodeValue();
            if (nodeValue.length() != 0) {
                try {
                    URI uri = new URI(nodeValue, true);
                    if (uri.isAbsoluteURI()) {
                        return uri.toString();
                    }
                    String baseURI = this.ownerNode != null ? this.ownerNode.getBaseURI() : null;
                    if (baseURI != null) {
                        uri.absolutize(new URI(baseURI));
                        return uri.toString();
                    }
                    return null;
                } catch (URI.MalformedURIException unused) {
                }
            }
        }
        NodeImpl nodeImpl = this.ownerNode;
        if (nodeImpl != null) {
            return nodeImpl.getBaseURI();
        }
        return null;
    }

    @Override // org.w3c.dom.ElementTraversal
    public final int getChildElementCount() {
        int i2 = 0;
        for (Element firstElementChild = getFirstElementChild(); firstElementChild != null; firstElementChild = ((ElementImpl) firstElementChild).getNextElementSibling()) {
            i2++;
        }
        return i2;
    }

    public NamedNodeMapImpl getDefaultAttributes() {
        ElementDefinitionImpl elementDefinitionImpl;
        DocumentTypeImpl documentTypeImpl = (DocumentTypeImpl) this.ownerDocument.getDoctype();
        if (documentTypeImpl == null || (elementDefinitionImpl = (ElementDefinitionImpl) documentTypeImpl.getElements().getNamedItem(getNodeName())) == null) {
            return null;
        }
        return (NamedNodeMapImpl) elementDefinitionImpl.getAttributes();
    }

    @Override // org.w3c.dom.Element
    public NodeList getElementsByTagName(String str) {
        return new DeepNodeListImpl(this, str);
    }

    @Override // org.w3c.dom.Element
    public NodeList getElementsByTagNameNS(String str, String str2) {
        return new DeepNodeListImpl(this, str, str2);
    }

    @Override // org.w3c.dom.ElementTraversal
    public final Element getFirstElementChild() {
        Element firstElementChild;
        for (Node firstChild = getFirstChild(); firstChild != null; firstChild = firstChild.getNextSibling()) {
            short nodeType = firstChild.getNodeType();
            if (nodeType == 1) {
                return (Element) firstChild;
            }
            if (nodeType == 5 && (firstElementChild = getFirstElementChild(firstChild)) != null) {
                return firstElementChild;
            }
        }
        return null;
    }

    @Override // org.w3c.dom.ElementTraversal
    public final Element getLastElementChild() {
        Element lastElementChild;
        for (Node lastChild = getLastChild(); lastChild != null; lastChild = lastChild.getPreviousSibling()) {
            short nodeType = lastChild.getNodeType();
            if (nodeType == 1) {
                return (Element) lastChild;
            }
            if (nodeType == 5 && (lastElementChild = getLastElementChild(lastChild)) != null) {
                return lastElementChild;
            }
        }
        return null;
    }

    @Override // org.w3c.dom.ElementTraversal
    public final Element getNextElementSibling() {
        Element firstElementChild;
        Node nextLogicalSibling = getNextLogicalSibling(this);
        while (nextLogicalSibling != null) {
            short nodeType = nextLogicalSibling.getNodeType();
            if (nodeType == 1) {
                return (Element) nextLogicalSibling;
            }
            if (nodeType == 5 && (firstElementChild = getFirstElementChild(nextLogicalSibling)) != null) {
                return firstElementChild;
            }
            nextLogicalSibling = getNextLogicalSibling(nextLogicalSibling);
        }
        return null;
    }

    @Override // org.apache.xerces.dom.NodeImpl, org.w3c.dom.Node
    public String getNodeName() {
        if (needsSyncData()) {
            synchronizeData();
        }
        return this.name;
    }

    @Override // org.apache.xerces.dom.NodeImpl, org.w3c.dom.Node
    public short getNodeType() {
        return 1;
    }

    @Override // org.w3c.dom.ElementTraversal
    public final Element getPreviousElementSibling() {
        Element lastElementChild;
        Node previousLogicalSibling = getPreviousLogicalSibling(this);
        while (previousLogicalSibling != null) {
            short nodeType = previousLogicalSibling.getNodeType();
            if (nodeType == 1) {
                return (Element) previousLogicalSibling;
            }
            if (nodeType == 5 && (lastElementChild = getLastElementChild(previousLogicalSibling)) != null) {
                return lastElementChild;
            }
            previousLogicalSibling = getPreviousLogicalSibling(previousLogicalSibling);
        }
        return null;
    }

    @Override // org.w3c.dom.Element
    public TypeInfo getSchemaTypeInfo() {
        if (needsSyncData()) {
            synchronizeData();
        }
        return this;
    }

    @Override // org.w3c.dom.Element
    public String getTagName() {
        if (needsSyncData()) {
            synchronizeData();
        }
        return this.name;
    }

    @Override // org.w3c.dom.TypeInfo
    public String getTypeName() {
        return null;
    }

    @Override // org.w3c.dom.TypeInfo
    public String getTypeNamespace() {
        return null;
    }

    public Attr getXMLBaseAttribute() {
        return (Attr) this.attributes.getNamedItem("xml:base");
    }

    public int getXercesAttribute(String str, String str2) {
        if (needsSyncData()) {
            synchronizeData();
        }
        AttributeMap attributeMap = this.attributes;
        if (attributeMap == null) {
            return -1;
        }
        return attributeMap.getNamedItemIndex(str, str2);
    }

    @Override // org.w3c.dom.Element
    public boolean hasAttribute(String str) {
        return getAttributeNode(str) != null;
    }

    @Override // org.w3c.dom.Element
    public boolean hasAttributeNS(String str, String str2) {
        return getAttributeNodeNS(str, str2) != null;
    }

    @Override // org.apache.xerces.dom.NodeImpl, org.w3c.dom.Node
    public boolean hasAttributes() {
        if (needsSyncData()) {
            synchronizeData();
        }
        AttributeMap attributeMap = this.attributes;
        return (attributeMap == null || attributeMap.getLength() == 0) ? false : true;
    }

    @Override // org.w3c.dom.TypeInfo
    public boolean isDerivedFrom(String str, String str2, int i2) {
        return false;
    }

    @Override // org.apache.xerces.dom.NodeImpl, org.w3c.dom.Node, org.apache.xerces.dom.ParentNode
    public boolean isEqualNode(Node node) {
        if (!super.isEqualNode(node)) {
            return false;
        }
        boolean hasAttributes = hasAttributes();
        Element element = (Element) node;
        if (hasAttributes != element.hasAttributes()) {
            return false;
        }
        if (!hasAttributes) {
            return true;
        }
        NamedNodeMap attributes2 = getAttributes();
        NamedNodeMap attributes3 = element.getAttributes();
        int length = attributes2.getLength();
        if (length != attributes3.getLength()) {
            return false;
        }
        for (int i2 = 0; i2 < length; i2++) {
            Node item = attributes2.item(i2);
            if (item.getLocalName() == null) {
                Node namedItem = attributes3.getNamedItem(item.getNodeName());
                if (namedItem == null || !((NodeImpl) item).isEqualNode(namedItem)) {
                    return false;
                }
            } else {
                Node namedItemNS = attributes3.getNamedItemNS(item.getNamespaceURI(), item.getLocalName());
                if (namedItemNS == null || !((NodeImpl) item).isEqualNode(namedItemNS)) {
                    return false;
                }
            }
        }
        return true;
    }

    public void moveSpecifiedAttributes(ElementImpl elementImpl) {
        if (needsSyncData()) {
            synchronizeData();
        }
        if (elementImpl.hasAttributes()) {
            if (this.attributes == null) {
                this.attributes = new AttributeMap(this, null);
            }
            this.attributes.moveSpecifiedAttributes(elementImpl.attributes);
        }
    }

    @Override // org.apache.xerces.dom.NodeImpl, org.w3c.dom.Node, org.apache.xerces.dom.ParentNode
    public void normalize() {
        if (!isNormalized()) {
            if (needsSyncChildren()) {
                synchronizeChildren();
            }
            ChildNode childNode = this.firstChild;
            while (childNode != null) {
                ChildNode childNode2 = childNode.nextSibling;
                if (childNode.getNodeType() == 3) {
                    if (childNode2 != null && childNode2.getNodeType() == 3) {
                        ((Text) childNode).appendData(childNode2.getNodeValue());
                        removeChild(childNode2);
                    } else if (childNode.getNodeValue() == null || childNode.getNodeValue().length() == 0) {
                        removeChild(childNode);
                    }
                } else if (childNode.getNodeType() == 1) {
                    childNode.normalize();
                }
                childNode = childNode2;
            }
            if (this.attributes != null) {
                for (int i2 = 0; i2 < this.attributes.getLength(); i2++) {
                    this.attributes.item(i2).normalize();
                }
            }
            isNormalized(true);
        }
    }

    public void reconcileDefaultAttributes() {
        if (this.attributes != null) {
            this.attributes.reconcileDefaults(getDefaultAttributes());
        }
    }

    @Override // org.w3c.dom.Element
    public void removeAttribute(String str) {
        if (!this.ownerDocument.errorChecking || !isReadOnly()) {
            if (needsSyncData()) {
                synchronizeData();
            }
            AttributeMap attributeMap = this.attributes;
            if (attributeMap != null) {
                attributeMap.safeRemoveNamedItem(str);
                return;
            }
            return;
        }
        throw new DOMException(7, DOMMessageFormatter.formatMessage(DOMMessageFormatter.DOM_DOMAIN, "NO_MODIFICATION_ALLOWED_ERR", null));
    }

    @Override // org.w3c.dom.Element
    public void removeAttributeNS(String str, String str2) {
        if (!this.ownerDocument.errorChecking || !isReadOnly()) {
            if (needsSyncData()) {
                synchronizeData();
            }
            AttributeMap attributeMap = this.attributes;
            if (attributeMap != null) {
                attributeMap.safeRemoveNamedItemNS(str, str2);
                return;
            }
            return;
        }
        throw new DOMException(7, DOMMessageFormatter.formatMessage(DOMMessageFormatter.DOM_DOMAIN, "NO_MODIFICATION_ALLOWED_ERR", null));
    }

    @Override // org.w3c.dom.Element
    public Attr removeAttributeNode(Attr attr) {
        if (!this.ownerDocument.errorChecking || !isReadOnly()) {
            if (needsSyncData()) {
                synchronizeData();
            }
            AttributeMap attributeMap = this.attributes;
            if (attributeMap != null) {
                return (Attr) attributeMap.removeItem(attr, true);
            }
            throw new DOMException(8, DOMMessageFormatter.formatMessage(DOMMessageFormatter.DOM_DOMAIN, "NOT_FOUND_ERR", null));
        }
        throw new DOMException(7, DOMMessageFormatter.formatMessage(DOMMessageFormatter.DOM_DOMAIN, "NO_MODIFICATION_ALLOWED_ERR", null));
    }

    public void rename(String str) {
        if (needsSyncData()) {
            synchronizeData();
        }
        if (this.ownerDocument.errorChecking) {
            if (str.indexOf(58) != -1) {
                throw new DOMException(14, DOMMessageFormatter.formatMessage(DOMMessageFormatter.DOM_DOMAIN, "NAMESPACE_ERR", null));
            } else if (!CoreDocumentImpl.isXMLName(str, this.ownerDocument.isXML11Version())) {
                throw new DOMException(5, DOMMessageFormatter.formatMessage(DOMMessageFormatter.DOM_DOMAIN, "INVALID_CHARACTER_ERR", null));
            }
        }
        this.name = str;
        reconcileDefaultAttributes();
    }

    @Override // org.w3c.dom.Element
    public void setAttribute(String str, String str2) {
        if (!this.ownerDocument.errorChecking || !isReadOnly()) {
            if (needsSyncData()) {
                synchronizeData();
            }
            Attr attributeNode = getAttributeNode(str);
            if (attributeNode == null) {
                Attr createAttribute = getOwnerDocument().createAttribute(str);
                if (this.attributes == null) {
                    this.attributes = new AttributeMap(this, null);
                }
                createAttribute.setNodeValue(str2);
                this.attributes.setNamedItem(createAttribute);
                return;
            }
            attributeNode.setNodeValue(str2);
            return;
        }
        throw new DOMException(7, DOMMessageFormatter.formatMessage(DOMMessageFormatter.DOM_DOMAIN, "NO_MODIFICATION_ALLOWED_ERR", null));
    }

    @Override // org.w3c.dom.Element
    public void setAttributeNS(String str, String str2, String str3) {
        String str4;
        String str5;
        if (!this.ownerDocument.errorChecking || !isReadOnly()) {
            if (needsSyncData()) {
                synchronizeData();
            }
            int indexOf = str2.indexOf(58);
            if (indexOf < 0) {
                str5 = str2;
                str4 = null;
            } else {
                str4 = str2.substring(0, indexOf);
                str5 = str2.substring(indexOf + 1);
            }
            Attr attributeNodeNS = getAttributeNodeNS(str, str5);
            if (attributeNodeNS == null) {
                Attr createAttributeNS = getOwnerDocument().createAttributeNS(str, str2);
                if (this.attributes == null) {
                    this.attributes = new AttributeMap(this, null);
                }
                createAttributeNS.setNodeValue(str3);
                this.attributes.setNamedItemNS(createAttributeNS);
                return;
            }
            if (attributeNodeNS instanceof AttrNSImpl) {
                AttrNSImpl attrNSImpl = (AttrNSImpl) attributeNodeNS;
                if (str4 != null) {
                    str5 = a.a(str4, ":", str5);
                }
                attrNSImpl.name = str5;
            } else {
                attributeNodeNS = ((CoreDocumentImpl) getOwnerDocument()).createAttributeNS(str, str2, str5);
                this.attributes.setNamedItemNS(attributeNodeNS);
            }
            attributeNodeNS.setNodeValue(str3);
            return;
        }
        throw new DOMException(7, DOMMessageFormatter.formatMessage(DOMMessageFormatter.DOM_DOMAIN, "NO_MODIFICATION_ALLOWED_ERR", null));
    }

    @Override // org.w3c.dom.Element
    public Attr setAttributeNode(Attr attr) {
        if (needsSyncData()) {
            synchronizeData();
        }
        if (this.ownerDocument.errorChecking) {
            if (isReadOnly()) {
                throw new DOMException(7, DOMMessageFormatter.formatMessage(DOMMessageFormatter.DOM_DOMAIN, "NO_MODIFICATION_ALLOWED_ERR", null));
            } else if (attr.getOwnerDocument() != this.ownerDocument) {
                throw new DOMException(4, DOMMessageFormatter.formatMessage(DOMMessageFormatter.DOM_DOMAIN, "WRONG_DOCUMENT_ERR", null));
            }
        }
        if (this.attributes == null) {
            this.attributes = new AttributeMap(this, null);
        }
        return (Attr) this.attributes.setNamedItem(attr);
    }

    @Override // org.w3c.dom.Element
    public Attr setAttributeNodeNS(Attr attr) {
        if (needsSyncData()) {
            synchronizeData();
        }
        if (this.ownerDocument.errorChecking) {
            if (isReadOnly()) {
                throw new DOMException(7, DOMMessageFormatter.formatMessage(DOMMessageFormatter.DOM_DOMAIN, "NO_MODIFICATION_ALLOWED_ERR", null));
            } else if (attr.getOwnerDocument() != this.ownerDocument) {
                throw new DOMException(4, DOMMessageFormatter.formatMessage(DOMMessageFormatter.DOM_DOMAIN, "WRONG_DOCUMENT_ERR", null));
            }
        }
        if (this.attributes == null) {
            this.attributes = new AttributeMap(this, null);
        }
        return (Attr) this.attributes.setNamedItemNS(attr);
    }

    @Override // org.w3c.dom.Element
    public void setIdAttribute(String str, boolean z) {
        if (needsSyncData()) {
            synchronizeData();
        }
        Attr attributeNode = getAttributeNode(str);
        if (attributeNode != null) {
            if (this.ownerDocument.errorChecking) {
                if (isReadOnly()) {
                    throw new DOMException(7, DOMMessageFormatter.formatMessage(DOMMessageFormatter.DOM_DOMAIN, "NO_MODIFICATION_ALLOWED_ERR", null));
                } else if (attributeNode.getOwnerElement() != this) {
                    throw new DOMException(8, DOMMessageFormatter.formatMessage(DOMMessageFormatter.DOM_DOMAIN, "NOT_FOUND_ERR", null));
                }
            }
            ((AttrImpl) attributeNode).isIdAttribute(z);
            if (!z) {
                this.ownerDocument.removeIdentifier(attributeNode.getValue());
            } else {
                this.ownerDocument.putIdentifier(attributeNode.getValue(), this);
            }
        } else {
            throw new DOMException(8, DOMMessageFormatter.formatMessage(DOMMessageFormatter.DOM_DOMAIN, "NOT_FOUND_ERR", null));
        }
    }

    @Override // org.w3c.dom.Element
    public void setIdAttributeNS(String str, String str2, boolean z) {
        if (needsSyncData()) {
            synchronizeData();
        }
        Attr attributeNodeNS = getAttributeNodeNS(str, str2);
        if (attributeNodeNS != null) {
            if (this.ownerDocument.errorChecking) {
                if (isReadOnly()) {
                    throw new DOMException(7, DOMMessageFormatter.formatMessage(DOMMessageFormatter.DOM_DOMAIN, "NO_MODIFICATION_ALLOWED_ERR", null));
                } else if (attributeNodeNS.getOwnerElement() != this) {
                    throw new DOMException(8, DOMMessageFormatter.formatMessage(DOMMessageFormatter.DOM_DOMAIN, "NOT_FOUND_ERR", null));
                }
            }
            ((AttrImpl) attributeNodeNS).isIdAttribute(z);
            CoreDocumentImpl coreDocumentImpl = this.ownerDocument;
            String value = attributeNodeNS.getValue();
            if (!z) {
                coreDocumentImpl.removeIdentifier(value);
            } else {
                coreDocumentImpl.putIdentifier(value, this);
            }
        } else {
            throw new DOMException(8, DOMMessageFormatter.formatMessage(DOMMessageFormatter.DOM_DOMAIN, "NOT_FOUND_ERR", null));
        }
    }

    @Override // org.w3c.dom.Element
    public void setIdAttributeNode(Attr attr, boolean z) {
        if (needsSyncData()) {
            synchronizeData();
        }
        if (this.ownerDocument.errorChecking) {
            if (isReadOnly()) {
                throw new DOMException(7, DOMMessageFormatter.formatMessage(DOMMessageFormatter.DOM_DOMAIN, "NO_MODIFICATION_ALLOWED_ERR", null));
            } else if (attr.getOwnerElement() != this) {
                throw new DOMException(8, DOMMessageFormatter.formatMessage(DOMMessageFormatter.DOM_DOMAIN, "NOT_FOUND_ERR", null));
            }
        }
        ((AttrImpl) attr).isIdAttribute(z);
        if (!z) {
            this.ownerDocument.removeIdentifier(attr.getValue());
        } else {
            this.ownerDocument.putIdentifier(attr.getValue(), this);
        }
    }

    @Override // org.apache.xerces.dom.NodeImpl, org.apache.xerces.dom.ParentNode
    public void setOwnerDocument(CoreDocumentImpl coreDocumentImpl) {
        super.setOwnerDocument(coreDocumentImpl);
        AttributeMap attributeMap = this.attributes;
        if (attributeMap != null) {
            attributeMap.setOwnerDocument(coreDocumentImpl);
        }
    }

    @Override // org.apache.xerces.dom.NodeImpl, org.apache.xerces.dom.ParentNode
    public void setReadOnly(boolean z, boolean z2) {
        super.setReadOnly(z, z2);
        AttributeMap attributeMap = this.attributes;
        if (attributeMap != null) {
            attributeMap.setReadOnly(z, true);
        }
    }

    public int setXercesAttributeNode(Attr attr) {
        if (needsSyncData()) {
            synchronizeData();
        }
        if (this.attributes == null) {
            this.attributes = new AttributeMap(this, null);
        }
        return this.attributes.addItem(attr);
    }

    public void setupDefaultAttributes() {
        NamedNodeMapImpl defaultAttributes = getDefaultAttributes();
        if (defaultAttributes != null) {
            this.attributes = new AttributeMap(this, defaultAttributes);
        }
    }

    @Override // org.apache.xerces.dom.NodeImpl
    public void synchronizeData() {
        needsSyncData(false);
        boolean mutationEvents = this.ownerDocument.getMutationEvents();
        this.ownerDocument.setMutationEvents(false);
        setupDefaultAttributes();
        this.ownerDocument.setMutationEvents(mutationEvents);
    }
}
