package org.apache.xerces.dom;

import java.io.ObjectInputStream;
import java.io.ObjectOutputStream;
import java.io.Serializable;
import java.util.ArrayList;
import java.util.List;
import java.util.Vector;
import org.w3c.dom.DOMException;
import org.w3c.dom.NamedNodeMap;
import org.w3c.dom.Node;

public class NamedNodeMapImpl implements NamedNodeMap, Serializable {
    public static final short CHANGED = 2;
    public static final short HASDEFAULTS = 4;
    public static final short READONLY = 1;
    public static final long serialVersionUID = -7039242451046758020L;
    public short flags;
    public List nodes;
    public NodeImpl ownerNode;

    public NamedNodeMapImpl(NodeImpl nodeImpl) {
        this.ownerNode = nodeImpl;
    }

    private void readObject(ObjectInputStream objectInputStream) {
        objectInputStream.defaultReadObject();
        if (this.nodes != null) {
            this.nodes = new ArrayList(this.nodes);
        }
    }

    private void writeObject(ObjectOutputStream objectOutputStream) {
        Vector vector = this.nodes;
        if (vector != null) {
            try {
                vector = new Vector(vector);
            } finally {
                this.nodes = vector;
            }
        }
        objectOutputStream.defaultWriteObject();
        this.nodes = vector;
    }

    public int addItem(Node node) {
        int findNamePoint = findNamePoint(node.getNamespaceURI(), node.getLocalName());
        if (findNamePoint >= 0) {
            this.nodes.set(findNamePoint, node);
        } else {
            findNamePoint = findNamePoint(node.getNodeName(), 0);
            if (findNamePoint < 0) {
                findNamePoint = -1 - findNamePoint;
                if (this.nodes == null) {
                    this.nodes = new ArrayList(5);
                }
            }
            this.nodes.add(findNamePoint, node);
        }
        return findNamePoint;
    }

    public final void changed(boolean z) {
        this.flags = (short) (z ? this.flags | 2 : this.flags & -3);
    }

    public final boolean changed() {
        return (this.flags & 2) != 0;
    }

    public void cloneContent(NamedNodeMapImpl namedNodeMapImpl) {
        int size;
        List list = namedNodeMapImpl.nodes;
        if (!(list == null || (size = list.size()) == 0)) {
            List list2 = this.nodes;
            if (list2 == null) {
                this.nodes = new ArrayList(size);
            } else {
                list2.clear();
            }
            for (int i2 = 0; i2 < size; i2++) {
                NodeImpl nodeImpl = (NodeImpl) namedNodeMapImpl.nodes.get(i2);
                NodeImpl nodeImpl2 = (NodeImpl) nodeImpl.cloneNode(true);
                nodeImpl2.isSpecified(nodeImpl.isSpecified());
                this.nodes.add(nodeImpl2);
            }
        }
    }

    public ArrayList cloneMap(ArrayList arrayList) {
        if (arrayList == null) {
            arrayList = new ArrayList(5);
        }
        arrayList.clear();
        List list = this.nodes;
        if (list != null) {
            int size = list.size();
            for (int i2 = 0; i2 < size; i2++) {
                arrayList.add(this.nodes.get(i2));
            }
        }
        return arrayList;
    }

    public NamedNodeMapImpl cloneMap(NodeImpl nodeImpl) {
        NamedNodeMapImpl namedNodeMapImpl = new NamedNodeMapImpl(nodeImpl);
        namedNodeMapImpl.cloneContent(this);
        return namedNodeMapImpl;
    }

    public int findNamePoint(String str, int i2) {
        List list = this.nodes;
        int i3 = 0;
        if (list != null) {
            int size = list.size() - 1;
            while (i2 <= size) {
                i3 = (i2 + size) / 2;
                int compareTo = str.compareTo(((Node) this.nodes.get(i3)).getNodeName());
                if (compareTo == 0) {
                    return i3;
                }
                if (compareTo < 0) {
                    size = i3 - 1;
                } else {
                    i2 = i3 + 1;
                }
            }
            if (i2 > i3) {
                i3 = i2;
            }
        }
        return -1 - i3;
    }

    public int findNamePoint(String str, String str2) {
        List list = this.nodes;
        if (list == null || str2 == null) {
            return -1;
        }
        int size = list.size();
        for (int i2 = 0; i2 < size; i2++) {
            NodeImpl nodeImpl = (NodeImpl) this.nodes.get(i2);
            String namespaceURI = nodeImpl.getNamespaceURI();
            String localName = nodeImpl.getLocalName();
            if (str == null) {
                if (namespaceURI == null && (str2.equals(localName) || (localName == null && str2.equals(nodeImpl.getNodeName())))) {
                    return i2;
                }
            } else if (str.equals(namespaceURI) && str2.equals(localName)) {
                return i2;
            }
        }
        return -1;
    }

    public Object getItem(int i2) {
        List list = this.nodes;
        if (list != null) {
            return list.get(i2);
        }
        return null;
    }

    @Override // org.w3c.dom.NamedNodeMap
    public int getLength() {
        List list = this.nodes;
        if (list != null) {
            return list.size();
        }
        return 0;
    }

    @Override // org.w3c.dom.NamedNodeMap
    public Node getNamedItem(String str) {
        int findNamePoint = findNamePoint(str, 0);
        if (findNamePoint < 0) {
            return null;
        }
        return (Node) this.nodes.get(findNamePoint);
    }

    public int getNamedItemIndex(String str, String str2) {
        return findNamePoint(str, str2);
    }

    @Override // org.w3c.dom.NamedNodeMap
    public Node getNamedItemNS(String str, String str2) {
        int findNamePoint = findNamePoint(str, str2);
        if (findNamePoint < 0) {
            return null;
        }
        return (Node) this.nodes.get(findNamePoint);
    }

    public boolean getReadOnly() {
        return isReadOnly();
    }

    public final void hasDefaults(boolean z) {
        this.flags = (short) (z ? this.flags | 4 : this.flags & -5);
    }

    public final boolean hasDefaults() {
        return (this.flags & 4) != 0;
    }

    public final void isReadOnly(boolean z) {
        this.flags = (short) (z ? this.flags | 1 : this.flags & -2);
    }

    public final boolean isReadOnly() {
        return (this.flags & 1) != 0;
    }

    @Override // org.w3c.dom.NamedNodeMap
    public Node item(int i2) {
        List list = this.nodes;
        if (list == null || i2 >= list.size()) {
            return null;
        }
        return (Node) this.nodes.get(i2);
    }

    public boolean precedes(Node node, Node node2) {
        List list = this.nodes;
        if (list != null) {
            int size = list.size();
            for (int i2 = 0; i2 < size; i2++) {
                Node node3 = (Node) this.nodes.get(i2);
                if (node3 == node) {
                    return true;
                }
                if (node3 == node2) {
                    return false;
                }
            }
        }
        return false;
    }

    public void removeAll() {
        List list = this.nodes;
        if (list != null) {
            list.clear();
        }
    }

    public void removeItem(int i2) {
        List list = this.nodes;
        if (list != null && i2 < list.size()) {
            this.nodes.remove(i2);
        }
    }

    @Override // org.w3c.dom.NamedNodeMap
    public Node removeNamedItem(String str) {
        if (!isReadOnly()) {
            int findNamePoint = findNamePoint(str, 0);
            if (findNamePoint >= 0) {
                NodeImpl nodeImpl = (NodeImpl) this.nodes.get(findNamePoint);
                this.nodes.remove(findNamePoint);
                return nodeImpl;
            }
            throw new DOMException(8, DOMMessageFormatter.formatMessage(DOMMessageFormatter.DOM_DOMAIN, "NOT_FOUND_ERR", null));
        }
        throw new DOMException(7, DOMMessageFormatter.formatMessage(DOMMessageFormatter.DOM_DOMAIN, "NO_MODIFICATION_ALLOWED_ERR", null));
    }

    @Override // org.w3c.dom.NamedNodeMap
    public Node removeNamedItemNS(String str, String str2) {
        if (!isReadOnly()) {
            int findNamePoint = findNamePoint(str, str2);
            if (findNamePoint >= 0) {
                NodeImpl nodeImpl = (NodeImpl) this.nodes.get(findNamePoint);
                this.nodes.remove(findNamePoint);
                return nodeImpl;
            }
            throw new DOMException(8, DOMMessageFormatter.formatMessage(DOMMessageFormatter.DOM_DOMAIN, "NOT_FOUND_ERR", null));
        }
        throw new DOMException(7, DOMMessageFormatter.formatMessage(DOMMessageFormatter.DOM_DOMAIN, "NO_MODIFICATION_ALLOWED_ERR", null));
    }

    @Override // org.w3c.dom.NamedNodeMap
    public Node setNamedItem(Node node) {
        CoreDocumentImpl ownerDocument = this.ownerNode.ownerDocument();
        if (ownerDocument.errorChecking) {
            if (isReadOnly()) {
                throw new DOMException(7, DOMMessageFormatter.formatMessage(DOMMessageFormatter.DOM_DOMAIN, "NO_MODIFICATION_ALLOWED_ERR", null));
            } else if (node.getOwnerDocument() != ownerDocument) {
                throw new DOMException(4, DOMMessageFormatter.formatMessage(DOMMessageFormatter.DOM_DOMAIN, "WRONG_DOCUMENT_ERR", null));
            }
        }
        int findNamePoint = findNamePoint(node.getNodeName(), 0);
        if (findNamePoint >= 0) {
            NodeImpl nodeImpl = (NodeImpl) this.nodes.get(findNamePoint);
            this.nodes.set(findNamePoint, node);
            return nodeImpl;
        }
        int i2 = -1 - findNamePoint;
        if (this.nodes == null) {
            this.nodes = new ArrayList(5);
        }
        this.nodes.add(i2, node);
        return null;
    }

    @Override // org.w3c.dom.NamedNodeMap
    public Node setNamedItemNS(Node node) {
        CoreDocumentImpl ownerDocument = this.ownerNode.ownerDocument();
        NodeImpl nodeImpl = null;
        if (ownerDocument.errorChecking) {
            if (isReadOnly()) {
                throw new DOMException(7, DOMMessageFormatter.formatMessage(DOMMessageFormatter.DOM_DOMAIN, "NO_MODIFICATION_ALLOWED_ERR", null));
            } else if (node.getOwnerDocument() != ownerDocument) {
                throw new DOMException(4, DOMMessageFormatter.formatMessage(DOMMessageFormatter.DOM_DOMAIN, "WRONG_DOCUMENT_ERR", null));
            }
        }
        int findNamePoint = findNamePoint(node.getNamespaceURI(), node.getLocalName());
        if (findNamePoint >= 0) {
            NodeImpl nodeImpl2 = (NodeImpl) this.nodes.get(findNamePoint);
            this.nodes.set(findNamePoint, node);
            return nodeImpl2;
        }
        int findNamePoint2 = findNamePoint(node.getNodeName(), 0);
        if (findNamePoint2 >= 0) {
            nodeImpl = (NodeImpl) this.nodes.get(findNamePoint2);
        } else {
            findNamePoint2 = -1 - findNamePoint2;
            if (this.nodes == null) {
                this.nodes = new ArrayList(5);
            }
        }
        this.nodes.add(findNamePoint2, node);
        return nodeImpl;
    }

    public void setOwnerDocument(CoreDocumentImpl coreDocumentImpl) {
        List list = this.nodes;
        if (list != null) {
            int size = list.size();
            for (int i2 = 0; i2 < size; i2++) {
                ((NodeImpl) item(i2)).setOwnerDocument(coreDocumentImpl);
            }
        }
    }

    public void setReadOnly(boolean z, boolean z2) {
        List list;
        isReadOnly(z);
        if (z2 && (list = this.nodes) != null) {
            for (int size = list.size() - 1; size >= 0; size--) {
                ((NodeImpl) this.nodes.get(size)).setReadOnly(z, z2);
            }
        }
    }
}
