package org.apache.xerces.dom;

import org.w3c.dom.DOMException;
import org.w3c.dom.Node;
import org.w3c.dom.traversal.NodeFilter;
import org.w3c.dom.traversal.NodeIterator;

public class NodeIteratorImpl implements NodeIterator {
    public Node fCurrentNode;
    public boolean fDetach = false;
    public DocumentImpl fDocument;
    public boolean fEntityReferenceExpansion;
    public boolean fForward = true;
    public NodeFilter fNodeFilter;
    public Node fRoot;
    public int fWhatToShow = -1;

    public NodeIteratorImpl(DocumentImpl documentImpl, Node node, int i2, NodeFilter nodeFilter, boolean z) {
        this.fDocument = documentImpl;
        this.fRoot = node;
        this.fCurrentNode = null;
        this.fWhatToShow = i2;
        this.fNodeFilter = nodeFilter;
        this.fEntityReferenceExpansion = z;
    }

    public boolean acceptNode(Node node) {
        if (this.fNodeFilter != null) {
            return (this.fWhatToShow & (1 << (node.getNodeType() - 1))) != 0 && this.fNodeFilter.acceptNode(node) == 1;
        }
        return ((1 << (node.getNodeType() - 1)) & this.fWhatToShow) != 0;
    }

    @Override // org.w3c.dom.traversal.NodeIterator
    public void detach() {
        this.fDetach = true;
        this.fDocument.removeNodeIterator(this);
    }

    @Override // org.w3c.dom.traversal.NodeIterator
    public boolean getExpandEntityReferences() {
        return this.fEntityReferenceExpansion;
    }

    @Override // org.w3c.dom.traversal.NodeIterator
    public NodeFilter getFilter() {
        return this.fNodeFilter;
    }

    @Override // org.w3c.dom.traversal.NodeIterator
    public Node getRoot() {
        return this.fRoot;
    }

    @Override // org.w3c.dom.traversal.NodeIterator
    public int getWhatToShow() {
        return this.fWhatToShow;
    }

    public Node matchNodeOrParent(Node node) {
        Node node2 = this.fCurrentNode;
        if (node2 == null) {
            return null;
        }
        while (node2 != this.fRoot) {
            if (node == node2) {
                return node2;
            }
            node2 = node2.getParentNode();
        }
        return null;
    }

    @Override // org.w3c.dom.traversal.NodeIterator
    public Node nextNode() {
        if (this.fDetach) {
            throw new DOMException(11, DOMMessageFormatter.formatMessage(DOMMessageFormatter.DOM_DOMAIN, "INVALID_STATE_ERR", null));
        } else if (this.fRoot == null) {
            return null;
        } else {
            Node node = this.fCurrentNode;
            boolean z = false;
            while (!z) {
                node = (this.fForward || node == null) ? (this.fEntityReferenceExpansion || node == null || node.getNodeType() != 5) ? nextNode(node, true) : nextNode(node, false) : this.fCurrentNode;
                this.fForward = true;
                if (node == null) {
                    return null;
                }
                z = acceptNode(node);
                if (z) {
                    this.fCurrentNode = node;
                    return node;
                }
            }
            return null;
        }
    }

    public Node nextNode(Node node, boolean z) {
        Node nextSibling;
        if (node == null) {
            return this.fRoot;
        }
        if (z && node.hasChildNodes()) {
            return node.getFirstChild();
        }
        if (node == this.fRoot) {
            return null;
        }
        Node nextSibling2 = node.getNextSibling();
        if (nextSibling2 != null) {
            return nextSibling2;
        }
        do {
            node = node.getParentNode();
            if (node == null || node == this.fRoot) {
                return null;
            }
            nextSibling = node.getNextSibling();
        } while (nextSibling == null);
        return nextSibling;
    }

    @Override // org.w3c.dom.traversal.NodeIterator
    public Node previousNode() {
        if (this.fDetach) {
            throw new DOMException(11, DOMMessageFormatter.formatMessage(DOMMessageFormatter.DOM_DOMAIN, "INVALID_STATE_ERR", null));
        } else if (this.fRoot == null || (r0 = this.fCurrentNode) == null) {
            return null;
        } else {
            boolean z = false;
            while (!z) {
                Node node = (!this.fForward || node == null) ? previousNode(node) : this.fCurrentNode;
                this.fForward = false;
                if (node == null) {
                    return null;
                }
                z = acceptNode(node);
                if (z) {
                    this.fCurrentNode = node;
                    return node;
                }
            }
            return null;
        }
    }

    public Node previousNode(Node node) {
        if (node == this.fRoot) {
            return null;
        }
        Node previousSibling = node.getPreviousSibling();
        if (previousSibling == null) {
            return node.getParentNode();
        }
        if (previousSibling.hasChildNodes() && (this.fEntityReferenceExpansion || previousSibling.getNodeType() != 5)) {
            while (previousSibling.hasChildNodes()) {
                previousSibling = previousSibling.getLastChild();
            }
        }
        return previousSibling;
    }

    public void removeNode(Node node) {
        Node matchNodeOrParent;
        if (node != null && (matchNodeOrParent = matchNodeOrParent(node)) != null) {
            if (this.fForward) {
                this.fCurrentNode = previousNode(matchNodeOrParent);
                return;
            }
            Node nextNode = nextNode(matchNodeOrParent, false);
            if (nextNode != null) {
                this.fCurrentNode = nextNode;
                return;
            }
            this.fCurrentNode = previousNode(matchNodeOrParent);
            this.fForward = true;
        }
    }
}
