package org.apache.xerces.dom;

import java.io.ObjectInputStream;
import java.io.ObjectOutputStream;
import java.io.Serializable;
import org.w3c.dom.DOMException;
import org.w3c.dom.Document;
import org.w3c.dom.Node;
import org.w3c.dom.NodeList;
import org.w3c.dom.UserDataHandler;

public abstract class ParentNode extends ChildNode {
    public static final long serialVersionUID = 2815829867152120872L;
    public transient NodeListCache fNodeListCache = null;
    public ChildNode firstChild = null;
    public CoreDocumentImpl ownerDocument;

    public class UserDataRecord implements Serializable {
        public static final long serialVersionUID = 3258126977134310455L;
        public Object fData;
        public UserDataHandler fHandler;

        public UserDataRecord(Object obj, UserDataHandler userDataHandler) {
            this.fData = obj;
            this.fHandler = userDataHandler;
        }
    }

    public ParentNode() {
    }

    public ParentNode(CoreDocumentImpl coreDocumentImpl) {
        super(coreDocumentImpl);
        this.ownerDocument = coreDocumentImpl;
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private int nodeListGetLength() {
        ChildNode childNode;
        int i2 = 0;
        if (this.fNodeListCache == null) {
            if (needsSyncChildren()) {
                synchronizeChildren();
            }
            ChildNode childNode2 = this.firstChild;
            if (childNode2 == null) {
                return 0;
            }
            if (childNode2 == lastChild()) {
                return 1;
            }
            this.fNodeListCache = this.ownerDocument.getNodeListCache(this);
        }
        NodeListCache nodeListCache = this.fNodeListCache;
        if (nodeListCache.fLength == -1) {
            int i3 = nodeListCache.fChildIndex;
            if (i3 == -1 || (childNode = nodeListCache.fChild) == null) {
                childNode = this.firstChild;
            } else {
                i2 = i3;
            }
            while (childNode != null) {
                i2++;
                childNode = childNode.nextSibling;
            }
            this.fNodeListCache.fLength = i2;
        }
        return this.fNodeListCache.fLength;
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private Node nodeListItem(int i2) {
        if (this.fNodeListCache == null) {
            if (needsSyncChildren()) {
                synchronizeChildren();
            }
            if (this.firstChild != lastChild()) {
                this.fNodeListCache = this.ownerDocument.getNodeListCache(this);
            } else if (i2 == 0) {
                return this.firstChild;
            } else {
                return null;
            }
        }
        NodeListCache nodeListCache = this.fNodeListCache;
        int i3 = nodeListCache.fChildIndex;
        ChildNode childNode = nodeListCache.fChild;
        boolean z = false;
        if (i3 == -1 || childNode == null) {
            if (i2 < 0) {
                return null;
            }
            childNode = this.firstChild;
            i3 = 0;
            while (i3 < i2 && childNode != null) {
                childNode = childNode.nextSibling;
                i3++;
            }
            z = true;
        } else if (i3 < i2) {
            while (i3 < i2 && childNode != null) {
                i3++;
                childNode = childNode.nextSibling;
            }
        } else if (i3 > i2) {
            while (i3 > i2 && childNode != null) {
                i3--;
                childNode = childNode.previousSibling();
            }
        }
        if (z || !(childNode == this.firstChild || childNode == lastChild())) {
            NodeListCache nodeListCache2 = this.fNodeListCache;
            nodeListCache2.fChildIndex = i3;
            nodeListCache2.fChild = childNode;
        } else {
            NodeListCache nodeListCache3 = this.fNodeListCache;
            nodeListCache3.fChildIndex = -1;
            nodeListCache3.fChild = null;
            this.ownerDocument.freeNodeListCache(nodeListCache3);
        }
        return childNode;
    }

    private void readObject(ObjectInputStream objectInputStream) {
        objectInputStream.defaultReadObject();
        needsSyncChildren(false);
    }

    private void writeObject(ObjectOutputStream objectOutputStream) {
        if (needsSyncChildren()) {
            synchronizeChildren();
        }
        objectOutputStream.defaultWriteObject();
    }

    public void checkNormalizationAfterInsert(ChildNode childNode) {
        if (childNode.getNodeType() == 3) {
            ChildNode previousSibling = childNode.previousSibling();
            ChildNode childNode2 = childNode.nextSibling;
            if ((previousSibling == null || previousSibling.getNodeType() != 3) && (childNode2 == null || childNode2.getNodeType() != 3)) {
                return;
            }
        } else if (childNode.isNormalized()) {
            return;
        }
        isNormalized(false);
    }

    public void checkNormalizationAfterRemove(ChildNode childNode) {
        ChildNode childNode2;
        if (childNode != null && childNode.getNodeType() == 3 && (childNode2 = childNode.nextSibling) != null && childNode2.getNodeType() == 3) {
            isNormalized(false);
        }
    }

    @Override // org.apache.xerces.dom.NodeImpl, org.w3c.dom.Node, org.apache.xerces.dom.ChildNode
    public Node cloneNode(boolean z) {
        if (needsSyncChildren()) {
            synchronizeChildren();
        }
        ParentNode parentNode = (ParentNode) super.cloneNode(z);
        parentNode.ownerDocument = this.ownerDocument;
        parentNode.firstChild = null;
        parentNode.fNodeListCache = null;
        if (z) {
            for (ChildNode childNode = this.firstChild; childNode != null; childNode = childNode.nextSibling) {
                parentNode.appendChild(childNode.cloneNode(true));
            }
        }
        return parentNode;
    }

    @Override // org.apache.xerces.dom.NodeImpl, org.w3c.dom.Node
    public NodeList getChildNodes() {
        if (needsSyncChildren()) {
            synchronizeChildren();
        }
        return this;
    }

    public final NodeList getChildNodesUnoptimized() {
        if (needsSyncChildren()) {
            synchronizeChildren();
        }
        return new NodeList() {
            /* class org.apache.xerces.dom.ParentNode.AnonymousClass1 */

            @Override // org.w3c.dom.NodeList
            public int getLength() {
                return ParentNode.this.nodeListGetLength();
            }

            @Override // org.w3c.dom.NodeList
            public Node item(int i2) {
                return ParentNode.this.nodeListItem(i2);
            }
        };
    }

    @Override // org.apache.xerces.dom.NodeImpl, org.w3c.dom.Node
    public Node getFirstChild() {
        if (needsSyncChildren()) {
            synchronizeChildren();
        }
        return this.firstChild;
    }

    @Override // org.apache.xerces.dom.NodeImpl, org.w3c.dom.Node
    public Node getLastChild() {
        if (needsSyncChildren()) {
            synchronizeChildren();
        }
        return lastChild();
    }

    @Override // org.apache.xerces.dom.NodeImpl, org.w3c.dom.NodeList
    public int getLength() {
        return nodeListGetLength();
    }

    @Override // org.apache.xerces.dom.NodeImpl, org.w3c.dom.Node
    public Document getOwnerDocument() {
        return this.ownerDocument;
    }

    @Override // org.apache.xerces.dom.NodeImpl, org.w3c.dom.Node
    public String getTextContent() {
        Node firstChild2 = getFirstChild();
        if (firstChild2 == null) {
            return "";
        }
        if (firstChild2.getNextSibling() == null) {
            return hasTextContent(firstChild2) ? ((NodeImpl) firstChild2).getTextContent() : "";
        }
        StringBuffer stringBuffer = new StringBuffer();
        getTextContent(stringBuffer);
        return stringBuffer.toString();
    }

    @Override // org.apache.xerces.dom.NodeImpl
    public void getTextContent(StringBuffer stringBuffer) {
        for (Node firstChild2 = getFirstChild(); firstChild2 != null; firstChild2 = firstChild2.getNextSibling()) {
            if (hasTextContent(firstChild2)) {
                ((NodeImpl) firstChild2).getTextContent(stringBuffer);
            }
        }
    }

    @Override // org.apache.xerces.dom.NodeImpl, org.w3c.dom.Node
    public boolean hasChildNodes() {
        if (needsSyncChildren()) {
            synchronizeChildren();
        }
        return this.firstChild != null;
    }

    public final boolean hasTextContent(Node node) {
        return (node.getNodeType() == 8 || node.getNodeType() == 7 || (node.getNodeType() == 3 && ((TextImpl) node).isIgnorableWhitespace())) ? false : true;
    }

    @Override // org.apache.xerces.dom.NodeImpl, org.w3c.dom.Node
    public Node insertBefore(Node node, Node node2) {
        return internalInsertBefore(node, node2, false);
    }

    public Node internalInsertBefore(Node node, Node node2, boolean z) {
        boolean z2 = this.ownerDocument.errorChecking;
        if (node.getNodeType() == 11) {
            if (z2) {
                for (Node firstChild2 = node.getFirstChild(); firstChild2 != null; firstChild2 = firstChild2.getNextSibling()) {
                    if (!this.ownerDocument.isKidOK(this, firstChild2)) {
                        throw new DOMException(3, DOMMessageFormatter.formatMessage(DOMMessageFormatter.DOM_DOMAIN, "HIERARCHY_REQUEST_ERR", null));
                    }
                }
            }
            while (node.hasChildNodes()) {
                insertBefore(node.getFirstChild(), node2);
            }
            return node;
        } else if (node == node2) {
            Node nextSibling = node2.getNextSibling();
            removeChild(node);
            insertBefore(node, nextSibling);
            return node;
        } else {
            if (needsSyncChildren()) {
                synchronizeChildren();
            }
            if (z2) {
                if (!isReadOnly()) {
                    Document ownerDocument2 = node.getOwnerDocument();
                    CoreDocumentImpl coreDocumentImpl = this.ownerDocument;
                    if (ownerDocument2 != coreDocumentImpl && node != coreDocumentImpl) {
                        throw new DOMException(4, DOMMessageFormatter.formatMessage(DOMMessageFormatter.DOM_DOMAIN, "WRONG_DOCUMENT_ERR", null));
                    } else if (!this.ownerDocument.isKidOK(this, node)) {
                        throw new DOMException(3, DOMMessageFormatter.formatMessage(DOMMessageFormatter.DOM_DOMAIN, "HIERARCHY_REQUEST_ERR", null));
                    } else if (node2 == null || node2.getParentNode() == this) {
                        NodeImpl nodeImpl = this;
                        boolean z3 = true;
                        while (z3 && nodeImpl != null) {
                            z3 = node != nodeImpl;
                            nodeImpl = nodeImpl.parentNode();
                        }
                        if (!z3) {
                            throw new DOMException(3, DOMMessageFormatter.formatMessage(DOMMessageFormatter.DOM_DOMAIN, "HIERARCHY_REQUEST_ERR", null));
                        }
                    } else {
                        throw new DOMException(8, DOMMessageFormatter.formatMessage(DOMMessageFormatter.DOM_DOMAIN, "NOT_FOUND_ERR", null));
                    }
                } else {
                    throw new DOMException(7, DOMMessageFormatter.formatMessage(DOMMessageFormatter.DOM_DOMAIN, "NO_MODIFICATION_ALLOWED_ERR", null));
                }
            }
            this.ownerDocument.insertingNode(this, z);
            ChildNode childNode = (ChildNode) node;
            NodeImpl parentNode = childNode.parentNode();
            if (parentNode != null) {
                parentNode.removeChild(childNode);
            }
            ChildNode childNode2 = (ChildNode) node2;
            childNode.ownerNode = this;
            childNode.isOwned(true);
            ChildNode childNode3 = this.firstChild;
            if (childNode3 == null) {
                this.firstChild = childNode;
                childNode.isFirstChild(true);
                childNode.previousSibling = childNode;
            } else if (childNode2 == null) {
                ChildNode childNode4 = childNode3.previousSibling;
                childNode4.nextSibling = childNode;
                childNode.previousSibling = childNode4;
                childNode3.previousSibling = childNode;
            } else if (node2 == childNode3) {
                childNode3.isFirstChild(false);
                ChildNode childNode5 = this.firstChild;
                childNode.nextSibling = childNode5;
                childNode.previousSibling = childNode5.previousSibling;
                childNode5.previousSibling = childNode;
                this.firstChild = childNode;
                childNode.isFirstChild(true);
            } else {
                ChildNode childNode6 = childNode2.previousSibling;
                childNode.nextSibling = childNode2;
                childNode6.nextSibling = childNode;
                childNode2.previousSibling = childNode;
                childNode.previousSibling = childNode6;
            }
            changed();
            NodeListCache nodeListCache = this.fNodeListCache;
            if (nodeListCache != null) {
                int i2 = nodeListCache.fLength;
                if (i2 != -1) {
                    nodeListCache.fLength = i2 + 1;
                }
                NodeListCache nodeListCache2 = this.fNodeListCache;
                if (nodeListCache2.fChildIndex != -1) {
                    if (nodeListCache2.fChild == childNode2) {
                        nodeListCache2.fChild = childNode;
                    } else {
                        nodeListCache2.fChildIndex = -1;
                    }
                }
            }
            this.ownerDocument.insertedNode(this, childNode, z);
            checkNormalizationAfterInsert(childNode);
            return node;
        }
    }

    public Node internalRemoveChild(Node node, boolean z) {
        ChildNode childNode;
        CoreDocumentImpl ownerDocument2 = ownerDocument();
        if (ownerDocument2.errorChecking) {
            if (isReadOnly()) {
                throw new DOMException(7, DOMMessageFormatter.formatMessage(DOMMessageFormatter.DOM_DOMAIN, "NO_MODIFICATION_ALLOWED_ERR", null));
            } else if (!(node == null || node.getParentNode() == this)) {
                throw new DOMException(8, DOMMessageFormatter.formatMessage(DOMMessageFormatter.DOM_DOMAIN, "NOT_FOUND_ERR", null));
            }
        }
        ChildNode childNode2 = (ChildNode) node;
        ownerDocument2.removingNode(this, childNode2, z);
        NodeListCache nodeListCache = this.fNodeListCache;
        if (nodeListCache != null) {
            int i2 = nodeListCache.fLength;
            if (i2 != -1) {
                nodeListCache.fLength = i2 - 1;
            }
            NodeListCache nodeListCache2 = this.fNodeListCache;
            int i3 = nodeListCache2.fChildIndex;
            if (i3 != -1) {
                if (nodeListCache2.fChild == childNode2) {
                    nodeListCache2.fChildIndex = i3 - 1;
                    nodeListCache2.fChild = childNode2.previousSibling();
                } else {
                    nodeListCache2.fChildIndex = -1;
                }
            }
        }
        ChildNode childNode3 = this.firstChild;
        if (childNode2 == childNode3) {
            childNode2.isFirstChild(false);
            ChildNode childNode4 = childNode2.nextSibling;
            this.firstChild = childNode4;
            if (childNode4 != null) {
                childNode4.isFirstChild(true);
                childNode3 = this.firstChild;
                childNode = childNode2.previousSibling;
            }
            ChildNode previousSibling = childNode2.previousSibling();
            childNode2.ownerNode = ownerDocument2;
            childNode2.isOwned(false);
            childNode2.nextSibling = null;
            childNode2.previousSibling = null;
            changed();
            ownerDocument2.removedNode(this, z);
            checkNormalizationAfterRemove(previousSibling);
            return childNode2;
        }
        childNode = childNode2.previousSibling;
        ChildNode childNode5 = childNode2.nextSibling;
        childNode.nextSibling = childNode5;
        if (childNode5 != null) {
            childNode5.previousSibling = childNode;
            ChildNode previousSibling2 = childNode2.previousSibling();
            childNode2.ownerNode = ownerDocument2;
            childNode2.isOwned(false);
            childNode2.nextSibling = null;
            childNode2.previousSibling = null;
            changed();
            ownerDocument2.removedNode(this, z);
            checkNormalizationAfterRemove(previousSibling2);
            return childNode2;
        }
        childNode3.previousSibling = childNode;
        ChildNode previousSibling22 = childNode2.previousSibling();
        childNode2.ownerNode = ownerDocument2;
        childNode2.isOwned(false);
        childNode2.nextSibling = null;
        childNode2.previousSibling = null;
        changed();
        ownerDocument2.removedNode(this, z);
        checkNormalizationAfterRemove(previousSibling22);
        return childNode2;
    }

    @Override // org.apache.xerces.dom.NodeImpl, org.w3c.dom.Node
    public boolean isEqualNode(Node node) {
        if (!super.isEqualNode(node)) {
            return false;
        }
        Node firstChild2 = getFirstChild();
        Node firstChild3 = node.getFirstChild();
        while (firstChild2 != null && firstChild3 != null) {
            if (!firstChild2.isEqualNode(firstChild3)) {
                return false;
            }
            firstChild2 = firstChild2.getNextSibling();
            firstChild3 = firstChild3.getNextSibling();
        }
        return firstChild2 == firstChild3;
    }

    @Override // org.apache.xerces.dom.NodeImpl, org.w3c.dom.NodeList
    public Node item(int i2) {
        return nodeListItem(i2);
    }

    public final ChildNode lastChild() {
        ChildNode childNode = this.firstChild;
        if (childNode != null) {
            return childNode.previousSibling;
        }
        return null;
    }

    public final void lastChild(ChildNode childNode) {
        ChildNode childNode2 = this.firstChild;
        if (childNode2 != null) {
            childNode2.previousSibling = childNode;
        }
    }

    @Override // org.apache.xerces.dom.NodeImpl, org.w3c.dom.Node
    public void normalize() {
        if (!isNormalized()) {
            if (needsSyncChildren()) {
                synchronizeChildren();
            }
            for (ChildNode childNode = this.firstChild; childNode != null; childNode = childNode.nextSibling) {
                childNode.normalize();
            }
            isNormalized(true);
        }
    }

    @Override // org.apache.xerces.dom.NodeImpl
    public CoreDocumentImpl ownerDocument() {
        return this.ownerDocument;
    }

    @Override // org.apache.xerces.dom.NodeImpl, org.w3c.dom.Node
    public Node removeChild(Node node) {
        return internalRemoveChild(node, false);
    }

    @Override // org.apache.xerces.dom.NodeImpl, org.w3c.dom.Node
    public Node replaceChild(Node node, Node node2) {
        this.ownerDocument.replacingNode(this);
        internalInsertBefore(node, node2, true);
        if (node != node2) {
            internalRemoveChild(node2, true);
        }
        this.ownerDocument.replacedNode(this);
        return node2;
    }

    @Override // org.apache.xerces.dom.NodeImpl
    public void setOwnerDocument(CoreDocumentImpl coreDocumentImpl) {
        if (needsSyncChildren()) {
            synchronizeChildren();
        }
        super.setOwnerDocument(coreDocumentImpl);
        this.ownerDocument = coreDocumentImpl;
        for (ChildNode childNode = this.firstChild; childNode != null; childNode = childNode.nextSibling) {
            childNode.setOwnerDocument(coreDocumentImpl);
        }
    }

    @Override // org.apache.xerces.dom.NodeImpl
    public void setReadOnly(boolean z, boolean z2) {
        super.setReadOnly(z, z2);
        if (z2) {
            if (needsSyncChildren()) {
                synchronizeChildren();
            }
            for (ChildNode childNode = this.firstChild; childNode != null; childNode = childNode.nextSibling) {
                if (childNode.getNodeType() != 5) {
                    childNode.setReadOnly(z, true);
                }
            }
        }
    }

    @Override // org.apache.xerces.dom.NodeImpl, org.w3c.dom.Node
    public void setTextContent(String str) {
        while (true) {
            Node firstChild2 = getFirstChild();
            if (firstChild2 == null) {
                break;
            }
            removeChild(firstChild2);
        }
        if (str != null && str.length() != 0) {
            appendChild(ownerDocument().createTextNode(str));
        }
    }

    public void synchronizeChildren() {
        needsSyncChildren(false);
    }
}
