package org.apache.xerces.dom;

import java.util.ArrayList;
import org.w3c.dom.CharacterData;
import org.w3c.dom.DOMException;
import org.w3c.dom.DocumentFragment;
import org.w3c.dom.Node;
import org.w3c.dom.ranges.Range;

public class RangeImpl implements Range {
    public static final int CLONE_CONTENTS = 2;
    public static final int DELETE_CONTENTS = 3;
    public static final int EXTRACT_CONTENTS = 1;
    public Node fDeleteNode = null;
    public boolean fDetach = false;
    public DocumentImpl fDocument;
    public Node fEndContainer;
    public int fEndOffset;
    public Node fInsertNode = null;
    public boolean fInsertedFromRange = false;
    public Node fRemoveChild = null;
    public Node fSplitNode = null;
    public Node fStartContainer;
    public int fStartOffset;

    public RangeImpl(DocumentImpl documentImpl) {
        this.fDocument = documentImpl;
        this.fStartContainer = documentImpl;
        this.fEndContainer = documentImpl;
        this.fStartOffset = 0;
        this.fEndOffset = 0;
        this.fDetach = false;
    }

    private Node getRootContainer(Node node) {
        if (node == null) {
            return null;
        }
        while (node.getParentNode() != null) {
            node = node.getParentNode();
        }
        return node;
    }

    private Node getSelectedNode(Node node, int i2) {
        if (node.getNodeType() == 3 || i2 < 0) {
            return node;
        }
        Node firstChild = node.getFirstChild();
        while (firstChild != null && i2 > 0) {
            i2--;
            firstChild = firstChild.getNextSibling();
        }
        return firstChild != null ? firstChild : node;
    }

    private boolean hasLegalRootContainer(Node node) {
        if (node == null) {
            return false;
        }
        short nodeType = getRootContainer(node).getNodeType();
        return nodeType == 2 || nodeType == 9 || nodeType == 11;
    }

    private boolean isLegalContainedNode(Node node) {
        short nodeType;
        return (node == null || (nodeType = node.getNodeType()) == 2 || nodeType == 6 || nodeType == 9 || nodeType == 11 || nodeType == 12) ? false : true;
    }

    private boolean isLegalContainer(Node node) {
        if (node == null) {
            return false;
        }
        while (node != null) {
            short nodeType = node.getNodeType();
            if (nodeType == 6 || nodeType == 10 || nodeType == 12) {
                return false;
            }
            node = node.getParentNode();
        }
        return true;
    }

    private Node traverseCharacterDataNode(Node node, boolean z, int i2) {
        String str;
        String str2;
        String nodeValue = node.getNodeValue();
        if (z) {
            int startOffset = getStartOffset();
            str2 = nodeValue.substring(startOffset);
            str = nodeValue.substring(0, startOffset);
        } else {
            int endOffset = getEndOffset();
            str2 = nodeValue.substring(0, endOffset);
            str = nodeValue.substring(endOffset);
        }
        if (i2 != 2) {
            node.setNodeValue(str);
        }
        if (i2 == 3) {
            return null;
        }
        Node cloneNode = node.cloneNode(false);
        cloneNode.setNodeValue(str2);
        return cloneNode;
    }

    private DocumentFragment traverseCommonAncestors(Node node, Node node2, int i2) {
        DocumentFragment createDocumentFragment = i2 != 3 ? this.fDocument.createDocumentFragment() : null;
        Node traverseLeftBoundary = traverseLeftBoundary(node, i2);
        if (createDocumentFragment != null) {
            createDocumentFragment.appendChild(traverseLeftBoundary);
        }
        Node parentNode = node.getParentNode();
        int indexOf = indexOf(node2, parentNode) - (indexOf(node, parentNode) + 1);
        Node nextSibling = node.getNextSibling();
        while (indexOf > 0) {
            Node nextSibling2 = nextSibling.getNextSibling();
            Node traverseFullySelected = traverseFullySelected(nextSibling, i2);
            if (createDocumentFragment != null) {
                createDocumentFragment.appendChild(traverseFullySelected);
            }
            indexOf--;
            nextSibling = nextSibling2;
        }
        Node traverseRightBoundary = traverseRightBoundary(node2, i2);
        if (createDocumentFragment != null) {
            createDocumentFragment.appendChild(traverseRightBoundary);
        }
        if (i2 != 2) {
            setStartAfter(node);
            collapse(true);
        }
        return createDocumentFragment;
    }

    private DocumentFragment traverseCommonEndContainer(Node node, int i2) {
        DocumentFragment createDocumentFragment = i2 != 3 ? this.fDocument.createDocumentFragment() : null;
        Node traverseLeftBoundary = traverseLeftBoundary(node, i2);
        if (createDocumentFragment != null) {
            createDocumentFragment.appendChild(traverseLeftBoundary);
        }
        int indexOf = this.fEndOffset - (indexOf(node, this.fEndContainer) + 1);
        Node nextSibling = node.getNextSibling();
        while (indexOf > 0) {
            Node nextSibling2 = nextSibling.getNextSibling();
            Node traverseFullySelected = traverseFullySelected(nextSibling, i2);
            if (createDocumentFragment != null) {
                createDocumentFragment.appendChild(traverseFullySelected);
            }
            indexOf--;
            nextSibling = nextSibling2;
        }
        if (i2 != 2) {
            setStartAfter(node);
            collapse(true);
        }
        return createDocumentFragment;
    }

    private DocumentFragment traverseCommonStartContainer(Node node, int i2) {
        DocumentFragment createDocumentFragment = i2 != 3 ? this.fDocument.createDocumentFragment() : null;
        Node traverseRightBoundary = traverseRightBoundary(node, i2);
        if (createDocumentFragment != null) {
            createDocumentFragment.appendChild(traverseRightBoundary);
        }
        int indexOf = indexOf(node, this.fStartContainer) - this.fStartOffset;
        if (indexOf <= 0) {
            if (i2 != 2) {
                setEndBefore(node);
                collapse(false);
            }
            return createDocumentFragment;
        }
        Node previousSibling = node.getPreviousSibling();
        while (indexOf > 0) {
            Node previousSibling2 = previousSibling.getPreviousSibling();
            Node traverseFullySelected = traverseFullySelected(previousSibling, i2);
            if (createDocumentFragment != null) {
                createDocumentFragment.insertBefore(traverseFullySelected, createDocumentFragment.getFirstChild());
            }
            indexOf--;
            previousSibling = previousSibling2;
        }
        if (i2 != 2) {
            setEndBefore(node);
            collapse(false);
        }
        return createDocumentFragment;
    }

    private DocumentFragment traverseContents(int i2) {
        Node node;
        Node node2 = this.fStartContainer;
        if (node2 == null || (node = this.fEndContainer) == null) {
            return null;
        }
        if (this.fDetach) {
            throw new DOMException(11, DOMMessageFormatter.formatMessage(DOMMessageFormatter.DOM_DOMAIN, "INVALID_STATE_ERR", null));
        } else if (node2 == node) {
            return traverseSameContainer(i2);
        } else {
            Node parentNode = node.getParentNode();
            int i3 = 0;
            int i4 = 0;
            while (true) {
                node = parentNode;
                if (node == null) {
                    Node node3 = this.fStartContainer;
                    while (true) {
                        node3 = node3.getParentNode();
                        if (node3 == null) {
                            int i5 = i3 - i4;
                            Node node4 = this.fStartContainer;
                            while (i5 > 0) {
                                node4 = node4.getParentNode();
                                i5--;
                            }
                            Node node5 = this.fEndContainer;
                            while (i5 < 0) {
                                node5 = node5.getParentNode();
                                i5++;
                            }
                            Node parentNode2 = node4.getParentNode();
                            Node parentNode3 = node5.getParentNode();
                            Node node6 = node4;
                            Node node7 = parentNode2;
                            Node node8 = node5;
                            while (node7 != parentNode3) {
                                node6 = node7;
                                node7 = node7.getParentNode();
                                parentNode3 = parentNode3.getParentNode();
                                node8 = parentNode3;
                            }
                            return traverseCommonAncestors(node6, node8, i2);
                        } else if (node3 == this.fEndContainer) {
                            return traverseCommonEndContainer(node3, i2);
                        } else {
                            i3++;
                        }
                    }
                } else if (node == this.fStartContainer) {
                    return traverseCommonStartContainer(node, i2);
                } else {
                    i4++;
                    parentNode = node.getParentNode();
                }
            }
        }
    }

    private Node traverseFullySelected(Node node, int i2) {
        if (i2 != 1) {
            if (i2 == 2) {
                return node.cloneNode(true);
            }
            if (i2 != 3) {
                return null;
            }
            node.getParentNode().removeChild(node);
            return null;
        } else if (node.getNodeType() != 10) {
            return node;
        } else {
            throw new DOMException(3, DOMMessageFormatter.formatMessage(DOMMessageFormatter.DOM_DOMAIN, "HIERARCHY_REQUEST_ERR", null));
        }
    }

    private Node traverseLeftBoundary(Node node, int i2) {
        Node selectedNode = getSelectedNode(getStartContainer(), getStartOffset());
        boolean z = selectedNode != getStartContainer();
        if (selectedNode == node) {
            return traverseNode(selectedNode, z, true, i2);
        }
        Node parentNode = selectedNode.getParentNode();
        Node traverseNode = traverseNode(parentNode, false, true, i2);
        while (parentNode != null) {
            while (selectedNode != null) {
                Node nextSibling = selectedNode.getNextSibling();
                Node traverseNode2 = traverseNode(selectedNode, z, true, i2);
                if (i2 != 3) {
                    traverseNode.appendChild(traverseNode2);
                }
                selectedNode = nextSibling;
                z = true;
            }
            if (parentNode == node) {
                return traverseNode;
            }
            selectedNode = parentNode.getNextSibling();
            parentNode = parentNode.getParentNode();
            Node traverseNode3 = traverseNode(parentNode, false, true, i2);
            if (i2 != 3) {
                traverseNode3.appendChild(traverseNode);
            }
            traverseNode = traverseNode3;
        }
        return null;
    }

    private Node traverseNode(Node node, boolean z, boolean z2, int i2) {
        if (z) {
            return traverseFullySelected(node, i2);
        }
        short nodeType = node.getNodeType();
        return (nodeType == 3 || nodeType == 4 || nodeType == 8 || nodeType == 7) ? traverseCharacterDataNode(node, z2, i2) : traversePartiallySelected(node, i2);
    }

    private Node traversePartiallySelected(Node node, int i2) {
        if (i2 == 1 || i2 == 2) {
            return node.cloneNode(false);
        }
        return null;
    }

    private Node traverseRightBoundary(Node node, int i2) {
        Node selectedNode = getSelectedNode(this.fEndContainer, this.fEndOffset - 1);
        boolean z = selectedNode != this.fEndContainer;
        if (selectedNode == node) {
            return traverseNode(selectedNode, z, false, i2);
        }
        Node parentNode = selectedNode.getParentNode();
        Node traverseNode = traverseNode(parentNode, false, false, i2);
        while (parentNode != null) {
            while (selectedNode != null) {
                Node previousSibling = selectedNode.getPreviousSibling();
                Node traverseNode2 = traverseNode(selectedNode, z, false, i2);
                if (i2 != 3) {
                    traverseNode.insertBefore(traverseNode2, traverseNode.getFirstChild());
                }
                selectedNode = previousSibling;
                z = true;
            }
            if (parentNode == node) {
                return traverseNode;
            }
            selectedNode = parentNode.getPreviousSibling();
            parentNode = parentNode.getParentNode();
            Node traverseNode3 = traverseNode(parentNode, false, false, i2);
            if (i2 != 3) {
                traverseNode3.appendChild(traverseNode);
            }
            traverseNode = traverseNode3;
        }
        return null;
    }

    private DocumentFragment traverseSameContainer(int i2) {
        Node createCDATASection;
        DocumentFragment createDocumentFragment = i2 != 3 ? this.fDocument.createDocumentFragment() : null;
        if (this.fStartOffset == this.fEndOffset) {
            return createDocumentFragment;
        }
        short nodeType = this.fStartContainer.getNodeType();
        if (nodeType == 3 || nodeType == 4 || nodeType == 8 || nodeType == 7) {
            String substring = this.fStartContainer.getNodeValue().substring(this.fStartOffset, this.fEndOffset);
            if (i2 != 2) {
                int i3 = this.fStartOffset;
                ((CharacterDataImpl) this.fStartContainer).deleteData(i3, this.fEndOffset - i3);
                collapse(true);
            }
            if (i2 == 3) {
                return null;
            }
            if (nodeType == 3) {
                createCDATASection = this.fDocument.createTextNode(substring);
            } else {
                DocumentImpl documentImpl = this.fDocument;
                createCDATASection = nodeType == 4 ? documentImpl.createCDATASection(substring) : nodeType == 8 ? documentImpl.createComment(substring) : documentImpl.createProcessingInstruction(this.fStartContainer.getNodeName(), substring);
            }
            createDocumentFragment.appendChild(createCDATASection);
            return createDocumentFragment;
        }
        Node selectedNode = getSelectedNode(this.fStartContainer, this.fStartOffset);
        int i4 = this.fEndOffset - this.fStartOffset;
        while (i4 > 0) {
            Node nextSibling = selectedNode.getNextSibling();
            Node traverseFullySelected = traverseFullySelected(selectedNode, i2);
            if (createDocumentFragment != null) {
                createDocumentFragment.appendChild(traverseFullySelected);
            }
            i4--;
            selectedNode = nextSibling;
        }
        if (i2 != 2) {
            collapse(true);
        }
        return createDocumentFragment;
    }

    public void checkIndex(Node node, int i2) {
        if (i2 >= 0) {
            short nodeType = node.getNodeType();
            if (nodeType == 3 || nodeType == 4 || nodeType == 8 || nodeType == 7) {
                if (i2 > node.getNodeValue().length()) {
                    throw new DOMException(1, DOMMessageFormatter.formatMessage(DOMMessageFormatter.DOM_DOMAIN, "INDEX_SIZE_ERR", null));
                }
            } else if (i2 > node.getChildNodes().getLength()) {
                throw new DOMException(1, DOMMessageFormatter.formatMessage(DOMMessageFormatter.DOM_DOMAIN, "INDEX_SIZE_ERR", null));
            }
        } else {
            throw new DOMException(1, DOMMessageFormatter.formatMessage(DOMMessageFormatter.DOM_DOMAIN, "INDEX_SIZE_ERR", null));
        }
    }

    @Override // org.w3c.dom.ranges.Range
    public DocumentFragment cloneContents() {
        return traverseContents(2);
    }

    @Override // org.w3c.dom.ranges.Range
    public Range cloneRange() {
        if (!this.fDetach) {
            Range createRange = this.fDocument.createRange();
            createRange.setStart(this.fStartContainer, this.fStartOffset);
            createRange.setEnd(this.fEndContainer, this.fEndOffset);
            return createRange;
        }
        throw new DOMException(11, DOMMessageFormatter.formatMessage(DOMMessageFormatter.DOM_DOMAIN, "INVALID_STATE_ERR", null));
    }

    @Override // org.w3c.dom.ranges.Range
    public void collapse(boolean z) {
        if (this.fDetach) {
            throw new DOMException(11, DOMMessageFormatter.formatMessage(DOMMessageFormatter.DOM_DOMAIN, "INVALID_STATE_ERR", null));
        } else if (z) {
            this.fEndContainer = this.fStartContainer;
            this.fEndOffset = this.fStartOffset;
        } else {
            this.fStartContainer = this.fEndContainer;
            this.fStartOffset = this.fEndOffset;
        }
    }

    /* JADX WARNING: Removed duplicated region for block: B:33:0x0098  */
    /* JADX WARNING: Removed duplicated region for block: B:38:0x009f  */
    @Override // org.w3c.dom.ranges.Range
    public short compareBoundaryPoints(short s, Range range) {
        int i2;
        Node node;
        int i3;
        Node node2;
        DocumentImpl documentImpl = this.fDocument;
        if (documentImpl.errorChecking) {
            if (this.fDetach) {
                throw new DOMException(11, DOMMessageFormatter.formatMessage(DOMMessageFormatter.DOM_DOMAIN, "INVALID_STATE_ERR", null));
            } else if (!((documentImpl == range.getStartContainer().getOwnerDocument() || this.fDocument == range.getStartContainer() || range.getStartContainer() == null) && (this.fDocument == range.getEndContainer().getOwnerDocument() || this.fDocument == range.getEndContainer() || range.getStartContainer() == null))) {
                throw new DOMException(4, DOMMessageFormatter.formatMessage(DOMMessageFormatter.DOM_DOMAIN, "WRONG_DOCUMENT_ERR", null));
            }
        }
        if (s == 0) {
            node = range.getStartContainer();
            node2 = this.fStartContainer;
            i2 = range.getStartOffset();
        } else {
            if (s == 1) {
                node = range.getStartContainer();
                node2 = this.fEndContainer;
                i2 = range.getStartOffset();
            } else if (s == 3) {
                node = range.getEndContainer();
                node2 = this.fStartContainer;
                i2 = range.getEndOffset();
            } else {
                node = range.getEndContainer();
                node2 = this.fEndContainer;
                i2 = range.getEndOffset();
            }
            i3 = this.fEndOffset;
            int i4 = 0;
            if (node == node2) {
                Node node3 = node2;
                for (Node parentNode = node2.getParentNode(); parentNode != null; parentNode = parentNode.getParentNode()) {
                    if (parentNode == node) {
                        return i2 <= indexOf(node3, node) ? (short) 1 : -1;
                    }
                    node3 = parentNode;
                }
                Node node4 = node;
                for (Node parentNode2 = node.getParentNode(); parentNode2 != null; parentNode2 = parentNode2.getParentNode()) {
                    if (parentNode2 == node2) {
                        return indexOf(node4, node2) < i3 ? (short) 1 : -1;
                    }
                    node4 = parentNode2;
                }
                for (Node node5 = node; node5 != null; node5 = node5.getParentNode()) {
                    i4++;
                }
                for (Node node6 = node2; node6 != null; node6 = node6.getParentNode()) {
                    i4--;
                }
                while (i4 > 0) {
                    node = node.getParentNode();
                    i4--;
                }
                while (i4 < 0) {
                    node2 = node2.getParentNode();
                    i4++;
                }
                do {
                    node = node.getParentNode();
                    node2 = node2.getParentNode();
                } while (node != node2);
                for (Node nextSibling = node.getNextSibling(); nextSibling != null; nextSibling = nextSibling.getNextSibling()) {
                    if (nextSibling == node2) {
                        return 1;
                    }
                }
                return -1;
            } else if (i2 < i3) {
                return 1;
            } else {
                return i2 == i3 ? (short) 0 : -1;
            }
        }
        i3 = this.fStartOffset;
        int i42 = 0;
        if (node == node2) {
        }
    }

    @Override // org.w3c.dom.ranges.Range
    public void deleteContents() {
        traverseContents(3);
    }

    public void deleteData(CharacterData characterData, int i2, int i3) {
        this.fDeleteNode = characterData;
        characterData.deleteData(i2, i3);
        this.fDeleteNode = null;
    }

    @Override // org.w3c.dom.ranges.Range
    public void detach() {
        if (!this.fDetach) {
            this.fDetach = true;
            this.fDocument.removeRange(this);
            return;
        }
        throw new DOMException(11, DOMMessageFormatter.formatMessage(DOMMessageFormatter.DOM_DOMAIN, "INVALID_STATE_ERR", null));
    }

    @Override // org.w3c.dom.ranges.Range
    public DocumentFragment extractContents() {
        return traverseContents(1);
    }

    @Override // org.w3c.dom.ranges.Range
    public boolean getCollapsed() {
        if (!this.fDetach) {
            return this.fStartContainer == this.fEndContainer && this.fStartOffset == this.fEndOffset;
        }
        throw new DOMException(11, DOMMessageFormatter.formatMessage(DOMMessageFormatter.DOM_DOMAIN, "INVALID_STATE_ERR", null));
    }

    @Override // org.w3c.dom.ranges.Range
    public Node getCommonAncestorContainer() {
        Object obj = null;
        if (!this.fDetach) {
            ArrayList arrayList = new ArrayList();
            for (Node node = this.fStartContainer; node != null; node = node.getParentNode()) {
                arrayList.add(node);
            }
            ArrayList arrayList2 = new ArrayList();
            for (Node node2 = this.fEndContainer; node2 != null; node2 = node2.getParentNode()) {
                arrayList2.add(node2);
            }
            int size = arrayList.size() - 1;
            int size2 = arrayList2.size() - 1;
            while (size >= 0 && size2 >= 0 && arrayList.get(size) == arrayList2.get(size2)) {
                obj = arrayList.get(size);
                size--;
                size2--;
            }
            return (Node) obj;
        }
        throw new DOMException(11, DOMMessageFormatter.formatMessage(DOMMessageFormatter.DOM_DOMAIN, "INVALID_STATE_ERR", null));
    }

    @Override // org.w3c.dom.ranges.Range
    public Node getEndContainer() {
        if (!this.fDetach) {
            return this.fEndContainer;
        }
        throw new DOMException(11, DOMMessageFormatter.formatMessage(DOMMessageFormatter.DOM_DOMAIN, "INVALID_STATE_ERR", null));
    }

    @Override // org.w3c.dom.ranges.Range
    public int getEndOffset() {
        if (!this.fDetach) {
            return this.fEndOffset;
        }
        throw new DOMException(11, DOMMessageFormatter.formatMessage(DOMMessageFormatter.DOM_DOMAIN, "INVALID_STATE_ERR", null));
    }

    @Override // org.w3c.dom.ranges.Range
    public Node getStartContainer() {
        if (!this.fDetach) {
            return this.fStartContainer;
        }
        throw new DOMException(11, DOMMessageFormatter.formatMessage(DOMMessageFormatter.DOM_DOMAIN, "INVALID_STATE_ERR", null));
    }

    @Override // org.w3c.dom.ranges.Range
    public int getStartOffset() {
        if (!this.fDetach) {
            return this.fStartOffset;
        }
        throw new DOMException(11, DOMMessageFormatter.formatMessage(DOMMessageFormatter.DOM_DOMAIN, "INVALID_STATE_ERR", null));
    }

    public int indexOf(Node node, Node node2) {
        if (node.getParentNode() != node2) {
            return -1;
        }
        int i2 = 0;
        for (Node firstChild = node2.getFirstChild(); firstChild != node; firstChild = firstChild.getNextSibling()) {
            i2++;
        }
        return i2;
    }

    public void insertData(CharacterData characterData, int i2, String str) {
        this.fInsertNode = characterData;
        characterData.insertData(i2, str);
        this.fInsertNode = null;
    }

    @Override // org.w3c.dom.ranges.Range
    public void insertNode(Node node) {
        int i2;
        if (node != null) {
            short nodeType = node.getNodeType();
            DocumentImpl documentImpl = this.fDocument;
            if (documentImpl.errorChecking) {
                if (this.fDetach) {
                    throw new DOMException(11, DOMMessageFormatter.formatMessage(DOMMessageFormatter.DOM_DOMAIN, "INVALID_STATE_ERR", null));
                } else if (documentImpl != node.getOwnerDocument()) {
                    throw new DOMException(4, DOMMessageFormatter.formatMessage(DOMMessageFormatter.DOM_DOMAIN, "WRONG_DOCUMENT_ERR", null));
                } else if (nodeType == 2 || nodeType == 6 || nodeType == 12 || nodeType == 9) {
                    throw new RangeExceptionImpl(2, DOMMessageFormatter.formatMessage(DOMMessageFormatter.DOM_DOMAIN, "INVALID_NODE_TYPE_ERR", null));
                }
            }
            this.fInsertedFromRange = true;
            if (this.fStartContainer.getNodeType() == 3) {
                Node parentNode = this.fStartContainer.getParentNode();
                int length = parentNode.getChildNodes().getLength();
                Node cloneNode = this.fStartContainer.cloneNode(false);
                ((TextImpl) cloneNode).setNodeValueInternal(cloneNode.getNodeValue().substring(this.fStartOffset));
                Node node2 = this.fStartContainer;
                ((TextImpl) node2).setNodeValueInternal(node2.getNodeValue().substring(0, this.fStartOffset));
                Node nextSibling = this.fStartContainer.getNextSibling();
                if (nextSibling != null) {
                    parentNode.insertBefore(node, nextSibling);
                    parentNode.insertBefore(cloneNode, nextSibling);
                } else {
                    parentNode.appendChild(node);
                    parentNode.appendChild(cloneNode);
                }
                Node node3 = this.fEndContainer;
                if (node3 == this.fStartContainer) {
                    this.fEndContainer = cloneNode;
                    this.fEndOffset -= this.fStartOffset;
                } else if (node3 == parentNode) {
                    this.fEndOffset = (parentNode.getChildNodes().getLength() - length) + this.fEndOffset;
                }
                signalSplitData(this.fStartContainer, cloneNode, this.fStartOffset);
            } else {
                Node node4 = this.fEndContainer;
                int length2 = node4 == this.fStartContainer ? node4.getChildNodes().getLength() : 0;
                Node firstChild = this.fStartContainer.getFirstChild();
                for (int i3 = 0; i3 < this.fStartOffset && firstChild != null; i3++) {
                    firstChild = firstChild.getNextSibling();
                }
                if (firstChild != null) {
                    this.fStartContainer.insertBefore(node, firstChild);
                } else {
                    this.fStartContainer.appendChild(node);
                }
                Node node5 = this.fEndContainer;
                if (node5 == this.fStartContainer && (i2 = this.fEndOffset) != 0) {
                    this.fEndOffset = (node5.getChildNodes().getLength() - length2) + i2;
                }
            }
            this.fInsertedFromRange = false;
        }
    }

    public void insertedNodeFromDOM(Node node) {
        int i2;
        int i3;
        if (node != null && this.fInsertNode != node && !this.fInsertedFromRange) {
            Node parentNode = node.getParentNode();
            Node node2 = this.fStartContainer;
            if (parentNode == node2 && indexOf(node, node2) < (i3 = this.fStartOffset)) {
                this.fStartOffset = i3 + 1;
            }
            Node node3 = this.fEndContainer;
            if (parentNode == node3 && indexOf(node, node3) < (i2 = this.fEndOffset)) {
                this.fEndOffset = i2 + 1;
            }
        }
    }

    public boolean isAncestorOf(Node node, Node node2) {
        while (node2 != null) {
            if (node2 == node) {
                return true;
            }
            node2 = node2.getParentNode();
        }
        return false;
    }

    public Node nextNode(Node node, boolean z) {
        Node nextSibling;
        Node firstChild;
        if (node == null) {
            return null;
        }
        if (z && (firstChild = node.getFirstChild()) != null) {
            return firstChild;
        }
        Node nextSibling2 = node.getNextSibling();
        if (nextSibling2 != null) {
            return nextSibling2;
        }
        do {
            node = node.getParentNode();
            if (node == null || node == this.fDocument) {
                return null;
            }
            nextSibling = node.getNextSibling();
        } while (nextSibling == null);
        return nextSibling;
    }

    public void receiveDeletedText(CharacterDataImpl characterDataImpl, int i2, int i3) {
        if (characterDataImpl != null && this.fDeleteNode != characterDataImpl) {
            if (characterDataImpl == this.fStartContainer) {
                int i4 = this.fStartOffset;
                int i5 = i2 + i3;
                if (i4 > i5) {
                    this.fStartOffset = (i4 - i5) + i2;
                } else if (i4 > i2) {
                    this.fStartOffset = i2;
                }
            }
            if (characterDataImpl == this.fEndContainer) {
                int i6 = this.fEndOffset;
                int i7 = i3 + i2;
                if (i6 > i7) {
                    this.fEndOffset = (i6 - i7) + i2;
                } else if (i6 > i2) {
                    this.fEndOffset = i2;
                }
            }
        }
    }

    public void receiveInsertedText(CharacterDataImpl characterDataImpl, int i2, int i3) {
        int i4;
        int i5;
        if (characterDataImpl != null && this.fInsertNode != characterDataImpl) {
            if (characterDataImpl == this.fStartContainer && i2 < (i5 = this.fStartOffset)) {
                this.fStartOffset = i5 + i3;
            }
            if (characterDataImpl == this.fEndContainer && i2 < (i4 = this.fEndOffset)) {
                this.fEndOffset = i4 + i3;
            }
        }
    }

    public void receiveReplacedText(CharacterDataImpl characterDataImpl) {
        if (characterDataImpl != null) {
            if (characterDataImpl == this.fStartContainer) {
                this.fStartOffset = 0;
            }
            if (characterDataImpl == this.fEndContainer) {
                this.fEndOffset = 0;
            }
        }
    }

    public void receiveSplitData(Node node, Node node2, int i2) {
        int i3;
        int i4;
        if (node != null && node2 != null && this.fSplitNode != node) {
            Node node3 = this.fStartContainer;
            if (node == node3 && node3.getNodeType() == 3 && (i4 = this.fStartOffset) > i2) {
                this.fStartOffset = i4 - i2;
                this.fStartContainer = node2;
            }
            Node node4 = this.fEndContainer;
            if (node == node4 && node4.getNodeType() == 3 && (i3 = this.fEndOffset) > i2) {
                this.fEndOffset = i3 - i2;
                this.fEndContainer = node2;
            }
        }
    }

    public Node removeChild(Node node, Node node2) {
        this.fRemoveChild = node2;
        Node removeChild = node.removeChild(node2);
        this.fRemoveChild = null;
        return removeChild;
    }

    public void removeNode(Node node) {
        int i2;
        int i3;
        if (node != null && this.fRemoveChild != node) {
            Node parentNode = node.getParentNode();
            Node node2 = this.fStartContainer;
            if (parentNode == node2 && indexOf(node, node2) < (i3 = this.fStartOffset)) {
                this.fStartOffset = i3 - 1;
            }
            Node node3 = this.fEndContainer;
            if (parentNode == node3 && indexOf(node, node3) < (i2 = this.fEndOffset)) {
                this.fEndOffset = i2 - 1;
            }
            if (parentNode != this.fStartContainer || parentNode != this.fEndContainer) {
                if (isAncestorOf(node, this.fStartContainer)) {
                    this.fStartContainer = parentNode;
                    this.fStartOffset = indexOf(node, parentNode);
                }
                if (isAncestorOf(node, this.fEndContainer)) {
                    this.fEndContainer = parentNode;
                    this.fEndOffset = indexOf(node, parentNode);
                }
            }
        }
    }

    @Override // org.w3c.dom.ranges.Range
    public void selectNode(Node node) {
        if (this.fDocument.errorChecking) {
            if (this.fDetach) {
                throw new DOMException(11, DOMMessageFormatter.formatMessage(DOMMessageFormatter.DOM_DOMAIN, "INVALID_STATE_ERR", null));
            } else if (!isLegalContainer(node.getParentNode()) || !isLegalContainedNode(node)) {
                throw new RangeExceptionImpl(2, DOMMessageFormatter.formatMessage(DOMMessageFormatter.DOM_DOMAIN, "INVALID_NODE_TYPE_ERR", null));
            } else if (!(this.fDocument == node.getOwnerDocument() || this.fDocument == node)) {
                throw new DOMException(4, DOMMessageFormatter.formatMessage(DOMMessageFormatter.DOM_DOMAIN, "WRONG_DOCUMENT_ERR", null));
            }
        }
        Node parentNode = node.getParentNode();
        if (parentNode != null) {
            this.fStartContainer = parentNode;
            this.fEndContainer = parentNode;
            int i2 = 0;
            while (node != null) {
                i2++;
                node = node.getPreviousSibling();
            }
            int i3 = i2 - 1;
            this.fStartOffset = i3;
            this.fEndOffset = i3 + 1;
        }
    }

    @Override // org.w3c.dom.ranges.Range
    public void selectNodeContents(Node node) {
        if (this.fDocument.errorChecking) {
            if (this.fDetach) {
                throw new DOMException(11, DOMMessageFormatter.formatMessage(DOMMessageFormatter.DOM_DOMAIN, "INVALID_STATE_ERR", null));
            } else if (!isLegalContainer(node)) {
                throw new RangeExceptionImpl(2, DOMMessageFormatter.formatMessage(DOMMessageFormatter.DOM_DOMAIN, "INVALID_NODE_TYPE_ERR", null));
            } else if (!(this.fDocument == node.getOwnerDocument() || this.fDocument == node)) {
                throw new DOMException(4, DOMMessageFormatter.formatMessage(DOMMessageFormatter.DOM_DOMAIN, "WRONG_DOCUMENT_ERR", null));
            }
        }
        this.fStartContainer = node;
        this.fEndContainer = node;
        Node firstChild = node.getFirstChild();
        int i2 = 0;
        this.fStartOffset = 0;
        if (firstChild != null) {
            while (firstChild != null) {
                i2++;
                firstChild = firstChild.getNextSibling();
            }
        }
        this.fEndOffset = i2;
    }

    @Override // org.w3c.dom.ranges.Range
    public void setEnd(Node node, int i2) {
        if (this.fDocument.errorChecking) {
            if (this.fDetach) {
                throw new DOMException(11, DOMMessageFormatter.formatMessage(DOMMessageFormatter.DOM_DOMAIN, "INVALID_STATE_ERR", null));
            } else if (!isLegalContainer(node)) {
                throw new RangeExceptionImpl(2, DOMMessageFormatter.formatMessage(DOMMessageFormatter.DOM_DOMAIN, "INVALID_NODE_TYPE_ERR", null));
            } else if (!(this.fDocument == node.getOwnerDocument() || this.fDocument == node)) {
                throw new DOMException(4, DOMMessageFormatter.formatMessage(DOMMessageFormatter.DOM_DOMAIN, "WRONG_DOCUMENT_ERR", null));
            }
        }
        checkIndex(node, i2);
        this.fEndContainer = node;
        this.fEndOffset = i2;
        if (getCommonAncestorContainer() == null || (this.fStartContainer == this.fEndContainer && this.fEndOffset < this.fStartOffset)) {
            collapse(false);
        }
    }

    @Override // org.w3c.dom.ranges.Range
    public void setEndAfter(Node node) {
        if (this.fDocument.errorChecking) {
            if (this.fDetach) {
                throw new DOMException(11, DOMMessageFormatter.formatMessage(DOMMessageFormatter.DOM_DOMAIN, "INVALID_STATE_ERR", null));
            } else if (!hasLegalRootContainer(node) || !isLegalContainedNode(node)) {
                throw new RangeExceptionImpl(2, DOMMessageFormatter.formatMessage(DOMMessageFormatter.DOM_DOMAIN, "INVALID_NODE_TYPE_ERR", null));
            } else if (!(this.fDocument == node.getOwnerDocument() || this.fDocument == node)) {
                throw new DOMException(4, DOMMessageFormatter.formatMessage(DOMMessageFormatter.DOM_DOMAIN, "WRONG_DOCUMENT_ERR", null));
            }
        }
        this.fEndContainer = node.getParentNode();
        int i2 = 0;
        while (node != null) {
            i2++;
            node = node.getPreviousSibling();
        }
        this.fEndOffset = i2;
        if (getCommonAncestorContainer() == null || (this.fStartContainer == this.fEndContainer && this.fEndOffset < this.fStartOffset)) {
            collapse(false);
        }
    }

    @Override // org.w3c.dom.ranges.Range
    public void setEndBefore(Node node) {
        if (this.fDocument.errorChecking) {
            if (this.fDetach) {
                throw new DOMException(11, DOMMessageFormatter.formatMessage(DOMMessageFormatter.DOM_DOMAIN, "INVALID_STATE_ERR", null));
            } else if (!hasLegalRootContainer(node) || !isLegalContainedNode(node)) {
                throw new RangeExceptionImpl(2, DOMMessageFormatter.formatMessage(DOMMessageFormatter.DOM_DOMAIN, "INVALID_NODE_TYPE_ERR", null));
            } else if (!(this.fDocument == node.getOwnerDocument() || this.fDocument == node)) {
                throw new DOMException(4, DOMMessageFormatter.formatMessage(DOMMessageFormatter.DOM_DOMAIN, "WRONG_DOCUMENT_ERR", null));
            }
        }
        this.fEndContainer = node.getParentNode();
        int i2 = 0;
        while (node != null) {
            i2++;
            node = node.getPreviousSibling();
        }
        this.fEndOffset = i2 - 1;
        if (getCommonAncestorContainer() == null || (this.fStartContainer == this.fEndContainer && this.fEndOffset < this.fStartOffset)) {
            collapse(false);
        }
    }

    @Override // org.w3c.dom.ranges.Range
    public void setStart(Node node, int i2) {
        if (this.fDocument.errorChecking) {
            if (this.fDetach) {
                throw new DOMException(11, DOMMessageFormatter.formatMessage(DOMMessageFormatter.DOM_DOMAIN, "INVALID_STATE_ERR", null));
            } else if (!isLegalContainer(node)) {
                throw new RangeExceptionImpl(2, DOMMessageFormatter.formatMessage(DOMMessageFormatter.DOM_DOMAIN, "INVALID_NODE_TYPE_ERR", null));
            } else if (!(this.fDocument == node.getOwnerDocument() || this.fDocument == node)) {
                throw new DOMException(4, DOMMessageFormatter.formatMessage(DOMMessageFormatter.DOM_DOMAIN, "WRONG_DOCUMENT_ERR", null));
            }
        }
        checkIndex(node, i2);
        this.fStartContainer = node;
        this.fStartOffset = i2;
        if (getCommonAncestorContainer() == null || (this.fStartContainer == this.fEndContainer && this.fEndOffset < this.fStartOffset)) {
            collapse(true);
        }
    }

    @Override // org.w3c.dom.ranges.Range
    public void setStartAfter(Node node) {
        if (this.fDocument.errorChecking) {
            if (this.fDetach) {
                throw new DOMException(11, DOMMessageFormatter.formatMessage(DOMMessageFormatter.DOM_DOMAIN, "INVALID_STATE_ERR", null));
            } else if (!hasLegalRootContainer(node) || !isLegalContainedNode(node)) {
                throw new RangeExceptionImpl(2, DOMMessageFormatter.formatMessage(DOMMessageFormatter.DOM_DOMAIN, "INVALID_NODE_TYPE_ERR", null));
            } else if (!(this.fDocument == node.getOwnerDocument() || this.fDocument == node)) {
                throw new DOMException(4, DOMMessageFormatter.formatMessage(DOMMessageFormatter.DOM_DOMAIN, "WRONG_DOCUMENT_ERR", null));
            }
        }
        this.fStartContainer = node.getParentNode();
        int i2 = 0;
        while (node != null) {
            i2++;
            node = node.getPreviousSibling();
        }
        this.fStartOffset = i2;
        if (getCommonAncestorContainer() == null || (this.fStartContainer == this.fEndContainer && this.fEndOffset < this.fStartOffset)) {
            collapse(true);
        }
    }

    @Override // org.w3c.dom.ranges.Range
    public void setStartBefore(Node node) {
        if (this.fDocument.errorChecking) {
            if (this.fDetach) {
                throw new DOMException(11, DOMMessageFormatter.formatMessage(DOMMessageFormatter.DOM_DOMAIN, "INVALID_STATE_ERR", null));
            } else if (!hasLegalRootContainer(node) || !isLegalContainedNode(node)) {
                throw new RangeExceptionImpl(2, DOMMessageFormatter.formatMessage(DOMMessageFormatter.DOM_DOMAIN, "INVALID_NODE_TYPE_ERR", null));
            } else if (!(this.fDocument == node.getOwnerDocument() || this.fDocument == node)) {
                throw new DOMException(4, DOMMessageFormatter.formatMessage(DOMMessageFormatter.DOM_DOMAIN, "WRONG_DOCUMENT_ERR", null));
            }
        }
        this.fStartContainer = node.getParentNode();
        int i2 = 0;
        while (node != null) {
            i2++;
            node = node.getPreviousSibling();
        }
        this.fStartOffset = i2 - 1;
        if (getCommonAncestorContainer() == null || (this.fStartContainer == this.fEndContainer && this.fEndOffset < this.fStartOffset)) {
            collapse(true);
        }
    }

    public void signalSplitData(Node node, Node node2, int i2) {
        this.fSplitNode = node;
        this.fDocument.splitData(node, node2, i2);
        this.fSplitNode = null;
    }

    @Override // org.w3c.dom.ranges.Range
    public void surroundContents(Node node) {
        if (node != null) {
            short nodeType = node.getNodeType();
            if (this.fDocument.errorChecking) {
                if (this.fDetach) {
                    throw new DOMException(11, DOMMessageFormatter.formatMessage(DOMMessageFormatter.DOM_DOMAIN, "INVALID_STATE_ERR", null));
                } else if (nodeType == 2 || nodeType == 6 || nodeType == 12 || nodeType == 10 || nodeType == 9 || nodeType == 11) {
                    throw new RangeExceptionImpl(2, DOMMessageFormatter.formatMessage(DOMMessageFormatter.DOM_DOMAIN, "INVALID_NODE_TYPE_ERR", null));
                }
            }
            Node node2 = this.fStartContainer;
            Node node3 = this.fEndContainer;
            if (node2.getNodeType() == 3) {
                node2 = this.fStartContainer.getParentNode();
            }
            if (this.fEndContainer.getNodeType() == 3) {
                node3 = this.fEndContainer.getParentNode();
            }
            if (node2 == node3) {
                DocumentFragment extractContents = extractContents();
                insertNode(node);
                node.appendChild(extractContents);
                selectNode(node);
                return;
            }
            throw new RangeExceptionImpl(1, DOMMessageFormatter.formatMessage(DOMMessageFormatter.DOM_DOMAIN, "BAD_BOUNDARYPOINTS_ERR", null));
        }
    }

    @Override // org.w3c.dom.ranges.Range
    public String toString() {
        Node node;
        if (!this.fDetach) {
            Node node2 = this.fStartContainer;
            Node node3 = this.fEndContainer;
            StringBuffer stringBuffer = new StringBuffer();
            if (this.fStartContainer.getNodeType() == 3 || this.fStartContainer.getNodeType() == 4) {
                Node node4 = this.fStartContainer;
                if (node4 == this.fEndContainer) {
                    stringBuffer.append(node4.getNodeValue().substring(this.fStartOffset, this.fEndOffset));
                    return stringBuffer.toString();
                }
                stringBuffer.append(node4.getNodeValue().substring(this.fStartOffset));
                node = nextNode(node2, true);
            } else {
                node = node2.getFirstChild();
                if (this.fStartOffset > 0) {
                    for (int i2 = 0; i2 < this.fStartOffset && node != null; i2++) {
                        node = node.getNextSibling();
                    }
                }
                if (node == null) {
                    node = nextNode(this.fStartContainer, false);
                }
            }
            if (!(this.fEndContainer.getNodeType() == 3 || this.fEndContainer.getNodeType() == 4)) {
                int i3 = this.fEndOffset;
                Node firstChild = this.fEndContainer.getFirstChild();
                while (i3 > 0 && firstChild != null) {
                    i3--;
                    firstChild = firstChild.getNextSibling();
                }
                node3 = firstChild == null ? nextNode(this.fEndContainer, false) : firstChild;
            }
            while (node != node3 && node != null) {
                if (node.getNodeType() == 3 || node.getNodeType() == 4) {
                    stringBuffer.append(node.getNodeValue());
                }
                node = nextNode(node, true);
            }
            if (this.fEndContainer.getNodeType() == 3 || this.fEndContainer.getNodeType() == 4) {
                stringBuffer.append(this.fEndContainer.getNodeValue().substring(0, this.fEndOffset));
            }
            return stringBuffer.toString();
        }
        throw new DOMException(11, DOMMessageFormatter.formatMessage(DOMMessageFormatter.DOM_DOMAIN, "INVALID_STATE_ERR", null));
    }
}
