package org.apache.xerces.impl;

import org.apache.xerces.util.SymbolTable;
import org.apache.xerces.util.XML11Char;
import org.apache.xerces.util.XMLChar;
import org.apache.xerces.util.XMLStringBuffer;
import org.apache.xerces.xni.XMLString;

public class XML11DTDScannerImpl extends XMLDTDScannerImpl {
    public final XMLStringBuffer fStringBuffer = new XMLStringBuffer();

    public XML11DTDScannerImpl() {
    }

    public XML11DTDScannerImpl(SymbolTable symbolTable, XMLErrorReporter xMLErrorReporter, XMLEntityManager xMLEntityManager) {
        super(symbolTable, xMLErrorReporter, xMLEntityManager);
    }

    @Override // org.apache.xerces.impl.XMLScanner
    public String getVersionNotSupportedKey() {
        return "VersionNotSupported11";
    }

    @Override // org.apache.xerces.impl.XMLScanner
    public boolean isInvalid(int i2) {
        return !XML11Char.isXML11Valid(i2);
    }

    @Override // org.apache.xerces.impl.XMLScanner
    public boolean isInvalidLiteral(int i2) {
        return !XML11Char.isXML11ValidLiteral(i2);
    }

    @Override // org.apache.xerces.impl.XMLScanner
    public int isUnchangedByNormalization(XMLString xMLString) {
        int i2 = xMLString.offset;
        int i3 = xMLString.length + i2;
        while (i2 < i3) {
            if (XMLChar.isSpace(xMLString.ch[i2])) {
                return i2 - xMLString.offset;
            }
            i2++;
        }
        return -1;
    }

    @Override // org.apache.xerces.impl.XMLScanner
    public boolean isValidNCName(int i2) {
        return XML11Char.isXML11NCName(i2);
    }

    @Override // org.apache.xerces.impl.XMLScanner
    public boolean isValidNameChar(int i2) {
        return XML11Char.isXML11Name(i2);
    }

    @Override // org.apache.xerces.impl.XMLScanner
    public boolean isValidNameStartChar(int i2) {
        return XML11Char.isXML11NameStart(i2);
    }

    @Override // org.apache.xerces.impl.XMLScanner
    public boolean isValidNameStartHighSurrogate(int i2) {
        return XML11Char.isXML11NameHighSurrogate(i2);
    }

    @Override // org.apache.xerces.impl.XMLScanner
    public void normalizeWhitespace(XMLString xMLString) {
        int i2 = xMLString.offset;
        int i3 = xMLString.length + i2;
        while (i2 < i3) {
            if (XMLChar.isSpace(xMLString.ch[i2])) {
                xMLString.ch[i2] = ' ';
            }
            i2++;
        }
    }

    @Override // org.apache.xerces.impl.XMLScanner
    public void normalizeWhitespace(XMLString xMLString, int i2) {
        int i3 = xMLString.offset;
        int i4 = xMLString.length + i3;
        for (int i5 = i3 + i2; i5 < i4; i5++) {
            if (XMLChar.isSpace(xMLString.ch[i5])) {
                xMLString.ch[i5] = ' ';
            }
        }
    }

    @Override // org.apache.xerces.impl.XMLScanner
    public boolean scanPubidLiteral(XMLString xMLString) {
        String str;
        int scanChar = this.fEntityScanner.scanChar();
        if (scanChar == 39 || scanChar == 34) {
            this.fStringBuffer.clear();
            boolean z = true;
            boolean z2 = true;
            while (true) {
                int scanChar2 = this.fEntityScanner.scanChar();
                if (scanChar2 == 32 || scanChar2 == 10 || scanChar2 == 13 || scanChar2 == 133 || scanChar2 == 8232) {
                    if (!z) {
                        this.fStringBuffer.append(' ');
                        z = true;
                    }
                } else if (scanChar2 == scanChar) {
                    if (z) {
                        this.fStringBuffer.length--;
                    }
                    xMLString.setValues(this.fStringBuffer);
                    return z2;
                } else if (XMLChar.isPubid(scanChar2)) {
                    this.fStringBuffer.append((char) scanChar2);
                    z = false;
                } else if (scanChar2 == -1) {
                    str = "PublicIDUnterminated";
                    break;
                } else {
                    reportFatalError("InvalidCharInPublicID", new Object[]{Integer.toHexString(scanChar2)});
                    z2 = false;
                }
            }
        } else {
            str = "QuoteRequiredInPublicID";
        }
        reportFatalError(str, null);
        return false;
    }

    @Override // org.apache.xerces.impl.XMLScanner
    public boolean versionSupported(String str) {
        return str.equals("1.1") || str.equals("1.0");
    }
}
