package org.apache.xerces.impl;

import b.b.a.a.a;
import org.apache.poi.ss.formula.ptg.PercentPtg;
import org.apache.xerces.impl.xs.SchemaSymbols;
import org.apache.xerces.util.SymbolTable;
import org.apache.xerces.util.XMLChar;
import org.apache.xerces.util.XMLResourceIdentifierImpl;
import org.apache.xerces.util.XMLStringBuffer;
import org.apache.xerces.util.XMLSymbols;
import org.apache.xerces.xni.Augmentations;
import org.apache.xerces.xni.XMLDTDContentModelHandler;
import org.apache.xerces.xni.XMLDTDHandler;
import org.apache.xerces.xni.XMLResourceIdentifier;
import org.apache.xerces.xni.XMLString;
import org.apache.xerces.xni.parser.XMLComponent;
import org.apache.xerces.xni.parser.XMLComponentManager;
import org.apache.xerces.xni.parser.XMLDTDScanner;
import org.apache.xerces.xni.parser.XMLInputSource;

public class XMLDTDScannerImpl extends XMLScanner implements XMLDTDScanner, XMLComponent, XMLEntityHandler {
    public static final boolean DEBUG_SCANNER_STATE = false;
    public static final Boolean[] FEATURE_DEFAULTS = {null, Boolean.FALSE};
    public static final Object[] PROPERTY_DEFAULTS = {null, null, null};
    public static final String[] RECOGNIZED_FEATURES = {"http://xml.org/sax/features/validation", "http://apache.org/xml/features/scanner/notify-char-refs"};
    public static final String[] RECOGNIZED_PROPERTIES = {"http://apache.org/xml/properties/internal/symbol-table", "http://apache.org/xml/properties/internal/error-reporter", "http://apache.org/xml/properties/internal/entity-manager"};
    public static final int SCANNER_STATE_END_OF_INPUT = 0;
    public static final int SCANNER_STATE_MARKUP_DECL = 2;
    public static final int SCANNER_STATE_TEXT_DECL = 1;
    public int fContentDepth;
    public int[] fContentStack;
    public XMLDTDContentModelHandler fDTDContentModelHandler;
    public XMLDTDHandler fDTDHandler;
    public String[] fEnumeration;
    public int fEnumerationCount;
    public int fExtEntityDepth;
    public final XMLStringBuffer fIgnoreConditionalBuffer;
    public int fIncludeSectDepth;
    public final XMLString fLiteral;
    public final XMLString fLiteral2;
    public int fMarkUpDepth;
    public int fPEDepth;
    public boolean[] fPEReport;
    public int[] fPEStack;
    public int fScannerState;
    public boolean fSeenExternalDTD;
    public boolean fSeenPEReferences;
    public boolean fStandalone;
    public boolean fStartDTDCalled;
    public final XMLString fString;
    public final XMLStringBuffer fStringBuffer;
    public final XMLStringBuffer fStringBuffer2;
    public final String[] fStrings;

    public XMLDTDScannerImpl() {
        this.fContentStack = new int[5];
        this.fPEStack = new int[5];
        this.fPEReport = new boolean[5];
        this.fStrings = new String[3];
        this.fString = new XMLString();
        this.fStringBuffer = new XMLStringBuffer();
        this.fStringBuffer2 = new XMLStringBuffer();
        this.fLiteral = new XMLString();
        this.fLiteral2 = new XMLString();
        this.fEnumeration = new String[5];
        this.fIgnoreConditionalBuffer = new XMLStringBuffer(128);
    }

    public XMLDTDScannerImpl(SymbolTable symbolTable, XMLErrorReporter xMLErrorReporter, XMLEntityManager xMLEntityManager) {
        this.fContentStack = new int[5];
        this.fPEStack = new int[5];
        this.fPEReport = new boolean[5];
        this.fStrings = new String[3];
        this.fString = new XMLString();
        this.fStringBuffer = new XMLStringBuffer();
        this.fStringBuffer2 = new XMLStringBuffer();
        this.fLiteral = new XMLString();
        this.fLiteral2 = new XMLString();
        this.fEnumeration = new String[5];
        this.fIgnoreConditionalBuffer = new XMLStringBuffer(128);
        this.fSymbolTable = symbolTable;
        this.fErrorReporter = xMLErrorReporter;
        this.fEntityManager = xMLEntityManager;
        xMLEntityManager.setProperty("http://apache.org/xml/properties/internal/symbol-table", symbolTable);
    }

    private final void ensureEnumerationSize(int i2) {
        String[] strArr = this.fEnumeration;
        if (strArr.length == i2) {
            String[] strArr2 = new String[(i2 * 2)];
            System.arraycopy(strArr, 0, strArr2, 0, i2);
            this.fEnumeration = strArr2;
        }
    }

    public static String getScannerStateName(int i2) {
        StringBuffer stringBuffer = new StringBuffer();
        stringBuffer.append("??? (");
        stringBuffer.append(i2);
        stringBuffer.append(')');
        return stringBuffer.toString();
    }

    private void init() {
        this.fStartDTDCalled = false;
        this.fExtEntityDepth = 0;
        this.fIncludeSectDepth = 0;
        this.fMarkUpDepth = 0;
        this.fPEDepth = 0;
        this.fStandalone = false;
        this.fSeenExternalDTD = false;
        this.fSeenPEReferences = false;
        setScannerState(1);
    }

    private final boolean peekReportEntity() {
        return this.fPEReport[this.fPEDepth - 1];
    }

    private final int popContentStack() {
        int[] iArr = this.fContentStack;
        int i2 = this.fContentDepth - 1;
        this.fContentDepth = i2;
        return iArr[i2];
    }

    private final int popPEStack() {
        int[] iArr = this.fPEStack;
        int i2 = this.fPEDepth - 1;
        this.fPEDepth = i2;
        return iArr[i2];
    }

    private final void pushContentStack(int i2) {
        int[] iArr = this.fContentStack;
        int length = iArr.length;
        int i3 = this.fContentDepth;
        if (length == i3) {
            int[] iArr2 = new int[(i3 * 2)];
            System.arraycopy(iArr, 0, iArr2, 0, i3);
            this.fContentStack = iArr2;
        }
        int[] iArr3 = this.fContentStack;
        int i4 = this.fContentDepth;
        this.fContentDepth = i4 + 1;
        iArr3[i4] = i2;
    }

    private final void pushPEStack(int i2, boolean z) {
        int[] iArr = this.fPEStack;
        int length = iArr.length;
        int i3 = this.fPEDepth;
        if (length == i3) {
            int[] iArr2 = new int[(i3 * 2)];
            System.arraycopy(iArr, 0, iArr2, 0, i3);
            this.fPEStack = iArr2;
            int i4 = this.fPEDepth;
            boolean[] zArr = new boolean[(i4 * 2)];
            System.arraycopy(this.fPEReport, 0, zArr, 0, i4);
            this.fPEReport = zArr;
        }
        boolean[] zArr2 = this.fPEReport;
        int i5 = this.fPEDepth;
        zArr2[i5] = z;
        int[] iArr3 = this.fPEStack;
        this.fPEDepth = i5 + 1;
        iArr3[i5] = i2;
    }

    private final String scanAttType(String str, String str2) {
        int i2;
        int i3;
        this.fEnumerationCount = 0;
        if (this.fEntityScanner.skipString("CDATA")) {
            return "CDATA";
        }
        if (this.fEntityScanner.skipString(SchemaSymbols.ATTVAL_IDREFS)) {
            return SchemaSymbols.ATTVAL_IDREFS;
        }
        if (this.fEntityScanner.skipString(SchemaSymbols.ATTVAL_IDREF)) {
            return SchemaSymbols.ATTVAL_IDREF;
        }
        if (this.fEntityScanner.skipString(SchemaSymbols.ATTVAL_ID)) {
            return SchemaSymbols.ATTVAL_ID;
        }
        if (this.fEntityScanner.skipString(SchemaSymbols.ATTVAL_ENTITY)) {
            return SchemaSymbols.ATTVAL_ENTITY;
        }
        if (this.fEntityScanner.skipString(SchemaSymbols.ATTVAL_ENTITIES)) {
            return SchemaSymbols.ATTVAL_ENTITIES;
        }
        if (this.fEntityScanner.skipString(SchemaSymbols.ATTVAL_NMTOKENS)) {
            return SchemaSymbols.ATTVAL_NMTOKENS;
        }
        if (this.fEntityScanner.skipString("NMTOKEN")) {
            return "NMTOKEN";
        }
        if (this.fEntityScanner.skipString(SchemaSymbols.ATTVAL_NOTATION)) {
            if (!skipSeparator(true, !scanningInternalSubset())) {
                reportFatalError("MSG_SPACE_REQUIRED_AFTER_NOTATION_IN_NOTATIONTYPE", new Object[]{str, str2});
            }
            if (this.fEntityScanner.scanChar() != 40) {
                reportFatalError("MSG_OPEN_PAREN_REQUIRED_IN_NOTATIONTYPE", new Object[]{str, str2});
            }
            this.fMarkUpDepth++;
            do {
                skipSeparator(false, !scanningInternalSubset());
                String scanName = this.fEntityScanner.scanName();
                if (scanName == null) {
                    reportFatalError("MSG_NAME_REQUIRED_IN_NOTATIONTYPE", new Object[]{str, str2});
                    i3 = skipInvalidEnumerationValue();
                    if (i3 != 124) {
                        break;
                    }
                } else {
                    ensureEnumerationSize(this.fEnumerationCount + 1);
                    String[] strArr = this.fEnumeration;
                    int i4 = this.fEnumerationCount;
                    this.fEnumerationCount = i4 + 1;
                    strArr[i4] = scanName;
                    skipSeparator(false, !scanningInternalSubset());
                    i3 = this.fEntityScanner.scanChar();
                    continue;
                }
            } while (i3 == 124);
            if (i3 != 41) {
                reportFatalError("NotationTypeUnterminated", new Object[]{str, str2});
            }
            this.fMarkUpDepth--;
            return SchemaSymbols.ATTVAL_NOTATION;
        }
        if (this.fEntityScanner.scanChar() != 40) {
            reportFatalError("AttTypeRequiredInAttDef", new Object[]{str, str2});
        }
        this.fMarkUpDepth++;
        do {
            skipSeparator(false, !scanningInternalSubset());
            String scanNmtoken = this.fEntityScanner.scanNmtoken();
            if (scanNmtoken == null) {
                reportFatalError("MSG_NMTOKEN_REQUIRED_IN_ENUMERATION", new Object[]{str, str2});
                i2 = skipInvalidEnumerationValue();
                if (i2 != 124) {
                    break;
                }
            } else {
                ensureEnumerationSize(this.fEnumerationCount + 1);
                String[] strArr2 = this.fEnumeration;
                int i5 = this.fEnumerationCount;
                this.fEnumerationCount = i5 + 1;
                strArr2[i5] = scanNmtoken;
                skipSeparator(false, !scanningInternalSubset());
                i2 = this.fEntityScanner.scanChar();
                continue;
            }
        } while (i2 == 124);
        if (i2 != 41) {
            reportFatalError("EnumerationUnterminated", new Object[]{str, str2});
        }
        this.fMarkUpDepth--;
        return "ENUMERATION";
    }

    private final void scanChildren(String str) {
        int peekChar;
        this.fContentDepth = 0;
        pushContentStack(0);
        while (true) {
            int i2 = 0;
            while (!this.fEntityScanner.skipChar(40)) {
                skipSeparator(false, !scanningInternalSubset());
                String scanName = this.fEntityScanner.scanName();
                if (scanName == null) {
                    reportFatalError("MSG_OPEN_PAREN_OR_ELEMENT_TYPE_REQUIRED_IN_CHILDREN", new Object[]{str});
                    return;
                }
                XMLDTDContentModelHandler xMLDTDContentModelHandler = this.fDTDContentModelHandler;
                if (xMLDTDContentModelHandler != null) {
                    xMLDTDContentModelHandler.element(scanName, null);
                }
                this.fStringBuffer.append(scanName);
                int peekChar2 = this.fEntityScanner.peekChar();
                if (peekChar2 == 63 || peekChar2 == 42 || peekChar2 == 43) {
                    if (this.fDTDContentModelHandler != null) {
                        this.fDTDContentModelHandler.occurrence(peekChar2 == 63 ? 2 : peekChar2 == 42 ? (short) 3 : 4, null);
                    }
                    this.fEntityScanner.scanChar();
                    this.fStringBuffer.append((char) peekChar2);
                }
                while (true) {
                    skipSeparator(false, !scanningInternalSubset());
                    peekChar = this.fEntityScanner.peekChar();
                    if (peekChar == 44 && i2 != 124) {
                        XMLDTDContentModelHandler xMLDTDContentModelHandler2 = this.fDTDContentModelHandler;
                        if (xMLDTDContentModelHandler2 != null) {
                            xMLDTDContentModelHandler2.separator(1, null);
                        }
                        this.fEntityScanner.scanChar();
                        this.fStringBuffer.append(',');
                    } else if (peekChar != 124 || i2 == 44) {
                        if (peekChar != 41) {
                            reportFatalError("MSG_CLOSE_PAREN_REQUIRED_IN_CHILDREN", new Object[]{str});
                        }
                        XMLDTDContentModelHandler xMLDTDContentModelHandler3 = this.fDTDContentModelHandler;
                        if (xMLDTDContentModelHandler3 != null) {
                            xMLDTDContentModelHandler3.endGroup(null);
                        }
                        int popContentStack = popContentStack();
                        if (this.fEntityScanner.skipString(")?")) {
                            this.fStringBuffer.append(")?");
                            XMLDTDContentModelHandler xMLDTDContentModelHandler4 = this.fDTDContentModelHandler;
                            if (xMLDTDContentModelHandler4 != null) {
                                xMLDTDContentModelHandler4.occurrence(2, null);
                            }
                        } else if (this.fEntityScanner.skipString(")+")) {
                            this.fStringBuffer.append(")+");
                            XMLDTDContentModelHandler xMLDTDContentModelHandler5 = this.fDTDContentModelHandler;
                            if (xMLDTDContentModelHandler5 != null) {
                                xMLDTDContentModelHandler5.occurrence(4, null);
                            }
                        } else if (this.fEntityScanner.skipString(")*")) {
                            this.fStringBuffer.append(")*");
                            XMLDTDContentModelHandler xMLDTDContentModelHandler6 = this.fDTDContentModelHandler;
                            if (xMLDTDContentModelHandler6 != null) {
                                xMLDTDContentModelHandler6.occurrence(3, null);
                            }
                        } else {
                            this.fEntityScanner.scanChar();
                            this.fStringBuffer.append(')');
                        }
                        this.fMarkUpDepth--;
                        if (this.fContentDepth != 0) {
                            i2 = popContentStack;
                        } else {
                            return;
                        }
                    } else {
                        XMLDTDContentModelHandler xMLDTDContentModelHandler7 = this.fDTDContentModelHandler;
                        if (xMLDTDContentModelHandler7 != null) {
                            xMLDTDContentModelHandler7.separator(0, null);
                        }
                        this.fEntityScanner.scanChar();
                        this.fStringBuffer.append('|');
                    }
                }
                skipSeparator(false, !scanningInternalSubset());
                i2 = peekChar;
            }
            this.fMarkUpDepth++;
            this.fStringBuffer.append('(');
            XMLDTDContentModelHandler xMLDTDContentModelHandler8 = this.fDTDContentModelHandler;
            if (xMLDTDContentModelHandler8 != null) {
                xMLDTDContentModelHandler8.startGroup(null);
            }
            pushContentStack(i2);
            skipSeparator(false, !scanningInternalSubset());
        }
    }

    /*  JADX ERROR: JadxOverflowException in pass: RegionMakerVisitor
        jadx.core.utils.exceptions.JadxOverflowException: Regions count limit reached
        	at jadx.core.utils.ErrorsCounter.addError(ErrorsCounter.java:57)
        	at jadx.core.utils.ErrorsCounter.error(ErrorsCounter.java:31)
        	at jadx.core.dex.attributes.nodes.NotificationAttrNode.addError(NotificationAttrNode.java:15)
        */
    /* JADX WARNING: Removed duplicated region for block: B:60:0x011d  */
    /* JADX WARNING: Removed duplicated region for block: B:68:0x0153  */
    /* JADX WARNING: Removed duplicated region for block: B:86:0x00a5 A[SYNTHETIC] */
    private final void scanConditionalSect(int r10) {
        /*
        // Method dump skipped, instructions count: 376
        */
        throw new UnsupportedOperationException("Method not decompiled: org.apache.xerces.impl.XMLDTDScannerImpl.scanConditionalSect(int):void");
    }

    /* JADX WARNING: Removed duplicated region for block: B:26:0x0068 A[LOOP:0: B:26:0x0068->B:97:0x0068, LOOP_START, PHI: r5 
      PHI: (r5v6 boolean) = (r5v0 boolean), (r5v7 boolean) binds: [B:25:0x0066, B:97:0x0068] A[DONT_GENERATE, DONT_INLINE]] */
    /* JADX WARNING: Removed duplicated region for block: B:42:0x00b5  */
    /* JADX WARNING: Removed duplicated region for block: B:43:0x00bc  */
    /* JADX WARNING: Removed duplicated region for block: B:45:0x00c4  */
    /* JADX WARNING: Removed duplicated region for block: B:48:0x00d4  */
    /* JADX WARNING: Removed duplicated region for block: B:61:0x0139  */
    /* JADX WARNING: Removed duplicated region for block: B:74:0x0178  */
    /* JADX WARNING: Removed duplicated region for block: B:77:0x01b5  */
    /* JADX WARNING: Removed duplicated region for block: B:80:0x01c5  */
    /* JADX WARNING: Removed duplicated region for block: B:82:0x01cd  */
    /* JADX WARNING: Removed duplicated region for block: B:92:0x01fe  */
    private final void scanEntityDecl() {
        boolean z;
        boolean z2;
        String scanNCName;
        String str;
        String str2;
        String str3;
        this.fReportEntity = false;
        if (this.fEntityScanner.skipSpaces()) {
            if (this.fEntityScanner.skipChar(37)) {
                if (!skipSeparator(true, !scanningInternalSubset())) {
                    if (scanningInternalSubset()) {
                        reportFatalError("MSG_SPACE_REQUIRED_BEFORE_ENTITY_NAME_IN_PEDECL", null);
                    } else if (this.fEntityScanner.peekChar() == 37) {
                        skipSeparator(false, !scanningInternalSubset());
                    }
                }
                z2 = false;
                z = true;
                if (z2) {
                    while (true) {
                        String scanName = this.fEntityScanner.scanName();
                        if (scanName == null) {
                            reportFatalError("NameRequiredInPEReference", null);
                        } else if (!this.fEntityScanner.skipChar(59)) {
                            reportFatalError("SemicolonRequiredInPEReference", new Object[]{scanName});
                        } else {
                            startPE(scanName, false);
                        }
                        this.fEntityScanner.skipSpaces();
                        if (!this.fEntityScanner.skipChar(37)) {
                            break;
                        } else if (!z) {
                            if (skipSeparator(true, !scanningInternalSubset())) {
                                z = true;
                                break;
                            }
                            z = this.fEntityScanner.skipChar(37);
                        }
                    }
                }
                scanNCName = !this.fNamespaces ? this.fEntityScanner.scanNCName() : this.fEntityScanner.scanName();
                if (scanNCName == null) {
                    reportFatalError("MSG_ENTITY_NAME_REQUIRED_IN_ENTITYDECL", null);
                }
                if (!skipSeparator(true, !scanningInternalSubset())) {
                    if (!this.fNamespaces || this.fEntityScanner.peekChar() != 58) {
                        reportFatalError("MSG_SPACE_REQUIRED_AFTER_ENTITY_NAME_IN_ENTITYDECL", new Object[]{scanNCName});
                    } else {
                        this.fEntityScanner.scanChar();
                        XMLStringBuffer xMLStringBuffer = new XMLStringBuffer(scanNCName);
                        xMLStringBuffer.append(':');
                        String scanName2 = this.fEntityScanner.scanName();
                        if (scanName2 != null) {
                            xMLStringBuffer.append(scanName2);
                        }
                        reportFatalError("ColonNotLegalWithNS", new Object[]{xMLStringBuffer.toString()});
                        if (!skipSeparator(true, !scanningInternalSubset())) {
                            reportFatalError("MSG_SPACE_REQUIRED_AFTER_ENTITY_NAME_IN_ENTITYDECL", new Object[]{scanNCName});
                        }
                    }
                }
                scanExternalID(this.fStrings, false);
                String[] strArr = this.fStrings;
                str = strArr[0];
                String str4 = strArr[1];
                boolean skipSeparator = skipSeparator(true, !scanningInternalSubset());
                if (!z || !this.fEntityScanner.skipString("NDATA")) {
                    str2 = null;
                } else {
                    if (!skipSeparator) {
                        reportFatalError("MSG_SPACE_REQUIRED_BEFORE_NDATA_IN_UNPARSED_ENTITYDECL", new Object[]{scanNCName});
                    }
                    if (!skipSeparator(true, !scanningInternalSubset())) {
                        reportFatalError("MSG_SPACE_REQUIRED_BEFORE_NOTATION_NAME_IN_UNPARSED_ENTITYDECL", new Object[]{scanNCName});
                    }
                    String scanName3 = this.fEntityScanner.scanName();
                    if (scanName3 == null) {
                        reportFatalError("MSG_NOTATION_NAME_REQUIRED_FOR_UNPARSED_ENTITYDECL", new Object[]{scanNCName});
                    }
                    str2 = scanName3;
                }
                if (str == null) {
                    scanEntityValue(this.fLiteral, this.fLiteral2);
                    this.fStringBuffer.clear();
                    this.fStringBuffer2.clear();
                    XMLStringBuffer xMLStringBuffer2 = this.fStringBuffer;
                    XMLString xMLString = this.fLiteral;
                    xMLStringBuffer2.append(xMLString.ch, xMLString.offset, xMLString.length);
                    XMLStringBuffer xMLStringBuffer3 = this.fStringBuffer2;
                    XMLString xMLString2 = this.fLiteral2;
                    xMLStringBuffer3.append(xMLString2.ch, xMLString2.offset, xMLString2.length);
                }
                skipSeparator(false, !scanningInternalSubset());
                if (!this.fEntityScanner.skipChar(62)) {
                    reportFatalError("EntityDeclUnterminated", new Object[]{scanNCName});
                }
                this.fMarkUpDepth--;
                if (z) {
                    scanNCName = a.a(PercentPtg.PERCENT, scanNCName);
                }
                if (str == null) {
                    String baseSystemId = this.fEntityScanner.getBaseSystemId();
                    XMLEntityManager xMLEntityManager = this.fEntityManager;
                    if (str2 != null) {
                        xMLEntityManager.addUnparsedEntity(scanNCName, str4, str, baseSystemId, str2);
                    } else {
                        xMLEntityManager.addExternalEntity(scanNCName, str4, str, baseSystemId);
                    }
                    if (this.fDTDHandler != null) {
                        this.fResourceIdentifier.setValues(str4, str, baseSystemId, XMLEntityManager.expandSystemId(str, baseSystemId, false));
                        XMLDTDHandler xMLDTDHandler = this.fDTDHandler;
                        XMLResourceIdentifierImpl xMLResourceIdentifierImpl = this.fResourceIdentifier;
                        if (str2 != null) {
                            xMLDTDHandler.unparsedEntityDecl(scanNCName, xMLResourceIdentifierImpl, str2, null);
                        } else {
                            xMLDTDHandler.externalEntityDecl(scanNCName, xMLResourceIdentifierImpl, null);
                        }
                    }
                } else {
                    this.fEntityManager.addInternalEntity(scanNCName, this.fStringBuffer.toString());
                    XMLDTDHandler xMLDTDHandler2 = this.fDTDHandler;
                    if (xMLDTDHandler2 != null) {
                        xMLDTDHandler2.internalEntityDecl(scanNCName, this.fStringBuffer, this.fStringBuffer2, null);
                    }
                }
                this.fReportEntity = true;
            }
            z2 = false;
            z = false;
            if (z2) {
            }
            if (!this.fNamespaces) {
            }
            if (scanNCName == null) {
            }
            if (!skipSeparator(true, !scanningInternalSubset())) {
            }
            scanExternalID(this.fStrings, false);
            String[] strArr2 = this.fStrings;
            str = strArr2[0];
            String str42 = strArr2[1];
            boolean skipSeparator2 = skipSeparator(true, !scanningInternalSubset());
            if (!z) {
            }
            str2 = null;
            if (str == null) {
            }
            skipSeparator(false, !scanningInternalSubset());
            if (!this.fEntityScanner.skipChar(62)) {
            }
            this.fMarkUpDepth--;
            if (z) {
            }
            if (str == null) {
            }
            this.fReportEntity = true;
        }
        if (scanningInternalSubset() || !this.fEntityScanner.skipChar(37)) {
            str3 = "MSG_SPACE_REQUIRED_BEFORE_ENTITY_NAME_IN_ENTITYDECL";
        } else if (this.fEntityScanner.skipSpaces()) {
            str3 = "MSG_SPACE_REQUIRED_BEFORE_PERCENT_IN_PEDECL";
        }
        reportFatalError(str3, null);
        z2 = false;
        z = false;
        if (z2) {
        }
        if (!this.fNamespaces) {
        }
        if (scanNCName == null) {
        }
        if (!skipSeparator(true, !scanningInternalSubset())) {
        }
        scanExternalID(this.fStrings, false);
        String[] strArr22 = this.fStrings;
        str = strArr22[0];
        String str422 = strArr22[1];
        boolean skipSeparator22 = skipSeparator(true, !scanningInternalSubset());
        if (!z) {
        }
        str2 = null;
        if (str == null) {
        }
        skipSeparator(false, !scanningInternalSubset());
        if (!this.fEntityScanner.skipChar(62)) {
        }
        this.fMarkUpDepth--;
        if (z) {
        }
        if (str == null) {
        }
        this.fReportEntity = true;
        z2 = true;
        z = false;
        if (z2) {
        }
        if (!this.fNamespaces) {
        }
        if (scanNCName == null) {
        }
        if (!skipSeparator(true, !scanningInternalSubset())) {
        }
        scanExternalID(this.fStrings, false);
        String[] strArr222 = this.fStrings;
        str = strArr222[0];
        String str4222 = strArr222[1];
        boolean skipSeparator222 = skipSeparator(true, !scanningInternalSubset());
        if (!z) {
        }
        str2 = null;
        if (str == null) {
        }
        skipSeparator(false, !scanningInternalSubset());
        if (!this.fEntityScanner.skipChar(62)) {
        }
        this.fMarkUpDepth--;
        if (z) {
        }
        if (str == null) {
        }
        this.fReportEntity = true;
    }

    private final void scanMixed(String str) {
        this.fStringBuffer.append("#PCDATA");
        XMLDTDContentModelHandler xMLDTDContentModelHandler = this.fDTDContentModelHandler;
        if (xMLDTDContentModelHandler != null) {
            xMLDTDContentModelHandler.pcdata(null);
        }
        skipSeparator(false, !scanningInternalSubset());
        String str2 = null;
        while (this.fEntityScanner.skipChar(124)) {
            this.fStringBuffer.append('|');
            XMLDTDContentModelHandler xMLDTDContentModelHandler2 = this.fDTDContentModelHandler;
            if (xMLDTDContentModelHandler2 != null) {
                xMLDTDContentModelHandler2.separator(0, null);
            }
            skipSeparator(false, !scanningInternalSubset());
            str2 = this.fEntityScanner.scanName();
            if (str2 == null) {
                reportFatalError("MSG_ELEMENT_TYPE_REQUIRED_IN_MIXED_CONTENT", new Object[]{str});
            }
            this.fStringBuffer.append(str2);
            XMLDTDContentModelHandler xMLDTDContentModelHandler3 = this.fDTDContentModelHandler;
            if (xMLDTDContentModelHandler3 != null) {
                xMLDTDContentModelHandler3.element(str2, null);
            }
            skipSeparator(false, !scanningInternalSubset());
        }
        if (this.fEntityScanner.skipString(")*")) {
            this.fStringBuffer.append(")*");
            XMLDTDContentModelHandler xMLDTDContentModelHandler4 = this.fDTDContentModelHandler;
            if (xMLDTDContentModelHandler4 != null) {
                xMLDTDContentModelHandler4.endGroup(null);
                this.fDTDContentModelHandler.occurrence(3, null);
            }
        } else if (str2 != null) {
            reportFatalError("MixedContentUnterminated", new Object[]{str});
        } else if (this.fEntityScanner.skipChar(41)) {
            this.fStringBuffer.append(')');
            XMLDTDContentModelHandler xMLDTDContentModelHandler5 = this.fDTDContentModelHandler;
            if (xMLDTDContentModelHandler5 != null) {
                xMLDTDContentModelHandler5.endGroup(null);
            }
        } else {
            reportFatalError("MSG_CLOSE_PAREN_REQUIRED_IN_CHILDREN", new Object[]{str});
        }
        this.fMarkUpDepth--;
    }

    private final void scanNotationDecl() {
        this.fReportEntity = false;
        if (!skipSeparator(true, !scanningInternalSubset())) {
            reportFatalError("MSG_SPACE_REQUIRED_BEFORE_NOTATION_NAME_IN_NOTATIONDECL", null);
        }
        String scanNCName = this.fNamespaces ? this.fEntityScanner.scanNCName() : this.fEntityScanner.scanName();
        if (scanNCName == null) {
            reportFatalError("MSG_NOTATION_NAME_REQUIRED_IN_NOTATIONDECL", null);
        }
        if (!skipSeparator(true, !scanningInternalSubset())) {
            if (!this.fNamespaces || this.fEntityScanner.peekChar() != 58) {
                reportFatalError("MSG_SPACE_REQUIRED_AFTER_NOTATION_NAME_IN_NOTATIONDECL", new Object[]{scanNCName});
            } else {
                this.fEntityScanner.scanChar();
                XMLStringBuffer xMLStringBuffer = new XMLStringBuffer(scanNCName);
                xMLStringBuffer.append(':');
                xMLStringBuffer.append(this.fEntityScanner.scanName());
                reportFatalError("ColonNotLegalWithNS", new Object[]{xMLStringBuffer.toString()});
                skipSeparator(true, !scanningInternalSubset());
            }
        }
        scanExternalID(this.fStrings, true);
        String[] strArr = this.fStrings;
        String str = strArr[0];
        String str2 = strArr[1];
        String baseSystemId = this.fEntityScanner.getBaseSystemId();
        if (str == null && str2 == null) {
            reportFatalError("ExternalIDorPublicIDRequired", new Object[]{scanNCName});
        }
        skipSeparator(false, !scanningInternalSubset());
        if (!this.fEntityScanner.skipChar(62)) {
            reportFatalError("NotationDeclUnterminated", new Object[]{scanNCName});
        }
        this.fMarkUpDepth--;
        if (this.fDTDHandler != null) {
            this.fResourceIdentifier.setValues(str2, str, baseSystemId, XMLEntityManager.expandSystemId(str, baseSystemId, false));
            this.fDTDHandler.notationDecl(scanNCName, this.fResourceIdentifier, null);
        }
        this.fReportEntity = true;
    }

    private int skipInvalidEnumerationValue() {
        int scanChar;
        do {
            scanChar = this.fEntityScanner.scanChar();
            if (scanChar == 124) {
                break;
            }
        } while (scanChar != 41);
        ensureEnumerationSize(this.fEnumerationCount + 1);
        String[] strArr = this.fEnumeration;
        int i2 = this.fEnumerationCount;
        this.fEnumerationCount = i2 + 1;
        strArr[i2] = XMLSymbols.EMPTY_STRING;
        return scanChar;
    }

    private boolean skipSeparator(boolean z, boolean z2) {
        int i2 = this.fPEDepth;
        boolean skipSpaces = this.fEntityScanner.skipSpaces();
        if (!z2 || !this.fEntityScanner.skipChar(37)) {
            return !z || skipSpaces || i2 != this.fPEDepth;
        }
        do {
            String scanName = this.fEntityScanner.scanName();
            if (scanName == null) {
                reportFatalError("NameRequiredInPEReference", null);
            } else if (!this.fEntityScanner.skipChar(59)) {
                reportFatalError("SemicolonRequiredInPEReference", new Object[]{scanName});
            }
            startPE(scanName, false);
            this.fEntityScanner.skipSpaces();
        } while (this.fEntityScanner.skipChar(37));
        return true;
    }

    @Override // org.apache.xerces.impl.XMLEntityHandler, org.apache.xerces.impl.XMLScanner
    public void endEntity(String str, Augmentations augmentations) {
        super.endEntity(str, augmentations);
        if (this.fScannerState != 0) {
            boolean z = false;
            if (str.startsWith(PercentPtg.PERCENT)) {
                boolean peekReportEntity = peekReportEntity();
                int popPEStack = popPEStack();
                if (popPEStack == 0 && popPEStack < this.fMarkUpDepth) {
                    this.fErrorReporter.reportError("http://www.w3.org/TR/1998/REC-xml-19980210", "ILL_FORMED_PARAMETER_ENTITY_WHEN_USED_IN_DECL", new Object[]{this.fEntityManager.fCurrentEntity.name}, 2);
                }
                if (popPEStack == this.fMarkUpDepth) {
                    z = peekReportEntity;
                } else if (this.fValidation) {
                    this.fErrorReporter.reportError("http://www.w3.org/TR/1998/REC-xml-19980210", "ImproperDeclarationNesting", new Object[]{str}, 1);
                }
                if (this.fEntityScanner.isExternal()) {
                    this.fExtEntityDepth--;
                }
                XMLDTDHandler xMLDTDHandler = this.fDTDHandler;
                if (xMLDTDHandler != null && z) {
                    xMLDTDHandler.endParameterEntity(str, augmentations);
                }
            } else if (str.equals("[dtd]")) {
                if (this.fIncludeSectDepth != 0) {
                    reportFatalError("IncludeSectUnterminated", null);
                }
                this.fScannerState = 0;
                this.fEntityManager.endExternalSubset();
                XMLDTDHandler xMLDTDHandler2 = this.fDTDHandler;
                if (xMLDTDHandler2 != null) {
                    xMLDTDHandler2.endExternalSubset(null);
                    this.fDTDHandler.endDTD(null);
                }
                this.fExtEntityDepth--;
            }
        }
    }

    @Override // org.apache.xerces.xni.parser.XMLDTDContentModelSource
    public XMLDTDContentModelHandler getDTDContentModelHandler() {
        return this.fDTDContentModelHandler;
    }

    @Override // org.apache.xerces.xni.parser.XMLDTDSource
    public XMLDTDHandler getDTDHandler() {
        return this.fDTDHandler;
    }

    @Override // org.apache.xerces.impl.XMLScanner, org.apache.xerces.xni.parser.XMLComponent
    public Boolean getFeatureDefault(String str) {
        int i2 = 0;
        while (true) {
            String[] strArr = RECOGNIZED_FEATURES;
            if (i2 >= strArr.length) {
                return null;
            }
            if (strArr[i2].equals(str)) {
                return FEATURE_DEFAULTS[i2];
            }
            i2++;
        }
    }

    @Override // org.apache.xerces.impl.XMLScanner, org.apache.xerces.xni.parser.XMLComponent
    public Object getPropertyDefault(String str) {
        int i2 = 0;
        while (true) {
            String[] strArr = RECOGNIZED_PROPERTIES;
            if (i2 >= strArr.length) {
                return null;
            }
            if (strArr[i2].equals(str)) {
                return PROPERTY_DEFAULTS[i2];
            }
            i2++;
        }
    }

    @Override // org.apache.xerces.impl.XMLScanner, org.apache.xerces.xni.parser.XMLComponent
    public String[] getRecognizedFeatures() {
        return (String[]) RECOGNIZED_FEATURES.clone();
    }

    @Override // org.apache.xerces.impl.XMLScanner, org.apache.xerces.xni.parser.XMLComponent
    public String[] getRecognizedProperties() {
        return (String[]) RECOGNIZED_PROPERTIES.clone();
    }

    @Override // org.apache.xerces.impl.XMLScanner
    public void reset() {
        super.reset();
        init();
    }

    @Override // org.apache.xerces.impl.XMLScanner, org.apache.xerces.xni.parser.XMLComponent
    public void reset(XMLComponentManager xMLComponentManager) {
        super.reset(xMLComponentManager);
        init();
    }

    public final String scanAttDefaultDecl(String str, String str2, String str3, XMLString xMLString, XMLString xMLString2) {
        this.fString.clear();
        xMLString.clear();
        if (this.fEntityScanner.skipString("#REQUIRED")) {
            return "#REQUIRED";
        }
        if (this.fEntityScanner.skipString("#IMPLIED")) {
            return "#IMPLIED";
        }
        String str4 = "#FIXED";
        if (!this.fEntityScanner.skipString(str4)) {
            str4 = null;
        } else if (!skipSeparator(true, !scanningInternalSubset())) {
            reportFatalError("MSG_SPACE_REQUIRED_AFTER_FIXED_IN_DEFAULTDECL", new Object[]{str, str2});
        }
        scanAttributeValue(xMLString, xMLString2, str2, !this.fStandalone && (this.fSeenExternalDTD || this.fSeenPEReferences), str);
        return str4;
    }

    public final void scanAttlistDecl() {
        String str;
        String[] strArr;
        this.fReportEntity = false;
        if (!skipSeparator(true, !scanningInternalSubset())) {
            reportFatalError("MSG_SPACE_REQUIRED_BEFORE_ELEMENT_TYPE_IN_ATTLISTDECL", null);
        }
        String scanName = this.fEntityScanner.scanName();
        if (scanName == null) {
            reportFatalError("MSG_ELEMENT_TYPE_REQUIRED_IN_ATTLISTDECL", null);
        }
        XMLDTDHandler xMLDTDHandler = this.fDTDHandler;
        if (xMLDTDHandler != null) {
            xMLDTDHandler.startAttlist(scanName, null);
        }
        if (!skipSeparator(true, !scanningInternalSubset())) {
            if (this.fEntityScanner.skipChar(62)) {
                XMLDTDHandler xMLDTDHandler2 = this.fDTDHandler;
                if (xMLDTDHandler2 != null) {
                    xMLDTDHandler2.endAttlist(null);
                }
                this.fMarkUpDepth--;
                return;
            }
            reportFatalError("MSG_SPACE_REQUIRED_BEFORE_ATTRIBUTE_NAME_IN_ATTDEF", new Object[]{scanName});
        }
        for (int i2 = 62; !this.fEntityScanner.skipChar(i2); i2 = 62) {
            String scanName2 = this.fEntityScanner.scanName();
            if (scanName2 == null) {
                reportFatalError("AttNameRequiredInAttDef", new Object[]{scanName});
            }
            if (!skipSeparator(true, !scanningInternalSubset())) {
                reportFatalError("MSG_SPACE_REQUIRED_BEFORE_ATTTYPE_IN_ATTDEF", new Object[]{scanName, scanName2});
            }
            String scanAttType = scanAttType(scanName, scanName2);
            if (!skipSeparator(true, !scanningInternalSubset())) {
                reportFatalError("MSG_SPACE_REQUIRED_BEFORE_DEFAULTDECL_IN_ATTDEF", new Object[]{scanName, scanName2});
            }
            String scanAttDefaultDecl = scanAttDefaultDecl(scanName, scanName2, scanAttType, this.fLiteral, this.fLiteral2);
            if (this.fDTDHandler != null) {
                int i3 = this.fEnumerationCount;
                if (i3 != 0) {
                    strArr = new String[i3];
                    System.arraycopy(this.fEnumeration, 0, strArr, 0, i3);
                } else {
                    strArr = null;
                }
                if (scanAttDefaultDecl == null || (!scanAttDefaultDecl.equals("#REQUIRED") && !scanAttDefaultDecl.equals("#IMPLIED"))) {
                    str = scanName;
                    this.fDTDHandler.attributeDecl(str, scanName2, scanAttType, strArr, scanAttDefaultDecl, this.fLiteral, this.fLiteral2, null);
                } else {
                    str = scanName;
                    this.fDTDHandler.attributeDecl(scanName, scanName2, scanAttType, strArr, scanAttDefaultDecl, null, null, null);
                }
            } else {
                str = scanName;
            }
            skipSeparator(false, !scanningInternalSubset());
            scanName = str;
        }
        XMLDTDHandler xMLDTDHandler3 = this.fDTDHandler;
        if (xMLDTDHandler3 != null) {
            xMLDTDHandler3.endAttlist(null);
        }
        this.fMarkUpDepth--;
        this.fReportEntity = true;
    }

    public final void scanComment() {
        this.fReportEntity = false;
        scanComment(this.fStringBuffer);
        this.fMarkUpDepth--;
        XMLDTDHandler xMLDTDHandler = this.fDTDHandler;
        if (xMLDTDHandler != null) {
            xMLDTDHandler.comment(this.fStringBuffer, null);
        }
        this.fReportEntity = true;
    }

    @Override // org.apache.xerces.xni.parser.XMLDTDScanner
    public boolean scanDTDExternalSubset(boolean z) {
        this.fEntityManager.setEntityHandler(this);
        if (this.fScannerState == 1) {
            this.fSeenExternalDTD = true;
            boolean scanTextDecl = scanTextDecl();
            if (this.fScannerState == 0) {
                return false;
            }
            setScannerState(2);
            if (scanTextDecl && !z) {
                return true;
            }
        }
        while (scanDecls(z)) {
            if (!z) {
                return true;
            }
        }
        return false;
    }

    @Override // org.apache.xerces.xni.parser.XMLDTDScanner
    public boolean scanDTDInternalSubset(boolean z, boolean z2, boolean z3) {
        this.fEntityScanner = this.fEntityManager.getEntityScanner();
        this.fEntityManager.setEntityHandler(this);
        this.fStandalone = z2;
        if (this.fScannerState == 1) {
            XMLDTDHandler xMLDTDHandler = this.fDTDHandler;
            if (xMLDTDHandler != null) {
                xMLDTDHandler.startDTD(this.fEntityScanner, null);
                this.fStartDTDCalled = true;
            }
            setScannerState(2);
        }
        while (scanDecls(z)) {
            if (!z) {
                return true;
            }
        }
        XMLDTDHandler xMLDTDHandler2 = this.fDTDHandler;
        if (xMLDTDHandler2 != null && !z3) {
            xMLDTDHandler2.endDTD(null);
        }
        setScannerState(1);
        return false;
    }

    public final boolean scanDecls(boolean z) {
        int peekChar;
        skipSeparator(false, true);
        boolean z2 = true;
        while (z2 && this.fScannerState == 2) {
            if (this.fEntityScanner.skipChar(60)) {
                this.fMarkUpDepth++;
                if (this.fEntityScanner.skipChar(63)) {
                    scanPI();
                } else {
                    if (this.fEntityScanner.skipChar(33)) {
                        if (this.fEntityScanner.skipChar(45)) {
                            if (this.fEntityScanner.skipChar(45)) {
                                scanComment();
                            }
                            reportFatalError("MSG_MARKUP_NOT_RECOGNIZED_IN_DTD", null);
                        } else if (this.fEntityScanner.skipString("ELEMENT")) {
                            scanElementDecl();
                        } else if (this.fEntityScanner.skipString("ATTLIST")) {
                            scanAttlistDecl();
                        } else if (this.fEntityScanner.skipString(SchemaSymbols.ATTVAL_ENTITY)) {
                            scanEntityDecl();
                        } else if (this.fEntityScanner.skipString(SchemaSymbols.ATTVAL_NOTATION)) {
                            scanNotationDecl();
                        } else if (this.fEntityScanner.skipChar(91) && !scanningInternalSubset()) {
                            scanConditionalSect(this.fPEDepth);
                        }
                    }
                    this.fMarkUpDepth--;
                    reportFatalError("MSG_MARKUP_NOT_RECOGNIZED_IN_DTD", null);
                }
            } else if (this.fIncludeSectDepth > 0 && this.fEntityScanner.skipChar(93)) {
                if (!this.fEntityScanner.skipChar(93) || !this.fEntityScanner.skipChar(62)) {
                    reportFatalError("IncludeSectUnterminated", null);
                }
                XMLDTDHandler xMLDTDHandler = this.fDTDHandler;
                if (xMLDTDHandler != null) {
                    xMLDTDHandler.endConditional(null);
                }
                this.fIncludeSectDepth--;
                this.fMarkUpDepth--;
            } else if (!scanningInternalSubset() || this.fEntityScanner.peekChar() != 93) {
                if (!this.fEntityScanner.skipSpaces()) {
                    reportFatalError("MSG_MARKUP_NOT_RECOGNIZED_IN_DTD", null);
                    do {
                        this.fEntityScanner.scanChar();
                        skipSeparator(false, true);
                        peekChar = this.fEntityScanner.peekChar();
                        if (peekChar == 60 || peekChar == 93) {
                            break;
                        }
                    } while (!XMLChar.isSpace(peekChar));
                }
            } else {
                return false;
            }
            skipSeparator(false, true);
            z2 = z;
        }
        return this.fScannerState != 0;
    }

    public final void scanElementDecl() {
        this.fReportEntity = false;
        if (!skipSeparator(true, !scanningInternalSubset())) {
            reportFatalError("MSG_SPACE_REQUIRED_BEFORE_ELEMENT_TYPE_IN_ELEMENTDECL", null);
        }
        String scanName = this.fEntityScanner.scanName();
        if (scanName == null) {
            reportFatalError("MSG_ELEMENT_TYPE_REQUIRED_IN_ELEMENTDECL", null);
        }
        if (!skipSeparator(true, !scanningInternalSubset())) {
            reportFatalError("MSG_SPACE_REQUIRED_BEFORE_CONTENTSPEC_IN_ELEMENTDECL", new Object[]{scanName});
        }
        XMLDTDContentModelHandler xMLDTDContentModelHandler = this.fDTDContentModelHandler;
        if (xMLDTDContentModelHandler != null) {
            xMLDTDContentModelHandler.startContentModel(scanName, null);
        }
        this.fReportEntity = true;
        String str = "EMPTY";
        if (this.fEntityScanner.skipString(str)) {
            XMLDTDContentModelHandler xMLDTDContentModelHandler2 = this.fDTDContentModelHandler;
            if (xMLDTDContentModelHandler2 != null) {
                xMLDTDContentModelHandler2.empty(null);
            }
        } else if (this.fEntityScanner.skipString("ANY")) {
            XMLDTDContentModelHandler xMLDTDContentModelHandler3 = this.fDTDContentModelHandler;
            if (xMLDTDContentModelHandler3 != null) {
                xMLDTDContentModelHandler3.any(null);
            }
            str = "ANY";
        } else {
            if (!this.fEntityScanner.skipChar(40)) {
                reportFatalError("MSG_OPEN_PAREN_OR_ELEMENT_TYPE_REQUIRED_IN_CHILDREN", new Object[]{scanName});
            }
            XMLDTDContentModelHandler xMLDTDContentModelHandler4 = this.fDTDContentModelHandler;
            if (xMLDTDContentModelHandler4 != null) {
                xMLDTDContentModelHandler4.startGroup(null);
            }
            this.fStringBuffer.clear();
            this.fStringBuffer.append('(');
            this.fMarkUpDepth++;
            skipSeparator(false, !scanningInternalSubset());
            if (this.fEntityScanner.skipString("#PCDATA")) {
                scanMixed(scanName);
            } else {
                scanChildren(scanName);
            }
            str = this.fStringBuffer.toString();
        }
        XMLDTDContentModelHandler xMLDTDContentModelHandler5 = this.fDTDContentModelHandler;
        if (xMLDTDContentModelHandler5 != null) {
            xMLDTDContentModelHandler5.endContentModel(null);
        }
        this.fReportEntity = false;
        skipSeparator(false, !scanningInternalSubset());
        if (!this.fEntityScanner.skipChar(62)) {
            reportFatalError("ElementDeclUnterminated", new Object[]{scanName});
        }
        this.fReportEntity = true;
        this.fMarkUpDepth--;
        XMLDTDHandler xMLDTDHandler = this.fDTDHandler;
        if (xMLDTDHandler != null) {
            xMLDTDHandler.elementDecl(scanName, str, null);
        }
    }

    public final void scanEntityValue(XMLString xMLString, XMLString xMLString2) {
        XMLString xMLString3;
        int scanChar = this.fEntityScanner.scanChar();
        if (!(scanChar == 39 || scanChar == 34)) {
            reportFatalError("OpenQuoteMissingInDecl", null);
        }
        int i2 = this.fEntityDepth;
        XMLString xMLString4 = this.fString;
        if (this.fEntityScanner.scanLiteral(scanChar, xMLString4) != scanChar) {
            this.fStringBuffer.clear();
            this.fStringBuffer2.clear();
            do {
                this.fStringBuffer.append(this.fString);
                this.fStringBuffer2.append(this.fString);
                if (this.fEntityScanner.skipChar(38)) {
                    if (this.fEntityScanner.skipChar(35)) {
                        this.fStringBuffer2.append("&#");
                        scanCharReferenceValue(this.fStringBuffer, this.fStringBuffer2);
                    } else {
                        this.fStringBuffer.append('&');
                        this.fStringBuffer2.append('&');
                        String scanName = this.fEntityScanner.scanName();
                        if (scanName == null) {
                            reportFatalError("NameRequiredInReference", null);
                        } else {
                            this.fStringBuffer.append(scanName);
                            this.fStringBuffer2.append(scanName);
                        }
                        if (!this.fEntityScanner.skipChar(59)) {
                            reportFatalError("SemicolonRequiredInReference", new Object[]{scanName});
                        } else {
                            this.fStringBuffer.append(';');
                            this.fStringBuffer2.append(';');
                        }
                    }
                } else if (this.fEntityScanner.skipChar(37)) {
                    do {
                        this.fStringBuffer2.append('%');
                        String scanName2 = this.fEntityScanner.scanName();
                        if (scanName2 == null) {
                            reportFatalError("NameRequiredInPEReference", null);
                        } else if (!this.fEntityScanner.skipChar(59)) {
                            reportFatalError("SemicolonRequiredInPEReference", new Object[]{scanName2});
                        } else {
                            if (scanningInternalSubset()) {
                                reportFatalError("PEReferenceWithinMarkup", new Object[]{scanName2});
                            }
                            this.fStringBuffer2.append(scanName2);
                            this.fStringBuffer2.append(';');
                        }
                        startPE(scanName2, true);
                        this.fEntityScanner.skipSpaces();
                    } while (this.fEntityScanner.skipChar(37));
                } else {
                    int peekChar = this.fEntityScanner.peekChar();
                    if (XMLChar.isHighSurrogate(peekChar)) {
                        scanSurrogates(this.fStringBuffer2);
                    } else {
                        if (isInvalidLiteral(peekChar)) {
                            reportFatalError("InvalidCharInLiteral", new Object[]{Integer.toHexString(peekChar)});
                        } else if (!(peekChar == scanChar && i2 == this.fEntityDepth)) {
                            char c = (char) peekChar;
                            this.fStringBuffer.append(c);
                            this.fStringBuffer2.append(c);
                        }
                        this.fEntityScanner.scanChar();
                    }
                }
            } while (this.fEntityScanner.scanLiteral(scanChar, this.fString) != scanChar);
            this.fStringBuffer.append(this.fString);
            this.fStringBuffer2.append(this.fString);
            xMLString4 = this.fStringBuffer;
            xMLString3 = this.fStringBuffer2;
        } else {
            xMLString3 = xMLString4;
        }
        xMLString.setValues(xMLString4);
        xMLString2.setValues(xMLString3);
        if (!this.fEntityScanner.skipChar(scanChar)) {
            reportFatalError("CloseQuoteMissingInDecl", null);
        }
    }

    @Override // org.apache.xerces.impl.XMLScanner
    public final void scanPIData(String str, XMLString xMLString) {
        super.scanPIData(str, xMLString);
        this.fMarkUpDepth--;
        XMLDTDHandler xMLDTDHandler = this.fDTDHandler;
        if (xMLDTDHandler != null) {
            xMLDTDHandler.processingInstruction(str, xMLString, null);
        }
    }

    public final boolean scanTextDecl() {
        boolean z = false;
        if (this.fEntityScanner.skipString("<?xml")) {
            this.fMarkUpDepth++;
            if (isValidNameChar(this.fEntityScanner.peekChar())) {
                this.fStringBuffer.clear();
                this.fStringBuffer.append("xml");
                if (this.fNamespaces) {
                    while (isValidNCName(this.fEntityScanner.peekChar())) {
                        this.fStringBuffer.append((char) this.fEntityScanner.scanChar());
                    }
                } else {
                    while (isValidNameChar(this.fEntityScanner.peekChar())) {
                        this.fStringBuffer.append((char) this.fEntityScanner.scanChar());
                    }
                }
                SymbolTable symbolTable = this.fSymbolTable;
                XMLStringBuffer xMLStringBuffer = this.fStringBuffer;
                scanPIData(symbolTable.addSymbol(xMLStringBuffer.ch, xMLStringBuffer.offset, xMLStringBuffer.length), this.fString);
            } else {
                scanXMLDeclOrTextDecl(true, this.fStrings);
                this.fMarkUpDepth--;
                String[] strArr = this.fStrings;
                String str = strArr[0];
                String str2 = strArr[1];
                this.fEntityScanner.setXMLVersion(str);
                if (!this.fEntityScanner.fCurrentEntity.isEncodingExternallySpecified()) {
                    this.fEntityScanner.setEncoding(str2);
                }
                XMLDTDHandler xMLDTDHandler = this.fDTDHandler;
                if (xMLDTDHandler != null) {
                    xMLDTDHandler.textDecl(str, str2, null);
                }
                z = true;
            }
        }
        this.fEntityManager.fCurrentEntity.mayReadChunks = true;
        return z;
    }

    public final boolean scanningInternalSubset() {
        return this.fExtEntityDepth == 0;
    }

    @Override // org.apache.xerces.xni.parser.XMLDTDContentModelSource
    public void setDTDContentModelHandler(XMLDTDContentModelHandler xMLDTDContentModelHandler) {
        this.fDTDContentModelHandler = xMLDTDContentModelHandler;
    }

    @Override // org.apache.xerces.xni.parser.XMLDTDSource
    public void setDTDHandler(XMLDTDHandler xMLDTDHandler) {
        this.fDTDHandler = xMLDTDHandler;
    }

    @Override // org.apache.xerces.xni.parser.XMLDTDScanner
    public void setInputSource(XMLInputSource xMLInputSource) {
        if (xMLInputSource == null) {
            XMLDTDHandler xMLDTDHandler = this.fDTDHandler;
            if (xMLDTDHandler != null) {
                xMLDTDHandler.startDTD(null, null);
                this.fDTDHandler.endDTD(null);
                return;
            }
            return;
        }
        this.fEntityManager.setEntityHandler(this);
        this.fEntityManager.startDTDEntity(xMLInputSource);
    }

    public final void setScannerState(int i2) {
        this.fScannerState = i2;
    }

    /* JADX WARNING: Code restructure failed: missing block: B:14:0x003c, code lost:
        if (r4.fEntityScanner.isExternal() != false) goto L_0x003e;
     */
    @Override // org.apache.xerces.impl.XMLEntityHandler, org.apache.xerces.impl.XMLScanner
    public void startEntity(String str, XMLResourceIdentifier xMLResourceIdentifier, String str2, Augmentations augmentations) {
        XMLDTDHandler xMLDTDHandler;
        super.startEntity(str, xMLResourceIdentifier, str2, augmentations);
        boolean equals = str.equals("[dtd]");
        if (equals) {
            XMLDTDHandler xMLDTDHandler2 = this.fDTDHandler;
            if (xMLDTDHandler2 != null && !this.fStartDTDCalled) {
                xMLDTDHandler2.startDTD(this.fEntityScanner, null);
            }
            XMLDTDHandler xMLDTDHandler3 = this.fDTDHandler;
            if (xMLDTDHandler3 != null) {
                xMLDTDHandler3.startExternalSubset(xMLResourceIdentifier, null);
            }
            this.fEntityManager.startExternalSubset();
        } else {
            if (str.charAt(0) == '%') {
                pushPEStack(this.fMarkUpDepth, this.fReportEntity);
            }
            xMLDTDHandler = this.fDTDHandler;
            if (xMLDTDHandler != null && !equals && this.fReportEntity) {
                xMLDTDHandler.startParameterEntity(str, xMLResourceIdentifier, str2, augmentations);
                return;
            }
            return;
        }
        this.fExtEntityDepth++;
        xMLDTDHandler = this.fDTDHandler;
        if (xMLDTDHandler != null) {
        }
    }

    public void startPE(String str, boolean z) {
        int i2 = this.fPEDepth;
        String a = a.a(PercentPtg.PERCENT, str);
        if (!this.fSeenPEReferences) {
            this.fSeenPEReferences = true;
            this.fEntityManager.notifyHasPEReferences();
        }
        if (this.fValidation && !this.fEntityManager.isDeclaredEntity(a)) {
            this.fErrorReporter.reportError("http://www.w3.org/TR/1998/REC-xml-19980210", "EntityNotDeclared", new Object[]{str}, 1);
        }
        this.fEntityManager.startEntity(this.fSymbolTable.addSymbol(a), z);
        if (i2 != this.fPEDepth && this.fEntityScanner.isExternal()) {
            scanTextDecl();
        }
    }
}
