package org.apache.xerces.impl;

import java.io.CharConversionException;
import java.io.EOFException;
import org.apache.poi.ss.formula.ptg.StringPtg;
import org.apache.xerces.impl.io.MalformedByteSequenceException;
import org.apache.xerces.util.AugmentationsImpl;
import org.apache.xerces.util.XMLAttributesImpl;
import org.apache.xerces.util.XMLChar;
import org.apache.xerces.util.XMLStringBuffer;
import org.apache.xerces.util.XMLSymbols;
import org.apache.xerces.xni.Augmentations;
import org.apache.xerces.xni.QName;
import org.apache.xerces.xni.XMLAttributes;
import org.apache.xerces.xni.XMLDocumentHandler;
import org.apache.xerces.xni.XMLResourceIdentifier;
import org.apache.xerces.xni.XMLString;
import org.apache.xerces.xni.parser.XMLComponent;
import org.apache.xerces.xni.parser.XMLComponentManager;
import org.apache.xerces.xni.parser.XMLConfigurationException;
import org.apache.xerces.xni.parser.XMLDocumentScanner;
import org.apache.xerces.xni.parser.XMLInputSource;

public class XMLDocumentFragmentScannerImpl extends XMLScanner implements XMLDocumentScanner, XMLComponent, XMLEntityHandler {
    public static final boolean DEBUG_CONTENT_SCANNING = false;
    public static final boolean DEBUG_DISPATCHER = false;
    public static final boolean DEBUG_SCANNER_STATE = false;
    public static final String ENTITY_RESOLVER = "http://apache.org/xml/properties/internal/entity-resolver";
    public static final Boolean[] FEATURE_DEFAULTS;
    public static final String NAMESPACES = "http://xml.org/sax/features/namespaces";
    public static final String NOTIFY_BUILTIN_REFS = "http://apache.org/xml/features/scanner/notify-builtin-refs";
    public static final Object[] PROPERTY_DEFAULTS = {null, null, null, null};
    public static final String[] RECOGNIZED_FEATURES = {"http://xml.org/sax/features/namespaces", "http://xml.org/sax/features/validation", "http://apache.org/xml/features/scanner/notify-builtin-refs", "http://apache.org/xml/features/scanner/notify-char-refs"};
    public static final String[] RECOGNIZED_PROPERTIES = {"http://apache.org/xml/properties/internal/symbol-table", "http://apache.org/xml/properties/internal/error-reporter", "http://apache.org/xml/properties/internal/entity-manager", "http://apache.org/xml/properties/internal/entity-resolver"};
    public static final int SCANNER_STATE_CDATA = 15;
    public static final int SCANNER_STATE_COMMENT = 2;
    public static final int SCANNER_STATE_CONTENT = 7;
    public static final int SCANNER_STATE_DOCTYPE = 4;
    public static final int SCANNER_STATE_END_OF_INPUT = 13;
    public static final int SCANNER_STATE_PI = 3;
    public static final int SCANNER_STATE_REFERENCE = 8;
    public static final int SCANNER_STATE_ROOT_ELEMENT = 6;
    public static final int SCANNER_STATE_START_OF_MARKUP = 1;
    public static final int SCANNER_STATE_TERMINATED = 14;
    public static final int SCANNER_STATE_TEXT_DECL = 16;
    public final QName fAttributeQName = new QName();
    public final XMLAttributesImpl fAttributes = new XMLAttributesImpl();
    public final Dispatcher fContentDispatcher = createContentDispatcher();
    public QName fCurrentElement;
    public Dispatcher fDispatcher;
    public XMLDocumentHandler fDocumentHandler;
    public final QName fElementQName = new QName();
    public final ElementStack fElementStack = new ElementStack();
    public int[] fEntityStack = new int[4];
    public ExternalSubsetResolver fExternalSubsetResolver;
    public boolean fHasExternalDTD;
    public boolean fInScanContent = false;
    public boolean fIsEntityDeclaredVC;
    public int fMarkupDepth;
    public boolean fNotifyBuiltInRefs = false;
    public final QName fQName = new QName();
    public boolean fSawSpace;
    public int fScannerState;
    public final char[] fSingleChar = new char[1];
    public boolean fStandalone;
    public final XMLStringBuffer fStringBuffer = new XMLStringBuffer();
    public final XMLStringBuffer fStringBuffer2 = new XMLStringBuffer();
    public final String[] fStrings = new String[3];
    public Augmentations fTempAugmentations = null;
    public final XMLString fTempString = new XMLString();
    public final XMLString fTempString2 = new XMLString();

    public interface Dispatcher {
        boolean dispatch(boolean z);
    }

    public static class ElementStack {
        public QName[] fElements = new QName[10];
        public int fSize;

        public ElementStack() {
            int i2 = 0;
            while (true) {
                QName[] qNameArr = this.fElements;
                if (i2 < qNameArr.length) {
                    qNameArr[i2] = new QName();
                    i2++;
                } else {
                    return;
                }
            }
        }

        public void clear() {
            this.fSize = 0;
        }

        public void popElement(QName qName) {
            QName[] qNameArr = this.fElements;
            int i2 = this.fSize - 1;
            this.fSize = i2;
            qName.setValues(qNameArr[i2]);
        }

        public QName pushElement(QName qName) {
            int i2 = this.fSize;
            QName[] qNameArr = this.fElements;
            if (i2 == qNameArr.length) {
                QName[] qNameArr2 = new QName[(qNameArr.length * 2)];
                System.arraycopy(qNameArr, 0, qNameArr2, 0, i2);
                this.fElements = qNameArr2;
                int i3 = this.fSize;
                while (true) {
                    QName[] qNameArr3 = this.fElements;
                    if (i3 >= qNameArr3.length) {
                        break;
                    }
                    qNameArr3[i3] = new QName();
                    i3++;
                }
            }
            this.fElements[this.fSize].setValues(qName);
            QName[] qNameArr4 = this.fElements;
            int i4 = this.fSize;
            this.fSize = i4 + 1;
            return qNameArr4[i4];
        }
    }

    public class FragmentContentDispatcher implements Dispatcher {
        public FragmentContentDispatcher() {
        }

        /* JADX WARN: Multi-variable type inference failed */
        /* JADX WARN: Type inference failed for: r12v3, types: [java.io.CharConversionException] */
        /* JADX WARNING: Removed duplicated region for block: B:106:0x02a5 A[ADDED_TO_REGION] */
        /* JADX WARNING: Removed duplicated region for block: B:121:0x0000 A[ADDED_TO_REGION, SYNTHETIC] */
        /* JADX WARNING: Unknown variable types count: 1 */
        @Override // org.apache.xerces.impl.XMLDocumentFragmentScannerImpl.Dispatcher
        public boolean dispatch(boolean z) {
            MalformedByteSequenceException malformedByteSequenceException;
            XMLErrorReporter xMLErrorReporter;
            String domain;
            String key;
            Object[] arguments;
            short s;
            XMLDocumentFragmentScannerImpl xMLDocumentFragmentScannerImpl;
            XMLDocumentFragmentScannerImpl xMLDocumentFragmentScannerImpl2;
            while (true) {
                boolean z2 = false;
                try {
                    int i2 = XMLDocumentFragmentScannerImpl.this.fScannerState;
                    int i3 = 2;
                    if (i2 == 1) {
                        XMLDocumentFragmentScannerImpl.this.fMarkupDepth++;
                        if (XMLDocumentFragmentScannerImpl.this.fEntityScanner.skipChar(47)) {
                            if (XMLDocumentFragmentScannerImpl.this.scanEndElement() == 0 && elementDepthIsZeroHook()) {
                                return true;
                            }
                            xMLDocumentFragmentScannerImpl = XMLDocumentFragmentScannerImpl.this;
                        } else if (XMLDocumentFragmentScannerImpl.this.isValidNameStartChar(XMLDocumentFragmentScannerImpl.this.fEntityScanner.peekChar())) {
                            XMLDocumentFragmentScannerImpl.this.scanStartElement();
                            xMLDocumentFragmentScannerImpl = XMLDocumentFragmentScannerImpl.this;
                        } else {
                            if (XMLDocumentFragmentScannerImpl.this.fEntityScanner.skipChar(33)) {
                                if (XMLDocumentFragmentScannerImpl.this.fEntityScanner.skipChar(45)) {
                                    if (!XMLDocumentFragmentScannerImpl.this.fEntityScanner.skipChar(45)) {
                                        XMLDocumentFragmentScannerImpl.this.reportFatalError("InvalidCommentStart", null);
                                    }
                                    xMLDocumentFragmentScannerImpl2 = XMLDocumentFragmentScannerImpl.this;
                                    xMLDocumentFragmentScannerImpl2.setScannerState(i3);
                                } else if (XMLDocumentFragmentScannerImpl.this.fEntityScanner.skipString("[CDATA[")) {
                                    XMLDocumentFragmentScannerImpl.this.setScannerState(15);
                                } else {
                                    if (!scanForDoctypeHook()) {
                                        XMLDocumentFragmentScannerImpl.this.reportFatalError("MarkupNotRecognizedInContent", null);
                                    }
                                    if (z) {
                                    }
                                }
                            } else if (XMLDocumentFragmentScannerImpl.this.fEntityScanner.skipChar(63)) {
                                XMLDocumentFragmentScannerImpl.this.setScannerState(3);
                            } else if (XMLDocumentFragmentScannerImpl.this.isValidNameStartHighSurrogate(XMLDocumentFragmentScannerImpl.this.fEntityScanner.peekChar())) {
                                XMLDocumentFragmentScannerImpl.this.scanStartElement();
                                xMLDocumentFragmentScannerImpl = XMLDocumentFragmentScannerImpl.this;
                            } else {
                                XMLDocumentFragmentScannerImpl.this.reportFatalError("MarkupNotRecognizedInContent", null);
                                xMLDocumentFragmentScannerImpl = XMLDocumentFragmentScannerImpl.this;
                            }
                            z2 = true;
                            if (z) {
                            }
                        }
                    } else if (i2 == 2) {
                        XMLDocumentFragmentScannerImpl.this.scanComment();
                        xMLDocumentFragmentScannerImpl = XMLDocumentFragmentScannerImpl.this;
                    } else if (i2 == 3) {
                        XMLDocumentFragmentScannerImpl.this.scanPI();
                        xMLDocumentFragmentScannerImpl = XMLDocumentFragmentScannerImpl.this;
                    } else if (i2 == 4) {
                        XMLDocumentFragmentScannerImpl.this.reportFatalError("DoctypeIllegalInContent", null);
                        xMLDocumentFragmentScannerImpl = XMLDocumentFragmentScannerImpl.this;
                    } else if (i2 != 6) {
                        i3 = 8;
                        if (i2 == 7) {
                            if (!XMLDocumentFragmentScannerImpl.this.fEntityScanner.skipChar(60)) {
                                if (!XMLDocumentFragmentScannerImpl.this.fEntityScanner.skipChar(38)) {
                                    while (true) {
                                        int scanContent = XMLDocumentFragmentScannerImpl.this.scanContent();
                                        if (scanContent != 60) {
                                            if (scanContent != 38) {
                                                if (scanContent != -1 && XMLDocumentFragmentScannerImpl.this.isInvalidLiteral(scanContent)) {
                                                    if (XMLChar.isHighSurrogate(scanContent)) {
                                                        XMLDocumentFragmentScannerImpl.this.fStringBuffer.clear();
                                                        if (XMLDocumentFragmentScannerImpl.this.scanSurrogates(XMLDocumentFragmentScannerImpl.this.fStringBuffer) && XMLDocumentFragmentScannerImpl.this.fDocumentHandler != null) {
                                                            XMLDocumentFragmentScannerImpl.this.fDocumentHandler.characters(XMLDocumentFragmentScannerImpl.this.fStringBuffer, null);
                                                            continue;
                                                        }
                                                    } else {
                                                        XMLDocumentFragmentScannerImpl.this.reportFatalError("InvalidCharInContent", new Object[]{Integer.toString(scanContent, 16)});
                                                        XMLDocumentFragmentScannerImpl.this.fEntityScanner.scanChar();
                                                        continue;
                                                    }
                                                }
                                                if (!z) {
                                                    break;
                                                }
                                            } else {
                                                XMLDocumentFragmentScannerImpl.this.fEntityScanner.scanChar();
                                                XMLDocumentFragmentScannerImpl.this.setScannerState(8);
                                                break;
                                            }
                                        } else {
                                            XMLDocumentFragmentScannerImpl.this.fEntityScanner.scanChar();
                                            XMLDocumentFragmentScannerImpl.this.setScannerState(1);
                                            break;
                                        }
                                    }
                                } else {
                                    xMLDocumentFragmentScannerImpl2 = XMLDocumentFragmentScannerImpl.this;
                                    xMLDocumentFragmentScannerImpl2.setScannerState(i3);
                                    z2 = true;
                                }
                            } else {
                                XMLDocumentFragmentScannerImpl.this.setScannerState(1);
                                z2 = true;
                            }
                        } else if (i2 == 8) {
                            XMLDocumentFragmentScannerImpl.this.fMarkupDepth++;
                            XMLDocumentFragmentScannerImpl.this.setScannerState(7);
                            if (XMLDocumentFragmentScannerImpl.this.fEntityScanner.skipChar(35)) {
                                XMLDocumentFragmentScannerImpl.this.scanCharReference();
                            } else {
                                XMLDocumentFragmentScannerImpl.this.scanEntityReference();
                            }
                        } else if (i2 == 15) {
                            XMLDocumentFragmentScannerImpl.this.scanCDATASection(z);
                            xMLDocumentFragmentScannerImpl = XMLDocumentFragmentScannerImpl.this;
                        } else if (i2 == 16) {
                            if (XMLDocumentFragmentScannerImpl.this.fEntityScanner.skipString("<?xml")) {
                                XMLDocumentFragmentScannerImpl.this.fMarkupDepth++;
                                if (XMLDocumentFragmentScannerImpl.this.isValidNameChar(XMLDocumentFragmentScannerImpl.this.fEntityScanner.peekChar())) {
                                    XMLDocumentFragmentScannerImpl.this.fStringBuffer.clear();
                                    XMLDocumentFragmentScannerImpl.this.fStringBuffer.append("xml");
                                    if (XMLDocumentFragmentScannerImpl.this.fNamespaces) {
                                        while (XMLDocumentFragmentScannerImpl.this.isValidNCName(XMLDocumentFragmentScannerImpl.this.fEntityScanner.peekChar())) {
                                            XMLDocumentFragmentScannerImpl.this.fStringBuffer.append((char) XMLDocumentFragmentScannerImpl.this.fEntityScanner.scanChar());
                                        }
                                    } else {
                                        while (XMLDocumentFragmentScannerImpl.this.isValidNameChar(XMLDocumentFragmentScannerImpl.this.fEntityScanner.peekChar())) {
                                            XMLDocumentFragmentScannerImpl.this.fStringBuffer.append((char) XMLDocumentFragmentScannerImpl.this.fEntityScanner.scanChar());
                                        }
                                    }
                                    XMLDocumentFragmentScannerImpl.this.scanPIData(XMLDocumentFragmentScannerImpl.this.fSymbolTable.addSymbol(XMLDocumentFragmentScannerImpl.this.fStringBuffer.ch, XMLDocumentFragmentScannerImpl.this.fStringBuffer.offset, XMLDocumentFragmentScannerImpl.this.fStringBuffer.length), XMLDocumentFragmentScannerImpl.this.fTempString);
                                } else {
                                    XMLDocumentFragmentScannerImpl.this.scanXMLDeclOrTextDecl(true);
                                }
                            }
                            XMLDocumentFragmentScannerImpl.this.fEntityManager.fCurrentEntity.mayReadChunks = true;
                            xMLDocumentFragmentScannerImpl = XMLDocumentFragmentScannerImpl.this;
                        }
                        if (z && !z2) {
                            return true;
                        }
                    } else if (scanRootElementHook()) {
                        return true;
                    } else {
                        xMLDocumentFragmentScannerImpl = XMLDocumentFragmentScannerImpl.this;
                    }
                    xMLDocumentFragmentScannerImpl.setScannerState(7);
                    if (z) {
                    }
                } catch (MalformedByteSequenceException e2) {
                    malformedByteSequenceException = e2;
                    xMLErrorReporter = XMLDocumentFragmentScannerImpl.this.fErrorReporter;
                    domain = malformedByteSequenceException.getDomain();
                    key = malformedByteSequenceException.getKey();
                    arguments = malformedByteSequenceException.getArguments();
                    s = 2;
                    xMLErrorReporter.reportError(domain, key, arguments, s, malformedByteSequenceException);
                    return false;
                } catch (CharConversionException e3) {
                    malformedByteSequenceException = e3;
                    xMLErrorReporter = XMLDocumentFragmentScannerImpl.this.fErrorReporter;
                    arguments = null;
                    s = 2;
                    domain = "http://www.w3.org/TR/1998/REC-xml-19980210";
                    key = "CharConversionFailure";
                    xMLErrorReporter.reportError(domain, key, arguments, s, malformedByteSequenceException);
                    return false;
                } catch (EOFException e4) {
                    endOfFileHook(e4);
                    return false;
                }
            }
        }

        public boolean elementDepthIsZeroHook() {
            return false;
        }

        public void endOfFileHook(EOFException eOFException) {
            XMLDocumentFragmentScannerImpl xMLDocumentFragmentScannerImpl = XMLDocumentFragmentScannerImpl.this;
            if (xMLDocumentFragmentScannerImpl.fMarkupDepth != 0) {
                xMLDocumentFragmentScannerImpl.reportFatalError("PrematureEOF", null);
            }
        }

        public boolean scanForDoctypeHook() {
            return false;
        }

        public boolean scanRootElementHook() {
            return false;
        }
    }

    static {
        Boolean bool = Boolean.FALSE;
        FEATURE_DEFAULTS = new Boolean[]{null, null, bool, bool};
    }

    private void handleCharacter(char c, String str) {
        XMLDocumentHandler xMLDocumentHandler = this.fDocumentHandler;
        if (xMLDocumentHandler != null) {
            if (this.fNotifyBuiltInRefs) {
                xMLDocumentHandler.startGeneralEntity(str, null, null, null);
            }
            char[] cArr = this.fSingleChar;
            cArr[0] = c;
            this.fTempString.setValues(cArr, 0, 1);
            this.fDocumentHandler.characters(this.fTempString, null);
            if (this.fNotifyBuiltInRefs) {
                this.fDocumentHandler.endGeneralEntity(str, null);
            }
        }
    }

    public Dispatcher createContentDispatcher() {
        return new FragmentContentDispatcher();
    }

    @Override // org.apache.xerces.impl.XMLEntityHandler, org.apache.xerces.impl.XMLScanner
    public void endEntity(String str, Augmentations augmentations) {
        XMLDocumentHandler xMLDocumentHandler;
        if (this.fInScanContent) {
            XMLStringBuffer xMLStringBuffer = this.fStringBuffer;
            if (!(xMLStringBuffer.length == 0 || (xMLDocumentHandler = this.fDocumentHandler) == null)) {
                xMLDocumentHandler.characters(xMLStringBuffer, null);
                this.fStringBuffer.length = 0;
            }
        }
        super.endEntity(str, augmentations);
        if (this.fMarkupDepth != this.fEntityStack[this.fEntityDepth]) {
            reportFatalError("MarkupEntityMismatch", null);
        }
        if (this.fDocumentHandler != null && !this.fScanningAttribute && !str.equals("[xml]")) {
            this.fDocumentHandler.endGeneralEntity(str, augmentations);
        }
    }

    public String getDispatcherName(Dispatcher dispatcher) {
        return "null";
    }

    @Override // org.apache.xerces.xni.parser.XMLDocumentSource
    public XMLDocumentHandler getDocumentHandler() {
        return this.fDocumentHandler;
    }

    @Override // org.apache.xerces.impl.XMLScanner, org.apache.xerces.xni.parser.XMLComponent
    public Boolean getFeatureDefault(String str) {
        int i2 = 0;
        while (true) {
            String[] strArr = RECOGNIZED_FEATURES;
            if (i2 >= strArr.length) {
                return null;
            }
            if (strArr[i2].equals(str)) {
                return FEATURE_DEFAULTS[i2];
            }
            i2++;
        }
    }

    @Override // org.apache.xerces.impl.XMLScanner, org.apache.xerces.xni.parser.XMLComponent
    public Object getPropertyDefault(String str) {
        int i2 = 0;
        while (true) {
            String[] strArr = RECOGNIZED_PROPERTIES;
            if (i2 >= strArr.length) {
                return null;
            }
            if (strArr[i2].equals(str)) {
                return PROPERTY_DEFAULTS[i2];
            }
            i2++;
        }
    }

    @Override // org.apache.xerces.impl.XMLScanner, org.apache.xerces.xni.parser.XMLComponent
    public String[] getRecognizedFeatures() {
        return (String[]) RECOGNIZED_FEATURES.clone();
    }

    @Override // org.apache.xerces.impl.XMLScanner, org.apache.xerces.xni.parser.XMLComponent
    public String[] getRecognizedProperties() {
        return (String[]) RECOGNIZED_PROPERTIES.clone();
    }

    public String getScannerStateName(int i2) {
        if (i2 == 1) {
            return "SCANNER_STATE_START_OF_MARKUP";
        }
        if (i2 == 2) {
            return "SCANNER_STATE_COMMENT";
        }
        if (i2 == 3) {
            return "SCANNER_STATE_PI";
        }
        if (i2 == 4) {
            return "SCANNER_STATE_DOCTYPE";
        }
        if (i2 == 6) {
            return "SCANNER_STATE_ROOT_ELEMENT";
        }
        if (i2 == 7) {
            return "SCANNER_STATE_CONTENT";
        }
        if (i2 == 8) {
            return "SCANNER_STATE_REFERENCE";
        }
        switch (i2) {
            case 13:
                return "SCANNER_STATE_END_OF_INPUT";
            case 14:
                return "SCANNER_STATE_TERMINATED";
            case 15:
                return "SCANNER_STATE_CDATA";
            case 16:
                return "SCANNER_STATE_TEXT_DECL";
            default:
                StringBuffer stringBuffer = new StringBuffer();
                stringBuffer.append("??? (");
                stringBuffer.append(i2);
                stringBuffer.append(')');
                return stringBuffer.toString();
        }
    }

    public int handleEndElement(QName qName, boolean z) {
        int i2 = this.fMarkupDepth - 1;
        this.fMarkupDepth = i2;
        if (i2 < this.fEntityStack[this.fEntityDepth - 1]) {
            reportFatalError("ElementEntityMismatch", new Object[]{this.fCurrentElement.rawname});
        }
        QName qName2 = this.fQName;
        this.fElementStack.popElement(qName2);
        String str = qName.rawname;
        String str2 = qName2.rawname;
        if (str != str2) {
            reportFatalError("ETagRequired", new Object[]{str2});
        }
        if (this.fNamespaces) {
            qName.uri = qName2.uri;
        }
        XMLDocumentHandler xMLDocumentHandler = this.fDocumentHandler;
        if (xMLDocumentHandler != null && !z) {
            xMLDocumentHandler.endElement(qName, null);
        }
        return this.fMarkupDepth;
    }

    @Override // org.apache.xerces.impl.XMLScanner, org.apache.xerces.xni.parser.XMLComponent
    public void reset(XMLComponentManager xMLComponentManager) {
        super.reset(xMLComponentManager);
        this.fAttributes.setNamespaces(this.fNamespaces);
        this.fMarkupDepth = 0;
        this.fCurrentElement = null;
        this.fElementStack.clear();
        this.fHasExternalDTD = false;
        this.fStandalone = false;
        this.fIsEntityDeclaredVC = false;
        this.fInScanContent = false;
        setScannerState(7);
        setDispatcher(this.fContentDispatcher);
        if (this.fParserSettings) {
            try {
                this.fNotifyBuiltInRefs = xMLComponentManager.getFeature("http://apache.org/xml/features/scanner/notify-builtin-refs");
            } catch (XMLConfigurationException unused) {
                this.fNotifyBuiltInRefs = false;
            }
            try {
                Object property = xMLComponentManager.getProperty("http://apache.org/xml/properties/internal/entity-resolver");
                this.fExternalSubsetResolver = property instanceof ExternalSubsetResolver ? (ExternalSubsetResolver) property : null;
            } catch (XMLConfigurationException unused2) {
                this.fExternalSubsetResolver = null;
            }
        }
    }

    public void scanAttribute(XMLAttributes xMLAttributes) {
        if (this.fNamespaces) {
            this.fEntityScanner.scanQName(this.fAttributeQName);
        } else {
            String scanName = this.fEntityScanner.scanName();
            this.fAttributeQName.setValues(null, scanName, scanName, null);
        }
        this.fEntityScanner.skipSpaces();
        if (!this.fEntityScanner.skipChar(61)) {
            reportFatalError("EqRequiredInAttribute", new Object[]{this.fCurrentElement.rawname, this.fAttributeQName.rawname});
        }
        this.fEntityScanner.skipSpaces();
        int length = xMLAttributes.getLength();
        int addAttribute = xMLAttributes.addAttribute(this.fAttributeQName, XMLSymbols.fCDATASymbol, null);
        if (length == xMLAttributes.getLength()) {
            reportFatalError("AttributeNotUnique", new Object[]{this.fCurrentElement.rawname, this.fAttributeQName.rawname});
        }
        boolean scanAttributeValue = scanAttributeValue(this.fTempString, this.fTempString2, this.fAttributeQName.rawname, this.fIsEntityDeclaredVC, this.fCurrentElement.rawname);
        xMLAttributes.setValue(addAttribute, this.fTempString.toString());
        if (!scanAttributeValue) {
            xMLAttributes.setNonNormalizedValue(addAttribute, this.fTempString2.toString());
        }
        xMLAttributes.setSpecified(addAttribute, true);
    }

    public boolean scanCDATASection(boolean z) {
        XMLDocumentHandler xMLDocumentHandler;
        XMLDocumentHandler xMLDocumentHandler2 = this.fDocumentHandler;
        if (xMLDocumentHandler2 != null) {
            xMLDocumentHandler2.startCDATA(null);
        }
        while (true) {
            this.fStringBuffer.clear();
            int i2 = 0;
            if (!this.fEntityScanner.scanData("]]", this.fStringBuffer)) {
                XMLDocumentHandler xMLDocumentHandler3 = this.fDocumentHandler;
                if (xMLDocumentHandler3 != null) {
                    XMLStringBuffer xMLStringBuffer = this.fStringBuffer;
                    if (xMLStringBuffer.length > 0) {
                        xMLDocumentHandler3.characters(xMLStringBuffer, null);
                    }
                }
                int i3 = 0;
                while (this.fEntityScanner.skipChar(93)) {
                    i3++;
                }
                if (this.fDocumentHandler != null && i3 > 0) {
                    this.fStringBuffer.clear();
                    if (i3 > 2048) {
                        int i4 = i3 / 2048;
                        int i5 = i3 % 2048;
                        for (int i6 = 0; i6 < 2048; i6++) {
                            this.fStringBuffer.append(']');
                        }
                        while (i2 < i4) {
                            this.fDocumentHandler.characters(this.fStringBuffer, null);
                            i2++;
                        }
                        if (i5 != 0) {
                            XMLStringBuffer xMLStringBuffer2 = this.fStringBuffer;
                            xMLStringBuffer2.length = i5;
                            this.fDocumentHandler.characters(xMLStringBuffer2, null);
                        }
                    } else {
                        while (i2 < i3) {
                            this.fStringBuffer.append(']');
                            i2++;
                        }
                        this.fDocumentHandler.characters(this.fStringBuffer, null);
                    }
                }
                if (this.fEntityScanner.skipChar(62)) {
                    break;
                } else if (this.fDocumentHandler != null) {
                    this.fStringBuffer.clear();
                    this.fStringBuffer.append("]]");
                    xMLDocumentHandler = this.fDocumentHandler;
                }
            } else {
                XMLDocumentHandler xMLDocumentHandler4 = this.fDocumentHandler;
                if (xMLDocumentHandler4 != null) {
                    xMLDocumentHandler4.characters(this.fStringBuffer, null);
                }
                int peekChar = this.fEntityScanner.peekChar();
                if (peekChar != -1 && isInvalidLiteral(peekChar)) {
                    if (XMLChar.isHighSurrogate(peekChar)) {
                        this.fStringBuffer.clear();
                        scanSurrogates(this.fStringBuffer);
                        xMLDocumentHandler = this.fDocumentHandler;
                        if (xMLDocumentHandler == null) {
                        }
                    } else {
                        reportFatalError("InvalidCharInCDSect", new Object[]{Integer.toString(peekChar, 16)});
                        this.fEntityScanner.scanChar();
                    }
                }
            }
            xMLDocumentHandler.characters(this.fStringBuffer, null);
        }
        this.fMarkupDepth--;
        XMLDocumentHandler xMLDocumentHandler5 = this.fDocumentHandler;
        if (xMLDocumentHandler5 != null) {
            xMLDocumentHandler5.endCDATA(null);
        }
        return true;
    }

    public void scanCharReference() {
        XMLDocumentHandler xMLDocumentHandler;
        Augmentations augmentations;
        this.fStringBuffer2.clear();
        int scanCharReferenceValue = scanCharReferenceValue(this.fStringBuffer2, null);
        this.fMarkupDepth--;
        if (scanCharReferenceValue != -1 && (xMLDocumentHandler = this.fDocumentHandler) != null) {
            if (this.fNotifyCharRefs) {
                xMLDocumentHandler.startGeneralEntity(this.fCharRefLiteral, null, null, null);
            }
            if (!this.fValidation || scanCharReferenceValue > 32) {
                augmentations = null;
            } else {
                Augmentations augmentations2 = this.fTempAugmentations;
                if (augmentations2 != null) {
                    augmentations2.removeAllItems();
                } else {
                    this.fTempAugmentations = new AugmentationsImpl();
                }
                augmentations = this.fTempAugmentations;
                augmentations.putItem(Constants.CHAR_REF_PROBABLE_WS, Boolean.TRUE);
            }
            this.fDocumentHandler.characters(this.fStringBuffer2, augmentations);
            if (this.fNotifyCharRefs) {
                this.fDocumentHandler.endGeneralEntity(this.fCharRefLiteral, null);
            }
        }
    }

    public void scanComment() {
        scanComment(this.fStringBuffer);
        this.fMarkupDepth--;
        XMLDocumentHandler xMLDocumentHandler = this.fDocumentHandler;
        if (xMLDocumentHandler != null) {
            xMLDocumentHandler.comment(this.fStringBuffer, null);
        }
    }

    public int scanContent() {
        XMLString xMLString = this.fTempString;
        int scanContent = this.fEntityScanner.scanContent(xMLString);
        if (scanContent == 13) {
            this.fEntityScanner.scanChar();
            this.fStringBuffer.clear();
            this.fStringBuffer.append(this.fTempString);
            this.fStringBuffer.append((char) scanContent);
            xMLString = this.fStringBuffer;
            scanContent = -1;
        }
        XMLDocumentHandler xMLDocumentHandler = this.fDocumentHandler;
        if (xMLDocumentHandler != null && xMLString.length > 0) {
            xMLDocumentHandler.characters(xMLString, null);
        }
        if (scanContent != 93 || this.fTempString.length != 0) {
            return scanContent;
        }
        this.fStringBuffer.clear();
        this.fStringBuffer.append((char) this.fEntityScanner.scanChar());
        this.fInScanContent = true;
        if (this.fEntityScanner.skipChar(93)) {
            do {
                this.fStringBuffer.append(']');
            } while (this.fEntityScanner.skipChar(93));
            if (this.fEntityScanner.skipChar(62)) {
                reportFatalError("CDEndInContent", null);
            }
        }
        XMLDocumentHandler xMLDocumentHandler2 = this.fDocumentHandler;
        if (xMLDocumentHandler2 != null) {
            XMLStringBuffer xMLStringBuffer = this.fStringBuffer;
            if (xMLStringBuffer.length != 0) {
                xMLDocumentHandler2.characters(xMLStringBuffer, null);
            }
        }
        this.fInScanContent = false;
        return -1;
    }

    @Override // org.apache.xerces.xni.parser.XMLDocumentScanner
    public boolean scanDocument(boolean z) {
        this.fEntityScanner = this.fEntityManager.getEntityScanner();
        this.fEntityManager.setEntityHandler(this);
        while (this.fDispatcher.dispatch(z)) {
            if (!z) {
                return true;
            }
        }
        return false;
    }

    public int scanEndElement() {
        this.fElementStack.popElement(this.fElementQName);
        if (!this.fEntityScanner.skipString(this.fElementQName.rawname)) {
            reportFatalError("ETagRequired", new Object[]{this.fElementQName.rawname});
        }
        this.fEntityScanner.skipSpaces();
        if (!this.fEntityScanner.skipChar(62)) {
            reportFatalError("ETagUnterminated", new Object[]{this.fElementQName.rawname});
        }
        int i2 = this.fMarkupDepth - 1;
        this.fMarkupDepth = i2;
        int i3 = i2 - 1;
        this.fMarkupDepth = i3;
        if (i3 < this.fEntityStack[this.fEntityDepth - 1]) {
            reportFatalError("ElementEntityMismatch", new Object[]{this.fCurrentElement.rawname});
        }
        XMLDocumentHandler xMLDocumentHandler = this.fDocumentHandler;
        if (xMLDocumentHandler != null) {
            xMLDocumentHandler.endElement(this.fElementQName, null);
        }
        return this.fMarkupDepth;
    }

    public void scanEntityReference() {
        char c;
        String scanName = this.fEntityScanner.scanName();
        if (scanName == null) {
            reportFatalError("NameRequiredInReference", null);
            return;
        }
        if (!this.fEntityScanner.skipChar(59)) {
            reportFatalError("SemicolonRequiredInReference", new Object[]{scanName});
        }
        this.fMarkupDepth--;
        String str = XMLScanner.fAmpSymbol;
        if (scanName == str) {
            c = '&';
        } else {
            str = XMLScanner.fLtSymbol;
            if (scanName == str) {
                c = '<';
            } else {
                str = XMLScanner.fGtSymbol;
                if (scanName == str) {
                    c = '>';
                } else {
                    str = XMLScanner.fQuotSymbol;
                    if (scanName == str) {
                        c = StringPtg.FORMULA_DELIMITER;
                    } else {
                        str = XMLScanner.fAposSymbol;
                        if (scanName == str) {
                            c = '\'';
                        } else if (this.fEntityManager.isUnparsedEntity(scanName)) {
                            reportFatalError("ReferenceToUnparsedEntity", new Object[]{scanName});
                            return;
                        } else {
                            if (!this.fEntityManager.isDeclaredEntity(scanName)) {
                                if (!this.fIsEntityDeclaredVC) {
                                    reportFatalError("EntityNotDeclared", new Object[]{scanName});
                                } else if (this.fValidation) {
                                    this.fErrorReporter.reportError("http://www.w3.org/TR/1998/REC-xml-19980210", "EntityNotDeclared", new Object[]{scanName}, 1);
                                }
                            }
                            this.fEntityManager.startEntity(scanName, false);
                            return;
                        }
                    }
                }
            }
        }
        handleCharacter(c, str);
    }

    @Override // org.apache.xerces.impl.XMLScanner
    public void scanPIData(String str, XMLString xMLString) {
        super.scanPIData(str, xMLString);
        this.fMarkupDepth--;
        XMLDocumentHandler xMLDocumentHandler = this.fDocumentHandler;
        if (xMLDocumentHandler != null) {
            xMLDocumentHandler.processingInstruction(str, xMLString, null);
        }
    }

    public boolean scanStartElement() {
        boolean z;
        if (this.fNamespaces) {
            this.fEntityScanner.scanQName(this.fElementQName);
        } else {
            String scanName = this.fEntityScanner.scanName();
            this.fElementQName.setValues(null, scanName, scanName, null);
        }
        QName qName = this.fElementQName;
        String str = qName.rawname;
        this.fCurrentElement = this.fElementStack.pushElement(qName);
        this.fAttributes.removeAllAttributes();
        while (true) {
            boolean skipSpaces = this.fEntityScanner.skipSpaces();
            int peekChar = this.fEntityScanner.peekChar();
            if (peekChar == 62) {
                this.fEntityScanner.scanChar();
                z = false;
                break;
            } else if (peekChar == 47) {
                this.fEntityScanner.scanChar();
                if (!this.fEntityScanner.skipChar(62)) {
                    reportFatalError("ElementUnterminated", new Object[]{str});
                }
                z = true;
            } else {
                if ((!isValidNameStartChar(peekChar) || !skipSpaces) && (!isValidNameStartHighSurrogate(peekChar) || !skipSpaces)) {
                    reportFatalError("ElementUnterminated", new Object[]{str});
                }
                scanAttribute(this.fAttributes);
            }
        }
        XMLDocumentHandler xMLDocumentHandler = this.fDocumentHandler;
        if (xMLDocumentHandler != null) {
            if (z) {
                int i2 = this.fMarkupDepth - 1;
                this.fMarkupDepth = i2;
                if (i2 < this.fEntityStack[this.fEntityDepth - 1]) {
                    reportFatalError("ElementEntityMismatch", new Object[]{this.fCurrentElement.rawname});
                }
                this.fDocumentHandler.emptyElement(this.fElementQName, this.fAttributes, null);
                this.fElementStack.popElement(this.fElementQName);
            } else {
                xMLDocumentHandler.startElement(this.fElementQName, this.fAttributes, null);
            }
        }
        return z;
    }

    public boolean scanStartElementAfterName() {
        boolean z;
        QName qName = this.fElementQName;
        String str = qName.rawname;
        this.fCurrentElement = this.fElementStack.pushElement(qName);
        this.fAttributes.removeAllAttributes();
        while (true) {
            int peekChar = this.fEntityScanner.peekChar();
            if (peekChar == 62) {
                this.fEntityScanner.scanChar();
                z = false;
                break;
            } else if (peekChar == 47) {
                this.fEntityScanner.scanChar();
                if (!this.fEntityScanner.skipChar(62)) {
                    reportFatalError("ElementUnterminated", new Object[]{str});
                }
                z = true;
            } else {
                if ((!isValidNameStartChar(peekChar) || !this.fSawSpace) && (!isValidNameStartHighSurrogate(peekChar) || !this.fSawSpace)) {
                    reportFatalError("ElementUnterminated", new Object[]{str});
                }
                scanAttribute(this.fAttributes);
                this.fSawSpace = this.fEntityScanner.skipSpaces();
            }
        }
        XMLDocumentHandler xMLDocumentHandler = this.fDocumentHandler;
        if (xMLDocumentHandler != null) {
            if (z) {
                int i2 = this.fMarkupDepth - 1;
                this.fMarkupDepth = i2;
                if (i2 < this.fEntityStack[this.fEntityDepth - 1]) {
                    reportFatalError("ElementEntityMismatch", new Object[]{this.fCurrentElement.rawname});
                }
                this.fDocumentHandler.emptyElement(this.fElementQName, this.fAttributes, null);
                this.fElementStack.popElement(this.fElementQName);
            } else {
                xMLDocumentHandler.startElement(this.fElementQName, this.fAttributes, null);
            }
        }
        return z;
    }

    public void scanStartElementName() {
        if (this.fNamespaces) {
            this.fEntityScanner.scanQName(this.fElementQName);
        } else {
            String scanName = this.fEntityScanner.scanName();
            this.fElementQName.setValues(null, scanName, scanName, null);
        }
        this.fSawSpace = this.fEntityScanner.skipSpaces();
    }

    public void scanXMLDeclOrTextDecl(boolean z) {
        super.scanXMLDeclOrTextDecl(z, this.fStrings);
        boolean z2 = true;
        this.fMarkupDepth--;
        String[] strArr = this.fStrings;
        String str = strArr[0];
        String str2 = strArr[1];
        String str3 = strArr[2];
        if (str3 == null || !str3.equals("yes")) {
            z2 = false;
        }
        this.fStandalone = z2;
        this.fEntityManager.setStandalone(z2);
        this.fEntityScanner.setXMLVersion(str);
        XMLDocumentHandler xMLDocumentHandler = this.fDocumentHandler;
        if (xMLDocumentHandler != null) {
            if (z) {
                xMLDocumentHandler.textDecl(str, str2, null);
            } else {
                xMLDocumentHandler.xmlDecl(str, str2, str3, null);
            }
        }
        if (str2 != null && !this.fEntityScanner.fCurrentEntity.isEncodingExternallySpecified()) {
            this.fEntityScanner.setEncoding(str2);
        }
    }

    public final void setDispatcher(Dispatcher dispatcher) {
        this.fDispatcher = dispatcher;
    }

    @Override // org.apache.xerces.xni.parser.XMLDocumentSource
    public void setDocumentHandler(XMLDocumentHandler xMLDocumentHandler) {
        this.fDocumentHandler = xMLDocumentHandler;
    }

    @Override // org.apache.xerces.impl.XMLScanner, org.apache.xerces.xni.parser.XMLComponent
    public void setFeature(String str, boolean z) {
        super.setFeature(str, z);
        if (str.startsWith(Constants.XERCES_FEATURE_PREFIX) && str.length() - 31 == 27 && str.endsWith(Constants.NOTIFY_BUILTIN_REFS_FEATURE)) {
            this.fNotifyBuiltInRefs = z;
        }
    }

    @Override // org.apache.xerces.xni.parser.XMLDocumentScanner
    public void setInputSource(XMLInputSource xMLInputSource) {
        this.fEntityManager.setEntityHandler(this);
        this.fEntityManager.startEntity("$fragment$", xMLInputSource, false, true);
    }

    @Override // org.apache.xerces.impl.XMLScanner, org.apache.xerces.xni.parser.XMLComponent
    public void setProperty(String str, Object obj) {
        super.setProperty(str, obj);
        if (str.startsWith(Constants.XERCES_PROPERTY_PREFIX)) {
            int length = str.length() - 33;
            if (length == 23 && str.endsWith(Constants.ENTITY_MANAGER_PROPERTY)) {
                this.fEntityManager = (XMLEntityManager) obj;
            } else if (length == 24 && str.endsWith(Constants.ENTITY_RESOLVER_PROPERTY)) {
                this.fExternalSubsetResolver = obj instanceof ExternalSubsetResolver ? (ExternalSubsetResolver) obj : null;
            }
        }
    }

    public final void setScannerState(int i2) {
        this.fScannerState = i2;
    }

    @Override // org.apache.xerces.impl.XMLEntityHandler, org.apache.xerces.impl.XMLScanner
    public void startEntity(String str, XMLResourceIdentifier xMLResourceIdentifier, String str2, Augmentations augmentations) {
        int i2 = this.fEntityDepth;
        int[] iArr = this.fEntityStack;
        if (i2 == iArr.length) {
            int[] iArr2 = new int[(iArr.length * 2)];
            System.arraycopy(iArr, 0, iArr2, 0, iArr.length);
            this.fEntityStack = iArr2;
        }
        this.fEntityStack[this.fEntityDepth] = this.fMarkupDepth;
        super.startEntity(str, xMLResourceIdentifier, str2, augmentations);
        if (this.fStandalone && this.fEntityManager.isEntityDeclInExternalSubset(str)) {
            reportFatalError("MSG_REFERENCE_TO_EXTERNALLY_DECLARED_ENTITY_WHEN_STANDALONE", new Object[]{str});
        }
        if (this.fDocumentHandler != null && !this.fScanningAttribute && !str.equals("[xml]")) {
            this.fDocumentHandler.startGeneralEntity(str, xMLResourceIdentifier, str2, augmentations);
        }
    }
}
