package org.apache.xerces.impl;

import java.io.CharConversionException;
import java.io.EOFException;
import org.apache.xerces.impl.XMLDocumentFragmentScannerImpl;
import org.apache.xerces.impl.dtd.XMLDTDDescription;
import org.apache.xerces.impl.io.MalformedByteSequenceException;
import org.apache.xerces.impl.validation.ValidationManager;
import org.apache.xerces.util.NamespaceSupport;
import org.apache.xerces.util.XMLChar;
import org.apache.xerces.util.XMLStringBuffer;
import org.apache.xerces.xni.Augmentations;
import org.apache.xerces.xni.NamespaceContext;
import org.apache.xerces.xni.XMLDocumentHandler;
import org.apache.xerces.xni.XMLResourceIdentifier;
import org.apache.xerces.xni.XMLString;
import org.apache.xerces.xni.XNIException;
import org.apache.xerces.xni.parser.XMLComponentManager;
import org.apache.xerces.xni.parser.XMLConfigurationException;
import org.apache.xerces.xni.parser.XMLDTDScanner;
import org.apache.xerces.xni.parser.XMLInputSource;

public class XMLDocumentScannerImpl extends XMLDocumentFragmentScannerImpl {
    public static final String DISALLOW_DOCTYPE_DECL_FEATURE = "http://apache.org/xml/features/disallow-doctype-decl";
    public static final String DTD_SCANNER = "http://apache.org/xml/properties/internal/dtd-scanner";
    public static final Boolean[] FEATURE_DEFAULTS = {Boolean.TRUE, Boolean.FALSE};
    public static final String LOAD_EXTERNAL_DTD = "http://apache.org/xml/features/nonvalidating/load-external-dtd";
    public static final String NAMESPACE_CONTEXT = "http://apache.org/xml/properties/internal/namespace-context";
    public static final Object[] PROPERTY_DEFAULTS = {null, null, null};
    public static final String[] RECOGNIZED_FEATURES = {"http://apache.org/xml/features/nonvalidating/load-external-dtd", "http://apache.org/xml/features/disallow-doctype-decl"};
    public static final String[] RECOGNIZED_PROPERTIES = {"http://apache.org/xml/properties/internal/dtd-scanner", "http://apache.org/xml/properties/internal/validation-manager", "http://apache.org/xml/properties/internal/namespace-context"};
    public static final int SCANNER_STATE_DTD_EXTERNAL = 18;
    public static final int SCANNER_STATE_DTD_EXTERNAL_DECLS = 19;
    public static final int SCANNER_STATE_DTD_INTERNAL_DECLS = 17;
    public static final int SCANNER_STATE_PROLOG = 5;
    public static final int SCANNER_STATE_TRAILING_MISC = 12;
    public static final int SCANNER_STATE_XML_DECL = 0;
    public static final String VALIDATION_MANAGER = "http://apache.org/xml/properties/internal/validation-manager";
    public final XMLDTDDescription fDTDDescription = new XMLDTDDescription(null, null, null, null, null);
    public final XMLDocumentFragmentScannerImpl.Dispatcher fDTDDispatcher = new DTDDispatcher();
    public XMLDTDScanner fDTDScanner;
    public boolean fDisallowDoctype = false;
    public String fDoctypeName;
    public String fDoctypePublicId;
    public String fDoctypeSystemId;
    public XMLInputSource fExternalSubsetSource = null;
    public boolean fLoadExternalDTD = true;
    public NamespaceContext fNamespaceContext = new NamespaceSupport();
    public final XMLDocumentFragmentScannerImpl.Dispatcher fPrologDispatcher = new PrologDispatcher();
    public boolean fScanningDTD;
    public boolean fSeenDoctypeDecl;
    public final XMLString fString = new XMLString();
    public final XMLStringBuffer fStringBuffer = new XMLStringBuffer();
    public final String[] fStrings = new String[3];
    public final XMLDocumentFragmentScannerImpl.Dispatcher fTrailingMiscDispatcher = new TrailingMiscDispatcher();
    public ValidationManager fValidationManager;
    public final XMLDocumentFragmentScannerImpl.Dispatcher fXMLDeclDispatcher = new XMLDeclDispatcher();

    public class ContentDispatcher extends XMLDocumentFragmentScannerImpl.FragmentContentDispatcher {
        public final /* synthetic */ XMLDocumentScannerImpl this$0;

        public ContentDispatcher(XMLDocumentScannerImpl xMLDocumentScannerImpl) {
            super();
            this.this$0 = xMLDocumentScannerImpl;
        }

        @Override // org.apache.xerces.impl.XMLDocumentFragmentScannerImpl.FragmentContentDispatcher
        public boolean elementDepthIsZeroHook() {
            this.this$0.setScannerState(12);
            XMLDocumentScannerImpl xMLDocumentScannerImpl = this.this$0;
            xMLDocumentScannerImpl.setDispatcher(xMLDocumentScannerImpl.fTrailingMiscDispatcher);
            return true;
        }

        @Override // org.apache.xerces.impl.XMLDocumentFragmentScannerImpl.FragmentContentDispatcher
        public void endOfFileHook(EOFException eOFException) {
            this.this$0.reportFatalError("PrematureEOF", null);
        }

        public void resolveExternalSubsetAndRead() {
            this.this$0.fDTDDescription.setValues(null, null, this.this$0.fEntityManager.getCurrentResourceIdentifier().getExpandedSystemId(), null);
            this.this$0.fDTDDescription.setRootName(this.this$0.fElementQName.rawname);
            XMLDocumentScannerImpl xMLDocumentScannerImpl = this.this$0;
            XMLInputSource externalSubset = xMLDocumentScannerImpl.fExternalSubsetResolver.getExternalSubset(xMLDocumentScannerImpl.fDTDDescription);
            if (externalSubset != null) {
                XMLDocumentScannerImpl xMLDocumentScannerImpl2 = this.this$0;
                xMLDocumentScannerImpl2.fDoctypeName = xMLDocumentScannerImpl2.fElementQName.rawname;
                xMLDocumentScannerImpl2.fDoctypePublicId = externalSubset.getPublicId();
                this.this$0.fDoctypeSystemId = externalSubset.getSystemId();
                XMLDocumentScannerImpl xMLDocumentScannerImpl3 = this.this$0;
                XMLDocumentHandler xMLDocumentHandler = xMLDocumentScannerImpl3.fDocumentHandler;
                if (xMLDocumentHandler != null) {
                    xMLDocumentHandler.doctypeDecl(xMLDocumentScannerImpl3.fDoctypeName, xMLDocumentScannerImpl3.fDoctypePublicId, xMLDocumentScannerImpl3.fDoctypeSystemId, null);
                }
                try {
                    if (this.this$0.fValidationManager != null) {
                        if (this.this$0.fValidationManager.isCachedDTD()) {
                            this.this$0.fDTDScanner.setInputSource(null);
                        }
                    }
                    this.this$0.fDTDScanner.setInputSource(externalSubset);
                    do {
                    } while (this.this$0.fDTDScanner.scanDTDExternalSubset(true));
                } finally {
                    XMLDocumentScannerImpl xMLDocumentScannerImpl4 = this.this$0;
                    xMLDocumentScannerImpl4.fEntityManager.setEntityHandler(xMLDocumentScannerImpl4);
                }
            }
        }

        @Override // org.apache.xerces.impl.XMLDocumentFragmentScannerImpl.FragmentContentDispatcher
        public boolean scanForDoctypeHook() {
            if (!this.this$0.fEntityScanner.skipString("DOCTYPE")) {
                return false;
            }
            this.this$0.setScannerState(4);
            return true;
        }

        @Override // org.apache.xerces.impl.XMLDocumentFragmentScannerImpl.FragmentContentDispatcher
        public boolean scanRootElementHook() {
            XMLDocumentScannerImpl xMLDocumentScannerImpl = this.this$0;
            if (xMLDocumentScannerImpl.fExternalSubsetResolver != null && !xMLDocumentScannerImpl.fSeenDoctypeDecl && !xMLDocumentScannerImpl.fDisallowDoctype && (xMLDocumentScannerImpl.fValidation || xMLDocumentScannerImpl.fLoadExternalDTD)) {
                this.this$0.scanStartElementName();
                resolveExternalSubsetAndRead();
                if (!this.this$0.scanStartElementAfterName()) {
                    return false;
                }
            } else if (!this.this$0.scanStartElement()) {
                return false;
            }
            this.this$0.setScannerState(12);
            XMLDocumentScannerImpl xMLDocumentScannerImpl2 = this.this$0;
            xMLDocumentScannerImpl2.setDispatcher(xMLDocumentScannerImpl2.fTrailingMiscDispatcher);
            return true;
        }
    }

    public final class DTDDispatcher implements XMLDocumentFragmentScannerImpl.Dispatcher {
        public DTDDispatcher() {
        }

        /* JADX WARNING: Missing exception handler attribute for start block: B:69:0x01b1 */
        @Override // org.apache.xerces.impl.XMLDocumentFragmentScannerImpl.Dispatcher
        public boolean dispatch(boolean z) {
            XMLDocumentScannerImpl.this.fEntityManager.setEntityHandler(null);
            while (true) {
                boolean z2 = false;
                try {
                    switch (XMLDocumentScannerImpl.this.fScannerState) {
                        case 17:
                            boolean z3 = (XMLDocumentScannerImpl.this.fValidation || XMLDocumentScannerImpl.this.fLoadExternalDTD) && (XMLDocumentScannerImpl.this.fValidationManager == null || !XMLDocumentScannerImpl.this.fValidationManager.isCachedDTD());
                            if (!XMLDocumentScannerImpl.this.fDTDScanner.scanDTDInternalSubset(true, XMLDocumentScannerImpl.this.fStandalone, XMLDocumentScannerImpl.this.fHasExternalDTD && z3)) {
                                if (!XMLDocumentScannerImpl.this.fEntityScanner.skipChar(93)) {
                                    XMLDocumentScannerImpl.this.reportFatalError("EXPECTED_SQUARE_BRACKET_TO_CLOSE_INTERNAL_SUBSET", null);
                                }
                                XMLDocumentScannerImpl.this.fEntityScanner.skipSpaces();
                                if (!XMLDocumentScannerImpl.this.fEntityScanner.skipChar(62)) {
                                    XMLDocumentScannerImpl.this.reportFatalError("DoctypedeclUnterminated", new Object[]{XMLDocumentScannerImpl.this.fDoctypeName});
                                }
                                XMLDocumentScannerImpl.this.fMarkupDepth--;
                                if (XMLDocumentScannerImpl.this.fDoctypeSystemId == null) {
                                    if (XMLDocumentScannerImpl.this.fExternalSubsetSource == null) {
                                        XMLDocumentScannerImpl.this.fIsEntityDeclaredVC = XMLDocumentScannerImpl.this.fEntityManager.hasPEReferences() && !XMLDocumentScannerImpl.this.fStandalone;
                                        break;
                                    } else {
                                        XMLDocumentScannerImpl.this.fIsEntityDeclaredVC = !XMLDocumentScannerImpl.this.fStandalone;
                                        if (!z3) {
                                            break;
                                        } else {
                                            XMLDocumentScannerImpl.this.fDTDScanner.setInputSource(XMLDocumentScannerImpl.this.fExternalSubsetSource);
                                            XMLDocumentScannerImpl.this.fExternalSubsetSource = null;
                                            XMLDocumentScannerImpl.this.setScannerState(19);
                                            break;
                                        }
                                    }
                                } else {
                                    XMLDocumentScannerImpl.this.fIsEntityDeclaredVC = !XMLDocumentScannerImpl.this.fStandalone;
                                    if (!z3) {
                                        break;
                                    } else {
                                        XMLDocumentScannerImpl.this.setScannerState(18);
                                        break;
                                    }
                                }
                            }
                            break;
                        case 18:
                            XMLDocumentScannerImpl.this.fDTDDescription.setValues(XMLDocumentScannerImpl.this.fDoctypePublicId, XMLDocumentScannerImpl.this.fDoctypeSystemId, null, null);
                            XMLDocumentScannerImpl.this.fDTDDescription.setRootName(XMLDocumentScannerImpl.this.fDoctypeName);
                            XMLDocumentScannerImpl.this.fDTDScanner.setInputSource(XMLDocumentScannerImpl.this.fEntityManager.resolveEntity(XMLDocumentScannerImpl.this.fDTDDescription));
                            XMLDocumentScannerImpl.this.setScannerState(19);
                            z2 = true;
                            break;
                        case 19:
                            if (!XMLDocumentScannerImpl.this.fDTDScanner.scanDTDExternalSubset(true)) {
                                XMLDocumentScannerImpl.this.setScannerState(5);
                                XMLDocumentScannerImpl.this.setDispatcher(XMLDocumentScannerImpl.this.fPrologDispatcher);
                                XMLDocumentScannerImpl.this.fEntityManager.setEntityHandler(XMLDocumentScannerImpl.this);
                                XMLDocumentScannerImpl xMLDocumentScannerImpl = XMLDocumentScannerImpl.this;
                                xMLDocumentScannerImpl.fEntityManager.setEntityHandler(xMLDocumentScannerImpl);
                                return true;
                            }
                            break;
                        default:
                            StringBuffer stringBuffer = new StringBuffer();
                            stringBuffer.append("DTDDispatcher#dispatch: scanner state=");
                            stringBuffer.append(XMLDocumentScannerImpl.this.fScannerState);
                            stringBuffer.append(" (");
                            stringBuffer.append(XMLDocumentScannerImpl.this.getScannerStateName(XMLDocumentScannerImpl.this.fScannerState));
                            stringBuffer.append(')');
                            throw new XNIException(stringBuffer.toString());
                    }
                    if (!z && !z2) {
                        XMLDocumentScannerImpl xMLDocumentScannerImpl2 = XMLDocumentScannerImpl.this;
                        xMLDocumentScannerImpl2.fEntityManager.setEntityHandler(xMLDocumentScannerImpl2);
                        return true;
                    }
                } catch (MalformedByteSequenceException e2) {
                    XMLDocumentScannerImpl.this.fErrorReporter.reportError(e2.getDomain(), e2.getKey(), e2.getArguments(), (short) 2, (Exception) e2);
                    XMLDocumentScannerImpl xMLDocumentScannerImpl3 = XMLDocumentScannerImpl.this;
                    xMLDocumentScannerImpl3.fEntityManager.setEntityHandler(xMLDocumentScannerImpl3);
                    return false;
                } catch (CharConversionException e3) {
                    XMLDocumentScannerImpl.this.fErrorReporter.reportError("http://www.w3.org/TR/1998/REC-xml-19980210", "CharConversionFailure", (Object[]) null, (short) 2, (Exception) e3);
                    XMLDocumentScannerImpl xMLDocumentScannerImpl4 = XMLDocumentScannerImpl.this;
                    xMLDocumentScannerImpl4.fEntityManager.setEntityHandler(xMLDocumentScannerImpl4);
                    return false;
                } catch (EOFException unknown) {
                    try {
                        XMLDocumentScannerImpl.this.reportFatalError("PrematureEOF", null);
                        return false;
                    } finally {
                        XMLDocumentScannerImpl xMLDocumentScannerImpl5 = XMLDocumentScannerImpl.this;
                        xMLDocumentScannerImpl5.fEntityManager.setEntityHandler(xMLDocumentScannerImpl5);
                    }
                }
            }
            XMLDocumentScannerImpl.this.setScannerState(5);
            XMLDocumentScannerImpl.this.setDispatcher(XMLDocumentScannerImpl.this.fPrologDispatcher);
            XMLDocumentScannerImpl.this.fEntityManager.setEntityHandler(XMLDocumentScannerImpl.this);
            XMLDocumentScannerImpl xMLDocumentScannerImpl6 = XMLDocumentScannerImpl.this;
            xMLDocumentScannerImpl6.fEntityManager.setEntityHandler(xMLDocumentScannerImpl6);
            return true;
        }
    }

    public final class PrologDispatcher implements XMLDocumentFragmentScannerImpl.Dispatcher {
        public PrologDispatcher() {
        }

        /* JADX WARNING: Code restructure failed: missing block: B:41:0x00d1, code lost:
            return true;
         */
        /* JADX WARNING: Removed duplicated region for block: B:114:0x0000 A[ADDED_TO_REGION, SYNTHETIC] */
        /* JADX WARNING: Removed duplicated region for block: B:89:0x01ef A[ADDED_TO_REGION] */
        @Override // org.apache.xerces.impl.XMLDocumentFragmentScannerImpl.Dispatcher
        public boolean dispatch(boolean z) {
            boolean z2;
            String str;
            XMLDocumentScannerImpl xMLDocumentScannerImpl;
            XMLDocumentScannerImpl xMLDocumentScannerImpl2;
            while (true) {
                try {
                    switch (XMLDocumentScannerImpl.this.fScannerState) {
                        case 1:
                            XMLDocumentScannerImpl.this.fMarkupDepth++;
                            str = "MarkupNotRecognizedInProlog";
                            if (XMLDocumentScannerImpl.this.fEntityScanner.skipChar(33)) {
                                if (XMLDocumentScannerImpl.this.fEntityScanner.skipChar(45)) {
                                    if (!XMLDocumentScannerImpl.this.fEntityScanner.skipChar(45)) {
                                        XMLDocumentScannerImpl.this.reportFatalError("InvalidCommentStart", null);
                                    }
                                    XMLDocumentScannerImpl.this.setScannerState(2);
                                } else if (XMLDocumentScannerImpl.this.fEntityScanner.skipString("DOCTYPE")) {
                                    XMLDocumentScannerImpl.this.setScannerState(4);
                                } else {
                                    xMLDocumentScannerImpl = XMLDocumentScannerImpl.this;
                                    xMLDocumentScannerImpl.reportFatalError(str, null);
                                    z2 = false;
                                    if (!z && !z2) {
                                        if (z) {
                                            if (XMLDocumentScannerImpl.this.fEntityScanner.scanChar() != 60) {
                                                XMLDocumentScannerImpl.this.reportFatalError("RootElementRequired", null);
                                            }
                                            XMLDocumentScannerImpl.this.setScannerState(6);
                                            XMLDocumentScannerImpl.this.setDispatcher(XMLDocumentScannerImpl.this.fContentDispatcher);
                                        }
                                        return true;
                                    }
                                }
                                z2 = true;
                                if (!z) {
                                }
                            } else if (XMLDocumentScannerImpl.this.isValidNameStartChar(XMLDocumentScannerImpl.this.fEntityScanner.peekChar())) {
                                XMLDocumentScannerImpl.this.setScannerState(6);
                                XMLDocumentScannerImpl.this.setDispatcher(XMLDocumentScannerImpl.this.fContentDispatcher);
                                return true;
                            } else if (XMLDocumentScannerImpl.this.fEntityScanner.skipChar(63)) {
                                XMLDocumentScannerImpl.this.setScannerState(3);
                                z2 = true;
                                if (!z) {
                                }
                            } else if (XMLDocumentScannerImpl.this.isValidNameStartHighSurrogate(XMLDocumentScannerImpl.this.fEntityScanner.peekChar())) {
                                XMLDocumentScannerImpl.this.setScannerState(6);
                                XMLDocumentScannerImpl.this.setDispatcher(XMLDocumentScannerImpl.this.fContentDispatcher);
                                return true;
                            } else {
                                xMLDocumentScannerImpl = XMLDocumentScannerImpl.this;
                                xMLDocumentScannerImpl.reportFatalError(str, null);
                                z2 = false;
                                if (!z) {
                                }
                            }
                        case 2:
                            XMLDocumentScannerImpl.this.scanComment();
                            xMLDocumentScannerImpl2 = XMLDocumentScannerImpl.this;
                            xMLDocumentScannerImpl2.setScannerState(5);
                            z2 = false;
                            if (!z) {
                            }
                            break;
                        case 3:
                            XMLDocumentScannerImpl.this.scanPI();
                            xMLDocumentScannerImpl2 = XMLDocumentScannerImpl.this;
                            xMLDocumentScannerImpl2.setScannerState(5);
                            z2 = false;
                            if (!z) {
                            }
                            break;
                        case 4:
                            if (XMLDocumentScannerImpl.this.fDisallowDoctype) {
                                XMLDocumentScannerImpl.this.reportFatalError("DoctypeNotAllowed", null);
                            }
                            if (XMLDocumentScannerImpl.this.fSeenDoctypeDecl) {
                                XMLDocumentScannerImpl.this.reportFatalError("AlreadySeenDoctype", null);
                            }
                            XMLDocumentScannerImpl.this.fSeenDoctypeDecl = true;
                            if (XMLDocumentScannerImpl.this.scanDoctypeDecl()) {
                                XMLDocumentScannerImpl.this.setScannerState(17);
                                XMLDocumentScannerImpl.this.setDispatcher(XMLDocumentScannerImpl.this.fDTDDispatcher);
                                return true;
                            }
                            if (XMLDocumentScannerImpl.this.fDoctypeSystemId == null) {
                                if (XMLDocumentScannerImpl.this.fExternalSubsetSource != null) {
                                    XMLDocumentScannerImpl.this.fIsEntityDeclaredVC = !XMLDocumentScannerImpl.this.fStandalone;
                                    if ((XMLDocumentScannerImpl.this.fValidation || XMLDocumentScannerImpl.this.fLoadExternalDTD) && (XMLDocumentScannerImpl.this.fValidationManager == null || !XMLDocumentScannerImpl.this.fValidationManager.isCachedDTD())) {
                                        XMLDocumentScannerImpl.this.fDTDScanner.setInputSource(XMLDocumentScannerImpl.this.fExternalSubsetSource);
                                        XMLDocumentScannerImpl.this.fExternalSubsetSource = null;
                                        XMLDocumentScannerImpl.this.setScannerState(19);
                                        XMLDocumentScannerImpl.this.setDispatcher(XMLDocumentScannerImpl.this.fDTDDispatcher);
                                        break;
                                    }
                                }
                            } else {
                                XMLDocumentScannerImpl.this.fIsEntityDeclaredVC = !XMLDocumentScannerImpl.this.fStandalone;
                                if ((XMLDocumentScannerImpl.this.fValidation || XMLDocumentScannerImpl.this.fLoadExternalDTD) && (XMLDocumentScannerImpl.this.fValidationManager == null || !XMLDocumentScannerImpl.this.fValidationManager.isCachedDTD())) {
                                    XMLDocumentScannerImpl.this.setScannerState(18);
                                    XMLDocumentScannerImpl.this.setDispatcher(XMLDocumentScannerImpl.this.fDTDDispatcher);
                                    break;
                                }
                            }
                            XMLDocumentScannerImpl.this.fDTDScanner.setInputSource(null);
                            xMLDocumentScannerImpl2 = XMLDocumentScannerImpl.this;
                            xMLDocumentScannerImpl2.setScannerState(5);
                            z2 = false;
                            if (!z) {
                            }
                            break;
                        case 5:
                            XMLDocumentScannerImpl.this.fEntityScanner.skipSpaces();
                            if (XMLDocumentScannerImpl.this.fEntityScanner.skipChar(60)) {
                                XMLDocumentScannerImpl.this.setScannerState(1);
                            } else if (XMLDocumentScannerImpl.this.fEntityScanner.skipChar(38)) {
                                XMLDocumentScannerImpl.this.setScannerState(8);
                            } else {
                                XMLDocumentScannerImpl.this.setScannerState(7);
                            }
                            z2 = true;
                            if (!z) {
                            }
                            break;
                        case 6:
                        default:
                            z2 = false;
                            if (!z) {
                            }
                            break;
                        case 7:
                            XMLDocumentScannerImpl.this.reportFatalError("ContentIllegalInProlog", null);
                            XMLDocumentScannerImpl.this.fEntityScanner.scanChar();
                            xMLDocumentScannerImpl = XMLDocumentScannerImpl.this;
                            str = "ReferenceIllegalInProlog";
                            xMLDocumentScannerImpl.reportFatalError(str, null);
                            z2 = false;
                            if (!z) {
                            }
                            break;
                        case 8:
                            xMLDocumentScannerImpl = XMLDocumentScannerImpl.this;
                            str = "ReferenceIllegalInProlog";
                            xMLDocumentScannerImpl.reportFatalError(str, null);
                            z2 = false;
                            if (!z) {
                            }
                            break;
                    }
                } catch (MalformedByteSequenceException e2) {
                    XMLDocumentScannerImpl.this.fErrorReporter.reportError(e2.getDomain(), e2.getKey(), e2.getArguments(), (short) 2, (Exception) e2);
                    return false;
                } catch (CharConversionException e3) {
                    XMLDocumentScannerImpl.this.fErrorReporter.reportError("http://www.w3.org/TR/1998/REC-xml-19980210", "CharConversionFailure", (Object[]) null, (short) 2, (Exception) e3);
                    return false;
                } catch (EOFException unused) {
                    XMLDocumentScannerImpl.this.reportFatalError("PrematureEOF", null);
                    return false;
                }
            }
            XMLDocumentScannerImpl.this.fDTDScanner.setInputSource(XMLDocumentScannerImpl.this.fExternalSubsetSource);
            XMLDocumentScannerImpl.this.fExternalSubsetSource = null;
            XMLDocumentScannerImpl.this.setScannerState(19);
            XMLDocumentScannerImpl.this.setDispatcher(XMLDocumentScannerImpl.this.fDTDDispatcher);
            return true;
        }
    }

    public final class TrailingMiscDispatcher implements XMLDocumentFragmentScannerImpl.Dispatcher {
        public TrailingMiscDispatcher() {
        }

        /* JADX WARNING: Removed duplicated region for block: B:50:0x0118 A[ADDED_TO_REGION] */
        /* JADX WARNING: Removed duplicated region for block: B:69:0x0000 A[ADDED_TO_REGION, SYNTHETIC] */
        @Override // org.apache.xerces.impl.XMLDocumentFragmentScannerImpl.Dispatcher
        public boolean dispatch(boolean z) {
            XMLDocumentScannerImpl xMLDocumentScannerImpl;
            XMLDocumentScannerImpl xMLDocumentScannerImpl2;
            while (true) {
                boolean z2 = false;
                try {
                    int i2 = XMLDocumentScannerImpl.this.fScannerState;
                    if (i2 != 1) {
                        if (i2 == 2) {
                            if (!XMLDocumentScannerImpl.this.fEntityScanner.skipString("--")) {
                                XMLDocumentScannerImpl.this.reportFatalError("InvalidCommentStart", null);
                            }
                            XMLDocumentScannerImpl.this.scanComment();
                            xMLDocumentScannerImpl2 = XMLDocumentScannerImpl.this;
                        } else if (i2 == 3) {
                            XMLDocumentScannerImpl.this.scanPI();
                            xMLDocumentScannerImpl2 = XMLDocumentScannerImpl.this;
                        } else if (i2 != 7) {
                            if (i2 == 8) {
                                XMLDocumentScannerImpl.this.reportFatalError("ReferenceIllegalInTrailingMisc", null);
                                xMLDocumentScannerImpl2 = XMLDocumentScannerImpl.this;
                            } else if (i2 == 12) {
                                XMLDocumentScannerImpl.this.fEntityScanner.skipSpaces();
                                if (XMLDocumentScannerImpl.this.fEntityScanner.skipChar(60)) {
                                    XMLDocumentScannerImpl.this.setScannerState(1);
                                } else {
                                    XMLDocumentScannerImpl.this.setScannerState(7);
                                }
                            } else if (i2 == 14) {
                                return false;
                            } else {
                                if (!z && !z2) {
                                    return true;
                                }
                            }
                        } else if (XMLDocumentScannerImpl.this.fEntityScanner.peekChar() == -1) {
                            XMLDocumentScannerImpl.this.setScannerState(14);
                            return false;
                        } else {
                            XMLDocumentScannerImpl.this.reportFatalError("ContentIllegalInTrailingMisc", null);
                            XMLDocumentScannerImpl.this.fEntityScanner.scanChar();
                            xMLDocumentScannerImpl2 = XMLDocumentScannerImpl.this;
                        }
                        xMLDocumentScannerImpl2.setScannerState(12);
                        if (!z) {
                        }
                    } else {
                        XMLDocumentScannerImpl.this.fMarkupDepth++;
                        if (XMLDocumentScannerImpl.this.fEntityScanner.skipChar(63)) {
                            XMLDocumentScannerImpl.this.setScannerState(3);
                        } else if (XMLDocumentScannerImpl.this.fEntityScanner.skipChar(33)) {
                            XMLDocumentScannerImpl.this.setScannerState(2);
                        } else if (XMLDocumentScannerImpl.this.fEntityScanner.skipChar(47)) {
                            XMLDocumentScannerImpl.this.reportFatalError("MarkupNotRecognizedInMisc", null);
                        } else {
                            if (XMLDocumentScannerImpl.this.isValidNameStartChar(XMLDocumentScannerImpl.this.fEntityScanner.peekChar())) {
                                XMLDocumentScannerImpl.this.reportFatalError("MarkupNotRecognizedInMisc", null);
                                XMLDocumentScannerImpl.this.scanStartElement();
                                xMLDocumentScannerImpl = XMLDocumentScannerImpl.this;
                            } else if (XMLDocumentScannerImpl.this.isValidNameStartHighSurrogate(XMLDocumentScannerImpl.this.fEntityScanner.peekChar())) {
                                XMLDocumentScannerImpl.this.reportFatalError("MarkupNotRecognizedInMisc", null);
                                XMLDocumentScannerImpl.this.scanStartElement();
                                xMLDocumentScannerImpl = XMLDocumentScannerImpl.this;
                            } else {
                                XMLDocumentScannerImpl.this.reportFatalError("MarkupNotRecognizedInMisc", null);
                                if (!z) {
                                }
                            }
                            xMLDocumentScannerImpl.setScannerState(7);
                            if (!z) {
                            }
                        }
                    }
                    z2 = true;
                    if (!z) {
                    }
                } catch (MalformedByteSequenceException e2) {
                    XMLDocumentScannerImpl.this.fErrorReporter.reportError(e2.getDomain(), e2.getKey(), e2.getArguments(), (short) 2, (Exception) e2);
                    return false;
                } catch (CharConversionException e3) {
                    XMLDocumentScannerImpl.this.fErrorReporter.reportError("http://www.w3.org/TR/1998/REC-xml-19980210", "CharConversionFailure", (Object[]) null, (short) 2, (Exception) e3);
                    return false;
                } catch (EOFException unused) {
                    XMLDocumentScannerImpl xMLDocumentScannerImpl3 = XMLDocumentScannerImpl.this;
                    if (xMLDocumentScannerImpl3.fMarkupDepth != 0) {
                        xMLDocumentScannerImpl3.reportFatalError("PrematureEOF", null);
                        return false;
                    }
                    xMLDocumentScannerImpl3.setScannerState(14);
                    return false;
                }
            }
        }
    }

    public final class XMLDeclDispatcher implements XMLDocumentFragmentScannerImpl.Dispatcher {
        public XMLDeclDispatcher() {
        }

        @Override // org.apache.xerces.impl.XMLDocumentFragmentScannerImpl.Dispatcher
        public boolean dispatch(boolean z) {
            XMLDocumentScannerImpl.this.setScannerState(5);
            XMLDocumentScannerImpl xMLDocumentScannerImpl = XMLDocumentScannerImpl.this;
            xMLDocumentScannerImpl.setDispatcher(xMLDocumentScannerImpl.fPrologDispatcher);
            try {
                if (XMLDocumentScannerImpl.this.fEntityScanner.skipString("<?xml")) {
                    XMLDocumentScannerImpl.this.fMarkupDepth++;
                    if (XMLChar.isName(XMLDocumentScannerImpl.this.fEntityScanner.peekChar())) {
                        XMLDocumentScannerImpl.this.fStringBuffer.clear();
                        XMLDocumentScannerImpl.this.fStringBuffer.append("xml");
                        if (XMLDocumentScannerImpl.this.fNamespaces) {
                            while (XMLChar.isNCName(XMLDocumentScannerImpl.this.fEntityScanner.peekChar())) {
                                XMLDocumentScannerImpl.this.fStringBuffer.append((char) XMLDocumentScannerImpl.this.fEntityScanner.scanChar());
                            }
                        } else {
                            while (XMLChar.isName(XMLDocumentScannerImpl.this.fEntityScanner.peekChar())) {
                                XMLDocumentScannerImpl.this.fStringBuffer.append((char) XMLDocumentScannerImpl.this.fEntityScanner.scanChar());
                            }
                        }
                        XMLDocumentScannerImpl.this.scanPIData(XMLDocumentScannerImpl.this.fSymbolTable.addSymbol(XMLDocumentScannerImpl.this.fStringBuffer.ch, XMLDocumentScannerImpl.this.fStringBuffer.offset, XMLDocumentScannerImpl.this.fStringBuffer.length), XMLDocumentScannerImpl.this.fString);
                    } else {
                        XMLDocumentScannerImpl.this.scanXMLDeclOrTextDecl(false);
                    }
                }
                XMLDocumentScannerImpl.this.fEntityManager.fCurrentEntity.mayReadChunks = true;
                return true;
            } catch (MalformedByteSequenceException e2) {
                XMLDocumentScannerImpl.this.fErrorReporter.reportError(e2.getDomain(), e2.getKey(), e2.getArguments(), (short) 2, (Exception) e2);
                return false;
            } catch (CharConversionException e3) {
                XMLDocumentScannerImpl.this.fErrorReporter.reportError("http://www.w3.org/TR/1998/REC-xml-19980210", "CharConversionFailure", (Object[]) null, (short) 2, (Exception) e3);
                return false;
            } catch (EOFException unused) {
                XMLDocumentScannerImpl.this.reportFatalError("PrematureEOF", null);
                return false;
            }
        }
    }

    @Override // org.apache.xerces.impl.XMLDocumentFragmentScannerImpl
    public XMLDocumentFragmentScannerImpl.Dispatcher createContentDispatcher() {
        return new ContentDispatcher(this);
    }

    @Override // org.apache.xerces.impl.XMLEntityHandler, org.apache.xerces.impl.XMLScanner, org.apache.xerces.impl.XMLDocumentFragmentScannerImpl
    public void endEntity(String str, Augmentations augmentations) {
        super.endEntity(str, augmentations);
        if (this.fDocumentHandler != null && str.equals("[xml]")) {
            this.fDocumentHandler.endDocument(null);
        }
    }

    @Override // org.apache.xerces.impl.XMLScanner, org.apache.xerces.xni.parser.XMLComponent, org.apache.xerces.impl.XMLDocumentFragmentScannerImpl
    public Boolean getFeatureDefault(String str) {
        int i2 = 0;
        while (true) {
            String[] strArr = RECOGNIZED_FEATURES;
            if (i2 >= strArr.length) {
                return super.getFeatureDefault(str);
            }
            if (strArr[i2].equals(str)) {
                return FEATURE_DEFAULTS[i2];
            }
            i2++;
        }
    }

    @Override // org.apache.xerces.impl.XMLScanner, org.apache.xerces.xni.parser.XMLComponent, org.apache.xerces.impl.XMLDocumentFragmentScannerImpl
    public Object getPropertyDefault(String str) {
        int i2 = 0;
        while (true) {
            String[] strArr = RECOGNIZED_PROPERTIES;
            if (i2 >= strArr.length) {
                return super.getPropertyDefault(str);
            }
            if (strArr[i2].equals(str)) {
                return PROPERTY_DEFAULTS[i2];
            }
            i2++;
        }
    }

    @Override // org.apache.xerces.impl.XMLScanner, org.apache.xerces.xni.parser.XMLComponent, org.apache.xerces.impl.XMLDocumentFragmentScannerImpl
    public String[] getRecognizedFeatures() {
        String[] recognizedFeatures = super.getRecognizedFeatures();
        int length = recognizedFeatures != null ? recognizedFeatures.length : 0;
        String[] strArr = new String[(RECOGNIZED_FEATURES.length + length)];
        if (recognizedFeatures != null) {
            System.arraycopy(recognizedFeatures, 0, strArr, 0, recognizedFeatures.length);
        }
        String[] strArr2 = RECOGNIZED_FEATURES;
        System.arraycopy(strArr2, 0, strArr, length, strArr2.length);
        return strArr;
    }

    @Override // org.apache.xerces.impl.XMLScanner, org.apache.xerces.xni.parser.XMLComponent, org.apache.xerces.impl.XMLDocumentFragmentScannerImpl
    public String[] getRecognizedProperties() {
        String[] recognizedProperties = super.getRecognizedProperties();
        int length = recognizedProperties != null ? recognizedProperties.length : 0;
        String[] strArr = new String[(RECOGNIZED_PROPERTIES.length + length)];
        if (recognizedProperties != null) {
            System.arraycopy(recognizedProperties, 0, strArr, 0, recognizedProperties.length);
        }
        String[] strArr2 = RECOGNIZED_PROPERTIES;
        System.arraycopy(strArr2, 0, strArr, length, strArr2.length);
        return strArr;
    }

    @Override // org.apache.xerces.impl.XMLDocumentFragmentScannerImpl
    public String getScannerStateName(int i2) {
        if (i2 == 0) {
            return "SCANNER_STATE_XML_DECL";
        }
        if (i2 == 5) {
            return "SCANNER_STATE_PROLOG";
        }
        if (i2 == 12) {
            return "SCANNER_STATE_TRAILING_MISC";
        }
        switch (i2) {
            case 17:
                return "SCANNER_STATE_DTD_INTERNAL_DECLS";
            case 18:
                return "SCANNER_STATE_DTD_EXTERNAL";
            case 19:
                return "SCANNER_STATE_DTD_EXTERNAL_DECLS";
            default:
                return super.getScannerStateName(i2);
        }
    }

    @Override // org.apache.xerces.impl.XMLScanner, org.apache.xerces.xni.parser.XMLComponent, org.apache.xerces.impl.XMLDocumentFragmentScannerImpl
    public void reset(XMLComponentManager xMLComponentManager) {
        super.reset(xMLComponentManager);
        this.fDoctypeName = null;
        this.fDoctypePublicId = null;
        this.fDoctypeSystemId = null;
        this.fSeenDoctypeDecl = false;
        this.fScanningDTD = false;
        this.fExternalSubsetSource = null;
        if (this.fParserSettings) {
            try {
                this.fLoadExternalDTD = xMLComponentManager.getFeature("http://apache.org/xml/features/nonvalidating/load-external-dtd");
            } catch (XMLConfigurationException unused) {
                this.fLoadExternalDTD = true;
            }
            try {
                this.fDisallowDoctype = xMLComponentManager.getFeature("http://apache.org/xml/features/disallow-doctype-decl");
            } catch (XMLConfigurationException unused2) {
                this.fDisallowDoctype = false;
            }
            this.fDTDScanner = (XMLDTDScanner) xMLComponentManager.getProperty("http://apache.org/xml/properties/internal/dtd-scanner");
            try {
                this.fValidationManager = (ValidationManager) xMLComponentManager.getProperty("http://apache.org/xml/properties/internal/validation-manager");
            } catch (XMLConfigurationException unused3) {
                this.fValidationManager = null;
            }
            try {
                this.fNamespaceContext = (NamespaceContext) xMLComponentManager.getProperty("http://apache.org/xml/properties/internal/namespace-context");
            } catch (XMLConfigurationException unused4) {
            }
            if (this.fNamespaceContext == null) {
                this.fNamespaceContext = new NamespaceSupport();
            }
        }
        this.fNamespaceContext.reset();
        setScannerState(0);
        setDispatcher(this.fXMLDeclDispatcher);
    }

    public boolean scanDoctypeDecl() {
        if (!this.fEntityScanner.skipSpaces()) {
            reportFatalError("MSG_SPACE_REQUIRED_BEFORE_ROOT_ELEMENT_TYPE_IN_DOCTYPEDECL", null);
        }
        String scanName = this.fEntityScanner.scanName();
        this.fDoctypeName = scanName;
        if (scanName == null) {
            reportFatalError("MSG_ROOT_ELEMENT_TYPE_REQUIRED", null);
        }
        if (this.fEntityScanner.skipSpaces()) {
            scanExternalID(this.fStrings, false);
            String[] strArr = this.fStrings;
            this.fDoctypeSystemId = strArr[0];
            this.fDoctypePublicId = strArr[1];
            this.fEntityScanner.skipSpaces();
        }
        boolean z = this.fDoctypeSystemId != null;
        this.fHasExternalDTD = z;
        if (!z && this.fExternalSubsetResolver != null) {
            this.fDTDDescription.setValues(null, null, this.fEntityManager.getCurrentResourceIdentifier().getExpandedSystemId(), null);
            this.fDTDDescription.setRootName(this.fDoctypeName);
            XMLInputSource externalSubset = this.fExternalSubsetResolver.getExternalSubset(this.fDTDDescription);
            this.fExternalSubsetSource = externalSubset;
            this.fHasExternalDTD = externalSubset != null;
        }
        XMLDocumentHandler xMLDocumentHandler = this.fDocumentHandler;
        if (xMLDocumentHandler != null) {
            XMLInputSource xMLInputSource = this.fExternalSubsetSource;
            if (xMLInputSource == null) {
                xMLDocumentHandler.doctypeDecl(this.fDoctypeName, this.fDoctypePublicId, this.fDoctypeSystemId, null);
            } else {
                xMLDocumentHandler.doctypeDecl(this.fDoctypeName, xMLInputSource.getPublicId(), this.fExternalSubsetSource.getSystemId(), null);
            }
        }
        if (this.fEntityScanner.skipChar(91)) {
            return true;
        }
        this.fEntityScanner.skipSpaces();
        if (!this.fEntityScanner.skipChar(62)) {
            reportFatalError("DoctypedeclUnterminated", new Object[]{this.fDoctypeName});
        }
        this.fMarkupDepth--;
        return false;
    }

    @Override // org.apache.xerces.impl.XMLScanner, org.apache.xerces.xni.parser.XMLComponent, org.apache.xerces.impl.XMLDocumentFragmentScannerImpl
    public void setFeature(String str, boolean z) {
        super.setFeature(str, z);
        if (str.startsWith(Constants.XERCES_FEATURE_PREFIX)) {
            int length = str.length() - 31;
            if (length == 31 && str.endsWith(Constants.LOAD_EXTERNAL_DTD_FEATURE)) {
                this.fLoadExternalDTD = z;
            } else if (length == 21 && str.endsWith(Constants.DISALLOW_DOCTYPE_DECL_FEATURE)) {
                this.fDisallowDoctype = z;
            }
        }
    }

    @Override // org.apache.xerces.xni.parser.XMLDocumentScanner, org.apache.xerces.impl.XMLDocumentFragmentScannerImpl
    public void setInputSource(XMLInputSource xMLInputSource) {
        this.fEntityManager.setEntityHandler(this);
        this.fEntityManager.startDocumentEntity(xMLInputSource);
    }

    @Override // org.apache.xerces.impl.XMLScanner, org.apache.xerces.xni.parser.XMLComponent, org.apache.xerces.impl.XMLDocumentFragmentScannerImpl
    public void setProperty(String str, Object obj) {
        super.setProperty(str, obj);
        if (str.startsWith(Constants.XERCES_PROPERTY_PREFIX)) {
            int length = str.length() - 33;
            if (length == 20 && str.endsWith(Constants.DTD_SCANNER_PROPERTY)) {
                this.fDTDScanner = (XMLDTDScanner) obj;
            }
            if (length == 26 && str.endsWith(Constants.NAMESPACE_CONTEXT_PROPERTY) && obj != null) {
                this.fNamespaceContext = (NamespaceContext) obj;
            }
        }
    }

    @Override // org.apache.xerces.impl.XMLEntityHandler, org.apache.xerces.impl.XMLScanner, org.apache.xerces.impl.XMLDocumentFragmentScannerImpl
    public void startEntity(String str, XMLResourceIdentifier xMLResourceIdentifier, String str2, Augmentations augmentations) {
        super.startEntity(str, xMLResourceIdentifier, str2, augmentations);
        if (!str.equals("[xml]") && this.fEntityScanner.isExternal()) {
            setScannerState(16);
        }
        if (this.fDocumentHandler != null && str.equals("[xml]")) {
            this.fDocumentHandler.startDocument(this.fEntityScanner, str2, this.fNamespaceContext, null);
        }
    }
}
