package org.apache.xerces.impl;

import java.io.EOFException;
import java.util.Locale;
import org.apache.xerces.impl.XMLEntityManager;
import org.apache.xerces.impl.io.UCSReader;
import org.apache.xerces.util.SymbolTable;
import org.apache.xerces.util.XMLChar;
import org.apache.xerces.util.XMLStringBuffer;
import org.apache.xerces.xni.QName;
import org.apache.xerces.xni.XMLLocator;
import org.apache.xerces.xni.XMLResourceIdentifier;
import org.apache.xerces.xni.XMLString;

public class XMLEntityScanner implements XMLLocator {
    public static final boolean DEBUG_BUFFER = false;
    public static final boolean DEBUG_ENCODINGS = false;
    public static final EOFException END_OF_DOCUMENT_ENTITY = new EOFException() {
        /* class org.apache.xerces.impl.XMLEntityScanner.AnonymousClass1 */
        public static final long serialVersionUID = 980337771224675268L;

        public Throwable fillInStackTrace() {
            return this;
        }
    };
    public int fBufferSize = 2048;
    public XMLEntityManager.ScannedEntity fCurrentEntity = null;
    public XMLEntityManager fEntityManager = null;
    public XMLErrorReporter fErrorReporter;
    public SymbolTable fSymbolTable = null;

    @Override // org.apache.xerces.xni.XMLLocator
    public final String getBaseSystemId() {
        XMLResourceIdentifier xMLResourceIdentifier;
        XMLEntityManager.ScannedEntity scannedEntity = this.fCurrentEntity;
        if (scannedEntity == null || (xMLResourceIdentifier = scannedEntity.entityLocation) == null) {
            return null;
        }
        return xMLResourceIdentifier.getExpandedSystemId();
    }

    @Override // org.apache.xerces.xni.XMLLocator
    public final int getCharacterOffset() {
        XMLEntityManager.ScannedEntity scannedEntity = this.fCurrentEntity;
        if (scannedEntity == null) {
            return -1;
        }
        if (!scannedEntity.isExternal()) {
            return this.fCurrentEntity.getCharacterOffset();
        }
        XMLEntityManager.ScannedEntity scannedEntity2 = this.fCurrentEntity;
        return (scannedEntity2.position - scannedEntity2.startPosition) + scannedEntity2.baseCharOffset;
    }

    @Override // org.apache.xerces.xni.XMLLocator
    public final int getColumnNumber() {
        XMLEntityManager.ScannedEntity scannedEntity = this.fCurrentEntity;
        if (scannedEntity != null) {
            return scannedEntity.isExternal() ? this.fCurrentEntity.columnNumber : this.fCurrentEntity.getColumnNumber();
        }
        return -1;
    }

    @Override // org.apache.xerces.xni.XMLLocator
    public final String getEncoding() {
        XMLEntityManager.ScannedEntity scannedEntity = this.fCurrentEntity;
        if (scannedEntity != null) {
            return scannedEntity.isExternal() ? this.fCurrentEntity.encoding : this.fCurrentEntity.getEncoding();
        }
        return null;
    }

    @Override // org.apache.xerces.xni.XMLLocator
    public final String getExpandedSystemId() {
        XMLEntityManager.ScannedEntity scannedEntity = this.fCurrentEntity;
        if (scannedEntity == null) {
            return null;
        }
        XMLResourceIdentifier xMLResourceIdentifier = scannedEntity.entityLocation;
        return (xMLResourceIdentifier == null || xMLResourceIdentifier.getExpandedSystemId() == null) ? this.fCurrentEntity.getExpandedSystemId() : this.fCurrentEntity.entityLocation.getExpandedSystemId();
    }

    @Override // org.apache.xerces.xni.XMLLocator
    public final int getLineNumber() {
        XMLEntityManager.ScannedEntity scannedEntity = this.fCurrentEntity;
        if (scannedEntity != null) {
            return scannedEntity.isExternal() ? this.fCurrentEntity.lineNumber : this.fCurrentEntity.getLineNumber();
        }
        return -1;
    }

    @Override // org.apache.xerces.xni.XMLLocator
    public final String getLiteralSystemId() {
        XMLEntityManager.ScannedEntity scannedEntity = this.fCurrentEntity;
        if (scannedEntity == null) {
            return null;
        }
        XMLResourceIdentifier xMLResourceIdentifier = scannedEntity.entityLocation;
        return (xMLResourceIdentifier == null || xMLResourceIdentifier.getLiteralSystemId() == null) ? this.fCurrentEntity.getLiteralSystemId() : this.fCurrentEntity.entityLocation.getLiteralSystemId();
    }

    @Override // org.apache.xerces.xni.XMLLocator
    public final String getPublicId() {
        XMLResourceIdentifier xMLResourceIdentifier;
        XMLEntityManager.ScannedEntity scannedEntity = this.fCurrentEntity;
        if (scannedEntity == null || (xMLResourceIdentifier = scannedEntity.entityLocation) == null) {
            return null;
        }
        return xMLResourceIdentifier.getPublicId();
    }

    @Override // org.apache.xerces.xni.XMLLocator
    public final String getXMLVersion() {
        XMLEntityManager.ScannedEntity scannedEntity = this.fCurrentEntity;
        if (scannedEntity != null) {
            return scannedEntity.isExternal() ? this.fCurrentEntity.xmlVersion : this.fCurrentEntity.getXMLVersion();
        }
        return null;
    }

    public final boolean isExternal() {
        return this.fCurrentEntity.isExternal();
    }

    public final boolean load(int i2, boolean z) {
        XMLEntityManager.ScannedEntity scannedEntity = this.fCurrentEntity;
        scannedEntity.baseCharOffset = (scannedEntity.position - scannedEntity.startPosition) + scannedEntity.baseCharOffset;
        int length = scannedEntity.ch.length - i2;
        if (!scannedEntity.mayReadChunks && length > 64) {
            length = 64;
        }
        XMLEntityManager.ScannedEntity scannedEntity2 = this.fCurrentEntity;
        int read = scannedEntity2.reader.read(scannedEntity2.ch, i2, length);
        if (read != -1) {
            if (read != 0) {
                XMLEntityManager.ScannedEntity scannedEntity3 = this.fCurrentEntity;
                scannedEntity3.count = read + i2;
                scannedEntity3.position = i2;
                scannedEntity3.startPosition = i2;
            }
            return false;
        }
        XMLEntityManager.ScannedEntity scannedEntity4 = this.fCurrentEntity;
        scannedEntity4.count = i2;
        scannedEntity4.position = i2;
        scannedEntity4.startPosition = i2;
        if (!z) {
            return true;
        }
        this.fEntityManager.endEntity();
        XMLEntityManager.ScannedEntity scannedEntity5 = this.fCurrentEntity;
        if (scannedEntity5 == null) {
            throw END_OF_DOCUMENT_ENTITY;
        } else if (scannedEntity5.position != scannedEntity5.count) {
            return true;
        } else {
            load(0, true);
            return true;
        }
    }

    public int peekChar() {
        XMLEntityManager.ScannedEntity scannedEntity = this.fCurrentEntity;
        if (scannedEntity.position == scannedEntity.count) {
            load(0, true);
        }
        XMLEntityManager.ScannedEntity scannedEntity2 = this.fCurrentEntity;
        char c = scannedEntity2.ch[scannedEntity2.position];
        if (!scannedEntity2.isExternal() || c != '\r') {
            return c;
        }
        return 10;
    }

    public final void reset(SymbolTable symbolTable, XMLEntityManager xMLEntityManager, XMLErrorReporter xMLErrorReporter) {
        this.fCurrentEntity = null;
        this.fSymbolTable = symbolTable;
        this.fEntityManager = xMLEntityManager;
        this.fErrorReporter = xMLErrorReporter;
    }

    /* JADX WARNING: Code restructure failed: missing block: B:7:0x0025, code lost:
        if (r0 != false) goto L_0x0029;
     */
    public int scanChar() {
        boolean z;
        XMLEntityManager.ScannedEntity scannedEntity = this.fCurrentEntity;
        if (scannedEntity.position == scannedEntity.count) {
            load(0, true);
        }
        XMLEntityManager.ScannedEntity scannedEntity2 = this.fCurrentEntity;
        char[] cArr = scannedEntity2.ch;
        int i2 = scannedEntity2.position;
        scannedEntity2.position = i2 + 1;
        char c = cArr[i2];
        if (c != '\n') {
            if (c == '\r') {
                z = scannedEntity2.isExternal();
            }
            this.fCurrentEntity.columnNumber++;
            return c;
        }
        z = false;
        XMLEntityManager.ScannedEntity scannedEntity3 = this.fCurrentEntity;
        scannedEntity3.lineNumber++;
        scannedEntity3.columnNumber = 1;
        if (scannedEntity3.position == scannedEntity3.count) {
            scannedEntity3.ch[0] = (char) c;
            load(1, false);
        }
        if (c == '\r' && z) {
            XMLEntityManager.ScannedEntity scannedEntity4 = this.fCurrentEntity;
            char[] cArr2 = scannedEntity4.ch;
            int i3 = scannedEntity4.position;
            int i4 = i3 + 1;
            scannedEntity4.position = i4;
            if (cArr2[i3] != '\n') {
                scannedEntity4.position = i4 - 1;
            }
            c = '\n';
        }
        this.fCurrentEntity.columnNumber++;
        return c;
    }

    public int scanContent(XMLString xMLString) {
        XMLEntityManager.ScannedEntity scannedEntity;
        int i2;
        XMLEntityManager.ScannedEntity scannedEntity2 = this.fCurrentEntity;
        int i3 = scannedEntity2.position;
        int i4 = scannedEntity2.count;
        int i5 = 0;
        if (i3 == i4) {
            load(0, true);
        } else if (i3 == i4 - 1) {
            char[] cArr = scannedEntity2.ch;
            cArr[0] = cArr[i4 - 1];
            load(1, false);
            XMLEntityManager.ScannedEntity scannedEntity3 = this.fCurrentEntity;
            scannedEntity3.position = 0;
            scannedEntity3.startPosition = 0;
        }
        XMLEntityManager.ScannedEntity scannedEntity4 = this.fCurrentEntity;
        int i6 = scannedEntity4.position;
        char c = scannedEntity4.ch[i6];
        boolean isExternal = scannedEntity4.isExternal();
        if (c == '\n' || (c == '\r' && isExternal)) {
            int i7 = 0;
            while (true) {
                XMLEntityManager.ScannedEntity scannedEntity5 = this.fCurrentEntity;
                char[] cArr2 = scannedEntity5.ch;
                int i8 = scannedEntity5.position;
                int i9 = i8 + 1;
                scannedEntity5.position = i9;
                char c2 = cArr2[i8];
                if (c2 != '\r' || !isExternal) {
                    if (c2 != '\n') {
                        this.fCurrentEntity.position--;
                        break;
                    }
                    i7++;
                    XMLEntityManager.ScannedEntity scannedEntity6 = this.fCurrentEntity;
                    scannedEntity6.lineNumber++;
                    scannedEntity6.columnNumber = 1;
                    int i10 = scannedEntity6.position;
                    if (i10 == scannedEntity6.count) {
                        scannedEntity6.baseCharOffset = (i10 - scannedEntity6.startPosition) + scannedEntity6.baseCharOffset;
                        scannedEntity6.position = i7;
                        scannedEntity6.startPosition = i7;
                        if (load(i7, false)) {
                            break;
                        }
                        i6 = 0;
                    }
                } else {
                    i7++;
                    scannedEntity5.lineNumber++;
                    scannedEntity5.columnNumber = 1;
                    if (i9 == scannedEntity5.count) {
                        scannedEntity5.baseCharOffset = (i9 - scannedEntity5.startPosition) + scannedEntity5.baseCharOffset;
                        scannedEntity5.position = i7;
                        scannedEntity5.startPosition = i7;
                        if (load(i7, false)) {
                            break;
                        }
                        i6 = 0;
                    }
                    XMLEntityManager.ScannedEntity scannedEntity7 = this.fCurrentEntity;
                    char[] cArr3 = scannedEntity7.ch;
                    int i11 = scannedEntity7.position;
                    if (cArr3[i11] == '\n') {
                        scannedEntity7.position = i11 + 1;
                        i6++;
                    } else {
                        i7++;
                    }
                }
                XMLEntityManager.ScannedEntity scannedEntity8 = this.fCurrentEntity;
                if (scannedEntity8.position >= scannedEntity8.count - 1) {
                    break;
                }
            }
            i5 = i6;
            int i12 = i5;
            while (true) {
                scannedEntity = this.fCurrentEntity;
                i2 = scannedEntity.position;
                if (i12 >= i2) {
                    break;
                }
                scannedEntity.ch[i12] = '\n';
                i12++;
            }
            int i13 = i2 - i5;
            if (i2 == scannedEntity.count - 1) {
                xMLString.setValues(scannedEntity.ch, i5, i13);
                return -1;
            }
            i6 = i5;
            i5 = i7;
        }
        while (true) {
            XMLEntityManager.ScannedEntity scannedEntity9 = this.fCurrentEntity;
            int i14 = scannedEntity9.position;
            if (i14 < scannedEntity9.count) {
                char[] cArr4 = scannedEntity9.ch;
                scannedEntity9.position = i14 + 1;
                if (!XMLChar.isContent(cArr4[i14])) {
                    this.fCurrentEntity.position--;
                    break;
                }
            } else {
                break;
            }
        }
        XMLEntityManager.ScannedEntity scannedEntity10 = this.fCurrentEntity;
        int i15 = scannedEntity10.position - i6;
        scannedEntity10.columnNumber = (i15 - i5) + scannedEntity10.columnNumber;
        xMLString.setValues(scannedEntity10.ch, i6, i15);
        XMLEntityManager.ScannedEntity scannedEntity11 = this.fCurrentEntity;
        int i16 = scannedEntity11.position;
        if (i16 == scannedEntity11.count) {
            return -1;
        }
        char c3 = scannedEntity11.ch[i16];
        if (c3 != '\r' || !isExternal) {
            return c3;
        }
        return 10;
    }

    /* JADX WARNING: Code restructure failed: missing block: B:35:0x00f1, code lost:
        r8 = 0;
     */
    /* JADX WARNING: Removed duplicated region for block: B:86:0x0105 A[EDGE_INSN: B:86:0x0105->B:40:0x0105 ?: BREAK  , SYNTHETIC] */
    public boolean scanData(String str, XMLStringBuffer xMLStringBuffer) {
        int i2;
        boolean z;
        XMLEntityManager.ScannedEntity scannedEntity;
        int i3;
        XMLEntityManager.ScannedEntity scannedEntity2;
        int length = str.length();
        char charAt = str.charAt(0);
        boolean isExternal = this.fCurrentEntity.isExternal();
        XMLEntityManager.ScannedEntity scannedEntity3 = this.fCurrentEntity;
        if (scannedEntity3.position == scannedEntity3.count) {
            load(0, true);
        }
        boolean z2 = false;
        while (true) {
            XMLEntityManager.ScannedEntity scannedEntity4 = this.fCurrentEntity;
            int i4 = scannedEntity4.position;
            int i5 = scannedEntity4.count;
            if (i4 <= i5 - length || z2) {
                XMLEntityManager.ScannedEntity scannedEntity5 = this.fCurrentEntity;
                int i6 = scannedEntity5.position;
                int i7 = scannedEntity5.count;
            } else {
                char[] cArr = scannedEntity4.ch;
                System.arraycopy(cArr, i4, cArr, 0, i5 - i4);
                XMLEntityManager.ScannedEntity scannedEntity6 = this.fCurrentEntity;
                z2 = load(scannedEntity6.count - scannedEntity6.position, false);
                XMLEntityManager.ScannedEntity scannedEntity7 = this.fCurrentEntity;
                scannedEntity7.position = 0;
                scannedEntity7.startPosition = 0;
            }
        }
        XMLEntityManager.ScannedEntity scannedEntity52 = this.fCurrentEntity;
        int i62 = scannedEntity52.position;
        int i72 = scannedEntity52.count;
        if (i62 > i72 - length) {
            xMLStringBuffer.append(scannedEntity52.ch, i62, i72 - i62);
            XMLEntityManager.ScannedEntity scannedEntity8 = this.fCurrentEntity;
            int i8 = scannedEntity8.columnNumber;
            int i9 = scannedEntity8.count;
            scannedEntity8.columnNumber = i8 + i9;
            scannedEntity8.baseCharOffset = (scannedEntity8.position - scannedEntity8.startPosition) + scannedEntity8.baseCharOffset;
            scannedEntity8.position = i9;
            scannedEntity8.startPosition = i9;
            load(0, true);
            return false;
        }
        char c = scannedEntity52.ch[i62];
        if (c == '\n' || (c == '\r' && isExternal)) {
            i2 = 0;
            while (true) {
                XMLEntityManager.ScannedEntity scannedEntity9 = this.fCurrentEntity;
                char[] cArr2 = scannedEntity9.ch;
                int i10 = scannedEntity9.position;
                int i11 = i10 + 1;
                scannedEntity9.position = i11;
                char c2 = cArr2[i10];
                if (c2 != '\r' || !isExternal) {
                    if (c2 != '\n') {
                        this.fCurrentEntity.position--;
                        break;
                    }
                    i2++;
                    XMLEntityManager.ScannedEntity scannedEntity10 = this.fCurrentEntity;
                    scannedEntity10.lineNumber++;
                    scannedEntity10.columnNumber = 1;
                    int i12 = scannedEntity10.position;
                    if (i12 == scannedEntity10.count) {
                        scannedEntity10.baseCharOffset = (i12 - scannedEntity10.startPosition) + scannedEntity10.baseCharOffset;
                        scannedEntity10.position = i2;
                        scannedEntity10.startPosition = i2;
                        scannedEntity10.count = i2;
                        if (load(i2, false)) {
                            break;
                        }
                        i62 = 0;
                    }
                    scannedEntity2 = this.fCurrentEntity;
                    if (scannedEntity2.position >= scannedEntity2.count - 1) {
                        break;
                    }
                } else {
                    i2++;
                    scannedEntity9.lineNumber++;
                    scannedEntity9.columnNumber = 1;
                    if (i11 == scannedEntity9.count) {
                        scannedEntity9.baseCharOffset = (i11 - scannedEntity9.startPosition) + scannedEntity9.baseCharOffset;
                        scannedEntity9.position = i2;
                        scannedEntity9.startPosition = i2;
                        if (load(i2, false)) {
                            break;
                        }
                        i62 = 0;
                    }
                    XMLEntityManager.ScannedEntity scannedEntity11 = this.fCurrentEntity;
                    char[] cArr3 = scannedEntity11.ch;
                    int i13 = scannedEntity11.position;
                    if (cArr3[i13] == '\n') {
                        scannedEntity11.position = i13 + 1;
                        i62++;
                    } else {
                        i2++;
                    }
                    scannedEntity2 = this.fCurrentEntity;
                    if (scannedEntity2.position >= scannedEntity2.count - 1) {
                    }
                }
            }
            int i14 = i62;
            while (true) {
                scannedEntity = this.fCurrentEntity;
                i3 = scannedEntity.position;
                if (i14 >= i3) {
                    break;
                }
                scannedEntity.ch[i14] = '\n';
                i14++;
            }
            int i15 = i3 - i62;
            if (i3 == scannedEntity.count - 1) {
                xMLStringBuffer.append(scannedEntity.ch, i62, i15);
                return true;
            }
        } else {
            i2 = 0;
        }
        loop3:
        while (true) {
            XMLEntityManager.ScannedEntity scannedEntity12 = this.fCurrentEntity;
            int i16 = scannedEntity12.position;
            if (i16 >= scannedEntity12.count) {
                break;
            }
            char[] cArr4 = scannedEntity12.ch;
            int i17 = i16 + 1;
            scannedEntity12.position = i17;
            char c3 = cArr4[i16];
            if (c3 == charAt) {
                int i18 = i17 - 1;
                int i19 = 1;
                while (true) {
                    if (i19 >= length) {
                        break;
                    }
                    XMLEntityManager.ScannedEntity scannedEntity13 = this.fCurrentEntity;
                    int i20 = scannedEntity13.position;
                    if (i20 == scannedEntity13.count) {
                        scannedEntity13.position = i20 - i19;
                        break loop3;
                    }
                    char[] cArr5 = scannedEntity13.ch;
                    scannedEntity13.position = i20 + 1;
                    if (str.charAt(i19) != cArr5[i20]) {
                        this.fCurrentEntity.position--;
                        break;
                    }
                    i19++;
                }
                if (this.fCurrentEntity.position == i18 + length) {
                    z = true;
                    break;
                }
            } else if (c3 == '\n' || (isExternal && c3 == '\r')) {
                this.fCurrentEntity.position--;
            } else if (XMLChar.isInvalid(c3)) {
                XMLEntityManager.ScannedEntity scannedEntity14 = this.fCurrentEntity;
                int i21 = scannedEntity14.position - 1;
                scannedEntity14.position = i21;
                int i22 = i21 - i62;
                scannedEntity14.columnNumber = (i22 - i2) + scannedEntity14.columnNumber;
                xMLStringBuffer.append(scannedEntity14.ch, i62, i22);
                return true;
            }
        }
        z = false;
        XMLEntityManager.ScannedEntity scannedEntity15 = this.fCurrentEntity;
        int i23 = scannedEntity15.position - i62;
        scannedEntity15.columnNumber = (i23 - i2) + scannedEntity15.columnNumber;
        if (z) {
            i23 -= length;
        }
        xMLStringBuffer.append(this.fCurrentEntity.ch, i62, i23);
        return !z;
    }

    /* JADX WARNING: Removed duplicated region for block: B:43:0x00d7  */
    /* JADX WARNING: Removed duplicated region for block: B:67:0x00f8 A[EDGE_INSN: B:67:0x00f8->B:53:0x00f8 ?: BREAK  , SYNTHETIC] */
    public int scanLiteral(int i2, XMLString xMLString) {
        XMLEntityManager.ScannedEntity scannedEntity;
        int i3;
        XMLEntityManager.ScannedEntity scannedEntity2 = this.fCurrentEntity;
        int i4 = scannedEntity2.position;
        int i5 = scannedEntity2.count;
        int i6 = 0;
        if (i4 == i5) {
            load(0, true);
        } else if (i4 == i5 - 1) {
            char[] cArr = scannedEntity2.ch;
            cArr[0] = cArr[i5 - 1];
            load(1, false);
            XMLEntityManager.ScannedEntity scannedEntity3 = this.fCurrentEntity;
            scannedEntity3.position = 0;
            scannedEntity3.startPosition = 0;
        }
        XMLEntityManager.ScannedEntity scannedEntity4 = this.fCurrentEntity;
        int i7 = scannedEntity4.position;
        char c = scannedEntity4.ch[i7];
        boolean isExternal = scannedEntity4.isExternal();
        if (c == '\n' || (c == '\r' && isExternal)) {
            int i8 = 0;
            while (true) {
                XMLEntityManager.ScannedEntity scannedEntity5 = this.fCurrentEntity;
                char[] cArr2 = scannedEntity5.ch;
                int i9 = scannedEntity5.position;
                int i10 = i9 + 1;
                scannedEntity5.position = i10;
                char c2 = cArr2[i9];
                if (c2 != '\r' || !isExternal) {
                    if (c2 != '\n') {
                        this.fCurrentEntity.position--;
                        break;
                    }
                    i8++;
                    XMLEntityManager.ScannedEntity scannedEntity6 = this.fCurrentEntity;
                    scannedEntity6.lineNumber++;
                    scannedEntity6.columnNumber = 1;
                    int i11 = scannedEntity6.position;
                    if (i11 == scannedEntity6.count) {
                        scannedEntity6.baseCharOffset = (i11 - scannedEntity6.startPosition) + scannedEntity6.baseCharOffset;
                        scannedEntity6.position = i8;
                        scannedEntity6.startPosition = i8;
                        if (load(i8, false)) {
                            break;
                        }
                        i7 = 0;
                    }
                } else {
                    i8++;
                    scannedEntity5.lineNumber++;
                    scannedEntity5.columnNumber = 1;
                    if (i10 == scannedEntity5.count) {
                        scannedEntity5.baseCharOffset = (i10 - scannedEntity5.startPosition) + scannedEntity5.baseCharOffset;
                        scannedEntity5.position = i8;
                        scannedEntity5.startPosition = i8;
                        if (load(i8, false)) {
                            break;
                        }
                        i7 = 0;
                    }
                    XMLEntityManager.ScannedEntity scannedEntity7 = this.fCurrentEntity;
                    char[] cArr3 = scannedEntity7.ch;
                    int i12 = scannedEntity7.position;
                    if (cArr3[i12] == '\n') {
                        scannedEntity7.position = i12 + 1;
                        i7++;
                    } else {
                        i8++;
                    }
                }
                XMLEntityManager.ScannedEntity scannedEntity8 = this.fCurrentEntity;
                if (scannedEntity8.position >= scannedEntity8.count - 1) {
                    break;
                }
            }
            i6 = i7;
            int i13 = i6;
            while (true) {
                scannedEntity = this.fCurrentEntity;
                i3 = scannedEntity.position;
                if (i13 >= i3) {
                    break;
                }
                scannedEntity.ch[i13] = '\n';
                i13++;
            }
            int i14 = i3 - i6;
            if (i3 == scannedEntity.count - 1) {
                xMLString.setValues(scannedEntity.ch, i6, i14);
                return -1;
            }
            i7 = i6;
            i6 = i8;
        }
        while (true) {
            XMLEntityManager.ScannedEntity scannedEntity9 = this.fCurrentEntity;
            int i15 = scannedEntity9.position;
            if (i15 < scannedEntity9.count) {
                break;
            }
            char[] cArr4 = scannedEntity9.ch;
            scannedEntity9.position = i15 + 1;
            char c3 = cArr4[i15];
            if ((c3 == i2 && (!scannedEntity9.literal || isExternal)) || c3 == '%' || !XMLChar.isContent(c3)) {
                this.fCurrentEntity.position--;
            }
            XMLEntityManager.ScannedEntity scannedEntity92 = this.fCurrentEntity;
            int i152 = scannedEntity92.position;
            if (i152 < scannedEntity92.count) {
            }
        }
        this.fCurrentEntity.position--;
        XMLEntityManager.ScannedEntity scannedEntity10 = this.fCurrentEntity;
        int i16 = scannedEntity10.position - i7;
        scannedEntity10.columnNumber = (i16 - i6) + scannedEntity10.columnNumber;
        xMLString.setValues(scannedEntity10.ch, i7, i16);
        XMLEntityManager.ScannedEntity scannedEntity11 = this.fCurrentEntity;
        int i17 = scannedEntity11.position;
        if (i17 == scannedEntity11.count) {
            return -1;
        }
        char c4 = scannedEntity11.ch[i17];
        if (c4 != i2 || !scannedEntity11.literal) {
            return c4;
        }
        return -1;
    }

    /* JADX WARNING: Code restructure failed: missing block: B:16:0x005d, code lost:
        r4 = r4 - r1;
        r0 = r0.ch;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:17:0x0061, code lost:
        if (r4 != r0.length) goto L_0x006f;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:18:0x0063, code lost:
        r5 = new char[(r0.length << 1)];
        java.lang.System.arraycopy(r0, r1, r5, 0, r4);
        r6.fCurrentEntity.ch = r5;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:19:0x006f, code lost:
        java.lang.System.arraycopy(r0, r1, r0, 0, r4);
     */
    /* JADX WARNING: Code restructure failed: missing block: B:21:0x0076, code lost:
        if (load(r4, false) == false) goto L_0x0042;
     */
    public String scanNCName() {
        XMLEntityManager.ScannedEntity scannedEntity = this.fCurrentEntity;
        int i2 = 0;
        if (scannedEntity.position == scannedEntity.count) {
            load(0, true);
        }
        XMLEntityManager.ScannedEntity scannedEntity2 = this.fCurrentEntity;
        int i3 = scannedEntity2.position;
        if (XMLChar.isNCNameStart(scannedEntity2.ch[i3])) {
            XMLEntityManager.ScannedEntity scannedEntity3 = this.fCurrentEntity;
            int i4 = scannedEntity3.position + 1;
            scannedEntity3.position = i4;
            if (i4 == scannedEntity3.count) {
                char[] cArr = scannedEntity3.ch;
                cArr[0] = cArr[i3];
                if (load(1, false)) {
                    XMLEntityManager.ScannedEntity scannedEntity4 = this.fCurrentEntity;
                    scannedEntity4.columnNumber++;
                    return this.fSymbolTable.addSymbol(scannedEntity4.ch, 0, 1);
                }
                i3 = 0;
            }
            while (true) {
                XMLEntityManager.ScannedEntity scannedEntity5 = this.fCurrentEntity;
                if (XMLChar.isNCName(scannedEntity5.ch[scannedEntity5.position])) {
                    XMLEntityManager.ScannedEntity scannedEntity6 = this.fCurrentEntity;
                    int i5 = scannedEntity6.position + 1;
                    scannedEntity6.position = i5;
                    if (i5 == scannedEntity6.count) {
                        break;
                    }
                } else {
                    break;
                }
                break;
                break;
            }
        }
        i2 = i3;
        XMLEntityManager.ScannedEntity scannedEntity7 = this.fCurrentEntity;
        int i6 = scannedEntity7.position - i2;
        scannedEntity7.columnNumber += i6;
        if (i6 > 0) {
            return this.fSymbolTable.addSymbol(scannedEntity7.ch, i2, i6);
        }
        return null;
    }

    /* JADX WARNING: Code restructure failed: missing block: B:16:0x005d, code lost:
        r4 = r4 - r1;
        r0 = r0.ch;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:17:0x0061, code lost:
        if (r4 != r0.length) goto L_0x006f;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:18:0x0063, code lost:
        r5 = new char[(r0.length << 1)];
        java.lang.System.arraycopy(r0, r1, r5, 0, r4);
        r6.fCurrentEntity.ch = r5;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:19:0x006f, code lost:
        java.lang.System.arraycopy(r0, r1, r0, 0, r4);
     */
    /* JADX WARNING: Code restructure failed: missing block: B:21:0x0076, code lost:
        if (load(r4, false) == false) goto L_0x0042;
     */
    public String scanName() {
        XMLEntityManager.ScannedEntity scannedEntity = this.fCurrentEntity;
        int i2 = 0;
        if (scannedEntity.position == scannedEntity.count) {
            load(0, true);
        }
        XMLEntityManager.ScannedEntity scannedEntity2 = this.fCurrentEntity;
        int i3 = scannedEntity2.position;
        if (XMLChar.isNameStart(scannedEntity2.ch[i3])) {
            XMLEntityManager.ScannedEntity scannedEntity3 = this.fCurrentEntity;
            int i4 = scannedEntity3.position + 1;
            scannedEntity3.position = i4;
            if (i4 == scannedEntity3.count) {
                char[] cArr = scannedEntity3.ch;
                cArr[0] = cArr[i3];
                if (load(1, false)) {
                    XMLEntityManager.ScannedEntity scannedEntity4 = this.fCurrentEntity;
                    scannedEntity4.columnNumber++;
                    return this.fSymbolTable.addSymbol(scannedEntity4.ch, 0, 1);
                }
                i3 = 0;
            }
            while (true) {
                XMLEntityManager.ScannedEntity scannedEntity5 = this.fCurrentEntity;
                if (XMLChar.isName(scannedEntity5.ch[scannedEntity5.position])) {
                    XMLEntityManager.ScannedEntity scannedEntity6 = this.fCurrentEntity;
                    int i5 = scannedEntity6.position + 1;
                    scannedEntity6.position = i5;
                    if (i5 == scannedEntity6.count) {
                        break;
                    }
                } else {
                    break;
                }
                break;
                break;
            }
        }
        i2 = i3;
        XMLEntityManager.ScannedEntity scannedEntity7 = this.fCurrentEntity;
        int i6 = scannedEntity7.position - i2;
        scannedEntity7.columnNumber += i6;
        if (i6 > 0) {
            return this.fSymbolTable.addSymbol(scannedEntity7.ch, i2, i6);
        }
        return null;
    }

    public String scanNmtoken() {
        XMLEntityManager.ScannedEntity scannedEntity = this.fCurrentEntity;
        int i2 = 0;
        if (scannedEntity.position == scannedEntity.count) {
            load(0, true);
        }
        int i3 = this.fCurrentEntity.position;
        while (true) {
            XMLEntityManager.ScannedEntity scannedEntity2 = this.fCurrentEntity;
            if (!XMLChar.isName(scannedEntity2.ch[scannedEntity2.position])) {
                i2 = i3;
                break;
            }
            XMLEntityManager.ScannedEntity scannedEntity3 = this.fCurrentEntity;
            int i4 = scannedEntity3.position + 1;
            scannedEntity3.position = i4;
            if (i4 == scannedEntity3.count) {
                int i5 = i4 - i3;
                char[] cArr = scannedEntity3.ch;
                if (i5 == cArr.length) {
                    char[] cArr2 = new char[(cArr.length << 1)];
                    System.arraycopy(cArr, i3, cArr2, 0, i5);
                    this.fCurrentEntity.ch = cArr2;
                } else {
                    System.arraycopy(cArr, i3, cArr, 0, i5);
                }
                if (load(i5, false)) {
                    break;
                }
                i3 = 0;
            }
        }
        XMLEntityManager.ScannedEntity scannedEntity4 = this.fCurrentEntity;
        int i6 = scannedEntity4.position - i2;
        scannedEntity4.columnNumber += i6;
        if (i6 > 0) {
            return this.fSymbolTable.addSymbol(scannedEntity4.ch, i2, i6);
        }
        return null;
    }

    public boolean scanQName(QName qName) {
        String str;
        String str2;
        XMLEntityManager.ScannedEntity scannedEntity = this.fCurrentEntity;
        if (scannedEntity.position == scannedEntity.count) {
            load(0, true);
        }
        XMLEntityManager.ScannedEntity scannedEntity2 = this.fCurrentEntity;
        int i2 = scannedEntity2.position;
        if (XMLChar.isNCNameStart(scannedEntity2.ch[i2])) {
            XMLEntityManager.ScannedEntity scannedEntity3 = this.fCurrentEntity;
            int i3 = scannedEntity3.position + 1;
            scannedEntity3.position = i3;
            if (i3 == scannedEntity3.count) {
                char[] cArr = scannedEntity3.ch;
                cArr[0] = cArr[i2];
                if (load(1, false)) {
                    XMLEntityManager.ScannedEntity scannedEntity4 = this.fCurrentEntity;
                    scannedEntity4.columnNumber++;
                    String addSymbol = this.fSymbolTable.addSymbol(scannedEntity4.ch, 0, 1);
                    qName.setValues(null, addSymbol, addSymbol, null);
                    return true;
                }
                i2 = 0;
            }
            int i4 = -1;
            while (true) {
                XMLEntityManager.ScannedEntity scannedEntity5 = this.fCurrentEntity;
                if (!XMLChar.isName(scannedEntity5.ch[scannedEntity5.position])) {
                    break;
                }
                XMLEntityManager.ScannedEntity scannedEntity6 = this.fCurrentEntity;
                char[] cArr2 = scannedEntity6.ch;
                int i5 = scannedEntity6.position;
                if (cArr2[i5] == ':') {
                    if (i4 != -1) {
                        break;
                    }
                    i4 = i5;
                }
                XMLEntityManager.ScannedEntity scannedEntity7 = this.fCurrentEntity;
                int i6 = scannedEntity7.position + 1;
                scannedEntity7.position = i6;
                if (i6 == scannedEntity7.count) {
                    int i7 = i6 - i2;
                    char[] cArr3 = scannedEntity7.ch;
                    if (i7 == cArr3.length) {
                        char[] cArr4 = new char[(cArr3.length << 1)];
                        System.arraycopy(cArr3, i2, cArr4, 0, i7);
                        this.fCurrentEntity.ch = cArr4;
                    } else {
                        System.arraycopy(cArr3, i2, cArr3, 0, i7);
                    }
                    if (i4 != -1) {
                        i4 -= i2;
                    }
                    if (load(i7, false)) {
                        i2 = 0;
                        break;
                    }
                    i2 = 0;
                }
            }
            XMLEntityManager.ScannedEntity scannedEntity8 = this.fCurrentEntity;
            int i8 = scannedEntity8.position - i2;
            scannedEntity8.columnNumber += i8;
            if (i8 > 0) {
                String addSymbol2 = this.fSymbolTable.addSymbol(scannedEntity8.ch, i2, i8);
                if (i4 != -1) {
                    int i9 = i4 - i2;
                    str = this.fSymbolTable.addSymbol(this.fCurrentEntity.ch, i2, i9);
                    int i10 = (i8 - i9) - 1;
                    int i11 = i4 + 1;
                    if (!XMLChar.isNCNameStart(this.fCurrentEntity.ch[i11])) {
                        this.fErrorReporter.reportError("http://www.w3.org/TR/1998/REC-xml-19980210", "IllegalQName", null, 2);
                    }
                    str2 = this.fSymbolTable.addSymbol(this.fCurrentEntity.ch, i11, i10);
                } else {
                    str2 = addSymbol2;
                    str = null;
                }
                qName.setValues(str, str2, addSymbol2, null);
                return true;
            }
        }
        return false;
    }

    public final void setBufferSize(int i2) {
        this.fBufferSize = i2;
    }

    public final void setCurrentEntity(XMLEntityManager.ScannedEntity scannedEntity) {
        this.fCurrentEntity = scannedEntity;
    }

    public final void setEncoding(String str) {
        XMLEntityManager.ScannedEntity scannedEntity;
        UCSReader uCSReader;
        XMLEntityManager.ScannedEntity scannedEntity2;
        UCSReader uCSReader2;
        XMLEntityManager.ScannedEntity scannedEntity3 = this.fCurrentEntity;
        if (scannedEntity3.stream != null) {
            String str2 = scannedEntity3.encoding;
            if (str2 == null || !str2.equals(str)) {
                String str3 = this.fCurrentEntity.encoding;
                if (str3 != null && str3.startsWith("UTF-16")) {
                    String upperCase = str.toUpperCase(Locale.ENGLISH);
                    if (!upperCase.equals("UTF-16")) {
                        if (upperCase.equals("ISO-10646-UCS-4")) {
                            if (this.fCurrentEntity.encoding.equals("UTF-16BE")) {
                                scannedEntity2 = this.fCurrentEntity;
                                uCSReader2 = new UCSReader(this.fCurrentEntity.stream, 8);
                            } else {
                                scannedEntity2 = this.fCurrentEntity;
                                uCSReader2 = new UCSReader(this.fCurrentEntity.stream, 4);
                            }
                            scannedEntity2.reader = uCSReader2;
                            return;
                        } else if (upperCase.equals("ISO-10646-UCS-2")) {
                            if (this.fCurrentEntity.encoding.equals("UTF-16BE")) {
                                scannedEntity = this.fCurrentEntity;
                                uCSReader = new UCSReader(this.fCurrentEntity.stream, 2);
                            } else {
                                scannedEntity = this.fCurrentEntity;
                                uCSReader = new UCSReader(this.fCurrentEntity.stream, 1);
                            }
                            scannedEntity.reader = uCSReader;
                            return;
                        }
                    } else {
                        return;
                    }
                }
                XMLEntityManager.ScannedEntity scannedEntity4 = this.fCurrentEntity;
                scannedEntity4.setReader(scannedEntity4.stream, str, null);
                this.fCurrentEntity.encoding = str;
            }
        }
    }

    public final void setXMLVersion(String str) {
        this.fCurrentEntity.xmlVersion = str;
    }

    public boolean skipChar(int i2) {
        XMLEntityManager.ScannedEntity scannedEntity = this.fCurrentEntity;
        if (scannedEntity.position == scannedEntity.count) {
            load(0, true);
        }
        XMLEntityManager.ScannedEntity scannedEntity2 = this.fCurrentEntity;
        char[] cArr = scannedEntity2.ch;
        int i3 = scannedEntity2.position;
        char c = cArr[i3];
        if (c == i2) {
            scannedEntity2.position = i3 + 1;
            if (i2 == 10) {
                scannedEntity2.lineNumber++;
                scannedEntity2.columnNumber = 1;
            } else {
                scannedEntity2.columnNumber++;
            }
            return true;
        } else if (i2 != 10 || c != '\r' || !scannedEntity2.isExternal()) {
            return false;
        } else {
            XMLEntityManager.ScannedEntity scannedEntity3 = this.fCurrentEntity;
            if (scannedEntity3.position == scannedEntity3.count) {
                scannedEntity3.ch[0] = (char) c;
                load(1, false);
            }
            XMLEntityManager.ScannedEntity scannedEntity4 = this.fCurrentEntity;
            int i4 = scannedEntity4.position + 1;
            scannedEntity4.position = i4;
            if (scannedEntity4.ch[i4] == '\n') {
                scannedEntity4.position = i4 + 1;
            }
            XMLEntityManager.ScannedEntity scannedEntity5 = this.fCurrentEntity;
            scannedEntity5.lineNumber++;
            scannedEntity5.columnNumber = 1;
            return true;
        }
    }

    public final boolean skipDeclSpaces() {
        boolean z;
        XMLEntityManager.ScannedEntity scannedEntity = this.fCurrentEntity;
        if (scannedEntity.position == scannedEntity.count) {
            load(0, true);
        }
        XMLEntityManager.ScannedEntity scannedEntity2 = this.fCurrentEntity;
        char c = scannedEntity2.ch[scannedEntity2.position];
        if (!XMLChar.isSpace(c)) {
            return false;
        }
        boolean isExternal = this.fCurrentEntity.isExternal();
        do {
            if (c == '\n' || (isExternal && c == '\r')) {
                XMLEntityManager.ScannedEntity scannedEntity3 = this.fCurrentEntity;
                scannedEntity3.lineNumber++;
                scannedEntity3.columnNumber = 1;
                if (scannedEntity3.position == scannedEntity3.count - 1) {
                    scannedEntity3.ch[0] = (char) c;
                    z = load(1, true);
                    if (!z) {
                        XMLEntityManager.ScannedEntity scannedEntity4 = this.fCurrentEntity;
                        scannedEntity4.position = 0;
                        scannedEntity4.startPosition = 0;
                    }
                } else {
                    z = false;
                }
                if (c == '\r' && isExternal) {
                    XMLEntityManager.ScannedEntity scannedEntity5 = this.fCurrentEntity;
                    char[] cArr = scannedEntity5.ch;
                    int i2 = scannedEntity5.position + 1;
                    scannedEntity5.position = i2;
                    if (cArr[i2] != '\n') {
                        scannedEntity5.position = i2 - 1;
                    }
                }
            } else {
                this.fCurrentEntity.columnNumber++;
                z = false;
            }
            if (!z) {
                this.fCurrentEntity.position++;
            }
            XMLEntityManager.ScannedEntity scannedEntity6 = this.fCurrentEntity;
            if (scannedEntity6.position == scannedEntity6.count) {
                load(0, true);
            }
            XMLEntityManager.ScannedEntity scannedEntity7 = this.fCurrentEntity;
            c = scannedEntity7.ch[scannedEntity7.position];
        } while (XMLChar.isSpace(c));
        return true;
    }

    public boolean skipSpaces() {
        boolean z;
        XMLEntityManager.ScannedEntity scannedEntity = this.fCurrentEntity;
        if (scannedEntity.position == scannedEntity.count) {
            load(0, true);
        }
        XMLEntityManager.ScannedEntity scannedEntity2 = this.fCurrentEntity;
        char c = scannedEntity2.ch[scannedEntity2.position];
        if (!XMLChar.isSpace(c)) {
            return false;
        }
        boolean isExternal = this.fCurrentEntity.isExternal();
        do {
            if (c == '\n' || (isExternal && c == '\r')) {
                XMLEntityManager.ScannedEntity scannedEntity3 = this.fCurrentEntity;
                scannedEntity3.lineNumber++;
                scannedEntity3.columnNumber = 1;
                if (scannedEntity3.position == scannedEntity3.count - 1) {
                    scannedEntity3.ch[0] = (char) c;
                    z = load(1, true);
                    if (!z) {
                        XMLEntityManager.ScannedEntity scannedEntity4 = this.fCurrentEntity;
                        scannedEntity4.position = 0;
                        scannedEntity4.startPosition = 0;
                    }
                } else {
                    z = false;
                }
                if (c == '\r' && isExternal) {
                    XMLEntityManager.ScannedEntity scannedEntity5 = this.fCurrentEntity;
                    char[] cArr = scannedEntity5.ch;
                    int i2 = scannedEntity5.position + 1;
                    scannedEntity5.position = i2;
                    if (cArr[i2] != '\n') {
                        scannedEntity5.position = i2 - 1;
                    }
                }
            } else {
                this.fCurrentEntity.columnNumber++;
                z = false;
            }
            if (!z) {
                this.fCurrentEntity.position++;
            }
            XMLEntityManager.ScannedEntity scannedEntity6 = this.fCurrentEntity;
            if (scannedEntity6.position == scannedEntity6.count) {
                load(0, true);
            }
            XMLEntityManager.ScannedEntity scannedEntity7 = this.fCurrentEntity;
            c = scannedEntity7.ch[scannedEntity7.position];
        } while (XMLChar.isSpace(c));
        return true;
    }

    public boolean skipString(String str) {
        XMLEntityManager.ScannedEntity scannedEntity;
        int i2;
        XMLEntityManager.ScannedEntity scannedEntity2;
        int i3;
        XMLEntityManager.ScannedEntity scannedEntity3 = this.fCurrentEntity;
        if (scannedEntity3.position == scannedEntity3.count) {
            load(0, true);
        }
        int length = str.length();
        for (int i4 = 0; i4 < length; i4++) {
            XMLEntityManager.ScannedEntity scannedEntity4 = this.fCurrentEntity;
            char[] cArr = scannedEntity4.ch;
            int i5 = scannedEntity4.position;
            scannedEntity4.position = i5 + 1;
            if (cArr[i5] != str.charAt(i4)) {
                scannedEntity = this.fCurrentEntity;
                i2 = scannedEntity.position - (i4 + 1);
            } else {
                if (i4 < length - 1 && (scannedEntity2 = this.fCurrentEntity).position == (i3 = scannedEntity2.count)) {
                    char[] cArr2 = scannedEntity2.ch;
                    int i6 = i4 + 1;
                    System.arraycopy(cArr2, (i3 - i4) - 1, cArr2, 0, i6);
                    if (load(i6, false)) {
                        scannedEntity = this.fCurrentEntity;
                        scannedEntity.startPosition -= i6;
                        i2 = scannedEntity.position - i6;
                    }
                }
            }
            scannedEntity.position = i2;
            return false;
        }
        this.fCurrentEntity.columnNumber += length;
        return true;
    }
}
