package org.apache.xerces.impl;

import b.b.a.a.a;
import javax.xml.transform.OutputKeys;
import org.apache.poi.ss.formula.ptg.StringPtg;
import org.apache.poi.ss.usermodel.DataFormatter;
import org.apache.xerces.impl.XMLEntityManager;
import org.apache.xerces.util.SymbolTable;
import org.apache.xerces.util.XMLChar;
import org.apache.xerces.util.XMLResourceIdentifierImpl;
import org.apache.xerces.util.XMLStringBuffer;
import org.apache.xerces.xni.Augmentations;
import org.apache.xerces.xni.XMLResourceIdentifier;
import org.apache.xerces.xni.XMLString;
import org.apache.xerces.xni.parser.XMLComponent;
import org.apache.xerces.xni.parser.XMLComponentManager;
import org.apache.xerces.xni.parser.XMLConfigurationException;

public abstract class XMLScanner implements XMLComponent {
    public static final boolean DEBUG_ATTR_NORMALIZATION = false;
    public static final String ENTITY_MANAGER = "http://apache.org/xml/properties/internal/entity-manager";
    public static final String ERROR_REPORTER = "http://apache.org/xml/properties/internal/error-reporter";
    public static final String NAMESPACES = "http://xml.org/sax/features/namespaces";
    public static final String NOTIFY_CHAR_REFS = "http://apache.org/xml/features/scanner/notify-char-refs";
    public static final String PARSER_SETTINGS = "http://apache.org/xml/features/internal/parser-settings";
    public static final String SYMBOL_TABLE = "http://apache.org/xml/properties/internal/symbol-table";
    public static final String VALIDATION = "http://xml.org/sax/features/validation";
    public static final String fAmpSymbol = "amp".intern();
    public static final String fAposSymbol = "apos".intern();
    public static final String fEncodingSymbol = OutputKeys.ENCODING.intern();
    public static final String fGtSymbol = "gt".intern();
    public static final String fLtSymbol = "lt".intern();
    public static final String fQuotSymbol = "quot".intern();
    public static final String fStandaloneSymbol = OutputKeys.STANDALONE.intern();
    public static final String fVersionSymbol = "version".intern();
    public String fCharRefLiteral = null;
    public int fEntityDepth;
    public XMLEntityManager fEntityManager;
    public XMLEntityScanner fEntityScanner;
    public XMLErrorReporter fErrorReporter;
    public boolean fNamespaces;
    public boolean fNotifyCharRefs = false;
    public boolean fParserSettings = true;
    public boolean fReportEntity;
    public final XMLResourceIdentifierImpl fResourceIdentifier = new XMLResourceIdentifierImpl();
    public boolean fScanningAttribute;
    public final XMLString fString = new XMLString();
    public final XMLStringBuffer fStringBuffer = new XMLStringBuffer();
    public final XMLStringBuffer fStringBuffer2 = new XMLStringBuffer();
    public final XMLStringBuffer fStringBuffer3 = new XMLStringBuffer();
    public SymbolTable fSymbolTable;
    public boolean fValidation = false;

    private void init() {
        this.fEntityScanner = null;
        this.fEntityDepth = 0;
        this.fReportEntity = true;
        this.fResourceIdentifier.clear();
    }

    public void endEntity(String str, Augmentations augmentations) {
        this.fEntityDepth--;
    }

    public boolean getFeature(String str) {
        if ("http://xml.org/sax/features/validation".equals(str)) {
            return this.fValidation;
        }
        if ("http://apache.org/xml/features/scanner/notify-char-refs".equals(str)) {
            return this.fNotifyCharRefs;
        }
        throw new XMLConfigurationException(0, str);
    }

    @Override // org.apache.xerces.xni.parser.XMLComponent
    public abstract Boolean getFeatureDefault(String str);

    @Override // org.apache.xerces.xni.parser.XMLComponent
    public abstract Object getPropertyDefault(String str);

    @Override // org.apache.xerces.xni.parser.XMLComponent
    public abstract String[] getRecognizedFeatures();

    @Override // org.apache.xerces.xni.parser.XMLComponent
    public abstract String[] getRecognizedProperties();

    public String getVersionNotSupportedKey() {
        return "VersionNotSupported";
    }

    public boolean isInvalid(int i2) {
        return XMLChar.isInvalid(i2);
    }

    public boolean isInvalidLiteral(int i2) {
        return XMLChar.isInvalid(i2);
    }

    public int isUnchangedByNormalization(XMLString xMLString) {
        int i2 = xMLString.offset;
        int i3 = xMLString.length + i2;
        while (i2 < i3) {
            if (xMLString.ch[i2] < ' ') {
                return i2 - xMLString.offset;
            }
            i2++;
        }
        return -1;
    }

    public boolean isValidNCName(int i2) {
        return XMLChar.isNCName(i2);
    }

    public boolean isValidNameChar(int i2) {
        return XMLChar.isName(i2);
    }

    public boolean isValidNameStartChar(int i2) {
        return XMLChar.isNameStart(i2);
    }

    public boolean isValidNameStartHighSurrogate(int i2) {
        return false;
    }

    public void normalizeWhitespace(XMLString xMLString) {
        int i2 = xMLString.offset;
        int i3 = xMLString.length + i2;
        while (i2 < i3) {
            char[] cArr = xMLString.ch;
            if (cArr[i2] < ' ') {
                cArr[i2] = ' ';
            }
            i2++;
        }
    }

    public void normalizeWhitespace(XMLString xMLString, int i2) {
        int i3 = xMLString.offset;
        int i4 = xMLString.length + i3;
        for (int i5 = i3 + i2; i5 < i4; i5++) {
            char[] cArr = xMLString.ch;
            if (cArr[i5] < ' ') {
                cArr[i5] = ' ';
            }
        }
    }

    public void reportFatalError(String str, Object[] objArr) {
        this.fErrorReporter.reportError("http://www.w3.org/TR/1998/REC-xml-19980210", str, objArr, 2);
    }

    public void reset() {
        init();
        this.fValidation = true;
        this.fNotifyCharRefs = false;
    }

    @Override // org.apache.xerces.xni.parser.XMLComponent
    public void reset(XMLComponentManager xMLComponentManager) {
        try {
            this.fParserSettings = xMLComponentManager.getFeature("http://apache.org/xml/features/internal/parser-settings");
        } catch (XMLConfigurationException unused) {
            this.fParserSettings = true;
        }
        if (!this.fParserSettings) {
            init();
            return;
        }
        this.fSymbolTable = (SymbolTable) xMLComponentManager.getProperty("http://apache.org/xml/properties/internal/symbol-table");
        this.fErrorReporter = (XMLErrorReporter) xMLComponentManager.getProperty("http://apache.org/xml/properties/internal/error-reporter");
        this.fEntityManager = (XMLEntityManager) xMLComponentManager.getProperty("http://apache.org/xml/properties/internal/entity-manager");
        try {
            this.fValidation = xMLComponentManager.getFeature("http://xml.org/sax/features/validation");
        } catch (XMLConfigurationException unused2) {
            this.fValidation = false;
        }
        try {
            this.fNamespaces = xMLComponentManager.getFeature("http://xml.org/sax/features/namespaces");
        } catch (XMLConfigurationException unused3) {
            this.fNamespaces = true;
        }
        try {
            this.fNotifyCharRefs = xMLComponentManager.getFeature("http://apache.org/xml/features/scanner/notify-char-refs");
        } catch (XMLConfigurationException unused4) {
            this.fNotifyCharRefs = false;
        }
        init();
    }

    /* JADX WARNING: Removed duplicated region for block: B:104:0x01ff  */
    /* JADX WARNING: Removed duplicated region for block: B:107:0x0209  */
    /* JADX WARNING: Removed duplicated region for block: B:117:0x021a A[ADDED_TO_REGION, SYNTHETIC] */
    public boolean scanAttributeValue(XMLString xMLString, XMLString xMLString2, String str, boolean z, String str2) {
        int i2;
        XMLStringBuffer xMLStringBuffer;
        char c;
        int peekChar = this.fEntityScanner.peekChar();
        if (!(peekChar == 39 || peekChar == 34)) {
            reportFatalError("OpenQuoteExpected", new Object[]{str2, str});
        }
        this.fEntityScanner.scanChar();
        int i3 = this.fEntityDepth;
        int scanLiteral = this.fEntityScanner.scanLiteral(peekChar, xMLString);
        if (scanLiteral == peekChar) {
            i2 = isUnchangedByNormalization(xMLString);
            if (i2 == -1) {
                xMLString2.setValues(xMLString);
                if (this.fEntityScanner.scanChar() != peekChar) {
                    reportFatalError("CloseQuoteExpected", new Object[]{str2, str});
                }
                return true;
            }
        } else {
            i2 = 0;
        }
        this.fStringBuffer2.clear();
        this.fStringBuffer2.append(xMLString);
        normalizeWhitespace(xMLString, i2);
        if (scanLiteral != peekChar) {
            this.fScanningAttribute = true;
            this.fStringBuffer.clear();
            while (true) {
                this.fStringBuffer.append(xMLString);
                if (scanLiteral == 38) {
                    this.fEntityScanner.skipChar(38);
                    if (i3 == this.fEntityDepth) {
                        this.fStringBuffer2.append('&');
                    }
                    if (this.fEntityScanner.skipChar(35)) {
                        if (i3 == this.fEntityDepth) {
                            this.fStringBuffer2.append('#');
                        }
                        scanCharReferenceValue(this.fStringBuffer, this.fStringBuffer2);
                    } else {
                        String scanName = this.fEntityScanner.scanName();
                        if (scanName == null) {
                            reportFatalError("NameRequiredInReference", null);
                        } else if (i3 == this.fEntityDepth) {
                            this.fStringBuffer2.append(scanName);
                        }
                        if (!this.fEntityScanner.skipChar(59)) {
                            reportFatalError("SemicolonRequiredInReference", new Object[]{scanName});
                        } else if (i3 == this.fEntityDepth) {
                            this.fStringBuffer2.append(';');
                        }
                        if (scanName == fAmpSymbol) {
                            this.fStringBuffer.append('&');
                        } else if (scanName == fAposSymbol) {
                            this.fStringBuffer.append('\'');
                        } else if (scanName == fLtSymbol) {
                            this.fStringBuffer.append('<');
                        } else if (scanName == fGtSymbol) {
                            this.fStringBuffer.append('>');
                        } else if (scanName == fQuotSymbol) {
                            this.fStringBuffer.append(StringPtg.FORMULA_DELIMITER);
                        } else if (this.fEntityManager.isExternalEntity(scanName)) {
                            reportFatalError("ReferenceToExternalEntity", new Object[]{scanName});
                        } else {
                            if (!this.fEntityManager.isDeclaredEntity(scanName)) {
                                if (!z) {
                                    reportFatalError("EntityNotDeclared", new Object[]{scanName});
                                } else if (this.fValidation) {
                                    this.fErrorReporter.reportError("http://www.w3.org/TR/1998/REC-xml-19980210", "EntityNotDeclared", new Object[]{scanName}, 1);
                                }
                            }
                            this.fEntityManager.startEntity(scanName, true);
                        }
                    }
                } else if (scanLiteral == 60) {
                    reportFatalError("LessthanInAttValue", new Object[]{str2, str});
                    this.fEntityScanner.scanChar();
                    if (i3 == this.fEntityDepth) {
                        this.fStringBuffer2.append((char) scanLiteral);
                    }
                } else {
                    if (scanLiteral == 37 || scanLiteral == 93) {
                        this.fEntityScanner.scanChar();
                        c = (char) scanLiteral;
                        this.fStringBuffer.append(c);
                        if (i3 == this.fEntityDepth) {
                            xMLStringBuffer = this.fStringBuffer2;
                        }
                        scanLiteral = this.fEntityScanner.scanLiteral(peekChar, xMLString);
                        if (i3 == this.fEntityDepth) {
                            this.fStringBuffer2.append(xMLString);
                        }
                        normalizeWhitespace(xMLString);
                        if (scanLiteral == peekChar && i3 == this.fEntityDepth) {
                            break;
                        }
                    } else if (scanLiteral == 10 || scanLiteral == 13) {
                        this.fEntityScanner.scanChar();
                        this.fStringBuffer.append(' ');
                        if (i3 == this.fEntityDepth) {
                            this.fStringBuffer2.append('\n');
                        }
                        scanLiteral = this.fEntityScanner.scanLiteral(peekChar, xMLString);
                        if (i3 == this.fEntityDepth) {
                        }
                        normalizeWhitespace(xMLString);
                        if (scanLiteral == peekChar) {
                        }
                    } else {
                        int i4 = -1;
                        if (scanLiteral != -1) {
                            if (XMLChar.isHighSurrogate(scanLiteral)) {
                                this.fStringBuffer3.clear();
                                if (scanSurrogates(this.fStringBuffer3)) {
                                    this.fStringBuffer.append(this.fStringBuffer3);
                                    if (i3 == this.fEntityDepth) {
                                        this.fStringBuffer2.append(this.fStringBuffer3);
                                    }
                                }
                            } else {
                                i4 = -1;
                            }
                        }
                        if (scanLiteral != i4 && isInvalidLiteral(scanLiteral)) {
                            reportFatalError("InvalidCharInAttValue", new Object[]{str2, str, Integer.toString(scanLiteral, 16)});
                            this.fEntityScanner.scanChar();
                            if (i3 == this.fEntityDepth) {
                                xMLStringBuffer = this.fStringBuffer2;
                                c = (char) scanLiteral;
                            }
                        }
                        scanLiteral = this.fEntityScanner.scanLiteral(peekChar, xMLString);
                        if (i3 == this.fEntityDepth) {
                        }
                        normalizeWhitespace(xMLString);
                        if (scanLiteral == peekChar) {
                        }
                    }
                    xMLStringBuffer.append(c);
                    scanLiteral = this.fEntityScanner.scanLiteral(peekChar, xMLString);
                    if (i3 == this.fEntityDepth) {
                    }
                    normalizeWhitespace(xMLString);
                    if (scanLiteral == peekChar) {
                    }
                }
                scanLiteral = this.fEntityScanner.scanLiteral(peekChar, xMLString);
                if (i3 == this.fEntityDepth) {
                }
                normalizeWhitespace(xMLString);
                if (scanLiteral == peekChar) {
                }
            }
            this.fStringBuffer.append(xMLString);
            xMLString.setValues(this.fStringBuffer);
            this.fScanningAttribute = false;
        }
        xMLString2.setValues(this.fStringBuffer2);
        if (this.fEntityScanner.scanChar() != peekChar) {
            reportFatalError("CloseQuoteExpected", new Object[]{str2, str});
        }
        return xMLString2.equals(xMLString.ch, xMLString.offset, xMLString.length);
    }

    /* JADX WARNING: Removed duplicated region for block: B:79:0x0135  */
    /* JADX WARNING: Removed duplicated region for block: B:83:0x0154  */
    /* JADX WARNING: Removed duplicated region for block: B:84:0x0156  */
    /* JADX WARNING: Removed duplicated region for block: B:90:0x0172  */
    /* JADX WARNING: Removed duplicated region for block: B:91:0x0176  */
    /* JADX WARNING: Removed duplicated region for block: B:94:0x018c  */
    public int scanCharReferenceValue(XMLStringBuffer xMLStringBuffer, XMLStringBuffer xMLStringBuffer2) {
        boolean z;
        int i2;
        char c;
        boolean z2;
        if (this.fEntityScanner.skipChar(120)) {
            if (xMLStringBuffer2 != null) {
                xMLStringBuffer2.append('x');
            }
            this.fStringBuffer3.clear();
            int peekChar = this.fEntityScanner.peekChar();
            int i3 = 70;
            if ((peekChar >= 48 && peekChar <= 57) || (peekChar >= 97 && peekChar <= 102) || (peekChar >= 65 && peekChar <= 70)) {
                if (xMLStringBuffer2 != null) {
                    xMLStringBuffer2.append((char) peekChar);
                }
                this.fEntityScanner.scanChar();
                this.fStringBuffer3.append((char) peekChar);
                while (true) {
                    int peekChar2 = this.fEntityScanner.peekChar();
                    boolean z3 = (peekChar2 >= 48 && peekChar2 <= 57) || (peekChar2 >= 97 && peekChar2 <= 102) || (peekChar2 >= 65 && peekChar2 <= i3);
                    if (z3) {
                        if (xMLStringBuffer2 != null) {
                            xMLStringBuffer2.append((char) peekChar2);
                        }
                        this.fEntityScanner.scanChar();
                        this.fStringBuffer3.append((char) peekChar2);
                    }
                    if (!z3) {
                        break;
                    }
                    i3 = 70;
                }
            } else {
                reportFatalError("HexdigitRequiredInCharRef", null);
            }
            z = true;
        } else {
            this.fStringBuffer3.clear();
            int peekChar3 = this.fEntityScanner.peekChar();
            if (peekChar3 >= 48 && peekChar3 <= 57) {
                if (xMLStringBuffer2 != null) {
                    xMLStringBuffer2.append((char) peekChar3);
                }
                this.fEntityScanner.scanChar();
                this.fStringBuffer3.append((char) peekChar3);
                do {
                    int peekChar4 = this.fEntityScanner.peekChar();
                    z2 = peekChar4 >= 48 && peekChar4 <= 57;
                    if (z2) {
                        if (xMLStringBuffer2 != null) {
                            xMLStringBuffer2.append((char) peekChar4);
                        }
                        this.fEntityScanner.scanChar();
                        this.fStringBuffer3.append((char) peekChar4);
                        continue;
                    }
                } while (z2);
            } else {
                reportFatalError("DigitRequiredInCharRef", null);
            }
            z = false;
        }
        if (!this.fEntityScanner.skipChar(59)) {
            reportFatalError("SemicolonRequiredInCharRef", null);
        }
        if (xMLStringBuffer2 != null) {
            xMLStringBuffer2.append(';');
        }
        try {
            i2 = Integer.parseInt(this.fStringBuffer3.toString(), z ? 16 : 10);
            try {
                if (isInvalid(i2)) {
                    StringBuffer stringBuffer = new StringBuffer(this.fStringBuffer3.length + 1);
                    if (z) {
                        stringBuffer.append('x');
                    }
                    stringBuffer.append(this.fStringBuffer3.ch, this.fStringBuffer3.offset, this.fStringBuffer3.length);
                    reportFatalError("InvalidCharRef", new Object[]{stringBuffer.toString()});
                }
            } catch (NumberFormatException unused) {
                StringBuffer stringBuffer2 = new StringBuffer(this.fStringBuffer3.length + 1);
                if (z) {
                }
                XMLStringBuffer xMLStringBuffer3 = this.fStringBuffer3;
                stringBuffer2.append(xMLStringBuffer3.ch, xMLStringBuffer3.offset, xMLStringBuffer3.length);
                reportFatalError("InvalidCharRef", new Object[]{stringBuffer2.toString()});
                if (!XMLChar.isSupplemental(i2)) {
                }
                xMLStringBuffer.append(c);
                StringBuffer a = a.a(DataFormatter.defaultFractionWholePartFormat);
                a.append(z ? "x" : "");
                a.append(this.fStringBuffer3.toString());
                String stringBuffer3 = a.toString();
                if (!this.fScanningAttribute) {
                }
                return i2;
            }
        } catch (NumberFormatException unused2) {
            i2 = -1;
            StringBuffer stringBuffer22 = new StringBuffer(this.fStringBuffer3.length + 1);
            if (z) {
                stringBuffer22.append('x');
            }
            XMLStringBuffer xMLStringBuffer32 = this.fStringBuffer3;
            stringBuffer22.append(xMLStringBuffer32.ch, xMLStringBuffer32.offset, xMLStringBuffer32.length);
            reportFatalError("InvalidCharRef", new Object[]{stringBuffer22.toString()});
            if (!XMLChar.isSupplemental(i2)) {
            }
            xMLStringBuffer.append(c);
            StringBuffer a2 = a.a(DataFormatter.defaultFractionWholePartFormat);
            a2.append(z ? "x" : "");
            a2.append(this.fStringBuffer3.toString());
            String stringBuffer32 = a2.toString();
            if (!this.fScanningAttribute) {
            }
            return i2;
        }
        if (!XMLChar.isSupplemental(i2)) {
            c = (char) i2;
        } else {
            xMLStringBuffer.append(XMLChar.highSurrogate(i2));
            c = XMLChar.lowSurrogate(i2);
        }
        xMLStringBuffer.append(c);
        if (this.fNotifyCharRefs && i2 != -1) {
            StringBuffer a22 = a.a(DataFormatter.defaultFractionWholePartFormat);
            a22.append(z ? "x" : "");
            a22.append(this.fStringBuffer3.toString());
            String stringBuffer322 = a22.toString();
            if (!this.fScanningAttribute) {
                this.fCharRefLiteral = stringBuffer322;
            }
        }
        return i2;
    }

    public void scanComment(XMLStringBuffer xMLStringBuffer) {
        xMLStringBuffer.clear();
        while (this.fEntityScanner.scanData("--", xMLStringBuffer)) {
            int peekChar = this.fEntityScanner.peekChar();
            if (peekChar != -1) {
                if (XMLChar.isHighSurrogate(peekChar)) {
                    scanSurrogates(xMLStringBuffer);
                } else if (isInvalidLiteral(peekChar)) {
                    reportFatalError("InvalidCharInComment", new Object[]{Integer.toHexString(peekChar)});
                    this.fEntityScanner.scanChar();
                }
            }
        }
        if (!this.fEntityScanner.skipChar(62)) {
            reportFatalError("DashDashInComment", null);
        }
    }

    public void scanExternalID(String[] strArr, boolean z) {
        String str;
        String str2 = null;
        if (this.fEntityScanner.skipString("PUBLIC")) {
            if (!this.fEntityScanner.skipSpaces()) {
                reportFatalError("SpaceRequiredAfterPUBLIC", null);
            }
            scanPubidLiteral(this.fString);
            str = this.fString.toString();
            if (!this.fEntityScanner.skipSpaces() && !z) {
                reportFatalError("SpaceRequiredBetweenPublicAndSystem", null);
            }
        } else {
            str = null;
        }
        if (str != null || this.fEntityScanner.skipString("SYSTEM")) {
            if (str == null && !this.fEntityScanner.skipSpaces()) {
                reportFatalError("SpaceRequiredAfterSYSTEM", null);
            }
            int peekChar = this.fEntityScanner.peekChar();
            if (!(peekChar == 39 || peekChar == 34)) {
                if (str == null || !z) {
                    reportFatalError("QuoteRequiredInSystemID", null);
                } else {
                    strArr[0] = null;
                    strArr[1] = str;
                    return;
                }
            }
            this.fEntityScanner.scanChar();
            XMLString xMLString = this.fString;
            if (this.fEntityScanner.scanLiteral(peekChar, xMLString) != peekChar) {
                this.fStringBuffer.clear();
                do {
                    this.fStringBuffer.append(xMLString);
                    int peekChar2 = this.fEntityScanner.peekChar();
                    if (XMLChar.isMarkup(peekChar2) || peekChar2 == 93) {
                        this.fStringBuffer.append((char) this.fEntityScanner.scanChar());
                    } else if (XMLChar.isHighSurrogate(peekChar2)) {
                        scanSurrogates(this.fStringBuffer);
                    } else if (isInvalidLiteral(peekChar2)) {
                        reportFatalError("InvalidCharInSystemID", new Object[]{Integer.toHexString(peekChar2)});
                        this.fEntityScanner.scanChar();
                    }
                } while (this.fEntityScanner.scanLiteral(peekChar, xMLString) != peekChar);
                this.fStringBuffer.append(xMLString);
                xMLString = this.fStringBuffer;
            }
            String xMLString2 = xMLString.toString();
            if (!this.fEntityScanner.skipChar(peekChar)) {
                reportFatalError("SystemIDUnterminated", null);
            }
            str2 = xMLString2;
        }
        strArr[0] = str2;
        strArr[1] = str;
    }

    public void scanPI() {
        this.fReportEntity = false;
        String scanNCName = this.fNamespaces ? this.fEntityScanner.scanNCName() : this.fEntityScanner.scanName();
        if (scanNCName == null) {
            reportFatalError("PITargetRequired", null);
        }
        scanPIData(scanNCName, this.fString);
        this.fReportEntity = true;
    }

    public void scanPIData(String str, XMLString xMLString) {
        if (str.length() == 3) {
            char lowerCase = Character.toLowerCase(str.charAt(0));
            char lowerCase2 = Character.toLowerCase(str.charAt(1));
            char lowerCase3 = Character.toLowerCase(str.charAt(2));
            if (lowerCase == 'x' && lowerCase2 == 'm' && lowerCase3 == 'l') {
                reportFatalError("ReservedPITarget", null);
            }
        }
        if (!this.fEntityScanner.skipSpaces()) {
            if (this.fEntityScanner.skipString("?>")) {
                xMLString.clear();
                return;
            } else if (!this.fNamespaces || this.fEntityScanner.peekChar() != 58) {
                reportFatalError("SpaceRequiredInPI", null);
            } else {
                this.fEntityScanner.scanChar();
                XMLStringBuffer xMLStringBuffer = new XMLStringBuffer(str);
                xMLStringBuffer.append(':');
                String scanName = this.fEntityScanner.scanName();
                if (scanName != null) {
                    xMLStringBuffer.append(scanName);
                }
                reportFatalError("ColonNotLegalWithNS", new Object[]{xMLStringBuffer.toString()});
                this.fEntityScanner.skipSpaces();
            }
        }
        this.fStringBuffer.clear();
        if (this.fEntityScanner.scanData("?>", this.fStringBuffer)) {
            do {
                int peekChar = this.fEntityScanner.peekChar();
                if (peekChar != -1) {
                    if (XMLChar.isHighSurrogate(peekChar)) {
                        scanSurrogates(this.fStringBuffer);
                    } else if (isInvalidLiteral(peekChar)) {
                        reportFatalError("InvalidCharInPI", new Object[]{Integer.toHexString(peekChar)});
                        this.fEntityScanner.scanChar();
                    }
                }
            } while (this.fEntityScanner.scanData("?>", this.fStringBuffer));
        }
        xMLString.setValues(this.fStringBuffer);
    }

    public String scanPseudoAttribute(boolean z, XMLString xMLString) {
        String scanName = this.fEntityScanner.scanName();
        XMLEntityManager.print(this.fEntityManager.getCurrentEntity());
        if (scanName == null) {
            reportFatalError("PseudoAttrNameExpected", null);
        }
        this.fEntityScanner.skipDeclSpaces();
        if (!this.fEntityScanner.skipChar(61)) {
            reportFatalError(z ? "EqRequiredInTextDecl" : "EqRequiredInXMLDecl", new Object[]{scanName});
        }
        this.fEntityScanner.skipDeclSpaces();
        int peekChar = this.fEntityScanner.peekChar();
        if (!(peekChar == 39 || peekChar == 34)) {
            reportFatalError(z ? "QuoteRequiredInTextDecl" : "QuoteRequiredInXMLDecl", new Object[]{scanName});
        }
        this.fEntityScanner.scanChar();
        int scanLiteral = this.fEntityScanner.scanLiteral(peekChar, xMLString);
        if (scanLiteral != peekChar) {
            this.fStringBuffer2.clear();
            do {
                this.fStringBuffer2.append(xMLString);
                if (scanLiteral != -1) {
                    if (scanLiteral == 38 || scanLiteral == 37 || scanLiteral == 60 || scanLiteral == 93) {
                        this.fStringBuffer2.append((char) this.fEntityScanner.scanChar());
                    } else if (XMLChar.isHighSurrogate(scanLiteral)) {
                        scanSurrogates(this.fStringBuffer2);
                    } else if (isInvalidLiteral(scanLiteral)) {
                        reportFatalError(z ? "InvalidCharInTextDecl" : "InvalidCharInXMLDecl", new Object[]{Integer.toString(scanLiteral, 16)});
                        this.fEntityScanner.scanChar();
                    }
                }
                scanLiteral = this.fEntityScanner.scanLiteral(peekChar, xMLString);
            } while (scanLiteral != peekChar);
            this.fStringBuffer2.append(xMLString);
            xMLString.setValues(this.fStringBuffer2);
        }
        if (!this.fEntityScanner.skipChar(peekChar)) {
            reportFatalError(z ? "CloseQuoteMissingInTextDecl" : "CloseQuoteMissingInXMLDecl", new Object[]{scanName});
        }
        return scanName;
    }

    public boolean scanPubidLiteral(XMLString xMLString) {
        String str;
        int scanChar = this.fEntityScanner.scanChar();
        if (scanChar == 39 || scanChar == 34) {
            this.fStringBuffer.clear();
            boolean z = true;
            boolean z2 = true;
            while (true) {
                int scanChar2 = this.fEntityScanner.scanChar();
                if (scanChar2 == 32 || scanChar2 == 10 || scanChar2 == 13) {
                    if (!z) {
                        this.fStringBuffer.append(' ');
                        z = true;
                    }
                } else if (scanChar2 == scanChar) {
                    if (z) {
                        this.fStringBuffer.length--;
                    }
                    xMLString.setValues(this.fStringBuffer);
                    return z2;
                } else if (XMLChar.isPubid(scanChar2)) {
                    this.fStringBuffer.append((char) scanChar2);
                    z = false;
                } else if (scanChar2 == -1) {
                    str = "PublicIDUnterminated";
                    break;
                } else {
                    reportFatalError("InvalidCharInPublicID", new Object[]{Integer.toHexString(scanChar2)});
                    z2 = false;
                }
            }
        } else {
            str = "QuoteRequiredInPublicID";
        }
        reportFatalError(str, null);
        return false;
    }

    public boolean scanSurrogates(XMLStringBuffer xMLStringBuffer) {
        int scanChar = this.fEntityScanner.scanChar();
        int peekChar = this.fEntityScanner.peekChar();
        if (!XMLChar.isLowSurrogate(peekChar)) {
            reportFatalError("InvalidCharInContent", new Object[]{Integer.toString(scanChar, 16)});
            return false;
        }
        this.fEntityScanner.scanChar();
        char c = (char) scanChar;
        char c2 = (char) peekChar;
        int supplemental = XMLChar.supplemental(c, c2);
        if (isInvalid(supplemental)) {
            reportFatalError("InvalidCharInContent", new Object[]{Integer.toString(supplemental, 16)});
            return false;
        }
        xMLStringBuffer.append(c);
        xMLStringBuffer.append(c2);
        return true;
    }

    public void scanXMLDeclOrTextDecl(boolean z, String[] strArr) {
        Object[] objArr;
        boolean z2;
        XMLEntityManager.ScannedEntity scannedEntity;
        boolean skipDeclSpaces = this.fEntityScanner.skipDeclSpaces();
        XMLEntityManager.ScannedEntity currentEntity = this.fEntityManager.getCurrentEntity();
        boolean z3 = currentEntity.literal;
        currentEntity.literal = false;
        boolean z4 = true;
        char c = 0;
        boolean z5 = false;
        String str = null;
        String str2 = null;
        String str3 = null;
        while (this.fEntityScanner.peekChar() != 63) {
            String scanPseudoAttribute = scanPseudoAttribute(z, this.fString);
            String str4 = "SpaceRequiredBeforeEncodingInTextDecl";
            if (c != 0) {
                scannedEntity = currentEntity;
                z2 = z3;
                if (c != z4) {
                    if (c != 2) {
                        reportFatalError("NoMorePseudoAttributes", null);
                    } else if (scanPseudoAttribute == fStandaloneSymbol) {
                        if (!skipDeclSpaces) {
                            reportFatalError("SpaceRequiredBeforeStandalone", null);
                        }
                        str3 = this.fString.toString();
                        if (!str3.equals("yes") && !str3.equals("no")) {
                            reportFatalError("SDDeclInvalid", new Object[]{str3});
                        }
                    } else {
                        reportFatalError("EncodingDeclRequired", null);
                    }
                } else if (scanPseudoAttribute == fEncodingSymbol) {
                    if (!skipDeclSpaces) {
                        if (!z) {
                            str4 = "SpaceRequiredBeforeEncodingInXMLDecl";
                        }
                        reportFatalError(str4, null);
                    }
                    str2 = this.fString.toString();
                    c = z ? (char) 3 : 2;
                    skipDeclSpaces = this.fEntityScanner.skipDeclSpaces();
                    currentEntity = scannedEntity;
                    z3 = z2;
                    z4 = true;
                    z5 = true;
                } else if (z || scanPseudoAttribute != fStandaloneSymbol) {
                    reportFatalError("EncodingDeclRequired", null);
                } else {
                    if (!skipDeclSpaces) {
                        reportFatalError("SpaceRequiredBeforeStandalone", null);
                    }
                    str3 = this.fString.toString();
                    if (!str3.equals("yes") && !str3.equals("no")) {
                        reportFatalError("SDDeclInvalid", new Object[]{str3});
                    }
                }
                skipDeclSpaces = this.fEntityScanner.skipDeclSpaces();
                currentEntity = scannedEntity;
                z3 = z2;
                z4 = true;
                z5 = true;
            } else {
                scannedEntity = currentEntity;
                z2 = z3;
                if (scanPseudoAttribute == fVersionSymbol) {
                    if (!skipDeclSpaces) {
                        reportFatalError(z ? "SpaceRequiredBeforeVersionInTextDecl" : "SpaceRequiredBeforeVersionInXMLDecl", null);
                    }
                    str = this.fString.toString();
                    if (!versionSupported(str)) {
                        reportFatalError(getVersionNotSupportedKey(), new Object[]{str});
                    }
                    c = 1;
                } else if (scanPseudoAttribute == fEncodingSymbol) {
                    if (!z) {
                        reportFatalError("VersionInfoRequired", null);
                    }
                    if (!skipDeclSpaces) {
                        if (!z) {
                            str4 = "SpaceRequiredBeforeEncodingInXMLDecl";
                        }
                        reportFatalError(str4, null);
                    }
                    str2 = this.fString.toString();
                    if (!z) {
                        c = 2;
                    }
                } else if (z) {
                    reportFatalError("EncodingDeclRequired", null);
                } else {
                    reportFatalError("VersionInfoRequired", null);
                }
                skipDeclSpaces = this.fEntityScanner.skipDeclSpaces();
                currentEntity = scannedEntity;
                z3 = z2;
                z4 = true;
                z5 = true;
            }
            c = 3;
            skipDeclSpaces = this.fEntityScanner.skipDeclSpaces();
            currentEntity = scannedEntity;
            z3 = z2;
            z4 = true;
            z5 = true;
        }
        if (z3) {
            currentEntity.literal = z4;
        }
        if (!z || c == 3) {
            objArr = null;
        } else {
            objArr = null;
            reportFatalError("MorePseudoAttributes", null);
        }
        if (z) {
            if (!z5 && str2 == null) {
                reportFatalError("EncodingDeclRequired", objArr);
            }
        } else if (!z5 && str == null) {
            reportFatalError("VersionInfoRequired", objArr);
        }
        if (!this.fEntityScanner.skipChar(63)) {
            reportFatalError("XMLDeclUnterminated", objArr);
        }
        if (!this.fEntityScanner.skipChar(62)) {
            reportFatalError("XMLDeclUnterminated", objArr);
        }
        strArr[0] = str;
        char c2 = z4 ? 1 : 0;
        char c3 = z4 ? 1 : 0;
        char c4 = z4 ? 1 : 0;
        strArr[c2] = str2;
        strArr[2] = str3;
    }

    @Override // org.apache.xerces.xni.parser.XMLComponent
    public void setFeature(String str, boolean z) {
        if ("http://xml.org/sax/features/validation".equals(str)) {
            this.fValidation = z;
        } else if ("http://apache.org/xml/features/scanner/notify-char-refs".equals(str)) {
            this.fNotifyCharRefs = z;
        }
    }

    @Override // org.apache.xerces.xni.parser.XMLComponent
    public void setProperty(String str, Object obj) {
        if (str.startsWith(Constants.XERCES_PROPERTY_PREFIX)) {
            int length = str.length() - 33;
            if (length == 21 && str.endsWith(Constants.SYMBOL_TABLE_PROPERTY)) {
                this.fSymbolTable = (SymbolTable) obj;
            } else if (length == 23 && str.endsWith(Constants.ERROR_REPORTER_PROPERTY)) {
                this.fErrorReporter = (XMLErrorReporter) obj;
            } else if (length == 23 && str.endsWith(Constants.ENTITY_MANAGER_PROPERTY)) {
                this.fEntityManager = (XMLEntityManager) obj;
            }
        }
    }

    public void startEntity(String str, XMLResourceIdentifier xMLResourceIdentifier, String str2, Augmentations augmentations) {
        this.fEntityDepth++;
        this.fEntityScanner = this.fEntityManager.getEntityScanner();
    }

    public boolean versionSupported(String str) {
        return str.equals("1.0");
    }
}
