package org.apache.xerces.impl;

import java.io.CharConversionException;
import java.io.EOFException;
import org.apache.poi.util.LittleEndianCP950Reader;
import org.apache.xerces.impl.XMLEntityManager;
import org.apache.xerces.impl.dv.util.Base64;
import org.apache.xerces.impl.io.MalformedByteSequenceException;
import org.apache.xerces.util.SymbolTable;
import org.apache.xerces.xni.parser.XMLComponentManager;
import org.apache.xerces.xni.parser.XMLInputSource;
import org.apache.xmlbeans.impl.common.NameUtil;

public class XMLVersionDetector {
    public static final String ENTITY_MANAGER = "http://apache.org/xml/properties/internal/entity-manager";
    public static final String ERROR_REPORTER = "http://apache.org/xml/properties/internal/error-reporter";
    public static final String SYMBOL_TABLE = "http://apache.org/xml/properties/internal/symbol-table";
    public static final char[] XML11_VERSION = {'1', NameUtil.PERIOD, '1'};
    public static final String fVersionSymbol = "version".intern();
    public static final String fXMLSymbol = "[xml]".intern();
    public String fEncoding = null;
    public XMLEntityManager fEntityManager;
    public XMLErrorReporter fErrorReporter;
    public final char[] fExpectedVersionString = {'<', LittleEndianCP950Reader.UNMAPPABLE, 'x', 'm', 'l', ' ', 'v', 'e', 'r', 's', 'i', 'o', 'n', Base64.PAD, ' ', ' ', ' ', ' ', ' '};
    public SymbolTable fSymbolTable;

    private void fixupCurrentEntity(XMLEntityManager xMLEntityManager, char[] cArr, int i2) {
        XMLEntityManager.ScannedEntity currentEntity = xMLEntityManager.getCurrentEntity();
        int i3 = currentEntity.count;
        int i4 = currentEntity.position;
        int i5 = (i3 - i4) + i2;
        char[] cArr2 = currentEntity.ch;
        if (i5 > cArr2.length) {
            char[] cArr3 = new char[(((i3 + i2) - i4) + 1)];
            currentEntity.ch = cArr3;
            System.arraycopy(cArr2, 0, cArr3, 0, cArr2.length);
        }
        int i6 = currentEntity.position;
        if (i6 < i2) {
            char[] cArr4 = currentEntity.ch;
            System.arraycopy(cArr4, i6, cArr4, i2, currentEntity.count - i6);
            currentEntity.count = (i2 - currentEntity.position) + currentEntity.count;
        } else {
            for (int i7 = i2; i7 < currentEntity.position; i7++) {
                currentEntity.ch[i7] = ' ';
            }
        }
        System.arraycopy(cArr, 0, currentEntity.ch, 0, i2);
        currentEntity.position = 0;
        currentEntity.baseCharOffset = 0;
        currentEntity.startPosition = 0;
        currentEntity.lineNumber = 1;
        currentEntity.columnNumber = 1;
    }

    public short determineDocVersion(XMLInputSource xMLInputSource) {
        int i2 = 0;
        this.fEncoding = this.fEntityManager.setupCurrentEntity(fXMLSymbol, xMLInputSource, false, true);
        this.fEntityManager.setScannerVersion(1);
        XMLEntityScanner entityScanner = this.fEntityManager.getEntityScanner();
        try {
            if (!entityScanner.skipString("<?xml")) {
                return 1;
            }
            if (!entityScanner.skipDeclSpaces()) {
                fixupCurrentEntity(this.fEntityManager, this.fExpectedVersionString, 5);
                return 1;
            } else if (!entityScanner.skipString("version")) {
                fixupCurrentEntity(this.fEntityManager, this.fExpectedVersionString, 6);
                return 1;
            } else {
                entityScanner.skipDeclSpaces();
                if (entityScanner.peekChar() != 61) {
                    fixupCurrentEntity(this.fEntityManager, this.fExpectedVersionString, 13);
                    return 1;
                }
                entityScanner.scanChar();
                entityScanner.skipDeclSpaces();
                this.fExpectedVersionString[14] = (char) entityScanner.scanChar();
                for (int i3 = 0; i3 < XML11_VERSION.length; i3++) {
                    this.fExpectedVersionString[i3 + 15] = (char) entityScanner.scanChar();
                }
                this.fExpectedVersionString[18] = (char) entityScanner.scanChar();
                fixupCurrentEntity(this.fEntityManager, this.fExpectedVersionString, 19);
                while (true) {
                    if (i2 >= XML11_VERSION.length) {
                        break;
                    } else if (this.fExpectedVersionString[i2 + 15] != XML11_VERSION[i2]) {
                        break;
                    } else {
                        i2++;
                    }
                }
                return i2 == XML11_VERSION.length ? (short) 2 : 1;
            }
        } catch (MalformedByteSequenceException e2) {
            this.fErrorReporter.reportError(e2.getDomain(), e2.getKey(), e2.getArguments(), (short) 2, (Exception) e2);
            return -1;
        } catch (CharConversionException e3) {
            this.fErrorReporter.reportError("http://www.w3.org/TR/1998/REC-xml-19980210", "CharConversionFailure", (Object[]) null, (short) 2, (Exception) e3);
            return -1;
        } catch (EOFException unused) {
            this.fErrorReporter.reportError("http://www.w3.org/TR/1998/REC-xml-19980210", "PrematureEOF", null, 2);
            return -1;
        }
    }

    public void reset(XMLComponentManager xMLComponentManager) {
        this.fSymbolTable = (SymbolTable) xMLComponentManager.getProperty("http://apache.org/xml/properties/internal/symbol-table");
        this.fErrorReporter = (XMLErrorReporter) xMLComponentManager.getProperty("http://apache.org/xml/properties/internal/error-reporter");
        this.fEntityManager = (XMLEntityManager) xMLComponentManager.getProperty("http://apache.org/xml/properties/internal/entity-manager");
        int i2 = 14;
        while (true) {
            char[] cArr = this.fExpectedVersionString;
            if (i2 < cArr.length) {
                cArr[i2] = ' ';
                i2++;
            } else {
                return;
            }
        }
    }

    public void startDocumentParsing(XMLEntityHandler xMLEntityHandler, short s) {
        XMLEntityManager xMLEntityManager;
        short s2 = 1;
        if (s == 1) {
            xMLEntityManager = this.fEntityManager;
        } else {
            xMLEntityManager = this.fEntityManager;
            s2 = 2;
        }
        xMLEntityManager.setScannerVersion(s2);
        this.fErrorReporter.setDocumentLocator(this.fEntityManager.getEntityScanner());
        this.fEntityManager.setEntityHandler(xMLEntityHandler);
        xMLEntityHandler.startEntity(fXMLSymbol, this.fEntityManager.getCurrentResourceIdentifier(), this.fEncoding, null);
    }
}
