package org.apache.xerces.impl.dtd;

import org.apache.xerces.util.SymbolTable;
import org.apache.xerces.xni.Augmentations;

public final class BalancedDTDGrammar extends DTDGrammar {
    public int fDepth = 0;
    public int[][] fGroupIndexStack;
    public int[] fGroupIndexStackSizes;
    public boolean fMixed;
    public short[] fOpStack = null;

    public BalancedDTDGrammar(SymbolTable symbolTable, XMLDTDDescription xMLDTDDescription) {
        super(symbolTable, xMLDTDDescription);
    }

    private int addContentSpecNodes(int i2, int i3) {
        if (i2 == i3) {
            return this.fGroupIndexStack[this.fDepth][i2];
        }
        int i4 = (i2 + i3) >>> 1;
        return addContentSpecNode(this.fOpStack[this.fDepth], addContentSpecNodes(i2, i4), addContentSpecNodes(i4 + 1, i3));
    }

    private void addToCurrentGroup(int i2) {
        int[][] iArr = this.fGroupIndexStack;
        int i3 = this.fDepth;
        int[] iArr2 = iArr[i3];
        int[] iArr3 = this.fGroupIndexStackSizes;
        int i4 = iArr3[i3];
        iArr3[i3] = i4 + 1;
        if (iArr2 == null) {
            iArr2 = new int[8];
            iArr[i3] = iArr2;
        } else if (i4 == iArr2.length) {
            int[] iArr4 = new int[(iArr2.length * 2)];
            System.arraycopy(iArr2, 0, iArr4, 0, iArr2.length);
            this.fGroupIndexStack[this.fDepth] = iArr4;
            iArr2 = iArr4;
        }
        iArr2[i4] = i2;
    }

    private void initializeContentModelStacks() {
        short[] sArr = this.fOpStack;
        if (sArr == null) {
            this.fOpStack = new short[8];
            this.fGroupIndexStack = new int[8][];
            this.fGroupIndexStackSizes = new int[8];
        } else {
            int i2 = this.fDepth;
            if (i2 == sArr.length) {
                short[] sArr2 = new short[(i2 * 2)];
                System.arraycopy(sArr, 0, sArr2, 0, i2);
                this.fOpStack = sArr2;
                int i3 = this.fDepth;
                int[][] iArr = new int[(i3 * 2)][];
                System.arraycopy(this.fGroupIndexStack, 0, iArr, 0, i3);
                this.fGroupIndexStack = iArr;
                int i4 = this.fDepth;
                int[] iArr2 = new int[(i4 * 2)];
                System.arraycopy(this.fGroupIndexStackSizes, 0, iArr2, 0, i4);
                this.fGroupIndexStackSizes = iArr2;
            }
        }
        short[] sArr3 = this.fOpStack;
        int i5 = this.fDepth;
        sArr3[i5] = -1;
        this.fGroupIndexStackSizes[i5] = 0;
    }

    @Override // org.apache.xerces.impl.dtd.DTDGrammar
    public final void addContentSpecToElement(XMLElementDecl xMLElementDecl) {
        setContentSpecIndex(this.fCurrentElementIndex, this.fGroupIndexStackSizes[0] > 0 ? this.fGroupIndexStack[0][0] : -1);
    }

    @Override // org.apache.xerces.impl.dtd.DTDGrammar, org.apache.xerces.xni.XMLDTDContentModelHandler
    public final void element(String str, Augmentations augmentations) {
        addToCurrentGroup(addUniqueLeafNode(str));
    }

    @Override // org.apache.xerces.xni.XMLDTDHandler, org.apache.xerces.impl.dtd.DTDGrammar
    public final void endDTD(Augmentations augmentations) {
        super.endDTD(augmentations);
        this.fOpStack = null;
        this.fGroupIndexStack = null;
        this.fGroupIndexStackSizes = null;
    }

    @Override // org.apache.xerces.impl.dtd.DTDGrammar, org.apache.xerces.xni.XMLDTDContentModelHandler
    public final void endGroup(Augmentations augmentations) {
        int i2 = this.fGroupIndexStackSizes[this.fDepth];
        this.fDepth--;
        addToCurrentGroup(i2 > 0 ? addContentSpecNodes(0, i2 - 1) : addUniqueLeafNode(null));
    }

    @Override // org.apache.xerces.impl.dtd.DTDGrammar, org.apache.xerces.xni.XMLDTDContentModelHandler
    public final void occurrence(short s, Augmentations augmentations) {
        if (!this.fMixed) {
            int[] iArr = this.fGroupIndexStackSizes;
            int i2 = this.fDepth;
            int i3 = iArr[i2] - 1;
            if (s == 2) {
                int[][] iArr2 = this.fGroupIndexStack;
                iArr2[i2][i3] = addContentSpecNode(1, iArr2[i2][i3], -1);
            } else if (s == 3) {
                int[][] iArr3 = this.fGroupIndexStack;
                iArr3[i2][i3] = addContentSpecNode(2, iArr3[i2][i3], -1);
            } else if (s == 4) {
                int[][] iArr4 = this.fGroupIndexStack;
                iArr4[i2][i3] = addContentSpecNode(3, iArr4[i2][i3], -1);
            }
        }
    }

    @Override // org.apache.xerces.impl.dtd.DTDGrammar, org.apache.xerces.xni.XMLDTDContentModelHandler
    public final void pcdata(Augmentations augmentations) {
        this.fMixed = true;
    }

    @Override // org.apache.xerces.impl.dtd.DTDGrammar, org.apache.xerces.xni.XMLDTDContentModelHandler
    public final void separator(short s, Augmentations augmentations) {
        if (s == 0) {
            this.fOpStack[this.fDepth] = 4;
        } else if (s == 1) {
            this.fOpStack[this.fDepth] = 5;
        }
    }

    @Override // org.apache.xerces.impl.dtd.DTDGrammar, org.apache.xerces.xni.XMLDTDContentModelHandler
    public final void startContentModel(String str, Augmentations augmentations) {
        this.fDepth = 0;
        initializeContentModelStacks();
        super.startContentModel(str, augmentations);
    }

    @Override // org.apache.xerces.impl.dtd.DTDGrammar, org.apache.xerces.xni.XMLDTDContentModelHandler
    public final void startGroup(Augmentations augmentations) {
        this.fDepth++;
        initializeContentModelStacks();
        this.fMixed = false;
    }
}
