package org.apache.xerces.impl.dtd;

import b.b.a.a.a;
import java.io.PrintStream;
import java.util.ArrayList;
import java.util.Hashtable;
import org.apache.poi.ss.formula.ptg.PercentPtg;
import org.apache.poi.util.LittleEndianCP950Reader;
import org.apache.poi.xssf.usermodel.XSSFDataValidationConstraint;
import org.apache.xerces.impl.dtd.models.CMAny;
import org.apache.xerces.impl.dtd.models.CMBinOp;
import org.apache.xerces.impl.dtd.models.CMLeaf;
import org.apache.xerces.impl.dtd.models.CMNode;
import org.apache.xerces.impl.dtd.models.CMUniOp;
import org.apache.xerces.impl.dtd.models.ContentModelValidator;
import org.apache.xerces.impl.dtd.models.DFAContentModel;
import org.apache.xerces.impl.dtd.models.MixedContentModel;
import org.apache.xerces.impl.dtd.models.SimpleContentModel;
import org.apache.xerces.impl.dv.DatatypeValidator;
import org.apache.xerces.impl.validation.EntityState;
import org.apache.xerces.impl.xs.SchemaSymbols;
import org.apache.xerces.util.SymbolTable;
import org.apache.xerces.xni.Augmentations;
import org.apache.xerces.xni.QName;
import org.apache.xerces.xni.XMLDTDContentModelHandler;
import org.apache.xerces.xni.XMLDTDHandler;
import org.apache.xerces.xni.XMLLocator;
import org.apache.xerces.xni.XMLResourceIdentifier;
import org.apache.xerces.xni.XMLString;
import org.apache.xerces.xni.grammars.Grammar;
import org.apache.xerces.xni.grammars.XMLGrammarDescription;
import org.apache.xerces.xni.parser.XMLDTDContentModelSource;
import org.apache.xerces.xni.parser.XMLDTDSource;

public class DTDGrammar implements XMLDTDHandler, XMLDTDContentModelHandler, EntityState, Grammar {
    public static final int CHUNK_MASK = 255;
    public static final int CHUNK_SHIFT = 8;
    public static final int CHUNK_SIZE = 256;
    public static final boolean DEBUG = false;
    public static final int INITIAL_CHUNK_COUNT = 4;
    public static final short LIST_FLAG = 128;
    public static final short LIST_MASK = -129;
    public static final int TOP_LEVEL_SCOPE = -1;
    public final XMLAttributeDecl fAttributeDecl = new XMLAttributeDecl();
    public int fAttributeDeclCount = 0;
    public DatatypeValidator[][] fAttributeDeclDatatypeValidator = new DatatypeValidator[4][];
    public short[][] fAttributeDeclDefaultType = new short[4][];
    public String[][] fAttributeDeclDefaultValue = new String[4][];
    public String[][][] fAttributeDeclEnumeration = new String[4][][];
    public int[][] fAttributeDeclIsExternal = new int[4][];
    public QName[][] fAttributeDeclName = new QName[4][];
    public int[][] fAttributeDeclNextAttributeDeclIndex = new int[4][];
    public String[][] fAttributeDeclNonNormalizedDefaultValue = new String[4][];
    public short[][] fAttributeDeclType = new short[4][];
    public XMLContentSpec fContentSpec = new XMLContentSpec();
    public int fContentSpecCount = 0;
    public Object[][] fContentSpecOtherValue = new Object[4][];
    public short[][] fContentSpecType = new short[4][];
    public Object[][] fContentSpecValue = new Object[4][];
    public int fCurrentAttributeIndex;
    public int fCurrentElementIndex;
    public XMLDTDContentModelSource fDTDContentModelSource = null;
    public XMLDTDSource fDTDSource = null;
    public int fDepth = 0;
    public XMLElementDecl fElementDecl = new XMLElementDecl();
    public ContentModelValidator[][] fElementDeclContentModelValidator = new ContentModelValidator[4][];
    public int[][] fElementDeclContentSpecIndex = new int[4][];
    public int fElementDeclCount = 0;
    public int[][] fElementDeclFirstAttributeDeclIndex = new int[4][];
    public int[][] fElementDeclIsExternal = new int[4][];
    public int[][] fElementDeclLastAttributeDeclIndex = new int[4][];
    public QName[][] fElementDeclName = new QName[4][];
    public Hashtable fElementDeclTab = new Hashtable();
    public short[][] fElementDeclType = new short[4][];
    public QNameHashtable fElementIndexMap = new QNameHashtable();
    public String[][] fEntityBaseSystemId = new String[4][];
    public int fEntityCount = 0;
    public XMLEntityDecl fEntityDecl = new XMLEntityDecl();
    public byte[][] fEntityInExternal = new byte[4][];
    public QNameHashtable fEntityIndexMap = new QNameHashtable();
    public byte[][] fEntityIsPE = new byte[4][];
    public String[][] fEntityName = new String[4][];
    public String[][] fEntityNotation = new String[4][];
    public String[][] fEntityPublicId = new String[4][];
    public String[][] fEntitySystemId = new String[4][];
    public String[][] fEntityValue = new String[4][];
    public int fEpsilonIndex = -1;
    public XMLDTDDescription fGrammarDescription = null;
    public boolean fIsImmutable = false;
    public int fLeafCount = 0;
    public boolean fMixed;
    public int[] fNodeIndexStack = null;
    public String[][] fNotationBaseSystemId = new String[4][];
    public int fNotationCount = 0;
    public QNameHashtable fNotationIndexMap = new QNameHashtable();
    public String[][] fNotationName = new String[4][];
    public String[][] fNotationPublicId = new String[4][];
    public String[][] fNotationSystemId = new String[4][];
    public short[] fOpStack = null;
    public int fPEDepth = 0;
    public boolean[] fPEntityStack = new boolean[4];
    public int[] fPrevNodeIndexStack = null;
    public final QName fQName = new QName();
    public final QName fQName2 = new QName();
    public boolean fReadingExternalDTD = false;
    public XMLSimpleType fSimpleType = new XMLSimpleType();
    public SymbolTable fSymbolTable;
    public int nodeIndex = -1;
    public int prevNodeIndex = -1;
    public int valueIndex = -1;

    public static class ChildrenList {
        public int length = 0;
        public QName[] qname = new QName[2];
        public int[] type = new int[2];
    }

    public static final class QNameHashtable {
        public static final int HASHTABLE_SIZE = 101;
        public static final int INITIAL_BUCKET_SIZE = 4;
        public Object[][] fHashTable = new Object[101][];

        public int get(String str) {
            Object[] objArr = this.fHashTable[(str.hashCode() & Integer.MAX_VALUE) % 101];
            if (objArr == null) {
                return -1;
            }
            int i2 = ((int[]) objArr[0])[0];
            int i3 = 1;
            for (int i4 = 0; i4 < i2; i4++) {
                if (((String) objArr[i3]) == str) {
                    return ((int[]) objArr[i3 + 1])[0];
                }
                i3 += 2;
            }
            return -1;
        }

        public void put(String str, int i2) {
            boolean z;
            int hashCode = (str.hashCode() & Integer.MAX_VALUE) % 101;
            Object[][] objArr = this.fHashTable;
            Object[] objArr2 = objArr[hashCode];
            if (objArr2 == null) {
                Object[] objArr3 = new Object[9];
                objArr3[0] = new int[]{1};
                objArr3[1] = str;
                objArr3[2] = new int[]{i2};
                objArr[hashCode] = objArr3;
                return;
            }
            int i3 = ((int[]) objArr2[0])[0];
            int i4 = (i3 * 2) + 1;
            if (i4 == objArr2.length) {
                Object[] objArr4 = new Object[(((i3 + 4) * 2) + 1)];
                System.arraycopy(objArr2, 0, objArr4, 0, i4);
                this.fHashTable[hashCode] = objArr4;
                objArr2 = objArr4;
            }
            int i5 = 0;
            int i6 = 1;
            while (true) {
                if (i5 >= i3) {
                    z = false;
                    break;
                } else if (((String) objArr2[i6]) == str) {
                    ((int[]) objArr2[i6 + 1])[0] = i2;
                    z = true;
                    break;
                } else {
                    i6 += 2;
                    i5++;
                }
            }
            if (!z) {
                objArr2[i4] = str;
                objArr2[i4 + 1] = new int[]{i2};
                ((int[]) objArr2[0])[0] = i3 + 1;
            }
        }
    }

    public DTDGrammar(SymbolTable symbolTable, XMLDTDDescription xMLDTDDescription) {
        this.fSymbolTable = symbolTable;
        this.fGrammarDescription = xMLDTDDescription;
    }

    private void appendContentSpec(XMLContentSpec xMLContentSpec, StringBuffer stringBuffer, boolean z, int i2) {
        Object obj;
        String str;
        String str2;
        char c;
        int i3 = xMLContentSpec.type & 15;
        boolean z2 = false;
        switch (i3) {
            case 0:
                if (xMLContentSpec.value == null && xMLContentSpec.otherValue == null) {
                    str2 = "#PCDATA";
                    stringBuffer.append(str2);
                    return;
                } else if (xMLContentSpec.value != null || xMLContentSpec.otherValue == null) {
                    obj = xMLContentSpec.value;
                    if (obj == null) {
                        stringBuffer.append(SchemaSymbols.ATTVAL_TWOPOUNDANY);
                        return;
                    }
                    stringBuffer.append(obj);
                    return;
                } else {
                    str = "##any:uri=";
                    stringBuffer.append(str);
                    obj = xMLContentSpec.otherValue;
                    stringBuffer.append(obj);
                    return;
                }
            case 1:
                if (i2 == 3 || i2 == 2 || i2 == 1) {
                    getContentSpec(((int[]) xMLContentSpec.value)[0], xMLContentSpec);
                    stringBuffer.append('(');
                    appendContentSpec(xMLContentSpec, stringBuffer, true, i3);
                    stringBuffer.append(')');
                } else {
                    getContentSpec(((int[]) xMLContentSpec.value)[0], xMLContentSpec);
                    appendContentSpec(xMLContentSpec, stringBuffer, true, i3);
                }
                c = LittleEndianCP950Reader.UNMAPPABLE;
                stringBuffer.append(c);
                return;
            case 2:
                if (i2 == 3 || i2 == 2 || i2 == 1) {
                    getContentSpec(((int[]) xMLContentSpec.value)[0], xMLContentSpec);
                    stringBuffer.append('(');
                    appendContentSpec(xMLContentSpec, stringBuffer, true, i3);
                    stringBuffer.append(')');
                } else {
                    getContentSpec(((int[]) xMLContentSpec.value)[0], xMLContentSpec);
                    appendContentSpec(xMLContentSpec, stringBuffer, true, i3);
                }
                c = '*';
                stringBuffer.append(c);
                return;
            case 3:
                if (i2 == 3 || i2 == 2 || i2 == 1) {
                    stringBuffer.append('(');
                    getContentSpec(((int[]) xMLContentSpec.value)[0], xMLContentSpec);
                    appendContentSpec(xMLContentSpec, stringBuffer, true, i3);
                    stringBuffer.append(')');
                } else {
                    getContentSpec(((int[]) xMLContentSpec.value)[0], xMLContentSpec);
                    appendContentSpec(xMLContentSpec, stringBuffer, true, i3);
                }
                c = '+';
                stringBuffer.append(c);
                return;
            case 4:
            case 5:
                if (z) {
                    stringBuffer.append('(');
                }
                short s = xMLContentSpec.type;
                int i4 = ((int[]) xMLContentSpec.otherValue)[0];
                getContentSpec(((int[]) xMLContentSpec.value)[0], xMLContentSpec);
                if (xMLContentSpec.type != s) {
                    z2 = true;
                }
                appendContentSpec(xMLContentSpec, stringBuffer, z2, i3);
                stringBuffer.append(s == 4 ? '|' : ',');
                getContentSpec(i4, xMLContentSpec);
                appendContentSpec(xMLContentSpec, stringBuffer, true, i3);
                if (z) {
                    stringBuffer.append(')');
                    return;
                }
                return;
            case 6:
                stringBuffer.append(SchemaSymbols.ATTVAL_TWOPOUNDANY);
                if (xMLContentSpec.otherValue != null) {
                    str = ":uri=";
                    stringBuffer.append(str);
                    obj = xMLContentSpec.otherValue;
                    stringBuffer.append(obj);
                    return;
                }
                return;
            case 7:
                str = "##other:uri=";
                stringBuffer.append(str);
                obj = xMLContentSpec.otherValue;
                stringBuffer.append(obj);
                return;
            case 8:
                str2 = SchemaSymbols.ATTVAL_TWOPOUNDLOCAL;
                stringBuffer.append(str2);
                return;
            default:
                str2 = "???";
                stringBuffer.append(str2);
                return;
        }
    }

    private final CMNode buildSyntaxTree(int i2, XMLContentSpec xMLContentSpec) {
        CMNode cMNode;
        getContentSpec(i2, xMLContentSpec);
        short s = xMLContentSpec.type;
        if ((s & 15) == 6) {
            int i3 = this.fLeafCount;
            this.fLeafCount = i3 + 1;
            return new CMAny(s, (String) xMLContentSpec.otherValue, i3);
        } else if ((s & 15) == 7) {
            int i4 = this.fLeafCount;
            this.fLeafCount = i4 + 1;
            return new CMAny(s, (String) xMLContentSpec.otherValue, i4);
        } else if ((s & 15) == 8) {
            int i5 = this.fLeafCount;
            this.fLeafCount = i5 + 1;
            return new CMAny(s, null, i5);
        } else if (s == 0) {
            QName qName = this.fQName;
            Object obj = xMLContentSpec.value;
            qName.setValues(null, (String) obj, (String) obj, (String) xMLContentSpec.otherValue);
            QName qName2 = this.fQName;
            int i6 = this.fLeafCount;
            this.fLeafCount = i6 + 1;
            return new CMLeaf(qName2, i6);
        } else {
            int i7 = ((int[]) xMLContentSpec.value)[0];
            int i8 = ((int[]) xMLContentSpec.otherValue)[0];
            if (s == 4 || s == 5) {
                cMNode = new CMBinOp(xMLContentSpec.type, buildSyntaxTree(i7, xMLContentSpec), buildSyntaxTree(i8, xMLContentSpec));
            } else if (s == 2) {
                return new CMUniOp(s, buildSyntaxTree(i7, xMLContentSpec));
            } else {
                if (s == 2 || s == 1 || s == 3) {
                    cMNode = new CMUniOp(xMLContentSpec.type, buildSyntaxTree(i7, xMLContentSpec));
                } else {
                    throw new RuntimeException("ImplementationMessages.VAL_CST");
                }
            }
            return cMNode;
        }
    }

    private void contentSpecTree(int i2, XMLContentSpec xMLContentSpec, ChildrenList childrenList) {
        getContentSpec(i2, xMLContentSpec);
        short s = xMLContentSpec.type;
        if (s == 0 || (s & 15) == 6 || (s & 15) == 8 || (s & 15) == 7) {
            int i3 = childrenList.length;
            QName[] qNameArr = childrenList.qname;
            if (i3 == qNameArr.length) {
                QName[] qNameArr2 = new QName[(i3 * 2)];
                System.arraycopy(qNameArr, 0, qNameArr2, 0, i3);
                childrenList.qname = qNameArr2;
                int i4 = childrenList.length;
                int[] iArr = new int[(i4 * 2)];
                System.arraycopy(childrenList.type, 0, iArr, 0, i4);
                childrenList.type = iArr;
            }
            QName[] qNameArr3 = childrenList.qname;
            int i5 = childrenList.length;
            Object obj = xMLContentSpec.value;
            qNameArr3[i5] = new QName(null, (String) obj, (String) obj, (String) xMLContentSpec.otherValue);
            int[] iArr2 = childrenList.type;
            int i6 = childrenList.length;
            iArr2[i6] = xMLContentSpec.type;
            childrenList.length = i6 + 1;
            return;
        }
        Object obj2 = xMLContentSpec.value;
        int i7 = obj2 != null ? ((int[]) obj2)[0] : -1;
        Object obj3 = xMLContentSpec.otherValue;
        if (obj3 != null) {
            int i8 = ((int[]) obj3)[0];
            short s2 = xMLContentSpec.type;
            if (s2 == 4 || s2 == 5) {
                contentSpecTree(i7, xMLContentSpec, childrenList);
                contentSpecTree(i8, xMLContentSpec, childrenList);
            } else if (s2 == 1 || s2 == 2 || s2 == 3) {
                contentSpecTree(i7, xMLContentSpec, childrenList);
            } else {
                StringBuffer a = a.a("Invalid content spec type seen in contentSpecTree() method of AbstractDTDGrammar class : ");
                a.append((int) xMLContentSpec.type);
                throw new RuntimeException(a.toString());
            }
        }
    }

    private synchronized ContentModelValidator createChildModel(int i2) {
        XMLContentSpec xMLContentSpec = new XMLContentSpec();
        getContentSpec(i2, xMLContentSpec);
        if (!((xMLContentSpec.type & 15) == 6 || (xMLContentSpec.type & 15) == 7)) {
            if ((xMLContentSpec.type & 15) != 8) {
                if (xMLContentSpec.type == 0) {
                    if (xMLContentSpec.value == null) {
                        if (xMLContentSpec.otherValue == null) {
                            throw new RuntimeException("ImplementationMessages.VAL_NPCD");
                        }
                    }
                    this.fQName.setValues(null, (String) xMLContentSpec.value, (String) xMLContentSpec.value, (String) xMLContentSpec.otherValue);
                    return new SimpleContentModel(xMLContentSpec.type, this.fQName, null);
                } else if (xMLContentSpec.type == 4 || xMLContentSpec.type == 5) {
                    XMLContentSpec xMLContentSpec2 = new XMLContentSpec();
                    XMLContentSpec xMLContentSpec3 = new XMLContentSpec();
                    getContentSpec(((int[]) xMLContentSpec.value)[0], xMLContentSpec2);
                    getContentSpec(((int[]) xMLContentSpec.otherValue)[0], xMLContentSpec3);
                    if (xMLContentSpec2.type == 0 && xMLContentSpec3.type == 0) {
                        this.fQName.setValues(null, (String) xMLContentSpec2.value, (String) xMLContentSpec2.value, (String) xMLContentSpec2.otherValue);
                        this.fQName2.setValues(null, (String) xMLContentSpec3.value, (String) xMLContentSpec3.value, (String) xMLContentSpec3.otherValue);
                        return new SimpleContentModel(xMLContentSpec.type, this.fQName, this.fQName2);
                    }
                } else if (xMLContentSpec.type == 1 || xMLContentSpec.type == 2 || xMLContentSpec.type == 3) {
                    XMLContentSpec xMLContentSpec4 = new XMLContentSpec();
                    getContentSpec(((int[]) xMLContentSpec.value)[0], xMLContentSpec4);
                    if (xMLContentSpec4.type == 0) {
                        this.fQName.setValues(null, (String) xMLContentSpec4.value, (String) xMLContentSpec4.value, (String) xMLContentSpec4.otherValue);
                        return new SimpleContentModel(xMLContentSpec.type, this.fQName, null);
                    }
                } else {
                    throw new RuntimeException("ImplementationMessages.VAL_CST");
                }
            }
        }
        this.fLeafCount = 0;
        this.fLeafCount = 0;
        return new DFAContentModel(buildSyntaxTree(i2, xMLContentSpec), this.fLeafCount, false);
    }

    private void ensureAttributeDeclCapacity(int i2) {
        QName[][] qNameArr = this.fAttributeDeclName;
        if (i2 >= qNameArr.length) {
            int[][] iArr = this.fAttributeDeclIsExternal;
            this.fAttributeDeclIsExternal = resize(iArr, iArr.length * 2);
            QName[][] qNameArr2 = this.fAttributeDeclName;
            this.fAttributeDeclName = resize(qNameArr2, qNameArr2.length * 2);
            short[][] sArr = this.fAttributeDeclType;
            this.fAttributeDeclType = resize(sArr, sArr.length * 2);
            String[][][] strArr = this.fAttributeDeclEnumeration;
            this.fAttributeDeclEnumeration = resize(strArr, strArr.length * 2);
            short[][] sArr2 = this.fAttributeDeclDefaultType;
            this.fAttributeDeclDefaultType = resize(sArr2, sArr2.length * 2);
            DatatypeValidator[][] datatypeValidatorArr = this.fAttributeDeclDatatypeValidator;
            this.fAttributeDeclDatatypeValidator = resize(datatypeValidatorArr, datatypeValidatorArr.length * 2);
            String[][] strArr2 = this.fAttributeDeclDefaultValue;
            this.fAttributeDeclDefaultValue = resize(strArr2, strArr2.length * 2);
            String[][] strArr3 = this.fAttributeDeclNonNormalizedDefaultValue;
            this.fAttributeDeclNonNormalizedDefaultValue = resize(strArr3, strArr3.length * 2);
            int[][] iArr2 = this.fAttributeDeclNextAttributeDeclIndex;
            this.fAttributeDeclNextAttributeDeclIndex = resize(iArr2, iArr2.length * 2);
        } else if (qNameArr[i2] != null) {
            return;
        }
        this.fAttributeDeclIsExternal[i2] = new int[256];
        this.fAttributeDeclName[i2] = new QName[256];
        this.fAttributeDeclType[i2] = new short[256];
        this.fAttributeDeclEnumeration[i2] = new String[256][];
        this.fAttributeDeclDefaultType[i2] = new short[256];
        this.fAttributeDeclDatatypeValidator[i2] = new DatatypeValidator[256];
        this.fAttributeDeclDefaultValue[i2] = new String[256];
        this.fAttributeDeclNonNormalizedDefaultValue[i2] = new String[256];
        this.fAttributeDeclNextAttributeDeclIndex[i2] = new int[256];
    }

    private void ensureContentSpecCapacity(int i2) {
        short[][] sArr = this.fContentSpecType;
        if (i2 >= sArr.length) {
            this.fContentSpecType = resize(sArr, sArr.length * 2);
            Object[][] objArr = this.fContentSpecValue;
            this.fContentSpecValue = resize(objArr, objArr.length * 2);
            Object[][] objArr2 = this.fContentSpecOtherValue;
            this.fContentSpecOtherValue = resize(objArr2, objArr2.length * 2);
        } else if (sArr[i2] != null) {
            return;
        }
        this.fContentSpecType[i2] = new short[256];
        this.fContentSpecValue[i2] = new Object[256];
        this.fContentSpecOtherValue[i2] = new Object[256];
    }

    private void ensureElementDeclCapacity(int i2) {
        QName[][] qNameArr = this.fElementDeclName;
        if (i2 >= qNameArr.length) {
            int[][] iArr = this.fElementDeclIsExternal;
            this.fElementDeclIsExternal = resize(iArr, iArr.length * 2);
            QName[][] qNameArr2 = this.fElementDeclName;
            this.fElementDeclName = resize(qNameArr2, qNameArr2.length * 2);
            short[][] sArr = this.fElementDeclType;
            this.fElementDeclType = resize(sArr, sArr.length * 2);
            ContentModelValidator[][] contentModelValidatorArr = this.fElementDeclContentModelValidator;
            this.fElementDeclContentModelValidator = resize(contentModelValidatorArr, contentModelValidatorArr.length * 2);
            int[][] iArr2 = this.fElementDeclContentSpecIndex;
            this.fElementDeclContentSpecIndex = resize(iArr2, iArr2.length * 2);
            int[][] iArr3 = this.fElementDeclFirstAttributeDeclIndex;
            this.fElementDeclFirstAttributeDeclIndex = resize(iArr3, iArr3.length * 2);
            int[][] iArr4 = this.fElementDeclLastAttributeDeclIndex;
            this.fElementDeclLastAttributeDeclIndex = resize(iArr4, iArr4.length * 2);
        } else if (qNameArr[i2] != null) {
            return;
        }
        this.fElementDeclIsExternal[i2] = new int[256];
        this.fElementDeclName[i2] = new QName[256];
        this.fElementDeclType[i2] = new short[256];
        this.fElementDeclContentModelValidator[i2] = new ContentModelValidator[256];
        this.fElementDeclContentSpecIndex[i2] = new int[256];
        this.fElementDeclFirstAttributeDeclIndex[i2] = new int[256];
        this.fElementDeclLastAttributeDeclIndex[i2] = new int[256];
    }

    private void ensureEntityDeclCapacity(int i2) {
        String[][] strArr = this.fEntityName;
        if (i2 >= strArr.length) {
            this.fEntityName = resize(strArr, strArr.length * 2);
            String[][] strArr2 = this.fEntityValue;
            this.fEntityValue = resize(strArr2, strArr2.length * 2);
            String[][] strArr3 = this.fEntityPublicId;
            this.fEntityPublicId = resize(strArr3, strArr3.length * 2);
            String[][] strArr4 = this.fEntitySystemId;
            this.fEntitySystemId = resize(strArr4, strArr4.length * 2);
            String[][] strArr5 = this.fEntityBaseSystemId;
            this.fEntityBaseSystemId = resize(strArr5, strArr5.length * 2);
            String[][] strArr6 = this.fEntityNotation;
            this.fEntityNotation = resize(strArr6, strArr6.length * 2);
            byte[][] bArr = this.fEntityIsPE;
            this.fEntityIsPE = resize(bArr, bArr.length * 2);
            byte[][] bArr2 = this.fEntityInExternal;
            this.fEntityInExternal = resize(bArr2, bArr2.length * 2);
        } else if (strArr[i2] != null) {
            return;
        }
        this.fEntityName[i2] = new String[256];
        this.fEntityValue[i2] = new String[256];
        this.fEntityPublicId[i2] = new String[256];
        this.fEntitySystemId[i2] = new String[256];
        this.fEntityBaseSystemId[i2] = new String[256];
        this.fEntityNotation[i2] = new String[256];
        this.fEntityIsPE[i2] = new byte[256];
        this.fEntityInExternal[i2] = new byte[256];
    }

    private void ensureNotationDeclCapacity(int i2) {
        String[][] strArr = this.fNotationName;
        if (i2 >= strArr.length) {
            this.fNotationName = resize(strArr, strArr.length * 2);
            String[][] strArr2 = this.fNotationPublicId;
            this.fNotationPublicId = resize(strArr2, strArr2.length * 2);
            String[][] strArr3 = this.fNotationSystemId;
            this.fNotationSystemId = resize(strArr3, strArr3.length * 2);
            String[][] strArr4 = this.fNotationBaseSystemId;
            this.fNotationBaseSystemId = resize(strArr4, strArr4.length * 2);
        } else if (strArr[i2] != null) {
            return;
        }
        this.fNotationName[i2] = new String[256];
        this.fNotationPublicId[i2] = new String[256];
        this.fNotationSystemId[i2] = new String[256];
        this.fNotationBaseSystemId[i2] = new String[256];
    }

    private void printAttribute(int i2) {
        XMLAttributeDecl xMLAttributeDecl = new XMLAttributeDecl();
        if (getAttributeDecl(i2, xMLAttributeDecl)) {
            System.out.print(" { ");
            System.out.print(xMLAttributeDecl.name.localpart);
            System.out.print(" }");
        }
    }

    public static byte[][] resize(byte[][] bArr, int i2) {
        byte[][] bArr2 = new byte[i2][];
        System.arraycopy(bArr, 0, bArr2, 0, bArr.length);
        return bArr2;
    }

    public static int[][] resize(int[][] iArr, int i2) {
        int[][] iArr2 = new int[i2][];
        System.arraycopy(iArr, 0, iArr2, 0, iArr.length);
        return iArr2;
    }

    public static Object[][] resize(Object[][] objArr, int i2) {
        Object[][] objArr2 = new Object[i2][];
        System.arraycopy(objArr, 0, objArr2, 0, objArr.length);
        return objArr2;
    }

    public static String[][] resize(String[][] strArr, int i2) {
        String[][] strArr2 = new String[i2][];
        System.arraycopy(strArr, 0, strArr2, 0, strArr.length);
        return strArr2;
    }

    public static ContentModelValidator[][] resize(ContentModelValidator[][] contentModelValidatorArr, int i2) {
        ContentModelValidator[][] contentModelValidatorArr2 = new ContentModelValidator[i2][];
        System.arraycopy(contentModelValidatorArr, 0, contentModelValidatorArr2, 0, contentModelValidatorArr.length);
        return contentModelValidatorArr2;
    }

    public static DatatypeValidator[][] resize(DatatypeValidator[][] datatypeValidatorArr, int i2) {
        DatatypeValidator[][] datatypeValidatorArr2 = new DatatypeValidator[i2][];
        System.arraycopy(datatypeValidatorArr, 0, datatypeValidatorArr2, 0, datatypeValidatorArr.length);
        return datatypeValidatorArr2;
    }

    public static QName[][] resize(QName[][] qNameArr, int i2) {
        QName[][] qNameArr2 = new QName[i2][];
        System.arraycopy(qNameArr, 0, qNameArr2, 0, qNameArr.length);
        return qNameArr2;
    }

    public static short[][] resize(short[][] sArr, int i2) {
        short[][] sArr2 = new short[i2][];
        System.arraycopy(sArr, 0, sArr2, 0, sArr.length);
        return sArr2;
    }

    public static String[][][] resize(String[][][] strArr, int i2) {
        String[][][] strArr2 = new String[i2][][];
        System.arraycopy(strArr, 0, strArr2, 0, strArr.length);
        return strArr2;
    }

    public int addContentSpecNode(short s, int i2, int i3) {
        int createContentSpec = createContentSpec();
        this.fContentSpec.setValues(s, new int[]{i2}, new int[]{i3});
        setContentSpec(createContentSpec, this.fContentSpec);
        return createContentSpec;
    }

    public int addContentSpecNode(short s, String str) {
        int createContentSpec = createContentSpec();
        this.fContentSpec.setValues(s, str, null);
        setContentSpec(createContentSpec, this.fContentSpec);
        return createContentSpec;
    }

    public void addContentSpecToElement(XMLElementDecl xMLElementDecl) {
        int i2 = this.fDepth;
        if ((i2 == 0 || (i2 == 1 && xMLElementDecl.type == 2)) && this.fNodeIndexStack != null) {
            if (xMLElementDecl.type == 2) {
                int addUniqueLeafNode = addUniqueLeafNode(null);
                int[] iArr = this.fNodeIndexStack;
                if (iArr[0] == -1) {
                    iArr[0] = addUniqueLeafNode;
                } else {
                    iArr[0] = addContentSpecNode(4, addUniqueLeafNode, iArr[0]);
                }
            }
            setContentSpecIndex(this.fCurrentElementIndex, this.fNodeIndexStack[this.fDepth]);
        }
    }

    public int addUniqueLeafNode(String str) {
        int createContentSpec = createContentSpec();
        this.fContentSpec.setValues(0, str, null);
        setContentSpec(createContentSpec, this.fContentSpec);
        return createContentSpec;
    }

    @Override // org.apache.xerces.xni.XMLDTDContentModelHandler
    public void any(Augmentations augmentations) {
    }

    @Override // org.apache.xerces.xni.XMLDTDHandler
    public void attributeDecl(String str, String str2, String str3, String[] strArr, String str4, XMLString xMLString, XMLString xMLString2, Augmentations augmentations) {
        XMLSimpleType xMLSimpleType;
        XMLSimpleType xMLSimpleType2;
        short s;
        if (!this.fElementDeclTab.containsKey(str)) {
            this.fCurrentElementIndex = createElementDecl();
            XMLElementDecl xMLElementDecl = new XMLElementDecl();
            xMLElementDecl.name.setValues(null, str, str, null);
            xMLElementDecl.scope = -1;
            this.fElementDeclTab.put(str, xMLElementDecl);
            setElementDecl(this.fCurrentElementIndex, xMLElementDecl);
        }
        int elementDeclIndex = getElementDeclIndex(str);
        if (getAttributeDeclIndex(elementDeclIndex, str2) == -1) {
            this.fCurrentAttributeIndex = createAttributeDecl();
            this.fSimpleType.clear();
            int i2 = 0;
            if (str4 != null) {
                if (str4.equals("#FIXED")) {
                    this.fSimpleType.defaultType = 1;
                } else if (str4.equals("#IMPLIED")) {
                    this.fSimpleType.defaultType = 0;
                } else if (str4.equals("#REQUIRED")) {
                    this.fSimpleType.defaultType = 2;
                }
            }
            this.fSimpleType.defaultValue = xMLString != null ? xMLString.toString() : null;
            this.fSimpleType.nonNormalizedDefaultValue = xMLString2 != null ? xMLString2.toString() : null;
            this.fSimpleType.enumeration = strArr;
            if (str3.equals("CDATA")) {
                this.fSimpleType.type = 0;
            } else {
                if (str3.equals(SchemaSymbols.ATTVAL_ID)) {
                    xMLSimpleType2 = this.fSimpleType;
                    s = 3;
                } else {
                    if (str3.startsWith(SchemaSymbols.ATTVAL_IDREF)) {
                        this.fSimpleType.type = 4;
                        if (str3.indexOf("S") > 0) {
                            xMLSimpleType = this.fSimpleType;
                        }
                    } else if (str3.equals(SchemaSymbols.ATTVAL_ENTITIES)) {
                        xMLSimpleType = this.fSimpleType;
                        xMLSimpleType.type = 1;
                    } else if (str3.equals(SchemaSymbols.ATTVAL_ENTITY)) {
                        this.fSimpleType.type = 1;
                    } else if (str3.equals(SchemaSymbols.ATTVAL_NMTOKENS)) {
                        xMLSimpleType = this.fSimpleType;
                        xMLSimpleType.type = 5;
                    } else if (str3.equals("NMTOKEN")) {
                        this.fSimpleType.type = 5;
                    } else if (str3.startsWith(SchemaSymbols.ATTVAL_NOTATION)) {
                        xMLSimpleType2 = this.fSimpleType;
                        s = 6;
                    } else if (str3.startsWith("ENUMERATION")) {
                        this.fSimpleType.type = 2;
                    } else {
                        PrintStream printStream = System.err;
                        StringBuffer stringBuffer = new StringBuffer();
                        stringBuffer.append("!!! unknown attribute type ");
                        stringBuffer.append(str3);
                        printStream.println(stringBuffer.toString());
                    }
                    xMLSimpleType.list = true;
                }
                xMLSimpleType2.type = s;
            }
            this.fQName.setValues(null, str2, str2, null);
            this.fAttributeDecl.setValues(this.fQName, this.fSimpleType, false);
            setAttributeDecl(elementDeclIndex, this.fCurrentAttributeIndex, this.fAttributeDecl);
            int i3 = this.fCurrentAttributeIndex;
            int i4 = i3 >> 8;
            int i5 = i3 & 255;
            ensureAttributeDeclCapacity(i4);
            int[] iArr = this.fAttributeDeclIsExternal[i4];
            if (this.fReadingExternalDTD || this.fPEDepth > 0) {
                i2 = 1;
            }
            iArr[i5] = i2;
        }
    }

    @Override // org.apache.xerces.xni.XMLDTDHandler
    public void comment(XMLString xMLString, Augmentations augmentations) {
    }

    public int createAttributeDecl() {
        int i2 = this.fAttributeDeclCount;
        int i3 = i2 >> 8;
        int i4 = i2 & 255;
        ensureAttributeDeclCapacity(i3);
        this.fAttributeDeclName[i3][i4] = new QName();
        this.fAttributeDeclType[i3][i4] = -1;
        this.fAttributeDeclDatatypeValidator[i3][i4] = null;
        this.fAttributeDeclEnumeration[i3][i4] = null;
        this.fAttributeDeclDefaultType[i3][i4] = 0;
        this.fAttributeDeclDefaultValue[i3][i4] = null;
        this.fAttributeDeclNonNormalizedDefaultValue[i3][i4] = null;
        this.fAttributeDeclNextAttributeDeclIndex[i3][i4] = -1;
        int i5 = this.fAttributeDeclCount;
        this.fAttributeDeclCount = i5 + 1;
        return i5;
    }

    public int createContentSpec() {
        int i2 = this.fContentSpecCount;
        int i3 = i2 >> 8;
        int i4 = i2 & 255;
        ensureContentSpecCapacity(i3);
        this.fContentSpecType[i3][i4] = -1;
        this.fContentSpecValue[i3][i4] = null;
        this.fContentSpecOtherValue[i3][i4] = null;
        int i5 = this.fContentSpecCount;
        this.fContentSpecCount = i5 + 1;
        return i5;
    }

    public int createElementDecl() {
        int i2 = this.fElementDeclCount;
        int i3 = i2 >> 8;
        int i4 = i2 & 255;
        ensureElementDeclCapacity(i3);
        this.fElementDeclName[i3][i4] = new QName();
        this.fElementDeclType[i3][i4] = -1;
        this.fElementDeclContentModelValidator[i3][i4] = null;
        this.fElementDeclFirstAttributeDeclIndex[i3][i4] = -1;
        this.fElementDeclLastAttributeDeclIndex[i3][i4] = -1;
        int i5 = this.fElementDeclCount;
        this.fElementDeclCount = i5 + 1;
        return i5;
    }

    public int createEntityDecl() {
        int i2 = this.fEntityCount;
        int i3 = i2 >> 8;
        int i4 = i2 & 255;
        ensureEntityDeclCapacity(i3);
        this.fEntityIsPE[i3][i4] = 0;
        this.fEntityInExternal[i3][i4] = 0;
        int i5 = this.fEntityCount;
        this.fEntityCount = i5 + 1;
        return i5;
    }

    public int createNotationDecl() {
        ensureNotationDeclCapacity(this.fNotationCount >> 8);
        int i2 = this.fNotationCount;
        this.fNotationCount = i2 + 1;
        return i2;
    }

    @Override // org.apache.xerces.xni.XMLDTDContentModelHandler
    public void element(String str, Augmentations augmentations) {
        if (this.fMixed) {
            int[] iArr = this.fNodeIndexStack;
            int i2 = this.fDepth;
            if (iArr[i2] == -1) {
                iArr[i2] = addUniqueLeafNode(str);
            } else {
                iArr[i2] = addContentSpecNode(4, iArr[i2], addUniqueLeafNode(str));
            }
        } else {
            this.fNodeIndexStack[this.fDepth] = addContentSpecNode(0, str);
        }
    }

    @Override // org.apache.xerces.xni.XMLDTDHandler
    public void elementDecl(String str, String str2, Augmentations augmentations) {
        int i2;
        XMLElementDecl xMLElementDecl = (XMLElementDecl) this.fElementDeclTab.get(str);
        if (xMLElementDecl == null) {
            i2 = createElementDecl();
        } else if (xMLElementDecl.type == -1) {
            i2 = getElementDeclIndex(str);
        } else {
            return;
        }
        this.fCurrentElementIndex = i2;
        XMLElementDecl xMLElementDecl2 = new XMLElementDecl();
        this.fQName.setValues(null, str, str, null);
        xMLElementDecl2.name.setValues(this.fQName);
        xMLElementDecl2.contentModelValidator = null;
        xMLElementDecl2.scope = -1;
        int i3 = 0;
        if (str2.equals("EMPTY")) {
            xMLElementDecl2.type = 1;
        } else if (str2.equals("ANY")) {
            xMLElementDecl2.type = 0;
        } else if (str2.startsWith("(")) {
            xMLElementDecl2.type = str2.indexOf("#PCDATA") > 0 ? (short) 2 : 3;
        }
        this.fElementDeclTab.put(str, xMLElementDecl2);
        this.fElementDecl = xMLElementDecl2;
        addContentSpecToElement(xMLElementDecl2);
        setElementDecl(this.fCurrentElementIndex, this.fElementDecl);
        int i4 = this.fCurrentElementIndex;
        int i5 = i4 >> 8;
        int i6 = i4 & 255;
        ensureElementDeclCapacity(i5);
        int[] iArr = this.fElementDeclIsExternal[i5];
        if (this.fReadingExternalDTD || this.fPEDepth > 0) {
            i3 = 1;
        }
        iArr[i6] = i3;
    }

    @Override // org.apache.xerces.xni.XMLDTDContentModelHandler
    public void empty(Augmentations augmentations) {
    }

    @Override // org.apache.xerces.xni.XMLDTDHandler
    public void endAttlist(Augmentations augmentations) {
    }

    @Override // org.apache.xerces.xni.XMLDTDHandler
    public void endConditional(Augmentations augmentations) {
    }

    @Override // org.apache.xerces.xni.XMLDTDContentModelHandler
    public void endContentModel(Augmentations augmentations) {
    }

    @Override // org.apache.xerces.xni.XMLDTDHandler
    public void endDTD(Augmentations augmentations) {
        this.fIsImmutable = true;
        if (this.fGrammarDescription.getRootName() == null) {
            int i2 = this.fElementDeclCount;
            ArrayList arrayList = new ArrayList(i2);
            for (int i3 = 0; i3 < i2; i3++) {
                arrayList.add(this.fElementDeclName[i3 >> 8][i3 & 255].rawname);
            }
            this.fGrammarDescription.setPossibleRoots(arrayList);
        }
    }

    @Override // org.apache.xerces.xni.XMLDTDHandler
    public void endExternalSubset(Augmentations augmentations) {
        this.fReadingExternalDTD = false;
    }

    @Override // org.apache.xerces.xni.XMLDTDContentModelHandler
    public void endGroup(Augmentations augmentations) {
        if (!this.fMixed) {
            int[] iArr = this.fPrevNodeIndexStack;
            int i2 = this.fDepth;
            if (iArr[i2] != -1) {
                int[] iArr2 = this.fNodeIndexStack;
                iArr2[i2] = addContentSpecNode(this.fOpStack[i2], iArr[i2], iArr2[i2]);
            }
            int[] iArr3 = this.fNodeIndexStack;
            int i3 = this.fDepth;
            int i4 = i3 - 1;
            this.fDepth = i4;
            iArr3[i4] = iArr3[i3];
        }
    }

    @Override // org.apache.xerces.xni.XMLDTDHandler
    public void endParameterEntity(String str, Augmentations augmentations) {
        int i2 = this.fPEDepth - 1;
        this.fPEDepth = i2;
        this.fReadingExternalDTD = this.fPEntityStack[i2];
    }

    @Override // org.apache.xerces.xni.XMLDTDHandler
    public void externalEntityDecl(String str, XMLResourceIdentifier xMLResourceIdentifier, Augmentations augmentations) {
        if (getEntityDeclIndex(str) == -1) {
            int createEntityDecl = createEntityDecl();
            boolean startsWith = str.startsWith(PercentPtg.PERCENT);
            boolean z = this.fReadingExternalDTD || this.fPEDepth > 0;
            XMLEntityDecl xMLEntityDecl = new XMLEntityDecl();
            xMLEntityDecl.setValues(str, xMLResourceIdentifier.getPublicId(), xMLResourceIdentifier.getLiteralSystemId(), xMLResourceIdentifier.getBaseSystemId(), null, null, startsWith, z);
            setEntityDecl(createEntityDecl, xMLEntityDecl);
        }
    }

    public boolean getAttributeDecl(int i2, XMLAttributeDecl xMLAttributeDecl) {
        boolean z;
        short s;
        boolean z2 = false;
        if (i2 < 0 || i2 >= this.fAttributeDeclCount) {
            return false;
        }
        int i3 = i2 >> 8;
        int i4 = i2 & 255;
        xMLAttributeDecl.name.setValues(this.fAttributeDeclName[i3][i4]);
        short[][] sArr = this.fAttributeDeclType;
        if (sArr[i3][i4] == -1) {
            s = -1;
            z = false;
        } else {
            short s2 = (short) (sArr[i3][i4] & LIST_MASK);
            if ((sArr[i3][i4] & 128) != 0) {
                z2 = true;
            }
            z = z2;
            s = s2;
        }
        xMLAttributeDecl.simpleType.setValues(s, this.fAttributeDeclName[i3][i4].localpart, this.fAttributeDeclEnumeration[i3][i4], z, this.fAttributeDeclDefaultType[i3][i4], this.fAttributeDeclDefaultValue[i3][i4], this.fAttributeDeclNonNormalizedDefaultValue[i3][i4], this.fAttributeDeclDatatypeValidator[i3][i4]);
        return true;
    }

    public int getAttributeDeclIndex(int i2, String str) {
        if (i2 == -1) {
            return -1;
        }
        int firstAttributeDeclIndex = getFirstAttributeDeclIndex(i2);
        while (firstAttributeDeclIndex != -1) {
            getAttributeDecl(firstAttributeDeclIndex, this.fAttributeDecl);
            String str2 = this.fAttributeDecl.name.rawname;
            if (str2 == str || str.equals(str2)) {
                return firstAttributeDeclIndex;
            }
            firstAttributeDeclIndex = getNextAttributeDeclIndex(firstAttributeDeclIndex);
        }
        return -1;
    }

    public boolean getAttributeDeclIsExternal(int i2) {
        if (i2 < 0) {
            return false;
        }
        return this.fAttributeDeclIsExternal[i2 >> 8][i2 & 255] != 0;
    }

    public boolean getContentSpec(int i2, XMLContentSpec xMLContentSpec) {
        if (i2 < 0 || i2 >= this.fContentSpecCount) {
            return false;
        }
        int i3 = i2 >> 8;
        int i4 = i2 & 255;
        xMLContentSpec.type = this.fContentSpecType[i3][i4];
        xMLContentSpec.value = this.fContentSpecValue[i3][i4];
        xMLContentSpec.otherValue = this.fContentSpecOtherValue[i3][i4];
        return true;
    }

    public String getContentSpecAsString(int i2) {
        char c;
        Object obj;
        String str;
        String str2;
        if (i2 >= 0 && i2 < this.fElementDeclCount) {
            int i3 = this.fElementDeclContentSpecIndex[i2 >> 8][i2 & 255];
            XMLContentSpec xMLContentSpec = new XMLContentSpec();
            if (getContentSpec(i3, xMLContentSpec)) {
                StringBuffer stringBuffer = new StringBuffer();
                int i4 = xMLContentSpec.type & 15;
                switch (i4) {
                    case 0:
                        stringBuffer.append('(');
                        if (xMLContentSpec.value == null && xMLContentSpec.otherValue == null) {
                            stringBuffer.append("#PCDATA");
                        } else {
                            stringBuffer.append(xMLContentSpec.value);
                        }
                        stringBuffer.append(')');
                        break;
                    case 1:
                        getContentSpec(((int[]) xMLContentSpec.value)[0], xMLContentSpec);
                        short s = xMLContentSpec.type;
                        if (s != 0) {
                            if (s != 3 && s != 2 && s != 1) {
                                appendContentSpec(xMLContentSpec, stringBuffer, true, i4);
                                c = LittleEndianCP950Reader.UNMAPPABLE;
                                stringBuffer.append(c);
                                break;
                            } else {
                                stringBuffer.append('(');
                                appendContentSpec(xMLContentSpec, stringBuffer, true, i4);
                            }
                        } else {
                            stringBuffer.append('(');
                            stringBuffer.append(xMLContentSpec.value);
                        }
                        stringBuffer.append(')');
                        c = LittleEndianCP950Reader.UNMAPPABLE;
                        stringBuffer.append(c);
                    case 2:
                        getContentSpec(((int[]) xMLContentSpec.value)[0], xMLContentSpec);
                        short s2 = xMLContentSpec.type;
                        if (s2 == 0) {
                            stringBuffer.append('(');
                            if (xMLContentSpec.value != null || xMLContentSpec.otherValue != null) {
                                if (xMLContentSpec.otherValue != null) {
                                    stringBuffer.append("##any:uri=");
                                    stringBuffer.append(xMLContentSpec.otherValue);
                                } else if (xMLContentSpec.value == null) {
                                    stringBuffer.append(SchemaSymbols.ATTVAL_TWOPOUNDANY);
                                }
                                stringBuffer.append(')');
                                c = '*';
                                stringBuffer.append(c);
                                break;
                            } else {
                                stringBuffer.append("#PCDATA");
                                stringBuffer.append(')');
                                c = '*';
                                stringBuffer.append(c);
                            }
                        } else if (s2 == 3 || s2 == 2 || s2 == 1) {
                            stringBuffer.append('(');
                        } else {
                            appendContentSpec(xMLContentSpec, stringBuffer, true, i4);
                            c = '*';
                            stringBuffer.append(c);
                        }
                        appendContentSpec(xMLContentSpec, stringBuffer, true, i4);
                        stringBuffer.append(')');
                        c = '*';
                        stringBuffer.append(c);
                        break;
                    case 3:
                        getContentSpec(((int[]) xMLContentSpec.value)[0], xMLContentSpec);
                        short s3 = xMLContentSpec.type;
                        if (s3 != 0) {
                            if (s3 != 3 && s3 != 2 && s3 != 1) {
                                appendContentSpec(xMLContentSpec, stringBuffer, true, i4);
                                c = '+';
                                stringBuffer.append(c);
                                break;
                            } else {
                                stringBuffer.append('(');
                                appendContentSpec(xMLContentSpec, stringBuffer, true, i4);
                            }
                        } else {
                            stringBuffer.append('(');
                            if (xMLContentSpec.value == null && xMLContentSpec.otherValue == null) {
                                stringBuffer.append("#PCDATA");
                            } else {
                                if (xMLContentSpec.otherValue != null) {
                                    stringBuffer.append("##any:uri=");
                                    obj = xMLContentSpec.otherValue;
                                } else {
                                    obj = xMLContentSpec.value;
                                    if (obj == null) {
                                        stringBuffer.append(SchemaSymbols.ATTVAL_TWOPOUNDANY);
                                    }
                                }
                                stringBuffer.append(obj);
                            }
                        }
                        stringBuffer.append(')');
                        c = '+';
                        stringBuffer.append(c);
                        break;
                    case 4:
                    case 5:
                        appendContentSpec(xMLContentSpec, stringBuffer, true, i4);
                        break;
                    case 6:
                        stringBuffer.append(SchemaSymbols.ATTVAL_TWOPOUNDANY);
                        if (xMLContentSpec.otherValue != null) {
                            str = ":uri=";
                            stringBuffer.append(str);
                            stringBuffer.append(xMLContentSpec.otherValue);
                            break;
                        }
                        break;
                    case 7:
                        str = "##other:uri=";
                        stringBuffer.append(str);
                        stringBuffer.append(xMLContentSpec.otherValue);
                        break;
                    case 8:
                        str2 = SchemaSymbols.ATTVAL_TWOPOUNDLOCAL;
                        stringBuffer.append(str2);
                        break;
                    default:
                        str2 = "???";
                        stringBuffer.append(str2);
                        break;
                }
                return stringBuffer.toString();
            }
        }
        return null;
    }

    public int getContentSpecIndex(int i2) {
        if (i2 < 0 || i2 >= this.fElementDeclCount) {
            return -1;
        }
        return this.fElementDeclContentSpecIndex[i2 >> 8][i2 & 255];
    }

    public short getContentSpecType(int i2) {
        if (i2 < 0 || i2 >= this.fElementDeclCount) {
            return -1;
        }
        int i3 = i2 >> 8;
        int i4 = i2 & 255;
        short[][] sArr = this.fElementDeclType;
        if (sArr[i3][i4] == -1) {
            return -1;
        }
        return (short) (sArr[i3][i4] & LIST_MASK);
    }

    @Override // org.apache.xerces.xni.XMLDTDContentModelHandler
    public XMLDTDContentModelSource getDTDContentModelSource() {
        return this.fDTDContentModelSource;
    }

    @Override // org.apache.xerces.xni.XMLDTDHandler
    public XMLDTDSource getDTDSource() {
        return this.fDTDSource;
    }

    public ContentModelValidator getElementContentModelValidator(int i2) {
        ContentModelValidator contentModelValidator;
        int i3 = i2 >> 8;
        int i4 = i2 & 255;
        ContentModelValidator contentModelValidator2 = this.fElementDeclContentModelValidator[i3][i4];
        if (contentModelValidator2 != null) {
            return contentModelValidator2;
        }
        short s = this.fElementDeclType[i3][i4];
        if (s == 4) {
            return null;
        }
        int i5 = this.fElementDeclContentSpecIndex[i3][i4];
        XMLContentSpec xMLContentSpec = new XMLContentSpec();
        getContentSpec(i5, xMLContentSpec);
        if (s == 2) {
            ChildrenList childrenList = new ChildrenList();
            contentSpecTree(i5, xMLContentSpec, childrenList);
            contentModelValidator = new MixedContentModel(childrenList.qname, childrenList.type, 0, childrenList.length, false);
        } else if (s == 3) {
            contentModelValidator = createChildModel(i5);
        } else {
            throw new RuntimeException("Unknown content type for a element decl in getElementContentModelValidator() in AbstractDTDGrammar class");
        }
        this.fElementDeclContentModelValidator[i3][i4] = contentModelValidator;
        return contentModelValidator;
    }

    public boolean getElementDecl(int i2, XMLElementDecl xMLElementDecl) {
        boolean z = false;
        if (i2 < 0 || i2 >= this.fElementDeclCount) {
            return false;
        }
        int i3 = i2 >> 8;
        int i4 = i2 & 255;
        xMLElementDecl.name.setValues(this.fElementDeclName[i3][i4]);
        short[][] sArr = this.fElementDeclType;
        if (sArr[i3][i4] == -1) {
            xMLElementDecl.type = -1;
            xMLElementDecl.simpleType.list = false;
        } else {
            xMLElementDecl.type = (short) (sArr[i3][i4] & LIST_MASK);
            XMLSimpleType xMLSimpleType = xMLElementDecl.simpleType;
            if ((sArr[i3][i4] & 128) != 0) {
                z = true;
            }
            xMLSimpleType.list = z;
        }
        short s = xMLElementDecl.type;
        if (s == 3 || s == 2) {
            xMLElementDecl.contentModelValidator = getElementContentModelValidator(i2);
        }
        XMLSimpleType xMLSimpleType2 = xMLElementDecl.simpleType;
        xMLSimpleType2.datatypeValidator = null;
        xMLSimpleType2.defaultType = -1;
        xMLSimpleType2.defaultValue = null;
        return true;
    }

    public int getElementDeclIndex(String str) {
        return this.fElementIndexMap.get(str);
    }

    public int getElementDeclIndex(QName qName) {
        return getElementDeclIndex(qName.rawname);
    }

    public boolean getElementDeclIsExternal(int i2) {
        if (i2 < 0) {
            return false;
        }
        return this.fElementDeclIsExternal[i2 >> 8][i2 & 255] != 0;
    }

    public QName getElementDeclName(int i2) {
        if (i2 < 0 || i2 >= this.fElementDeclCount) {
            return null;
        }
        return this.fElementDeclName[i2 >> 8][i2 & 255];
    }

    public boolean getEntityDecl(int i2, XMLEntityDecl xMLEntityDecl) {
        if (i2 < 0 || i2 >= this.fEntityCount) {
            return false;
        }
        int i3 = i2 >> 8;
        int i4 = i2 & 255;
        xMLEntityDecl.setValues(this.fEntityName[i3][i4], this.fEntityPublicId[i3][i4], this.fEntitySystemId[i3][i4], this.fEntityBaseSystemId[i3][i4], this.fEntityNotation[i3][i4], this.fEntityValue[i3][i4], this.fEntityIsPE[i3][i4] != 0, this.fEntityInExternal[i3][i4] != 0);
        return true;
    }

    public int getEntityDeclIndex(String str) {
        if (str == null) {
            return -1;
        }
        return this.fEntityIndexMap.get(str);
    }

    public int getFirstAttributeDeclIndex(int i2) {
        return this.fElementDeclFirstAttributeDeclIndex[i2 >> 8][i2 & 255];
    }

    public int getFirstElementDeclIndex() {
        return this.fElementDeclCount >= 0 ? 0 : -1;
    }

    @Override // org.apache.xerces.xni.grammars.Grammar
    public XMLGrammarDescription getGrammarDescription() {
        return this.fGrammarDescription;
    }

    public int getNextAttributeDeclIndex(int i2) {
        return this.fAttributeDeclNextAttributeDeclIndex[i2 >> 8][i2 & 255];
    }

    public int getNextElementDeclIndex(int i2) {
        if (i2 < this.fElementDeclCount - 1) {
            return i2 + 1;
        }
        return -1;
    }

    public boolean getNotationDecl(int i2, XMLNotationDecl xMLNotationDecl) {
        if (i2 < 0 || i2 >= this.fNotationCount) {
            return false;
        }
        int i3 = i2 >> 8;
        int i4 = i2 & 255;
        xMLNotationDecl.setValues(this.fNotationName[i3][i4], this.fNotationPublicId[i3][i4], this.fNotationSystemId[i3][i4], this.fNotationBaseSystemId[i3][i4]);
        return true;
    }

    public int getNotationDeclIndex(String str) {
        if (str == null) {
            return -1;
        }
        return this.fNotationIndexMap.get(str);
    }

    public SymbolTable getSymbolTable() {
        return this.fSymbolTable;
    }

    @Override // org.apache.xerces.xni.XMLDTDHandler
    public void ignoredCharacters(XMLString xMLString, Augmentations augmentations) {
    }

    public void initializeContentModelStack() {
        short[] sArr = this.fOpStack;
        if (sArr == null) {
            this.fOpStack = new short[8];
            this.fNodeIndexStack = new int[8];
            this.fPrevNodeIndexStack = new int[8];
        } else {
            int i2 = this.fDepth;
            if (i2 == sArr.length) {
                short[] sArr2 = new short[(i2 * 2)];
                System.arraycopy(sArr, 0, sArr2, 0, i2);
                this.fOpStack = sArr2;
                int i3 = this.fDepth;
                int[] iArr = new int[(i3 * 2)];
                System.arraycopy(this.fNodeIndexStack, 0, iArr, 0, i3);
                this.fNodeIndexStack = iArr;
                int i4 = this.fDepth;
                int[] iArr2 = new int[(i4 * 2)];
                System.arraycopy(this.fPrevNodeIndexStack, 0, iArr2, 0, i4);
                this.fPrevNodeIndexStack = iArr2;
            }
        }
        short[] sArr3 = this.fOpStack;
        int i5 = this.fDepth;
        sArr3[i5] = -1;
        this.fNodeIndexStack[i5] = -1;
        this.fPrevNodeIndexStack[i5] = -1;
    }

    @Override // org.apache.xerces.xni.XMLDTDHandler
    public void internalEntityDecl(String str, XMLString xMLString, XMLString xMLString2, Augmentations augmentations) {
        if (getEntityDeclIndex(str) == -1) {
            int createEntityDecl = createEntityDecl();
            boolean startsWith = str.startsWith(PercentPtg.PERCENT);
            boolean z = this.fReadingExternalDTD || this.fPEDepth > 0;
            XMLEntityDecl xMLEntityDecl = new XMLEntityDecl();
            xMLEntityDecl.setValues(str, null, null, null, null, xMLString.toString(), startsWith, z);
            setEntityDecl(createEntityDecl, xMLEntityDecl);
        }
    }

    public boolean isCDATAAttribute(QName qName, QName qName2) {
        return !getAttributeDecl(getElementDeclIndex(qName), this.fAttributeDecl) || this.fAttributeDecl.simpleType.type == 0;
    }

    @Override // org.apache.xerces.impl.validation.EntityState
    public boolean isEntityDeclared(String str) {
        return getEntityDeclIndex(str) != -1;
    }

    @Override // org.apache.xerces.impl.validation.EntityState
    public boolean isEntityUnparsed(String str) {
        int entityDeclIndex = getEntityDeclIndex(str);
        if (entityDeclIndex <= -1) {
            return false;
        }
        return this.fEntityNotation[entityDeclIndex >> 8][entityDeclIndex & 255] != null;
    }

    public boolean isImmutable() {
        return this.fIsImmutable;
    }

    public boolean isNamespaceAware() {
        return false;
    }

    @Override // org.apache.xerces.xni.XMLDTDHandler
    public void notationDecl(String str, XMLResourceIdentifier xMLResourceIdentifier, Augmentations augmentations) {
        XMLNotationDecl xMLNotationDecl = new XMLNotationDecl();
        xMLNotationDecl.setValues(str, xMLResourceIdentifier.getPublicId(), xMLResourceIdentifier.getLiteralSystemId(), xMLResourceIdentifier.getBaseSystemId());
        if (getNotationDeclIndex(str) == -1) {
            setNotationDecl(createNotationDecl(), xMLNotationDecl);
        }
    }

    @Override // org.apache.xerces.xni.XMLDTDContentModelHandler
    public void occurrence(short s, Augmentations augmentations) {
        if (this.fMixed) {
            return;
        }
        if (s == 2) {
            int[] iArr = this.fNodeIndexStack;
            int i2 = this.fDepth;
            iArr[i2] = addContentSpecNode(1, iArr[i2], -1);
        } else if (s == 3) {
            int[] iArr2 = this.fNodeIndexStack;
            int i3 = this.fDepth;
            iArr2[i3] = addContentSpecNode(2, iArr2[i3], -1);
        } else if (s == 4) {
            int[] iArr3 = this.fNodeIndexStack;
            int i4 = this.fDepth;
            iArr3[i4] = addContentSpecNode(3, iArr3[i4], -1);
        }
    }

    @Override // org.apache.xerces.xni.XMLDTDContentModelHandler
    public void pcdata(Augmentations augmentations) {
        this.fMixed = true;
    }

    public void printAttributes(int i2) {
        int firstAttributeDeclIndex = getFirstAttributeDeclIndex(i2);
        System.out.print(i2);
        PrintStream printStream = System.out;
        String str = " [";
        while (true) {
            printStream.print(str);
            while (firstAttributeDeclIndex != -1) {
                System.out.print(' ');
                System.out.print(firstAttributeDeclIndex);
                printAttribute(firstAttributeDeclIndex);
                firstAttributeDeclIndex = getNextAttributeDeclIndex(firstAttributeDeclIndex);
                if (firstAttributeDeclIndex != -1) {
                    printStream = System.out;
                    str = XSSFDataValidationConstraint.LIST_SEPARATOR;
                }
            }
            System.out.println(" ]");
            return;
        }
    }

    public void printElements() {
        XMLElementDecl xMLElementDecl = new XMLElementDecl();
        int i2 = 0;
        while (true) {
            int i3 = i2 + 1;
            if (getElementDecl(i2, xMLElementDecl)) {
                PrintStream printStream = System.out;
                StringBuffer a = a.a("element decl: ");
                a.append(xMLElementDecl.name);
                a.append(", ");
                a.append(xMLElementDecl.name.rawname);
                printStream.println(a.toString());
                i2 = i3;
            } else {
                return;
            }
        }
    }

    @Override // org.apache.xerces.xni.XMLDTDHandler
    public void processingInstruction(String str, XMLString xMLString, Augmentations augmentations) {
    }

    public void putElementNameMapping(QName qName, int i2, int i3) {
    }

    @Override // org.apache.xerces.xni.XMLDTDContentModelHandler
    public void separator(short s, Augmentations augmentations) {
        if (!this.fMixed) {
            short[] sArr = this.fOpStack;
            int i2 = this.fDepth;
            if (sArr[i2] == 5 || s != 0) {
                short[] sArr2 = this.fOpStack;
                int i3 = this.fDepth;
                if (sArr2[i3] != 4 && s == 1) {
                    int[] iArr = this.fPrevNodeIndexStack;
                    if (iArr[i3] != -1) {
                        int[] iArr2 = this.fNodeIndexStack;
                        iArr2[i3] = addContentSpecNode(sArr2[i3], iArr[i3], iArr2[i3]);
                    }
                    int[] iArr3 = this.fPrevNodeIndexStack;
                    int i4 = this.fDepth;
                    iArr3[i4] = this.fNodeIndexStack[i4];
                    this.fOpStack[i4] = 5;
                    return;
                }
                return;
            }
            int[] iArr4 = this.fPrevNodeIndexStack;
            if (iArr4[i2] != -1) {
                int[] iArr5 = this.fNodeIndexStack;
                iArr5[i2] = addContentSpecNode(sArr[i2], iArr4[i2], iArr5[i2]);
            }
            int[] iArr6 = this.fPrevNodeIndexStack;
            int i5 = this.fDepth;
            iArr6[i5] = this.fNodeIndexStack[i5];
            this.fOpStack[i5] = 4;
        }
    }

    public void setAttributeDecl(int i2, int i3, XMLAttributeDecl xMLAttributeDecl) {
        int i4 = i3 >> 8;
        int i5 = i3 & 255;
        this.fAttributeDeclName[i4][i5].setValues(xMLAttributeDecl.name);
        short[][] sArr = this.fAttributeDeclType;
        short[] sArr2 = sArr[i4];
        XMLSimpleType xMLSimpleType = xMLAttributeDecl.simpleType;
        sArr2[i5] = xMLSimpleType.type;
        if (xMLSimpleType.list) {
            short[] sArr3 = sArr[i4];
            sArr3[i5] = (short) (sArr3[i5] | 128);
        }
        String[][] strArr = this.fAttributeDeclEnumeration[i4];
        XMLSimpleType xMLSimpleType2 = xMLAttributeDecl.simpleType;
        strArr[i5] = xMLSimpleType2.enumeration;
        this.fAttributeDeclDefaultType[i4][i5] = xMLSimpleType2.defaultType;
        this.fAttributeDeclDatatypeValidator[i4][i5] = xMLSimpleType2.datatypeValidator;
        this.fAttributeDeclDefaultValue[i4][i5] = xMLSimpleType2.defaultValue;
        this.fAttributeDeclNonNormalizedDefaultValue[i4][i5] = xMLSimpleType2.nonNormalizedDefaultValue;
        int i6 = i2 >> 8;
        int i7 = i2 & 255;
        int i8 = this.fElementDeclFirstAttributeDeclIndex[i6][i7];
        while (i8 != -1 && i8 != i3) {
            i8 = this.fAttributeDeclNextAttributeDeclIndex[i8 >> 8][i8 & 255];
        }
        if (i8 == -1) {
            int[][] iArr = this.fElementDeclFirstAttributeDeclIndex;
            if (iArr[i6][i7] == -1) {
                iArr[i6][i7] = i3;
            } else {
                int i9 = this.fElementDeclLastAttributeDeclIndex[i6][i7];
                this.fAttributeDeclNextAttributeDeclIndex[i9 >> 8][i9 & 255] = i3;
            }
            this.fElementDeclLastAttributeDeclIndex[i6][i7] = i3;
        }
    }

    public void setContentSpec(int i2, XMLContentSpec xMLContentSpec) {
        int i3 = i2 >> 8;
        int i4 = i2 & 255;
        this.fContentSpecType[i3][i4] = xMLContentSpec.type;
        this.fContentSpecValue[i3][i4] = xMLContentSpec.value;
        this.fContentSpecOtherValue[i3][i4] = xMLContentSpec.otherValue;
    }

    public void setContentSpecIndex(int i2, int i3) {
        if (i2 >= 0 && i2 < this.fElementDeclCount) {
            this.fElementDeclContentSpecIndex[i2 >> 8][i2 & 255] = i3;
        }
    }

    @Override // org.apache.xerces.xni.XMLDTDContentModelHandler
    public void setDTDContentModelSource(XMLDTDContentModelSource xMLDTDContentModelSource) {
        this.fDTDContentModelSource = xMLDTDContentModelSource;
    }

    @Override // org.apache.xerces.xni.XMLDTDHandler
    public void setDTDSource(XMLDTDSource xMLDTDSource) {
        this.fDTDSource = xMLDTDSource;
    }

    public void setElementDecl(int i2, XMLElementDecl xMLElementDecl) {
        if (i2 >= 0 && i2 < this.fElementDeclCount) {
            int i3 = i2 >> 8;
            int i4 = i2 & 255;
            this.fElementDeclName[i3][i4].setValues(xMLElementDecl.name);
            short[][] sArr = this.fElementDeclType;
            sArr[i3][i4] = xMLElementDecl.type;
            this.fElementDeclContentModelValidator[i3][i4] = xMLElementDecl.contentModelValidator;
            if (xMLElementDecl.simpleType.list) {
                short[] sArr2 = sArr[i3];
                sArr2[i4] = (short) (sArr2[i4] | 128);
            }
            this.fElementIndexMap.put(xMLElementDecl.name.rawname, i2);
        }
    }

    public void setEntityDecl(int i2, XMLEntityDecl xMLEntityDecl) {
        int i3 = i2 >> 8;
        int i4 = i2 & 255;
        String[] strArr = this.fEntityName[i3];
        String str = xMLEntityDecl.name;
        strArr[i4] = str;
        this.fEntityValue[i3][i4] = xMLEntityDecl.value;
        this.fEntityPublicId[i3][i4] = xMLEntityDecl.publicId;
        this.fEntitySystemId[i3][i4] = xMLEntityDecl.systemId;
        this.fEntityBaseSystemId[i3][i4] = xMLEntityDecl.baseSystemId;
        this.fEntityNotation[i3][i4] = xMLEntityDecl.notation;
        this.fEntityIsPE[i3][i4] = xMLEntityDecl.isPE;
        this.fEntityInExternal[i3][i4] = xMLEntityDecl.inExternal;
        this.fEntityIndexMap.put(str, i2);
    }

    public void setFirstAttributeDeclIndex(int i2, int i3) {
        if (i2 >= 0 && i2 < this.fElementDeclCount) {
            this.fElementDeclFirstAttributeDeclIndex[i2 >> 8][i2 & 255] = i3;
        }
    }

    public void setNotationDecl(int i2, XMLNotationDecl xMLNotationDecl) {
        int i3 = i2 >> 8;
        int i4 = i2 & 255;
        String[] strArr = this.fNotationName[i3];
        String str = xMLNotationDecl.name;
        strArr[i4] = str;
        this.fNotationPublicId[i3][i4] = xMLNotationDecl.publicId;
        this.fNotationSystemId[i3][i4] = xMLNotationDecl.systemId;
        this.fNotationBaseSystemId[i3][i4] = xMLNotationDecl.baseSystemId;
        this.fNotationIndexMap.put(str, i2);
    }

    @Override // org.apache.xerces.xni.XMLDTDHandler
    public void startAttlist(String str, Augmentations augmentations) {
    }

    @Override // org.apache.xerces.xni.XMLDTDHandler
    public void startConditional(short s, Augmentations augmentations) {
    }

    @Override // org.apache.xerces.xni.XMLDTDContentModelHandler
    public void startContentModel(String str, Augmentations augmentations) {
        XMLElementDecl xMLElementDecl = (XMLElementDecl) this.fElementDeclTab.get(str);
        if (xMLElementDecl != null) {
            this.fElementDecl = xMLElementDecl;
        }
        this.fDepth = 0;
        initializeContentModelStack();
    }

    @Override // org.apache.xerces.xni.XMLDTDHandler
    public void startDTD(XMLLocator xMLLocator, Augmentations augmentations) {
        this.fOpStack = null;
        this.fNodeIndexStack = null;
        this.fPrevNodeIndexStack = null;
    }

    @Override // org.apache.xerces.xni.XMLDTDHandler
    public void startExternalSubset(XMLResourceIdentifier xMLResourceIdentifier, Augmentations augmentations) {
        this.fReadingExternalDTD = true;
    }

    @Override // org.apache.xerces.xni.XMLDTDContentModelHandler
    public void startGroup(Augmentations augmentations) {
        this.fDepth++;
        initializeContentModelStack();
        this.fMixed = false;
    }

    @Override // org.apache.xerces.xni.XMLDTDHandler
    public void startParameterEntity(String str, XMLResourceIdentifier xMLResourceIdentifier, String str2, Augmentations augmentations) {
        int i2 = this.fPEDepth;
        boolean[] zArr = this.fPEntityStack;
        if (i2 == zArr.length) {
            boolean[] zArr2 = new boolean[(zArr.length * 2)];
            System.arraycopy(zArr, 0, zArr2, 0, zArr.length);
            this.fPEntityStack = zArr2;
        }
        boolean[] zArr3 = this.fPEntityStack;
        int i3 = this.fPEDepth;
        zArr3[i3] = this.fReadingExternalDTD;
        this.fPEDepth = i3 + 1;
    }

    @Override // org.apache.xerces.xni.XMLDTDHandler
    public void textDecl(String str, String str2, Augmentations augmentations) {
    }

    @Override // org.apache.xerces.xni.XMLDTDHandler
    public void unparsedEntityDecl(String str, XMLResourceIdentifier xMLResourceIdentifier, String str2, Augmentations augmentations) {
        XMLEntityDecl xMLEntityDecl = new XMLEntityDecl();
        xMLEntityDecl.setValues(str, xMLResourceIdentifier.getPublicId(), xMLResourceIdentifier.getLiteralSystemId(), xMLResourceIdentifier.getBaseSystemId(), str2, null, str.startsWith(PercentPtg.PERCENT), this.fReadingExternalDTD || this.fPEDepth > 0);
        if (getEntityDeclIndex(str) == -1) {
            setEntityDecl(createEntityDecl(), xMLEntityDecl);
        }
    }
}
