package org.apache.xerces.impl.dtd;

import org.apache.xerces.impl.msg.XMLMessageFormatter;
import org.apache.xerces.util.XMLSymbols;
import org.apache.xerces.xni.Augmentations;
import org.apache.xerces.xni.NamespaceContext;
import org.apache.xerces.xni.QName;
import org.apache.xerces.xni.XMLAttributes;
import org.apache.xerces.xni.XMLDocumentHandler;

public class XML11NSDTDValidator extends XML11DTDValidator {
    public final QName fAttributeQName = new QName();

    @Override // org.apache.xerces.impl.dtd.XMLDTDValidator
    public void endNamespaceScope(QName qName, Augmentations augmentations, boolean z) {
        String str = qName.prefix;
        if (str == null) {
            str = XMLSymbols.EMPTY_STRING;
        }
        String uri = this.fNamespaceContext.getURI(str);
        qName.uri = uri;
        if (uri != null) {
            qName.prefix = str;
        }
        XMLDocumentHandler xMLDocumentHandler = this.fDocumentHandler;
        if (xMLDocumentHandler != null && !z) {
            xMLDocumentHandler.endElement(qName, augmentations);
        }
        this.fNamespaceContext.popContext();
    }

    @Override // org.apache.xerces.impl.dtd.XMLDTDValidator
    public final void startNamespaceScope(QName qName, XMLAttributes xMLAttributes, Augmentations augmentations) {
        this.fNamespaceContext.pushContext();
        if (qName.prefix == XMLSymbols.PREFIX_XMLNS) {
            this.fErrorReporter.reportError(XMLMessageFormatter.XMLNS_DOMAIN, "ElementXMLNSPrefix", new Object[]{qName.rawname}, 2);
        }
        int length = xMLAttributes.getLength();
        for (int i2 = 0; i2 < length; i2++) {
            String localName = xMLAttributes.getLocalName(i2);
            String prefix = xMLAttributes.getPrefix(i2);
            if (prefix == XMLSymbols.PREFIX_XMLNS || (prefix == XMLSymbols.EMPTY_STRING && localName == XMLSymbols.PREFIX_XMLNS)) {
                String addSymbol = this.fSymbolTable.addSymbol(xMLAttributes.getValue(i2));
                String str = XMLSymbols.PREFIX_XMLNS;
                if (prefix == str && localName == str) {
                    this.fErrorReporter.reportError(XMLMessageFormatter.XMLNS_DOMAIN, "CantBindXMLNS", new Object[]{xMLAttributes.getQName(i2)}, 2);
                }
                if (addSymbol == NamespaceContext.XMLNS_URI) {
                    this.fErrorReporter.reportError(XMLMessageFormatter.XMLNS_DOMAIN, "CantBindXMLNS", new Object[]{xMLAttributes.getQName(i2)}, 2);
                }
                if (localName == XMLSymbols.PREFIX_XML) {
                    if (addSymbol != NamespaceContext.XML_URI) {
                        this.fErrorReporter.reportError(XMLMessageFormatter.XMLNS_DOMAIN, "CantBindXML", new Object[]{xMLAttributes.getQName(i2)}, 2);
                    }
                } else if (addSymbol == NamespaceContext.XML_URI) {
                    this.fErrorReporter.reportError(XMLMessageFormatter.XMLNS_DOMAIN, "CantBindXML", new Object[]{xMLAttributes.getQName(i2)}, 2);
                }
                if (localName == XMLSymbols.PREFIX_XMLNS) {
                    localName = XMLSymbols.EMPTY_STRING;
                }
                NamespaceContext namespaceContext = this.fNamespaceContext;
                if (addSymbol.length() == 0) {
                    addSymbol = null;
                }
                namespaceContext.declarePrefix(localName, addSymbol);
            }
        }
        String str2 = qName.prefix;
        if (str2 == null) {
            str2 = XMLSymbols.EMPTY_STRING;
        }
        String uri = this.fNamespaceContext.getURI(str2);
        qName.uri = uri;
        if (qName.prefix == null && uri != null) {
            qName.prefix = XMLSymbols.EMPTY_STRING;
        }
        String str3 = qName.prefix;
        if (str3 != null && qName.uri == null) {
            this.fErrorReporter.reportError(XMLMessageFormatter.XMLNS_DOMAIN, "ElementPrefixUnbound", new Object[]{str3, qName.rawname}, 2);
        }
        for (int i3 = 0; i3 < length; i3++) {
            xMLAttributes.getName(i3, this.fAttributeQName);
            String str4 = this.fAttributeQName.prefix;
            if (str4 == null) {
                str4 = XMLSymbols.EMPTY_STRING;
            }
            QName qName2 = this.fAttributeQName;
            String str5 = qName2.rawname;
            String str6 = XMLSymbols.PREFIX_XMLNS;
            if (str5 == str6) {
                qName2.uri = this.fNamespaceContext.getURI(str6);
            } else if (str4 != XMLSymbols.EMPTY_STRING) {
                qName2.uri = this.fNamespaceContext.getURI(str4);
                if (this.fAttributeQName.uri == null) {
                    this.fErrorReporter.reportError(XMLMessageFormatter.XMLNS_DOMAIN, "AttributePrefixUnbound", new Object[]{qName.rawname, str5, str4}, 2);
                }
            }
            xMLAttributes.setName(i3, this.fAttributeQName);
        }
        int length2 = xMLAttributes.getLength();
        for (int i4 = 0; i4 < length2 - 1; i4++) {
            String uri2 = xMLAttributes.getURI(i4);
            if (!(uri2 == null || uri2 == NamespaceContext.XMLNS_URI)) {
                String localName2 = xMLAttributes.getLocalName(i4);
                for (int i5 = i4 + 1; i5 < length2; i5++) {
                    String localName3 = xMLAttributes.getLocalName(i5);
                    String uri3 = xMLAttributes.getURI(i5);
                    if (localName2 == localName3 && uri2 == uri3) {
                        this.fErrorReporter.reportError(XMLMessageFormatter.XMLNS_DOMAIN, "AttributeNSNotUnique", new Object[]{qName.rawname, localName2, uri2}, 2);
                    }
                }
            }
        }
    }
}
