package org.apache.xerces.impl.dv.xs;

import b.b.a.a.a;
import java.math.BigDecimal;
import javax.xml.datatype.DatatypeFactory;
import javax.xml.datatype.Duration;
import javax.xml.datatype.XMLGregorianCalendar;
import org.apache.poi.ss.formula.functions.NumericFunction;
import org.apache.poi.ss.util.SheetUtil;
import org.apache.xerces.jaxp.datatype.DatatypeFactoryImpl;
import org.apache.xerces.xs.datatypes.XSDateTime;
import org.apache.xmlbeans.impl.common.NameUtil;

public abstract class AbstractDateTimeDV extends TypeValidator {
    public static final int DAY = 1;
    public static final boolean DEBUG = false;
    public static final int MONTH = 1;
    public static final int YEAR = 2000;
    public static final DatatypeFactory datatypeFactory = new DatatypeFactoryImpl();

    public static final class DateTimeData implements XSDateTime {
        public String canonical;
        public int day;
        public int hour;
        public int minute;
        public int month;
        public boolean normalized = true;
        public String originalValue;
        public int position;
        public double second;
        public int timezoneHr;
        public int timezoneMin;
        public final AbstractDateTimeDV type;
        public int unNormDay;
        public int unNormHour;
        public int unNormMinute;
        public int unNormMonth;
        public double unNormSecond;
        public int unNormYear;
        public int utc;
        public int year;

        public DateTimeData(int i2, int i3, int i4, int i5, int i6, double d2, int i7, String str, boolean z, AbstractDateTimeDV abstractDateTimeDV) {
            this.year = i2;
            this.month = i3;
            this.day = i4;
            this.hour = i5;
            this.minute = i6;
            this.second = d2;
            this.utc = i7;
            this.type = abstractDateTimeDV;
            this.originalValue = str;
        }

        public DateTimeData(String str, AbstractDateTimeDV abstractDateTimeDV) {
            this.originalValue = str;
            this.type = abstractDateTimeDV;
        }

        public Object clone() {
            DateTimeData dateTimeData = new DateTimeData(this.year, this.month, this.day, this.hour, this.minute, this.second, this.utc, this.originalValue, this.normalized, this.type);
            dateTimeData.canonical = this.canonical;
            dateTimeData.position = this.position;
            dateTimeData.timezoneHr = this.timezoneHr;
            dateTimeData.timezoneMin = this.timezoneMin;
            dateTimeData.unNormYear = this.unNormYear;
            dateTimeData.unNormMonth = this.unNormMonth;
            dateTimeData.unNormDay = this.unNormDay;
            dateTimeData.unNormHour = this.unNormHour;
            dateTimeData.unNormMinute = this.unNormMinute;
            dateTimeData.unNormSecond = this.unNormSecond;
            return dateTimeData;
        }

        public boolean equals(Object obj) {
            return (obj instanceof DateTimeData) && this.type.compareDates(this, (DateTimeData) obj, true) == 0;
        }

        @Override // org.apache.xerces.xs.datatypes.XSDateTime
        public int getDays() {
            if (this.type instanceof DurationDV) {
                return 0;
            }
            return this.normalized ? this.day : this.unNormDay;
        }

        @Override // org.apache.xerces.xs.datatypes.XSDateTime
        public Duration getDuration() {
            return this.type.getDuration(this);
        }

        @Override // org.apache.xerces.xs.datatypes.XSDateTime
        public int getHours() {
            if (this.type instanceof DurationDV) {
                return 0;
            }
            return this.normalized ? this.hour : this.unNormHour;
        }

        @Override // org.apache.xerces.xs.datatypes.XSDateTime
        public String getLexicalValue() {
            return this.originalValue;
        }

        @Override // org.apache.xerces.xs.datatypes.XSDateTime
        public int getMinutes() {
            if (this.type instanceof DurationDV) {
                return 0;
            }
            return this.normalized ? this.minute : this.unNormMinute;
        }

        @Override // org.apache.xerces.xs.datatypes.XSDateTime
        public int getMonths() {
            return this.type instanceof DurationDV ? (this.year * 12) + this.month : this.normalized ? this.month : this.unNormMonth;
        }

        @Override // org.apache.xerces.xs.datatypes.XSDateTime
        public double getSeconds() {
            if (!(this.type instanceof DurationDV)) {
                return this.normalized ? this.second : this.unNormSecond;
            }
            return ((double) ((this.minute * 60) + (this.hour * 60 * 60) + (this.day * 24 * 60 * 60))) + this.second;
        }

        @Override // org.apache.xerces.xs.datatypes.XSDateTime
        public int getTimeZoneHours() {
            return this.timezoneHr;
        }

        @Override // org.apache.xerces.xs.datatypes.XSDateTime
        public int getTimeZoneMinutes() {
            return this.timezoneMin;
        }

        @Override // org.apache.xerces.xs.datatypes.XSDateTime
        public XMLGregorianCalendar getXMLGregorianCalendar() {
            return this.type.getXMLGregorianCalendar(this);
        }

        @Override // org.apache.xerces.xs.datatypes.XSDateTime
        public int getYears() {
            if (this.type instanceof DurationDV) {
                return 0;
            }
            return this.normalized ? this.year : this.unNormYear;
        }

        @Override // org.apache.xerces.xs.datatypes.XSDateTime
        public boolean hasTimeZone() {
            return this.utc != 0;
        }

        @Override // org.apache.xerces.xs.datatypes.XSDateTime
        public boolean isNormalized() {
            return this.normalized;
        }

        @Override // org.apache.xerces.xs.datatypes.XSDateTime
        public XSDateTime normalize() {
            if (this.normalized) {
                return this;
            }
            DateTimeData dateTimeData = (DateTimeData) clone();
            dateTimeData.normalized = true;
            return dateTimeData;
        }

        public synchronized String toString() {
            if (this.canonical == null) {
                this.canonical = this.type.dateToString(this);
            }
            return this.canonical;
        }
    }

    private void append3(StringBuffer stringBuffer, double d2) {
        String valueOf = String.valueOf(d2);
        int indexOf = valueOf.indexOf(69);
        if (indexOf == -1) {
            stringBuffer.append(valueOf);
            return;
        }
        int i2 = 0;
        if (d2 < 1.0d) {
            try {
                int parseInt = parseInt(valueOf, indexOf + 2, valueOf.length());
                stringBuffer.append("0.");
                for (int i3 = 1; i3 < parseInt; i3++) {
                    stringBuffer.append(SheetUtil.defaultChar);
                }
                int i4 = indexOf - 1;
                while (i4 > 0 && valueOf.charAt(i4) == '0') {
                    i4--;
                }
                while (i2 <= i4) {
                    char charAt = valueOf.charAt(i2);
                    if (charAt != '.') {
                        stringBuffer.append(charAt);
                    }
                    i2++;
                }
            } catch (Exception unused) {
                stringBuffer.append(valueOf);
            }
        } else {
            try {
                int parseInt2 = parseInt(valueOf, indexOf + 1, valueOf.length()) + 2;
                while (i2 < indexOf) {
                    char charAt2 = valueOf.charAt(i2);
                    if (charAt2 != '.') {
                        if (i2 == parseInt2) {
                            stringBuffer.append(NameUtil.PERIOD);
                        }
                        stringBuffer.append(charAt2);
                    }
                    i2++;
                }
                for (int i5 = parseInt2 - indexOf; i5 > 0; i5--) {
                    stringBuffer.append(SheetUtil.defaultChar);
                }
            } catch (Exception unused2) {
                stringBuffer.append(valueOf);
            }
        }
    }

    private void cloneDate(DateTimeData dateTimeData, DateTimeData dateTimeData2) {
        dateTimeData2.year = dateTimeData.year;
        dateTimeData2.month = dateTimeData.month;
        dateTimeData2.day = dateTimeData.day;
        dateTimeData2.hour = dateTimeData.hour;
        dateTimeData2.minute = dateTimeData.minute;
        dateTimeData2.second = dateTimeData.second;
        dateTimeData2.utc = dateTimeData.utc;
        dateTimeData2.timezoneHr = dateTimeData.timezoneHr;
        dateTimeData2.timezoneMin = dateTimeData.timezoneMin;
    }

    private boolean isLeapYear(int i2) {
        return i2 % 4 == 0 && (i2 % 100 != 0 || i2 % 400 == 0);
    }

    public final void append(StringBuffer stringBuffer, double d2) {
        if (d2 < NumericFunction.LOG_10_TO_BASE_e) {
            stringBuffer.append(NameUtil.HYPHEN);
            d2 = -d2;
        }
        if (d2 < 10.0d) {
            stringBuffer.append(SheetUtil.defaultChar);
        }
        append2(stringBuffer, d2);
    }

    /* JADX WARNING: Code restructure failed: missing block: B:15:0x0028, code lost:
        if (r5 < 1000) goto L_0x0030;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:18:0x002e, code lost:
        if (r5 < 10) goto L_0x0030;
     */
    public final void append(StringBuffer stringBuffer, int i2, int i3) {
        String str;
        if (i2 == Integer.MIN_VALUE) {
            stringBuffer.append(i2);
            return;
        }
        if (i2 < 0) {
            stringBuffer.append(NameUtil.HYPHEN);
            i2 = -i2;
        }
        if (i3 == 4) {
            if (i2 < 10) {
                str = "000";
            } else if (i2 < 100) {
                str = "00";
            }
            stringBuffer.append(str);
            stringBuffer.append(i2);
        } else if (i3 != 2) {
            if (i2 != 0) {
                stringBuffer.append((char) i2);
                return;
            }
            return;
        }
        stringBuffer.append(SheetUtil.defaultChar);
        stringBuffer.append(i2);
    }

    public final void append2(StringBuffer stringBuffer, double d2) {
        int i2 = (int) d2;
        if (d2 == ((double) i2)) {
            stringBuffer.append(i2);
        } else {
            append3(stringBuffer, d2);
        }
    }

    @Override // org.apache.xerces.impl.dv.xs.TypeValidator
    public int compare(Object obj, Object obj2) {
        return compareDates((DateTimeData) obj, (DateTimeData) obj2, true);
    }

    public short compareDates(DateTimeData dateTimeData, DateTimeData dateTimeData2, boolean z) {
        if (dateTimeData.utc == dateTimeData2.utc) {
            return compareOrder(dateTimeData, dateTimeData2);
        }
        DateTimeData dateTimeData3 = new DateTimeData(null, this);
        if (dateTimeData.utc == 90) {
            cloneDate(dateTimeData2, dateTimeData3);
            dateTimeData3.timezoneHr = 14;
            dateTimeData3.timezoneMin = 0;
            dateTimeData3.utc = 43;
            normalize(dateTimeData3);
            short compareOrder = compareOrder(dateTimeData, dateTimeData3);
            if (compareOrder == -1) {
                return compareOrder;
            }
            cloneDate(dateTimeData2, dateTimeData3);
            dateTimeData3.timezoneHr = -14;
            dateTimeData3.timezoneMin = 0;
            dateTimeData3.utc = 45;
            normalize(dateTimeData3);
            short compareOrder2 = compareOrder(dateTimeData, dateTimeData3);
            if (compareOrder2 == 1) {
                return compareOrder2;
            }
            return 2;
        }
        if (dateTimeData2.utc == 90) {
            cloneDate(dateTimeData, dateTimeData3);
            dateTimeData3.timezoneHr = -14;
            dateTimeData3.timezoneMin = 0;
            dateTimeData3.utc = 45;
            normalize(dateTimeData3);
            short compareOrder3 = compareOrder(dateTimeData3, dateTimeData2);
            if (compareOrder3 == -1) {
                return compareOrder3;
            }
            cloneDate(dateTimeData, dateTimeData3);
            dateTimeData3.timezoneHr = 14;
            dateTimeData3.timezoneMin = 0;
            dateTimeData3.utc = 43;
            normalize(dateTimeData3);
            short compareOrder4 = compareOrder(dateTimeData3, dateTimeData2);
            if (compareOrder4 == 1) {
                return compareOrder4;
            }
        }
        return 2;
    }

    public short compareOrder(DateTimeData dateTimeData, DateTimeData dateTimeData2) {
        if (dateTimeData.position < 1) {
            int i2 = dateTimeData.year;
            int i3 = dateTimeData2.year;
            if (i2 < i3) {
                return -1;
            }
            if (i2 > i3) {
                return 1;
            }
        }
        if (dateTimeData.position < 2) {
            int i4 = dateTimeData.month;
            int i5 = dateTimeData2.month;
            if (i4 < i5) {
                return -1;
            }
            if (i4 > i5) {
                return 1;
            }
        }
        int i6 = dateTimeData.day;
        int i7 = dateTimeData2.day;
        if (i6 < i7) {
            return -1;
        }
        if (i6 > i7) {
            return 1;
        }
        int i8 = dateTimeData.hour;
        int i9 = dateTimeData2.hour;
        if (i8 < i9) {
            return -1;
        }
        if (i8 > i9) {
            return 1;
        }
        int i10 = dateTimeData.minute;
        int i11 = dateTimeData2.minute;
        if (i10 < i11) {
            return -1;
        }
        if (i10 > i11) {
            return 1;
        }
        double d2 = dateTimeData.second;
        double d3 = dateTimeData2.second;
        if (d2 < d3) {
            return -1;
        }
        if (d2 > d3) {
            return 1;
        }
        int i12 = dateTimeData.utc;
        int i13 = dateTimeData2.utc;
        if (i12 < i13) {
            return -1;
        }
        return i12 > i13 ? (short) 1 : 0;
    }

    public String dateToString(DateTimeData dateTimeData) {
        StringBuffer stringBuffer = new StringBuffer(25);
        append(stringBuffer, dateTimeData.year, 4);
        stringBuffer.append(NameUtil.HYPHEN);
        append(stringBuffer, dateTimeData.month, 2);
        stringBuffer.append(NameUtil.HYPHEN);
        append(stringBuffer, dateTimeData.day, 2);
        stringBuffer.append('T');
        append(stringBuffer, dateTimeData.hour, 2);
        stringBuffer.append(':');
        append(stringBuffer, dateTimeData.minute, 2);
        stringBuffer.append(':');
        append(stringBuffer, dateTimeData.second);
        append(stringBuffer, (char) dateTimeData.utc, 0);
        return stringBuffer.toString();
    }

    public int fQuotient(int i2, int i3) {
        return (int) Math.floor((double) (((float) i2) / ((float) i3)));
    }

    public int fQuotient(int i2, int i3, int i4) {
        return fQuotient(i2 - i3, i4 - i3);
    }

    public int findUTCSign(String str, int i2, int i3) {
        while (i2 < i3) {
            char charAt = str.charAt(i2);
            if (charAt == 'Z' || charAt == '+' || charAt == '-') {
                return i2;
            }
            i2++;
        }
        return -1;
    }

    @Override // org.apache.xerces.impl.dv.xs.TypeValidator
    public short getAllowedFacets() {
        return 2552;
    }

    public int getDate(String str, int i2, int i3, DateTimeData dateTimeData) {
        int yearMonth = getYearMonth(str, i2, i3, dateTimeData);
        int i4 = yearMonth + 1;
        if (str.charAt(yearMonth) == '-') {
            int i5 = i4 + 2;
            dateTimeData.day = parseInt(str, i4, i5);
            return i5;
        }
        throw new RuntimeException("CCYY-MM must be followed by '-' sign");
    }

    public Duration getDuration(DateTimeData dateTimeData) {
        return null;
    }

    public final BigDecimal getFractionalSecondsAsBigDecimal(DateTimeData dateTimeData) {
        StringBuffer stringBuffer = new StringBuffer();
        append3(stringBuffer, dateTimeData.unNormSecond);
        String stringBuffer2 = stringBuffer.toString();
        int indexOf = stringBuffer2.indexOf(46);
        if (indexOf == -1) {
            return null;
        }
        BigDecimal bigDecimal = new BigDecimal(stringBuffer2.substring(indexOf));
        if (bigDecimal.compareTo(BigDecimal.valueOf(0L)) == 0) {
            return null;
        }
        return bigDecimal;
    }

    public void getTime(String str, int i2, int i3, DateTimeData dateTimeData) {
        int i4 = i2 + 2;
        dateTimeData.hour = parseInt(str, i2, i4);
        int i5 = i4 + 1;
        if (str.charAt(i4) == ':') {
            int i6 = i5 + 2;
            dateTimeData.minute = parseInt(str, i5, i6);
            int i7 = i6 + 1;
            if (str.charAt(i6) == ':') {
                int findUTCSign = findUTCSign(str, i5, i3);
                dateTimeData.second = parseSecond(str, i7, findUTCSign < 0 ? i3 : findUTCSign);
                if (findUTCSign > 0) {
                    getTimeZone(str, dateTimeData, findUTCSign, i3);
                    return;
                }
                return;
            }
            throw new RuntimeException("Error in parsing time zone");
        }
        throw new RuntimeException("Error in parsing time zone");
    }

    public void getTimeZone(String str, DateTimeData dateTimeData, int i2, int i3) {
        dateTimeData.utc = str.charAt(i2);
        if (str.charAt(i2) == 'Z') {
            if (i3 > i2 + 1) {
                throw new RuntimeException("Error in parsing time zone");
            }
        } else if (i2 <= i3 - 6) {
            int i4 = str.charAt(i2) == '-' ? -1 : 1;
            int i5 = i2 + 1;
            int i6 = i5 + 2;
            dateTimeData.timezoneHr = parseInt(str, i5, i6) * i4;
            int i7 = i6 + 1;
            if (str.charAt(i6) == ':') {
                int i8 = i7 + 2;
                int parseInt = parseInt(str, i7, i8) * i4;
                dateTimeData.timezoneMin = parseInt;
                if (i8 != i3) {
                    throw new RuntimeException("Error in parsing time zone");
                } else if (dateTimeData.timezoneHr != 0 || parseInt != 0) {
                    dateTimeData.normalized = false;
                }
            } else {
                throw new RuntimeException("Error in parsing time zone");
            }
        } else {
            throw new RuntimeException("Error in parsing time zone");
        }
    }

    public XMLGregorianCalendar getXMLGregorianCalendar(DateTimeData dateTimeData) {
        return null;
    }

    public int getYearMonth(String str, int i2, int i3, DateTimeData dateTimeData) {
        if (str.charAt(0) == '-') {
            i2++;
        }
        int indexOf = indexOf(str, i2, i3, NameUtil.HYPHEN);
        if (indexOf != -1) {
            int i4 = indexOf - i2;
            if (i4 < 4) {
                throw new RuntimeException("Year must have 'CCYY' format");
            } else if (i4 <= 4 || str.charAt(i2) != '0') {
                dateTimeData.year = parseIntYear(str, indexOf);
                if (str.charAt(indexOf) == '-') {
                    int i5 = indexOf + 1;
                    int i6 = i5 + 2;
                    dateTimeData.month = parseInt(str, i5, i6);
                    return i6;
                }
                throw new RuntimeException("CCYY must be followed by '-' sign");
            } else {
                throw new RuntimeException("Leading zeros are required if the year value would otherwise have fewer than four digits; otherwise they are forbidden");
            }
        } else {
            throw new RuntimeException("Year separator is missing or misplaced");
        }
    }

    public int indexOf(String str, int i2, int i3, char c) {
        while (i2 < i3) {
            if (str.charAt(i2) == c) {
                return i2;
            }
            i2++;
        }
        return -1;
    }

    @Override // org.apache.xerces.impl.dv.xs.TypeValidator
    public boolean isIdentical(Object obj, Object obj2) {
        if ((obj instanceof DateTimeData) && (obj2 instanceof DateTimeData)) {
            DateTimeData dateTimeData = (DateTimeData) obj;
            DateTimeData dateTimeData2 = (DateTimeData) obj2;
            if (dateTimeData.timezoneHr == dateTimeData2.timezoneHr && dateTimeData.timezoneMin == dateTimeData2.timezoneMin) {
                return dateTimeData.equals(dateTimeData2);
            }
        }
        return false;
    }

    public final boolean isNextCharUTCSign(String str, int i2, int i3) {
        if (i2 >= i3) {
            return false;
        }
        char charAt = str.charAt(i2);
        return charAt == 'Z' || charAt == '+' || charAt == '-';
    }

    public int maxDayInMonthFor(int i2, int i3) {
        if (i3 == 4 || i3 == 6 || i3 == 9 || i3 == 11) {
            return 30;
        }
        if (i3 == 2) {
            return isLeapYear(i2) ? 29 : 28;
        }
        return 31;
    }

    public int mod(int i2, int i3, int i4) {
        return i2 - (i4 * i3);
    }

    public int modulo(int i2, int i3, int i4) {
        int i5 = i2 - i3;
        int i6 = i4 - i3;
        return mod(i5, i6, fQuotient(i5, i6)) + i3;
    }

    public void normalize(DateTimeData dateTimeData) {
        int i2;
        int i3 = (dateTimeData.timezoneMin * -1) + dateTimeData.minute;
        int fQuotient = fQuotient(i3, 60);
        dateTimeData.minute = mod(i3, 60, fQuotient);
        int i4 = (dateTimeData.timezoneHr * -1) + dateTimeData.hour + fQuotient;
        int fQuotient2 = fQuotient(i4, 24);
        dateTimeData.hour = mod(i4, 24, fQuotient2);
        dateTimeData.day += fQuotient2;
        while (true) {
            int maxDayInMonthFor = maxDayInMonthFor(dateTimeData.year, dateTimeData.month);
            int i5 = dateTimeData.day;
            int i6 = 1;
            if (i5 < 1) {
                dateTimeData.day = maxDayInMonthFor(dateTimeData.year, dateTimeData.month - 1) + i5;
                i2 = -1;
            } else if (i5 > maxDayInMonthFor) {
                dateTimeData.day = i5 - maxDayInMonthFor;
                i2 = 1;
            } else {
                dateTimeData.utc = 90;
                return;
            }
            int i7 = dateTimeData.month + i2;
            dateTimeData.month = modulo(i7, 1, 13);
            int fQuotient3 = fQuotient(i7, 1, 13) + dateTimeData.year;
            dateTimeData.year = fQuotient3;
            if (fQuotient3 == 0) {
                if (dateTimeData.timezoneHr >= 0 && dateTimeData.timezoneMin >= 0) {
                    i6 = -1;
                }
                dateTimeData.year = i6;
            }
        }
    }

    public int parseInt(String str, int i2, int i3) {
        int i4 = 0;
        do {
            int digit = TypeValidator.getDigit(str.charAt(i2));
            if (digit < 0) {
                throw new NumberFormatException(a.a("'", str, "' has wrong format"));
            } else if (i4 >= -214748364) {
                int i5 = i4 * 10;
                if (i5 >= -2147483647 + digit) {
                    i4 = i5 - digit;
                    i2++;
                } else {
                    throw new NumberFormatException(a.a("'", str, "' has wrong format"));
                }
            } else {
                throw new NumberFormatException(a.a("'", str, "' has wrong format"));
            }
        } while (i2 < i3);
        return -i4;
    }

    public int parseIntYear(String str, int i2) {
        int i3;
        boolean z;
        int i4;
        int i5 = 0;
        if (str.charAt(0) == '-') {
            i4 = Integer.MIN_VALUE;
            z = true;
            i3 = 1;
        } else {
            i4 = -2147483647;
            z = false;
            i3 = 0;
        }
        int i6 = i4 / 10;
        while (i3 < i2) {
            int i7 = i3 + 1;
            int digit = TypeValidator.getDigit(str.charAt(i3));
            if (digit < 0) {
                throw new NumberFormatException(a.a("'", str, "' has wrong format"));
            } else if (i5 >= i6) {
                int i8 = i5 * 10;
                if (i8 >= i4 + digit) {
                    i5 = i8 - digit;
                    i3 = i7;
                } else {
                    throw new NumberFormatException(a.a("'", str, "' has wrong format"));
                }
            } else {
                throw new NumberFormatException(a.a("'", str, "' has wrong format"));
            }
        }
        if (!z) {
            return -i5;
        }
        if (i3 > 1) {
            return i5;
        }
        throw new NumberFormatException(a.a("'", str, "' has wrong format"));
    }

    public double parseSecond(String str, int i2, int i3) {
        int i4 = -1;
        for (int i5 = i2; i5 < i3; i5++) {
            char charAt = str.charAt(i5);
            if (charAt == '.') {
                i4 = i5;
            } else if (charAt > '9' || charAt < '0') {
                throw new NumberFormatException(a.a("'", str, "' has wrong format"));
            }
        }
        if (i4 == -1) {
            if (i2 + 2 != i3) {
                throw new NumberFormatException(a.a("'", str, "' has wrong format"));
            }
        } else if (i2 + 2 != i4 || i4 + 1 == i3) {
            throw new NumberFormatException(a.a("'", str, "' has wrong format"));
        }
        return Double.parseDouble(str.substring(i2, i3));
    }

    public void parseTimeZone(String str, int i2, int i3, DateTimeData dateTimeData) {
        if (i2 >= i3) {
            return;
        }
        if (isNextCharUTCSign(str, i2, i3)) {
            getTimeZone(str, dateTimeData, i2, i3);
            return;
        }
        throw new RuntimeException("Error in month parsing");
    }

    public void resetDateObj(DateTimeData dateTimeData) {
        dateTimeData.year = 0;
        dateTimeData.month = 0;
        dateTimeData.day = 0;
        dateTimeData.hour = 0;
        dateTimeData.minute = 0;
        dateTimeData.second = NumericFunction.LOG_10_TO_BASE_e;
        dateTimeData.utc = 0;
        dateTimeData.timezoneHr = 0;
        dateTimeData.timezoneMin = 0;
    }

    public void saveUnnormalized(DateTimeData dateTimeData) {
        dateTimeData.unNormYear = dateTimeData.year;
        dateTimeData.unNormMonth = dateTimeData.month;
        dateTimeData.unNormDay = dateTimeData.day;
        dateTimeData.unNormHour = dateTimeData.hour;
        dateTimeData.unNormMinute = dateTimeData.minute;
        dateTimeData.unNormSecond = dateTimeData.second;
    }

    public void validateDateTime(DateTimeData dateTimeData) {
        int i2 = dateTimeData.year;
        if (i2 != 0) {
            int i3 = dateTimeData.month;
            if (i3 < 1 || i3 > 12) {
                throw new RuntimeException("The month must have values 1 to 12");
            } else if (dateTimeData.day > maxDayInMonthFor(i2, i3) || dateTimeData.day < 1) {
                throw new RuntimeException("The day must have values 1 to 31");
            } else {
                int i4 = dateTimeData.hour;
                if (i4 > 23 || i4 < 0) {
                    if (dateTimeData.hour == 24 && dateTimeData.minute == 0 && dateTimeData.second == NumericFunction.LOG_10_TO_BASE_e) {
                        dateTimeData.hour = 0;
                        int i5 = dateTimeData.day + 1;
                        dateTimeData.day = i5;
                        if (i5 > maxDayInMonthFor(dateTimeData.year, dateTimeData.month)) {
                            dateTimeData.day = 1;
                            int i6 = dateTimeData.month + 1;
                            dateTimeData.month = i6;
                            if (i6 > 12) {
                                dateTimeData.month = 1;
                                int i7 = dateTimeData.year + 1;
                                dateTimeData.year = i7;
                                if (i7 == 0) {
                                    dateTimeData.year = 1;
                                }
                            }
                        }
                    } else {
                        throw new RuntimeException("Hour must have values 0-23, unless 24:00:00");
                    }
                }
                int i8 = dateTimeData.minute;
                if (i8 > 59 || i8 < 0) {
                    throw new RuntimeException("Minute must have values 0-59");
                }
                double d2 = dateTimeData.second;
                if (d2 >= 60.0d || d2 < NumericFunction.LOG_10_TO_BASE_e) {
                    throw new RuntimeException("Second must have values 0-59");
                }
                int i9 = dateTimeData.timezoneHr;
                if (i9 > 14 || i9 < -14) {
                    throw new RuntimeException("Time zone should have range -14:00 to +14:00");
                } else if ((i9 == 14 || i9 == -14) && dateTimeData.timezoneMin != 0) {
                    throw new RuntimeException("Time zone should have range -14:00 to +14:00");
                } else {
                    int i10 = dateTimeData.timezoneMin;
                    if (i10 > 59 || i10 < -59) {
                        throw new RuntimeException("Minute must have values 0-59");
                    }
                }
            }
        } else {
            throw new RuntimeException("The year \"0000\" is an illegal year value");
        }
    }
}
