package org.apache.xerces.impl.dv.xs;

import java.io.UnsupportedEncodingException;
import org.apache.poi.ss.formula.ptg.StringPtg;
import org.apache.poi.ss.util.SheetUtil;
import org.apache.xerces.impl.dv.InvalidDatatypeValueException;
import org.apache.xerces.impl.dv.ValidationContext;
import org.apache.xerces.util.URI;

public class AnyURIDV extends TypeValidator {
    public static final URI BASE_URI;
    public static char[] gAfterEscaping1 = new char[128];
    public static char[] gAfterEscaping2 = new char[128];
    public static char[] gHexChs = {SheetUtil.defaultChar, '1', '2', '3', '4', '5', '6', '7', '8', '9', 'A', 'B', 'C', 'D', 'E', 'F'};
    public static boolean[] gNeedEscaping = new boolean[128];

    static {
        URI uri;
        try {
            uri = new URI("abc://def.ghi.jkl");
        } catch (URI.MalformedURIException unused) {
            uri = null;
        }
        BASE_URI = uri;
        for (int i2 = 0; i2 <= 31; i2++) {
            gNeedEscaping[i2] = true;
            char[] cArr = gAfterEscaping1;
            char[] cArr2 = gHexChs;
            cArr[i2] = cArr2[i2 >> 4];
            gAfterEscaping2[i2] = cArr2[i2 & 15];
        }
        gNeedEscaping[127] = true;
        gAfterEscaping1[127] = '7';
        gAfterEscaping2[127] = 'F';
        char[] cArr3 = {' ', '<', '>', StringPtg.FORMULA_DELIMITER, '{', '}', '|', '\\', '^', '~', '`'};
        for (int i3 = 0; i3 < 11; i3++) {
            char c = cArr3[i3];
            gNeedEscaping[c] = true;
            char[] cArr4 = gAfterEscaping1;
            char[] cArr5 = gHexChs;
            cArr4[c] = cArr5[c >> 4];
            gAfterEscaping2[c] = cArr5[c & 15];
        }
    }

    public static String encode(String str) {
        char c;
        char charAt;
        char c2;
        int length = str.length();
        StringBuffer stringBuffer = new StringBuffer(length * 3);
        int i2 = 0;
        while (i2 < length && (charAt = str.charAt(i2)) < 128) {
            if (gNeedEscaping[charAt]) {
                stringBuffer.append('%');
                stringBuffer.append(gAfterEscaping1[charAt]);
                c2 = gAfterEscaping2[charAt];
            } else {
                c2 = (char) charAt;
            }
            stringBuffer.append(c2);
            i2++;
        }
        if (i2 < length) {
            try {
                byte[] bytes = str.substring(i2).getBytes("UTF-8");
                int length2 = bytes.length;
                for (byte b2 : bytes) {
                    if (b2 < 0) {
                        int i3 = b2 + 256;
                        stringBuffer.append('%');
                        stringBuffer.append(gHexChs[i3 >> 4]);
                        c = gHexChs[i3 & 15];
                    } else if (gNeedEscaping[b2]) {
                        stringBuffer.append('%');
                        stringBuffer.append(gAfterEscaping1[b2]);
                        c = gAfterEscaping2[b2];
                    } else {
                        c = (char) b2;
                    }
                    stringBuffer.append(c);
                }
                length = length2;
            } catch (UnsupportedEncodingException unused) {
                return str;
            }
        }
        return stringBuffer.length() != length ? stringBuffer.toString() : str;
    }

    @Override // org.apache.xerces.impl.dv.xs.TypeValidator
    public Object getActualValue(String str, ValidationContext validationContext) {
        try {
            if (str.length() != 0) {
                new URI(BASE_URI, encode(str));
            }
            return str;
        } catch (URI.MalformedURIException unused) {
            throw new InvalidDatatypeValueException("cvc-datatype-valid.1.2.1", new Object[]{str, "anyURI"});
        }
    }

    @Override // org.apache.xerces.impl.dv.xs.TypeValidator
    public short getAllowedFacets() {
        return 2079;
    }
}
