package org.apache.xerces.impl.dv.xs;

import javax.xml.datatype.XMLGregorianCalendar;
import org.apache.xerces.impl.dv.InvalidDatatypeValueException;
import org.apache.xerces.impl.dv.ValidationContext;
import org.apache.xerces.impl.dv.xs.AbstractDateTimeDV;
import org.apache.xerces.impl.xs.SchemaSymbols;
import org.apache.xmlbeans.impl.common.NameUtil;

public class DayDV extends AbstractDateTimeDV {
    public static final int DAY_SIZE = 5;

    @Override // org.apache.xerces.impl.dv.xs.AbstractDateTimeDV
    public String dateToString(AbstractDateTimeDV.DateTimeData dateTimeData) {
        StringBuffer stringBuffer = new StringBuffer(6);
        stringBuffer.append(NameUtil.HYPHEN);
        stringBuffer.append(NameUtil.HYPHEN);
        stringBuffer.append(NameUtil.HYPHEN);
        append(stringBuffer, dateTimeData.day, 2);
        append(stringBuffer, (char) dateTimeData.utc, 0);
        return stringBuffer.toString();
    }

    @Override // org.apache.xerces.impl.dv.xs.TypeValidator
    public Object getActualValue(String str, ValidationContext validationContext) {
        try {
            return parse(str);
        } catch (Exception unused) {
            throw new InvalidDatatypeValueException("cvc-datatype-valid.1.2.1", new Object[]{str, SchemaSymbols.ATTVAL_DAY});
        }
    }

    @Override // org.apache.xerces.impl.dv.xs.AbstractDateTimeDV
    public XMLGregorianCalendar getXMLGregorianCalendar(AbstractDateTimeDV.DateTimeData dateTimeData) {
        return AbstractDateTimeDV.datatypeFactory.newXMLGregorianCalendar(Integer.MIN_VALUE, Integer.MIN_VALUE, dateTimeData.unNormDay, Integer.MIN_VALUE, Integer.MIN_VALUE, Integer.MIN_VALUE, Integer.MIN_VALUE, dateTimeData.hasTimeZone() ? (dateTimeData.timezoneHr * 60) + dateTimeData.timezoneMin : Integer.MIN_VALUE);
    }

    public AbstractDateTimeDV.DateTimeData parse(String str) {
        AbstractDateTimeDV.DateTimeData dateTimeData = new AbstractDateTimeDV.DateTimeData(str, this);
        int length = str.length();
        if (str.charAt(0) == '-' && str.charAt(1) == '-' && str.charAt(2) == '-') {
            dateTimeData.year = 2000;
            dateTimeData.month = 1;
            dateTimeData.day = parseInt(str, 3, 5);
            if (5 < length) {
                if (isNextCharUTCSign(str, 5, length)) {
                    getTimeZone(str, dateTimeData, 5, length);
                } else {
                    throw new SchemaDateTimeException("Error in day parsing");
                }
            }
            validateDateTime(dateTimeData);
            saveUnnormalized(dateTimeData);
            int i2 = dateTimeData.utc;
            if (!(i2 == 0 || i2 == 90)) {
                normalize(dateTimeData);
            }
            dateTimeData.position = 2;
            return dateTimeData;
        }
        throw new SchemaDateTimeException("Error in day parsing");
    }
}
