package org.apache.xerces.impl.dv.xs;

import b.b.a.a.a;
import java.math.BigDecimal;
import java.math.BigInteger;
import org.apache.poi.ss.formula.ptg.UnaryMinusPtg;
import org.apache.poi.ss.util.SheetUtil;
import org.apache.xerces.impl.dv.InvalidDatatypeValueException;
import org.apache.xerces.impl.dv.ValidationContext;
import org.apache.xerces.xs.datatypes.XSDecimal;
import org.apache.xmlbeans.impl.common.NameUtil;

public class DecimalDV extends TypeValidator {

    public static class XDecimal implements XSDecimal {
        public String canonical;
        public int fracDigits = 0;
        public String fvalue = "";
        public int intDigits = 0;
        public boolean integer = false;
        public String ivalue = "";
        public int sign = 1;
        public int totalDigits = 0;

        public XDecimal(String str) {
            initD(str);
        }

        public XDecimal(String str, boolean z) {
            if (z) {
                initI(str);
            } else {
                initD(str);
            }
        }

        private int intComp(XDecimal xDecimal) {
            int i2 = this.intDigits;
            int i3 = xDecimal.intDigits;
            if (i2 != i3) {
                return i2 > i3 ? 1 : -1;
            }
            int compareTo = this.ivalue.compareTo(xDecimal.ivalue);
            if (compareTo != 0) {
                return compareTo > 0 ? 1 : -1;
            }
            int compareTo2 = this.fvalue.compareTo(xDecimal.fvalue);
            if (compareTo2 == 0) {
                return 0;
            }
            return compareTo2 > 0 ? 1 : -1;
        }

        private void makeCanonical() {
            String stringBuffer;
            int i2 = this.sign;
            if (i2 == 0) {
                this.canonical = this.integer ? "0" : "0.0";
                return;
            }
            if (!this.integer || i2 <= 0) {
                StringBuffer stringBuffer2 = new StringBuffer(this.totalDigits + 3);
                if (this.sign == -1) {
                    stringBuffer2.append(NameUtil.HYPHEN);
                }
                if (this.intDigits != 0) {
                    stringBuffer2.append(this.ivalue);
                } else {
                    stringBuffer2.append(SheetUtil.defaultChar);
                }
                if (!this.integer) {
                    stringBuffer2.append(NameUtil.PERIOD);
                    if (this.fracDigits != 0) {
                        stringBuffer2.append(this.fvalue);
                    } else {
                        stringBuffer2.append(SheetUtil.defaultChar);
                    }
                }
                stringBuffer = stringBuffer2.toString();
            } else {
                stringBuffer = this.ivalue;
            }
            this.canonical = stringBuffer;
        }

        public int compareTo(XDecimal xDecimal) {
            int i2 = this.sign;
            int i3 = xDecimal.sign;
            if (i2 != i3) {
                return i2 > i3 ? 1 : -1;
            }
            if (i2 == 0) {
                return 0;
            }
            return i2 * intComp(xDecimal);
        }

        public boolean equals(Object obj) {
            if (obj == this) {
                return true;
            }
            if (!(obj instanceof XDecimal)) {
                return false;
            }
            XDecimal xDecimal = (XDecimal) obj;
            int i2 = this.sign;
            if (i2 != xDecimal.sign) {
                return false;
            }
            if (i2 == 0) {
                return true;
            }
            return this.intDigits == xDecimal.intDigits && this.fracDigits == xDecimal.fracDigits && this.ivalue.equals(xDecimal.ivalue) && this.fvalue.equals(xDecimal.fvalue);
        }

        @Override // org.apache.xerces.xs.datatypes.XSDecimal
        public BigDecimal getBigDecimal() {
            return this.sign == 0 ? new BigDecimal(BigInteger.ZERO) : new BigDecimal(toString());
        }

        @Override // org.apache.xerces.xs.datatypes.XSDecimal
        public BigInteger getBigInteger() {
            if (this.fracDigits == 0) {
                int i2 = this.sign;
                if (i2 == 0) {
                    return BigInteger.ZERO;
                }
                if (i2 == 1) {
                    return new BigInteger(this.ivalue);
                }
                StringBuffer a = a.a(UnaryMinusPtg.MINUS);
                a.append(this.ivalue);
                return new BigInteger(a.toString());
            }
            throw new NumberFormatException();
        }

        @Override // org.apache.xerces.xs.datatypes.XSDecimal
        public byte getByte() {
            String str;
            if (this.fracDigits == 0) {
                int i2 = this.sign;
                if (i2 == 0) {
                    return 0;
                }
                if (i2 == 1) {
                    str = this.ivalue;
                } else {
                    StringBuffer a = a.a(UnaryMinusPtg.MINUS);
                    a.append(this.ivalue);
                    str = a.toString();
                }
                return Byte.parseByte(str);
            }
            throw new NumberFormatException();
        }

        @Override // org.apache.xerces.xs.datatypes.XSDecimal
        public int getInt() {
            String str;
            if (this.fracDigits == 0) {
                int i2 = this.sign;
                if (i2 == 0) {
                    return 0;
                }
                if (i2 == 1) {
                    str = this.ivalue;
                } else {
                    StringBuffer a = a.a(UnaryMinusPtg.MINUS);
                    a.append(this.ivalue);
                    str = a.toString();
                }
                return Integer.parseInt(str);
            }
            throw new NumberFormatException();
        }

        @Override // org.apache.xerces.xs.datatypes.XSDecimal
        public long getLong() {
            String str;
            if (this.fracDigits == 0) {
                int i2 = this.sign;
                if (i2 == 0) {
                    return 0;
                }
                if (i2 == 1) {
                    str = this.ivalue;
                } else {
                    StringBuffer a = a.a(UnaryMinusPtg.MINUS);
                    a.append(this.ivalue);
                    str = a.toString();
                }
                return Long.parseLong(str);
            }
            throw new NumberFormatException();
        }

        @Override // org.apache.xerces.xs.datatypes.XSDecimal
        public short getShort() {
            String str;
            if (this.fracDigits == 0) {
                int i2 = this.sign;
                if (i2 == 0) {
                    return 0;
                }
                if (i2 == 1) {
                    str = this.ivalue;
                } else {
                    StringBuffer a = a.a(UnaryMinusPtg.MINUS);
                    a.append(this.ivalue);
                    str = a.toString();
                }
                return Short.parseShort(str);
            }
            throw new NumberFormatException();
        }

        public void initD(String str) {
            int i2;
            int length = str.length();
            if (length != 0) {
                int i3 = 1;
                if (str.charAt(0) != '+') {
                    if (str.charAt(0) == '-') {
                        this.sign = -1;
                    } else {
                        i3 = 0;
                    }
                }
                int i4 = i3;
                while (i4 < length && str.charAt(i4) == '0') {
                    i4++;
                }
                int i5 = i4;
                while (i5 < length && TypeValidator.isDigit(str.charAt(i5))) {
                    i5++;
                }
                if (i5 >= length) {
                    length = 0;
                    i2 = 0;
                } else if (str.charAt(i5) == '.') {
                    i2 = i5 + 1;
                } else {
                    throw new NumberFormatException();
                }
                if (i3 == i5 && i2 == length) {
                    throw new NumberFormatException();
                }
                while (length > i2 && str.charAt(length - 1) == '0') {
                    length--;
                }
                for (int i6 = i2; i6 < length; i6++) {
                    if (!TypeValidator.isDigit(str.charAt(i6))) {
                        throw new NumberFormatException();
                    }
                }
                int i7 = i5 - i4;
                this.intDigits = i7;
                int i8 = length - i2;
                this.fracDigits = i8;
                this.totalDigits = i7 + i8;
                if (i7 > 0) {
                    this.ivalue = str.substring(i4, i5);
                    if (this.fracDigits <= 0) {
                        return;
                    }
                } else if (i8 <= 0) {
                    this.sign = 0;
                    return;
                }
                this.fvalue = str.substring(i2, length);
                return;
            }
            throw new NumberFormatException();
        }

        /* JADX WARNING: Removed duplicated region for block: B:20:0x0041  */
        /* JADX WARNING: Removed duplicated region for block: B:29:0x005f  */
        public void initI(String str) {
            int i2;
            int i3;
            int i4;
            int length = str.length();
            if (length != 0) {
                if (str.charAt(0) != '+') {
                    if (str.charAt(0) == '-') {
                        this.sign = -1;
                    } else {
                        i2 = 0;
                        i3 = i2;
                        while (i3 < length && str.charAt(i3) == '0') {
                            i3++;
                        }
                        i4 = i3;
                        while (i4 < length && TypeValidator.isDigit(str.charAt(i4))) {
                            i4++;
                        }
                        if (i4 >= length) {
                            throw new NumberFormatException();
                        } else if (i2 != i4) {
                            int i5 = i4 - i3;
                            this.intDigits = i5;
                            this.fracDigits = 0;
                            this.totalDigits = i5;
                            if (i5 > 0) {
                                this.ivalue = str.substring(i3, i4);
                            } else {
                                this.sign = 0;
                            }
                            this.integer = true;
                            return;
                        } else {
                            throw new NumberFormatException();
                        }
                    }
                }
                i2 = 1;
                i3 = i2;
                while (i3 < length) {
                    i3++;
                }
                i4 = i3;
                while (i4 < length) {
                    i4++;
                }
                if (i4 >= length) {
                }
            } else {
                throw new NumberFormatException();
            }
        }

        public synchronized String toString() {
            if (this.canonical == null) {
                makeCanonical();
            }
            return this.canonical;
        }
    }

    @Override // org.apache.xerces.impl.dv.xs.TypeValidator
    public final int compare(Object obj, Object obj2) {
        return ((XDecimal) obj).compareTo((XDecimal) obj2);
    }

    @Override // org.apache.xerces.impl.dv.xs.TypeValidator
    public Object getActualValue(String str, ValidationContext validationContext) {
        try {
            return new XDecimal(str);
        } catch (NumberFormatException unused) {
            throw new InvalidDatatypeValueException("cvc-datatype-valid.1.2.1", new Object[]{str, "decimal"});
        }
    }

    @Override // org.apache.xerces.impl.dv.xs.TypeValidator
    public final short getAllowedFacets() {
        return 4088;
    }

    @Override // org.apache.xerces.impl.dv.xs.TypeValidator
    public final int getFractionDigits(Object obj) {
        return ((XDecimal) obj).fracDigits;
    }

    @Override // org.apache.xerces.impl.dv.xs.TypeValidator
    public final int getTotalDigits(Object obj) {
        return ((XDecimal) obj).totalDigits;
    }
}
