package org.apache.xerces.impl.dv.xs;

import org.apache.poi.ss.formula.functions.NumericFunction;
import org.apache.poi.ss.util.SheetUtil;
import org.apache.xerces.impl.dv.InvalidDatatypeValueException;
import org.apache.xerces.impl.dv.ValidationContext;
import org.apache.xerces.xs.datatypes.XSDouble;
import org.apache.xmlbeans.impl.common.NameUtil;
import org.apache.xmlbeans.impl.util.XsTypeConverter;

public class DoubleDV extends TypeValidator {

    public static final class XDouble implements XSDouble {
        public String canonical;
        public final double value;

        public XDouble(String str) {
            double d2;
            if (DoubleDV.isPossibleFP(str)) {
                d2 = Double.parseDouble(str);
            } else if (str.equals(XsTypeConverter.POS_INF_LEX)) {
                d2 = Double.POSITIVE_INFINITY;
            } else if (str.equals(XsTypeConverter.NEG_INF_LEX)) {
                d2 = Double.NEGATIVE_INFINITY;
            } else if (str.equals(XsTypeConverter.NAN_LEX)) {
                d2 = Double.NaN;
            } else {
                throw new NumberFormatException(str);
            }
            this.value = d2;
        }

        /* access modifiers changed from: private */
        /* access modifiers changed from: public */
        private int compareTo(XDouble xDouble) {
            double d2 = xDouble.value;
            double d3 = this.value;
            if (d3 < d2) {
                return -1;
            }
            if (d3 > d2) {
                return 1;
            }
            if (d3 == d2) {
                return 0;
            }
            return (d3 == d3 || d2 == d2) ? 2 : 0;
        }

        public boolean equals(Object obj) {
            if (obj == this) {
                return true;
            }
            if (!(obj instanceof XDouble)) {
                return false;
            }
            double d2 = this.value;
            double d3 = ((XDouble) obj).value;
            if (d2 == d3) {
                return true;
            }
            return (d2 == d2 || d3 == d3) ? false : true;
        }

        @Override // org.apache.xerces.xs.datatypes.XSDouble
        public double getValue() {
            return this.value;
        }

        public int hashCode() {
            double d2 = this.value;
            if (d2 == NumericFunction.LOG_10_TO_BASE_e) {
                return 0;
            }
            long doubleToLongBits = Double.doubleToLongBits(d2);
            return (int) (doubleToLongBits ^ (doubleToLongBits >>> 32));
        }

        public boolean isIdentical(XDouble xDouble) {
            if (xDouble == this) {
                return true;
            }
            double d2 = this.value;
            double d3 = xDouble.value;
            return d2 == d3 ? d2 != NumericFunction.LOG_10_TO_BASE_e || Double.doubleToLongBits(d2) == Double.doubleToLongBits(xDouble.value) : (d2 == d2 || d3 == d3) ? false : true;
        }

        public synchronized String toString() {
            int i2;
            String str;
            int i3;
            if (this.canonical == null) {
                if (this.value == Double.POSITIVE_INFINITY) {
                    str = XsTypeConverter.POS_INF_LEX;
                } else if (this.value == Double.NEGATIVE_INFINITY) {
                    str = XsTypeConverter.NEG_INF_LEX;
                } else if (this.value != this.value) {
                    str = XsTypeConverter.NAN_LEX;
                } else if (this.value == NumericFunction.LOG_10_TO_BASE_e) {
                    str = "0.0E1";
                } else {
                    String d2 = Double.toString(this.value);
                    this.canonical = d2;
                    if (d2.indexOf(69) == -1) {
                        int length = this.canonical.length();
                        char[] cArr = new char[(length + 3)];
                        this.canonical.getChars(0, length, cArr, 0);
                        int i4 = cArr[0] == '-' ? 2 : 1;
                        if (this.value < 1.0d) {
                            if (this.value > -1.0d) {
                                int i5 = i4 + 1;
                                int i6 = i5;
                                while (cArr[i6] == '0') {
                                    i6++;
                                }
                                cArr[i4 - 1] = cArr[i6];
                                cArr[i4] = NameUtil.PERIOD;
                                int i7 = i6 + 1;
                                int i8 = i5;
                                while (i7 < length) {
                                    cArr[i8] = cArr[i7];
                                    i7++;
                                    i8++;
                                }
                                int i9 = i6 - i4;
                                int i10 = length - i9;
                                if (i10 == i5) {
                                    cArr[i10] = SheetUtil.defaultChar;
                                    i10++;
                                }
                                int i11 = i10 + 1;
                                cArr[i10] = 'E';
                                int i12 = i11 + 1;
                                cArr[i11] = NameUtil.HYPHEN;
                                i2 = i12 + 1;
                                cArr[i12] = (char) (i9 + 48);
                                str = new String(cArr, 0, i2);
                            }
                        }
                        int indexOf = this.canonical.indexOf(46);
                        for (int i13 = indexOf; i13 > i4; i13--) {
                            cArr[i13] = cArr[i13 - 1];
                        }
                        cArr[i4] = NameUtil.PERIOD;
                        while (true) {
                            i3 = length - 1;
                            if (cArr[i3] != '0') {
                                break;
                            }
                            length--;
                        }
                        if (cArr[i3] == '.') {
                            length++;
                        }
                        int i14 = length + 1;
                        cArr[length] = 'E';
                        i2 = i14 + 1;
                        cArr[i14] = (char) ((indexOf - i4) + 48);
                        str = new String(cArr, 0, i2);
                    }
                }
                this.canonical = str;
            }
            return this.canonical;
        }
    }

    public static boolean isPossibleFP(String str) {
        int length = str.length();
        for (int i2 = 0; i2 < length; i2++) {
            char charAt = str.charAt(i2);
            if (!((charAt >= '0' && charAt <= '9') || charAt == '.' || charAt == '-' || charAt == '+' || charAt == 'E' || charAt == 'e')) {
                return false;
            }
        }
        return true;
    }

    @Override // org.apache.xerces.impl.dv.xs.TypeValidator
    public int compare(Object obj, Object obj2) {
        return ((XDouble) obj).compareTo((XDouble) obj2);
    }

    @Override // org.apache.xerces.impl.dv.xs.TypeValidator
    public Object getActualValue(String str, ValidationContext validationContext) {
        try {
            return new XDouble(str);
        } catch (NumberFormatException unused) {
            throw new InvalidDatatypeValueException("cvc-datatype-valid.1.2.1", new Object[]{str, "double"});
        }
    }

    @Override // org.apache.xerces.impl.dv.xs.TypeValidator
    public short getAllowedFacets() {
        return 2552;
    }

    @Override // org.apache.xerces.impl.dv.xs.TypeValidator
    public boolean isIdentical(Object obj, Object obj2) {
        if (obj2 instanceof XDouble) {
            return ((XDouble) obj).isIdentical((XDouble) obj2);
        }
        return false;
    }
}
