package org.apache.xerces.impl.dv.xs;

import org.apache.poi.ss.util.SheetUtil;
import org.apache.xerces.impl.dv.InvalidDatatypeValueException;
import org.apache.xerces.impl.dv.ValidationContext;
import org.apache.xerces.xs.datatypes.XSFloat;
import org.apache.xmlbeans.impl.common.NameUtil;
import org.apache.xmlbeans.impl.util.XsTypeConverter;

public class FloatDV extends TypeValidator {

    public static final class XFloat implements XSFloat {
        public String canonical;
        public final float value;

        public XFloat(String str) {
            float f2;
            if (DoubleDV.isPossibleFP(str)) {
                f2 = Float.parseFloat(str);
            } else if (str.equals(XsTypeConverter.POS_INF_LEX)) {
                f2 = Float.POSITIVE_INFINITY;
            } else if (str.equals(XsTypeConverter.NEG_INF_LEX)) {
                f2 = Float.NEGATIVE_INFINITY;
            } else if (str.equals(XsTypeConverter.NAN_LEX)) {
                f2 = Float.NaN;
            } else {
                throw new NumberFormatException(str);
            }
            this.value = f2;
        }

        /* access modifiers changed from: private */
        /* access modifiers changed from: public */
        private int compareTo(XFloat xFloat) {
            float f2 = xFloat.value;
            float f3 = this.value;
            if (f3 < f2) {
                return -1;
            }
            if (f3 > f2) {
                return 1;
            }
            if (f3 == f2) {
                return 0;
            }
            return (f3 == f3 || f2 == f2) ? 2 : 0;
        }

        public boolean equals(Object obj) {
            if (obj == this) {
                return true;
            }
            if (!(obj instanceof XFloat)) {
                return false;
            }
            float f2 = this.value;
            float f3 = ((XFloat) obj).value;
            if (f2 == f3) {
                return true;
            }
            return (f2 == f2 || f3 == f3) ? false : true;
        }

        @Override // org.apache.xerces.xs.datatypes.XSFloat
        public float getValue() {
            return this.value;
        }

        public int hashCode() {
            float f2 = this.value;
            if (f2 == 0.0f) {
                return 0;
            }
            return Float.floatToIntBits(f2);
        }

        public boolean isIdentical(XFloat xFloat) {
            if (xFloat == this) {
                return true;
            }
            float f2 = this.value;
            float f3 = xFloat.value;
            return f2 == f3 ? f2 != 0.0f || Float.floatToIntBits(f2) == Float.floatToIntBits(xFloat.value) : (f2 == f2 || f3 == f3) ? false : true;
        }

        public synchronized String toString() {
            int i2;
            String str;
            int i3;
            if (this.canonical == null) {
                if (this.value == Float.POSITIVE_INFINITY) {
                    str = XsTypeConverter.POS_INF_LEX;
                } else if (this.value == Float.NEGATIVE_INFINITY) {
                    str = XsTypeConverter.NEG_INF_LEX;
                } else if (this.value != this.value) {
                    str = XsTypeConverter.NAN_LEX;
                } else if (this.value == 0.0f) {
                    str = "0.0E1";
                } else {
                    String f2 = Float.toString(this.value);
                    this.canonical = f2;
                    if (f2.indexOf(69) == -1) {
                        int length = this.canonical.length();
                        char[] cArr = new char[(length + 3)];
                        this.canonical.getChars(0, length, cArr, 0);
                        int i4 = cArr[0] == '-' ? 2 : 1;
                        if (this.value < 1.0f) {
                            if (this.value > -1.0f) {
                                int i5 = i4 + 1;
                                int i6 = i5;
                                while (cArr[i6] == '0') {
                                    i6++;
                                }
                                cArr[i4 - 1] = cArr[i6];
                                cArr[i4] = NameUtil.PERIOD;
                                int i7 = i6 + 1;
                                int i8 = i5;
                                while (i7 < length) {
                                    cArr[i8] = cArr[i7];
                                    i7++;
                                    i8++;
                                }
                                int i9 = i6 - i4;
                                int i10 = length - i9;
                                if (i10 == i5) {
                                    cArr[i10] = SheetUtil.defaultChar;
                                    i10++;
                                }
                                int i11 = i10 + 1;
                                cArr[i10] = 'E';
                                int i12 = i11 + 1;
                                cArr[i11] = NameUtil.HYPHEN;
                                i2 = i12 + 1;
                                cArr[i12] = (char) (i9 + 48);
                                str = new String(cArr, 0, i2);
                            }
                        }
                        int indexOf = this.canonical.indexOf(46);
                        for (int i13 = indexOf; i13 > i4; i13--) {
                            cArr[i13] = cArr[i13 - 1];
                        }
                        cArr[i4] = NameUtil.PERIOD;
                        while (true) {
                            i3 = length - 1;
                            if (cArr[i3] != '0') {
                                break;
                            }
                            length--;
                        }
                        if (cArr[i3] == '.') {
                            length++;
                        }
                        int i14 = length + 1;
                        cArr[length] = 'E';
                        i2 = i14 + 1;
                        cArr[i14] = (char) ((indexOf - i4) + 48);
                        str = new String(cArr, 0, i2);
                    }
                }
                this.canonical = str;
            }
            return this.canonical;
        }
    }

    @Override // org.apache.xerces.impl.dv.xs.TypeValidator
    public int compare(Object obj, Object obj2) {
        return ((XFloat) obj).compareTo((XFloat) obj2);
    }

    @Override // org.apache.xerces.impl.dv.xs.TypeValidator
    public Object getActualValue(String str, ValidationContext validationContext) {
        try {
            return new XFloat(str);
        } catch (NumberFormatException unused) {
            throw new InvalidDatatypeValueException("cvc-datatype-valid.1.2.1", new Object[]{str, "float"});
        }
    }

    @Override // org.apache.xerces.impl.dv.xs.TypeValidator
    public short getAllowedFacets() {
        return 2552;
    }

    @Override // org.apache.xerces.impl.dv.xs.TypeValidator
    public boolean isIdentical(Object obj, Object obj2) {
        if (obj2 instanceof XFloat) {
            return ((XFloat) obj).isIdentical((XFloat) obj2);
        }
        return false;
    }
}
