package org.apache.xerces.impl.dv.xs;

import b.b.a.a.a;
import javax.xml.datatype.XMLGregorianCalendar;
import org.apache.xerces.impl.dv.InvalidDatatypeValueException;
import org.apache.xerces.impl.dv.ValidationContext;
import org.apache.xerces.impl.dv.xs.AbstractDateTimeDV;
import org.apache.xerces.impl.xs.SchemaSymbols;
import org.apache.xmlbeans.impl.common.NameUtil;

public class MonthDayDV extends AbstractDateTimeDV {
    public static final int MONTHDAY_SIZE = 7;

    @Override // org.apache.xerces.impl.dv.xs.AbstractDateTimeDV
    public String dateToString(AbstractDateTimeDV.DateTimeData dateTimeData) {
        StringBuffer stringBuffer = new StringBuffer(8);
        stringBuffer.append(NameUtil.HYPHEN);
        stringBuffer.append(NameUtil.HYPHEN);
        append(stringBuffer, dateTimeData.month, 2);
        stringBuffer.append(NameUtil.HYPHEN);
        append(stringBuffer, dateTimeData.day, 2);
        append(stringBuffer, (char) dateTimeData.utc, 0);
        return stringBuffer.toString();
    }

    @Override // org.apache.xerces.impl.dv.xs.TypeValidator
    public Object getActualValue(String str, ValidationContext validationContext) {
        try {
            return parse(str);
        } catch (Exception unused) {
            throw new InvalidDatatypeValueException("cvc-datatype-valid.1.2.1", new Object[]{str, SchemaSymbols.ATTVAL_MONTHDAY});
        }
    }

    @Override // org.apache.xerces.impl.dv.xs.AbstractDateTimeDV
    public XMLGregorianCalendar getXMLGregorianCalendar(AbstractDateTimeDV.DateTimeData dateTimeData) {
        return AbstractDateTimeDV.datatypeFactory.newXMLGregorianCalendar(Integer.MIN_VALUE, dateTimeData.unNormMonth, dateTimeData.unNormDay, Integer.MIN_VALUE, Integer.MIN_VALUE, Integer.MIN_VALUE, Integer.MIN_VALUE, dateTimeData.hasTimeZone() ? (dateTimeData.timezoneHr * 60) + dateTimeData.timezoneMin : Integer.MIN_VALUE);
    }

    public AbstractDateTimeDV.DateTimeData parse(String str) {
        AbstractDateTimeDV.DateTimeData dateTimeData = new AbstractDateTimeDV.DateTimeData(str, this);
        int length = str.length();
        dateTimeData.year = 2000;
        if (str.charAt(0) == '-' && str.charAt(1) == '-') {
            dateTimeData.month = parseInt(str, 2, 4);
            if (str.charAt(4) == '-') {
                dateTimeData.day = parseInt(str, 5, 7);
                if (7 < length) {
                    if (isNextCharUTCSign(str, 7, length)) {
                        getTimeZone(str, dateTimeData, 7, length);
                    } else {
                        throw new SchemaDateTimeException(a.a("Error in month parsing:", str));
                    }
                }
                validateDateTime(dateTimeData);
                saveUnnormalized(dateTimeData);
                int i2 = dateTimeData.utc;
                if (!(i2 == 0 || i2 == 90)) {
                    normalize(dateTimeData);
                }
                dateTimeData.position = 1;
                return dateTimeData;
            }
            throw new SchemaDateTimeException(a.a("Invalid format for gMonthDay: ", str));
        }
        throw new SchemaDateTimeException(a.a("Invalid format for gMonthDay: ", str));
    }
}
