package org.apache.xerces.impl.dv.xs;

import org.apache.poi.ss.util.SheetUtil;
import org.apache.xerces.impl.dv.InvalidDatatypeValueException;
import org.apache.xerces.impl.dv.ValidationContext;
import org.apache.xmlbeans.impl.util.XsTypeConverter;

public class PrecisionDecimalDV extends TypeValidator {

    public static class XPrecisionDecimal {
        public String canonical;
        public int fracDigits = 0;
        public String fvalue = "";
        public int intDigits = 0;
        public String ivalue = "";
        public int pvalue = 0;
        public int sign = 1;
        public int totalDigits = 0;

        public XPrecisionDecimal(String str) {
            if (str.equals(XsTypeConverter.NAN_LEX)) {
                this.ivalue = str;
                this.sign = 0;
            }
            if (str.equals("+INF") || str.equals(XsTypeConverter.POS_INF_LEX) || str.equals(XsTypeConverter.NEG_INF_LEX)) {
                this.ivalue = str.charAt(0) == '+' ? str.substring(1) : str;
            } else {
                initD(str);
            }
        }

        private int compare(XPrecisionDecimal xPrecisionDecimal) {
            if (this.pvalue == 0 && xPrecisionDecimal.pvalue == 0) {
                return intComp(xPrecisionDecimal);
            }
            int i2 = this.pvalue;
            int i3 = xPrecisionDecimal.pvalue;
            if (i2 == i3) {
                return intComp(xPrecisionDecimal);
            }
            int i4 = this.intDigits;
            int i5 = i4 + i2;
            int i6 = xPrecisionDecimal.intDigits;
            if (i5 != i6 + i3) {
                return i4 + i2 > i6 + i3 ? 1 : -1;
            }
            int i7 = 0;
            if (i2 > i3) {
                int i8 = i2 - i3;
                StringBuffer stringBuffer = new StringBuffer(this.ivalue);
                StringBuffer stringBuffer2 = new StringBuffer(this.fvalue);
                while (i7 < i8) {
                    if (i7 < this.fracDigits) {
                        stringBuffer.append(this.fvalue.charAt(i7));
                        stringBuffer2.deleteCharAt(i7);
                    } else {
                        stringBuffer.append(SheetUtil.defaultChar);
                    }
                    i7++;
                }
                return compareDecimal(stringBuffer.toString(), xPrecisionDecimal.ivalue, stringBuffer2.toString(), xPrecisionDecimal.fvalue);
            }
            int i9 = i3 - i2;
            StringBuffer stringBuffer3 = new StringBuffer(xPrecisionDecimal.ivalue);
            StringBuffer stringBuffer4 = new StringBuffer(xPrecisionDecimal.fvalue);
            while (i7 < i9) {
                if (i7 < xPrecisionDecimal.fracDigits) {
                    stringBuffer3.append(xPrecisionDecimal.fvalue.charAt(i7));
                    stringBuffer4.deleteCharAt(i7);
                } else {
                    stringBuffer3.append(SheetUtil.defaultChar);
                }
                i7++;
            }
            return compareDecimal(this.ivalue, stringBuffer3.toString(), this.fvalue, stringBuffer4.toString());
        }

        private int compareDecimal(String str, String str2, String str3, String str4) {
            int compareTo = str.compareTo(str3);
            if (compareTo != 0) {
                return compareTo > 0 ? 1 : -1;
            }
            if (str2.equals(str4)) {
                return 0;
            }
            StringBuffer stringBuffer = new StringBuffer(str2);
            StringBuffer stringBuffer2 = new StringBuffer(str4);
            truncateTrailingZeros(stringBuffer, stringBuffer2);
            int compareTo2 = stringBuffer.toString().compareTo(stringBuffer2.toString());
            if (compareTo2 == 0) {
                return 0;
            }
            return compareTo2 > 0 ? 1 : -1;
        }

        private int compareFractionalPart(XPrecisionDecimal xPrecisionDecimal) {
            if (this.fvalue.equals(xPrecisionDecimal.fvalue)) {
                return 0;
            }
            StringBuffer stringBuffer = new StringBuffer(this.fvalue);
            StringBuffer stringBuffer2 = new StringBuffer(xPrecisionDecimal.fvalue);
            truncateTrailingZeros(stringBuffer, stringBuffer2);
            return stringBuffer.toString().compareTo(stringBuffer2.toString());
        }

        private int intComp(XPrecisionDecimal xPrecisionDecimal) {
            int i2 = this.intDigits;
            int i3 = xPrecisionDecimal.intDigits;
            return i2 != i3 ? i2 > i3 ? 1 : -1 : compareDecimal(this.ivalue, xPrecisionDecimal.ivalue, this.fvalue, xPrecisionDecimal.fvalue);
        }

        private void makeCanonical() {
            this.canonical = "TBD by Working Group";
        }

        private void truncateTrailingZeros(StringBuffer stringBuffer, StringBuffer stringBuffer2) {
            int length = stringBuffer.length();
            while (true) {
                length--;
                if (length >= 0 && stringBuffer.charAt(length) == '0') {
                    stringBuffer.deleteCharAt(length);
                }
            }
            int length2 = stringBuffer2.length() - 1;
            while (length2 >= 0 && stringBuffer2.charAt(length2) == '0') {
                stringBuffer2.deleteCharAt(length2);
                length2--;
            }
        }

        public int compareTo(XPrecisionDecimal xPrecisionDecimal) {
            if (this.sign == 0) {
                return 2;
            }
            if (this.ivalue.equals(XsTypeConverter.POS_INF_LEX) || xPrecisionDecimal.ivalue.equals(XsTypeConverter.POS_INF_LEX)) {
                if (this.ivalue.equals(xPrecisionDecimal.ivalue)) {
                    return 0;
                }
                return this.ivalue.equals(XsTypeConverter.POS_INF_LEX) ? 1 : -1;
            } else if (!this.ivalue.equals(XsTypeConverter.NEG_INF_LEX) && !xPrecisionDecimal.ivalue.equals(XsTypeConverter.NEG_INF_LEX)) {
                int i2 = this.sign;
                int i3 = xPrecisionDecimal.sign;
                return i2 != i3 ? i2 > i3 ? 1 : -1 : i2 * compare(xPrecisionDecimal);
            } else if (this.ivalue.equals(xPrecisionDecimal.ivalue)) {
                return 0;
            } else {
                return this.ivalue.equals(XsTypeConverter.NEG_INF_LEX) ? -1 : 1;
            }
        }

        public boolean equals(Object obj) {
            if (obj == this) {
                return true;
            }
            return (obj instanceof XPrecisionDecimal) && compareTo((XPrecisionDecimal) obj) == 0;
        }

        /* JADX WARNING: Removed duplicated region for block: B:20:0x0041  */
        /* JADX WARNING: Removed duplicated region for block: B:38:0x0088 A[ADDED_TO_REGION] */
        /* JADX WARNING: Removed duplicated region for block: B:45:0x009e  */
        /* JADX WARNING: Removed duplicated region for block: B:48:0x00a8  */
        /* JADX WARNING: Removed duplicated region for block: B:53:0x00c3  */
        public void initD(String str) {
            int i2;
            int i3;
            int i4;
            int i5;
            int i6;
            int i7;
            int length = str.length();
            if (length != 0) {
                int i8 = 0;
                if (str.charAt(0) != '+') {
                    if (str.charAt(0) == '-') {
                        this.sign = -1;
                    } else {
                        i2 = 0;
                        i3 = i2;
                        while (i3 < length && str.charAt(i3) == '0') {
                            i3++;
                        }
                        i4 = i3;
                        while (i4 < length && TypeValidator.isDigit(str.charAt(i4))) {
                            i4++;
                        }
                        if (i4 < length) {
                            if (str.charAt(i4) != '.' && str.charAt(i4) != 'E' && str.charAt(i4) != 'e') {
                                throw new NumberFormatException();
                            } else if (str.charAt(i4) == '.') {
                                i8 = i4 + 1;
                                i5 = i8;
                                while (i5 < length && TypeValidator.isDigit(str.charAt(i5))) {
                                    i5++;
                                }
                                if (i2 == i4 || i8 != i5) {
                                    for (i6 = i8; i6 < i5; i6++) {
                                        if (!TypeValidator.isDigit(str.charAt(i6))) {
                                            throw new NumberFormatException();
                                        }
                                    }
                                    i7 = i4 - i3;
                                    this.intDigits = i7;
                                    this.fracDigits = i5 - i8;
                                    if (i7 > 0) {
                                        this.ivalue = str.substring(i3, i4);
                                    }
                                    if (this.fracDigits > 0) {
                                        this.fvalue = str.substring(i8, i5);
                                        if (i5 < length) {
                                            this.pvalue = Integer.parseInt(str.substring(i5 + 1, length));
                                        }
                                    }
                                    this.totalDigits = this.intDigits + this.fracDigits;
                                    return;
                                }
                                throw new NumberFormatException();
                            } else {
                                this.pvalue = Integer.parseInt(str.substring(i4 + 1, length));
                            }
                        }
                        i5 = 0;
                        if (i2 == i4) {
                        }
                        while (i6 < i5) {
                        }
                        i7 = i4 - i3;
                        this.intDigits = i7;
                        this.fracDigits = i5 - i8;
                        if (i7 > 0) {
                        }
                        if (this.fracDigits > 0) {
                        }
                        this.totalDigits = this.intDigits + this.fracDigits;
                        return;
                    }
                }
                i2 = 1;
                i3 = i2;
                while (i3 < length) {
                    i3++;
                }
                i4 = i3;
                while (i4 < length) {
                    i4++;
                }
                if (i4 < length) {
                }
                i5 = 0;
                if (i2 == i4) {
                }
                while (i6 < i5) {
                }
                i7 = i4 - i3;
                this.intDigits = i7;
                this.fracDigits = i5 - i8;
                if (i7 > 0) {
                }
                if (this.fracDigits > 0) {
                }
                this.totalDigits = this.intDigits + this.fracDigits;
                return;
            }
            throw new NumberFormatException();
        }

        public boolean isIdentical(XPrecisionDecimal xPrecisionDecimal) {
            if (!this.ivalue.equals(xPrecisionDecimal.ivalue) || (!this.ivalue.equals(XsTypeConverter.POS_INF_LEX) && !this.ivalue.equals(XsTypeConverter.NEG_INF_LEX) && !this.ivalue.equals(XsTypeConverter.NAN_LEX))) {
                return this.sign == xPrecisionDecimal.sign && this.intDigits == xPrecisionDecimal.intDigits && this.fracDigits == xPrecisionDecimal.fracDigits && this.pvalue == xPrecisionDecimal.pvalue && this.ivalue.equals(xPrecisionDecimal.ivalue) && this.fvalue.equals(xPrecisionDecimal.fvalue);
            }
            return true;
        }

        public synchronized String toString() {
            if (this.canonical == null) {
                makeCanonical();
            }
            return this.canonical;
        }
    }

    @Override // org.apache.xerces.impl.dv.xs.TypeValidator
    public int compare(Object obj, Object obj2) {
        return ((XPrecisionDecimal) obj).compareTo((XPrecisionDecimal) obj2);
    }

    @Override // org.apache.xerces.impl.dv.xs.TypeValidator
    public Object getActualValue(String str, ValidationContext validationContext) {
        try {
            return new XPrecisionDecimal(str);
        } catch (NumberFormatException unused) {
            throw new InvalidDatatypeValueException("cvc-datatype-valid.1.2.1", new Object[]{str, "precisionDecimal"});
        }
    }

    @Override // org.apache.xerces.impl.dv.xs.TypeValidator
    public short getAllowedFacets() {
        return 4088;
    }

    @Override // org.apache.xerces.impl.dv.xs.TypeValidator
    public int getFractionDigits(Object obj) {
        return ((XPrecisionDecimal) obj).fracDigits;
    }

    @Override // org.apache.xerces.impl.dv.xs.TypeValidator
    public int getTotalDigits(Object obj) {
        return ((XPrecisionDecimal) obj).totalDigits;
    }

    @Override // org.apache.xerces.impl.dv.xs.TypeValidator
    public boolean isIdentical(Object obj, Object obj2) {
        if (!(obj2 instanceof XPrecisionDecimal) || !(obj instanceof XPrecisionDecimal)) {
            return false;
        }
        return ((XPrecisionDecimal) obj).isIdentical((XPrecisionDecimal) obj2);
    }
}
