package org.apache.xerces.impl.io;

import java.io.InputStream;
import java.io.Reader;
import java.util.Locale;
import org.apache.xerces.util.MessageFormatter;

public final class ASCIIReader extends Reader {
    public static final int DEFAULT_BUFFER_SIZE = 2048;
    public final byte[] fBuffer;
    public final MessageFormatter fFormatter;
    public final InputStream fInputStream;
    public final Locale fLocale;

    public ASCIIReader(InputStream inputStream, int i2, MessageFormatter messageFormatter, Locale locale) {
        this(inputStream, new byte[i2], messageFormatter, locale);
    }

    public ASCIIReader(InputStream inputStream, MessageFormatter messageFormatter, Locale locale) {
        this(inputStream, 2048, messageFormatter, locale);
    }

    public ASCIIReader(InputStream inputStream, byte[] bArr, MessageFormatter messageFormatter, Locale locale) {
        this.fInputStream = inputStream;
        this.fBuffer = bArr;
        this.fFormatter = messageFormatter;
        this.fLocale = locale;
    }

    @Override // java.io.Closeable, java.io.Reader, java.lang.AutoCloseable
    public void close() {
        this.fInputStream.close();
    }

    @Override // java.io.Reader
    public void mark(int i2) {
        this.fInputStream.mark(i2);
    }

    public boolean markSupported() {
        return this.fInputStream.markSupported();
    }

    @Override // java.io.Reader
    public int read() {
        int read = this.fInputStream.read();
        if (read < 128) {
            return read;
        }
        throw new MalformedByteSequenceException(this.fFormatter, this.fLocale, "http://www.w3.org/TR/1998/REC-xml-19980210", "InvalidASCII", new Object[]{Integer.toString(read)});
    }

    @Override // java.io.Reader
    public int read(char[] cArr, int i2, int i3) {
        byte[] bArr = this.fBuffer;
        if (i3 > bArr.length) {
            i3 = bArr.length;
        }
        int read = this.fInputStream.read(this.fBuffer, 0, i3);
        for (int i4 = 0; i4 < read; i4++) {
            byte b2 = this.fBuffer[i4];
            if (b2 >= 0) {
                cArr[i2 + i4] = (char) b2;
            } else {
                throw new MalformedByteSequenceException(this.fFormatter, this.fLocale, "http://www.w3.org/TR/1998/REC-xml-19980210", "InvalidASCII", new Object[]{Integer.toString(b2 & 255)});
            }
        }
        return read;
    }

    @Override // java.io.Reader
    public boolean ready() {
        return false;
    }

    @Override // java.io.Reader
    public void reset() {
        this.fInputStream.reset();
    }

    @Override // java.io.Reader
    public long skip(long j) {
        return this.fInputStream.skip(j);
    }
}
