package org.apache.xerces.impl.io;

import java.io.InputStream;
import java.io.Reader;

public final class Latin1Reader extends Reader {
    public static final int DEFAULT_BUFFER_SIZE = 2048;
    public final byte[] fBuffer;
    public final InputStream fInputStream;

    public Latin1Reader(InputStream inputStream) {
        this(inputStream, 2048);
    }

    public Latin1Reader(InputStream inputStream, int i2) {
        this(inputStream, new byte[i2]);
    }

    public Latin1Reader(InputStream inputStream, byte[] bArr) {
        this.fInputStream = inputStream;
        this.fBuffer = bArr;
    }

    @Override // java.io.Closeable, java.io.Reader, java.lang.AutoCloseable
    public void close() {
        this.fInputStream.close();
    }

    @Override // java.io.Reader
    public void mark(int i2) {
        this.fInputStream.mark(i2);
    }

    public boolean markSupported() {
        return this.fInputStream.markSupported();
    }

    @Override // java.io.Reader
    public int read() {
        return this.fInputStream.read();
    }

    @Override // java.io.Reader
    public int read(char[] cArr, int i2, int i3) {
        byte[] bArr = this.fBuffer;
        if (i3 > bArr.length) {
            i3 = bArr.length;
        }
        int read = this.fInputStream.read(this.fBuffer, 0, i3);
        for (int i4 = 0; i4 < read; i4++) {
            cArr[i2 + i4] = (char) (this.fBuffer[i4] & 255);
        }
        return read;
    }

    @Override // java.io.Reader
    public boolean ready() {
        return false;
    }

    @Override // java.io.Reader
    public void reset() {
        this.fInputStream.reset();
    }

    @Override // java.io.Reader
    public long skip(long j) {
        return this.fInputStream.skip(j);
    }
}
