package org.apache.xerces.impl.io;

import java.io.InputStream;
import java.io.Reader;

public final class UCSReader extends Reader {
    public static final int DEFAULT_BUFFER_SIZE = 8192;
    public static final short UCS2BE = 2;
    public static final short UCS2LE = 1;
    public static final short UCS4BE = 8;
    public static final short UCS4LE = 4;
    public final byte[] fBuffer;
    public final short fEncoding;
    public final InputStream fInputStream;

    public UCSReader(InputStream inputStream, int i2, short s) {
        this(inputStream, new byte[i2], s);
    }

    public UCSReader(InputStream inputStream, short s) {
        this(inputStream, 8192, s);
    }

    public UCSReader(InputStream inputStream, byte[] bArr, short s) {
        this.fInputStream = inputStream;
        this.fBuffer = bArr;
        this.fEncoding = s;
    }

    @Override // java.io.Closeable, java.io.Reader, java.lang.AutoCloseable
    public void close() {
        this.fInputStream.close();
    }

    @Override // java.io.Reader
    public void mark(int i2) {
        this.fInputStream.mark(i2);
    }

    public boolean markSupported() {
        return this.fInputStream.markSupported();
    }

    @Override // java.io.Reader
    public int read() {
        int read;
        int i2;
        int read2;
        int read3 = this.fInputStream.read() & 255;
        if (read3 == 255 || (read = this.fInputStream.read() & 255) == 255) {
            return -1;
        }
        short s = this.fEncoding;
        if (s >= 4) {
            int read4 = this.fInputStream.read() & 255;
            if (read4 == 255 || (read2 = this.fInputStream.read() & 255) == 255) {
                return -1;
            }
            if (this.fEncoding == 8) {
                return (read3 << 24) + (read << 16) + (read4 << 8) + read2;
            }
            i2 = (read2 << 24) + (read4 << 16) + (read << 8);
        } else if (s == 2) {
            return (read3 << 8) + read;
        } else {
            i2 = read << 8;
        }
        return i2 + read3;
    }

    @Override // java.io.Reader
    public int read(char[] cArr, int i2, int i3) {
        int i4 = 1;
        int i5 = i3 << (this.fEncoding >= 4 ? 2 : 1);
        byte[] bArr = this.fBuffer;
        if (i5 > bArr.length) {
            i5 = bArr.length;
        }
        int read = this.fInputStream.read(this.fBuffer, 0, i5);
        if (read == -1) {
            return -1;
        }
        if (this.fEncoding >= 4) {
            int i6 = (4 - (read & 3)) & 3;
            int i7 = 0;
            while (true) {
                if (i7 >= i6) {
                    break;
                }
                int read2 = this.fInputStream.read();
                if (read2 == -1) {
                    while (i7 < i6) {
                        this.fBuffer[read + i7] = 0;
                        i7++;
                    }
                } else {
                    this.fBuffer[read + i7] = (byte) read2;
                    i7++;
                }
            }
            read += i6;
        } else if ((read & 1) != 0) {
            read++;
            int read3 = this.fInputStream.read();
            if (read3 == -1) {
                this.fBuffer[read] = 0;
            } else {
                this.fBuffer[read] = (byte) read3;
            }
        }
        if (this.fEncoding >= 4) {
            i4 = 2;
        }
        int i8 = read >> i4;
        int i9 = 0;
        for (int i10 = 0; i10 < i8; i10++) {
            byte[] bArr2 = this.fBuffer;
            int i11 = i9 + 1;
            int i12 = bArr2[i9] & 255;
            int i13 = i11 + 1;
            int i14 = bArr2[i11] & 255;
            short s = this.fEncoding;
            if (s >= 4) {
                int i15 = i13 + 1;
                int i16 = bArr2[i13] & 255;
                int i17 = i15 + 1;
                int i18 = bArr2[i15] & 255;
                if (s == 8) {
                    cArr[i2 + i10] = (char) ((i12 << 24) + (i14 << 16) + (i16 << 8) + i18);
                } else {
                    cArr[i2 + i10] = (char) ((i18 << 24) + (i16 << 16) + (i14 << 8) + i12);
                }
                i9 = i17;
            } else {
                int i19 = i2 + i10;
                if (s == 2) {
                    cArr[i19] = (char) ((i12 << 8) + i14);
                } else {
                    cArr[i19] = (char) ((i14 << 8) + i12);
                }
                i9 = i13;
            }
        }
        return i8;
    }

    @Override // java.io.Reader
    public boolean ready() {
        return false;
    }

    @Override // java.io.Reader
    public void reset() {
        this.fInputStream.reset();
    }

    @Override // java.io.Reader
    public long skip(long j) {
        int i2 = this.fEncoding >= 4 ? 2 : 1;
        long skip = this.fInputStream.skip(j << i2);
        int i3 = ((((long) (i2 | 1)) & skip) > 0 ? 1 : ((((long) (i2 | 1)) & skip) == 0 ? 0 : -1));
        long j2 = skip >> i2;
        return i3 == 0 ? j2 : j2 + 1;
    }
}
