package org.apache.xerces.impl.io;

import java.io.IOException;
import java.io.InputStream;
import java.io.Reader;
import java.util.Locale;
import org.apache.poi.hssf.usermodel.HSSFShapeTypes;
import org.apache.xerces.impl.msg.XMLMessageFormatter;
import org.apache.xerces.util.MessageFormatter;

public final class UTF8Reader extends Reader {
    public static final boolean DEBUG_READ = false;
    public static final int DEFAULT_BUFFER_SIZE = 2048;
    public final byte[] fBuffer;
    public final MessageFormatter fFormatter;
    public final InputStream fInputStream;
    public final Locale fLocale;
    public int fOffset;
    public int fSurrogate;

    public UTF8Reader(InputStream inputStream) {
        this(inputStream, 2048, new XMLMessageFormatter(), Locale.getDefault());
    }

    public UTF8Reader(InputStream inputStream, int i2, MessageFormatter messageFormatter, Locale locale) {
        this(inputStream, new byte[i2], messageFormatter, locale);
    }

    public UTF8Reader(InputStream inputStream, MessageFormatter messageFormatter, Locale locale) {
        this(inputStream, 2048, messageFormatter, locale);
    }

    public UTF8Reader(InputStream inputStream, byte[] bArr, MessageFormatter messageFormatter, Locale locale) {
        this.fSurrogate = -1;
        this.fInputStream = inputStream;
        this.fBuffer = bArr;
        this.fFormatter = messageFormatter;
        this.fLocale = locale;
    }

    private void expectedByte(int i2, int i3) {
        throw new MalformedByteSequenceException(this.fFormatter, this.fLocale, "http://www.w3.org/TR/1998/REC-xml-19980210", "ExpectedByte", new Object[]{Integer.toString(i2), Integer.toString(i3)});
    }

    private void invalidByte(int i2, int i3, int i4) {
        throw new MalformedByteSequenceException(this.fFormatter, this.fLocale, "http://www.w3.org/TR/1998/REC-xml-19980210", "InvalidByte", new Object[]{Integer.toString(i2), Integer.toString(i3)});
    }

    private void invalidSurrogate(int i2) {
        throw new MalformedByteSequenceException(this.fFormatter, this.fLocale, "http://www.w3.org/TR/1998/REC-xml-19980210", "InvalidHighSurrogate", new Object[]{Integer.toHexString(i2)});
    }

    @Override // java.io.Closeable, java.io.Reader, java.lang.AutoCloseable
    public void close() {
        this.fInputStream.close();
    }

    @Override // java.io.Reader
    public void mark(int i2) {
        throw new IOException(this.fFormatter.formatMessage(this.fLocale, "OperationNotSupported", new Object[]{"mark()", "UTF-8"}));
    }

    public boolean markSupported() {
        return false;
    }

    @Override // java.io.Reader
    public int read() {
        int i2;
        int i3;
        int i4;
        int i5;
        int i6 = this.fSurrogate;
        int i7 = -1;
        if (i6 == -1) {
            int i8 = 0;
            if (this.fOffset == 0) {
                i2 = this.fInputStream.read();
            } else {
                i2 = this.fBuffer[0] & 255;
                i8 = 1;
            }
            if (i2 == -1) {
                return -1;
            }
            if (i2 < 128) {
                return (char) i2;
            }
            if ((i2 & 224) == 192 && (i2 & 30) != 0) {
                int read = i8 == this.fOffset ? this.fInputStream.read() : this.fBuffer[i8] & 255;
                if (read == -1) {
                    expectedByte(2, 2);
                }
                if ((read & HSSFShapeTypes.ActionButtonInformation) != 128) {
                    invalidByte(2, 2, read);
                }
                return (read & 63) | ((i2 << 6) & 1984);
            } else if ((i2 & 240) == 224) {
                if (i8 == this.fOffset) {
                    i5 = this.fInputStream.read();
                } else {
                    i5 = this.fBuffer[i8] & 255;
                    i8++;
                }
                if (i5 == -1) {
                    expectedByte(2, 3);
                }
                if ((i5 & HSSFShapeTypes.ActionButtonInformation) != 128 || ((i2 == 237 && i5 >= 160) || ((i2 & 15) == 0 && (i5 & 32) == 0))) {
                    invalidByte(2, 3, i5);
                }
                int read2 = i8 == this.fOffset ? this.fInputStream.read() : this.fBuffer[i8] & 255;
                if (read2 == -1) {
                    expectedByte(3, 3);
                }
                if ((read2 & HSSFShapeTypes.ActionButtonInformation) != 128) {
                    invalidByte(3, 3, read2);
                }
                return ((i5 << 6) & 4032) | ((i2 << 12) & 61440) | (read2 & 63);
            } else if ((i2 & 248) == 240) {
                if (i8 == this.fOffset) {
                    i3 = this.fInputStream.read();
                } else {
                    i3 = this.fBuffer[i8] & 255;
                    i8++;
                }
                if (i3 == -1) {
                    expectedByte(2, 4);
                }
                if ((i3 & HSSFShapeTypes.ActionButtonInformation) != 128 || ((i3 & 48) == 0 && (i2 & 7) == 0)) {
                    invalidByte(2, 3, i3);
                }
                if (i8 == this.fOffset) {
                    i4 = this.fInputStream.read();
                } else {
                    i4 = this.fBuffer[i8] & 255;
                    i8++;
                }
                if (i4 == -1) {
                    expectedByte(3, 4);
                }
                if ((i4 & HSSFShapeTypes.ActionButtonInformation) != 128) {
                    invalidByte(3, 3, i4);
                }
                int read3 = i8 == this.fOffset ? this.fInputStream.read() : this.fBuffer[i8] & 255;
                if (read3 == -1) {
                    expectedByte(4, 4);
                }
                if ((read3 & HSSFShapeTypes.ActionButtonInformation) != 128) {
                    invalidByte(4, 4, read3);
                }
                int i9 = ((i2 << 2) & 28) | ((i3 >> 4) & 3);
                if (i9 > 16) {
                    invalidSurrogate(i9);
                }
                i6 = ((i3 << 2) & 60) | (((i9 - 1) << 6) & 960) | 55296 | ((i4 >> 4) & 3);
                i7 = 56320 | ((i4 << 6) & 960) | (read3 & 63);
            } else {
                invalidByte(1, 1, i2);
                return i6;
            }
        }
        this.fSurrogate = i7;
        return i6;
    }

    @Override // java.io.Reader
    public int read(char[] cArr, int i2, int i3) {
        int i4;
        int i5;
        int i6;
        int i7;
        int i8;
        int i9;
        int i10;
        int i11;
        int i12;
        int i13;
        int i14;
        int i15 = this.fOffset;
        int i16 = -1;
        if (i15 == 0) {
            byte[] bArr = this.fBuffer;
            i6 = i3 > bArr.length ? bArr.length : i3;
            int i17 = this.fSurrogate;
            if (i17 != -1) {
                i4 = i2 + 1;
                cArr[i2] = (char) i17;
                this.fSurrogate = -1;
                i6--;
            } else {
                i4 = i2;
            }
            int read = this.fInputStream.read(this.fBuffer, 0, i6);
            if (read == -1) {
                return -1;
            }
            i5 = read + (i4 - i2);
        } else {
            this.fOffset = 0;
            i5 = i15;
            i6 = i3;
            i4 = i2;
        }
        int i18 = 0;
        while (i18 < i5) {
            byte b2 = this.fBuffer[i18];
            if (b2 < 0) {
                break;
            }
            cArr[i4] = (char) b2;
            i18++;
            i4++;
        }
        int i19 = i5;
        while (i18 < i5) {
            byte[] bArr2 = this.fBuffer;
            byte b3 = bArr2[i18];
            if (b3 >= 0) {
                i13 = i4 + 1;
                cArr[i4] = (char) b3;
            } else {
                int i20 = b3 & 255;
                if ((i20 & 224) != 192 || (i20 & 30) == 0) {
                    if ((i20 & 240) == 224) {
                        int i21 = i18 + 1;
                        if (i21 < i5) {
                            i11 = this.fBuffer[i21] & 255;
                        } else {
                            i11 = this.fInputStream.read();
                            if (i11 == i16) {
                                if (i4 > i2) {
                                    this.fBuffer[0] = (byte) i20;
                                } else {
                                    expectedByte(2, 3);
                                }
                            }
                            i19++;
                        }
                        if ((i11 & HSSFShapeTypes.ActionButtonInformation) != 128 || ((i20 == 237 && i11 >= 160) || ((i20 & 15) == 0 && (i11 & 32) == 0))) {
                            if (i4 > i2) {
                                byte[] bArr3 = this.fBuffer;
                                bArr3[0] = (byte) i20;
                                bArr3[1] = (byte) i11;
                                this.fOffset = 2;
                                return i4 - i2;
                            }
                            invalidByte(2, 3, i11);
                        }
                        i18 = i21 + 1;
                        if (i18 < i5) {
                            i12 = this.fBuffer[i18] & 255;
                        } else {
                            i12 = this.fInputStream.read();
                            if (i12 == i16) {
                                if (i4 > i2) {
                                    byte[] bArr4 = this.fBuffer;
                                    bArr4[0] = (byte) i20;
                                    bArr4[1] = (byte) i11;
                                    this.fOffset = 2;
                                    return i4 - i2;
                                }
                                expectedByte(3, 3);
                            }
                            i19++;
                        }
                        if ((i12 & HSSFShapeTypes.ActionButtonInformation) != 128) {
                            if (i4 > i2) {
                                byte[] bArr5 = this.fBuffer;
                                bArr5[0] = (byte) i20;
                                bArr5[1] = (byte) i11;
                                bArr5[2] = (byte) i12;
                            } else {
                                invalidByte(3, 3, i12);
                            }
                        }
                        int i22 = ((i20 << 12) & 61440) | ((i11 << 6) & 4032) | (i12 & 63);
                        i13 = i4 + 1;
                        cArr[i4] = (char) i22;
                        i19 -= 2;
                    } else if ((i20 & 248) == 240) {
                        int i23 = i18 + 1;
                        if (i23 < i5) {
                            i7 = this.fBuffer[i23] & 255;
                        } else {
                            i7 = this.fInputStream.read();
                            if (i7 == -1) {
                                if (i4 > i2) {
                                    this.fBuffer[0] = (byte) i20;
                                } else {
                                    expectedByte(2, 4);
                                }
                            }
                            i19++;
                        }
                        if ((i7 & HSSFShapeTypes.ActionButtonInformation) != 128 || ((i7 & 48) == 0 && (i20 & 7) == 0)) {
                            if (i4 > i2) {
                                byte[] bArr6 = this.fBuffer;
                                bArr6[0] = (byte) i20;
                                bArr6[1] = (byte) i7;
                                this.fOffset = 2;
                                return i4 - i2;
                            }
                            invalidByte(2, 4, i7);
                        }
                        int i24 = i23 + 1;
                        if (i24 < i5) {
                            i8 = this.fBuffer[i24] & 255;
                        } else {
                            i8 = this.fInputStream.read();
                            if (i8 == -1) {
                                if (i4 > i2) {
                                    byte[] bArr7 = this.fBuffer;
                                    bArr7[0] = (byte) i20;
                                    bArr7[1] = (byte) i7;
                                    this.fOffset = 2;
                                    return i4 - i2;
                                }
                                expectedByte(3, 4);
                            }
                            i19++;
                        }
                        if ((i8 & HSSFShapeTypes.ActionButtonInformation) != 128) {
                            if (i4 > i2) {
                                byte[] bArr8 = this.fBuffer;
                                bArr8[0] = (byte) i20;
                                bArr8[1] = (byte) i7;
                                bArr8[2] = (byte) i8;
                            } else {
                                invalidByte(3, 4, i8);
                            }
                        }
                        i18 = i24 + 1;
                        if (i18 < i5) {
                            i9 = this.fBuffer[i18] & 255;
                        } else {
                            i9 = this.fInputStream.read();
                            if (i9 == -1) {
                                if (i4 > i2) {
                                    byte[] bArr9 = this.fBuffer;
                                    bArr9[0] = (byte) i20;
                                    bArr9[1] = (byte) i7;
                                    bArr9[2] = (byte) i8;
                                } else {
                                    expectedByte(4, 4);
                                }
                            }
                            i19++;
                        }
                        if ((i9 & HSSFShapeTypes.ActionButtonInformation) != 128) {
                            if (i4 > i2) {
                                byte[] bArr10 = this.fBuffer;
                                bArr10[0] = (byte) i20;
                                bArr10[1] = (byte) i7;
                                bArr10[2] = (byte) i8;
                                bArr10[3] = (byte) i9;
                                this.fOffset = 4;
                                return i4 - i2;
                            }
                            invalidByte(4, 4, i8);
                        }
                        int i25 = ((i20 << 2) & 28) | ((i7 >> 4) & 3);
                        if (i25 > 16) {
                            invalidSurrogate(i25);
                        }
                        int i26 = i8 & 63;
                        int i27 = ((i7 & 15) << 2) | (((i25 - 1) << 6) & 960) | 55296 | (i26 >> 4);
                        int i28 = (i9 & 63) | 56320 | ((i26 << 6) & 960);
                        i10 = i4 + 1;
                        cArr[i4] = (char) i27;
                        i19 -= 2;
                        if (i19 <= i6) {
                            i4 = i10 + 1;
                            cArr[i10] = (char) i28;
                            i18++;
                            i16 = -1;
                        } else {
                            this.fSurrogate = i28;
                            i19--;
                            i4 = i10;
                            i18++;
                            i16 = -1;
                        }
                    } else if (i4 > i2) {
                        this.fBuffer[0] = (byte) i20;
                    } else {
                        invalidByte(1, 1, i20);
                        i18++;
                        i16 = -1;
                    }
                    this.fOffset = 3;
                    return i4 - i2;
                }
                i18++;
                if (i18 < i5) {
                    i14 = bArr2[i18] & 255;
                } else {
                    i14 = this.fInputStream.read();
                    if (i14 == i16) {
                        if (i4 > i2) {
                            this.fBuffer[0] = (byte) i20;
                        } else {
                            expectedByte(2, 2);
                        }
                    }
                    i19++;
                }
                if ((i14 & HSSFShapeTypes.ActionButtonInformation) != 128) {
                    if (i4 > i2) {
                        byte[] bArr11 = this.fBuffer;
                        bArr11[0] = (byte) i20;
                        bArr11[1] = (byte) i14;
                        this.fOffset = 2;
                        return i4 - i2;
                    }
                    invalidByte(2, 2, i14);
                }
                int i29 = (i14 & 63) | ((i20 << 6) & 1984);
                i10 = i4 + 1;
                cArr[i4] = (char) i29;
                i19 += i16;
                i4 = i10;
                i18++;
                i16 = -1;
                this.fOffset = 1;
                return i4 - i2;
            }
            i4 = i13;
            i18++;
            i16 = -1;
        }
        return i19;
    }

    @Override // java.io.Reader
    public boolean ready() {
        return false;
    }

    @Override // java.io.Reader
    public void reset() {
        this.fOffset = 0;
        this.fSurrogate = -1;
    }

    @Override // java.io.Reader
    public long skip(long j) {
        int length = this.fBuffer.length;
        char[] cArr = new char[length];
        long j2 = j;
        do {
            int read = read(cArr, 0, ((long) length) < j2 ? length : (int) j2);
            if (read <= 0) {
                break;
            }
            j2 -= (long) read;
        } while (j2 > 0);
        return j - j2;
    }
}
