package org.apache.xerces.impl.xpath;

import b.b.a.a.a;
import java.io.PrintStream;
import java.util.ArrayList;
import java.util.Hashtable;
import java.util.Vector;
import org.apache.poi.ss.formula.ptg.StringPtg;
import org.apache.xerces.util.SymbolTable;
import org.apache.xerces.util.XMLChar;
import org.apache.xerces.util.XMLSymbols;
import org.apache.xerces.xni.NamespaceContext;
import org.apache.xerces.xni.QName;
import org.apache.xmlbeans.impl.common.JarHelper;
import org.apache.xmlbeans.impl.jam.internal.JamPrinter;
import org.apache.xmlbeans.impl.jam.xml.JamXmlElements;

public class XPath {
    public static final boolean DEBUG_ALL = false;
    public static final boolean DEBUG_ANY = false;
    public static final boolean DEBUG_XPATH_PARSE = false;
    public final String fExpression;
    public final LocationPath[] fLocationPaths;
    public final SymbolTable fSymbolTable;

    public static class Axis implements Cloneable {
        public static final short ATTRIBUTE = 2;
        public static final short CHILD = 1;
        public static final short DESCENDANT = 4;
        public static final short SELF = 3;
        public final short type;

        public Axis(Axis axis) {
            this.type = axis.type;
        }

        public Axis(short s) {
            this.type = s;
        }

        @Override // java.lang.Object
        public Object clone() {
            return new Axis(this);
        }

        public String toString() {
            short s = this.type;
            return s != 1 ? s != 2 ? s != 3 ? s != 4 ? "???" : "descendant" : "self" : "attribute" : "child";
        }
    }

    public static class LocationPath implements Cloneable {
        public final Step[] steps;

        public LocationPath(LocationPath locationPath) {
            this.steps = new Step[locationPath.steps.length];
            int i2 = 0;
            while (true) {
                Step[] stepArr = this.steps;
                if (i2 < stepArr.length) {
                    stepArr[i2] = (Step) locationPath.steps[i2].clone();
                    i2++;
                } else {
                    return;
                }
            }
        }

        public LocationPath(Step[] stepArr) {
            this.steps = stepArr;
        }

        @Override // java.lang.Object
        public Object clone() {
            return new LocationPath(this);
        }

        public String toString() {
            StringBuffer stringBuffer = new StringBuffer();
            int i2 = 0;
            while (true) {
                Step[] stepArr = this.steps;
                if (i2 >= stepArr.length) {
                    return stringBuffer.toString();
                }
                if (!(i2 <= 0 || stepArr[i2 - 1].axis.type == 4 || stepArr[i2].axis.type == 4)) {
                    stringBuffer.append(JarHelper.SEP);
                }
                stringBuffer.append(this.steps[i2].toString());
                i2++;
            }
        }
    }

    public static class NodeTest implements Cloneable {
        public static final short NAMESPACE = 4;
        public static final short NODE = 3;
        public static final short QNAME = 1;
        public static final short WILDCARD = 2;
        public final QName name;
        public final short type;

        public NodeTest(String str, String str2) {
            QName qName = new QName();
            this.name = qName;
            this.type = 4;
            qName.setValues(str, null, null, str2);
        }

        public NodeTest(NodeTest nodeTest) {
            QName qName = new QName();
            this.name = qName;
            this.type = nodeTest.type;
            qName.setValues(nodeTest.name);
        }

        public NodeTest(QName qName) {
            QName qName2 = new QName();
            this.name = qName2;
            this.type = 1;
            qName2.setValues(qName);
        }

        public NodeTest(short s) {
            this.name = new QName();
            this.type = s;
        }

        @Override // java.lang.Object
        public Object clone() {
            return new NodeTest(this);
        }

        public String toString() {
            short s = this.type;
            if (s != 1) {
                if (s == 2) {
                    return "*";
                }
                if (s == 3) {
                    return "node()";
                }
                if (s != 4) {
                    return "???";
                }
                if (this.name.prefix.length() == 0) {
                    return "???:*";
                }
                if (this.name.uri != null) {
                    return a.a(new StringBuffer(), this.name.prefix, ":*");
                }
                StringBuffer a = a.a("{");
                a.append(this.name.uri);
                a.append('}');
                return a.a(a, this.name.prefix, ":*");
            } else if (this.name.prefix.length() == 0) {
                return this.name.localpart;
            } else {
                if (this.name.uri != null) {
                    StringBuffer stringBuffer = new StringBuffer();
                    stringBuffer.append(this.name.prefix);
                    stringBuffer.append(':');
                    stringBuffer.append(this.name.localpart);
                    return stringBuffer.toString();
                }
                StringBuffer a2 = a.a("{");
                a2.append(this.name.uri);
                a2.append('}');
                a2.append(this.name.prefix);
                a2.append(':');
                a2.append(this.name.localpart);
                return a2.toString();
            }
        }
    }

    public static class Scanner {
        public static final byte CHARTYPE_ATSIGN = 19;
        public static final byte CHARTYPE_CLOSE_BRACKET = 22;
        public static final byte CHARTYPE_CLOSE_PAREN = 7;
        public static final byte CHARTYPE_COLON = 15;
        public static final byte CHARTYPE_COMMA = 10;
        public static final byte CHARTYPE_DIGIT = 14;
        public static final byte CHARTYPE_DOLLAR = 5;
        public static final byte CHARTYPE_EQUAL = 17;
        public static final byte CHARTYPE_EXCLAMATION = 3;
        public static final byte CHARTYPE_GREATER = 18;
        public static final byte CHARTYPE_INVALID = 0;
        public static final byte CHARTYPE_LESS = 16;
        public static final byte CHARTYPE_LETTER = 20;
        public static final byte CHARTYPE_MINUS = 11;
        public static final byte CHARTYPE_NONASCII = 25;
        public static final byte CHARTYPE_OPEN_BRACKET = 21;
        public static final byte CHARTYPE_OPEN_PAREN = 6;
        public static final byte CHARTYPE_OTHER = 1;
        public static final byte CHARTYPE_PERIOD = 12;
        public static final byte CHARTYPE_PLUS = 9;
        public static final byte CHARTYPE_QUOTE = 4;
        public static final byte CHARTYPE_SLASH = 13;
        public static final byte CHARTYPE_STAR = 8;
        public static final byte CHARTYPE_UNDERSCORE = 23;
        public static final byte CHARTYPE_UNION = 24;
        public static final byte CHARTYPE_WHITESPACE = 2;
        public static final byte[] fASCIICharMap = {0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 2, 0, 0, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 3, 4, 1, 5, 1, 1, 4, 6, 7, 8, 9, 10, 11, 12, 13, 14, 14, 14, 14, 14, 14, 14, 14, 14, 14, 15, 1, 16, 17, 18, 1, 19, 20, 20, 20, 20, 20, 20, 20, 20, 20, 20, 20, 20, 20, 20, 20, 20, 20, 20, 20, 20, 20, 20, 20, 20, 20, 20, 21, 1, 22, 1, 23, 1, 20, 20, 20, 20, 20, 20, 20, 20, 20, 20, 20, 20, 20, 20, 20, 20, 20, 20, 20, 20, 20, 20, 20, 20, 20, 20, 1, CHARTYPE_UNION, 1, 1, 1};
        public static final String fAncestorOrSelfSymbol = "ancestor-or-self".intern();
        public static final String fAncestorSymbol = "ancestor".intern();
        public static final String fAndSymbol = "and".intern();
        public static final String fAttributeSymbol = "attribute".intern();
        public static final String fChildSymbol = "child".intern();
        public static final String fCommentSymbol = JamXmlElements.COMMENT.intern();
        public static final String fDescendantOrSelfSymbol = "descendant-or-self".intern();
        public static final String fDescendantSymbol = "descendant".intern();
        public static final String fDivSymbol = "div".intern();
        public static final String fFollowingSiblingSymbol = "following-sibling".intern();
        public static final String fFollowingSymbol = "following".intern();
        public static final String fModSymbol = "mod".intern();
        public static final String fNamespaceSymbol = "namespace".intern();
        public static final String fNodeSymbol = "node".intern();
        public static final String fOrSymbol = "or".intern();
        public static final String fPISymbol = "processing-instruction".intern();
        public static final String fParentSymbol = "parent".intern();
        public static final String fPrecedingSiblingSymbol = "preceding-sibling".intern();
        public static final String fPrecedingSymbol = "preceding".intern();
        public static final String fSelfSymbol = "self".intern();
        public static final String fTextSymbol = "text".intern();
        public SymbolTable fSymbolTable;

        public Scanner(SymbolTable symbolTable) {
            this.fSymbolTable = symbolTable;
        }

        /* JADX WARNING: Removed duplicated region for block: B:17:0x003b  */
        private int scanNumber(Tokens tokens, String str, int i2, int i3) {
            char charAt = str.charAt(i3);
            int i4 = 0;
            int i5 = 0;
            while (charAt >= '0' && charAt <= '9') {
                i5 = (i5 * 10) + (charAt - '0');
                i3++;
                if (i3 == i2) {
                    break;
                }
                charAt = str.charAt(i3);
            }
            if (charAt == '.' && (i3 = i3 + 1) < i2) {
                do {
                    char charAt2 = str.charAt(i3);
                    if (charAt2 >= '0' && charAt2 <= '9') {
                        i4 = (i4 * 10) + (charAt2 - '0');
                        i3++;
                    } else if (i4 != 0) {
                        throw new RuntimeException("find a solution!");
                    }
                } while (i3 != i2);
                if (i4 != 0) {
                }
            }
            tokens.addToken(i5);
            tokens.addToken(i4);
            return i3;
        }

        public void addToken(Tokens tokens, int i2) {
            tokens.addToken(i2);
        }

        /* JADX WARNING: Removed duplicated region for block: B:154:0x01b9  */
        /* JADX WARNING: Removed duplicated region for block: B:158:0x01c8 A[LOOP:3: B:57:0x00c1->B:158:0x01c8, LOOP_END] */
        /* JADX WARNING: Removed duplicated region for block: B:294:0x01b8 A[SYNTHETIC] */
        /* JADX WARNING: Removed duplicated region for block: B:317:0x00d0 A[SYNTHETIC] */
        /* JADX WARNING: Removed duplicated region for block: B:324:0x00ce A[SYNTHETIC] */
        /* JADX WARNING: Removed duplicated region for block: B:58:0x00c3 A[ADDED_TO_REGION] */
        /* JADX WARNING: Removed duplicated region for block: B:83:0x00f9  */
        public boolean scanExpr(SymbolTable symbolTable, Tokens tokens, String str, int i2, int i3) {
            int i4;
            int i5;
            int scanNCName;
            int i6;
            String str2;
            int i7;
            boolean z;
            boolean z2;
            char c;
            int i8;
            String str3;
            int i9;
            int i10;
            int i11;
            int i12;
            boolean z3 = true;
            int i13 = i2;
            while (true) {
                boolean z4 = false;
                while (i13 != i3) {
                    char charAt = str.charAt(i13);
                    while (true) {
                        if ((charAt == ' ' || charAt == '\n' || charAt == '\t' || charAt == '\r') && (i13 = i13 + 1) != i3) {
                            charAt = str.charAt(i13);
                            z3 = true;
                        }
                    }
                    if (i13 != i3) {
                        char c2 = 65535;
                        switch (charAt >= 128 ? 25 : fASCIICharMap[charAt]) {
                            case 3:
                                i13++;
                                if (i13 != i3 && str.charAt(i13) == '=') {
                                    i4 = 27;
                                    addToken(tokens, i4);
                                    i13++;
                                    break;
                                } else {
                                    return false;
                                }
                                break;
                            case 4:
                                int i14 = i13 + 1;
                                if (i14 == i3) {
                                    return false;
                                }
                                char charAt2 = str.charAt(i14);
                                int i15 = i14;
                                while (charAt2 != charAt) {
                                    i15++;
                                    if (i15 == i3) {
                                        return false;
                                    }
                                    charAt2 = str.charAt(i15);
                                }
                                addToken(tokens, 46);
                                tokens.addToken(symbolTable.addSymbol(str.substring(i14, (i15 - i14) + i14)));
                                i13 = i15 + 1;
                                z3 = true;
                                z4 = true;
                            case 5:
                                int i16 = i13 + 1;
                                if (i16 == i3 || (scanNCName = scanNCName(str, i3, i16)) == i16) {
                                    return false;
                                }
                                char charAt3 = scanNCName < i3 ? str.charAt(scanNCName) : 65535;
                                String addSymbol = symbolTable.addSymbol(str.substring(i16, scanNCName));
                                if (charAt3 != ':') {
                                    i6 = 48;
                                    addSymbol = XMLSymbols.EMPTY_STRING;
                                    i7 = scanNCName;
                                    str2 = addSymbol;
                                } else {
                                    int i17 = scanNCName + 1;
                                    if (i17 == i3 || (i7 = scanNCName(str, i3, i17)) == i17) {
                                        return false;
                                    }
                                    if (i7 < i3) {
                                        str.charAt(i7);
                                    }
                                    str2 = symbolTable.addSymbol(str.substring(i17, i7));
                                    i6 = 48;
                                }
                                addToken(tokens, i6);
                                tokens.addToken(addSymbol);
                                tokens.addToken(str2);
                                i13 = i7;
                                z3 = true;
                                z4 = true;
                                break;
                            case 6:
                                addToken(tokens, 0);
                                i13++;
                                break;
                            case 7:
                                addToken(tokens, 1);
                                i13++;
                                z3 = true;
                                z4 = true;
                            case 8:
                                if (z4) {
                                    addToken(tokens, 20);
                                    z4 = false;
                                } else {
                                    addToken(tokens, 9);
                                    z4 = true;
                                }
                                i13++;
                                z3 = true;
                            case 9:
                                i4 = 24;
                                addToken(tokens, i4);
                                i13++;
                                break;
                            case 10:
                                i4 = 7;
                                addToken(tokens, i4);
                                i13++;
                                break;
                            case 11:
                                i4 = 25;
                                addToken(tokens, i4);
                                i13++;
                                break;
                            case 12:
                                i7 = i13 + 1;
                                if (i7 != i3) {
                                    char charAt4 = str.charAt(i7);
                                    if (charAt4 == '.') {
                                        addToken(tokens, 5);
                                        i13 += 2;
                                    } else if (charAt4 >= '0' && charAt4 <= '9') {
                                        addToken(tokens, 47);
                                        i7 = scanNumber(tokens, str, i3, i13);
                                        i13 = i7;
                                    } else if (charAt4 == '/') {
                                        addToken(tokens, 4);
                                        i13 = i7;
                                    } else if (charAt4 != '|') {
                                        if (charAt4 == ' ' || charAt4 == '\n' || charAt4 == '\t' || charAt4 == '\r') {
                                            while (true) {
                                                i13++;
                                                if (i13 != i3 && ((charAt4 = str.charAt(i13)) == ' ' || charAt4 == '\n' || charAt4 == '\t' || charAt4 == '\r')) {
                                                }
                                            }
                                            if (i13 == i3 || charAt4 == '|') {
                                                addToken(tokens, 4);
                                            } else {
                                                throw new XPathException("c-general-xpath");
                                            }
                                        } else {
                                            throw new XPathException("c-general-xpath");
                                        }
                                    }
                                    z3 = true;
                                    z4 = true;
                                }
                                addToken(tokens, 4);
                                i13 = i7;
                                z3 = true;
                                z4 = true;
                                break;
                            case 13:
                                i13++;
                                if (i13 == i3 || str.charAt(i13) != '/') {
                                    addToken(tokens, 21);
                                    break;
                                } else {
                                    i4 = 22;
                                    addToken(tokens, i4);
                                    i13++;
                                    break;
                                }
                                break;
                            case 14:
                                addToken(tokens, 47);
                                i13 = scanNumber(tokens, str, i3, i13);
                                z3 = true;
                                z4 = true;
                            case 15:
                                i13++;
                                if (i13 != i3 && str.charAt(i13) == ':') {
                                    i4 = 8;
                                    addToken(tokens, i4);
                                    i13++;
                                    break;
                                } else {
                                    return false;
                                }
                                break;
                            case 16:
                                i13++;
                                i5 = 28;
                                if (i13 != i3 && str.charAt(i13) == '=') {
                                    i4 = 29;
                                    addToken(tokens, i4);
                                    i13++;
                                    break;
                                }
                                addToken(tokens, i5);
                                break;
                            case 17:
                                i4 = 26;
                                addToken(tokens, i4);
                                i13++;
                                break;
                            case 18:
                                i13++;
                                i5 = 30;
                                if (i13 != i3 && str.charAt(i13) == '=') {
                                    i4 = 31;
                                    addToken(tokens, i4);
                                    i13++;
                                    break;
                                }
                                addToken(tokens, i5);
                                break;
                            case 19:
                                i4 = 6;
                                addToken(tokens, i4);
                                i13++;
                                break;
                            case 20:
                            case 23:
                            case 25:
                                int scanNCName2 = scanNCName(str, i3, i13);
                                if (scanNCName2 == i13) {
                                    return false;
                                }
                                char charAt5 = scanNCName2 < i3 ? str.charAt(scanNCName2) : 65535;
                                String addSymbol2 = symbolTable.addSymbol(str.substring(i13, scanNCName2));
                                String str4 = XMLSymbols.EMPTY_STRING;
                                if (charAt5 == ':') {
                                    int i18 = scanNCName2 + 1;
                                    if (i18 == i3) {
                                        return false;
                                    }
                                    char charAt6 = str.charAt(i18);
                                    if (charAt6 == '*') {
                                        scanNCName2 = i18 + 1;
                                        if (scanNCName2 < i3) {
                                            charAt6 = str.charAt(scanNCName2);
                                        }
                                        c = charAt6;
                                        z2 = true;
                                    } else if (charAt6 == ':') {
                                        scanNCName2 = i18 + 1;
                                        if (scanNCName2 < i3) {
                                            charAt6 = str.charAt(scanNCName2);
                                        }
                                        c = charAt6;
                                        z2 = false;
                                        z = true;
                                        i8 = scanNCName2;
                                        str3 = str4;
                                        while (true) {
                                            if (c != ' ' || c == '\n' || c == '\t' || c == '\r') {
                                                i8++;
                                                if (i8 != i3) {
                                                    c = str.charAt(i8);
                                                }
                                            }
                                        }
                                        if (z4) {
                                            if (addSymbol2 == fAndSymbol) {
                                                i9 = 16;
                                            } else if (addSymbol2 == fOrSymbol) {
                                                i9 = 17;
                                            } else if (addSymbol2 == fModSymbol) {
                                                i9 = 18;
                                            } else if (addSymbol2 != fDivSymbol) {
                                                return false;
                                            } else {
                                                i9 = 19;
                                            }
                                            addToken(tokens, i9);
                                            if (z2 || z) {
                                                return false;
                                            }
                                        } else if (c == '(' && !z2 && !z) {
                                            if (addSymbol2 != fCommentSymbol) {
                                                if (addSymbol2 == fTextSymbol) {
                                                    addToken(tokens, 13);
                                                } else if (addSymbol2 == fPISymbol) {
                                                    i12 = 14;
                                                } else if (addSymbol2 == fNodeSymbol) {
                                                    i12 = 15;
                                                } else {
                                                    addToken(tokens, 32);
                                                    tokens.addToken(str3);
                                                    tokens.addToken(addSymbol2);
                                                }
                                                addToken(tokens, 0);
                                                i13 = i8 + 1;
                                                break;
                                            } else {
                                                i12 = 12;
                                            }
                                            addToken(tokens, i12);
                                            addToken(tokens, 0);
                                            i13 = i8 + 1;
                                        } else if (z || (c == ':' && (i11 = i8 + 1) < i3 && str.charAt(i11) == ':')) {
                                            if (addSymbol2 != fAncestorSymbol) {
                                                if (addSymbol2 != fAncestorOrSelfSymbol) {
                                                    if (addSymbol2 != fAttributeSymbol) {
                                                        if (addSymbol2 != fChildSymbol) {
                                                            if (addSymbol2 != fDescendantSymbol) {
                                                                if (addSymbol2 != fDescendantOrSelfSymbol) {
                                                                    if (addSymbol2 != fFollowingSymbol) {
                                                                        if (addSymbol2 == fFollowingSiblingSymbol) {
                                                                            addToken(tokens, 40);
                                                                        } else if (addSymbol2 == fNamespaceSymbol) {
                                                                            i10 = 41;
                                                                        } else if (addSymbol2 == fParentSymbol) {
                                                                            addToken(tokens, 42);
                                                                        } else if (addSymbol2 == fPrecedingSymbol) {
                                                                            i10 = 43;
                                                                        } else if (addSymbol2 == fPrecedingSiblingSymbol) {
                                                                            i10 = 44;
                                                                        } else if (addSymbol2 != fSelfSymbol) {
                                                                            return false;
                                                                        } else {
                                                                            i10 = 45;
                                                                        }
                                                                        if (z2) {
                                                                            addToken(tokens, 8);
                                                                            if (!z) {
                                                                                i13 = i8 + 1 + 1;
                                                                                break;
                                                                            }
                                                                        } else {
                                                                            return false;
                                                                        }
                                                                    } else {
                                                                        i10 = 39;
                                                                    }
                                                                } else {
                                                                    i10 = 38;
                                                                }
                                                            } else {
                                                                i10 = 37;
                                                            }
                                                        } else {
                                                            i10 = 36;
                                                        }
                                                    } else {
                                                        i10 = 35;
                                                    }
                                                } else {
                                                    i10 = 34;
                                                }
                                            } else {
                                                i10 = 33;
                                            }
                                            addToken(tokens, i10);
                                            if (z2) {
                                            }
                                        } else {
                                            if (z2) {
                                                addToken(tokens, 10);
                                            } else {
                                                addToken(tokens, 11);
                                                tokens.addToken(str3);
                                            }
                                            tokens.addToken(addSymbol2);
                                            i13 = i8;
                                            z3 = true;
                                            z4 = true;
                                        }
                                        i13 = i8;
                                        break;
                                    } else {
                                        i8 = scanNCName(str, i3, i18);
                                        if (i8 == i18) {
                                            return false;
                                        }
                                        if (i8 < i3) {
                                            c2 = str.charAt(i8);
                                        }
                                        String addSymbol3 = symbolTable.addSymbol(str.substring(i18, i8));
                                        c = c2;
                                        z2 = false;
                                        z = false;
                                        str3 = addSymbol2;
                                        addSymbol2 = addSymbol3;
                                        while (true) {
                                            if (c != ' ') {
                                            }
                                            i8++;
                                            if (i8 != i3) {
                                            }
                                            c = str.charAt(i8);
                                        }
                                        if (z4) {
                                        }
                                        i13 = i8;
                                    }
                                } else {
                                    c = charAt5;
                                    z2 = false;
                                }
                                z = false;
                                i8 = scanNCName2;
                                str3 = str4;
                                while (true) {
                                    if (c != ' ') {
                                    }
                                    i8++;
                                    if (i8 != i3) {
                                    }
                                    c = str.charAt(i8);
                                }
                                if (z4) {
                                }
                                i13 = i8;
                                break;
                            case 21:
                                i4 = 2;
                                addToken(tokens, i4);
                                i13++;
                                break;
                            case 22:
                                addToken(tokens, 3);
                                i13++;
                                z3 = true;
                                z4 = true;
                            case 24:
                                i4 = 23;
                                addToken(tokens, i4);
                                i13++;
                                break;
                            default:
                                return false;
                        }
                        z3 = true;
                    }
                }
            }
            return z3;
        }

        public int scanNCName(String str, int i2, int i3) {
            char charAt = str.charAt(i3);
            if (charAt < 128) {
                byte b2 = fASCIICharMap[charAt];
                if (!(b2 == 20 || b2 == 23)) {
                    return i3;
                }
            } else if (!XMLChar.isNameStart(charAt)) {
                return i3;
            }
            while (true) {
                i3++;
                if (i3 >= i2) {
                    break;
                }
                char charAt2 = str.charAt(i3);
                if (charAt2 < 128) {
                    byte b3 = fASCIICharMap[charAt2];
                    if (!(b3 == 20 || b3 == 14 || b3 == 12 || b3 == 11 || b3 == 23)) {
                        break;
                    }
                } else if (!XMLChar.isName(charAt2)) {
                    break;
                }
            }
            return i3;
        }
    }

    public static class Step implements Cloneable {
        public final Axis axis;
        public final NodeTest nodeTest;

        public Step(Axis axis2, NodeTest nodeTest2) {
            this.axis = axis2;
            this.nodeTest = nodeTest2;
        }

        public Step(Step step) {
            this.axis = (Axis) step.axis.clone();
            this.nodeTest = (NodeTest) step.nodeTest.clone();
        }

        @Override // java.lang.Object
        public Object clone() {
            return new Step(this);
        }

        public String toString() {
            short s = this.axis.type;
            if (s == 3) {
                return ".";
            }
            if (s == 2) {
                StringBuffer a = a.a("@");
                a.append(this.nodeTest.toString());
                return a.toString();
            } else if (s == 1) {
                return this.nodeTest.toString();
            } else {
                if (s == 4) {
                    return "//";
                }
                StringBuffer a2 = a.a("??? (");
                a2.append((int) this.axis.type);
                a2.append(')');
                return a2.toString();
            }
        }
    }

    public static final class Tokens {
        public static final boolean DUMP_TOKENS = false;
        public static final int EXPRTOKEN_ATSIGN = 6;
        public static final int EXPRTOKEN_AXISNAME_ANCESTOR = 33;
        public static final int EXPRTOKEN_AXISNAME_ANCESTOR_OR_SELF = 34;
        public static final int EXPRTOKEN_AXISNAME_ATTRIBUTE = 35;
        public static final int EXPRTOKEN_AXISNAME_CHILD = 36;
        public static final int EXPRTOKEN_AXISNAME_DESCENDANT = 37;
        public static final int EXPRTOKEN_AXISNAME_DESCENDANT_OR_SELF = 38;
        public static final int EXPRTOKEN_AXISNAME_FOLLOWING = 39;
        public static final int EXPRTOKEN_AXISNAME_FOLLOWING_SIBLING = 40;
        public static final int EXPRTOKEN_AXISNAME_NAMESPACE = 41;
        public static final int EXPRTOKEN_AXISNAME_PARENT = 42;
        public static final int EXPRTOKEN_AXISNAME_PRECEDING = 43;
        public static final int EXPRTOKEN_AXISNAME_PRECEDING_SIBLING = 44;
        public static final int EXPRTOKEN_AXISNAME_SELF = 45;
        public static final int EXPRTOKEN_CLOSE_BRACKET = 3;
        public static final int EXPRTOKEN_CLOSE_PAREN = 1;
        public static final int EXPRTOKEN_COMMA = 7;
        public static final int EXPRTOKEN_DOUBLE_COLON = 8;
        public static final int EXPRTOKEN_DOUBLE_PERIOD = 5;
        public static final int EXPRTOKEN_FUNCTION_NAME = 32;
        public static final int EXPRTOKEN_LITERAL = 46;
        public static final int EXPRTOKEN_NAMETEST_ANY = 9;
        public static final int EXPRTOKEN_NAMETEST_NAMESPACE = 10;
        public static final int EXPRTOKEN_NAMETEST_QNAME = 11;
        public static final int EXPRTOKEN_NODETYPE_COMMENT = 12;
        public static final int EXPRTOKEN_NODETYPE_NODE = 15;
        public static final int EXPRTOKEN_NODETYPE_PI = 14;
        public static final int EXPRTOKEN_NODETYPE_TEXT = 13;
        public static final int EXPRTOKEN_NUMBER = 47;
        public static final int EXPRTOKEN_OPEN_BRACKET = 2;
        public static final int EXPRTOKEN_OPEN_PAREN = 0;
        public static final int EXPRTOKEN_OPERATOR_AND = 16;
        public static final int EXPRTOKEN_OPERATOR_DIV = 19;
        public static final int EXPRTOKEN_OPERATOR_DOUBLE_SLASH = 22;
        public static final int EXPRTOKEN_OPERATOR_EQUAL = 26;
        public static final int EXPRTOKEN_OPERATOR_GREATER = 30;
        public static final int EXPRTOKEN_OPERATOR_GREATER_EQUAL = 31;
        public static final int EXPRTOKEN_OPERATOR_LESS = 28;
        public static final int EXPRTOKEN_OPERATOR_LESS_EQUAL = 29;
        public static final int EXPRTOKEN_OPERATOR_MINUS = 25;
        public static final int EXPRTOKEN_OPERATOR_MOD = 18;
        public static final int EXPRTOKEN_OPERATOR_MULT = 20;
        public static final int EXPRTOKEN_OPERATOR_NOT_EQUAL = 27;
        public static final int EXPRTOKEN_OPERATOR_OR = 17;
        public static final int EXPRTOKEN_OPERATOR_PLUS = 24;
        public static final int EXPRTOKEN_OPERATOR_SLASH = 21;
        public static final int EXPRTOKEN_OPERATOR_UNION = 23;
        public static final int EXPRTOKEN_PERIOD = 4;
        public static final int EXPRTOKEN_VARIABLE_REFERENCE = 48;
        public static final int INITIAL_TOKEN_COUNT = 256;
        public static final String[] fgTokenNames = {"EXPRTOKEN_OPEN_PAREN", "EXPRTOKEN_CLOSE_PAREN", "EXPRTOKEN_OPEN_BRACKET", "EXPRTOKEN_CLOSE_BRACKET", "EXPRTOKEN_PERIOD", "EXPRTOKEN_DOUBLE_PERIOD", "EXPRTOKEN_ATSIGN", "EXPRTOKEN_COMMA", "EXPRTOKEN_DOUBLE_COLON", "EXPRTOKEN_NAMETEST_ANY", "EXPRTOKEN_NAMETEST_NAMESPACE", "EXPRTOKEN_NAMETEST_QNAME", "EXPRTOKEN_NODETYPE_COMMENT", "EXPRTOKEN_NODETYPE_TEXT", "EXPRTOKEN_NODETYPE_PI", "EXPRTOKEN_NODETYPE_NODE", "EXPRTOKEN_OPERATOR_AND", "EXPRTOKEN_OPERATOR_OR", "EXPRTOKEN_OPERATOR_MOD", "EXPRTOKEN_OPERATOR_DIV", "EXPRTOKEN_OPERATOR_MULT", "EXPRTOKEN_OPERATOR_SLASH", "EXPRTOKEN_OPERATOR_DOUBLE_SLASH", "EXPRTOKEN_OPERATOR_UNION", "EXPRTOKEN_OPERATOR_PLUS", "EXPRTOKEN_OPERATOR_MINUS", "EXPRTOKEN_OPERATOR_EQUAL", "EXPRTOKEN_OPERATOR_NOT_EQUAL", "EXPRTOKEN_OPERATOR_LESS", "EXPRTOKEN_OPERATOR_LESS_EQUAL", "EXPRTOKEN_OPERATOR_GREATER", "EXPRTOKEN_OPERATOR_GREATER_EQUAL", "EXPRTOKEN_FUNCTION_NAME", "EXPRTOKEN_AXISNAME_ANCESTOR", "EXPRTOKEN_AXISNAME_ANCESTOR_OR_SELF", "EXPRTOKEN_AXISNAME_ATTRIBUTE", "EXPRTOKEN_AXISNAME_CHILD", "EXPRTOKEN_AXISNAME_DESCENDANT", "EXPRTOKEN_AXISNAME_DESCENDANT_OR_SELF", "EXPRTOKEN_AXISNAME_FOLLOWING", "EXPRTOKEN_AXISNAME_FOLLOWING_SIBLING", "EXPRTOKEN_AXISNAME_NAMESPACE", "EXPRTOKEN_AXISNAME_PARENT", "EXPRTOKEN_AXISNAME_PRECEDING", "EXPRTOKEN_AXISNAME_PRECEDING_SIBLING", "EXPRTOKEN_AXISNAME_SELF", "EXPRTOKEN_LITERAL", "EXPRTOKEN_NUMBER", "EXPRTOKEN_VARIABLE_REFERENCE"};
        public int fCurrentTokenIndex;
        public Hashtable fSymbolMapping = new Hashtable();
        public SymbolTable fSymbolTable;
        public int fTokenCount = 0;
        public Hashtable fTokenNames = new Hashtable();
        public int[] fTokens = new int[256];

        public Tokens(SymbolTable symbolTable) {
            this.fSymbolTable = symbolTable;
            String[] strArr = {"ancestor", "ancestor-or-self", "attribute", "child", "descendant", "descendant-or-self", "following", "following-sibling", "namespace", "parent", "preceding", "preceding-sibling", "self"};
            for (int i2 = 0; i2 < 13; i2++) {
                this.fSymbolMapping.put(this.fSymbolTable.addSymbol(strArr[i2]), new Integer(i2));
            }
            a.a(0, this.fTokenNames, "EXPRTOKEN_OPEN_PAREN");
            a.a(1, this.fTokenNames, "EXPRTOKEN_CLOSE_PAREN");
            a.a(2, this.fTokenNames, "EXPRTOKEN_OPEN_BRACKET");
            a.a(3, this.fTokenNames, "EXPRTOKEN_CLOSE_BRACKET");
            a.a(4, this.fTokenNames, "EXPRTOKEN_PERIOD");
            a.a(5, this.fTokenNames, "EXPRTOKEN_DOUBLE_PERIOD");
            a.a(6, this.fTokenNames, "EXPRTOKEN_ATSIGN");
            a.a(7, this.fTokenNames, "EXPRTOKEN_COMMA");
            a.a(8, this.fTokenNames, "EXPRTOKEN_DOUBLE_COLON");
            a.a(9, this.fTokenNames, "EXPRTOKEN_NAMETEST_ANY");
            a.a(10, this.fTokenNames, "EXPRTOKEN_NAMETEST_NAMESPACE");
            a.a(11, this.fTokenNames, "EXPRTOKEN_NAMETEST_QNAME");
            a.a(12, this.fTokenNames, "EXPRTOKEN_NODETYPE_COMMENT");
            a.a(13, this.fTokenNames, "EXPRTOKEN_NODETYPE_TEXT");
            a.a(14, this.fTokenNames, "EXPRTOKEN_NODETYPE_PI");
            a.a(15, this.fTokenNames, "EXPRTOKEN_NODETYPE_NODE");
            a.a(16, this.fTokenNames, "EXPRTOKEN_OPERATOR_AND");
            a.a(17, this.fTokenNames, "EXPRTOKEN_OPERATOR_OR");
            a.a(18, this.fTokenNames, "EXPRTOKEN_OPERATOR_MOD");
            a.a(19, this.fTokenNames, "EXPRTOKEN_OPERATOR_DIV");
            a.a(20, this.fTokenNames, "EXPRTOKEN_OPERATOR_MULT");
            a.a(21, this.fTokenNames, "EXPRTOKEN_OPERATOR_SLASH");
            a.a(22, this.fTokenNames, "EXPRTOKEN_OPERATOR_DOUBLE_SLASH");
            a.a(23, this.fTokenNames, "EXPRTOKEN_OPERATOR_UNION");
            a.a(24, this.fTokenNames, "EXPRTOKEN_OPERATOR_PLUS");
            a.a(25, this.fTokenNames, "EXPRTOKEN_OPERATOR_MINUS");
            a.a(26, this.fTokenNames, "EXPRTOKEN_OPERATOR_EQUAL");
            a.a(27, this.fTokenNames, "EXPRTOKEN_OPERATOR_NOT_EQUAL");
            a.a(28, this.fTokenNames, "EXPRTOKEN_OPERATOR_LESS");
            a.a(29, this.fTokenNames, "EXPRTOKEN_OPERATOR_LESS_EQUAL");
            a.a(30, this.fTokenNames, "EXPRTOKEN_OPERATOR_GREATER");
            a.a(31, this.fTokenNames, "EXPRTOKEN_OPERATOR_GREATER_EQUAL");
            a.a(32, this.fTokenNames, "EXPRTOKEN_FUNCTION_NAME");
            a.a(33, this.fTokenNames, "EXPRTOKEN_AXISNAME_ANCESTOR");
            a.a(34, this.fTokenNames, "EXPRTOKEN_AXISNAME_ANCESTOR_OR_SELF");
            a.a(35, this.fTokenNames, "EXPRTOKEN_AXISNAME_ATTRIBUTE");
            a.a(36, this.fTokenNames, "EXPRTOKEN_AXISNAME_CHILD");
            a.a(37, this.fTokenNames, "EXPRTOKEN_AXISNAME_DESCENDANT");
            a.a(38, this.fTokenNames, "EXPRTOKEN_AXISNAME_DESCENDANT_OR_SELF");
            a.a(39, this.fTokenNames, "EXPRTOKEN_AXISNAME_FOLLOWING");
            a.a(40, this.fTokenNames, "EXPRTOKEN_AXISNAME_FOLLOWING_SIBLING");
            a.a(41, this.fTokenNames, "EXPRTOKEN_AXISNAME_NAMESPACE");
            a.a(42, this.fTokenNames, "EXPRTOKEN_AXISNAME_PARENT");
            a.a(43, this.fTokenNames, "EXPRTOKEN_AXISNAME_PRECEDING");
            a.a(44, this.fTokenNames, "EXPRTOKEN_AXISNAME_PRECEDING_SIBLING");
            a.a(45, this.fTokenNames, "EXPRTOKEN_AXISNAME_SELF");
            a.a(46, this.fTokenNames, "EXPRTOKEN_LITERAL");
            a.a(47, this.fTokenNames, "EXPRTOKEN_NUMBER");
            a.a(48, this.fTokenNames, "EXPRTOKEN_VARIABLE_REFERENCE");
        }

        public void addToken(int i2) {
            try {
                this.fTokens[this.fTokenCount] = i2;
            } catch (ArrayIndexOutOfBoundsException unused) {
                int[] iArr = this.fTokens;
                int i3 = this.fTokenCount;
                int[] iArr2 = new int[(i3 << 1)];
                this.fTokens = iArr2;
                System.arraycopy(iArr, 0, iArr2, 0, i3);
                this.fTokens[this.fTokenCount] = i2;
            }
            this.fTokenCount++;
        }

        public void addToken(String str) {
            Integer num = (Integer) this.fTokenNames.get(str);
            if (num == null) {
                num = new Integer(this.fTokenNames.size());
                this.fTokenNames.put(num, str);
            }
            addToken(num.intValue());
        }

        public void dumpTokens() {
            String str;
            PrintStream printStream;
            int i2;
            StringBuffer stringBuffer;
            PrintStream printStream2;
            int i3 = 0;
            while (i3 < this.fTokenCount) {
                switch (this.fTokens[i3]) {
                    case 0:
                        printStream = System.out;
                        str = "<OPEN_PAREN/>";
                        printStream.print(str);
                        break;
                    case 1:
                        printStream = System.out;
                        str = "<CLOSE_PAREN/>";
                        printStream.print(str);
                        break;
                    case 2:
                        printStream = System.out;
                        str = "<OPEN_BRACKET/>";
                        printStream.print(str);
                        break;
                    case 3:
                        printStream = System.out;
                        str = "<CLOSE_BRACKET/>";
                        printStream.print(str);
                        break;
                    case 4:
                        printStream = System.out;
                        str = "<PERIOD/>";
                        printStream.print(str);
                        break;
                    case 5:
                        printStream = System.out;
                        str = "<DOUBLE_PERIOD/>";
                        printStream.print(str);
                        break;
                    case 6:
                        printStream = System.out;
                        str = "<ATSIGN/>";
                        printStream.print(str);
                        break;
                    case 7:
                        printStream = System.out;
                        str = "<COMMA/>";
                        printStream.print(str);
                        break;
                    case 8:
                        printStream = System.out;
                        str = "<DOUBLE_COLON/>";
                        printStream.print(str);
                        break;
                    case 9:
                        printStream = System.out;
                        str = "<NAMETEST_ANY/>";
                        printStream.print(str);
                        break;
                    case 10:
                        System.out.print("<NAMETEST_NAMESPACE");
                        printStream2 = System.out;
                        stringBuffer = a.a(" prefix=\"");
                        i3++;
                        i2 = this.fTokens[i3];
                        stringBuffer.append(getTokenString(i2));
                        stringBuffer.append("\"");
                        printStream2.print(stringBuffer.toString());
                        System.out.print("/>");
                        break;
                    case 11:
                        System.out.print("<NAMETEST_QNAME");
                        int i4 = i3 + 1;
                        if (this.fTokens[i4] != -1) {
                            PrintStream printStream3 = System.out;
                            StringBuffer a = a.a(" prefix=\"");
                            a.append(getTokenString(this.fTokens[i4]));
                            a.append("\"");
                            printStream3.print(a.toString());
                        }
                        printStream2 = System.out;
                        stringBuffer = a.a(" localpart=\"");
                        i3 = i4 + 1;
                        i2 = this.fTokens[i3];
                        stringBuffer.append(getTokenString(i2));
                        stringBuffer.append("\"");
                        printStream2.print(stringBuffer.toString());
                        System.out.print("/>");
                        break;
                    case 12:
                        printStream = System.out;
                        str = "<NODETYPE_COMMENT/>";
                        printStream.print(str);
                        break;
                    case 13:
                        printStream = System.out;
                        str = "<NODETYPE_TEXT/>";
                        printStream.print(str);
                        break;
                    case 14:
                        printStream = System.out;
                        str = "<NODETYPE_PI/>";
                        printStream.print(str);
                        break;
                    case 15:
                        printStream = System.out;
                        str = "<NODETYPE_NODE/>";
                        printStream.print(str);
                        break;
                    case 16:
                        printStream = System.out;
                        str = "<OPERATOR_AND/>";
                        printStream.print(str);
                        break;
                    case 17:
                        printStream = System.out;
                        str = "<OPERATOR_OR/>";
                        printStream.print(str);
                        break;
                    case 18:
                        printStream = System.out;
                        str = "<OPERATOR_MOD/>";
                        printStream.print(str);
                        break;
                    case 19:
                        printStream = System.out;
                        str = "<OPERATOR_DIV/>";
                        printStream.print(str);
                        break;
                    case 20:
                        printStream = System.out;
                        str = "<OPERATOR_MULT/>";
                        printStream.print(str);
                        break;
                    case 21:
                        System.out.print("<OPERATOR_SLASH/>");
                        if (i3 + 1 >= this.fTokenCount) {
                            break;
                        } else {
                            System.out.println();
                            printStream = System.out;
                            str = JamPrinter.INDENT;
                            printStream.print(str);
                            break;
                        }
                    case 22:
                        printStream = System.out;
                        str = "<OPERATOR_DOUBLE_SLASH/>";
                        printStream.print(str);
                        break;
                    case 23:
                        printStream = System.out;
                        str = "<OPERATOR_UNION/>";
                        printStream.print(str);
                        break;
                    case 24:
                        printStream = System.out;
                        str = "<OPERATOR_PLUS/>";
                        printStream.print(str);
                        break;
                    case 25:
                        printStream = System.out;
                        str = "<OPERATOR_MINUS/>";
                        printStream.print(str);
                        break;
                    case 26:
                        printStream = System.out;
                        str = "<OPERATOR_EQUAL/>";
                        printStream.print(str);
                        break;
                    case 27:
                        printStream = System.out;
                        str = "<OPERATOR_NOT_EQUAL/>";
                        printStream.print(str);
                        break;
                    case 28:
                        printStream = System.out;
                        str = "<OPERATOR_LESS/>";
                        printStream.print(str);
                        break;
                    case 29:
                        printStream = System.out;
                        str = "<OPERATOR_LESS_EQUAL/>";
                        printStream.print(str);
                        break;
                    case 30:
                        printStream = System.out;
                        str = "<OPERATOR_GREATER/>";
                        printStream.print(str);
                        break;
                    case 31:
                        printStream = System.out;
                        str = "<OPERATOR_GREATER_EQUAL/>";
                        printStream.print(str);
                        break;
                    case 32:
                        System.out.print("<FUNCTION_NAME");
                        int i5 = i3 + 1;
                        if (this.fTokens[i5] != -1) {
                            PrintStream printStream4 = System.out;
                            StringBuffer a2 = a.a(" prefix=\"");
                            a2.append(getTokenString(this.fTokens[i5]));
                            a2.append("\"");
                            printStream4.print(a2.toString());
                        }
                        printStream2 = System.out;
                        stringBuffer = a.a(" localpart=\"");
                        i3 = i5 + 1;
                        i2 = this.fTokens[i3];
                        stringBuffer.append(getTokenString(i2));
                        stringBuffer.append("\"");
                        printStream2.print(stringBuffer.toString());
                        System.out.print("/>");
                        break;
                    case 33:
                        printStream = System.out;
                        str = "<AXISNAME_ANCESTOR/>";
                        printStream.print(str);
                        break;
                    case 34:
                        printStream = System.out;
                        str = "<AXISNAME_ANCESTOR_OR_SELF/>";
                        printStream.print(str);
                        break;
                    case 35:
                        printStream = System.out;
                        str = "<AXISNAME_ATTRIBUTE/>";
                        printStream.print(str);
                        break;
                    case 36:
                        printStream = System.out;
                        str = "<AXISNAME_CHILD/>";
                        printStream.print(str);
                        break;
                    case 37:
                        printStream = System.out;
                        str = "<AXISNAME_DESCENDANT/>";
                        printStream.print(str);
                        break;
                    case 38:
                        printStream = System.out;
                        str = "<AXISNAME_DESCENDANT_OR_SELF/>";
                        printStream.print(str);
                        break;
                    case 39:
                        printStream = System.out;
                        str = "<AXISNAME_FOLLOWING/>";
                        printStream.print(str);
                        break;
                    case 40:
                        printStream = System.out;
                        str = "<AXISNAME_FOLLOWING_SIBLING/>";
                        printStream.print(str);
                        break;
                    case 41:
                        printStream = System.out;
                        str = "<AXISNAME_NAMESPACE/>";
                        printStream.print(str);
                        break;
                    case 42:
                        printStream = System.out;
                        str = "<AXISNAME_PARENT/>";
                        printStream.print(str);
                        break;
                    case 43:
                        printStream = System.out;
                        str = "<AXISNAME_PRECEDING/>";
                        printStream.print(str);
                        break;
                    case 44:
                        printStream = System.out;
                        str = "<AXISNAME_PRECEDING_SIBLING/>";
                        printStream.print(str);
                        break;
                    case 45:
                        printStream = System.out;
                        str = "<AXISNAME_SELF/>";
                        printStream.print(str);
                        break;
                    case 46:
                        System.out.print("<LITERAL");
                        printStream2 = System.out;
                        stringBuffer = a.a(" value=\"");
                        i3++;
                        i2 = this.fTokens[i3];
                        stringBuffer.append(getTokenString(i2));
                        stringBuffer.append("\"");
                        printStream2.print(stringBuffer.toString());
                        System.out.print("/>");
                        break;
                    case 47:
                        System.out.print("<NUMBER");
                        PrintStream printStream5 = System.out;
                        StringBuffer a3 = a.a(" whole=\"");
                        int i6 = i3 + 1;
                        a3.append(getTokenString(this.fTokens[i6]));
                        a3.append("\"");
                        printStream5.print(a3.toString());
                        printStream2 = System.out;
                        stringBuffer = a.a(" part=\"");
                        i3 = i6 + 1;
                        i2 = this.fTokens[i3];
                        stringBuffer.append(getTokenString(i2));
                        stringBuffer.append("\"");
                        printStream2.print(stringBuffer.toString());
                        System.out.print("/>");
                        break;
                    case 48:
                        System.out.print("<VARIABLE_REFERENCE");
                        int i7 = i3 + 1;
                        if (this.fTokens[i7] != -1) {
                            PrintStream printStream6 = System.out;
                            StringBuffer a4 = a.a(" prefix=\"");
                            a4.append(getTokenString(this.fTokens[i7]));
                            a4.append("\"");
                            printStream6.print(a4.toString());
                        }
                        printStream2 = System.out;
                        stringBuffer = a.a(" localpart=\"");
                        i3 = i7 + 1;
                        i2 = this.fTokens[i3];
                        stringBuffer.append(getTokenString(i2));
                        stringBuffer.append("\"");
                        printStream2.print(stringBuffer.toString());
                        System.out.print("/>");
                        break;
                    default:
                        System.out.println("<???/>");
                        break;
                }
                i3++;
            }
            System.out.println();
        }

        public String getTokenString(int i2) {
            return (String) this.fTokenNames.get(new Integer(i2));
        }

        public boolean hasMore() {
            return this.fCurrentTokenIndex < this.fTokenCount;
        }

        public int nextToken() {
            int i2 = this.fCurrentTokenIndex;
            if (i2 != this.fTokenCount) {
                int[] iArr = this.fTokens;
                this.fCurrentTokenIndex = i2 + 1;
                return iArr[i2];
            }
            throw new XPathException("c-general-xpath");
        }

        public String nextTokenAsString() {
            String tokenString = getTokenString(nextToken());
            if (tokenString != null) {
                return tokenString;
            }
            throw new XPathException("c-general-xpath");
        }

        public int peekToken() {
            int i2 = this.fCurrentTokenIndex;
            if (i2 != this.fTokenCount) {
                return this.fTokens[i2];
            }
            throw new XPathException("c-general-xpath");
        }

        public void rewind() {
            this.fCurrentTokenIndex = 0;
        }
    }

    public XPath(String str, SymbolTable symbolTable, NamespaceContext namespaceContext) {
        this.fExpression = str;
        this.fSymbolTable = symbolTable;
        this.fLocationPaths = parseExpression(namespaceContext);
    }

    private LocationPath buildLocationPath(Vector vector) {
        int size = vector.size();
        check(size != 0);
        Step[] stepArr = new Step[size];
        vector.copyInto(stepArr);
        vector.removeAllElements();
        return new LocationPath(stepArr);
    }

    public static void check(boolean z) {
        if (!z) {
            throw new XPathException("c-general-xpath");
        }
    }

    public static void main(String[] strArr) {
        for (String str : strArr) {
            PrintStream printStream = System.out;
            StringBuffer stringBuffer = new StringBuffer();
            stringBuffer.append("# XPath expression: \"");
            stringBuffer.append(str);
            stringBuffer.append(StringPtg.FORMULA_DELIMITER);
            printStream.println(stringBuffer.toString());
            try {
                XPath xPath = new XPath(str, new SymbolTable(), null);
                PrintStream printStream2 = System.out;
                StringBuffer stringBuffer2 = new StringBuffer();
                stringBuffer2.append("expanded xpath: \"");
                stringBuffer2.append(xPath.toString());
                stringBuffer2.append(StringPtg.FORMULA_DELIMITER);
                printStream2.println(stringBuffer2.toString());
            } catch (XPathException e2) {
                PrintStream printStream3 = System.out;
                StringBuffer a = a.a("error: ");
                a.append(e2.getMessage());
                printStream3.println(a.toString());
            }
        }
    }

    private LocationPath[] parseExpression(NamespaceContext namespaceContext) {
        Step step;
        Tokens tokens = new Tokens(this.fSymbolTable);
        if (new Scanner(this, this.fSymbolTable) {
            /* class org.apache.xerces.impl.xpath.XPath.AnonymousClass1 */
            public final /* synthetic */ XPath this$0;

            {
                this.this$0 = r1;
            }

            @Override // org.apache.xerces.impl.xpath.XPath.Scanner
            public void addToken(Tokens tokens, int i2) {
                if (i2 == 6 || i2 == 11 || i2 == 21 || i2 == 4 || i2 == 9 || i2 == 10 || i2 == 22 || i2 == 23 || i2 == 36 || i2 == 35 || i2 == 8) {
                    super.addToken(tokens, i2);
                    return;
                }
                throw new XPathException("c-general-xpath");
            }
        }.scanExpr(this.fSymbolTable, tokens, this.fExpression, 0, this.fExpression.length())) {
            Vector vector = new Vector();
            ArrayList arrayList = new ArrayList();
            while (true) {
                boolean z = true;
                while (tokens.hasMore()) {
                    int nextToken = tokens.nextToken();
                    if (nextToken != 4) {
                        if (nextToken == 6) {
                            check(z);
                            step = new Step(new Axis((short) 2), parseNodeTest(tokens.nextToken(), tokens, namespaceContext));
                        } else if (nextToken == 35) {
                            check(z);
                            if (tokens.nextToken() == 8) {
                                step = new Step(new Axis((short) 2), parseNodeTest(tokens.nextToken(), tokens, namespaceContext));
                            } else {
                                throw new XPathException("c-general-xpath");
                            }
                        } else if (nextToken != 36) {
                            switch (nextToken) {
                                case 8:
                                    throw new XPathException("c-general-xpath");
                                case 9:
                                case 10:
                                case 11:
                                    check(z);
                                    step = new Step(new Axis((short) 1), parseNodeTest(nextToken, tokens, namespaceContext));
                                    break;
                                default:
                                    switch (nextToken) {
                                        case 21:
                                            check(!z);
                                            continue;
                                        case 22:
                                            throw new XPathException("c-general-xpath");
                                        case 23:
                                            check(!z);
                                            arrayList.add(buildLocationPath(vector));
                                            continue;
                                        default:
                                            throw new InternalError();
                                    }
                            }
                        } else {
                            check(z);
                            if (tokens.nextToken() == 8) {
                                step = new Step(new Axis((short) 1), parseNodeTest(tokens.nextToken(), tokens, namespaceContext));
                            } else {
                                throw new XPathException("c-general-xpath");
                            }
                        }
                        vector.addElement(step);
                    } else {
                        check(z);
                        if (vector.size() == 0) {
                            vector.addElement(new Step(new Axis((short) 3), new NodeTest((short) 3)));
                            if (tokens.hasMore() && tokens.peekToken() == 22) {
                                tokens.nextToken();
                                vector.addElement(new Step(new Axis((short) 4), new NodeTest((short) 3)));
                            }
                        } else {
                            continue;
                        }
                    }
                    z = false;
                }
                check(!z);
                arrayList.add(buildLocationPath(vector));
                return (LocationPath[]) arrayList.toArray(new LocationPath[arrayList.size()]);
            }
        }
        throw new XPathException("c-general-xpath");
    }

    private NodeTest parseNodeTest(int i2, Tokens tokens, NamespaceContext namespaceContext) {
        String str;
        switch (i2) {
            case 9:
                return new NodeTest((short) 2);
            case 10:
            case 11:
                String nextTokenAsString = tokens.nextTokenAsString();
                String str2 = null;
                if (!(namespaceContext == null || nextTokenAsString == XMLSymbols.EMPTY_STRING)) {
                    str2 = namespaceContext.getURI(nextTokenAsString);
                }
                if (nextTokenAsString != XMLSymbols.EMPTY_STRING && namespaceContext != null && str2 == null) {
                    throw new XPathException("c-general-xpath-ns");
                } else if (i2 == 10) {
                    return new NodeTest(nextTokenAsString, str2);
                } else {
                    String nextTokenAsString2 = tokens.nextTokenAsString();
                    if (nextTokenAsString != XMLSymbols.EMPTY_STRING) {
                        SymbolTable symbolTable = this.fSymbolTable;
                        StringBuffer stringBuffer = new StringBuffer();
                        stringBuffer.append(nextTokenAsString);
                        stringBuffer.append(':');
                        stringBuffer.append(nextTokenAsString2);
                        str = symbolTable.addSymbol(stringBuffer.toString());
                    } else {
                        str = nextTokenAsString2;
                    }
                    return new NodeTest(new QName(nextTokenAsString, nextTokenAsString2, str, str2));
                }
            default:
                throw new XPathException("c-general-xpath");
        }
    }

    public LocationPath getLocationPath() {
        return (LocationPath) this.fLocationPaths[0].clone();
    }

    public LocationPath[] getLocationPaths() {
        LocationPath[] locationPathArr = new LocationPath[this.fLocationPaths.length];
        int i2 = 0;
        while (true) {
            LocationPath[] locationPathArr2 = this.fLocationPaths;
            if (i2 >= locationPathArr2.length) {
                return locationPathArr;
            }
            locationPathArr[i2] = (LocationPath) locationPathArr2[i2].clone();
            i2++;
        }
    }

    public String toString() {
        StringBuffer stringBuffer = new StringBuffer();
        for (int i2 = 0; i2 < this.fLocationPaths.length; i2++) {
            if (i2 > 0) {
                stringBuffer.append('|');
            }
            stringBuffer.append(this.fLocationPaths[i2].toString());
        }
        return stringBuffer.toString();
    }
}
