package org.apache.xerces.impl.xpath.regex;

import java.lang.reflect.Array;

public final class CaseInsensitiveMap {
    public static int CHUNK_MASK = 0;
    public static int CHUNK_SHIFT = 10;
    public static int CHUNK_SIZE = 0;
    public static int INITIAL_CHUNK_COUNT = 64;
    public static int LOWER_CASE_MATCH = 1;
    public static int UPPER_CASE_MATCH = 2;
    public static int[][][] caseInsensitiveMap;

    static {
        int i2 = 1 << 10;
        CHUNK_SIZE = i2;
        CHUNK_MASK = i2 - 1;
        buildCaseInsensitiveMap();
    }

    public static void buildCaseInsensitiveMap() {
        int i2;
        int i3 = INITIAL_CHUNK_COUNT;
        int[] iArr = new int[2];
        iArr[1] = CHUNK_SIZE;
        iArr[0] = i3;
        caseInsensitiveMap = (int[][][]) Array.newInstance(int[].class, iArr);
        for (int i4 = 0; i4 < 65536; i4++) {
            char c = (char) i4;
            int lowerCase = Character.toLowerCase(c);
            int upperCase = Character.toUpperCase(c);
            if (lowerCase != upperCase || lowerCase != i4) {
                int[] iArr2 = new int[2];
                if (lowerCase != i4) {
                    iArr2[0] = lowerCase;
                    iArr2[1] = LOWER_CASE_MATCH;
                    int[] mapping = getMapping(lowerCase);
                    if (mapping != null) {
                        iArr2 = updateMap(i4, iArr2, lowerCase, mapping, LOWER_CASE_MATCH);
                    }
                    i2 = 2;
                } else {
                    i2 = 0;
                }
                if (upperCase != i4) {
                    if (i2 == iArr2.length) {
                        iArr2 = expandMap(iArr2, 2);
                    }
                    iArr2[i2] = upperCase;
                    iArr2[i2 + 1] = UPPER_CASE_MATCH;
                    int[] mapping2 = getMapping(upperCase);
                    if (mapping2 != null) {
                        iArr2 = updateMap(i4, iArr2, upperCase, mapping2, UPPER_CASE_MATCH);
                    }
                }
                set(i4, iArr2);
            }
        }
    }

    public static boolean contains(int[] iArr, int i2) {
        for (int i3 = 0; i3 < iArr.length; i3 += 2) {
            if (iArr[i3] == i2) {
                return true;
            }
        }
        return false;
    }

    public static boolean contains(int[] iArr, int i2, int i3) {
        for (int i4 = 0; i4 < iArr.length; i4 += 2) {
            if (iArr[i4] == i2 && iArr[i4 + 1] == i3) {
                return true;
            }
        }
        return false;
    }

    public static int[] expandAndAdd(int[] iArr, int i2, int i3) {
        int length = iArr.length;
        int[] iArr2 = new int[(length + 2)];
        System.arraycopy(iArr, 0, iArr2, 0, length);
        iArr2[length] = i2;
        iArr2[length + 1] = i3;
        return iArr2;
    }

    public static int[] expandMap(int[] iArr, int i2) {
        int length = iArr.length;
        int[] iArr2 = new int[(i2 + length)];
        System.arraycopy(iArr, 0, iArr2, 0, length);
        return iArr2;
    }

    public static int[] get(int i2) {
        if (i2 < 65536) {
            return getMapping(i2);
        }
        return null;
    }

    public static int[] getMapping(int i2) {
        int i3 = i2 >>> CHUNK_SHIFT;
        return caseInsensitiveMap[i3][i2 & CHUNK_MASK];
    }

    public static void set(int i2, int[] iArr) {
        int i3 = i2 >>> CHUNK_SHIFT;
        caseInsensitiveMap[i3][i2 & CHUNK_MASK] = iArr;
    }

    public static int[] updateMap(int i2, int[] iArr, int i3, int[] iArr2, int i4) {
        for (int i5 = 0; i5 < iArr2.length; i5 += 2) {
            int i6 = iArr2[i5];
            int[] mapping = getMapping(i6);
            if (mapping != null && contains(mapping, i3, i4)) {
                if (!contains(mapping, i2)) {
                    set(i6, expandAndAdd(mapping, i2, i4));
                }
                if (!contains(iArr, i6)) {
                    iArr = expandAndAdd(iArr, i6, i4);
                }
            }
        }
        if (!contains(iArr2, i2)) {
            set(i3, expandAndAdd(iArr2, i2, i4));
        }
        return iArr;
    }
}
