package org.apache.xerces.impl.xpath.regex;

import b.b.a.a.a;
import java.io.Serializable;
import java.text.CharacterIterator;
import java.util.Locale;
import org.apache.poi.openxml4j.opc.internal.ZipHelper;
import org.apache.xerces.impl.xpath.regex.Op;
import org.apache.xerces.impl.xpath.regex.Token;

public class RegularExpression implements Serializable {
    public static final int CARRIAGE_RETURN = 13;
    public static final boolean DEBUG = false;
    public static final int EXTENDED_COMMENT = 16;
    public static final int IGNORE_CASE = 2;
    public static final int LINE_FEED = 10;
    public static final int LINE_SEPARATOR = 8232;
    public static final int MULTIPLE_LINES = 8;
    public static final int PARAGRAPH_SEPARATOR = 8233;
    public static final int PROHIBIT_FIXED_STRING_OPTIMIZATION = 256;
    public static final int PROHIBIT_HEAD_CHARACTER_OPTIMIZATION = 128;
    public static final int SINGLE_LINE = 4;
    public static final int SPECIAL_COMMA = 1024;
    public static final int UNICODE_WORD_BOUNDARY = 64;
    public static final int USE_UNICODE_CATEGORY = 32;
    public static final int WT_IGNORE = 0;
    public static final int WT_LETTER = 1;
    public static final int WT_OTHER = 2;
    public static final int XMLSCHEMA_MODE = 512;
    public static final long serialVersionUID = 6242499334195006401L;
    public transient Context context;
    public transient RangeToken firstChar;
    public transient String fixedString;
    public transient boolean fixedStringOnly;
    public transient int fixedStringOptions;
    public transient BMPattern fixedStringTable;
    public boolean hasBackReferences;
    public transient int minlength;
    public int nofparen;
    public transient int numberOfClosures;
    public transient Op operations;
    public int options;
    public String regex;
    public Token tokentree;

    public static final class CharArrayTarget extends ExpressionTarget {
        public char[] target;

        public CharArrayTarget(char[] cArr) {
            this.target = cArr;
        }

        private final boolean regionMatches(int i2, int i3, int i4, int i5) {
            while (true) {
                int i6 = i5 - 1;
                if (i5 <= 0) {
                    return true;
                }
                char[] cArr = this.target;
                int i7 = i2 + 1;
                int i8 = i4 + 1;
                if (cArr[i2] != cArr[i4]) {
                    return false;
                }
                i5 = i6;
                i2 = i7;
                i4 = i8;
            }
        }

        private final boolean regionMatches(int i2, int i3, String str, int i4) {
            int i5 = 0;
            while (true) {
                int i6 = i4 - 1;
                if (i4 <= 0) {
                    return true;
                }
                int i7 = i2 + 1;
                int i8 = i5 + 1;
                if (this.target[i2] != str.charAt(i5)) {
                    return false;
                }
                i5 = i8;
                i4 = i6;
                i2 = i7;
            }
        }

        private final boolean regionMatchesIgnoreCase(int i2, int i3, int i4, int i5) {
            char upperCase;
            char upperCase2;
            while (true) {
                int i6 = i5 - 1;
                if (i5 <= 0) {
                    return true;
                }
                char[] cArr = this.target;
                int i7 = i2 + 1;
                char c = cArr[i2];
                int i8 = i4 + 1;
                char c2 = cArr[i4];
                if (c != c2 && (upperCase = Character.toUpperCase(c)) != (upperCase2 = Character.toUpperCase(c2)) && Character.toLowerCase(upperCase) != Character.toLowerCase(upperCase2)) {
                    return false;
                }
                i5 = i6;
                i2 = i7;
                i4 = i8;
            }
        }

        private final boolean regionMatchesIgnoreCase(int i2, int i3, String str, int i4) {
            char upperCase;
            char upperCase2;
            int i5 = 0;
            while (true) {
                int i6 = i4 - 1;
                if (i4 <= 0) {
                    return true;
                }
                int i7 = i2 + 1;
                char c = this.target[i2];
                int i8 = i5 + 1;
                char charAt = str.charAt(i5);
                if (c != charAt && (upperCase = Character.toUpperCase(c)) != (upperCase2 = Character.toUpperCase(charAt)) && Character.toLowerCase(upperCase) != Character.toLowerCase(upperCase2)) {
                    return false;
                }
                i5 = i8;
                i4 = i6;
                i2 = i7;
            }
        }

        @Override // org.apache.xerces.impl.xpath.regex.RegularExpression.ExpressionTarget
        public char charAt(int i2) {
            return this.target[i2];
        }

        @Override // org.apache.xerces.impl.xpath.regex.RegularExpression.ExpressionTarget
        public final boolean regionMatches(boolean z, int i2, int i3, int i4, int i5) {
            if (i2 < 0 || i3 - i2 < i5) {
                return false;
            }
            return z ? regionMatchesIgnoreCase(i2, i3, i4, i5) : regionMatches(i2, i3, i4, i5);
        }

        @Override // org.apache.xerces.impl.xpath.regex.RegularExpression.ExpressionTarget
        public final boolean regionMatches(boolean z, int i2, int i3, String str, int i4) {
            if (i2 < 0 || i3 - i2 < i4) {
                return false;
            }
            return z ? regionMatchesIgnoreCase(i2, i3, str, i4) : regionMatches(i2, i3, str, i4);
        }

        public final void resetTarget(char[] cArr) {
            this.target = cArr;
        }
    }

    public static final class CharacterIteratorTarget extends ExpressionTarget {
        public CharacterIterator target;

        public CharacterIteratorTarget(CharacterIterator characterIterator) {
            this.target = characterIterator;
        }

        private final boolean regionMatches(int i2, int i3, int i4, int i5) {
            while (true) {
                int i6 = i5 - 1;
                if (i5 <= 0) {
                    return true;
                }
                int i7 = i2 + 1;
                int i8 = i4 + 1;
                if (this.target.setIndex(i2) != this.target.setIndex(i4)) {
                    return false;
                }
                i5 = i6;
                i2 = i7;
                i4 = i8;
            }
        }

        private final boolean regionMatches(int i2, int i3, String str, int i4) {
            int i5 = 0;
            while (true) {
                int i6 = i4 - 1;
                if (i4 <= 0) {
                    return true;
                }
                int i7 = i2 + 1;
                int i8 = i5 + 1;
                if (this.target.setIndex(i2) != str.charAt(i5)) {
                    return false;
                }
                i5 = i8;
                i4 = i6;
                i2 = i7;
            }
        }

        private final boolean regionMatchesIgnoreCase(int i2, int i3, int i4, int i5) {
            char upperCase;
            char upperCase2;
            while (true) {
                int i6 = i5 - 1;
                if (i5 <= 0) {
                    return true;
                }
                int i7 = i2 + 1;
                char index = this.target.setIndex(i2);
                int i8 = i4 + 1;
                char index2 = this.target.setIndex(i4);
                if (index != index2 && (upperCase = Character.toUpperCase(index)) != (upperCase2 = Character.toUpperCase(index2)) && Character.toLowerCase(upperCase) != Character.toLowerCase(upperCase2)) {
                    return false;
                }
                i5 = i6;
                i2 = i7;
                i4 = i8;
            }
        }

        private final boolean regionMatchesIgnoreCase(int i2, int i3, String str, int i4) {
            char upperCase;
            char upperCase2;
            int i5 = 0;
            while (true) {
                int i6 = i4 - 1;
                if (i4 <= 0) {
                    return true;
                }
                int i7 = i2 + 1;
                char index = this.target.setIndex(i2);
                int i8 = i5 + 1;
                char charAt = str.charAt(i5);
                if (index != charAt && (upperCase = Character.toUpperCase(index)) != (upperCase2 = Character.toUpperCase(charAt)) && Character.toLowerCase(upperCase) != Character.toLowerCase(upperCase2)) {
                    return false;
                }
                i5 = i8;
                i4 = i6;
                i2 = i7;
            }
        }

        @Override // org.apache.xerces.impl.xpath.regex.RegularExpression.ExpressionTarget
        public final char charAt(int i2) {
            return this.target.setIndex(i2);
        }

        @Override // org.apache.xerces.impl.xpath.regex.RegularExpression.ExpressionTarget
        public final boolean regionMatches(boolean z, int i2, int i3, int i4, int i5) {
            if (i2 < 0 || i3 - i2 < i5) {
                return false;
            }
            return z ? regionMatchesIgnoreCase(i2, i3, i4, i5) : regionMatches(i2, i3, i4, i5);
        }

        @Override // org.apache.xerces.impl.xpath.regex.RegularExpression.ExpressionTarget
        public final boolean regionMatches(boolean z, int i2, int i3, String str, int i4) {
            if (i2 < 0 || i3 - i2 < i4) {
                return false;
            }
            return z ? regionMatchesIgnoreCase(i2, i3, str, i4) : regionMatches(i2, i3, str, i4);
        }

        public final void resetTarget(CharacterIterator characterIterator) {
            this.target = characterIterator;
        }
    }

    public static final class ClosureContext {
        public int currentIndex = 0;
        public int[] offsets = new int[4];

        private int[] expandOffsets() {
            int[] iArr = this.offsets;
            int[] iArr2 = new int[(iArr.length << 1)];
            System.arraycopy(iArr, 0, iArr2, 0, this.currentIndex);
            return iArr2;
        }

        public void addOffset(int i2) {
            if (this.currentIndex == this.offsets.length) {
                this.offsets = expandOffsets();
            }
            int[] iArr = this.offsets;
            int i3 = this.currentIndex;
            this.currentIndex = i3 + 1;
            iArr[i3] = i2;
        }

        public boolean contains(int i2) {
            for (int i3 = 0; i3 < this.currentIndex; i3++) {
                if (this.offsets[i3] == i2) {
                    return true;
                }
            }
            return false;
        }

        public void reset() {
            this.currentIndex = 0;
        }
    }

    public static final class Context {
        public CharArrayTarget charArrayTarget;
        public CharacterIteratorTarget characterIteratorTarget;
        public ClosureContext[] closureContexts;
        public boolean inuse = false;
        public int length;
        public int limit;
        public Match match;
        public int start;
        public StringTarget stringTarget;
        public ExpressionTarget target;

        private void resetCommon(int i2) {
            this.length = this.limit - this.start;
            setInUse(true);
            this.match = null;
            ClosureContext[] closureContextArr = this.closureContexts;
            if (closureContextArr == null || closureContextArr.length != i2) {
                this.closureContexts = new ClosureContext[i2];
            }
            for (int i3 = 0; i3 < i2; i3++) {
                ClosureContext[] closureContextArr2 = this.closureContexts;
                if (closureContextArr2[i3] == null) {
                    closureContextArr2[i3] = new ClosureContext();
                } else {
                    closureContextArr2[i3].reset();
                }
            }
        }

        public void reset(String str, int i2, int i3, int i4) {
            StringTarget stringTarget2 = this.stringTarget;
            if (stringTarget2 == null) {
                this.stringTarget = new StringTarget(str);
            } else {
                stringTarget2.resetTarget(str);
            }
            this.target = this.stringTarget;
            this.start = i2;
            this.limit = i3;
            resetCommon(i4);
        }

        public void reset(CharacterIterator characterIterator, int i2, int i3, int i4) {
            CharacterIteratorTarget characterIteratorTarget2 = this.characterIteratorTarget;
            if (characterIteratorTarget2 == null) {
                this.characterIteratorTarget = new CharacterIteratorTarget(characterIterator);
            } else {
                characterIteratorTarget2.resetTarget(characterIterator);
            }
            this.target = this.characterIteratorTarget;
            this.start = i2;
            this.limit = i3;
            resetCommon(i4);
        }

        public void reset(char[] cArr, int i2, int i3, int i4) {
            CharArrayTarget charArrayTarget2 = this.charArrayTarget;
            if (charArrayTarget2 == null) {
                this.charArrayTarget = new CharArrayTarget(cArr);
            } else {
                charArrayTarget2.resetTarget(cArr);
            }
            this.target = this.charArrayTarget;
            this.start = i2;
            this.limit = i3;
            resetCommon(i4);
        }

        public synchronized void setInUse(boolean z) {
            this.inuse = z;
        }
    }

    public static abstract class ExpressionTarget {
        public abstract char charAt(int i2);

        public abstract boolean regionMatches(boolean z, int i2, int i3, int i4, int i5);

        public abstract boolean regionMatches(boolean z, int i2, int i3, String str, int i4);
    }

    public static final class StringTarget extends ExpressionTarget {
        public String target;

        public StringTarget(String str) {
            this.target = str;
        }

        @Override // org.apache.xerces.impl.xpath.regex.RegularExpression.ExpressionTarget
        public final char charAt(int i2) {
            return this.target.charAt(i2);
        }

        @Override // org.apache.xerces.impl.xpath.regex.RegularExpression.ExpressionTarget
        public final boolean regionMatches(boolean z, int i2, int i3, int i4, int i5) {
            if (i3 - i2 < i5) {
                return false;
            }
            if (z) {
                String str = this.target;
                return str.regionMatches(true, i2, str, i4, i5);
            }
            String str2 = this.target;
            return str2.regionMatches(i2, str2, i4, i5);
        }

        @Override // org.apache.xerces.impl.xpath.regex.RegularExpression.ExpressionTarget
        public final boolean regionMatches(boolean z, int i2, int i3, String str, int i4) {
            if (i3 - i2 < i4) {
                return false;
            }
            return z ? this.target.regionMatches(true, i2, str, 0, i4) : this.target.regionMatches(i2, str, 0, i4);
        }

        public final void resetTarget(String str) {
            this.target = str;
        }
    }

    public RegularExpression(String str) {
        this(str, null);
    }

    public RegularExpression(String str, String str2) {
        this.hasBackReferences = false;
        this.operations = null;
        this.context = null;
        this.firstChar = null;
        this.fixedString = null;
        this.fixedStringTable = null;
        this.fixedStringOnly = false;
        setPattern(str, str2);
    }

    public RegularExpression(String str, String str2, Locale locale) {
        this.hasBackReferences = false;
        this.operations = null;
        this.context = null;
        this.firstChar = null;
        this.fixedString = null;
        this.fixedStringTable = null;
        this.fixedStringOnly = false;
        setPattern(str, str2, locale);
    }

    public RegularExpression(String str, Token token, int i2, boolean z, int i3) {
        this.hasBackReferences = false;
        this.operations = null;
        this.context = null;
        this.firstChar = null;
        this.fixedString = null;
        this.fixedStringTable = null;
        this.fixedStringOnly = false;
        this.regex = str;
        this.tokentree = token;
        this.nofparen = i2;
        this.options = i3;
        this.hasBackReferences = z;
    }

    private Op compile(Token token, Op op, boolean z) {
        Op op2;
        Op op3;
        Op.ChildOp childOp;
        Op op4;
        int i2;
        int i3;
        Op op5;
        int i4 = token.type;
        int i5 = 0;
        switch (i4) {
            case 0:
                op2 = Op.createChar(token.getChar());
                break;
            case 1:
                if (!z) {
                    for (int size = token.size() - 1; size >= 0; size--) {
                        op = compile(token.getChild(size), op, false);
                    }
                    return op;
                }
                while (i5 < token.size()) {
                    op = compile(token.getChild(i5), op, true);
                    i5++;
                }
                return op;
            case 2:
                Op.UnionOp createUnion = Op.createUnion(token.size());
                while (i5 < token.size()) {
                    createUnion.addElement(compile(token.getChild(i5), op, z));
                    i5++;
                }
                return createUnion;
            case 3:
            case 9:
                Token child = token.getChild(0);
                int min = token.getMin();
                int max = token.getMax();
                if (min < 0 || min != max) {
                    if (min > 0 && max > 0) {
                        max -= min;
                    }
                    if (max > 0) {
                        int i6 = 0;
                        Op op6 = op;
                        while (i6 < max) {
                            Op.ChildOp createQuestion = Op.createQuestion(token.type == 9);
                            createQuestion.next = op;
                            createQuestion.setChild(compile(child, op6, z));
                            i6++;
                            op6 = createQuestion;
                        }
                        op3 = op6;
                    } else {
                        if (token.type == 9) {
                            childOp = Op.createNonGreedyClosure();
                        } else {
                            int i7 = this.numberOfClosures;
                            this.numberOfClosures = i7 + 1;
                            childOp = Op.createClosure(i7);
                        }
                        childOp.next = op;
                        childOp.setChild(compile(child, childOp, z));
                        op3 = childOp;
                    }
                    if (min <= 0) {
                        return op3;
                    }
                    while (i5 < min) {
                        op3 = compile(child, op3, z);
                        i5++;
                    }
                    return op3;
                }
                while (i5 < min) {
                    op = compile(child, op, z);
                    i5++;
                }
                return op;
            case 4:
            case 5:
                op2 = Op.createRange(token);
                break;
            case 6:
                if (token.getParenNumber() == 0) {
                    return compile(token.getChild(0), op, z);
                }
                int parenNumber = token.getParenNumber();
                if (z) {
                    op4 = compile(token.getChild(0), Op.createCapture(parenNumber, op), z);
                    i2 = -token.getParenNumber();
                } else {
                    op4 = compile(token.getChild(0), Op.createCapture(-parenNumber, op), z);
                    i2 = token.getParenNumber();
                }
                return Op.createCapture(i2, op4);
            case 7:
                return op;
            case 8:
                op2 = Op.createAnchor(token.getChar());
                break;
            case 10:
                op2 = Op.createString(token.getString());
                break;
            case 11:
                op2 = Op.createDot();
                break;
            case 12:
                op2 = Op.createBackReference(token.getReferenceNumber());
                break;
            default:
                Op op7 = null;
                switch (i4) {
                    case 20:
                        i3 = 20;
                        op5 = compile(token.getChild(0), null, false);
                        return Op.createLook(i3, op, op5);
                    case 21:
                        i3 = 21;
                        op5 = compile(token.getChild(0), null, false);
                        return Op.createLook(i3, op, op5);
                    case 22:
                        i3 = 22;
                        op5 = compile(token.getChild(0), null, true);
                        return Op.createLook(i3, op, op5);
                    case 23:
                        i3 = 23;
                        op5 = compile(token.getChild(0), null, true);
                        return Op.createLook(i3, op, op5);
                    case 24:
                        return Op.createIndependent(op, compile(token.getChild(0), null, z));
                    case 25:
                        Token.ModifierToken modifierToken = (Token.ModifierToken) token;
                        return Op.createModifier(op, compile(token.getChild(0), null, z), modifierToken.getOptions(), modifierToken.getOptionsMask());
                    case 26:
                        Token.ConditionToken conditionToken = (Token.ConditionToken) token;
                        int i8 = conditionToken.refNumber;
                        Token token2 = conditionToken.condition;
                        Op compile = token2 == null ? null : compile(token2, null, z);
                        Op compile2 = compile(conditionToken.yes, op, z);
                        Token token3 = conditionToken.no;
                        if (token3 != null) {
                            op7 = compile(token3, op, z);
                        }
                        return Op.createCondition(op, i8, compile, compile2, op7);
                    default:
                        StringBuffer a = a.a("Unknown token type: ");
                        a.append(token.type);
                        throw new RuntimeException(a.toString());
                }
        }
        op2.next = op;
        return op2;
    }

    private synchronized void compile(Token token) {
        if (this.operations == null) {
            this.numberOfClosures = 0;
            this.operations = compile(token, null, false);
        }
    }

    public static final int getPreviousWordType(ExpressionTarget expressionTarget, int i2, int i3, int i4, int i5) {
        int wordType;
        do {
            i4--;
            wordType = getWordType(expressionTarget, i2, i3, i4, i5);
        } while (wordType == 0);
        return wordType;
    }

    public static final int getWordType(ExpressionTarget expressionTarget, int i2, int i3, int i4, int i5) {
        if (i4 < i2 || i4 >= i3) {
            return 2;
        }
        return getWordType0(expressionTarget.charAt(i4), i5);
    }

    public static final int getWordType0(char c, int i2) {
        if (!isSet(i2, 64)) {
            return isSet(i2, 32) ? Token.getRange("IsWord", true).match(c) ? 1 : 2 : isWordChar(c) ? 1 : 2;
        }
        int type = Character.getType(c);
        if (type != 15) {
            if (type != 16) {
                switch (type) {
                    case 1:
                    case 2:
                    case 3:
                    case 4:
                    case 5:
                    case 8:
                    case 9:
                    case 10:
                    case 11:
                        return 1;
                    case 6:
                    case 7:
                        break;
                    default:
                        return 2;
                }
            }
            return 0;
        }
        switch (c) {
            case '\t':
            case '\n':
            case 11:
            case '\f':
            case '\r':
                return 2;
            default:
                return 0;
        }
    }

    public static final boolean isEOLChar(int i2) {
        return i2 == 10 || i2 == 13 || i2 == 8232 || i2 == 8233;
    }

    public static final boolean isSet(int i2, int i3) {
        return (i2 & i3) == i3;
    }

    public static final boolean isWordChar(int i2) {
        if (i2 == 95) {
            return true;
        }
        if (i2 < 48 || i2 > 122) {
            return false;
        }
        if (i2 <= 57) {
            return true;
        }
        if (i2 < 65) {
            return false;
        }
        return i2 <= 90 || i2 >= 97;
    }

    /* JADX DEBUG: Failed to insert an additional move for type inference into block B:222:0x0331 */
    /* JADX DEBUG: Failed to insert an additional move for type inference into block B:211:0x03a7 */
    /* JADX DEBUG: Failed to insert an additional move for type inference into block B:219:0x0331 */
    /*  JADX ERROR: JadxOverflowException in pass: RegionMakerVisitor
        jadx.core.utils.exceptions.JadxOverflowException: Regions count limit reached
        	at jadx.core.utils.ErrorsCounter.addError(ErrorsCounter.java:57)
        	at jadx.core.utils.ErrorsCounter.error(ErrorsCounter.java:31)
        	at jadx.core.dex.attributes.nodes.NotificationAttrNode.addError(NotificationAttrNode.java:15)
        */
    /* JADX WARNING: Removed duplicated region for block: B:165:0x0336  */
    /* JADX WARNING: Removed duplicated region for block: B:189:0x038e  */
    /* JADX WARNING: Removed duplicated region for block: B:217:0x0331 A[SYNTHETIC] */
    private int match(org.apache.xerces.impl.xpath.regex.RegularExpression.Context r23, org.apache.xerces.impl.xpath.regex.Op r24, int r25, int r26, int r27) {
        /*
        // Method dump skipped, instructions count: 1034
        */
        throw new UnsupportedOperationException("Method not decompiled: org.apache.xerces.impl.xpath.regex.RegularExpression.match(org.apache.xerces.impl.xpath.regex.RegularExpression$Context, org.apache.xerces.impl.xpath.regex.Op, int, int, int):int");
    }

    private boolean matchChar(int i2, int i3, boolean z) {
        return z ? matchIgnoreCase(i2, i3) : i2 == i3;
    }

    public static final boolean matchIgnoreCase(int i2, int i3) {
        if (i2 == i3) {
            return true;
        }
        if (i2 > 65535 || i3 > 65535) {
            return false;
        }
        char upperCase = Character.toUpperCase((char) i2);
        char upperCase2 = Character.toUpperCase((char) i3);
        return upperCase == upperCase2 || Character.toLowerCase(upperCase) == Character.toLowerCase(upperCase2);
    }

    private void setPattern(String str, int i2, Locale locale) {
        this.regex = str;
        this.options = i2;
        RegexParser parserForXMLSchema = isSet(i2, 512) ? new ParserForXMLSchema(locale) : new RegexParser(locale);
        this.tokentree = parserForXMLSchema.parse(this.regex, this.options);
        this.nofparen = parserForXMLSchema.parennumber;
        this.hasBackReferences = parserForXMLSchema.hasBackReferences;
        this.operations = null;
        this.context = null;
    }

    public boolean equals(Object obj) {
        if (obj == null || !(obj instanceof RegularExpression)) {
            return false;
        }
        RegularExpression regularExpression = (RegularExpression) obj;
        return this.regex.equals(regularExpression.regex) && this.options == regularExpression.options;
    }

    public boolean equals(String str, int i2) {
        return this.regex.equals(str) && this.options == i2;
    }

    public int getNumberOfGroups() {
        return this.nofparen;
    }

    public String getOptions() {
        return REUtil.createOptionString(this.options);
    }

    public String getPattern() {
        return this.regex;
    }

    public int hashCode() {
        StringBuffer stringBuffer = new StringBuffer();
        stringBuffer.append(this.regex);
        stringBuffer.append(ZipHelper.FORWARD_SLASH);
        stringBuffer.append(getOptions());
        return stringBuffer.toString().hashCode();
    }

    /* JADX WARNING: Removed duplicated region for block: B:111:0x013e A[RETURN] */
    public boolean matchAnchor(ExpressionTarget expressionTarget, Op op, Context context2, int i2, int i3) {
        int i4;
        int i5;
        int i6;
        int i7;
        int wordType;
        int wordType2;
        int data = op.getData();
        if (data != 36) {
            if (data != 60) {
                if (data != 62) {
                    if (data == 90) {
                        int i8 = context2.limit;
                        if (i2 != i8 && (((i7 = i2 + 1) != i8 || !isEOLChar(expressionTarget.charAt(i2))) && (i2 + 2 != context2.limit || expressionTarget.charAt(i2) != '\r' || expressionTarget.charAt(i7) != '\n'))) {
                            return false;
                        }
                    } else if (data != 94) {
                        if (data != 98) {
                            if (data != 122) {
                                switch (data) {
                                    case 64:
                                        int i9 = context2.start;
                                        return i2 == i9 || (i2 > i9 && isEOLChar(expressionTarget.charAt(i2 - 1)));
                                    case 65:
                                        if (i2 != context2.start) {
                                            return false;
                                        }
                                        break;
                                    case 66:
                                        if (!(context2.length == 0 || (wordType2 = getWordType(expressionTarget, context2.start, context2.limit, i2, i3)) == 0 || wordType2 == getPreviousWordType(expressionTarget, context2.start, context2.limit, i2, i3))) {
                                            return false;
                                        }
                                        break;
                                }
                            } else if (i2 != context2.limit) {
                                return false;
                            }
                        } else if (context2.length == 0 || (wordType = getWordType(expressionTarget, context2.start, context2.limit, i2, i3)) == 0 || wordType == getPreviousWordType(expressionTarget, context2.start, context2.limit, i2, i3)) {
                            return false;
                        }
                    } else if (isSet(i3, 8)) {
                        int i10 = context2.start;
                        if (i2 != i10 && (i2 <= i10 || i2 >= context2.limit || !isEOLChar(expressionTarget.charAt(i2 - 1)))) {
                            return false;
                        }
                    } else if (i2 != context2.start) {
                        return false;
                    }
                } else if (context2.length == 0 || i2 == (i6 = context2.start) || getWordType(expressionTarget, i6, context2.limit, i2, i3) != 2 || getPreviousWordType(expressionTarget, context2.start, context2.limit, i2, i3) != 1) {
                    return false;
                }
            } else if (context2.length == 0 || i2 == (i5 = context2.limit) || getWordType(expressionTarget, context2.start, i5, i2, i3) != 1 || getPreviousWordType(expressionTarget, context2.start, context2.limit, i2, i3) != 2) {
                return false;
            }
        } else if (isSet(i3, 8)) {
            int i11 = context2.limit;
            if (i2 != i11 && (i2 >= i11 || !isEOLChar(expressionTarget.charAt(i2)))) {
                return false;
            }
        } else {
            int i12 = context2.limit;
            if (i2 != i12 && (((i4 = i2 + 1) != i12 || !isEOLChar(expressionTarget.charAt(i2))) && (i2 + 2 != context2.limit || expressionTarget.charAt(i2) != '\r' || expressionTarget.charAt(i4) != '\n'))) {
                return false;
            }
        }
    }

    public boolean matches(String str) {
        return matches(str, 0, str.length(), (Match) null);
    }

    public boolean matches(String str, int i2, int i3) {
        return matches(str, i2, i3, (Match) null);
    }

    /* JADX WARNING: Removed duplicated region for block: B:90:0x0163  */
    /* JADX WARNING: Removed duplicated region for block: B:95:0x0173  */
    public boolean matches(String str, int i2, int i3, Match match) {
        Context context2;
        int i4;
        int i5;
        int i6;
        int i7;
        int i8;
        synchronized (this) {
            if (this.operations == null) {
                prepare();
            }
            if (this.context == null) {
                this.context = new Context();
            }
        }
        synchronized (this.context) {
            context2 = this.context.inuse ? new Context() : this.context;
            context2.reset(str, i2, i3, this.numberOfClosures);
        }
        if (match != null) {
            match.setNumberOfGroups(this.nofparen);
            match.setSource(str);
        } else if (this.hasBackReferences) {
            match = new Match();
            match.setNumberOfGroups(this.nofparen);
        }
        context2.match = match;
        if (isSet(this.options, 512)) {
            int match2 = match(context2, this.operations, context2.start, 1, this.options);
            if (match2 != context2.limit) {
                return false;
            }
            Match match3 = context2.match;
            if (match3 != null) {
                match3.setBeginning(0, context2.start);
                context2.match.setEnd(0, match2);
            }
            context2.setInUse(false);
            return true;
        } else if (this.fixedStringOnly) {
            int matches = this.fixedStringTable.matches(str, context2.start, context2.limit);
            if (matches >= 0) {
                Match match4 = context2.match;
                if (match4 != null) {
                    match4.setBeginning(0, matches);
                    context2.match.setEnd(0, this.fixedString.length() + matches);
                }
                context2.setInUse(false);
                return true;
            }
            context2.setInUse(false);
            return false;
        } else if (this.fixedString == null || this.fixedStringTable.matches(str, context2.start, context2.limit) >= 0) {
            int i9 = context2.limit - this.minlength;
            int i10 = -1;
            Op op = this.operations;
            if (op == null || op.type != 7 || op.getChild().type != 0) {
                RangeToken rangeToken = this.firstChar;
                if (rangeToken != null) {
                    i7 = context2.start;
                    i6 = -1;
                    while (i7 <= i9) {
                        int charAt = str.charAt(i7);
                        if (REUtil.isHighSurrogate(charAt) && (i8 = i7 + 1) < context2.limit) {
                            charAt = REUtil.composeFromSurrogates(charAt, str.charAt(i8));
                        }
                        if (rangeToken.match(charAt) && (i6 = match(context2, this.operations, i7, 1, this.options)) >= 0) {
                            break;
                        }
                        i7++;
                    }
                } else {
                    i5 = context2.start;
                    while (i5 <= i9) {
                        i10 = match(context2, this.operations, i5, 1, this.options);
                        if (i10 >= 0) {
                            break;
                        }
                        i5++;
                    }
                    i4 = i10;
                    if (i4 >= 0) {
                        Match match5 = context2.match;
                        if (match5 != null) {
                            match5.setBeginning(0, i5);
                            context2.match.setEnd(0, i4);
                        }
                        context2.setInUse(false);
                        return true;
                    }
                    context2.setInUse(false);
                    return false;
                }
            } else if (isSet(this.options, 4)) {
                i5 = context2.start;
                i4 = match(context2, this.operations, i5, 1, this.options);
                if (i4 >= 0) {
                }
            } else {
                i7 = context2.start;
                i6 = -1;
                boolean z = true;
                while (i7 <= i9) {
                    if (!isEOLChar(str.charAt(i7))) {
                        if (z && (i6 = match(context2, this.operations, i7, 1, this.options)) >= 0) {
                            break;
                        }
                        z = false;
                    } else {
                        z = true;
                    }
                    i7++;
                }
            }
            i5 = i7;
            i4 = i6;
            if (i4 >= 0) {
            }
        } else {
            context2.setInUse(false);
            return false;
        }
    }

    public boolean matches(String str, Match match) {
        return matches(str, 0, str.length(), match);
    }

    public boolean matches(CharacterIterator characterIterator) {
        return matches(characterIterator, (Match) null);
    }

    /* JADX WARNING: Removed duplicated region for block: B:91:0x016b  */
    /* JADX WARNING: Removed duplicated region for block: B:96:0x017b  */
    public boolean matches(CharacterIterator characterIterator, Match match) {
        Context context2;
        int i2;
        int i3;
        int i4;
        int i5;
        int i6;
        int beginIndex = characterIterator.getBeginIndex();
        int endIndex = characterIterator.getEndIndex();
        synchronized (this) {
            if (this.operations == null) {
                prepare();
            }
            if (this.context == null) {
                this.context = new Context();
            }
        }
        synchronized (this.context) {
            context2 = this.context.inuse ? new Context() : this.context;
            context2.reset(characterIterator, beginIndex, endIndex, this.numberOfClosures);
        }
        if (match != null) {
            match.setNumberOfGroups(this.nofparen);
            match.setSource(characterIterator);
        } else if (this.hasBackReferences) {
            match = new Match();
            match.setNumberOfGroups(this.nofparen);
        }
        context2.match = match;
        if (isSet(this.options, 512)) {
            int match2 = match(context2, this.operations, context2.start, 1, this.options);
            if (match2 != context2.limit) {
                return false;
            }
            Match match3 = context2.match;
            if (match3 != null) {
                match3.setBeginning(0, context2.start);
                context2.match.setEnd(0, match2);
            }
            context2.setInUse(false);
            return true;
        } else if (this.fixedStringOnly) {
            int matches = this.fixedStringTable.matches(characterIterator, context2.start, context2.limit);
            if (matches >= 0) {
                Match match4 = context2.match;
                if (match4 != null) {
                    match4.setBeginning(0, matches);
                    context2.match.setEnd(0, this.fixedString.length() + matches);
                }
                context2.setInUse(false);
                return true;
            }
            context2.setInUse(false);
            return false;
        } else if (this.fixedString == null || this.fixedStringTable.matches(characterIterator, context2.start, context2.limit) >= 0) {
            int i7 = context2.limit - this.minlength;
            int i8 = -1;
            Op op = this.operations;
            if (op == null || op.type != 7 || op.getChild().type != 0) {
                RangeToken rangeToken = this.firstChar;
                if (rangeToken != null) {
                    i5 = context2.start;
                    i4 = -1;
                    while (i5 <= i7) {
                        int index = characterIterator.setIndex(i5);
                        if (REUtil.isHighSurrogate(index) && (i6 = i5 + 1) < context2.limit) {
                            index = REUtil.composeFromSurrogates(index, characterIterator.setIndex(i6));
                        }
                        if (rangeToken.match(index) && (i4 = match(context2, this.operations, i5, 1, this.options)) >= 0) {
                            break;
                        }
                        i5++;
                    }
                } else {
                    i3 = context2.start;
                    while (i3 <= i7) {
                        i8 = match(context2, this.operations, i3, 1, this.options);
                        if (i8 >= 0) {
                            break;
                        }
                        i3++;
                    }
                    i2 = i8;
                    if (i2 >= 0) {
                        Match match5 = context2.match;
                        if (match5 != null) {
                            match5.setBeginning(0, i3);
                            context2.match.setEnd(0, i2);
                        }
                        context2.setInUse(false);
                        return true;
                    }
                    context2.setInUse(false);
                    return false;
                }
            } else if (isSet(this.options, 4)) {
                i3 = context2.start;
                i2 = match(context2, this.operations, i3, 1, this.options);
                if (i2 >= 0) {
                }
            } else {
                i5 = context2.start;
                i4 = -1;
                boolean z = true;
                while (i5 <= i7) {
                    if (!isEOLChar(characterIterator.setIndex(i5))) {
                        if (z && (i4 = match(context2, this.operations, i5, 1, this.options)) >= 0) {
                            break;
                        }
                        z = false;
                    } else {
                        z = true;
                    }
                    i5++;
                }
            }
            i3 = i5;
            i2 = i4;
            if (i2 >= 0) {
            }
        } else {
            context2.setInUse(false);
            return false;
        }
    }

    public boolean matches(char[] cArr) {
        return matches(cArr, 0, cArr.length, (Match) null);
    }

    public boolean matches(char[] cArr, int i2, int i3) {
        return matches(cArr, i2, i3, (Match) null);
    }

    /* JADX WARNING: Removed duplicated region for block: B:90:0x015d  */
    /* JADX WARNING: Removed duplicated region for block: B:95:0x016d  */
    public boolean matches(char[] cArr, int i2, int i3, Match match) {
        Context context2;
        int i4;
        int i5;
        int i6;
        int i7;
        synchronized (this) {
            if (this.operations == null) {
                prepare();
            }
            if (this.context == null) {
                this.context = new Context();
            }
        }
        synchronized (this.context) {
            context2 = this.context.inuse ? new Context() : this.context;
            context2.reset(cArr, i2, i3, this.numberOfClosures);
        }
        if (match != null) {
            match.setNumberOfGroups(this.nofparen);
            match.setSource(cArr);
        } else if (this.hasBackReferences) {
            match = new Match();
            match.setNumberOfGroups(this.nofparen);
        }
        context2.match = match;
        if (isSet(this.options, 512)) {
            int match2 = match(context2, this.operations, context2.start, 1, this.options);
            if (match2 != context2.limit) {
                return false;
            }
            Match match3 = context2.match;
            if (match3 != null) {
                match3.setBeginning(0, context2.start);
                context2.match.setEnd(0, match2);
            }
            context2.setInUse(false);
            return true;
        } else if (this.fixedStringOnly) {
            int matches = this.fixedStringTable.matches(cArr, context2.start, context2.limit);
            if (matches >= 0) {
                Match match4 = context2.match;
                if (match4 != null) {
                    match4.setBeginning(0, matches);
                    context2.match.setEnd(0, this.fixedString.length() + matches);
                }
                context2.setInUse(false);
                return true;
            }
            context2.setInUse(false);
            return false;
        } else if (this.fixedString == null || this.fixedStringTable.matches(cArr, context2.start, context2.limit) >= 0) {
            int i8 = context2.limit - this.minlength;
            int i9 = -1;
            Op op = this.operations;
            if (op == null || op.type != 7 || op.getChild().type != 0) {
                RangeToken rangeToken = this.firstChar;
                if (rangeToken != null) {
                    i7 = context2.start;
                    i6 = -1;
                    while (i7 <= i8) {
                        char c = cArr[i7];
                        boolean isHighSurrogate = REUtil.isHighSurrogate(c);
                        int i10 = c;
                        if (isHighSurrogate) {
                            int i11 = i7 + 1;
                            i10 = c;
                            if (i11 < context2.limit) {
                                i10 = REUtil.composeFromSurrogates(c, cArr[i11]);
                            }
                        }
                        if (rangeToken.match(i10 == 1 ? 1 : 0) && (i6 = match(context2, this.operations, i7, 1, this.options)) >= 0) {
                            break;
                        }
                        i7++;
                    }
                } else {
                    i5 = context2.start;
                    while (i5 <= i8) {
                        i9 = match(context2, this.operations, i5, 1, this.options);
                        if (i9 >= 0) {
                            break;
                        }
                        i5++;
                    }
                    i4 = i9;
                    if (i4 >= 0) {
                        Match match5 = context2.match;
                        if (match5 != null) {
                            match5.setBeginning(0, i5);
                            context2.match.setEnd(0, i4);
                        }
                        context2.setInUse(false);
                        return true;
                    }
                    context2.setInUse(false);
                    return false;
                }
            } else if (isSet(this.options, 4)) {
                i5 = context2.start;
                i4 = match(context2, this.operations, i5, 1, this.options);
                if (i4 >= 0) {
                }
            } else {
                i7 = context2.start;
                i6 = -1;
                boolean z = true;
                while (i7 <= i8) {
                    if (!isEOLChar(cArr[i7])) {
                        if (z && (i6 = match(context2, this.operations, i7, 1, this.options)) >= 0) {
                            break;
                        }
                        z = false;
                    } else {
                        z = true;
                    }
                    i7++;
                }
            }
            i5 = i7;
            i4 = i6;
            if (i4 >= 0) {
            }
        } else {
            context2.setInUse(false);
            return false;
        }
    }

    public boolean matches(char[] cArr, Match match) {
        return matches(cArr, 0, cArr.length, match);
    }

    public void prepare() {
        BMPattern bMPattern;
        int i2;
        String decomposeToSurrogates;
        compile(this.tokentree);
        this.minlength = this.tokentree.getMinLength();
        this.firstChar = null;
        if (!isSet(this.options, 128) && !isSet(this.options, 512)) {
            RangeToken createRange = Token.createRange();
            if (this.tokentree.analyzeFirstCharacter(createRange, this.options) == 1) {
                createRange.compactRanges();
                this.firstChar = createRange;
            }
        }
        Op op = this.operations;
        if (op != null && ((i2 = op.type) == 6 || i2 == 1)) {
            Op op2 = this.operations;
            if (op2.next == null) {
                this.fixedStringOnly = true;
                if (op2.type == 6) {
                    decomposeToSurrogates = op2.getString();
                } else if (op2.getData() >= 65536) {
                    decomposeToSurrogates = REUtil.decomposeToSurrogates(this.operations.getData());
                } else {
                    this.fixedString = new String(new char[]{(char) this.operations.getData()});
                    int i3 = this.options;
                    this.fixedStringOptions = i3;
                    bMPattern = new BMPattern(this.fixedString, 256, isSet(i3, 2));
                    this.fixedStringTable = bMPattern;
                }
                this.fixedString = decomposeToSurrogates;
                int i32 = this.options;
                this.fixedStringOptions = i32;
                bMPattern = new BMPattern(this.fixedString, 256, isSet(i32, 2));
                this.fixedStringTable = bMPattern;
            }
        }
        if (!isSet(this.options, 256) && !isSet(this.options, 512)) {
            Token.FixedStringContainer fixedStringContainer = new Token.FixedStringContainer();
            this.tokentree.findFixedString(fixedStringContainer, this.options);
            Token token = fixedStringContainer.token;
            String string = token == null ? null : token.getString();
            this.fixedString = string;
            this.fixedStringOptions = fixedStringContainer.options;
            if (string != null && string.length() < 2) {
                this.fixedString = null;
            }
            String str = this.fixedString;
            if (str != null) {
                bMPattern = new BMPattern(str, 256, isSet(this.fixedStringOptions, 2));
                this.fixedStringTable = bMPattern;
            }
        }
    }

    public void setPattern(String str) {
        setPattern(str, Locale.getDefault());
    }

    public void setPattern(String str, String str2) {
        setPattern(str, str2, Locale.getDefault());
    }

    public void setPattern(String str, String str2, Locale locale) {
        setPattern(str, REUtil.parseOptions(str2), locale);
    }

    public void setPattern(String str, Locale locale) {
        setPattern(str, this.options, locale);
    }

    public String toString() {
        return this.tokentree.toString(this.options);
    }
}
