package org.apache.xerces.impl.xs;

import java.io.BufferedInputStream;
import java.io.File;
import java.io.FileInputStream;
import java.io.FileNotFoundException;
import java.io.IOException;
import java.io.InputStream;
import java.io.Reader;
import java.io.StringReader;
import java.util.ArrayList;
import java.util.Hashtable;
import java.util.Locale;
import java.util.StringTokenizer;
import java.util.WeakHashMap;
import org.apache.xerces.dom.DOMErrorImpl;
import org.apache.xerces.dom.DOMMessageFormatter;
import org.apache.xerces.dom.DOMStringListImpl;
import org.apache.xerces.impl.Constants;
import org.apache.xerces.impl.XMLEntityManager;
import org.apache.xerces.impl.XMLErrorReporter;
import org.apache.xerces.impl.dv.InvalidDatatypeValueException;
import org.apache.xerces.impl.dv.SchemaDVFactory;
import org.apache.xerces.impl.dv.ValidatedInfo;
import org.apache.xerces.impl.dv.ValidationContext;
import org.apache.xerces.impl.dv.xs.SchemaDVFactoryImpl;
import org.apache.xerces.impl.xs.models.CMBuilder;
import org.apache.xerces.impl.xs.models.CMNodeFactory;
import org.apache.xerces.impl.xs.traversers.XSDHandler;
import org.apache.xerces.util.DOMEntityResolverWrapper;
import org.apache.xerces.util.DOMErrorHandlerWrapper;
import org.apache.xerces.util.DefaultErrorHandler;
import org.apache.xerces.util.MessageFormatter;
import org.apache.xerces.util.ParserConfigurationSettings;
import org.apache.xerces.util.SymbolTable;
import org.apache.xerces.util.URI;
import org.apache.xerces.util.XMLSymbols;
import org.apache.xerces.xni.QName;
import org.apache.xerces.xni.grammars.Grammar;
import org.apache.xerces.xni.grammars.XMLGrammarLoader;
import org.apache.xerces.xni.grammars.XMLGrammarPool;
import org.apache.xerces.xni.grammars.XSGrammar;
import org.apache.xerces.xni.parser.XMLComponent;
import org.apache.xerces.xni.parser.XMLComponentManager;
import org.apache.xerces.xni.parser.XMLConfigurationException;
import org.apache.xerces.xni.parser.XMLEntityResolver;
import org.apache.xerces.xni.parser.XMLErrorHandler;
import org.apache.xerces.xni.parser.XMLInputSource;
import org.apache.xerces.xs.LSInputList;
import org.apache.xerces.xs.StringList;
import org.apache.xerces.xs.XSLoader;
import org.apache.xerces.xs.XSModel;
import org.w3c.dom.DOMConfiguration;
import org.w3c.dom.DOMErrorHandler;
import org.w3c.dom.DOMException;
import org.w3c.dom.DOMStringList;
import org.w3c.dom.ls.LSInput;
import org.w3c.dom.ls.LSResourceResolver;
import org.xml.sax.InputSource;

public class XMLSchemaLoader implements XMLGrammarLoader, XMLComponent, XSElementDeclHelper, XSLoader, DOMConfiguration {
    public static final String ALLOW_JAVA_ENCODINGS = "http://apache.org/xml/features/allow-java-encodings";
    public static final String AUGMENT_PSVI = "http://apache.org/xml/features/validation/schema/augment-psvi";
    public static final String CONTINUE_AFTER_FATAL_ERROR = "http://apache.org/xml/features/continue-after-fatal-error";
    public static final String DISALLOW_DOCTYPE = "http://apache.org/xml/features/disallow-doctype-decl";
    public static final String ENTITY_MANAGER = "http://apache.org/xml/properties/internal/entity-manager";
    public static final String ENTITY_RESOLVER = "http://apache.org/xml/properties/internal/entity-resolver";
    public static final String ERROR_HANDLER = "http://apache.org/xml/properties/internal/error-handler";
    public static final String ERROR_REPORTER = "http://apache.org/xml/properties/internal/error-reporter";
    public static final String GENERATE_SYNTHETIC_ANNOTATIONS = "http://apache.org/xml/features/generate-synthetic-annotations";
    public static final String HONOUR_ALL_SCHEMALOCATIONS = "http://apache.org/xml/features/honour-all-schemaLocations";
    public static final String JAXP_SCHEMA_SOURCE = "http://java.sun.com/xml/jaxp/properties/schemaSource";
    public static final String LOCALE = "http://apache.org/xml/properties/locale";
    public static final String NAMESPACE_GROWTH = "http://apache.org/xml/features/namespace-growth";
    public static final String PARSER_SETTINGS = "http://apache.org/xml/features/internal/parser-settings";
    public static final String[] RECOGNIZED_FEATURES = {"http://apache.org/xml/features/validation/schema-full-checking", "http://apache.org/xml/features/validation/schema/augment-psvi", "http://apache.org/xml/features/continue-after-fatal-error", "http://apache.org/xml/features/allow-java-encodings", "http://apache.org/xml/features/standard-uri-conformant", "http://apache.org/xml/features/disallow-doctype-decl", "http://apache.org/xml/features/generate-synthetic-annotations", "http://apache.org/xml/features/validate-annotations", "http://apache.org/xml/features/honour-all-schemaLocations", "http://apache.org/xml/features/namespace-growth", "http://apache.org/xml/features/internal/tolerate-duplicates"};
    public static final String[] RECOGNIZED_PROPERTIES = {"http://apache.org/xml/properties/internal/entity-manager", "http://apache.org/xml/properties/internal/symbol-table", "http://apache.org/xml/properties/internal/error-reporter", "http://apache.org/xml/properties/internal/error-handler", "http://apache.org/xml/properties/internal/entity-resolver", "http://apache.org/xml/properties/internal/grammar-pool", "http://apache.org/xml/properties/schema/external-schemaLocation", "http://apache.org/xml/properties/schema/external-noNamespaceSchemaLocation", "http://java.sun.com/xml/jaxp/properties/schemaSource", "http://apache.org/xml/properties/security-manager", "http://apache.org/xml/properties/locale", "http://apache.org/xml/properties/internal/validation/schema/dv-factory"};
    public static final String SCHEMA_DV_FACTORY = "http://apache.org/xml/properties/internal/validation/schema/dv-factory";
    public static final String SCHEMA_FULL_CHECKING = "http://apache.org/xml/features/validation/schema-full-checking";
    public static final String SCHEMA_LOCATION = "http://apache.org/xml/properties/schema/external-schemaLocation";
    public static final String SCHEMA_NONS_LOCATION = "http://apache.org/xml/properties/schema/external-noNamespaceSchemaLocation";
    public static final String SECURITY_MANAGER = "http://apache.org/xml/properties/security-manager";
    public static final String STANDARD_URI_CONFORMANT_FEATURE = "http://apache.org/xml/features/standard-uri-conformant";
    public static final String SYMBOL_TABLE = "http://apache.org/xml/properties/internal/symbol-table";
    public static final String TOLERATE_DUPLICATES = "http://apache.org/xml/features/internal/tolerate-duplicates";
    public static final String VALIDATE_ANNOTATIONS = "http://apache.org/xml/features/validate-annotations";
    public static final String XMLGRAMMAR_POOL = "http://apache.org/xml/properties/internal/grammar-pool";
    public static /* synthetic */ Class class$java$io$File;
    public static /* synthetic */ Class class$java$io$InputStream;
    public static /* synthetic */ Class class$java$lang$Object;
    public static /* synthetic */ Class class$java$lang$String;
    public static /* synthetic */ Class class$org$xml$sax$InputSource;
    public CMBuilder fCMBuilder;
    public XSDeclarationPool fDeclPool;
    public SchemaDVFactory fDefaultSchemaDVFactory;
    public XMLEntityManager fEntityManager;
    public DOMErrorHandlerWrapper fErrorHandler;
    public XMLErrorReporter fErrorReporter;
    public String fExternalNoNSSchema;
    public String fExternalSchemas;
    public XSGrammarBucket fGrammarBucket;
    public XMLGrammarPool fGrammarPool;
    public boolean fIsCheckedFully;
    public WeakHashMap fJAXPCache;
    public boolean fJAXPProcessed;
    public Object fJAXPSource;
    public final ParserConfigurationSettings fLoaderConfig;
    public Locale fLocale;
    public DOMStringList fRecognizedParameters;
    public DOMEntityResolverWrapper fResourceResolver;
    public XSDHandler fSchemaHandler;
    public boolean fSettingsChanged;
    public SubstitutionGroupHandler fSubGroupHandler;
    public XMLEntityResolver fUserEntityResolver;
    public XSDDescription fXSDDescription;

    public static class LocationArray {
        public int length;
        public String[] locations = new String[2];

        public void addLocation(String str) {
            int i2 = this.length;
            if (i2 >= this.locations.length) {
                resize(i2, Math.max(1, i2 * 2));
            }
            String[] strArr = this.locations;
            int i3 = this.length;
            this.length = i3 + 1;
            strArr[i3] = str;
        }

        public String getFirstLocation() {
            if (this.length > 0) {
                return this.locations[0];
            }
            return null;
        }

        public int getLength() {
            return this.length;
        }

        public String[] getLocationArray() {
            int i2 = this.length;
            String[] strArr = this.locations;
            if (i2 < strArr.length) {
                resize(strArr.length, i2);
            }
            return this.locations;
        }

        public void resize(int i2, int i3) {
            String[] strArr = new String[i3];
            System.arraycopy(this.locations, 0, strArr, 0, Math.min(i2, i3));
            this.locations = strArr;
            this.length = Math.min(i2, i3);
        }
    }

    public XMLSchemaLoader() {
        this(new SymbolTable(), null, new XMLEntityManager(), null, null, null);
    }

    public XMLSchemaLoader(XMLErrorReporter xMLErrorReporter, XSGrammarBucket xSGrammarBucket, SubstitutionGroupHandler substitutionGroupHandler, CMBuilder cMBuilder) {
        this(null, xMLErrorReporter, null, xSGrammarBucket, substitutionGroupHandler, cMBuilder);
    }

    public XMLSchemaLoader(SymbolTable symbolTable) {
        this(symbolTable, null, new XMLEntityManager(), null, null, null);
    }

    public XMLSchemaLoader(SymbolTable symbolTable, XMLErrorReporter xMLErrorReporter, XMLEntityManager xMLEntityManager, XSGrammarBucket xSGrammarBucket, SubstitutionGroupHandler substitutionGroupHandler, CMBuilder cMBuilder) {
        this.fLoaderConfig = new ParserConfigurationSettings();
        this.fErrorReporter = new XMLErrorReporter();
        this.fEntityManager = null;
        this.fUserEntityResolver = null;
        this.fGrammarPool = null;
        this.fExternalSchemas = null;
        this.fExternalNoNSSchema = null;
        this.fJAXPSource = null;
        this.fIsCheckedFully = false;
        this.fJAXPProcessed = false;
        this.fSettingsChanged = true;
        this.fDeclPool = null;
        this.fXSDDescription = new XSDDescription();
        this.fLocale = Locale.getDefault();
        this.fRecognizedParameters = null;
        this.fErrorHandler = null;
        this.fResourceResolver = null;
        this.fLoaderConfig.addRecognizedFeatures(RECOGNIZED_FEATURES);
        this.fLoaderConfig.addRecognizedProperties(RECOGNIZED_PROPERTIES);
        if (symbolTable != null) {
            this.fLoaderConfig.setProperty("http://apache.org/xml/properties/internal/symbol-table", symbolTable);
        }
        if (xMLErrorReporter == null) {
            xMLErrorReporter = new XMLErrorReporter();
            xMLErrorReporter.setLocale(this.fLocale);
            xMLErrorReporter.setProperty("http://apache.org/xml/properties/internal/error-handler", new DefaultErrorHandler());
        }
        this.fErrorReporter = xMLErrorReporter;
        if (xMLErrorReporter.getMessageFormatter(XSMessageFormatter.SCHEMA_DOMAIN) == null) {
            this.fErrorReporter.putMessageFormatter(XSMessageFormatter.SCHEMA_DOMAIN, new XSMessageFormatter());
        }
        this.fLoaderConfig.setProperty("http://apache.org/xml/properties/internal/error-reporter", this.fErrorReporter);
        this.fEntityManager = xMLEntityManager;
        if (xMLEntityManager != null) {
            this.fLoaderConfig.setProperty("http://apache.org/xml/properties/internal/entity-manager", xMLEntityManager);
        }
        this.fLoaderConfig.setFeature("http://apache.org/xml/features/validation/schema/augment-psvi", true);
        this.fGrammarBucket = xSGrammarBucket == null ? new XSGrammarBucket() : xSGrammarBucket;
        this.fSubGroupHandler = substitutionGroupHandler == null ? new SubstitutionGroupHandler(this) : substitutionGroupHandler;
        this.fCMBuilder = cMBuilder == null ? new CMBuilder(new CMNodeFactory()) : cMBuilder;
        this.fSchemaHandler = new XSDHandler(this.fGrammarBucket);
        this.fJAXPCache = new WeakHashMap();
        this.fSettingsChanged = true;
    }

    public static /* synthetic */ Class class$(String str) {
        try {
            return Class.forName(str);
        } catch (ClassNotFoundException e2) {
            throw new NoClassDefFoundError(e2.getMessage());
        }
    }

    private void initGrammarBucket() {
        XMLGrammarPool xMLGrammarPool = this.fGrammarPool;
        if (xMLGrammarPool != null) {
            Grammar[] retrieveInitialGrammarSet = xMLGrammarPool.retrieveInitialGrammarSet("http://www.w3.org/2001/XMLSchema");
            int length = retrieveInitialGrammarSet != null ? retrieveInitialGrammarSet.length : 0;
            for (int i2 = 0; i2 < length; i2++) {
                if (!this.fGrammarBucket.putGrammar((SchemaGrammar) retrieveInitialGrammarSet[i2], true)) {
                    this.fErrorReporter.reportError(XSMessageFormatter.SCHEMA_DOMAIN, "GrammarConflict", null, 0);
                }
            }
        }
    }

    private boolean parserSettingsUpdated(XMLComponentManager xMLComponentManager) {
        if (xMLComponentManager == this.fLoaderConfig) {
            return true;
        }
        try {
            return xMLComponentManager.getFeature("http://apache.org/xml/features/internal/parser-settings");
        } catch (XMLConfigurationException unused) {
            return true;
        }
    }

    public static void processExternalHints(String str, String str2, Hashtable hashtable, XMLErrorReporter xMLErrorReporter) {
        if (str != null) {
            try {
                SchemaGrammar.SG_XSI.getGlobalAttributeDecl(SchemaSymbols.XSI_SCHEMALOCATION).fType.validate(str, (ValidationContext) null, (ValidatedInfo) null);
                if (!tokenizeSchemaLocationStr(str, hashtable, null)) {
                    xMLErrorReporter.reportError(XSMessageFormatter.SCHEMA_DOMAIN, "SchemaLocation", new Object[]{str}, 0);
                }
            } catch (InvalidDatatypeValueException e2) {
                xMLErrorReporter.reportError(XSMessageFormatter.SCHEMA_DOMAIN, e2.getKey(), e2.getArgs(), 0);
            }
        }
        if (str2 != null) {
            try {
                SchemaGrammar.SG_XSI.getGlobalAttributeDecl(SchemaSymbols.XSI_NONAMESPACESCHEMALOCATION).fType.validate(str2, (ValidationContext) null, (ValidatedInfo) null);
                LocationArray locationArray = (LocationArray) hashtable.get(XMLSymbols.EMPTY_STRING);
                if (locationArray == null) {
                    locationArray = new LocationArray();
                    hashtable.put(XMLSymbols.EMPTY_STRING, locationArray);
                }
                locationArray.addLocation(str2);
            } catch (InvalidDatatypeValueException e3) {
                xMLErrorReporter.reportError(XSMessageFormatter.SCHEMA_DOMAIN, e3.getKey(), e3.getArgs(), 0);
            }
        }
    }

    private void processJAXPSchemaSource(Hashtable hashtable) {
        SchemaGrammar parseSchema;
        SchemaGrammar schemaGrammar;
        this.fJAXPProcessed = true;
        Object obj = this.fJAXPSource;
        if (obj != null) {
            Class<?> componentType = obj.getClass().getComponentType();
            if (componentType == null) {
                Object obj2 = this.fJAXPSource;
                if (((obj2 instanceof InputStream) || (obj2 instanceof InputSource)) && (schemaGrammar = (SchemaGrammar) this.fJAXPCache.get(this.fJAXPSource)) != null) {
                    this.fGrammarBucket.putGrammar(schemaGrammar);
                    return;
                }
                this.fXSDDescription.reset();
                XMLInputSource xsdToXMLInputSource = xsdToXMLInputSource(this.fJAXPSource);
                String systemId = xsdToXMLInputSource.getSystemId();
                XSDDescription xSDDescription = this.fXSDDescription;
                xSDDescription.fContextType = 3;
                if (systemId != null) {
                    xSDDescription.setBaseSystemId(xsdToXMLInputSource.getBaseSystemId());
                    this.fXSDDescription.setLiteralSystemId(systemId);
                    this.fXSDDescription.setExpandedSystemId(systemId);
                    this.fXSDDescription.fLocationHints = new String[]{systemId};
                }
                SchemaGrammar loadSchema = loadSchema(this.fXSDDescription, xsdToXMLInputSource, hashtable);
                if (loadSchema != null) {
                    Object obj3 = this.fJAXPSource;
                    if ((obj3 instanceof InputStream) || (obj3 instanceof InputSource)) {
                        this.fJAXPCache.put(this.fJAXPSource, loadSchema);
                        if (this.fIsCheckedFully) {
                            XSConstraints.fullSchemaChecking(this.fGrammarBucket, this.fSubGroupHandler, this.fCMBuilder, this.fErrorReporter);
                        }
                    }
                    this.fGrammarBucket.putGrammar(loadSchema);
                    return;
                }
                return;
            }
            Class<?> cls = class$java$lang$Object;
            if (cls == null) {
                cls = class$("java.lang.Object");
                class$java$lang$Object = cls;
            }
            if (componentType != cls) {
                Class<?> cls2 = class$java$lang$String;
                if (cls2 == null) {
                    cls2 = class$("java.lang.String");
                    class$java$lang$String = cls2;
                }
                if (componentType != cls2) {
                    Class<?> cls3 = class$java$io$File;
                    if (cls3 == null) {
                        cls3 = class$("java.io.File");
                        class$java$io$File = cls3;
                    }
                    if (componentType != cls3) {
                        Class<?> cls4 = class$java$io$InputStream;
                        if (cls4 == null) {
                            cls4 = class$("java.io.InputStream");
                            class$java$io$InputStream = cls4;
                        }
                        if (componentType != cls4) {
                            Class<?> cls5 = class$org$xml$sax$InputSource;
                            if (cls5 == null) {
                                cls5 = class$("org.xml.sax.InputSource");
                                class$org$xml$sax$InputSource = cls5;
                            }
                            if (componentType != cls5) {
                                Class cls6 = class$java$io$File;
                                if (cls6 == null) {
                                    cls6 = class$("java.io.File");
                                    class$java$io$File = cls6;
                                }
                                if (!cls6.isAssignableFrom(componentType)) {
                                    Class cls7 = class$java$io$InputStream;
                                    if (cls7 == null) {
                                        cls7 = class$("java.io.InputStream");
                                        class$java$io$InputStream = cls7;
                                    }
                                    if (!cls7.isAssignableFrom(componentType)) {
                                        Class cls8 = class$org$xml$sax$InputSource;
                                        if (cls8 == null) {
                                            cls8 = class$("org.xml.sax.InputSource");
                                            class$org$xml$sax$InputSource = cls8;
                                        }
                                        if (!cls8.isAssignableFrom(componentType) && !componentType.isInterface()) {
                                            throw new XMLConfigurationException(1, this.fErrorReporter.getMessageFormatter(XSMessageFormatter.SCHEMA_DOMAIN).formatMessage(this.fErrorReporter.getLocale(), "jaxp12-schema-source-type.2", new Object[]{componentType.getName()}));
                                        }
                                    }
                                }
                            }
                        }
                    }
                }
            }
            Object[] objArr = (Object[]) this.fJAXPSource;
            ArrayList arrayList = new ArrayList();
            for (int i2 = 0; i2 < objArr.length; i2++) {
                if ((!(objArr[i2] instanceof InputStream) && !(objArr[i2] instanceof InputSource)) || (parseSchema = (SchemaGrammar) this.fJAXPCache.get(objArr[i2])) == null) {
                    this.fXSDDescription.reset();
                    XMLInputSource xsdToXMLInputSource2 = xsdToXMLInputSource(objArr[i2]);
                    String systemId2 = xsdToXMLInputSource2.getSystemId();
                    XSDDescription xSDDescription2 = this.fXSDDescription;
                    xSDDescription2.fContextType = 3;
                    if (systemId2 != null) {
                        xSDDescription2.setBaseSystemId(xsdToXMLInputSource2.getBaseSystemId());
                        this.fXSDDescription.setLiteralSystemId(systemId2);
                        this.fXSDDescription.setExpandedSystemId(systemId2);
                        this.fXSDDescription.fLocationHints = new String[]{systemId2};
                    }
                    parseSchema = this.fSchemaHandler.parseSchema(xsdToXMLInputSource2, this.fXSDDescription, hashtable);
                    if (this.fIsCheckedFully) {
                        XSConstraints.fullSchemaChecking(this.fGrammarBucket, this.fSubGroupHandler, this.fCMBuilder, this.fErrorReporter);
                    }
                    if (parseSchema != null) {
                        String targetNamespace = parseSchema.getTargetNamespace();
                        if (!arrayList.contains(targetNamespace)) {
                            arrayList.add(targetNamespace);
                            if ((objArr[i2] instanceof InputStream) || (objArr[i2] instanceof InputSource)) {
                                this.fJAXPCache.put(objArr[i2], parseSchema);
                            }
                        } else {
                            throw new IllegalArgumentException(this.fErrorReporter.getMessageFormatter(XSMessageFormatter.SCHEMA_DOMAIN).formatMessage(this.fErrorReporter.getLocale(), "jaxp12-schema-source-ns", null));
                        }
                    } else {
                        continue;
                    }
                }
                this.fGrammarBucket.putGrammar(parseSchema);
            }
        }
    }

    public static XMLInputSource resolveDocument(XSDDescription xSDDescription, Hashtable hashtable, XMLEntityResolver xMLEntityResolver) {
        String str;
        String[] locationHints;
        if (xSDDescription.getContextType() == 2 || xSDDescription.fromInstance()) {
            String targetNamespace = xSDDescription.getTargetNamespace();
            if (targetNamespace == null) {
                targetNamespace = XMLSymbols.EMPTY_STRING;
            }
            LocationArray locationArray = (LocationArray) hashtable.get(targetNamespace);
            if (locationArray != null) {
                str = locationArray.getFirstLocation();
                if (str == null && (locationHints = xSDDescription.getLocationHints()) != null && locationHints.length > 0) {
                    str = locationHints[0];
                }
                String expandSystemId = XMLEntityManager.expandSystemId(str, xSDDescription.getBaseSystemId(), false);
                xSDDescription.setLiteralSystemId(str);
                xSDDescription.setExpandedSystemId(expandSystemId);
                return xMLEntityResolver.resolveEntity(xSDDescription);
            }
        }
        str = null;
        str = locationHints[0];
        String expandSystemId2 = XMLEntityManager.expandSystemId(str, xSDDescription.getBaseSystemId(), false);
        xSDDescription.setLiteralSystemId(str);
        xSDDescription.setExpandedSystemId(expandSystemId2);
        return xMLEntityResolver.resolveEntity(xSDDescription);
    }

    public static XMLInputSource saxToXMLInputSource(InputSource inputSource) {
        String publicId = inputSource.getPublicId();
        String systemId = inputSource.getSystemId();
        Reader characterStream = inputSource.getCharacterStream();
        if (characterStream != null) {
            return new XMLInputSource(publicId, systemId, (String) null, characterStream, (String) null);
        }
        InputStream byteStream = inputSource.getByteStream();
        return byteStream != null ? new XMLInputSource(publicId, systemId, (String) null, byteStream, inputSource.getEncoding()) : new XMLInputSource(publicId, systemId, null);
    }

    public static boolean tokenizeSchemaLocationStr(String str, Hashtable hashtable, String str2) {
        if (str == null) {
            return true;
        }
        StringTokenizer stringTokenizer = new StringTokenizer(str, " \n\t\r");
        while (stringTokenizer.hasMoreTokens()) {
            String nextToken = stringTokenizer.nextToken();
            if (!stringTokenizer.hasMoreTokens()) {
                return false;
            }
            String nextToken2 = stringTokenizer.nextToken();
            LocationArray locationArray = (LocationArray) hashtable.get(nextToken);
            if (locationArray == null) {
                locationArray = new LocationArray();
                hashtable.put(nextToken, locationArray);
            }
            if (str2 != null) {
                try {
                    nextToken2 = XMLEntityManager.expandSystemId(nextToken2, str2, false);
                } catch (URI.MalformedURIException unused) {
                }
            }
            locationArray.addLocation(nextToken2);
        }
        return true;
    }

    private XMLInputSource xsdToXMLInputSource(Object obj) {
        BufferedInputStream bufferedInputStream;
        XMLInputSource xMLInputSource;
        if (obj instanceof String) {
            String str = (String) obj;
            this.fXSDDescription.reset();
            this.fXSDDescription.setValues(null, str, null, null);
            try {
                xMLInputSource = this.fEntityManager.resolveEntity(this.fXSDDescription);
            } catch (IOException unused) {
                this.fErrorReporter.reportError(XSMessageFormatter.SCHEMA_DOMAIN, "schema_reference.4", new Object[]{str}, 1);
                xMLInputSource = null;
            }
            return xMLInputSource == null ? new XMLInputSource(null, str, null) : xMLInputSource;
        } else if (obj instanceof InputSource) {
            return saxToXMLInputSource((InputSource) obj);
        } else {
            if (obj instanceof InputStream) {
                return new XMLInputSource((String) null, (String) null, (String) null, (InputStream) obj, (String) null);
            }
            if (obj instanceof File) {
                File file = (File) obj;
                String filepath2URI = FilePathToURI.filepath2URI(file.getAbsolutePath());
                try {
                    bufferedInputStream = new BufferedInputStream(new FileInputStream(file));
                } catch (FileNotFoundException unused2) {
                    this.fErrorReporter.reportError(XSMessageFormatter.SCHEMA_DOMAIN, "schema_reference.4", new Object[]{file.toString()}, 1);
                    bufferedInputStream = null;
                }
                return new XMLInputSource((String) null, filepath2URI, (String) null, bufferedInputStream, (String) null);
            }
            MessageFormatter messageFormatter = this.fErrorReporter.getMessageFormatter(XSMessageFormatter.SCHEMA_DOMAIN);
            Locale locale = this.fErrorReporter.getLocale();
            Object[] objArr = new Object[1];
            objArr[0] = obj != null ? obj.getClass().getName() : "null";
            throw new XMLConfigurationException(1, messageFormatter.formatMessage(locale, "jaxp12-schema-source-type.1", objArr));
        }
    }

    @Override // org.w3c.dom.DOMConfiguration
    public boolean canSetParameter(String str, Object obj) {
        return obj instanceof Boolean ? str.equals(Constants.DOM_VALIDATE) || str.equals("http://apache.org/xml/features/validation/schema-full-checking") || str.equals("http://apache.org/xml/features/validate-annotations") || str.equals("http://apache.org/xml/features/continue-after-fatal-error") || str.equals("http://apache.org/xml/features/allow-java-encodings") || str.equals("http://apache.org/xml/features/standard-uri-conformant") || str.equals("http://apache.org/xml/features/generate-synthetic-annotations") || str.equals("http://apache.org/xml/features/honour-all-schemaLocations") || str.equals("http://apache.org/xml/features/namespace-growth") || str.equals("http://apache.org/xml/features/internal/tolerate-duplicates") : str.equals(Constants.DOM_ERROR_HANDLER) || str.equals(Constants.DOM_RESOURCE_RESOLVER) || str.equals("http://apache.org/xml/properties/internal/symbol-table") || str.equals("http://apache.org/xml/properties/internal/error-reporter") || str.equals("http://apache.org/xml/properties/internal/error-handler") || str.equals("http://apache.org/xml/properties/internal/entity-resolver") || str.equals("http://apache.org/xml/properties/internal/grammar-pool") || str.equals("http://apache.org/xml/properties/schema/external-schemaLocation") || str.equals("http://apache.org/xml/properties/schema/external-noNamespaceSchemaLocation") || str.equals("http://java.sun.com/xml/jaxp/properties/schemaSource") || str.equals("http://apache.org/xml/properties/internal/validation/schema/dv-factory");
    }

    public XMLInputSource dom2xmlInputSource(LSInput lSInput) {
        return lSInput.getCharacterStream() != null ? new XMLInputSource(lSInput.getPublicId(), lSInput.getSystemId(), lSInput.getBaseURI(), lSInput.getCharacterStream(), "UTF-16") : lSInput.getByteStream() != null ? new XMLInputSource(lSInput.getPublicId(), lSInput.getSystemId(), lSInput.getBaseURI(), lSInput.getByteStream(), lSInput.getEncoding()) : (lSInput.getStringData() == null || lSInput.getStringData().length() == 0) ? new XMLInputSource(lSInput.getPublicId(), lSInput.getSystemId(), lSInput.getBaseURI()) : new XMLInputSource(lSInput.getPublicId(), lSInput.getSystemId(), lSInput.getBaseURI(), new StringReader(lSInput.getStringData()), "UTF-16");
    }

    @Override // org.apache.xerces.xs.XSLoader
    public DOMConfiguration getConfig() {
        return this;
    }

    @Override // org.apache.xerces.xni.grammars.XMLGrammarLoader
    public XMLEntityResolver getEntityResolver() {
        return this.fUserEntityResolver;
    }

    @Override // org.apache.xerces.xni.grammars.XMLGrammarLoader
    public XMLErrorHandler getErrorHandler() {
        return this.fErrorReporter.getErrorHandler();
    }

    @Override // org.apache.xerces.xni.grammars.XMLGrammarLoader
    public boolean getFeature(String str) {
        return this.fLoaderConfig.getFeature(str);
    }

    @Override // org.apache.xerces.xni.parser.XMLComponent
    public Boolean getFeatureDefault(String str) {
        if (str.equals("http://apache.org/xml/features/validation/schema/augment-psvi")) {
            return Boolean.TRUE;
        }
        return null;
    }

    @Override // org.apache.xerces.impl.xs.XSElementDeclHelper
    public XSElementDecl getGlobalElementDecl(QName qName) {
        SchemaGrammar grammar = this.fGrammarBucket.getGrammar(qName.uri);
        if (grammar != null) {
            return grammar.getGlobalElementDecl(qName.localpart);
        }
        return null;
    }

    @Override // org.apache.xerces.xni.grammars.XMLGrammarLoader
    public Locale getLocale() {
        return this.fLocale;
    }

    /* JADX WARNING: Code restructure failed: missing block: B:17:0x0034, code lost:
        return getProperty(r3);
     */
    /* JADX WARNING: Code restructure failed: missing block: B:20:0x004b, code lost:
        throw new org.w3c.dom.DOMException(9, org.apache.xerces.dom.DOMMessageFormatter.formatMessage(org.apache.xerces.dom.DOMMessageFormatter.DOM_DOMAIN, "FEATURE_NOT_SUPPORTED", new java.lang.Object[]{r3}));
     */
    /* JADX WARNING: Failed to process nested try/catch */
    /* JADX WARNING: Missing exception handler attribute for start block: B:15:0x0030 */
    @Override // org.w3c.dom.DOMConfiguration
    public Object getParameter(String str) {
        if (str.equals(Constants.DOM_ERROR_HANDLER)) {
            DOMErrorHandlerWrapper dOMErrorHandlerWrapper = this.fErrorHandler;
            if (dOMErrorHandlerWrapper != null) {
                return dOMErrorHandlerWrapper.getErrorHandler();
            }
            return null;
        } else if (!str.equals(Constants.DOM_RESOURCE_RESOLVER)) {
            return getFeature(str) ? Boolean.TRUE : Boolean.FALSE;
        } else {
            DOMEntityResolverWrapper dOMEntityResolverWrapper = this.fResourceResolver;
            if (dOMEntityResolverWrapper != null) {
                return dOMEntityResolverWrapper.getEntityResolver();
            }
            return null;
        }
    }

    @Override // org.w3c.dom.DOMConfiguration
    public DOMStringList getParameterNames() {
        if (this.fRecognizedParameters == null) {
            ArrayList arrayList = new ArrayList();
            arrayList.add(Constants.DOM_VALIDATE);
            arrayList.add(Constants.DOM_ERROR_HANDLER);
            arrayList.add(Constants.DOM_RESOURCE_RESOLVER);
            arrayList.add("http://apache.org/xml/properties/internal/symbol-table");
            arrayList.add("http://apache.org/xml/properties/internal/error-reporter");
            arrayList.add("http://apache.org/xml/properties/internal/error-handler");
            arrayList.add("http://apache.org/xml/properties/internal/entity-resolver");
            arrayList.add("http://apache.org/xml/properties/internal/grammar-pool");
            arrayList.add("http://apache.org/xml/properties/schema/external-schemaLocation");
            arrayList.add("http://apache.org/xml/properties/schema/external-noNamespaceSchemaLocation");
            arrayList.add("http://java.sun.com/xml/jaxp/properties/schemaSource");
            arrayList.add("http://apache.org/xml/features/validation/schema-full-checking");
            arrayList.add("http://apache.org/xml/features/continue-after-fatal-error");
            arrayList.add("http://apache.org/xml/features/allow-java-encodings");
            arrayList.add("http://apache.org/xml/features/standard-uri-conformant");
            arrayList.add("http://apache.org/xml/features/validate-annotations");
            arrayList.add("http://apache.org/xml/features/generate-synthetic-annotations");
            arrayList.add("http://apache.org/xml/features/honour-all-schemaLocations");
            arrayList.add("http://apache.org/xml/features/namespace-growth");
            arrayList.add("http://apache.org/xml/features/internal/tolerate-duplicates");
            this.fRecognizedParameters = new DOMStringListImpl(arrayList);
        }
        return this.fRecognizedParameters;
    }

    @Override // org.apache.xerces.xni.grammars.XMLGrammarLoader
    public Object getProperty(String str) {
        return this.fLoaderConfig.getProperty(str);
    }

    @Override // org.apache.xerces.xni.parser.XMLComponent
    public Object getPropertyDefault(String str) {
        return null;
    }

    @Override // org.apache.xerces.xni.parser.XMLComponent, org.apache.xerces.xni.grammars.XMLGrammarLoader
    public String[] getRecognizedFeatures() {
        return (String[]) RECOGNIZED_FEATURES.clone();
    }

    @Override // org.apache.xerces.xni.parser.XMLComponent, org.apache.xerces.xni.grammars.XMLGrammarLoader
    public String[] getRecognizedProperties() {
        return (String[]) RECOGNIZED_PROPERTIES.clone();
    }

    @Override // org.apache.xerces.xs.XSLoader
    public XSModel load(LSInput lSInput) {
        try {
            return ((XSGrammar) loadGrammar(dom2xmlInputSource(lSInput))).toXSModel();
        } catch (Exception e2) {
            reportDOMFatalError(e2);
            return null;
        }
    }

    @Override // org.apache.xerces.xni.grammars.XMLGrammarLoader
    public Grammar loadGrammar(XMLInputSource xMLInputSource) {
        XMLGrammarPool xMLGrammarPool;
        reset(this.fLoaderConfig);
        this.fSettingsChanged = false;
        XSDDescription xSDDescription = new XSDDescription();
        xSDDescription.fContextType = 3;
        xSDDescription.setBaseSystemId(xMLInputSource.getBaseSystemId());
        xSDDescription.setLiteralSystemId(xMLInputSource.getSystemId());
        Hashtable hashtable = new Hashtable();
        processExternalHints(this.fExternalSchemas, this.fExternalNoNSSchema, hashtable, this.fErrorReporter);
        SchemaGrammar loadSchema = loadSchema(xSDDescription, xMLInputSource, hashtable);
        if (!(loadSchema == null || (xMLGrammarPool = this.fGrammarPool) == null)) {
            xMLGrammarPool.cacheGrammars("http://www.w3.org/2001/XMLSchema", this.fGrammarBucket.getGrammars());
            if (this.fIsCheckedFully && this.fJAXPCache.get(loadSchema) != loadSchema) {
                XSConstraints.fullSchemaChecking(this.fGrammarBucket, this.fSubGroupHandler, this.fCMBuilder, this.fErrorReporter);
            }
        }
        return loadSchema;
    }

    public void loadGrammar(XMLInputSource[] xMLInputSourceArr) {
        for (XMLInputSource xMLInputSource : xMLInputSourceArr) {
            loadGrammar(xMLInputSource);
        }
    }

    @Override // org.apache.xerces.xs.XSLoader
    public XSModel loadInputList(LSInputList lSInputList) {
        int length = lSInputList.getLength();
        SchemaGrammar[] schemaGrammarArr = new SchemaGrammar[length];
        for (int i2 = 0; i2 < length; i2++) {
            try {
                schemaGrammarArr[i2] = (SchemaGrammar) loadGrammar(dom2xmlInputSource(lSInputList.item(i2)));
            } catch (Exception e2) {
                reportDOMFatalError(e2);
                return null;
            }
        }
        return new XSModelImpl(schemaGrammarArr);
    }

    public SchemaGrammar loadSchema(XSDDescription xSDDescription, XMLInputSource xMLInputSource, Hashtable hashtable) {
        if (!this.fJAXPProcessed) {
            processJAXPSchemaSource(hashtable);
        }
        return this.fSchemaHandler.parseSchema(xMLInputSource, xSDDescription, hashtable);
    }

    @Override // org.apache.xerces.xs.XSLoader
    public XSModel loadURI(String str) {
        try {
            return ((XSGrammar) loadGrammar(new XMLInputSource(null, str, null))).toXSModel();
        } catch (Exception e2) {
            reportDOMFatalError(e2);
            return null;
        }
    }

    @Override // org.apache.xerces.xs.XSLoader
    public XSModel loadURIList(StringList stringList) {
        int length = stringList.getLength();
        SchemaGrammar[] schemaGrammarArr = new SchemaGrammar[length];
        for (int i2 = 0; i2 < length; i2++) {
            try {
                schemaGrammarArr[i2] = (SchemaGrammar) loadGrammar(new XMLInputSource(null, stringList.item(i2), null));
            } catch (Exception e2) {
                reportDOMFatalError(e2);
                return null;
            }
        }
        return new XSModelImpl(schemaGrammarArr);
    }

    public void reportDOMFatalError(Exception exc) {
        if (this.fErrorHandler != null) {
            DOMErrorImpl dOMErrorImpl = new DOMErrorImpl();
            dOMErrorImpl.fException = exc;
            dOMErrorImpl.fMessage = exc.getMessage();
            dOMErrorImpl.fSeverity = 3;
            this.fErrorHandler.getErrorHandler().handleError(dOMErrorImpl);
        }
    }

    @Override // org.apache.xerces.xni.parser.XMLComponent
    public void reset(XMLComponentManager xMLComponentManager) {
        SchemaDVFactory schemaDVFactory;
        this.fGrammarBucket.reset();
        this.fSubGroupHandler.reset();
        if (!this.fSettingsChanged || !parserSettingsUpdated(xMLComponentManager)) {
            this.fJAXPProcessed = false;
            initGrammarBucket();
            XSDeclarationPool xSDeclarationPool = this.fDeclPool;
            if (xSDeclarationPool != null) {
                xSDeclarationPool.reset();
                return;
            }
            return;
        }
        this.fEntityManager = (XMLEntityManager) xMLComponentManager.getProperty("http://apache.org/xml/properties/internal/entity-manager");
        this.fErrorReporter = (XMLErrorReporter) xMLComponentManager.getProperty("http://apache.org/xml/properties/internal/error-reporter");
        try {
            schemaDVFactory = (SchemaDVFactory) xMLComponentManager.getProperty("http://apache.org/xml/properties/internal/validation/schema/dv-factory");
        } catch (XMLConfigurationException unused) {
            schemaDVFactory = null;
        }
        if (schemaDVFactory == null) {
            if (this.fDefaultSchemaDVFactory == null) {
                this.fDefaultSchemaDVFactory = SchemaDVFactory.getInstance();
            }
            schemaDVFactory = this.fDefaultSchemaDVFactory;
        }
        this.fSchemaHandler.setDVFactory(schemaDVFactory);
        try {
            this.fExternalSchemas = (String) xMLComponentManager.getProperty("http://apache.org/xml/properties/schema/external-schemaLocation");
            this.fExternalNoNSSchema = (String) xMLComponentManager.getProperty("http://apache.org/xml/properties/schema/external-noNamespaceSchemaLocation");
        } catch (XMLConfigurationException unused2) {
            this.fExternalSchemas = null;
            this.fExternalNoNSSchema = null;
        }
        try {
            this.fJAXPSource = xMLComponentManager.getProperty("http://java.sun.com/xml/jaxp/properties/schemaSource");
            this.fJAXPProcessed = false;
        } catch (XMLConfigurationException unused3) {
            this.fJAXPSource = null;
            this.fJAXPProcessed = false;
        }
        try {
            this.fGrammarPool = (XMLGrammarPool) xMLComponentManager.getProperty("http://apache.org/xml/properties/internal/grammar-pool");
        } catch (XMLConfigurationException unused4) {
            this.fGrammarPool = null;
        }
        initGrammarBucket();
        try {
            xMLComponentManager.getFeature("http://apache.org/xml/features/validation/schema/augment-psvi");
        } catch (XMLConfigurationException unused5) {
        }
        this.fCMBuilder.setDeclPool(null);
        this.fSchemaHandler.setDeclPool(null);
        if (schemaDVFactory instanceof SchemaDVFactoryImpl) {
            ((SchemaDVFactoryImpl) schemaDVFactory).setDeclPool(null);
        }
        try {
            this.fErrorReporter.setFeature("http://apache.org/xml/features/continue-after-fatal-error", xMLComponentManager.getFeature("http://apache.org/xml/features/continue-after-fatal-error"));
        } catch (XMLConfigurationException unused6) {
        }
        try {
            this.fIsCheckedFully = xMLComponentManager.getFeature("http://apache.org/xml/features/validation/schema-full-checking");
        } catch (XMLConfigurationException unused7) {
            this.fIsCheckedFully = false;
        }
        try {
            this.fSchemaHandler.setGenerateSyntheticAnnotations(xMLComponentManager.getFeature("http://apache.org/xml/features/generate-synthetic-annotations"));
        } catch (XMLConfigurationException unused8) {
            this.fSchemaHandler.setGenerateSyntheticAnnotations(false);
        }
        this.fSchemaHandler.reset(xMLComponentManager);
    }

    @Override // org.apache.xerces.xni.grammars.XMLGrammarLoader
    public void setEntityResolver(XMLEntityResolver xMLEntityResolver) {
        this.fUserEntityResolver = xMLEntityResolver;
        this.fLoaderConfig.setProperty("http://apache.org/xml/properties/internal/entity-resolver", xMLEntityResolver);
        this.fEntityManager.setProperty("http://apache.org/xml/properties/internal/entity-resolver", xMLEntityResolver);
    }

    @Override // org.apache.xerces.xni.grammars.XMLGrammarLoader
    public void setErrorHandler(XMLErrorHandler xMLErrorHandler) {
        this.fErrorReporter.setProperty("http://apache.org/xml/properties/internal/error-handler", xMLErrorHandler);
    }

    @Override // org.apache.xerces.xni.parser.XMLComponent, org.apache.xerces.xni.grammars.XMLGrammarLoader
    public void setFeature(String str, boolean z) {
        this.fSettingsChanged = true;
        if (str.equals("http://apache.org/xml/features/continue-after-fatal-error")) {
            this.fErrorReporter.setFeature("http://apache.org/xml/features/continue-after-fatal-error", z);
        } else if (str.equals("http://apache.org/xml/features/generate-synthetic-annotations")) {
            this.fSchemaHandler.setGenerateSyntheticAnnotations(z);
        }
        this.fLoaderConfig.setFeature(str, z);
    }

    @Override // org.apache.xerces.xni.grammars.XMLGrammarLoader
    public void setLocale(Locale locale) {
        this.fLocale = locale;
        this.fErrorReporter.setLocale(locale);
    }

    @Override // org.w3c.dom.DOMConfiguration
    public void setParameter(String str, Object obj) {
        if (obj instanceof Boolean) {
            boolean booleanValue = ((Boolean) obj).booleanValue();
            if (!str.equals(Constants.DOM_VALIDATE) || !booleanValue) {
                try {
                    setFeature(str, booleanValue);
                } catch (Exception unused) {
                    throw new DOMException(9, DOMMessageFormatter.formatMessage(DOMMessageFormatter.DOM_DOMAIN, "FEATURE_NOT_SUPPORTED", new Object[]{str}));
                }
            }
        } else if (str.equals(Constants.DOM_ERROR_HANDLER)) {
            if (obj instanceof DOMErrorHandler) {
                try {
                    DOMErrorHandlerWrapper dOMErrorHandlerWrapper = new DOMErrorHandlerWrapper((DOMErrorHandler) obj);
                    this.fErrorHandler = dOMErrorHandlerWrapper;
                    setErrorHandler(dOMErrorHandlerWrapper);
                } catch (XMLConfigurationException unused2) {
                }
            } else {
                throw new DOMException(9, DOMMessageFormatter.formatMessage(DOMMessageFormatter.DOM_DOMAIN, "FEATURE_NOT_SUPPORTED", new Object[]{str}));
            }
        } else if (!str.equals(Constants.DOM_RESOURCE_RESOLVER)) {
            try {
                setProperty(str, obj);
            } catch (Exception unused3) {
                throw new DOMException(9, DOMMessageFormatter.formatMessage(DOMMessageFormatter.DOM_DOMAIN, "FEATURE_NOT_SUPPORTED", new Object[]{str}));
            }
        } else if (obj instanceof LSResourceResolver) {
            try {
                DOMEntityResolverWrapper dOMEntityResolverWrapper = new DOMEntityResolverWrapper((LSResourceResolver) obj);
                this.fResourceResolver = dOMEntityResolverWrapper;
                setEntityResolver(dOMEntityResolverWrapper);
            } catch (XMLConfigurationException unused4) {
            }
        } else {
            throw new DOMException(9, DOMMessageFormatter.formatMessage(DOMMessageFormatter.DOM_DOMAIN, "FEATURE_NOT_SUPPORTED", new Object[]{str}));
        }
    }

    @Override // org.apache.xerces.xni.parser.XMLComponent, org.apache.xerces.xni.grammars.XMLGrammarLoader
    public void setProperty(String str, Object obj) {
        this.fSettingsChanged = true;
        this.fLoaderConfig.setProperty(str, obj);
        if (str.equals("http://java.sun.com/xml/jaxp/properties/schemaSource")) {
            this.fJAXPSource = obj;
            this.fJAXPProcessed = false;
        } else if (str.equals("http://apache.org/xml/properties/internal/grammar-pool")) {
            this.fGrammarPool = (XMLGrammarPool) obj;
        } else if (str.equals("http://apache.org/xml/properties/schema/external-schemaLocation")) {
            this.fExternalSchemas = (String) obj;
        } else if (str.equals("http://apache.org/xml/properties/schema/external-noNamespaceSchemaLocation")) {
            this.fExternalNoNSSchema = (String) obj;
        } else if (str.equals("http://apache.org/xml/properties/locale")) {
            setLocale((Locale) obj);
        } else if (str.equals("http://apache.org/xml/properties/internal/entity-resolver")) {
            this.fEntityManager.setProperty("http://apache.org/xml/properties/internal/entity-resolver", obj);
        } else if (str.equals("http://apache.org/xml/properties/internal/error-reporter")) {
            XMLErrorReporter xMLErrorReporter = (XMLErrorReporter) obj;
            this.fErrorReporter = xMLErrorReporter;
            if (xMLErrorReporter.getMessageFormatter(XSMessageFormatter.SCHEMA_DOMAIN) == null) {
                this.fErrorReporter.putMessageFormatter(XSMessageFormatter.SCHEMA_DOMAIN, new XSMessageFormatter());
            }
        }
    }
}
