package org.apache.xerces.impl.xs;

import java.io.IOException;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.Hashtable;
import java.util.Map;
import java.util.Stack;
import java.util.Vector;
import javax.xml.namespace.QName;
import org.apache.poi.xssf.usermodel.XSSFDataValidationConstraint;
import org.apache.xerces.impl.Constants;
import org.apache.xerces.impl.RevalidationHandler;
import org.apache.xerces.impl.XMLEntityManager;
import org.apache.xerces.impl.XMLErrorReporter;
import org.apache.xerces.impl.dv.DatatypeException;
import org.apache.xerces.impl.dv.InvalidDatatypeValueException;
import org.apache.xerces.impl.dv.ValidatedInfo;
import org.apache.xerces.impl.dv.ValidationContext;
import org.apache.xerces.impl.dv.XSSimpleType;
import org.apache.xerces.impl.dv.xs.XSSimpleTypeDecl;
import org.apache.xerces.impl.validation.ConfigurableValidationState;
import org.apache.xerces.impl.validation.ValidationManager;
import org.apache.xerces.impl.validation.ValidationState;
import org.apache.xerces.impl.xs.XMLSchemaLoader;
import org.apache.xerces.impl.xs.identity.Field;
import org.apache.xerces.impl.xs.identity.FieldActivator;
import org.apache.xerces.impl.xs.identity.IdentityConstraint;
import org.apache.xerces.impl.xs.identity.KeyRef;
import org.apache.xerces.impl.xs.identity.Selector;
import org.apache.xerces.impl.xs.identity.UniqueOrKey;
import org.apache.xerces.impl.xs.identity.ValueStore;
import org.apache.xerces.impl.xs.identity.XPathMatcher;
import org.apache.xerces.impl.xs.models.CMBuilder;
import org.apache.xerces.impl.xs.models.CMNodeFactory;
import org.apache.xerces.impl.xs.models.XSCMValidator;
import org.apache.xerces.util.AugmentationsImpl;
import org.apache.xerces.util.IntStack;
import org.apache.xerces.util.SymbolTable;
import org.apache.xerces.util.URI;
import org.apache.xerces.util.XMLAttributesImpl;
import org.apache.xerces.util.XMLChar;
import org.apache.xerces.util.XMLSymbols;
import org.apache.xerces.xni.Augmentations;
import org.apache.xerces.xni.NamespaceContext;
import org.apache.xerces.xni.XMLAttributes;
import org.apache.xerces.xni.XMLDocumentHandler;
import org.apache.xerces.xni.XMLLocator;
import org.apache.xerces.xni.XMLResourceIdentifier;
import org.apache.xerces.xni.XMLString;
import org.apache.xerces.xni.grammars.XMLGrammarPool;
import org.apache.xerces.xni.parser.XMLComponent;
import org.apache.xerces.xni.parser.XMLComponentManager;
import org.apache.xerces.xni.parser.XMLConfigurationException;
import org.apache.xerces.xni.parser.XMLDocumentFilter;
import org.apache.xerces.xni.parser.XMLDocumentSource;
import org.apache.xerces.xni.parser.XMLEntityResolver;
import org.apache.xerces.xni.parser.XMLInputSource;
import org.apache.xerces.xs.ShortList;
import org.apache.xerces.xs.StringList;
import org.apache.xerces.xs.XSObjectList;
import org.apache.xerces.xs.XSTypeDefinition;
import org.apache.xmlbeans.XmlErrorCodes;
import org.apache.xmlbeans.impl.common.Sax2Dom;

public class XMLSchemaValidator implements XMLComponent, XMLDocumentFilter, FieldActivator, RevalidationHandler, XSElementDeclHelper {
    public static final String ALLOW_JAVA_ENCODINGS = "http://apache.org/xml/features/allow-java-encodings";
    public static final int BUFFER_SIZE = 20;
    public static final String CONTINUE_AFTER_FATAL_ERROR = "http://apache.org/xml/features/continue-after-fatal-error";
    public static final boolean DEBUG = false;
    public static final boolean DEBUG_NORMALIZATION = false;
    public static final String DYNAMIC_VALIDATION = "http://apache.org/xml/features/validation/dynamic";
    public static final Hashtable EMPTY_TABLE = new Hashtable();
    public static final String ENTITY_MANAGER = "http://apache.org/xml/properties/internal/entity-manager";
    public static final String ENTITY_RESOLVER = "http://apache.org/xml/properties/internal/entity-resolver";
    public static final String ERROR_REPORTER = "http://apache.org/xml/properties/internal/error-reporter";
    public static final Boolean[] FEATURE_DEFAULTS = {null, null, null, null, null, null, null, null, null, null, null, null, null, null, null, null, null};
    public static final String GENERATE_SYNTHETIC_ANNOTATIONS = "http://apache.org/xml/features/generate-synthetic-annotations";
    public static final String HONOUR_ALL_SCHEMALOCATIONS = "http://apache.org/xml/features/honour-all-schemaLocations";
    public static final String IDENTITY_CONSTRAINT_CHECKING = "http://apache.org/xml/features/validation/identity-constraint-checking";
    public static final int ID_CONSTRAINT_NUM = 1;
    public static final String ID_IDREF_CHECKING = "http://apache.org/xml/features/validation/id-idref-checking";
    public static final String IGNORE_XSI_TYPE = "http://apache.org/xml/features/validation/schema/ignore-xsi-type-until-elemdecl";
    public static final int INC_STACK_SIZE = 8;
    public static final int INITIAL_STACK_SIZE = 8;
    public static final String JAXP_SCHEMA_LANGUAGE = "http://java.sun.com/xml/jaxp/properties/schemaLanguage";
    public static final String JAXP_SCHEMA_SOURCE = "http://java.sun.com/xml/jaxp/properties/schemaSource";
    public static final String NAMESPACE_GROWTH = "http://apache.org/xml/features/namespace-growth";
    public static final String NORMALIZE_DATA = "http://apache.org/xml/features/validation/schema/normalized-value";
    public static final String PARSER_SETTINGS = "http://apache.org/xml/features/internal/parser-settings";
    public static final Object[] PROPERTY_DEFAULTS = {null, null, null, null, null, null, null, null, null, null, null};
    public static final String[] RECOGNIZED_FEATURES = {"http://xml.org/sax/features/validation", "http://apache.org/xml/features/validation/schema", "http://apache.org/xml/features/validation/dynamic", "http://apache.org/xml/features/validation/schema-full-checking", "http://apache.org/xml/features/allow-java-encodings", "http://apache.org/xml/features/continue-after-fatal-error", "http://apache.org/xml/features/standard-uri-conformant", "http://apache.org/xml/features/generate-synthetic-annotations", "http://apache.org/xml/features/validate-annotations", "http://apache.org/xml/features/honour-all-schemaLocations", "http://apache.org/xml/features/internal/validation/schema/use-grammar-pool-only", "http://apache.org/xml/features/validation/schema/ignore-xsi-type-until-elemdecl", "http://apache.org/xml/features/validation/id-idref-checking", "http://apache.org/xml/features/validation/identity-constraint-checking", "http://apache.org/xml/features/validation/unparsed-entity-checking", "http://apache.org/xml/features/namespace-growth", "http://apache.org/xml/features/internal/tolerate-duplicates"};
    public static final String[] RECOGNIZED_PROPERTIES = {"http://apache.org/xml/properties/internal/symbol-table", "http://apache.org/xml/properties/internal/error-reporter", "http://apache.org/xml/properties/internal/entity-resolver", "http://apache.org/xml/properties/internal/validation-manager", "http://apache.org/xml/properties/schema/external-schemaLocation", "http://apache.org/xml/properties/schema/external-noNamespaceSchemaLocation", "http://java.sun.com/xml/jaxp/properties/schemaSource", "http://java.sun.com/xml/jaxp/properties/schemaLanguage", "http://apache.org/xml/properties/validation/schema/root-type-definition", "http://apache.org/xml/properties/validation/schema/root-element-declaration", "http://apache.org/xml/properties/internal/validation/schema/dv-factory"};
    public static final String ROOT_ELEMENT_DECL = "http://apache.org/xml/properties/validation/schema/root-element-declaration";
    public static final String ROOT_TYPE_DEF = "http://apache.org/xml/properties/validation/schema/root-type-definition";
    public static final String SCHEMA_AUGMENT_PSVI = "http://apache.org/xml/features/validation/schema/augment-psvi";
    public static final String SCHEMA_DV_FACTORY = "http://apache.org/xml/properties/internal/validation/schema/dv-factory";
    public static final String SCHEMA_ELEMENT_DEFAULT = "http://apache.org/xml/features/validation/schema/element-default";
    public static final String SCHEMA_FULL_CHECKING = "http://apache.org/xml/features/validation/schema-full-checking";
    public static final String SCHEMA_LOCATION = "http://apache.org/xml/properties/schema/external-schemaLocation";
    public static final String SCHEMA_NONS_LOCATION = "http://apache.org/xml/properties/schema/external-noNamespaceSchemaLocation";
    public static final String SCHEMA_VALIDATION = "http://apache.org/xml/features/validation/schema";
    public static final String STANDARD_URI_CONFORMANT_FEATURE = "http://apache.org/xml/features/standard-uri-conformant";
    public static final String SYMBOL_TABLE = "http://apache.org/xml/properties/internal/symbol-table";
    public static final String TOLERATE_DUPLICATES = "http://apache.org/xml/features/internal/tolerate-duplicates";
    public static final String UNPARSED_ENTITY_CHECKING = "http://apache.org/xml/features/validation/unparsed-entity-checking";
    public static final String USE_GRAMMAR_POOL_ONLY = "http://apache.org/xml/features/internal/validation/schema/use-grammar-pool-only";
    public static final String VALIDATE_ANNOTATIONS = "http://apache.org/xml/features/validate-annotations";
    public static final String VALIDATION = "http://xml.org/sax/features/validation";
    public static final String VALIDATION_MANAGER = "http://apache.org/xml/properties/internal/validation-manager";
    public static final String XMLGRAMMAR_POOL = "http://apache.org/xml/properties/internal/grammar-pool";
    public static final XSAttributeDecl XSI_NIL = SchemaGrammar.SG_XSI.getGlobalAttributeDecl(SchemaSymbols.XSI_NIL);
    public static final XSAttributeDecl XSI_NONAMESPACESCHEMALOCATION = SchemaGrammar.SG_XSI.getGlobalAttributeDecl(SchemaSymbols.XSI_NONAMESPACESCHEMALOCATION);
    public static final XSAttributeDecl XSI_SCHEMALOCATION = SchemaGrammar.SG_XSI.getGlobalAttributeDecl(SchemaSymbols.XSI_SCHEMALOCATION);
    public static final XSAttributeDecl XSI_TYPE = SchemaGrammar.SG_XSI.getGlobalAttributeDecl(SchemaSymbols.XSI_TYPE);
    public boolean fAppendBuffer;
    public boolean fAugPSVI = true;
    public final AugmentationsImpl fAugmentations = new AugmentationsImpl();
    public final StringBuffer fBuffer;
    public final CMBuilder fCMBuilder;
    public XSCMValidator[] fCMStack;
    public int[][] fCMStateStack;
    public int[] fCurrCMState;
    public XSCMValidator fCurrentCM;
    public XSElementDecl fCurrentElemDecl;
    public ElementPSVImpl fCurrentPSVI = new ElementPSVImpl();
    public XSTypeDefinition fCurrentType;
    public XMLString fDefaultValue;
    public boolean fDoValidation = false;
    public XMLDocumentHandler fDocumentHandler;
    public XMLDocumentSource fDocumentSource;
    public boolean fDynamicValidation = false;
    public XSElementDecl[] fElemDeclStack;
    public int fElementDepth;
    public final XMLString fEmptyXMLStr = new XMLString(null, 0, -1);
    public boolean fEntityRef = false;
    public XMLEntityResolver fEntityResolver;
    public final Hashtable fExpandedLocationPairs = new Hashtable();
    public String fExternalNoNamespaceSchema = null;
    public String fExternalSchemas = null;
    public boolean fFirstChunk = true;
    public boolean fFullChecking = false;
    public final XSGrammarBucket fGrammarBucket = new XSGrammarBucket();
    public XMLGrammarPool fGrammarPool;
    public boolean fIDCChecking;
    public boolean fIdConstraint = false;
    public int fIgnoreXSITypeDepth;
    public boolean fInCDATA = false;
    public Object fJaxpSchemaSource = null;
    public final Hashtable fLocationPairs = new Hashtable();
    public XMLLocator fLocator;
    public XPathMatcherStack fMatcherStack;
    public int fNFullValidationDepth;
    public int fNNoneValidationDepth;
    public boolean fNamespaceGrowth = false;
    public boolean fNil;
    public boolean[] fNilStack;
    public boolean fNormalizeData = true;
    public final XMLString fNormalizedStr = new XMLString();
    public XSNotationDecl fNotation;
    public XSNotationDecl[] fNotationStack;
    public final XSSimpleType fQNameDV = ((XSSimpleType) SchemaGrammar.SG_SchemaNS.getGlobalTypeDecl("QName"));
    public QName fRootElementDeclQName;
    public XSElementDecl fRootElementDeclaration;
    public XSTypeDefinition fRootTypeDefinition;
    public QName fRootTypeQName;
    public boolean fSawCharacters;
    public boolean fSawText;
    public boolean[] fSawTextStack;
    public boolean fSchemaDynamicValidation = false;
    public boolean fSchemaElementDefault = true;
    public final XMLSchemaLoader fSchemaLoader;
    public String fSchemaType = null;
    public int fSkipValidationDepth;
    public ValidationState fState4ApplyDefault;
    public ValidationState fState4XsiType;
    public boolean fStrictAssess;
    public boolean[] fStrictAssessStack;
    public boolean[] fStringContent;
    public boolean fSubElement;
    public boolean[] fSubElementStack;
    public final SubstitutionGroupHandler fSubGroupHandler = new SubstitutionGroupHandler(this);
    public SymbolTable fSymbolTable;
    public final org.apache.xerces.xni.QName fTempQName;
    public boolean fTrailing = false;
    public XSTypeDefinition[] fTypeStack;
    public boolean fUnionType = false;
    public final ArrayList fUnparsedLocations = new ArrayList();
    public boolean fUseGrammarPoolOnly = false;
    public ValidatedInfo fValidatedInfo;
    public ValidationManager fValidationManager = null;
    public String fValidationRoot;
    public ConfigurableValidationState fValidationState = new ConfigurableValidationState();
    public ValueStoreCache fValueStoreCache;
    public short fWhiteSpace = -1;
    public final XSDDescription fXSDDescription = new XSDDescription();
    public final XSIErrorReporter fXSIErrorReporter = new XSIErrorReporter();
    public final CMNodeFactory nodeFactory = new CMNodeFactory();

    public class KeyRefValueStore extends ValueStoreBase {
        public ValueStoreBase fKeyValueStore;
        public final /* synthetic */ XMLSchemaValidator this$0;

        public KeyRefValueStore(XMLSchemaValidator xMLSchemaValidator, KeyRef keyRef, KeyValueStore keyValueStore) {
            super(keyRef);
            this.this$0 = xMLSchemaValidator;
            this.fKeyValueStore = keyValueStore;
        }

        @Override // org.apache.xerces.impl.xs.XMLSchemaValidator.ValueStoreBase
        public void endDocument() {
            super.endDocument();
        }

        @Override // org.apache.xerces.impl.xs.XMLSchemaValidator.ValueStoreBase
        public void endDocumentFragment() {
            super.endDocumentFragment();
            ValueStoreBase valueStoreBase = (ValueStoreBase) this.this$0.fValueStoreCache.fGlobalIDConstraintMap.get(((KeyRef) this.fIdentityConstraint).getKey());
            this.fKeyValueStore = valueStoreBase;
            if (valueStoreBase == null) {
                String identityConstraint = this.fIdentityConstraint.toString();
                this.this$0.reportSchemaError("KeyRefOutOfScope", new Object[]{identityConstraint});
                return;
            }
            int contains = valueStoreBase.contains(this);
            if (contains != -1) {
                String valueStoreBase2 = toString(this.fValues, contains, this.fFieldCount);
                String elementName = this.fIdentityConstraint.getElementName();
                String name = this.fIdentityConstraint.getName();
                this.this$0.reportSchemaError("KeyNotFound", new Object[]{name, valueStoreBase2, elementName});
            }
        }
    }

    public class KeyValueStore extends ValueStoreBase {
        public final /* synthetic */ XMLSchemaValidator this$0;

        public KeyValueStore(XMLSchemaValidator xMLSchemaValidator, UniqueOrKey uniqueOrKey) {
            super(uniqueOrKey);
            this.this$0 = xMLSchemaValidator;
        }

        @Override // org.apache.xerces.impl.xs.XMLSchemaValidator.ValueStoreBase
        public void checkDuplicateValues() {
            if (contains()) {
                String valueStoreBase = toString(this.fLocalValues);
                String elementName = this.fIdentityConstraint.getElementName();
                String identityConstraintName = this.fIdentityConstraint.getIdentityConstraintName();
                this.this$0.reportSchemaError("DuplicateKey", new Object[]{valueStoreBase, elementName, identityConstraintName});
            }
        }
    }

    public static final class LocalIDKey {
        public int fDepth;
        public IdentityConstraint fId;

        public LocalIDKey() {
        }

        public LocalIDKey(IdentityConstraint identityConstraint, int i2) {
            this.fId = identityConstraint;
            this.fDepth = i2;
        }

        public boolean equals(Object obj) {
            if (!(obj instanceof LocalIDKey)) {
                return false;
            }
            LocalIDKey localIDKey = (LocalIDKey) obj;
            return localIDKey.fId == this.fId && localIDKey.fDepth == this.fDepth;
        }

        public int hashCode() {
            return this.fId.hashCode() + this.fDepth;
        }
    }

    public static final class ShortVector {
        public short[] fData;
        public int fLength;

        public ShortVector() {
        }

        public ShortVector(int i2) {
            this.fData = new short[i2];
        }

        private void ensureCapacity(int i2) {
            short[] sArr = this.fData;
            if (sArr == null) {
                this.fData = new short[8];
            } else if (sArr.length <= i2) {
                short[] sArr2 = new short[(sArr.length * 2)];
                System.arraycopy(sArr, 0, sArr2, 0, sArr.length);
                this.fData = sArr2;
            }
        }

        public void add(short s) {
            ensureCapacity(this.fLength + 1);
            short[] sArr = this.fData;
            int i2 = this.fLength;
            this.fLength = i2 + 1;
            sArr[i2] = s;
        }

        public void clear() {
            this.fLength = 0;
        }

        public boolean contains(short s) {
            for (int i2 = 0; i2 < this.fLength; i2++) {
                if (this.fData[i2] == s) {
                    return true;
                }
            }
            return false;
        }

        public int length() {
            return this.fLength;
        }

        public short valueAt(int i2) {
            return this.fData[i2];
        }
    }

    public class UniqueValueStore extends ValueStoreBase {
        public final /* synthetic */ XMLSchemaValidator this$0;

        public UniqueValueStore(XMLSchemaValidator xMLSchemaValidator, UniqueOrKey uniqueOrKey) {
            super(uniqueOrKey);
            this.this$0 = xMLSchemaValidator;
        }

        @Override // org.apache.xerces.impl.xs.XMLSchemaValidator.ValueStoreBase
        public void checkDuplicateValues() {
            if (contains()) {
                String valueStoreBase = toString(this.fLocalValues);
                String elementName = this.fIdentityConstraint.getElementName();
                String identityConstraintName = this.fIdentityConstraint.getIdentityConstraintName();
                this.this$0.reportSchemaError("DuplicateUnique", new Object[]{valueStoreBase, elementName, identityConstraintName});
            }
        }
    }

    public abstract class ValueStoreBase implements ValueStore {
        public int fFieldCount = 0;
        public Field[] fFields = null;
        public IdentityConstraint fIdentityConstraint;
        public ShortList fItemValueType = null;
        public Vector fItemValueTypes = null;
        public int fItemValueTypesLength = 0;
        public ShortList[] fLocalItemValueTypes = null;
        public short[] fLocalValueTypes = null;
        public Object[] fLocalValues = null;
        public final StringBuffer fTempBuffer = new StringBuffer();
        public boolean fUseItemValueTypeVector = false;
        public boolean fUseValueTypeVector = false;
        public short fValueType = 0;
        public ShortVector fValueTypes = null;
        public int fValueTypesLength = 0;
        public final Vector fValues = new Vector();
        public int fValuesCount;

        public ValueStoreBase(IdentityConstraint identityConstraint) {
            this.fIdentityConstraint = identityConstraint;
            int fieldCount = identityConstraint.getFieldCount();
            this.fFieldCount = fieldCount;
            this.fFields = new Field[fieldCount];
            this.fLocalValues = new Object[fieldCount];
            this.fLocalValueTypes = new short[fieldCount];
            this.fLocalItemValueTypes = new ShortList[fieldCount];
            for (int i2 = 0; i2 < this.fFieldCount; i2++) {
                this.fFields[i2] = this.fIdentityConstraint.getFieldAt(i2);
            }
        }

        private void addItemValueType(ShortList shortList) {
            if (!this.fUseItemValueTypeVector) {
                int i2 = this.fItemValueTypesLength;
                this.fItemValueTypesLength = i2 + 1;
                if (i2 == 0) {
                    this.fItemValueType = shortList;
                    return;
                }
                ShortList shortList2 = this.fItemValueType;
                if (shortList2 == shortList) {
                    return;
                }
                if (shortList2 == null || !shortList2.equals(shortList)) {
                    this.fUseItemValueTypeVector = true;
                    if (this.fItemValueTypes == null) {
                        this.fItemValueTypes = new Vector(this.fItemValueTypesLength * 2);
                    }
                    for (int i3 = 1; i3 < this.fItemValueTypesLength; i3++) {
                        this.fItemValueTypes.add(this.fItemValueType);
                    }
                } else {
                    return;
                }
            }
            this.fItemValueTypes.add(shortList);
        }

        private void addValueType(short s) {
            if (!this.fUseValueTypeVector) {
                int i2 = this.fValueTypesLength;
                int i3 = i2 + 1;
                this.fValueTypesLength = i3;
                if (i2 == 0) {
                    this.fValueType = s;
                    return;
                } else if (this.fValueType != s) {
                    this.fUseValueTypeVector = true;
                    if (this.fValueTypes == null) {
                        this.fValueTypes = new ShortVector(i3 * 2);
                    }
                    for (int i4 = 1; i4 < this.fValueTypesLength; i4++) {
                        this.fValueTypes.add(this.fValueType);
                    }
                } else {
                    return;
                }
            }
            this.fValueTypes.add(s);
        }

        private ShortList getItemValueTypeAt(int i2) {
            return this.fUseItemValueTypeVector ? (ShortList) this.fItemValueTypes.elementAt(i2) : this.fItemValueType;
        }

        private short getValueTypeAt(int i2) {
            return this.fUseValueTypeVector ? this.fValueTypes.valueAt(i2) : this.fValueType;
        }

        private boolean itemValueTypeContains(ShortList shortList) {
            if (this.fUseItemValueTypeVector) {
                return this.fItemValueTypes.contains(shortList);
            }
            ShortList shortList2 = this.fItemValueType;
            return shortList2 == shortList || (shortList2 != null && shortList2.equals(shortList));
        }

        private boolean valueTypeContains(short s) {
            return this.fUseValueTypeVector ? this.fValueTypes.contains(s) : this.fValueType == s;
        }

        @Override // org.apache.xerces.impl.xs.identity.ValueStore
        public void addValue(Field field, boolean z, Object obj, short s, ShortList shortList) {
            int i2 = this.fFieldCount - 1;
            while (i2 > -1 && this.fFields[i2] != field) {
                i2--;
            }
            if (i2 == -1) {
                XMLSchemaValidator.this.reportSchemaError("UnknownField", new Object[]{field.toString(), this.fIdentityConstraint.getElementName(), this.fIdentityConstraint.getIdentityConstraintName()});
                return;
            }
            if (!z) {
                XMLSchemaValidator.this.reportSchemaError("FieldMultipleMatch", new Object[]{field.toString(), this.fIdentityConstraint.getIdentityConstraintName()});
            } else {
                this.fValuesCount++;
            }
            this.fLocalValues[i2] = obj;
            this.fLocalValueTypes[i2] = s;
            this.fLocalItemValueTypes[i2] = shortList;
            if (this.fValuesCount == this.fFieldCount) {
                checkDuplicateValues();
                for (int i3 = 0; i3 < this.fFieldCount; i3++) {
                    this.fValues.addElement(this.fLocalValues[i3]);
                    addValueType(this.fLocalValueTypes[i3]);
                    addItemValueType(this.fLocalItemValueTypes[i3]);
                }
            }
        }

        public void append(ValueStoreBase valueStoreBase) {
            for (int i2 = 0; i2 < valueStoreBase.fValues.size(); i2++) {
                this.fValues.addElement(valueStoreBase.fValues.elementAt(i2));
            }
        }

        public void checkDuplicateValues() {
        }

        public void clear() {
            this.fValuesCount = 0;
            this.fUseValueTypeVector = false;
            this.fValueTypesLength = 0;
            this.fValueType = 0;
            this.fUseItemValueTypeVector = false;
            this.fItemValueTypesLength = 0;
            this.fItemValueType = null;
            this.fValues.setSize(0);
            ShortVector shortVector = this.fValueTypes;
            if (shortVector != null) {
                shortVector.clear();
            }
            Vector vector = this.fItemValueTypes;
            if (vector != null) {
                vector.setSize(0);
            }
        }

        /* JADX WARNING: Code restructure failed: missing block: B:23:0x0055, code lost:
            r7 = r7 + r11;
         */
        public int contains(ValueStoreBase valueStoreBase) {
            Vector vector = valueStoreBase.fValues;
            int size = vector.size();
            if (this.fFieldCount <= 1) {
                for (int i2 = 0; i2 < size; i2++) {
                    short valueTypeAt = valueStoreBase.getValueTypeAt(i2);
                    if (!valueTypeContains(valueTypeAt) || !this.fValues.contains(vector.elementAt(i2))) {
                        return i2;
                    }
                    if ((valueTypeAt == 44 || valueTypeAt == 43) && !itemValueTypeContains(valueStoreBase.getItemValueTypeAt(i2))) {
                        return i2;
                    }
                }
                return -1;
            }
            int size2 = this.fValues.size();
            int i3 = 0;
            while (i3 < size) {
                int i4 = 0;
                while (i4 < size2) {
                    int i5 = 0;
                    while (true) {
                        int i6 = this.fFieldCount;
                        if (i5 >= i6) {
                            break;
                        }
                        int i7 = i3 + i5;
                        Object elementAt = vector.elementAt(i7);
                        int i8 = i4 + i5;
                        Object elementAt2 = this.fValues.elementAt(i8);
                        short valueTypeAt2 = valueStoreBase.getValueTypeAt(i7);
                        short valueTypeAt3 = getValueTypeAt(i8);
                        if (!(elementAt == elementAt2 || (valueTypeAt2 == valueTypeAt3 && elementAt != null && elementAt.equals(elementAt2)))) {
                            break;
                        }
                        if (valueTypeAt2 == 44 || valueTypeAt2 == 43) {
                            ShortList itemValueTypeAt = valueStoreBase.getItemValueTypeAt(i7);
                            ShortList itemValueTypeAt2 = getItemValueTypeAt(i8);
                            if (itemValueTypeAt == null || itemValueTypeAt2 == null || !itemValueTypeAt.equals(itemValueTypeAt2)) {
                                break;
                            }
                        }
                        i5++;
                    }
                    i4 += this.fFieldCount;
                }
                return i3;
            }
            return -1;
        }

        public boolean contains() {
            int size = this.fValues.size();
            int i2 = 0;
            while (i2 < size) {
                int i3 = this.fFieldCount + i2;
                for (int i4 = 0; i4 < this.fFieldCount; i4++) {
                    Object obj = this.fLocalValues[i4];
                    Object elementAt = this.fValues.elementAt(i2);
                    short s = this.fLocalValueTypes[i4];
                    short valueTypeAt = getValueTypeAt(i2);
                    if (obj != null && elementAt != null && s == valueTypeAt && obj.equals(elementAt)) {
                        if (s == 44 || s == 43) {
                            ShortList shortList = this.fLocalItemValueTypes[i4];
                            ShortList itemValueTypeAt = getItemValueTypeAt(i2);
                            if (!(shortList == null || itemValueTypeAt == null || !shortList.equals(itemValueTypeAt))) {
                            }
                        }
                        i2++;
                    }
                    i2 = i3;
                }
                return true;
            }
            return false;
        }

        public void endDocument() {
        }

        public void endDocumentFragment() {
        }

        public void endValueScope() {
            int i2 = this.fValuesCount;
            if (i2 == 0) {
                if (this.fIdentityConstraint.getCategory() == 1) {
                    String elementName = this.fIdentityConstraint.getElementName();
                    String identityConstraintName = this.fIdentityConstraint.getIdentityConstraintName();
                    XMLSchemaValidator.this.reportSchemaError("AbsentKeyValue", new Object[]{elementName, identityConstraintName});
                }
            } else if (i2 != this.fFieldCount && this.fIdentityConstraint.getCategory() == 1) {
                IdentityConstraint identityConstraint = this.fIdentityConstraint;
                UniqueOrKey uniqueOrKey = (UniqueOrKey) identityConstraint;
                String elementName2 = identityConstraint.getElementName();
                String identityConstraintName2 = uniqueOrKey.getIdentityConstraintName();
                XMLSchemaValidator.this.reportSchemaError("KeyNotEnoughValues", new Object[]{elementName2, identityConstraintName2});
            }
        }

        @Override // org.apache.xerces.impl.xs.identity.ValueStore
        public void reportError(String str, Object[] objArr) {
            XMLSchemaValidator.this.reportSchemaError(str, objArr);
        }

        public void startValueScope() {
            this.fValuesCount = 0;
            for (int i2 = 0; i2 < this.fFieldCount; i2++) {
                this.fLocalValues[i2] = null;
                this.fLocalValueTypes[i2] = 0;
                this.fLocalItemValueTypes[i2] = null;
            }
        }

        public String toString() {
            String obj = super.toString();
            int lastIndexOf = obj.lastIndexOf(36);
            if (lastIndexOf != -1) {
                obj = obj.substring(lastIndexOf + 1);
            }
            int lastIndexOf2 = obj.lastIndexOf(46);
            if (lastIndexOf2 != -1) {
                obj = obj.substring(lastIndexOf2 + 1);
            }
            StringBuffer stringBuffer = new StringBuffer();
            stringBuffer.append(obj);
            stringBuffer.append('[');
            stringBuffer.append(this.fIdentityConstraint);
            stringBuffer.append(']');
            return stringBuffer.toString();
        }

        public String toString(Vector vector, int i2, int i3) {
            if (i3 == 0) {
                return "";
            }
            if (i3 == 1) {
                return String.valueOf(vector.elementAt(i2));
            }
            StringBuffer stringBuffer = new StringBuffer();
            for (int i4 = 0; i4 < i3; i4++) {
                if (i4 > 0) {
                    stringBuffer.append(',');
                }
                stringBuffer.append(vector.elementAt(i2 + i4));
            }
            return stringBuffer.toString();
        }

        public String toString(Object[] objArr) {
            int length = objArr.length;
            if (length == 0) {
                return "";
            }
            this.fTempBuffer.setLength(0);
            for (int i2 = 0; i2 < length; i2++) {
                if (i2 > 0) {
                    this.fTempBuffer.append(',');
                }
                this.fTempBuffer.append(objArr[i2]);
            }
            return this.fTempBuffer.toString();
        }
    }

    public class ValueStoreCache {
        public final HashMap fGlobalIDConstraintMap = new HashMap();
        public final Stack fGlobalMapStack = new Stack();
        public final HashMap fIdentityConstraint2ValueStoreMap = new HashMap();
        public final LocalIDKey fLocalId = new LocalIDKey();
        public final ArrayList fValueStores = new ArrayList();

        public ValueStoreCache() {
        }

        public void endDocument() {
            int size = this.fValueStores.size();
            for (int i2 = 0; i2 < size; i2++) {
                ((ValueStoreBase) this.fValueStores.get(i2)).endDocument();
            }
        }

        public void endElement() {
            HashMap hashMap;
            if (!this.fGlobalMapStack.isEmpty() && (hashMap = (HashMap) this.fGlobalMapStack.pop()) != null) {
                for (Map.Entry entry : hashMap.entrySet()) {
                    IdentityConstraint identityConstraint = (IdentityConstraint) entry.getKey();
                    ValueStoreBase valueStoreBase = (ValueStoreBase) entry.getValue();
                    if (valueStoreBase != null) {
                        ValueStoreBase valueStoreBase2 = (ValueStoreBase) this.fGlobalIDConstraintMap.get(identityConstraint);
                        if (valueStoreBase2 == null) {
                            this.fGlobalIDConstraintMap.put(identityConstraint, valueStoreBase);
                        } else if (valueStoreBase2 != valueStoreBase) {
                            valueStoreBase2.append(valueStoreBase);
                        }
                    }
                }
            }
        }

        public ValueStoreBase getGlobalValueStoreFor(IdentityConstraint identityConstraint) {
            return (ValueStoreBase) this.fGlobalIDConstraintMap.get(identityConstraint);
        }

        public ValueStoreBase getValueStoreFor(IdentityConstraint identityConstraint, int i2) {
            LocalIDKey localIDKey = this.fLocalId;
            localIDKey.fDepth = i2;
            localIDKey.fId = identityConstraint;
            return (ValueStoreBase) this.fIdentityConstraint2ValueStoreMap.get(localIDKey);
        }

        public void initValueStoresFor(XSElementDecl xSElementDecl, FieldActivator fieldActivator) {
            IdentityConstraint identityConstraint;
            XMLSchemaValidator xMLSchemaValidator;
            IdentityConstraint[] identityConstraintArr = xSElementDecl.fIDConstraints;
            int i2 = xSElementDecl.fIDCPos;
            for (int i3 = 0; i3 < i2; i3++) {
                short category = identityConstraintArr[i3].getCategory();
                if (category == 1) {
                    UniqueOrKey uniqueOrKey = (UniqueOrKey) identityConstraintArr[i3];
                    LocalIDKey localIDKey = new LocalIDKey(uniqueOrKey, XMLSchemaValidator.this.fElementDepth);
                    KeyValueStore keyValueStore = (KeyValueStore) this.fIdentityConstraint2ValueStoreMap.get(localIDKey);
                    if (keyValueStore == null) {
                        keyValueStore = new KeyValueStore(XMLSchemaValidator.this, uniqueOrKey);
                        this.fIdentityConstraint2ValueStoreMap.put(localIDKey, keyValueStore);
                    } else {
                        keyValueStore.clear();
                    }
                    this.fValueStores.add(keyValueStore);
                    xMLSchemaValidator = XMLSchemaValidator.this;
                    identityConstraint = identityConstraintArr[i3];
                } else if (category == 2) {
                    KeyRef keyRef = (KeyRef) identityConstraintArr[i3];
                    LocalIDKey localIDKey2 = new LocalIDKey(keyRef, XMLSchemaValidator.this.fElementDepth);
                    KeyRefValueStore keyRefValueStore = (KeyRefValueStore) this.fIdentityConstraint2ValueStoreMap.get(localIDKey2);
                    if (keyRefValueStore == null) {
                        keyRefValueStore = new KeyRefValueStore(XMLSchemaValidator.this, keyRef, null);
                        this.fIdentityConstraint2ValueStoreMap.put(localIDKey2, keyRefValueStore);
                    } else {
                        keyRefValueStore.clear();
                    }
                    this.fValueStores.add(keyRefValueStore);
                    xMLSchemaValidator = XMLSchemaValidator.this;
                    identityConstraint = identityConstraintArr[i3];
                } else if (category == 3) {
                    UniqueOrKey uniqueOrKey2 = (UniqueOrKey) identityConstraintArr[i3];
                    LocalIDKey localIDKey3 = new LocalIDKey(uniqueOrKey2, XMLSchemaValidator.this.fElementDepth);
                    UniqueValueStore uniqueValueStore = (UniqueValueStore) this.fIdentityConstraint2ValueStoreMap.get(localIDKey3);
                    if (uniqueValueStore == null) {
                        uniqueValueStore = new UniqueValueStore(XMLSchemaValidator.this, uniqueOrKey2);
                        this.fIdentityConstraint2ValueStoreMap.put(localIDKey3, uniqueValueStore);
                    } else {
                        uniqueValueStore.clear();
                    }
                    this.fValueStores.add(uniqueValueStore);
                    xMLSchemaValidator = XMLSchemaValidator.this;
                    identityConstraint = identityConstraintArr[i3];
                }
                xMLSchemaValidator.activateSelectorFor(identityConstraint);
            }
        }

        public void startDocument() {
            this.fValueStores.clear();
            this.fIdentityConstraint2ValueStoreMap.clear();
            this.fGlobalIDConstraintMap.clear();
            this.fGlobalMapStack.removeAllElements();
        }

        public void startElement() {
            Object obj;
            Stack stack;
            if (this.fGlobalIDConstraintMap.size() > 0) {
                stack = this.fGlobalMapStack;
                obj = this.fGlobalIDConstraintMap.clone();
            } else {
                stack = this.fGlobalMapStack;
                obj = null;
            }
            stack.push(obj);
            this.fGlobalIDConstraintMap.clear();
        }

        public String toString() {
            String obj = super.toString();
            int lastIndexOf = obj.lastIndexOf(36);
            return (lastIndexOf == -1 && (lastIndexOf = obj.lastIndexOf(46)) == -1) ? obj : obj.substring(lastIndexOf + 1);
        }

        public void transplant(IdentityConstraint identityConstraint, int i2) {
            LocalIDKey localIDKey = this.fLocalId;
            localIDKey.fDepth = i2;
            localIDKey.fId = identityConstraint;
            ValueStoreBase valueStoreBase = (ValueStoreBase) this.fIdentityConstraint2ValueStoreMap.get(localIDKey);
            if (identityConstraint.getCategory() != 2) {
                ValueStoreBase valueStoreBase2 = (ValueStoreBase) this.fGlobalIDConstraintMap.get(identityConstraint);
                if (valueStoreBase2 != null) {
                    valueStoreBase2.append(valueStoreBase);
                    this.fGlobalIDConstraintMap.put(identityConstraint, valueStoreBase2);
                    return;
                }
                this.fGlobalIDConstraintMap.put(identityConstraint, valueStoreBase);
            }
        }
    }

    public static class XPathMatcherStack {
        public IntStack fContextStack = new IntStack();
        public XPathMatcher[] fMatchers = new XPathMatcher[4];
        public int fMatchersCount;

        private void ensureMatcherCapacity() {
            int i2 = this.fMatchersCount;
            XPathMatcher[] xPathMatcherArr = this.fMatchers;
            if (i2 == xPathMatcherArr.length) {
                XPathMatcher[] xPathMatcherArr2 = new XPathMatcher[(xPathMatcherArr.length * 2)];
                System.arraycopy(xPathMatcherArr, 0, xPathMatcherArr2, 0, xPathMatcherArr.length);
                this.fMatchers = xPathMatcherArr2;
            }
        }

        public void addMatcher(XPathMatcher xPathMatcher) {
            ensureMatcherCapacity();
            XPathMatcher[] xPathMatcherArr = this.fMatchers;
            int i2 = this.fMatchersCount;
            this.fMatchersCount = i2 + 1;
            xPathMatcherArr[i2] = xPathMatcher;
        }

        public void clear() {
            for (int i2 = 0; i2 < this.fMatchersCount; i2++) {
                this.fMatchers[i2] = null;
            }
            this.fMatchersCount = 0;
            this.fContextStack.clear();
        }

        public XPathMatcher getMatcherAt(int i2) {
            return this.fMatchers[i2];
        }

        public int getMatcherCount() {
            return this.fMatchersCount;
        }

        public void popContext() {
            this.fMatchersCount = this.fContextStack.pop();
        }

        public void pushContext() {
            this.fContextStack.push(this.fMatchersCount);
        }

        public int size() {
            return this.fContextStack.size();
        }
    }

    public final class XSIErrorReporter {
        public int[] fContext = new int[8];
        public int fContextCount;
        public XMLErrorReporter fErrorReporter;
        public Vector fErrors = new Vector();

        public XSIErrorReporter() {
        }

        public String[] mergeContext() {
            if (!XMLSchemaValidator.this.fAugPSVI) {
                return null;
            }
            int[] iArr = this.fContext;
            int i2 = this.fContextCount - 1;
            this.fContextCount = i2;
            int i3 = iArr[i2];
            int size = this.fErrors.size() - i3;
            if (size == 0) {
                return null;
            }
            String[] strArr = new String[size];
            for (int i4 = 0; i4 < size; i4++) {
                strArr[i4] = (String) this.fErrors.elementAt(i3 + i4);
            }
            return strArr;
        }

        public String[] popContext() {
            if (!XMLSchemaValidator.this.fAugPSVI) {
                return null;
            }
            int[] iArr = this.fContext;
            int i2 = this.fContextCount - 1;
            this.fContextCount = i2;
            int i3 = iArr[i2];
            int size = this.fErrors.size() - i3;
            if (size == 0) {
                return null;
            }
            String[] strArr = new String[size];
            for (int i4 = 0; i4 < size; i4++) {
                strArr[i4] = (String) this.fErrors.elementAt(i3 + i4);
            }
            this.fErrors.setSize(i3);
            return strArr;
        }

        public void pushContext() {
            if (XMLSchemaValidator.this.fAugPSVI) {
                int i2 = this.fContextCount;
                int[] iArr = this.fContext;
                if (i2 == iArr.length) {
                    int[] iArr2 = new int[(i2 + 8)];
                    System.arraycopy(iArr, 0, iArr2, 0, i2);
                    this.fContext = iArr2;
                }
                int[] iArr3 = this.fContext;
                int i3 = this.fContextCount;
                this.fContextCount = i3 + 1;
                iArr3[i3] = this.fErrors.size();
            }
        }

        public void reportError(String str, String str2, Object[] objArr, short s) {
            String reportError = this.fErrorReporter.reportError(str, str2, objArr, s);
            if (XMLSchemaValidator.this.fAugPSVI) {
                this.fErrors.addElement(str2);
                this.fErrors.addElement(reportError);
            }
        }

        public void reportError(XMLLocator xMLLocator, String str, String str2, Object[] objArr, short s) {
            String reportError = this.fErrorReporter.reportError(xMLLocator, str, str2, objArr, s);
            if (XMLSchemaValidator.this.fAugPSVI) {
                this.fErrors.addElement(str2);
                this.fErrors.addElement(reportError);
            }
        }

        public void reset(XMLErrorReporter xMLErrorReporter) {
            this.fErrorReporter = xMLErrorReporter;
            this.fErrors.removeAllElements();
            this.fContextCount = 0;
        }
    }

    public XMLSchemaValidator() {
        CMBuilder cMBuilder = new CMBuilder(this.nodeFactory);
        this.fCMBuilder = cMBuilder;
        this.fSchemaLoader = new XMLSchemaLoader(this.fXSIErrorReporter.fErrorReporter, this.fGrammarBucket, this.fSubGroupHandler, cMBuilder);
        this.fSubElementStack = new boolean[8];
        this.fElemDeclStack = new XSElementDecl[8];
        this.fNilStack = new boolean[8];
        this.fNotationStack = new XSNotationDecl[8];
        this.fTypeStack = new XSTypeDefinition[8];
        this.fCMStack = new XSCMValidator[8];
        this.fCMStateStack = new int[8][];
        this.fStrictAssess = true;
        this.fStrictAssessStack = new boolean[8];
        this.fBuffer = new StringBuffer();
        this.fAppendBuffer = true;
        this.fSawText = false;
        this.fSawTextStack = new boolean[8];
        this.fSawCharacters = false;
        this.fStringContent = new boolean[8];
        this.fTempQName = new org.apache.xerces.xni.QName();
        this.fRootTypeQName = null;
        this.fRootTypeDefinition = null;
        this.fRootElementDeclQName = null;
        this.fRootElementDeclaration = null;
        this.fValidatedInfo = new ValidatedInfo();
        this.fState4XsiType = new ValidationState();
        this.fState4ApplyDefault = new ValidationState();
        this.fMatcherStack = new XPathMatcherStack();
        this.fValueStoreCache = new ValueStoreCache();
        this.fState4XsiType.setExtraChecking(false);
        this.fState4ApplyDefault.setFacetChecking(false);
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private void activateSelectorFor(IdentityConstraint identityConstraint) {
        Selector selector = identityConstraint.getSelector();
        if (selector != null) {
            XPathMatcher createMatcher = selector.createMatcher(this, this.fElementDepth);
            this.fMatcherStack.addMatcher(createMatcher);
            createMatcher.startDocumentFragment();
        }
    }

    private String expectedStr(Vector vector) {
        StringBuffer stringBuffer = new StringBuffer("{");
        int size = vector.size();
        for (int i2 = 0; i2 < size; i2++) {
            if (i2 > 0) {
                stringBuffer.append(", ");
            }
            stringBuffer.append(vector.elementAt(i2).toString());
        }
        stringBuffer.append('}');
        return stringBuffer.toString();
    }

    private boolean hasSchemaComponent(SchemaGrammar schemaGrammar, short s, org.apache.xerces.xni.QName qName) {
        String str;
        if (schemaGrammar == null || qName == null || (str = qName.localpart) == null || str.length() <= 0) {
            return false;
        }
        return s != 5 ? s != 6 ? s == 7 && schemaGrammar.getTypeDefinition(str) != null : schemaGrammar.getAttributeDeclaration(str) != null : schemaGrammar.getElementDeclaration(str) != null;
    }

    private void normalizeWhitespace(String str, boolean z) {
        XMLString xMLString;
        int i2;
        int length = str.length();
        char[] cArr = this.fNormalizedStr.ch;
        if (cArr == null || cArr.length < length) {
            this.fNormalizedStr.ch = new char[length];
        }
        XMLString xMLString2 = this.fNormalizedStr;
        xMLString2.offset = 0;
        xMLString2.length = 0;
        boolean z2 = z;
        for (int i3 = 0; i3 < length; i3++) {
            char charAt = str.charAt(i3);
            if (!XMLChar.isSpace(charAt)) {
                XMLString xMLString3 = this.fNormalizedStr;
                char[] cArr2 = xMLString3.ch;
                int i4 = xMLString3.length;
                xMLString3.length = i4 + 1;
                cArr2[i4] = charAt;
                z2 = false;
            } else if (!z2) {
                XMLString xMLString4 = this.fNormalizedStr;
                char[] cArr3 = xMLString4.ch;
                int i5 = xMLString4.length;
                xMLString4.length = i5 + 1;
                cArr3[i5] = ' ';
                z2 = z;
            }
        }
        if (z2 && (i2 = (xMLString = this.fNormalizedStr).length) != 0) {
            xMLString.length = i2 - 1;
        }
    }

    /* JADX WARNING: Code restructure failed: missing block: B:15:0x003a, code lost:
        if (r11.fFirstChunk == false) goto L_0x0034;
     */
    /* JADX WARNING: Removed duplicated region for block: B:25:0x0051  */
    /* JADX WARNING: Removed duplicated region for block: B:26:0x0058  */
    private void normalizeWhitespace(XMLString xMLString, boolean z) {
        boolean z2;
        int i2 = xMLString.offset;
        int i3 = xMLString.length;
        int i4 = i2 + i3;
        char[] cArr = this.fNormalizedStr.ch;
        if (cArr == null || cArr.length < i3 + 1) {
            this.fNormalizedStr.ch = new char[(xMLString.length + 1)];
        }
        XMLString xMLString2 = this.fNormalizedStr;
        xMLString2.offset = 1;
        xMLString2.length = 1;
        boolean z3 = z;
        boolean z4 = false;
        boolean z5 = false;
        for (int i5 = xMLString.offset; i5 < i4; i5++) {
            char c = xMLString.ch[i5];
            if (XMLChar.isSpace(c)) {
                if (!z3) {
                    XMLString xMLString3 = this.fNormalizedStr;
                    char[] cArr2 = xMLString3.ch;
                    int i6 = xMLString3.length;
                    xMLString3.length = i6 + 1;
                    cArr2[i6] = ' ';
                    z3 = z;
                }
                if (!z4) {
                    z5 = true;
                }
            } else {
                XMLString xMLString4 = this.fNormalizedStr;
                char[] cArr3 = xMLString4.ch;
                int i7 = xMLString4.length;
                xMLString4.length = i7 + 1;
                cArr3[i7] = c;
                z3 = false;
                z4 = true;
            }
        }
        if (z3) {
            XMLString xMLString5 = this.fNormalizedStr;
            int i8 = xMLString5.length;
            if (i8 > 1) {
                xMLString5.length = i8 - 1;
            } else if (z5) {
            }
            z2 = true;
            XMLString xMLString6 = this.fNormalizedStr;
            if (xMLString6.length > 1 && !this.fFirstChunk && this.fWhiteSpace == 2) {
                if (!this.fTrailing) {
                    xMLString6.offset = 0;
                    xMLString6.ch[0] = ' ';
                } else if (z5) {
                    xMLString6.offset = 0;
                    xMLString6.ch[0] = ' ';
                }
            }
            XMLString xMLString7 = this.fNormalizedStr;
            xMLString7.length -= xMLString7.offset;
            this.fTrailing = z2;
            if (!z2 || z4) {
                this.fFirstChunk = false;
            }
            return;
        }
        z2 = false;
        XMLString xMLString62 = this.fNormalizedStr;
        if (!this.fTrailing) {
        }
        XMLString xMLString72 = this.fNormalizedStr;
        xMLString72.length -= xMLString72.offset;
        this.fTrailing = z2;
        if (!z2) {
        }
        this.fFirstChunk = false;
    }

    private void setLocationHints(XSDDescription xSDDescription, String[] strArr, SchemaGrammar schemaGrammar) {
        int length = strArr.length;
        if (schemaGrammar == null) {
            String[] strArr2 = new String[length];
            this.fXSDDescription.fLocationHints = strArr2;
            System.arraycopy(strArr, 0, strArr2, 0, length);
            return;
        }
        setLocationHints(xSDDescription, strArr, schemaGrammar.getDocumentLocations());
    }

    private void setLocationHints(XSDDescription xSDDescription, String[] strArr, StringList stringList) {
        int length = strArr.length;
        String[] strArr2 = new String[length];
        int i2 = 0;
        for (int i3 = 0; i3 < length; i3++) {
            if (!stringList.contains(strArr[i3])) {
                strArr2[i2] = strArr[i3];
                i2++;
            }
        }
        if (i2 <= 0) {
            return;
        }
        if (i2 == length) {
            this.fXSDDescription.fLocationHints = strArr2;
            return;
        }
        String[] strArr3 = new String[i2];
        this.fXSDDescription.fLocationHints = strArr3;
        System.arraycopy(strArr2, 0, strArr3, 0, i2);
    }

    @Override // org.apache.xerces.impl.xs.identity.FieldActivator
    public XPathMatcher activateField(Field field, int i2) {
        XPathMatcher createMatcher = field.createMatcher(this.fValueStoreCache.getValueStoreFor(field.getIdentityConstraint(), i2));
        this.fMatcherStack.addMatcher(createMatcher);
        createMatcher.startDocumentFragment();
        return createMatcher;
    }

    public void addDefaultAttributes(org.apache.xerces.xni.QName qName, XMLAttributes xMLAttributes, XSAttributeGroupDecl xSAttributeGroupDecl) {
        int i2;
        XSObjectList attributeUses = xSAttributeGroupDecl.getAttributeUses();
        int length = attributeUses.getLength();
        for (int i3 = 0; i3 < length; i3++) {
            XSAttributeUseImpl xSAttributeUseImpl = (XSAttributeUseImpl) attributeUses.item(i3);
            XSAttributeDecl xSAttributeDecl = xSAttributeUseImpl.fAttrDecl;
            short s = xSAttributeUseImpl.fConstraintType;
            ValidatedInfo validatedInfo = xSAttributeUseImpl.fDefault;
            if (s == 0) {
                s = xSAttributeDecl.getConstraintType();
                validatedInfo = xSAttributeDecl.fDefault;
            }
            boolean z = xMLAttributes.getValue(xSAttributeDecl.fTargetNamespace, xSAttributeDecl.fName) != null;
            if (xSAttributeUseImpl.fUse == 1 && !z) {
                reportSchemaError(XmlErrorCodes.ELEM_COMPLEX_TYPE_LOCALLY_VALID$MISSING_REQUIRED_ATTRIBUTE, new Object[]{qName.rawname, xSAttributeDecl.fName});
            }
            if (!z && s != 0) {
                String str = xSAttributeDecl.fName;
                org.apache.xerces.xni.QName qName2 = new org.apache.xerces.xni.QName(null, str, str, xSAttributeDecl.fTargetNamespace);
                String stringValue = validatedInfo != null ? validatedInfo.stringValue() : "";
                if (xMLAttributes instanceof XMLAttributesImpl) {
                    XMLAttributesImpl xMLAttributesImpl = (XMLAttributesImpl) xMLAttributes;
                    i2 = xMLAttributesImpl.getLength();
                    xMLAttributesImpl.addAttributeNS(qName2, "CDATA", stringValue);
                } else {
                    i2 = xMLAttributes.addAttribute(qName2, "CDATA", stringValue);
                }
                if (this.fAugPSVI) {
                    Augmentations augmentations = xMLAttributes.getAugmentations(i2);
                    AttributePSVImpl attributePSVImpl = new AttributePSVImpl();
                    augmentations.putItem(Constants.ATTRIBUTE_PSVI, attributePSVImpl);
                    attributePSVImpl.fDeclaration = xSAttributeDecl;
                    attributePSVImpl.fTypeDecl = xSAttributeDecl.fType;
                    attributePSVImpl.fValue.copyFrom(validatedInfo);
                    attributePSVImpl.fValidationContext = this.fValidationRoot;
                    attributePSVImpl.fValidity = 2;
                    attributePSVImpl.fValidationAttempted = 2;
                    attributePSVImpl.fSpecified = true;
                }
            }
        }
    }

    @Override // org.apache.xerces.impl.RevalidationHandler
    public boolean characterData(String str, Augmentations augmentations) {
        short s;
        this.fSawText = this.fSawText || str.length() > 0;
        if (this.fNormalizeData && (s = this.fWhiteSpace) != -1 && s != 0) {
            normalizeWhitespace(str, s == 2);
            StringBuffer stringBuffer = this.fBuffer;
            XMLString xMLString = this.fNormalizedStr;
            stringBuffer.append(xMLString.ch, xMLString.offset, xMLString.length);
        } else if (this.fAppendBuffer) {
            this.fBuffer.append(str);
        }
        XSTypeDefinition xSTypeDefinition = this.fCurrentType;
        if (xSTypeDefinition != null && xSTypeDefinition.getTypeCategory() == 15 && ((XSComplexTypeDecl) this.fCurrentType).fContentType == 2) {
            for (int i2 = 0; i2 < str.length(); i2++) {
                if (!XMLChar.isSpace(str.charAt(i2))) {
                    this.fSawCharacters = true;
                    return false;
                }
            }
        }
        return true;
    }

    @Override // org.apache.xerces.xni.XMLDocumentHandler
    public void characters(XMLString xMLString, Augmentations augmentations) {
        XMLString handleCharacters = handleCharacters(xMLString);
        XMLDocumentHandler xMLDocumentHandler = this.fDocumentHandler;
        if (xMLDocumentHandler != null) {
            if (!this.fNormalizeData || !this.fUnionType) {
                xMLDocumentHandler = this.fDocumentHandler;
            } else if (augmentations != null) {
                handleCharacters = this.fEmptyXMLStr;
            } else {
                return;
            }
            xMLDocumentHandler.characters(handleCharacters, augmentations);
        }
    }

    public void checkElementMatchesRootElementDecl(XSElementDecl xSElementDecl, org.apache.xerces.xni.QName qName) {
        if (qName.localpart != xSElementDecl.fName || qName.uri != xSElementDecl.fTargetNamespace) {
            reportSchemaError("cvc-elt.1.b", new Object[]{qName.rawname, xSElementDecl.fName});
        }
    }

    @Override // org.apache.xerces.xni.XMLDocumentHandler
    public void comment(XMLString xMLString, Augmentations augmentations) {
        XMLDocumentHandler xMLDocumentHandler = this.fDocumentHandler;
        if (xMLDocumentHandler != null) {
            xMLDocumentHandler.comment(xMLString, augmentations);
        }
    }

    @Override // org.apache.xerces.xni.XMLDocumentHandler
    public void doctypeDecl(String str, String str2, String str3, Augmentations augmentations) {
        XMLDocumentHandler xMLDocumentHandler = this.fDocumentHandler;
        if (xMLDocumentHandler != null) {
            xMLDocumentHandler.doctypeDecl(str, str2, str3, augmentations);
        }
    }

    public void elementDefault(String str) {
    }

    public Object elementLocallyValidComplexType(org.apache.xerces.xni.QName qName, Object obj) {
        XSComplexTypeDecl xSComplexTypeDecl = (XSComplexTypeDecl) this.fCurrentType;
        Object obj2 = null;
        if (!this.fNil) {
            if (xSComplexTypeDecl.fContentType != 0 || (!this.fSubElement && !this.fSawText)) {
                short s = xSComplexTypeDecl.fContentType;
                if (s == 1) {
                    if (this.fSubElement) {
                        reportSchemaError(XmlErrorCodes.ELEM_COMPLEX_TYPE_LOCALLY_VALID$SIMPLE_TYPE_WITH_CONTENT, new Object[]{qName.rawname});
                    }
                    XSSimpleType xSSimpleType = xSComplexTypeDecl.fXSSimpleType;
                    try {
                        if (!this.fNormalizeData || this.fUnionType) {
                            this.fValidationState.setNormalizationRequired(true);
                        }
                        obj2 = xSSimpleType.validate(obj, this.fValidationState, this.fValidatedInfo);
                    } catch (InvalidDatatypeValueException e2) {
                        reportSchemaError(e2.getKey(), e2.getArgs());
                        reportSchemaError(XmlErrorCodes.ELEM_COMPLEX_TYPE_LOCALLY_VALID$SIMPLE_TYPE_WITH_CONTENT, new Object[]{qName.rawname});
                    }
                } else if (s == 2 && this.fSawCharacters) {
                    reportSchemaError(XmlErrorCodes.ELEM_COMPLEX_TYPE_LOCALLY_VALID$ELEMENT_ONLY_WITH_TEXT, new Object[]{qName.rawname});
                }
            } else {
                reportSchemaError(XmlErrorCodes.ELEM_COMPLEX_TYPE_LOCALLY_VALID$EMPTY_WITH_CONTENT, new Object[]{qName.rawname});
            }
            short s2 = xSComplexTypeDecl.fContentType;
            if (s2 == 2 || s2 == 3) {
                int[] iArr = this.fCurrCMState;
                if (iArr[0] >= 0 && !this.fCurrentCM.endContentModel(iArr)) {
                    String expectedStr = expectedStr(this.fCurrentCM.whatCanGoHere(this.fCurrCMState));
                    int[] occurenceInfo = this.fCurrentCM.occurenceInfo(this.fCurrCMState);
                    if (occurenceInfo != null) {
                        int i2 = occurenceInfo[0];
                        int i3 = occurenceInfo[2];
                        if (i3 < i2) {
                            int i4 = i2 - i3;
                            if (i4 > 1) {
                                reportSchemaError("cvc-complex-type.2.4.j", new Object[]{qName.rawname, this.fCurrentCM.getTermName(occurenceInfo[3]), Integer.toString(i2), Integer.toString(i4)});
                            } else {
                                reportSchemaError("cvc-complex-type.2.4.i", new Object[]{qName.rawname, this.fCurrentCM.getTermName(occurenceInfo[3]), Integer.toString(i2)});
                            }
                        } else {
                            reportSchemaError("cvc-complex-type.2.4.b", new Object[]{qName.rawname, expectedStr});
                        }
                    } else {
                        reportSchemaError("cvc-complex-type.2.4.b", new Object[]{qName.rawname, expectedStr});
                    }
                }
            }
        }
        return obj2;
    }

    public Object elementLocallyValidType(org.apache.xerces.xni.QName qName, Object obj) {
        XSTypeDefinition xSTypeDefinition = this.fCurrentType;
        if (xSTypeDefinition == null) {
            return null;
        }
        if (xSTypeDefinition.getTypeCategory() != 16) {
            return elementLocallyValidComplexType(qName, obj);
        }
        if (this.fSubElement) {
            reportSchemaError("cvc-type.3.1.2", new Object[]{qName.rawname});
        }
        if (this.fNil) {
            return null;
        }
        XSSimpleType xSSimpleType = (XSSimpleType) this.fCurrentType;
        try {
            if (!this.fNormalizeData || this.fUnionType) {
                this.fValidationState.setNormalizationRequired(true);
            }
            return xSSimpleType.validate(obj, this.fValidationState, this.fValidatedInfo);
        } catch (InvalidDatatypeValueException e2) {
            reportSchemaError(e2.getKey(), e2.getArgs());
            reportSchemaError("cvc-type.3.1.3", new Object[]{qName.rawname, obj});
            return null;
        }
    }

    @Override // org.apache.xerces.xni.XMLDocumentHandler
    public void emptyElement(org.apache.xerces.xni.QName qName, XMLAttributes xMLAttributes, Augmentations augmentations) {
        Augmentations handleStartElement = handleStartElement(qName, xMLAttributes, augmentations);
        this.fDefaultValue = null;
        if (this.fElementDepth != -2) {
            handleStartElement = handleEndElement(qName, handleStartElement);
        }
        XMLDocumentHandler xMLDocumentHandler = this.fDocumentHandler;
        if (xMLDocumentHandler == null) {
            return;
        }
        if (!this.fSchemaElementDefault || this.fDefaultValue == null) {
            this.fDocumentHandler.emptyElement(qName, xMLAttributes, handleStartElement);
            return;
        }
        xMLDocumentHandler.startElement(qName, xMLAttributes, handleStartElement);
        this.fDocumentHandler.characters(this.fDefaultValue, null);
        this.fDocumentHandler.endElement(qName, handleStartElement);
    }

    @Override // org.apache.xerces.xni.XMLDocumentHandler
    public void endCDATA(Augmentations augmentations) {
        this.fInCDATA = false;
        XMLDocumentHandler xMLDocumentHandler = this.fDocumentHandler;
        if (xMLDocumentHandler != null) {
            xMLDocumentHandler.endCDATA(augmentations);
        }
    }

    @Override // org.apache.xerces.xni.XMLDocumentHandler
    public void endDocument(Augmentations augmentations) {
        handleEndDocument();
        XMLDocumentHandler xMLDocumentHandler = this.fDocumentHandler;
        if (xMLDocumentHandler != null) {
            xMLDocumentHandler.endDocument(augmentations);
        }
        this.fLocator = null;
    }

    @Override // org.apache.xerces.xni.XMLDocumentHandler
    public void endElement(org.apache.xerces.xni.QName qName, Augmentations augmentations) {
        XMLString xMLString;
        this.fDefaultValue = null;
        Augmentations handleEndElement = handleEndElement(qName, augmentations);
        XMLDocumentHandler xMLDocumentHandler = this.fDocumentHandler;
        if (xMLDocumentHandler != null) {
            if (this.fSchemaElementDefault && (xMLString = this.fDefaultValue) != null) {
                xMLDocumentHandler.characters(xMLString, null);
            }
            this.fDocumentHandler.endElement(qName, handleEndElement);
        }
    }

    public final Augmentations endElementPSVI(boolean z, SchemaGrammar[] schemaGrammarArr, Augmentations augmentations) {
        if (this.fAugPSVI) {
            augmentations = getEmptyAugs(augmentations);
            ElementPSVImpl elementPSVImpl = this.fCurrentPSVI;
            elementPSVImpl.fDeclaration = this.fCurrentElemDecl;
            elementPSVImpl.fTypeDecl = this.fCurrentType;
            elementPSVImpl.fNotation = this.fNotation;
            elementPSVImpl.fValidationContext = this.fValidationRoot;
            elementPSVImpl.fNil = this.fNil;
            int i2 = this.fElementDepth;
            short s = 2;
            if (i2 > this.fNFullValidationDepth) {
                elementPSVImpl.fValidationAttempted = 2;
            } else if (i2 > this.fNNoneValidationDepth) {
                elementPSVImpl.fValidationAttempted = 0;
            } else {
                elementPSVImpl.fValidationAttempted = 1;
            }
            int i3 = this.fNFullValidationDepth;
            int i4 = this.fElementDepth;
            if (i3 == i4) {
                this.fNFullValidationDepth = i4 - 1;
            }
            int i5 = this.fNNoneValidationDepth;
            int i6 = this.fElementDepth;
            if (i5 == i6) {
                this.fNNoneValidationDepth = i6 - 1;
            }
            if (this.fDefaultValue != null) {
                this.fCurrentPSVI.fSpecified = true;
            }
            this.fCurrentPSVI.fValue.copyFrom(this.fValidatedInfo);
            if (this.fStrictAssess) {
                String[] mergeContext = this.fXSIErrorReporter.mergeContext();
                ElementPSVImpl elementPSVImpl2 = this.fCurrentPSVI;
                elementPSVImpl2.fErrors = mergeContext;
                if (mergeContext != null) {
                    s = 1;
                }
                elementPSVImpl2.fValidity = s;
            } else {
                this.fCurrentPSVI.fValidity = 0;
                this.fXSIErrorReporter.popContext();
            }
            if (z) {
                ElementPSVImpl elementPSVImpl3 = this.fCurrentPSVI;
                elementPSVImpl3.fGrammars = schemaGrammarArr;
                elementPSVImpl3.fSchemaInformation = null;
            }
        }
        return augmentations;
    }

    @Override // org.apache.xerces.xni.XMLDocumentHandler
    public void endGeneralEntity(String str, Augmentations augmentations) {
        this.fEntityRef = false;
        XMLDocumentHandler xMLDocumentHandler = this.fDocumentHandler;
        if (xMLDocumentHandler != null) {
            xMLDocumentHandler.endGeneralEntity(str, augmentations);
        }
    }

    @Override // org.apache.xerces.impl.xs.identity.FieldActivator
    public void endValueScopeFor(IdentityConstraint identityConstraint, int i2) {
        this.fValueStoreCache.getValueStoreFor(identityConstraint, i2).endValueScope();
    }

    public void ensureStackCapacity() {
        int i2 = this.fElementDepth;
        if (i2 == this.fElemDeclStack.length) {
            int i3 = i2 + 8;
            boolean[] zArr = new boolean[i3];
            System.arraycopy(this.fSubElementStack, 0, zArr, 0, i2);
            this.fSubElementStack = zArr;
            XSElementDecl[] xSElementDeclArr = new XSElementDecl[i3];
            System.arraycopy(this.fElemDeclStack, 0, xSElementDeclArr, 0, this.fElementDepth);
            this.fElemDeclStack = xSElementDeclArr;
            boolean[] zArr2 = new boolean[i3];
            System.arraycopy(this.fNilStack, 0, zArr2, 0, this.fElementDepth);
            this.fNilStack = zArr2;
            XSNotationDecl[] xSNotationDeclArr = new XSNotationDecl[i3];
            System.arraycopy(this.fNotationStack, 0, xSNotationDeclArr, 0, this.fElementDepth);
            this.fNotationStack = xSNotationDeclArr;
            XSTypeDefinition[] xSTypeDefinitionArr = new XSTypeDefinition[i3];
            System.arraycopy(this.fTypeStack, 0, xSTypeDefinitionArr, 0, this.fElementDepth);
            this.fTypeStack = xSTypeDefinitionArr;
            XSCMValidator[] xSCMValidatorArr = new XSCMValidator[i3];
            System.arraycopy(this.fCMStack, 0, xSCMValidatorArr, 0, this.fElementDepth);
            this.fCMStack = xSCMValidatorArr;
            boolean[] zArr3 = new boolean[i3];
            System.arraycopy(this.fSawTextStack, 0, zArr3, 0, this.fElementDepth);
            this.fSawTextStack = zArr3;
            boolean[] zArr4 = new boolean[i3];
            System.arraycopy(this.fStringContent, 0, zArr4, 0, this.fElementDepth);
            this.fStringContent = zArr4;
            boolean[] zArr5 = new boolean[i3];
            System.arraycopy(this.fStrictAssessStack, 0, zArr5, 0, this.fElementDepth);
            this.fStrictAssessStack = zArr5;
            int[][] iArr = new int[i3][];
            System.arraycopy(this.fCMStateStack, 0, iArr, 0, this.fElementDepth);
            this.fCMStateStack = iArr;
        }
    }

    /* JADX WARNING: Removed duplicated region for block: B:43:0x00b1  */
    /* JADX WARNING: Removed duplicated region for block: B:55:? A[RETURN, SYNTHETIC] */
    public SchemaGrammar findSchemaGrammar(short s, String str, org.apache.xerces.xni.QName qName, org.apache.xerces.xni.QName qName2, XMLAttributes xMLAttributes) {
        boolean z;
        SchemaGrammar grammar = this.fGrammarBucket.getGrammar(str);
        if (grammar == null) {
            this.fXSDDescription.setNamespace(str);
            XMLGrammarPool xMLGrammarPool = this.fGrammarPool;
            if (!(xMLGrammarPool == null || (grammar = (SchemaGrammar) xMLGrammarPool.retrieveGrammar(this.fXSDDescription)) == null || this.fGrammarBucket.putGrammar(grammar, true, this.fNamespaceGrowth))) {
                this.fXSIErrorReporter.fErrorReporter.reportError(XSMessageFormatter.SCHEMA_DOMAIN, "GrammarConflict", null, 0);
                grammar = null;
            }
        }
        if (this.fUseGrammarPoolOnly) {
            return grammar;
        }
        if (grammar != null && (!this.fNamespaceGrowth || hasSchemaComponent(grammar, s, qName2))) {
            return grammar;
        }
        this.fXSDDescription.reset();
        XSDDescription xSDDescription = this.fXSDDescription;
        xSDDescription.fContextType = s;
        xSDDescription.setNamespace(str);
        XSDDescription xSDDescription2 = this.fXSDDescription;
        xSDDescription2.fEnclosedElementName = qName;
        xSDDescription2.fTriggeringComponent = qName2;
        xSDDescription2.fAttributes = xMLAttributes;
        XMLLocator xMLLocator = this.fLocator;
        if (xMLLocator != null) {
            xSDDescription2.setBaseSystemId(xMLLocator.getExpandedSystemId());
        }
        Hashtable hashtable = this.fLocationPairs;
        if (str == null) {
            str = XMLSymbols.EMPTY_STRING;
        }
        Object obj = hashtable.get(str);
        if (obj != null) {
            String[] locationArray = ((XMLSchemaLoader.LocationArray) obj).getLocationArray();
            if (locationArray.length != 0) {
                setLocationHints(this.fXSDDescription, locationArray, grammar);
            }
        }
        if (grammar != null && this.fXSDDescription.fLocationHints == null) {
            return grammar;
        }
        if (grammar != null) {
            hashtable = EMPTY_TABLE;
        }
        try {
            XMLInputSource resolveDocument = XMLSchemaLoader.resolveDocument(this.fXSDDescription, hashtable, this.fEntityResolver);
            if (grammar != null && this.fNamespaceGrowth) {
                try {
                    z = !grammar.getDocumentLocations().contains(XMLEntityManager.expandSystemId(resolveDocument.getSystemId(), resolveDocument.getBaseSystemId(), false));
                } catch (URI.MalformedURIException unused) {
                }
                return !z ? this.fSchemaLoader.loadSchema(this.fXSDDescription, resolveDocument, this.fLocationPairs) : grammar;
            }
            z = true;
            if (!z) {
            }
        } catch (IOException e2) {
            String[] locationHints = this.fXSDDescription.getLocationHints();
            XMLErrorReporter xMLErrorReporter = this.fXSIErrorReporter.fErrorReporter;
            Object[] objArr = new Object[1];
            objArr[0] = locationHints != null ? locationHints[0] : XMLSymbols.EMPTY_STRING;
            xMLErrorReporter.reportError(XSMessageFormatter.SCHEMA_DOMAIN, "schema_reference.4", objArr, (short) 0, (Exception) e2);
            return grammar;
        }
    }

    public XSTypeDefinition getAndCheckXsiType(org.apache.xerces.xni.QName qName, String str, XMLAttributes xMLAttributes) {
        SchemaGrammar findSchemaGrammar;
        try {
            org.apache.xerces.xni.QName qName2 = (org.apache.xerces.xni.QName) this.fQNameDV.validate(str, (ValidationContext) this.fValidationState, (ValidatedInfo) null);
            XSTypeDefinition globalTypeDecl = qName2.uri == SchemaSymbols.URI_SCHEMAFORSCHEMA ? SchemaGrammar.SG_SchemaNS.getGlobalTypeDecl(qName2.localpart) : null;
            if (globalTypeDecl == null && (findSchemaGrammar = findSchemaGrammar(7, qName2.uri, qName, qName2, xMLAttributes)) != null) {
                globalTypeDecl = findSchemaGrammar.getGlobalTypeDecl(qName2.localpart);
            }
            if (globalTypeDecl == null) {
                reportSchemaError(XmlErrorCodes.ELEM_LOCALLY_VALID$XSI_TYPE_NOT_FOUND, new Object[]{qName.rawname, str});
                return null;
            }
            if (this.fCurrentType != null) {
                XSElementDecl xSElementDecl = this.fCurrentElemDecl;
                short s = xSElementDecl != null ? xSElementDecl.fBlock : 0;
                if (this.fCurrentType.getTypeCategory() == 15) {
                    s = (short) (s | ((XSComplexTypeDecl) this.fCurrentType).fBlock);
                }
                if (!XSConstraints.checkTypeDerivationOk(globalTypeDecl, this.fCurrentType, s)) {
                    reportSchemaError("cvc-elt.4.3", new Object[]{qName.rawname, str, this.fCurrentType.getName()});
                }
            }
            return globalTypeDecl;
        } catch (InvalidDatatypeValueException e2) {
            reportSchemaError(e2.getKey(), e2.getArgs());
            StringBuffer stringBuffer = new StringBuffer();
            stringBuffer.append(SchemaSymbols.URI_XSI);
            stringBuffer.append(XSSFDataValidationConstraint.LIST_SEPARATOR);
            stringBuffer.append(SchemaSymbols.XSI_TYPE);
            reportSchemaError(XmlErrorCodes.ELEM_LOCALLY_VALID$XSI_TYPE_INVALID_QNAME, new Object[]{qName.rawname, stringBuffer.toString(), str});
            return null;
        }
    }

    @Override // org.apache.xerces.xni.parser.XMLDocumentSource
    public XMLDocumentHandler getDocumentHandler() {
        return this.fDocumentHandler;
    }

    @Override // org.apache.xerces.xni.XMLDocumentHandler
    public XMLDocumentSource getDocumentSource() {
        return this.fDocumentSource;
    }

    public Augmentations getEmptyAugs(Augmentations augmentations) {
        if (augmentations == null) {
            augmentations = this.fAugmentations;
            augmentations.removeAllItems();
        }
        augmentations.putItem(Constants.ELEMENT_PSVI, this.fCurrentPSVI);
        this.fCurrentPSVI.reset();
        return augmentations;
    }

    @Override // org.apache.xerces.xni.parser.XMLComponent
    public Boolean getFeatureDefault(String str) {
        int i2 = 0;
        while (true) {
            String[] strArr = RECOGNIZED_FEATURES;
            if (i2 >= strArr.length) {
                return null;
            }
            if (strArr[i2].equals(str)) {
                return FEATURE_DEFAULTS[i2];
            }
            i2++;
        }
    }

    @Override // org.apache.xerces.impl.xs.XSElementDeclHelper
    public XSElementDecl getGlobalElementDecl(org.apache.xerces.xni.QName qName) {
        SchemaGrammar findSchemaGrammar = findSchemaGrammar(5, qName.uri, null, qName, null);
        if (findSchemaGrammar != null) {
            return findSchemaGrammar.getGlobalElementDecl(qName.localpart);
        }
        return null;
    }

    @Override // org.apache.xerces.xni.parser.XMLComponent
    public Object getPropertyDefault(String str) {
        int i2 = 0;
        while (true) {
            String[] strArr = RECOGNIZED_PROPERTIES;
            if (i2 >= strArr.length) {
                return null;
            }
            if (strArr[i2].equals(str)) {
                return PROPERTY_DEFAULTS[i2];
            }
            i2++;
        }
    }

    @Override // org.apache.xerces.xni.parser.XMLComponent
    public String[] getRecognizedFeatures() {
        return (String[]) RECOGNIZED_FEATURES.clone();
    }

    @Override // org.apache.xerces.xni.parser.XMLComponent
    public String[] getRecognizedProperties() {
        return (String[]) RECOGNIZED_PROPERTIES.clone();
    }

    public boolean getXsiNil(org.apache.xerces.xni.QName qName, String str) {
        XSElementDecl xSElementDecl = this.fCurrentElemDecl;
        if (xSElementDecl == null || xSElementDecl.getNillable()) {
            String trim = XMLChar.trim(str);
            if (trim.equals(SchemaSymbols.ATTVAL_TRUE) || trim.equals("1")) {
                XSElementDecl xSElementDecl2 = this.fCurrentElemDecl;
                if (xSElementDecl2 != null && xSElementDecl2.getConstraintType() == 2) {
                    StringBuffer stringBuffer = new StringBuffer();
                    stringBuffer.append(SchemaSymbols.URI_XSI);
                    stringBuffer.append(XSSFDataValidationConstraint.LIST_SEPARATOR);
                    stringBuffer.append(SchemaSymbols.XSI_NIL);
                    reportSchemaError(XmlErrorCodes.ELEM_LOCALLY_VALID$NIL_WITH_FIXED, new Object[]{qName.rawname, stringBuffer.toString()});
                }
                return true;
            }
        } else {
            StringBuffer stringBuffer2 = new StringBuffer();
            stringBuffer2.append(SchemaSymbols.URI_XSI);
            stringBuffer2.append(XSSFDataValidationConstraint.LIST_SEPARATOR);
            stringBuffer2.append(SchemaSymbols.XSI_NIL);
            reportSchemaError(XmlErrorCodes.ELEM_LOCALLY_VALID$NOT_NILLABLE, new Object[]{qName.rawname, stringBuffer2.toString()});
        }
        return false;
    }

    public XMLString handleCharacters(XMLString xMLString) {
        short s;
        if (this.fSkipValidationDepth >= 0) {
            return xMLString;
        }
        boolean z = false;
        this.fSawText = this.fSawText || xMLString.length > 0;
        if (!(!this.fNormalizeData || (s = this.fWhiteSpace) == -1 || s == 0)) {
            if (s == 2) {
                z = true;
            }
            normalizeWhitespace(xMLString, z);
            xMLString = this.fNormalizedStr;
        }
        if (this.fAppendBuffer) {
            this.fBuffer.append(xMLString.ch, xMLString.offset, xMLString.length);
        }
        XSTypeDefinition xSTypeDefinition = this.fCurrentType;
        if (xSTypeDefinition != null && xSTypeDefinition.getTypeCategory() == 15 && ((XSComplexTypeDecl) this.fCurrentType).fContentType == 2) {
            int i2 = xMLString.offset;
            while (true) {
                if (i2 >= xMLString.offset + xMLString.length) {
                    break;
                } else if (!XMLChar.isSpace(xMLString.ch[i2])) {
                    this.fSawCharacters = true;
                    break;
                } else {
                    i2++;
                }
            }
        }
        return xMLString;
    }

    public void handleEndDocument() {
        if (this.fIDCChecking) {
            this.fValueStoreCache.endDocument();
        }
    }

    public Augmentations handleEndElement(org.apache.xerces.xni.QName qName, Augmentations augmentations) {
        Selector.Matcher matcher;
        IdentityConstraint identityConstraint;
        ValueStoreBase valueStoreFor;
        Selector.Matcher matcher2;
        IdentityConstraint identityConstraint2;
        boolean nillable;
        Object obj;
        short s;
        ShortList shortList;
        int i2 = this.fSkipValidationDepth;
        if (i2 >= 0) {
            int i3 = this.fElementDepth;
            if (i2 != i3 || i2 <= 0) {
                this.fElementDepth--;
            } else {
                this.fNFullValidationDepth = i2 - 1;
                this.fSkipValidationDepth = -1;
                int i4 = i3 - 1;
                this.fElementDepth = i4;
                this.fSubElement = this.fSubElementStack[i4];
                this.fCurrentElemDecl = this.fElemDeclStack[i4];
                this.fNil = this.fNilStack[i4];
                this.fNotation = this.fNotationStack[i4];
                this.fCurrentType = this.fTypeStack[i4];
                this.fCurrentCM = this.fCMStack[i4];
                this.fStrictAssess = this.fStrictAssessStack[i4];
                this.fCurrCMState = this.fCMStateStack[i4];
                this.fSawText = this.fSawTextStack[i4];
                this.fSawCharacters = this.fStringContent[i4];
            }
            if (this.fElementDepth == -1 && this.fFullChecking && !this.fUseGrammarPoolOnly) {
                XSConstraints.fullSchemaChecking(this.fGrammarBucket, this.fSubGroupHandler, this.fCMBuilder, this.fXSIErrorReporter.fErrorReporter);
            }
            return this.fAugPSVI ? getEmptyAugs(augmentations) : augmentations;
        }
        processElementContent(qName);
        if (this.fIDCChecking) {
            int matcherCount = this.fMatcherStack.getMatcherCount() - 1;
            for (int i5 = matcherCount; i5 >= 0; i5--) {
                XPathMatcher matcherAt = this.fMatcherStack.getMatcherAt(i5);
                XSElementDecl xSElementDecl = this.fCurrentElemDecl;
                XSTypeDefinition xSTypeDefinition = this.fCurrentType;
                if (xSElementDecl == null) {
                    nillable = false;
                    ValidatedInfo validatedInfo = this.fValidatedInfo;
                    obj = validatedInfo.actualValue;
                    s = validatedInfo.actualValueType;
                    shortList = validatedInfo.itemValueTypes;
                } else {
                    nillable = xSElementDecl.getNillable();
                    obj = (this.fDefaultValue == null ? this.fValidatedInfo : this.fCurrentElemDecl.fDefault).actualValue;
                    s = (this.fDefaultValue == null ? this.fValidatedInfo : this.fCurrentElemDecl.fDefault).actualValueType;
                    shortList = (this.fDefaultValue == null ? this.fValidatedInfo : this.fCurrentElemDecl.fDefault).itemValueTypes;
                }
                matcherAt.endElement(qName, xSTypeDefinition, nillable, obj, s, shortList);
            }
            if (this.fMatcherStack.size() > 0) {
                this.fMatcherStack.popContext();
            }
            int matcherCount2 = this.fMatcherStack.getMatcherCount();
            for (int i6 = matcherCount; i6 >= matcherCount2; i6--) {
                XPathMatcher matcherAt2 = this.fMatcherStack.getMatcherAt(i6);
                if (!(!(matcherAt2 instanceof Selector.Matcher) || (identityConstraint2 = (matcher2 = (Selector.Matcher) matcherAt2).getIdentityConstraint()) == null || identityConstraint2.getCategory() == 2)) {
                    this.fValueStoreCache.transplant(identityConstraint2, matcher2.getInitialDepth());
                }
            }
            while (matcherCount >= matcherCount2) {
                XPathMatcher matcherAt3 = this.fMatcherStack.getMatcherAt(matcherCount);
                if ((matcherAt3 instanceof Selector.Matcher) && (identityConstraint = (matcher = (Selector.Matcher) matcherAt3).getIdentityConstraint()) != null && identityConstraint.getCategory() == 2 && (valueStoreFor = this.fValueStoreCache.getValueStoreFor(identityConstraint, matcher.getInitialDepth())) != null) {
                    valueStoreFor.endDocumentFragment();
                }
                matcherCount--;
            }
            this.fValueStoreCache.endElement();
        }
        int i7 = this.fElementDepth;
        int i8 = this.fIgnoreXSITypeDepth;
        if (i7 < i8) {
            this.fIgnoreXSITypeDepth = i8 - 1;
        }
        if (this.fElementDepth == 0) {
            String checkIDRefID = this.fValidationState.checkIDRefID();
            this.fValidationState.resetIDTables();
            if (checkIDRefID != null) {
                reportSchemaError("cvc-id.1", new Object[]{checkIDRefID});
            }
            if (this.fFullChecking && !this.fUseGrammarPoolOnly) {
                XSConstraints.fullSchemaChecking(this.fGrammarBucket, this.fSubGroupHandler, this.fCMBuilder, this.fXSIErrorReporter.fErrorReporter);
            }
            SchemaGrammar[] grammars = this.fGrammarBucket.getGrammars();
            if (this.fGrammarPool != null) {
                for (SchemaGrammar schemaGrammar : grammars) {
                    schemaGrammar.setImmutable(true);
                }
                this.fGrammarPool.cacheGrammars("http://www.w3.org/2001/XMLSchema", grammars);
            }
            return endElementPSVI(true, grammars, augmentations);
        }
        Augmentations endElementPSVI = endElementPSVI(false, null, augmentations);
        int i9 = this.fElementDepth - 1;
        this.fElementDepth = i9;
        this.fSubElement = this.fSubElementStack[i9];
        this.fCurrentElemDecl = this.fElemDeclStack[i9];
        this.fNil = this.fNilStack[i9];
        this.fNotation = this.fNotationStack[i9];
        this.fCurrentType = this.fTypeStack[i9];
        this.fCurrentCM = this.fCMStack[i9];
        this.fStrictAssess = this.fStrictAssessStack[i9];
        this.fCurrCMState = this.fCMStateStack[i9];
        this.fSawText = this.fSawTextStack[i9];
        this.fSawCharacters = this.fStringContent[i9];
        this.fWhiteSpace = -1;
        this.fAppendBuffer = false;
        this.fUnionType = false;
        return endElementPSVI;
    }

    public void handleIgnorableWhitespace(XMLString xMLString) {
        int i2 = this.fSkipValidationDepth;
    }

    public void handleStartDocument(XMLLocator xMLLocator, String str) {
        if (this.fIDCChecking) {
            this.fValueStoreCache.startDocument();
        }
        if (this.fAugPSVI) {
            ElementPSVImpl elementPSVImpl = this.fCurrentPSVI;
            elementPSVImpl.fGrammars = null;
            elementPSVImpl.fSchemaInformation = null;
        }
    }

    /* JADX WARNING: Removed duplicated region for block: B:124:0x0299  */
    /* JADX WARNING: Removed duplicated region for block: B:138:0x02cd  */
    /* JADX WARNING: Removed duplicated region for block: B:139:0x02cf  */
    /* JADX WARNING: Removed duplicated region for block: B:148:0x02eb  */
    /* JADX WARNING: Removed duplicated region for block: B:151:0x02f3  */
    /* JADX WARNING: Removed duplicated region for block: B:154:0x0305  */
    /* JADX WARNING: Removed duplicated region for block: B:166:0x0334  */
    /* JADX WARNING: Removed duplicated region for block: B:175:0x0355  */
    /* JADX WARNING: Removed duplicated region for block: B:178:0x0367  */
    /* JADX WARNING: Removed duplicated region for block: B:186:0x0389  */
    /* JADX WARNING: Removed duplicated region for block: B:187:0x0392  */
    /* JADX WARNING: Removed duplicated region for block: B:190:0x0397  */
    /* JADX WARNING: Removed duplicated region for block: B:197:0x03b5  */
    /* JADX WARNING: Removed duplicated region for block: B:202:0x03c4  */
    /* JADX WARNING: Removed duplicated region for block: B:203:0x03df  */
    /* JADX WARNING: Removed duplicated region for block: B:204:0x03e1 A[LOOP:0: B:199:0x03be->B:204:0x03e1, LOOP_END] */
    /* JADX WARNING: Removed duplicated region for block: B:65:0x01bf  */
    /* JADX WARNING: Removed duplicated region for block: B:79:0x01e3  */
    /* JADX WARNING: Removed duplicated region for block: B:94:0x021a  */
    /* JADX WARNING: Removed duplicated region for block: B:95:0x0223  */
    public Augmentations handleStartElement(org.apache.xerces.xni.QName qName, XMLAttributes xMLAttributes, Augmentations augmentations) {
        Object obj;
        XSWildcardDecl xSWildcardDecl;
        int i2;
        String value;
        XSCMValidator xSCMValidator;
        String value2;
        XSAttributeGroupDecl attrGrp;
        int matcherCount;
        short whitespace;
        XSElementDecl xSElementDecl;
        SchemaGrammar findSchemaGrammar;
        if (this.fElementDepth == -1 && this.fValidationManager.isGrammarFound() && this.fSchemaType == null) {
            this.fSchemaDynamicValidation = true;
        }
        if (!this.fUseGrammarPoolOnly) {
            storeLocations(xMLAttributes.getValue(SchemaSymbols.URI_XSI, SchemaSymbols.XSI_SCHEMALOCATION), xMLAttributes.getValue(SchemaSymbols.URI_XSI, SchemaSymbols.XSI_NONAMESPACESCHEMALOCATION));
        }
        if (this.fSkipValidationDepth >= 0) {
            this.fElementDepth++;
            return this.fAugPSVI ? getEmptyAugs(augmentations) : augmentations;
        }
        XSCMValidator xSCMValidator2 = this.fCurrentCM;
        if (xSCMValidator2 != null) {
            obj = xSCMValidator2.oneTransition(qName, this.fCurrCMState, this.fSubGroupHandler);
            int[] iArr = this.fCurrCMState;
            if (iArr[0] == -1) {
                if (((XSComplexTypeDecl) this.fCurrentType).fParticle != null) {
                    Vector whatCanGoHere = this.fCurrentCM.whatCanGoHere(iArr);
                    if (whatCanGoHere.size() > 0) {
                        String expectedStr = expectedStr(whatCanGoHere);
                        int[] occurenceInfo = this.fCurrentCM.occurenceInfo(this.fCurrCMState);
                        if (occurenceInfo != null) {
                            int i3 = occurenceInfo[0];
                            int i4 = occurenceInfo[1];
                            int i5 = occurenceInfo[2];
                            if (i5 < i3) {
                                int i6 = i3 - i5;
                                if (i6 > 1) {
                                    reportSchemaError("cvc-complex-type.2.4.h", new Object[]{qName.rawname, this.fCurrentCM.getTermName(occurenceInfo[3]), Integer.toString(i3), Integer.toString(i6)});
                                } else {
                                    reportSchemaError("cvc-complex-type.2.4.g", new Object[]{qName.rawname, this.fCurrentCM.getTermName(occurenceInfo[3]), Integer.toString(i3)});
                                }
                            } else if (i5 < i4 || i4 == -1) {
                                reportSchemaError("cvc-complex-type.2.4.a", new Object[]{qName.rawname, expectedStr});
                            } else {
                                reportSchemaError("cvc-complex-type.2.4.e", new Object[]{qName.rawname, expectedStr, Integer.toString(i4)});
                            }
                        } else {
                            reportSchemaError("cvc-complex-type.2.4.a", new Object[]{qName.rawname, expectedStr});
                        }
                    }
                }
                int[] occurenceInfo2 = this.fCurrentCM.occurenceInfo(this.fCurrCMState);
                if (occurenceInfo2 != null) {
                    int i7 = occurenceInfo2[1];
                    if (occurenceInfo2[2] < i7 || i7 == -1) {
                        reportSchemaError("cvc-complex-type.2.4.d", new Object[]{qName.rawname});
                    } else {
                        reportSchemaError("cvc-complex-type.2.4.f", new Object[]{qName.rawname, Integer.toString(i7)});
                    }
                } else {
                    reportSchemaError("cvc-complex-type.2.4.d", new Object[]{qName.rawname});
                }
            }
        } else {
            obj = null;
        }
        if (this.fElementDepth != -1) {
            ensureStackCapacity();
            boolean[] zArr = this.fSubElementStack;
            int i8 = this.fElementDepth;
            zArr[i8] = true;
            this.fSubElement = false;
            this.fElemDeclStack[i8] = this.fCurrentElemDecl;
            this.fNilStack[i8] = this.fNil;
            this.fNotationStack[i8] = this.fNotation;
            this.fTypeStack[i8] = this.fCurrentType;
            this.fStrictAssessStack[i8] = this.fStrictAssess;
            this.fCMStack[i8] = this.fCurrentCM;
            this.fCMStateStack[i8] = this.fCurrCMState;
            this.fSawTextStack[i8] = this.fSawText;
            this.fStringContent[i8] = this.fSawCharacters;
        }
        this.fElementDepth++;
        this.fCurrentElemDecl = null;
        this.fCurrentType = null;
        this.fStrictAssess = true;
        this.fNil = false;
        this.fNotation = null;
        this.fBuffer.setLength(0);
        this.fSawText = false;
        this.fSawCharacters = false;
        if (obj != null) {
            if (obj instanceof XSElementDecl) {
                this.fCurrentElemDecl = (XSElementDecl) obj;
            } else {
                xSWildcardDecl = (XSWildcardDecl) obj;
                if (xSWildcardDecl == null && xSWildcardDecl.fProcessContents == 2) {
                    this.fSkipValidationDepth = this.fElementDepth;
                    return this.fAugPSVI ? getEmptyAugs(augmentations) : augmentations;
                }
                if (this.fElementDepth == 0) {
                    XSElementDecl xSElementDecl2 = this.fRootElementDeclaration;
                    if (xSElementDecl2 != null) {
                        this.fCurrentElemDecl = xSElementDecl2;
                        checkElementMatchesRootElementDecl(xSElementDecl2, qName);
                    } else {
                        QName qName2 = this.fRootElementDeclQName;
                        if (qName2 != null) {
                            processRootElementDeclQName(qName2, qName);
                        } else {
                            XSTypeDefinition xSTypeDefinition = this.fRootTypeDefinition;
                            if (xSTypeDefinition != null) {
                                this.fCurrentType = xSTypeDefinition;
                            } else {
                                QName qName3 = this.fRootTypeQName;
                                if (qName3 != null) {
                                    processRootTypeQName(qName3);
                                }
                            }
                        }
                    }
                }
                if (this.fCurrentType == null) {
                    if (this.fCurrentElemDecl == null && (findSchemaGrammar = findSchemaGrammar(5, qName.uri, null, qName, xMLAttributes)) != null) {
                        this.fCurrentElemDecl = findSchemaGrammar.getGlobalElementDecl(qName.localpart);
                    }
                    XSElementDecl xSElementDecl3 = this.fCurrentElemDecl;
                    if (xSElementDecl3 != null) {
                        this.fCurrentType = xSElementDecl3.fType;
                    }
                }
                int i9 = this.fElementDepth;
                i2 = this.fIgnoreXSITypeDepth;
                if (i9 == i2 && this.fCurrentElemDecl == null) {
                    this.fIgnoreXSITypeDepth = i2 + 1;
                }
                value = this.fElementDepth < this.fIgnoreXSITypeDepth ? xMLAttributes.getValue(SchemaSymbols.URI_XSI, SchemaSymbols.XSI_TYPE) : null;
                if (this.fCurrentType == null || value != null) {
                    this.fXSIErrorReporter.pushContext();
                    if (value != null) {
                        XSTypeDefinition xSTypeDefinition2 = this.fCurrentType;
                        XSTypeDefinition andCheckXsiType = getAndCheckXsiType(qName, value, xMLAttributes);
                        this.fCurrentType = andCheckXsiType;
                        if (andCheckXsiType == null) {
                            if (xSTypeDefinition2 == null) {
                                xSTypeDefinition2 = SchemaGrammar.fAnyType;
                            }
                            this.fCurrentType = xSTypeDefinition2;
                        }
                    }
                    this.fNNoneValidationDepth = this.fElementDepth;
                    xSElementDecl = this.fCurrentElemDecl;
                    if ((xSElementDecl == null && xSElementDecl.getConstraintType() == 2) || this.fCurrentType.getTypeCategory() == 16) {
                        this.fAppendBuffer = true;
                    } else {
                        this.fAppendBuffer = ((XSComplexTypeDecl) this.fCurrentType).fContentType != 1;
                    }
                } else {
                    if (this.fElementDepth == 0) {
                        if (this.fDynamicValidation || this.fSchemaDynamicValidation) {
                            XMLDocumentSource xMLDocumentSource = this.fDocumentSource;
                            if (xMLDocumentSource != null) {
                                xMLDocumentSource.setDocumentHandler(this.fDocumentHandler);
                                XMLDocumentHandler xMLDocumentHandler = this.fDocumentHandler;
                                if (xMLDocumentHandler != null) {
                                    xMLDocumentHandler.setDocumentSource(this.fDocumentSource);
                                }
                                this.fElementDepth = -2;
                                return augmentations;
                            }
                            this.fSkipValidationDepth = this.fElementDepth;
                            return this.fAugPSVI ? getEmptyAugs(augmentations) : augmentations;
                        }
                        this.fXSIErrorReporter.fErrorReporter.reportError(XSMessageFormatter.SCHEMA_DOMAIN, "cvc-elt.1.a", new Object[]{qName.rawname}, 1);
                    } else if (xSWildcardDecl != null && xSWildcardDecl.fProcessContents == 1) {
                        reportSchemaError("cvc-complex-type.2.4.c", new Object[]{qName.rawname});
                    }
                    this.fCurrentType = SchemaGrammar.fAnyType;
                    this.fStrictAssess = false;
                    this.fNFullValidationDepth = this.fElementDepth;
                    this.fAppendBuffer = false;
                    this.fXSIErrorReporter.pushContext();
                }
                XSElementDecl xSElementDecl4 = this.fCurrentElemDecl;
                if (xSElementDecl4 != null && xSElementDecl4.getAbstract()) {
                    reportSchemaError(XmlErrorCodes.ELEM_LOCALLY_VALID$ABSTRACT, new Object[]{qName.rawname});
                }
                if (this.fElementDepth == 0) {
                    this.fValidationRoot = qName.rawname;
                }
                if (this.fNormalizeData) {
                    this.fFirstChunk = true;
                    this.fTrailing = false;
                    this.fUnionType = false;
                    this.fWhiteSpace = -1;
                }
                if (this.fCurrentType.getTypeCategory() != 15) {
                    XSComplexTypeDecl xSComplexTypeDecl = (XSComplexTypeDecl) this.fCurrentType;
                    if (xSComplexTypeDecl.getAbstract()) {
                        reportSchemaError(XmlErrorCodes.ELEM_TYPE_LOCALLY_VALID$ABSTRACT, new Object[]{qName.rawname});
                    }
                    if (this.fNormalizeData && xSComplexTypeDecl.fContentType == 1) {
                        if (xSComplexTypeDecl.fXSSimpleType.getVariety() != 3) {
                            try {
                                whitespace = xSComplexTypeDecl.fXSSimpleType.getWhitespace();
                            } catch (DatatypeException unused) {
                            }
                        }
                        this.fUnionType = true;
                    }
                    this.fCurrentCM = null;
                    if (this.fCurrentType.getTypeCategory() == 15) {
                        this.fCurrentCM = ((XSComplexTypeDecl) this.fCurrentType).getContentModel(this.fCMBuilder);
                    }
                    this.fCurrCMState = null;
                    xSCMValidator = this.fCurrentCM;
                    if (xSCMValidator != null) {
                        this.fCurrCMState = xSCMValidator.startContentModel();
                    }
                    value2 = xMLAttributes.getValue(SchemaSymbols.URI_XSI, SchemaSymbols.XSI_NIL);
                    if (!(value2 == null || this.fCurrentElemDecl == null)) {
                        this.fNil = getXsiNil(qName, value2);
                    }
                    attrGrp = this.fCurrentType.getTypeCategory() != 15 ? ((XSComplexTypeDecl) this.fCurrentType).getAttrGrp() : null;
                    if (this.fIDCChecking) {
                        this.fValueStoreCache.startElement();
                        this.fMatcherStack.pushContext();
                        XSElementDecl xSElementDecl5 = this.fCurrentElemDecl;
                        if (xSElementDecl5 != null && xSElementDecl5.fIDCPos > 0) {
                            this.fIdConstraint = true;
                            this.fValueStoreCache.initValueStoresFor(xSElementDecl5, this);
                        }
                    }
                    processAttributes(qName, xMLAttributes, attrGrp);
                    if (attrGrp != null) {
                        addDefaultAttributes(qName, xMLAttributes, attrGrp);
                    }
                    matcherCount = this.fMatcherStack.getMatcherCount();
                    for (int i10 = 0; i10 < matcherCount; i10++) {
                        this.fMatcherStack.getMatcherAt(i10).startElement(qName, xMLAttributes);
                    }
                    if (this.fAugPSVI) {
                        return augmentations;
                    }
                    Augmentations emptyAugs = getEmptyAugs(augmentations);
                    ElementPSVImpl elementPSVImpl = this.fCurrentPSVI;
                    elementPSVImpl.fValidationContext = this.fValidationRoot;
                    elementPSVImpl.fDeclaration = this.fCurrentElemDecl;
                    elementPSVImpl.fTypeDecl = this.fCurrentType;
                    elementPSVImpl.fNotation = this.fNotation;
                    elementPSVImpl.fNil = this.fNil;
                    return emptyAugs;
                }
                if (this.fNormalizeData) {
                    XSSimpleType xSSimpleType = (XSSimpleType) this.fCurrentType;
                    if (xSSimpleType.getVariety() != 3) {
                        whitespace = xSSimpleType.getWhitespace();
                    }
                    this.fUnionType = true;
                }
                this.fCurrentCM = null;
                if (this.fCurrentType.getTypeCategory() == 15) {
                }
                this.fCurrCMState = null;
                xSCMValidator = this.fCurrentCM;
                if (xSCMValidator != null) {
                }
                value2 = xMLAttributes.getValue(SchemaSymbols.URI_XSI, SchemaSymbols.XSI_NIL);
                this.fNil = getXsiNil(qName, value2);
                if (this.fCurrentType.getTypeCategory() != 15) {
                }
                if (this.fIDCChecking) {
                }
                processAttributes(qName, xMLAttributes, attrGrp);
                if (attrGrp != null) {
                }
                matcherCount = this.fMatcherStack.getMatcherCount();
                while (i10 < matcherCount) {
                }
                if (this.fAugPSVI) {
                }
                this.fWhiteSpace = whitespace;
                this.fCurrentCM = null;
                if (this.fCurrentType.getTypeCategory() == 15) {
                }
                this.fCurrCMState = null;
                xSCMValidator = this.fCurrentCM;
                if (xSCMValidator != null) {
                }
                value2 = xMLAttributes.getValue(SchemaSymbols.URI_XSI, SchemaSymbols.XSI_NIL);
                this.fNil = getXsiNil(qName, value2);
                if (this.fCurrentType.getTypeCategory() != 15) {
                }
                if (this.fIDCChecking) {
                }
                processAttributes(qName, xMLAttributes, attrGrp);
                if (attrGrp != null) {
                }
                matcherCount = this.fMatcherStack.getMatcherCount();
                while (i10 < matcherCount) {
                }
                if (this.fAugPSVI) {
                }
            }
        }
        xSWildcardDecl = null;
        if (xSWildcardDecl == null) {
        }
        if (this.fElementDepth == 0) {
        }
        if (this.fCurrentType == null) {
        }
        int i92 = this.fElementDepth;
        i2 = this.fIgnoreXSITypeDepth;
        this.fIgnoreXSITypeDepth = i2 + 1;
        if (this.fElementDepth < this.fIgnoreXSITypeDepth) {
        }
        if (this.fCurrentType == null) {
        }
        this.fXSIErrorReporter.pushContext();
        if (value != null) {
        }
        this.fNNoneValidationDepth = this.fElementDepth;
        xSElementDecl = this.fCurrentElemDecl;
        if (xSElementDecl == null) {
        }
        this.fAppendBuffer = ((XSComplexTypeDecl) this.fCurrentType).fContentType != 1;
        XSElementDecl xSElementDecl42 = this.fCurrentElemDecl;
        reportSchemaError(XmlErrorCodes.ELEM_LOCALLY_VALID$ABSTRACT, new Object[]{qName.rawname});
        if (this.fElementDepth == 0) {
        }
        if (this.fNormalizeData) {
        }
        if (this.fCurrentType.getTypeCategory() != 15) {
        }
        this.fWhiteSpace = whitespace;
        this.fCurrentCM = null;
        if (this.fCurrentType.getTypeCategory() == 15) {
        }
        this.fCurrCMState = null;
        xSCMValidator = this.fCurrentCM;
        if (xSCMValidator != null) {
        }
        value2 = xMLAttributes.getValue(SchemaSymbols.URI_XSI, SchemaSymbols.XSI_NIL);
        this.fNil = getXsiNil(qName, value2);
        if (this.fCurrentType.getTypeCategory() != 15) {
        }
        if (this.fIDCChecking) {
        }
        processAttributes(qName, xMLAttributes, attrGrp);
        if (attrGrp != null) {
        }
        matcherCount = this.fMatcherStack.getMatcherCount();
        while (i10 < matcherCount) {
        }
        if (this.fAugPSVI) {
        }
    }

    @Override // org.apache.xerces.xni.XMLDocumentHandler
    public void ignorableWhitespace(XMLString xMLString, Augmentations augmentations) {
        handleIgnorableWhitespace(xMLString);
        XMLDocumentHandler xMLDocumentHandler = this.fDocumentHandler;
        if (xMLDocumentHandler != null) {
            xMLDocumentHandler.ignorableWhitespace(xMLString, augmentations);
        }
    }

    /* JADX WARNING: Removed duplicated region for block: B:45:0x00b2  */
    public void processAttributes(org.apache.xerces.xni.QName qName, XMLAttributes xMLAttributes, XSAttributeGroupDecl xSAttributeGroupDecl) {
        XSObjectList xSObjectList;
        int i2;
        XSWildcardDecl xSWildcardDecl;
        String str;
        int i3;
        XSWildcardDecl xSWildcardDecl2;
        int i4;
        XSObjectList xSObjectList2;
        XSObjectList xSObjectList3;
        XSWildcardDecl xSWildcardDecl3;
        XSAttributeUseImpl xSAttributeUseImpl;
        XSObjectList xSObjectList4;
        XSObjectList xSObjectList5;
        XSWildcardDecl xSWildcardDecl4;
        XSAttributeDecl xSAttributeDecl;
        XSAttributeDecl globalAttributeDecl;
        XSAttributeDecl xSAttributeDecl2;
        XSAttributeDecl xSAttributeDecl3;
        XMLAttributes xMLAttributes2 = xMLAttributes;
        int length = xMLAttributes.getLength();
        XSTypeDefinition xSTypeDefinition = this.fCurrentType;
        char c = 0;
        char c2 = 1;
        boolean z = xSTypeDefinition == null || xSTypeDefinition.getTypeCategory() == 16;
        if (!z) {
            XSObjectList attributeUses = xSAttributeGroupDecl.getAttributeUses();
            xSObjectList = attributeUses;
            i2 = attributeUses.getLength();
            xSWildcardDecl = xSAttributeGroupDecl.fAttributeWC;
        } else {
            xSWildcardDecl = null;
            xSObjectList = null;
            i2 = 0;
        }
        AttributePSVImpl attributePSVImpl = null;
        String str2 = null;
        int i5 = 0;
        while (true) {
            int i6 = 2;
            if (i5 >= length) {
                break;
            }
            xMLAttributes2.getName(i5, this.fTempQName);
            if (this.fAugPSVI || this.fIdConstraint) {
                Augmentations augmentations = xMLAttributes2.getAugmentations(i5);
                AttributePSVImpl attributePSVImpl2 = (AttributePSVImpl) augmentations.getItem(Constants.ATTRIBUTE_PSVI);
                if (attributePSVImpl2 != null) {
                    attributePSVImpl2.reset();
                    attributePSVImpl = attributePSVImpl2;
                } else {
                    AttributePSVImpl attributePSVImpl3 = new AttributePSVImpl();
                    augmentations.putItem(Constants.ATTRIBUTE_PSVI, attributePSVImpl3);
                    attributePSVImpl = attributePSVImpl3;
                }
                attributePSVImpl.fValidationContext = this.fValidationRoot;
            }
            org.apache.xerces.xni.QName qName2 = this.fTempQName;
            if (qName2.uri == SchemaSymbols.URI_XSI) {
                String str3 = qName2.localpart;
                if (str3 == SchemaSymbols.XSI_TYPE) {
                    xSAttributeDecl3 = XSI_TYPE;
                } else if (str3 == SchemaSymbols.XSI_NIL) {
                    xSAttributeDecl3 = XSI_NIL;
                } else if (str3 == SchemaSymbols.XSI_SCHEMALOCATION) {
                    xSAttributeDecl3 = XSI_SCHEMALOCATION;
                } else if (str3 == SchemaSymbols.XSI_NONAMESPACESCHEMALOCATION) {
                    xSAttributeDecl3 = XSI_NONAMESPACESCHEMALOCATION;
                } else {
                    xSAttributeDecl2 = null;
                    if (xSAttributeDecl2 != null) {
                        i3 = i5;
                        xSWildcardDecl3 = xSWildcardDecl;
                        i4 = i2;
                        xSObjectList3 = xSObjectList;
                        processOneAttribute(qName, xMLAttributes, i5, xSAttributeDecl2, null, attributePSVImpl);
                        xSWildcardDecl2 = xSWildcardDecl3;
                        xSObjectList2 = xSObjectList3;
                        i5 = i3 + 1;
                        xMLAttributes2 = xMLAttributes;
                        attributePSVImpl = attributePSVImpl;
                        xSObjectList = xSObjectList2;
                        i2 = i4;
                        xSWildcardDecl = xSWildcardDecl2;
                        c = 0;
                        c2 = 1;
                    }
                }
                xSAttributeDecl2 = xSAttributeDecl3;
                if (xSAttributeDecl2 != null) {
                }
            }
            i3 = i5;
            xSWildcardDecl3 = xSWildcardDecl;
            i4 = i2;
            xSObjectList3 = xSObjectList;
            String str4 = this.fTempQName.rawname;
            if (str4 != XMLSymbols.PREFIX_XMLNS && !str4.startsWith(Sax2Dom.XMLNS_STRING)) {
                if (z) {
                    Object[] objArr = new Object[2];
                    objArr[c] = qName.rawname;
                    objArr[1] = this.fTempQName.rawname;
                    reportSchemaError("cvc-type.3.1.1", objArr);
                } else {
                    int i7 = 0;
                    while (true) {
                        if (i7 < i4) {
                            xSObjectList4 = xSObjectList3;
                            XSAttributeUseImpl xSAttributeUseImpl2 = (XSAttributeUseImpl) xSObjectList4.item(i7);
                            XSAttributeDecl xSAttributeDecl4 = xSAttributeUseImpl2.fAttrDecl;
                            String str5 = xSAttributeDecl4.fName;
                            org.apache.xerces.xni.QName qName3 = this.fTempQName;
                            if (str5 == qName3.localpart && xSAttributeDecl4.fTargetNamespace == qName3.uri) {
                                xSAttributeUseImpl = xSAttributeUseImpl2;
                                break;
                            }
                            i7++;
                            xSObjectList3 = xSObjectList4;
                            xSWildcardDecl3 = xSWildcardDecl3;
                            i6 = 2;
                        } else {
                            xSAttributeUseImpl = null;
                            xSObjectList4 = xSObjectList3;
                            break;
                        }
                    }
                    if (xSAttributeUseImpl != null || (xSWildcardDecl3 != null && xSWildcardDecl3.allowNamespace(this.fTempQName.uri))) {
                        if (xSAttributeUseImpl != null) {
                            globalAttributeDecl = xSAttributeUseImpl.fAttrDecl;
                            xSObjectList5 = xSObjectList4;
                            xSWildcardDecl4 = xSWildcardDecl3;
                        } else if (xSWildcardDecl3.fProcessContents != i6) {
                            org.apache.xerces.xni.QName qName4 = this.fTempQName;
                            xSObjectList5 = xSObjectList4;
                            xSWildcardDecl4 = xSWildcardDecl3;
                            SchemaGrammar findSchemaGrammar = findSchemaGrammar(6, qName4.uri, qName, qName4, xMLAttributes);
                            globalAttributeDecl = findSchemaGrammar != null ? findSchemaGrammar.getGlobalAttributeDecl(this.fTempQName.localpart) : null;
                            if (globalAttributeDecl == null) {
                                if (xSWildcardDecl4.fProcessContents == 1) {
                                    reportSchemaError(XmlErrorCodes.ELEM_COMPLEX_TYPE_LOCALLY_VALID$NOT_WILDCARD_VALID, new Object[]{qName.rawname, this.fTempQName.rawname});
                                }
                                xSWildcardDecl2 = xSWildcardDecl4;
                                xSObjectList2 = xSObjectList5;
                                i5 = i3 + 1;
                                xMLAttributes2 = xMLAttributes;
                                attributePSVImpl = attributePSVImpl;
                                xSObjectList = xSObjectList2;
                                i2 = i4;
                                xSWildcardDecl = xSWildcardDecl2;
                                c = 0;
                                c2 = 1;
                            } else if (globalAttributeDecl.fType.getTypeCategory() == 16 && globalAttributeDecl.fType.isIDType()) {
                                if (str2 != null) {
                                    reportSchemaError("cvc-complex-type.5.1", new Object[]{qName.rawname, globalAttributeDecl.fName, str2});
                                } else {
                                    xSAttributeDecl = globalAttributeDecl;
                                    str2 = globalAttributeDecl.fName;
                                    xSWildcardDecl2 = xSWildcardDecl4;
                                    xSObjectList2 = xSObjectList5;
                                    processOneAttribute(qName, xMLAttributes, i3, xSAttributeDecl, xSAttributeUseImpl, attributePSVImpl);
                                    i5 = i3 + 1;
                                    xMLAttributes2 = xMLAttributes;
                                    attributePSVImpl = attributePSVImpl;
                                    xSObjectList = xSObjectList2;
                                    i2 = i4;
                                    xSWildcardDecl = xSWildcardDecl2;
                                    c = 0;
                                    c2 = 1;
                                }
                            }
                        }
                        xSAttributeDecl = globalAttributeDecl;
                        xSWildcardDecl2 = xSWildcardDecl4;
                        xSObjectList2 = xSObjectList5;
                        processOneAttribute(qName, xMLAttributes, i3, xSAttributeDecl, xSAttributeUseImpl, attributePSVImpl);
                        i5 = i3 + 1;
                        xMLAttributes2 = xMLAttributes;
                        attributePSVImpl = attributePSVImpl;
                        xSObjectList = xSObjectList2;
                        i2 = i4;
                        xSWildcardDecl = xSWildcardDecl2;
                        c = 0;
                        c2 = 1;
                    } else {
                        Object[] objArr2 = new Object[i6];
                        objArr2[0] = qName.rawname;
                        objArr2[1] = this.fTempQName.rawname;
                        reportSchemaError(XmlErrorCodes.ELEM_COMPLEX_TYPE_LOCALLY_VALID$NOT_WILDCARD_VALID, objArr2);
                        this.fNFullValidationDepth = this.fElementDepth;
                    }
                    xSWildcardDecl2 = xSWildcardDecl3;
                    xSObjectList2 = xSObjectList4;
                    i5 = i3 + 1;
                    xMLAttributes2 = xMLAttributes;
                    attributePSVImpl = attributePSVImpl;
                    xSObjectList = xSObjectList2;
                    i2 = i4;
                    xSWildcardDecl = xSWildcardDecl2;
                    c = 0;
                    c2 = 1;
                }
            }
            xSWildcardDecl2 = xSWildcardDecl3;
            xSObjectList2 = xSObjectList3;
            i5 = i3 + 1;
            xMLAttributes2 = xMLAttributes;
            attributePSVImpl = attributePSVImpl;
            xSObjectList = xSObjectList2;
            i2 = i4;
            xSWildcardDecl = xSWildcardDecl2;
            c = 0;
            c2 = 1;
        }
        if (!z && (str = xSAttributeGroupDecl.fIDAttrName) != null && str2 != null) {
            Object[] objArr3 = new Object[3];
            objArr3[c] = qName.rawname;
            objArr3[c2] = str2;
            objArr3[2] = str;
            reportSchemaError("cvc-complex-type.5.2", objArr3);
        }
    }

    public void processElementContent(org.apache.xerces.xni.QName qName) {
        ValidatedInfo validatedInfo;
        XSElementDecl xSElementDecl = this.fCurrentElemDecl;
        if (xSElementDecl != null && (validatedInfo = xSElementDecl.fDefault) != null && !this.fSawText && !this.fSubElement && !this.fNil) {
            String stringValue = validatedInfo.stringValue();
            int length = stringValue.length();
            char[] cArr = this.fNormalizedStr.ch;
            if (cArr == null || cArr.length < length) {
                this.fNormalizedStr.ch = new char[length];
            }
            stringValue.getChars(0, length, this.fNormalizedStr.ch, 0);
            XMLString xMLString = this.fNormalizedStr;
            xMLString.offset = 0;
            xMLString.length = length;
            this.fDefaultValue = xMLString;
        }
        this.fValidatedInfo.normalizedValue = null;
        if (this.fNil && (this.fSubElement || this.fSawText)) {
            StringBuffer stringBuffer = new StringBuffer();
            stringBuffer.append(SchemaSymbols.URI_XSI);
            stringBuffer.append(XSSFDataValidationConstraint.LIST_SEPARATOR);
            stringBuffer.append(SchemaSymbols.XSI_NIL);
            reportSchemaError(XmlErrorCodes.ELEM_LOCALLY_VALID$NIL_WITH_CONTENT, new Object[]{qName.rawname, stringBuffer.toString()});
        }
        this.fValidatedInfo.reset();
        XSElementDecl xSElementDecl2 = this.fCurrentElemDecl;
        if (xSElementDecl2 == null || xSElementDecl2.getConstraintType() == 0 || this.fSubElement || this.fSawText || this.fNil) {
            Object elementLocallyValidType = elementLocallyValidType(qName, this.fBuffer);
            XSElementDecl xSElementDecl3 = this.fCurrentElemDecl;
            if (xSElementDecl3 != null && xSElementDecl3.getConstraintType() == 2 && !this.fNil) {
                String stringBuffer2 = this.fBuffer.toString();
                if (this.fSubElement) {
                    reportSchemaError(XmlErrorCodes.ELEM_LOCALLY_VALID$FIXED_WITH_CONTENT, new Object[]{qName.rawname});
                }
                if (this.fCurrentType.getTypeCategory() == 15) {
                    short s = ((XSComplexTypeDecl) this.fCurrentType).fContentType;
                    if (s == 3) {
                        if (!this.fCurrentElemDecl.fDefault.normalizedValue.equals(stringBuffer2)) {
                            reportSchemaError(XmlErrorCodes.ELEM_LOCALLY_VALID$FIXED_VALID_MIXED_CONTENT, new Object[]{qName.rawname, stringBuffer2, this.fCurrentElemDecl.fDefault.normalizedValue});
                        }
                    } else if (s == 1 && elementLocallyValidType != null && (!ValidatedInfo.isComparable(this.fValidatedInfo, this.fCurrentElemDecl.fDefault) || !elementLocallyValidType.equals(this.fCurrentElemDecl.fDefault.actualValue))) {
                        reportSchemaError(XmlErrorCodes.ELEM_LOCALLY_VALID$FIXED_VALID_SIMPLE_TYPE, new Object[]{qName.rawname, stringBuffer2, this.fCurrentElemDecl.fDefault.stringValue()});
                    }
                } else if (this.fCurrentType.getTypeCategory() == 16 && elementLocallyValidType != null && (!ValidatedInfo.isComparable(this.fValidatedInfo, this.fCurrentElemDecl.fDefault) || !elementLocallyValidType.equals(this.fCurrentElemDecl.fDefault.actualValue))) {
                    reportSchemaError(XmlErrorCodes.ELEM_LOCALLY_VALID$FIXED_VALID_SIMPLE_TYPE, new Object[]{qName.rawname, stringBuffer2, this.fCurrentElemDecl.fDefault.stringValue()});
                }
            }
        } else {
            XSTypeDefinition xSTypeDefinition = this.fCurrentType;
            XSElementDecl xSElementDecl4 = this.fCurrentElemDecl;
            if (xSTypeDefinition != xSElementDecl4.fType && XSConstraints.ElementDefaultValidImmediate(xSTypeDefinition, xSElementDecl4.fDefault.stringValue(), this.fState4XsiType, null) == null) {
                reportSchemaError("cvc-elt.5.1.1", new Object[]{qName.rawname, this.fCurrentType.getName(), this.fCurrentElemDecl.fDefault.stringValue()});
            }
            elementLocallyValidType(qName, this.fCurrentElemDecl.fDefault.stringValue());
        }
        if (this.fDefaultValue == null && this.fNormalizeData && this.fDocumentHandler != null && this.fUnionType) {
            String str = this.fValidatedInfo.normalizedValue;
            if (str == null) {
                str = this.fBuffer.toString();
            }
            int length2 = str.length();
            char[] cArr2 = this.fNormalizedStr.ch;
            if (cArr2 == null || cArr2.length < length2) {
                this.fNormalizedStr.ch = new char[length2];
            }
            str.getChars(0, length2, this.fNormalizedStr.ch, 0);
            XMLString xMLString2 = this.fNormalizedStr;
            xMLString2.offset = 0;
            xMLString2.length = length2;
            this.fDocumentHandler.characters(xMLString2, null);
        }
    }

    public void processOneAttribute(org.apache.xerces.xni.QName qName, XMLAttributes xMLAttributes, int i2, XSAttributeDecl xSAttributeDecl, XSAttributeUseImpl xSAttributeUseImpl, AttributePSVImpl attributePSVImpl) {
        String value = xMLAttributes.getValue(i2);
        this.fXSIErrorReporter.pushContext();
        XSSimpleType xSSimpleType = xSAttributeDecl.fType;
        short s = 1;
        Object obj = null;
        try {
            obj = xSSimpleType.validate(value, (ValidationContext) this.fValidationState, this.fValidatedInfo);
            if (this.fNormalizeData) {
                xMLAttributes.setValue(i2, this.fValidatedInfo.normalizedValue);
            }
            if (xSSimpleType.getVariety() == 1 && xSSimpleType.getPrimitiveKind() == 20) {
                org.apache.xerces.xni.QName qName2 = (org.apache.xerces.xni.QName) obj;
                SchemaGrammar grammar = this.fGrammarBucket.getGrammar(qName2.uri);
                if (grammar != null) {
                    this.fNotation = grammar.getGlobalNotationDecl(qName2.localpart);
                }
            }
        } catch (InvalidDatatypeValueException e2) {
            reportSchemaError(e2.getKey(), e2.getArgs());
            Object[] objArr = new Object[4];
            objArr[0] = qName.rawname;
            objArr[1] = this.fTempQName.rawname;
            objArr[2] = value;
            objArr[3] = xSSimpleType instanceof XSSimpleTypeDecl ? ((XSSimpleTypeDecl) xSSimpleType).getTypeName() : xSSimpleType.getName();
            reportSchemaError("cvc-attribute.3", objArr);
        }
        if (obj != null && xSAttributeDecl.getConstraintType() == 2 && (!ValidatedInfo.isComparable(this.fValidatedInfo, xSAttributeDecl.fDefault) || !obj.equals(xSAttributeDecl.fDefault.actualValue))) {
            reportSchemaError(XmlErrorCodes.ATTR_LOCALLY_VALID$FIXED, new Object[]{qName.rawname, this.fTempQName.rawname, value, xSAttributeDecl.fDefault.stringValue()});
        }
        if (obj != null && xSAttributeUseImpl != null && xSAttributeUseImpl.fConstraintType == 2 && (!ValidatedInfo.isComparable(this.fValidatedInfo, xSAttributeUseImpl.fDefault) || !obj.equals(xSAttributeUseImpl.fDefault.actualValue))) {
            reportSchemaError(XmlErrorCodes.ELEM_COMPLEX_TYPE_LOCALLY_VALID$ATTRIBUTE_VALID, new Object[]{qName.rawname, this.fTempQName.rawname, value, xSAttributeUseImpl.fDefault.stringValue()});
        }
        if (this.fIdConstraint) {
            attributePSVImpl.fValue.copyFrom(this.fValidatedInfo);
        }
        if (this.fAugPSVI) {
            attributePSVImpl.fDeclaration = xSAttributeDecl;
            attributePSVImpl.fTypeDecl = xSSimpleType;
            attributePSVImpl.fValue.copyFrom(this.fValidatedInfo);
            attributePSVImpl.fValidationAttempted = 2;
            this.fNNoneValidationDepth = this.fElementDepth;
            String[] mergeContext = this.fXSIErrorReporter.mergeContext();
            attributePSVImpl.fErrors = mergeContext;
            if (mergeContext == null) {
                s = 2;
            }
            attributePSVImpl.fValidity = s;
        }
    }

    public void processRootElementDeclQName(QName qName, org.apache.xerces.xni.QName qName2) {
        String str;
        String namespaceURI = qName.getNamespaceURI();
        if (namespaceURI != null && namespaceURI.equals("")) {
            namespaceURI = null;
        }
        SchemaGrammar findSchemaGrammar = findSchemaGrammar(5, namespaceURI, null, null, null);
        if (findSchemaGrammar != null) {
            this.fCurrentElemDecl = findSchemaGrammar.getGlobalElementDecl(qName.getLocalPart());
        }
        XSElementDecl xSElementDecl = this.fCurrentElemDecl;
        if (xSElementDecl == null) {
            if (qName.getPrefix().equals("")) {
                str = qName.getLocalPart();
            } else {
                StringBuffer stringBuffer = new StringBuffer();
                stringBuffer.append(qName.getPrefix());
                stringBuffer.append(":");
                stringBuffer.append(qName.getLocalPart());
                str = stringBuffer.toString();
            }
            reportSchemaError("cvc-elt.1.a", new Object[]{str});
            return;
        }
        checkElementMatchesRootElementDecl(xSElementDecl, qName2);
    }

    /* JADX WARNING: Code restructure failed: missing block: B:10:0x002e, code lost:
        if (r0 != null) goto L_0x001a;
     */
    public void processRootTypeQName(QName qName) {
        String str;
        String namespaceURI = qName.getNamespaceURI();
        if (namespaceURI != null && namespaceURI.equals("")) {
            namespaceURI = null;
        }
        SchemaGrammar findSchemaGrammar = SchemaSymbols.URI_SCHEMAFORSCHEMA.equals(namespaceURI) ? SchemaGrammar.SG_SchemaNS : findSchemaGrammar(5, namespaceURI, null, null, null);
        this.fCurrentType = findSchemaGrammar.getGlobalTypeDecl(qName.getLocalPart());
        if (this.fCurrentType == null) {
            if (qName.getPrefix().equals("")) {
                str = qName.getLocalPart();
            } else {
                StringBuffer stringBuffer = new StringBuffer();
                stringBuffer.append(qName.getPrefix());
                stringBuffer.append(":");
                stringBuffer.append(qName.getLocalPart());
                str = stringBuffer.toString();
            }
            reportSchemaError("cvc-type.1", new Object[]{str});
        }
    }

    @Override // org.apache.xerces.xni.XMLDocumentHandler
    public void processingInstruction(String str, XMLString xMLString, Augmentations augmentations) {
        XMLDocumentHandler xMLDocumentHandler = this.fDocumentHandler;
        if (xMLDocumentHandler != null) {
            xMLDocumentHandler.processingInstruction(str, xMLString, augmentations);
        }
    }

    public void reportSchemaError(String str, Object[] objArr) {
        if (this.fDoValidation) {
            this.fXSIErrorReporter.reportError(XSMessageFormatter.SCHEMA_DOMAIN, str, objArr, 1);
        }
    }

    /* JADX WARNING: Removed duplicated region for block: B:81:0x014b A[Catch:{ XMLConfigurationException -> 0x0160 }] */
    /* JADX WARNING: Removed duplicated region for block: B:83:0x0150 A[Catch:{ XMLConfigurationException -> 0x0160 }] */
    /* JADX WARNING: Removed duplicated region for block: B:95:0x0170  */
    @Override // org.apache.xerces.xni.parser.XMLComponent
    public void reset(XMLComponentManager xMLComponentManager) {
        boolean z;
        boolean z2;
        Object property;
        int i2 = 0;
        this.fIdConstraint = false;
        this.fLocationPairs.clear();
        this.fExpandedLocationPairs.clear();
        this.fValidationState.resetIDTables();
        this.fSchemaLoader.reset(xMLComponentManager);
        this.fCurrentElemDecl = null;
        this.fCurrentCM = null;
        this.fCurrCMState = null;
        this.fSkipValidationDepth = -1;
        this.fNFullValidationDepth = -1;
        this.fNNoneValidationDepth = -1;
        this.fElementDepth = -1;
        this.fSubElement = false;
        this.fSchemaDynamicValidation = false;
        this.fEntityRef = false;
        this.fInCDATA = false;
        this.fMatcherStack.clear();
        this.fXSIErrorReporter.reset((XMLErrorReporter) xMLComponentManager.getProperty("http://apache.org/xml/properties/internal/error-reporter"));
        try {
            z = xMLComponentManager.getFeature("http://apache.org/xml/features/internal/parser-settings");
        } catch (XMLConfigurationException unused) {
            z = true;
        }
        if (!z) {
            this.fValidationManager.addValidationState(this.fValidationState);
            this.nodeFactory.reset();
            XMLSchemaLoader.processExternalHints(this.fExternalSchemas, this.fExternalNoNamespaceSchema, this.fLocationPairs, this.fXSIErrorReporter.fErrorReporter);
            return;
        }
        this.nodeFactory.reset(xMLComponentManager);
        SymbolTable symbolTable = (SymbolTable) xMLComponentManager.getProperty("http://apache.org/xml/properties/internal/symbol-table");
        if (symbolTable != this.fSymbolTable) {
            this.fSymbolTable = symbolTable;
        }
        try {
            this.fNamespaceGrowth = xMLComponentManager.getFeature("http://apache.org/xml/features/namespace-growth");
        } catch (XMLConfigurationException unused2) {
            this.fNamespaceGrowth = false;
        }
        try {
            this.fDynamicValidation = xMLComponentManager.getFeature("http://apache.org/xml/features/validation/dynamic");
        } catch (XMLConfigurationException unused3) {
            this.fDynamicValidation = false;
        }
        if (this.fDynamicValidation) {
            this.fDoValidation = true;
        } else {
            try {
                this.fDoValidation = xMLComponentManager.getFeature("http://xml.org/sax/features/validation");
            } catch (XMLConfigurationException unused4) {
                this.fDoValidation = false;
            }
        }
        if (this.fDoValidation) {
            try {
                this.fDoValidation = xMLComponentManager.getFeature("http://apache.org/xml/features/validation/schema");
            } catch (XMLConfigurationException unused5) {
            }
        }
        try {
            this.fFullChecking = xMLComponentManager.getFeature("http://apache.org/xml/features/validation/schema-full-checking");
        } catch (XMLConfigurationException unused6) {
            this.fFullChecking = false;
        }
        try {
            this.fNormalizeData = xMLComponentManager.getFeature("http://apache.org/xml/features/validation/schema/normalized-value");
        } catch (XMLConfigurationException unused7) {
            this.fNormalizeData = false;
        }
        try {
            this.fSchemaElementDefault = xMLComponentManager.getFeature("http://apache.org/xml/features/validation/schema/element-default");
        } catch (XMLConfigurationException unused8) {
            this.fSchemaElementDefault = false;
        }
        try {
            this.fAugPSVI = xMLComponentManager.getFeature("http://apache.org/xml/features/validation/schema/augment-psvi");
        } catch (XMLConfigurationException unused9) {
            this.fAugPSVI = true;
        }
        try {
            this.fSchemaType = (String) xMLComponentManager.getProperty("http://java.sun.com/xml/jaxp/properties/schemaLanguage");
        } catch (XMLConfigurationException unused10) {
            this.fSchemaType = null;
        }
        try {
            this.fUseGrammarPoolOnly = xMLComponentManager.getFeature("http://apache.org/xml/features/internal/validation/schema/use-grammar-pool-only");
        } catch (XMLConfigurationException unused11) {
            this.fUseGrammarPoolOnly = false;
        }
        this.fEntityResolver = (XMLEntityResolver) xMLComponentManager.getProperty("http://apache.org/xml/properties/internal/entity-manager");
        ValidationManager validationManager = (ValidationManager) xMLComponentManager.getProperty("http://apache.org/xml/properties/internal/validation-manager");
        this.fValidationManager = validationManager;
        validationManager.addValidationState(this.fValidationState);
        this.fValidationState.setSymbolTable(this.fSymbolTable);
        try {
            Object property2 = xMLComponentManager.getProperty("http://apache.org/xml/properties/validation/schema/root-type-definition");
            if (property2 == null) {
                this.fRootTypeQName = null;
            } else if (property2 instanceof QName) {
                this.fRootTypeQName = (QName) property2;
            } else {
                this.fRootTypeDefinition = (XSTypeDefinition) property2;
                this.fRootTypeQName = null;
                property = xMLComponentManager.getProperty("http://apache.org/xml/properties/validation/schema/root-element-declaration");
                if (property != null) {
                    this.fRootElementDeclQName = null;
                } else if (property instanceof QName) {
                    this.fRootElementDeclQName = (QName) property;
                } else {
                    this.fRootElementDeclaration = (XSElementDecl) property;
                    this.fRootElementDeclQName = null;
                    z2 = xMLComponentManager.getFeature("http://apache.org/xml/features/validation/schema/ignore-xsi-type-until-elemdecl");
                    if (!z2) {
                        i2 = -1;
                    }
                    this.fIgnoreXSITypeDepth = i2;
                    this.fIDCChecking = xMLComponentManager.getFeature("http://apache.org/xml/features/validation/identity-constraint-checking");
                    this.fValidationState.setIdIdrefChecking(xMLComponentManager.getFeature("http://apache.org/xml/features/validation/id-idref-checking"));
                    this.fValidationState.setUnparsedEntityChecking(xMLComponentManager.getFeature("http://apache.org/xml/features/validation/unparsed-entity-checking"));
                    this.fExternalSchemas = (String) xMLComponentManager.getProperty("http://apache.org/xml/properties/schema/external-schemaLocation");
                    this.fExternalNoNamespaceSchema = (String) xMLComponentManager.getProperty("http://apache.org/xml/properties/schema/external-noNamespaceSchemaLocation");
                    XMLSchemaLoader.processExternalHints(this.fExternalSchemas, this.fExternalNoNamespaceSchema, this.fLocationPairs, this.fXSIErrorReporter.fErrorReporter);
                    this.fJaxpSchemaSource = xMLComponentManager.getProperty("http://java.sun.com/xml/jaxp/properties/schemaSource");
                    this.fGrammarPool = (XMLGrammarPool) xMLComponentManager.getProperty("http://apache.org/xml/properties/internal/grammar-pool");
                    this.fState4XsiType.setSymbolTable(symbolTable);
                    this.fState4ApplyDefault.setSymbolTable(symbolTable);
                }
                this.fRootElementDeclaration = null;
                z2 = xMLComponentManager.getFeature("http://apache.org/xml/features/validation/schema/ignore-xsi-type-until-elemdecl");
                if (!z2) {
                }
                this.fIgnoreXSITypeDepth = i2;
                this.fIDCChecking = xMLComponentManager.getFeature("http://apache.org/xml/features/validation/identity-constraint-checking");
                this.fValidationState.setIdIdrefChecking(xMLComponentManager.getFeature("http://apache.org/xml/features/validation/id-idref-checking"));
                this.fValidationState.setUnparsedEntityChecking(xMLComponentManager.getFeature("http://apache.org/xml/features/validation/unparsed-entity-checking"));
                this.fExternalSchemas = (String) xMLComponentManager.getProperty("http://apache.org/xml/properties/schema/external-schemaLocation");
                this.fExternalNoNamespaceSchema = (String) xMLComponentManager.getProperty("http://apache.org/xml/properties/schema/external-noNamespaceSchemaLocation");
                XMLSchemaLoader.processExternalHints(this.fExternalSchemas, this.fExternalNoNamespaceSchema, this.fLocationPairs, this.fXSIErrorReporter.fErrorReporter);
                this.fJaxpSchemaSource = xMLComponentManager.getProperty("http://java.sun.com/xml/jaxp/properties/schemaSource");
                this.fGrammarPool = (XMLGrammarPool) xMLComponentManager.getProperty("http://apache.org/xml/properties/internal/grammar-pool");
                this.fState4XsiType.setSymbolTable(symbolTable);
                this.fState4ApplyDefault.setSymbolTable(symbolTable);
            }
            this.fRootTypeDefinition = null;
        } catch (XMLConfigurationException unused12) {
            this.fRootTypeQName = null;
            this.fRootTypeDefinition = null;
        }
        try {
            property = xMLComponentManager.getProperty("http://apache.org/xml/properties/validation/schema/root-element-declaration");
            if (property != null) {
            }
            this.fRootElementDeclaration = null;
        } catch (XMLConfigurationException unused13) {
            this.fRootElementDeclQName = null;
            this.fRootElementDeclaration = null;
        }
        try {
            z2 = xMLComponentManager.getFeature("http://apache.org/xml/features/validation/schema/ignore-xsi-type-until-elemdecl");
        } catch (XMLConfigurationException unused14) {
            z2 = false;
        }
        if (!z2) {
        }
        this.fIgnoreXSITypeDepth = i2;
        try {
            this.fIDCChecking = xMLComponentManager.getFeature("http://apache.org/xml/features/validation/identity-constraint-checking");
        } catch (XMLConfigurationException unused15) {
            this.fIDCChecking = true;
        }
        try {
            this.fValidationState.setIdIdrefChecking(xMLComponentManager.getFeature("http://apache.org/xml/features/validation/id-idref-checking"));
        } catch (XMLConfigurationException unused16) {
            this.fValidationState.setIdIdrefChecking(true);
        }
        try {
            this.fValidationState.setUnparsedEntityChecking(xMLComponentManager.getFeature("http://apache.org/xml/features/validation/unparsed-entity-checking"));
        } catch (XMLConfigurationException unused17) {
            this.fValidationState.setUnparsedEntityChecking(true);
        }
        try {
            this.fExternalSchemas = (String) xMLComponentManager.getProperty("http://apache.org/xml/properties/schema/external-schemaLocation");
            this.fExternalNoNamespaceSchema = (String) xMLComponentManager.getProperty("http://apache.org/xml/properties/schema/external-noNamespaceSchemaLocation");
        } catch (XMLConfigurationException unused18) {
            this.fExternalSchemas = null;
            this.fExternalNoNamespaceSchema = null;
        }
        XMLSchemaLoader.processExternalHints(this.fExternalSchemas, this.fExternalNoNamespaceSchema, this.fLocationPairs, this.fXSIErrorReporter.fErrorReporter);
        try {
            this.fJaxpSchemaSource = xMLComponentManager.getProperty("http://java.sun.com/xml/jaxp/properties/schemaSource");
        } catch (XMLConfigurationException unused19) {
            this.fJaxpSchemaSource = null;
        }
        try {
            this.fGrammarPool = (XMLGrammarPool) xMLComponentManager.getProperty("http://apache.org/xml/properties/internal/grammar-pool");
        } catch (XMLConfigurationException unused20) {
            this.fGrammarPool = null;
        }
        this.fState4XsiType.setSymbolTable(symbolTable);
        this.fState4ApplyDefault.setSymbolTable(symbolTable);
    }

    @Override // org.apache.xerces.xni.parser.XMLDocumentSource
    public void setDocumentHandler(XMLDocumentHandler xMLDocumentHandler) {
        this.fDocumentHandler = xMLDocumentHandler;
    }

    @Override // org.apache.xerces.xni.XMLDocumentHandler
    public void setDocumentSource(XMLDocumentSource xMLDocumentSource) {
        this.fDocumentSource = xMLDocumentSource;
    }

    @Override // org.apache.xerces.xni.parser.XMLComponent
    public void setFeature(String str, boolean z) {
    }

    @Override // org.apache.xerces.xni.parser.XMLComponent
    public void setProperty(String str, Object obj) {
        if (str.equals("http://apache.org/xml/properties/validation/schema/root-type-definition")) {
            if (obj == null) {
                this.fRootTypeQName = null;
            } else if (obj instanceof QName) {
                this.fRootTypeQName = (QName) obj;
            } else {
                this.fRootTypeDefinition = (XSTypeDefinition) obj;
                this.fRootTypeQName = null;
                return;
            }
            this.fRootTypeDefinition = null;
        } else if (str.equals("http://apache.org/xml/properties/validation/schema/root-element-declaration")) {
            if (obj == null) {
                this.fRootElementDeclQName = null;
            } else if (obj instanceof QName) {
                this.fRootElementDeclQName = (QName) obj;
            } else {
                this.fRootElementDeclaration = (XSElementDecl) obj;
                this.fRootElementDeclQName = null;
                return;
            }
            this.fRootElementDeclaration = null;
        }
    }

    @Override // org.apache.xerces.xni.XMLDocumentHandler
    public void startCDATA(Augmentations augmentations) {
        this.fInCDATA = true;
        XMLDocumentHandler xMLDocumentHandler = this.fDocumentHandler;
        if (xMLDocumentHandler != null) {
            xMLDocumentHandler.startCDATA(augmentations);
        }
    }

    @Override // org.apache.xerces.xni.XMLDocumentHandler
    public void startDocument(XMLLocator xMLLocator, String str, NamespaceContext namespaceContext, Augmentations augmentations) {
        this.fValidationState.setNamespaceSupport(namespaceContext);
        this.fState4XsiType.setNamespaceSupport(namespaceContext);
        this.fState4ApplyDefault.setNamespaceSupport(namespaceContext);
        this.fLocator = xMLLocator;
        handleStartDocument(xMLLocator, str);
        XMLDocumentHandler xMLDocumentHandler = this.fDocumentHandler;
        if (xMLDocumentHandler != null) {
            xMLDocumentHandler.startDocument(xMLLocator, str, namespaceContext, augmentations);
        }
    }

    @Override // org.apache.xerces.xni.XMLDocumentHandler
    public void startElement(org.apache.xerces.xni.QName qName, XMLAttributes xMLAttributes, Augmentations augmentations) {
        Augmentations handleStartElement = handleStartElement(qName, xMLAttributes, augmentations);
        XMLDocumentHandler xMLDocumentHandler = this.fDocumentHandler;
        if (xMLDocumentHandler != null) {
            xMLDocumentHandler.startElement(qName, xMLAttributes, handleStartElement);
        }
    }

    @Override // org.apache.xerces.xni.XMLDocumentHandler
    public void startGeneralEntity(String str, XMLResourceIdentifier xMLResourceIdentifier, String str2, Augmentations augmentations) {
        this.fEntityRef = true;
        XMLDocumentHandler xMLDocumentHandler = this.fDocumentHandler;
        if (xMLDocumentHandler != null) {
            xMLDocumentHandler.startGeneralEntity(str, xMLResourceIdentifier, str2, augmentations);
        }
    }

    @Override // org.apache.xerces.impl.xs.identity.FieldActivator
    public void startValueScopeFor(IdentityConstraint identityConstraint, int i2) {
        this.fValueStoreCache.getValueStoreFor(identityConstraint, i2).startValueScope();
    }

    public void storeLocations(String str, String str2) {
        if (str != null) {
            Hashtable hashtable = this.fLocationPairs;
            XMLLocator xMLLocator = this.fLocator;
            if (!XMLSchemaLoader.tokenizeSchemaLocationStr(str, hashtable, xMLLocator == null ? null : xMLLocator.getExpandedSystemId())) {
                this.fXSIErrorReporter.reportError(XSMessageFormatter.SCHEMA_DOMAIN, "SchemaLocation", new Object[]{str}, 0);
            }
        }
        if (str2 != null) {
            XMLSchemaLoader.LocationArray locationArray = (XMLSchemaLoader.LocationArray) this.fLocationPairs.get(XMLSymbols.EMPTY_STRING);
            if (locationArray == null) {
                locationArray = new XMLSchemaLoader.LocationArray();
                this.fLocationPairs.put(XMLSymbols.EMPTY_STRING, locationArray);
            }
            XMLLocator xMLLocator2 = this.fLocator;
            if (xMLLocator2 != null) {
                try {
                    str2 = XMLEntityManager.expandSystemId(str2, xMLLocator2.getExpandedSystemId(), false);
                } catch (URI.MalformedURIException unused) {
                }
            }
            locationArray.addLocation(str2);
        }
    }

    @Override // org.apache.xerces.xni.XMLDocumentHandler
    public void textDecl(String str, String str2, Augmentations augmentations) {
        XMLDocumentHandler xMLDocumentHandler = this.fDocumentHandler;
        if (xMLDocumentHandler != null) {
            xMLDocumentHandler.textDecl(str, str2, augmentations);
        }
    }

    @Override // org.apache.xerces.xni.XMLDocumentHandler
    public void xmlDecl(String str, String str2, String str3, Augmentations augmentations) {
        XMLDocumentHandler xMLDocumentHandler = this.fDocumentHandler;
        if (xMLDocumentHandler != null) {
            xMLDocumentHandler.xmlDecl(str, str2, str3, augmentations);
        }
    }
}
