package org.apache.xerces.impl.xs;

import org.apache.xerces.impl.dv.ValidatedInfo;
import org.apache.xerces.impl.dv.XSSimpleType;
import org.apache.xerces.impl.xs.util.XSObjectListImpl;
import org.apache.xerces.xs.XSAnnotation;
import org.apache.xerces.xs.XSAttributeGroupDefinition;
import org.apache.xerces.xs.XSAttributeUse;
import org.apache.xerces.xs.XSNamespaceItem;
import org.apache.xerces.xs.XSObjectList;
import org.apache.xerces.xs.XSWildcard;
import org.apache.xmlbeans.XmlErrorCodes;

public class XSAttributeGroupDecl implements XSAttributeGroupDefinition {
    public static final int INITIAL_SIZE = 5;
    public XSObjectList fAnnotations;
    public int fAttrUseNum = 0;
    public XSObjectListImpl fAttrUses = null;
    public XSAttributeUseImpl[] fAttributeUses = new XSAttributeUseImpl[5];
    public XSWildcardDecl fAttributeWC = null;
    public String fIDAttrName = null;
    public String fName = null;
    public XSNamespaceItem fNamespaceItem = null;
    public String fTargetNamespace = null;

    public static final XSAttributeUseImpl[] resize(XSAttributeUseImpl[] xSAttributeUseImplArr, int i2) {
        XSAttributeUseImpl[] xSAttributeUseImplArr2 = new XSAttributeUseImpl[i2];
        System.arraycopy(xSAttributeUseImplArr, 0, xSAttributeUseImplArr2, 0, Math.min(xSAttributeUseImplArr.length, i2));
        return xSAttributeUseImplArr2;
    }

    public String addAttributeUse(XSAttributeUseImpl xSAttributeUseImpl) {
        if (xSAttributeUseImpl.fUse != 2 && xSAttributeUseImpl.fAttrDecl.fType.isIDType()) {
            String str = this.fIDAttrName;
            if (str != null) {
                return str;
            }
            this.fIDAttrName = xSAttributeUseImpl.fAttrDecl.fName;
        }
        int i2 = this.fAttrUseNum;
        XSAttributeUseImpl[] xSAttributeUseImplArr = this.fAttributeUses;
        if (i2 == xSAttributeUseImplArr.length) {
            this.fAttributeUses = resize(xSAttributeUseImplArr, i2 * 2);
        }
        XSAttributeUseImpl[] xSAttributeUseImplArr2 = this.fAttributeUses;
        int i3 = this.fAttrUseNum;
        this.fAttrUseNum = i3 + 1;
        xSAttributeUseImplArr2[i3] = xSAttributeUseImpl;
        return null;
    }

    @Override // org.apache.xerces.xs.XSAttributeGroupDefinition
    public XSAnnotation getAnnotation() {
        XSObjectList xSObjectList = this.fAnnotations;
        if (xSObjectList != null) {
            return (XSAnnotation) xSObjectList.item(0);
        }
        return null;
    }

    @Override // org.apache.xerces.xs.XSAttributeGroupDefinition
    public XSObjectList getAnnotations() {
        XSObjectList xSObjectList = this.fAnnotations;
        return xSObjectList != null ? xSObjectList : XSObjectListImpl.EMPTY_LIST;
    }

    public XSAttributeUse getAttributeUse(String str, String str2) {
        for (int i2 = 0; i2 < this.fAttrUseNum; i2++) {
            XSAttributeUseImpl[] xSAttributeUseImplArr = this.fAttributeUses;
            if (xSAttributeUseImplArr[i2].fAttrDecl.fTargetNamespace == str && xSAttributeUseImplArr[i2].fAttrDecl.fName == str2) {
                return xSAttributeUseImplArr[i2];
            }
        }
        return null;
    }

    public XSAttributeUse getAttributeUseNoProhibited(String str, String str2) {
        for (int i2 = 0; i2 < this.fAttrUseNum; i2++) {
            XSAttributeUseImpl[] xSAttributeUseImplArr = this.fAttributeUses;
            if (xSAttributeUseImplArr[i2].fAttrDecl.fTargetNamespace == str && xSAttributeUseImplArr[i2].fAttrDecl.fName == str2 && xSAttributeUseImplArr[i2].fUse != 2) {
                return xSAttributeUseImplArr[i2];
            }
        }
        return null;
    }

    @Override // org.apache.xerces.xs.XSAttributeGroupDefinition
    public XSObjectList getAttributeUses() {
        if (this.fAttrUses == null) {
            this.fAttrUses = new XSObjectListImpl(this.fAttributeUses, this.fAttrUseNum);
        }
        return this.fAttrUses;
    }

    @Override // org.apache.xerces.xs.XSAttributeGroupDefinition
    public XSWildcard getAttributeWildcard() {
        return this.fAttributeWC;
    }

    @Override // org.apache.xerces.xs.XSObject
    public String getName() {
        return this.fName;
    }

    @Override // org.apache.xerces.xs.XSObject
    public String getNamespace() {
        return this.fTargetNamespace;
    }

    @Override // org.apache.xerces.xs.XSObject
    public XSNamespaceItem getNamespaceItem() {
        return this.fNamespaceItem;
    }

    @Override // org.apache.xerces.xs.XSObject
    public short getType() {
        return 5;
    }

    public void removeProhibitedAttrs() {
        int i2 = this.fAttrUseNum;
        if (i2 != 0) {
            XSAttributeUseImpl[] xSAttributeUseImplArr = new XSAttributeUseImpl[i2];
            int i3 = 0;
            for (int i4 = 0; i4 < this.fAttrUseNum; i4++) {
                XSAttributeUseImpl[] xSAttributeUseImplArr2 = this.fAttributeUses;
                if (xSAttributeUseImplArr2[i4].fUse != 2) {
                    xSAttributeUseImplArr[i3] = xSAttributeUseImplArr2[i4];
                    i3++;
                }
            }
            this.fAttributeUses = xSAttributeUseImplArr;
            this.fAttrUseNum = i3;
        }
    }

    public void replaceAttributeUse(XSAttributeUse xSAttributeUse, XSAttributeUseImpl xSAttributeUseImpl) {
        for (int i2 = 0; i2 < this.fAttrUseNum; i2++) {
            XSAttributeUseImpl[] xSAttributeUseImplArr = this.fAttributeUses;
            if (xSAttributeUseImplArr[i2] == xSAttributeUse) {
                xSAttributeUseImplArr[i2] = xSAttributeUseImpl;
            }
        }
    }

    public void reset() {
        this.fName = null;
        this.fTargetNamespace = null;
        for (int i2 = 0; i2 < this.fAttrUseNum; i2++) {
            this.fAttributeUses[i2] = null;
        }
        this.fAttrUseNum = 0;
        this.fAttributeWC = null;
        this.fAnnotations = null;
        this.fIDAttrName = null;
    }

    public void setNamespaceItem(XSNamespaceItem xSNamespaceItem) {
        this.fNamespaceItem = xSNamespaceItem;
    }

    public Object[] validRestrictionOf(String str, XSAttributeGroupDecl xSAttributeGroupDecl) {
        for (int i2 = 0; i2 < this.fAttrUseNum; i2++) {
            XSAttributeUseImpl xSAttributeUseImpl = this.fAttributeUses[i2];
            XSAttributeDecl xSAttributeDecl = xSAttributeUseImpl.fAttrDecl;
            XSAttributeUseImpl xSAttributeUseImpl2 = (XSAttributeUseImpl) xSAttributeGroupDecl.getAttributeUse(xSAttributeDecl.fTargetNamespace, xSAttributeDecl.fName);
            if (xSAttributeUseImpl2 == null) {
                XSWildcardDecl xSWildcardDecl = xSAttributeGroupDecl.fAttributeWC;
                if (xSWildcardDecl == null) {
                    return new Object[]{str, xSAttributeDecl.fName, "derivation-ok-restriction.2.2.a"};
                } else if (!xSWildcardDecl.allowNamespace(xSAttributeDecl.fTargetNamespace)) {
                    Object[] objArr = new Object[4];
                    objArr[0] = str;
                    objArr[1] = xSAttributeDecl.fName;
                    String str2 = xSAttributeDecl.fTargetNamespace;
                    if (str2 == null) {
                        str2 = "";
                    }
                    objArr[2] = str2;
                    objArr[3] = "derivation-ok-restriction.2.2.b";
                    return objArr;
                }
            } else if (xSAttributeUseImpl2.getRequired() && !xSAttributeUseImpl.getRequired()) {
                Object[] objArr2 = new Object[4];
                objArr2[0] = str;
                objArr2[1] = xSAttributeDecl.fName;
                objArr2[2] = xSAttributeUseImpl.fUse == 0 ? SchemaSymbols.ATTVAL_OPTIONAL : SchemaSymbols.ATTVAL_PROHIBITED;
                objArr2[3] = XmlErrorCodes.COMPLEX_TYPE_RESTRICTION$ATTR_REQUIRED;
                return objArr2;
            } else if (xSAttributeUseImpl.fUse == 2) {
                continue;
            } else {
                XSAttributeDecl xSAttributeDecl2 = xSAttributeUseImpl2.fAttrDecl;
                XSSimpleType xSSimpleType = xSAttributeDecl.fType;
                XSSimpleType xSSimpleType2 = xSAttributeDecl2.fType;
                if (!XSConstraints.checkSimpleDerivationOk(xSSimpleType, xSSimpleType2, xSSimpleType2.getFinal())) {
                    return new Object[]{str, xSAttributeDecl.fName, xSAttributeDecl.fType.getName(), xSAttributeDecl2.fType.getName(), "derivation-ok-restriction.2.1.2"};
                }
                short s = xSAttributeUseImpl2.fConstraintType;
                if (s == 0) {
                    s = xSAttributeDecl2.getConstraintType();
                }
                short s2 = xSAttributeUseImpl.fConstraintType;
                if (s2 == 0) {
                    s2 = xSAttributeDecl.getConstraintType();
                }
                if (s != 2) {
                    continue;
                } else if (s2 != 2) {
                    return new Object[]{str, xSAttributeDecl.fName, "derivation-ok-restriction.2.1.3.a"};
                } else {
                    ValidatedInfo validatedInfo = xSAttributeUseImpl2.fDefault;
                    if (validatedInfo == null) {
                        validatedInfo = xSAttributeDecl2.fDefault;
                    }
                    ValidatedInfo validatedInfo2 = xSAttributeUseImpl.fDefault;
                    if (validatedInfo2 == null) {
                        validatedInfo2 = xSAttributeDecl.fDefault;
                    }
                    if (!validatedInfo.actualValue.equals(validatedInfo2.actualValue)) {
                        return new Object[]{str, xSAttributeDecl.fName, validatedInfo2.stringValue(), validatedInfo.stringValue(), "derivation-ok-restriction.2.1.3.b"};
                    }
                }
            }
        }
        for (int i3 = 0; i3 < xSAttributeGroupDecl.fAttrUseNum; i3++) {
            XSAttributeUseImpl xSAttributeUseImpl3 = xSAttributeGroupDecl.fAttributeUses[i3];
            if (xSAttributeUseImpl3.fUse == 1) {
                XSAttributeDecl xSAttributeDecl3 = xSAttributeUseImpl3.fAttrDecl;
                if (getAttributeUse(xSAttributeDecl3.fTargetNamespace, xSAttributeDecl3.fName) == null) {
                    return new Object[]{str, xSAttributeUseImpl3.fAttrDecl.fName, "derivation-ok-restriction.3"};
                }
            }
        }
        XSWildcardDecl xSWildcardDecl2 = this.fAttributeWC;
        if (xSWildcardDecl2 == null) {
            return null;
        }
        XSWildcardDecl xSWildcardDecl3 = xSAttributeGroupDecl.fAttributeWC;
        if (xSWildcardDecl3 == null) {
            return new Object[]{str, XmlErrorCodes.COMPLEX_TYPE_RESTRICTION$BASE_HAS_ATTR_WILDCARD};
        } else if (!xSWildcardDecl2.isSubsetOf(xSWildcardDecl3)) {
            return new Object[]{str, XmlErrorCodes.COMPLEX_TYPE_RESTRICTION$ATTR_WILDCARD_SUBSET};
        } else if (!this.fAttributeWC.weakerProcessContents(xSAttributeGroupDecl.fAttributeWC)) {
            return null;
        } else {
            return new Object[]{str, this.fAttributeWC.getProcessContentsAsString(), xSAttributeGroupDecl.fAttributeWC.getProcessContentsAsString(), "derivation-ok-restriction.4.3"};
        }
    }
}
