package org.apache.xerces.impl.xs;

import java.util.Collections;
import java.util.Comparator;
import java.util.Vector;
import org.apache.poi.xssf.usermodel.XSSFDataValidationConstraint;
import org.apache.xerces.impl.XMLErrorReporter;
import org.apache.xerces.impl.dv.InvalidDatatypeValueException;
import org.apache.xerces.impl.dv.ValidatedInfo;
import org.apache.xerces.impl.dv.ValidationContext;
import org.apache.xerces.impl.dv.XSSimpleType;
import org.apache.xerces.impl.xs.models.CMBuilder;
import org.apache.xerces.impl.xs.models.XSCMValidator;
import org.apache.xerces.impl.xs.util.SimpleLocator;
import org.apache.xerces.impl.xs.util.XSObjectListImpl;
import org.apache.xerces.util.SymbolHash;
import org.apache.xerces.xni.XMLLocator;
import org.apache.xerces.xs.XSObjectList;
import org.apache.xerces.xs.XSTerm;
import org.apache.xerces.xs.XSTypeDefinition;
import org.apache.xmlbeans.XmlErrorCodes;

public class XSConstraints {
    public static final Comparator ELEMENT_PARTICLE_COMPARATOR = new Comparator() {
        /* class org.apache.xerces.impl.xs.XSConstraints.AnonymousClass1 */

        @Override // java.util.Comparator
        public int compare(Object obj, Object obj2) {
            XSElementDecl xSElementDecl = (XSElementDecl) ((XSParticleDecl) obj).fValue;
            XSElementDecl xSElementDecl2 = (XSElementDecl) ((XSParticleDecl) obj2).fValue;
            String namespace = xSElementDecl.getNamespace();
            String namespace2 = xSElementDecl2.getNamespace();
            String name = xSElementDecl.getName();
            String name2 = xSElementDecl2.getName();
            int i2 = 1;
            if (namespace == namespace2) {
                i2 = 0;
            } else if (namespace == null) {
                i2 = -1;
            } else if (namespace2 != null) {
                i2 = namespace.compareTo(namespace2);
            }
            return i2 != 0 ? i2 : name.compareTo(name2);
        }
    };
    public static final int OCCURRENCE_UNKNOWN = -2;
    public static final XSSimpleType STRING_TYPE = ((XSSimpleType) SchemaGrammar.SG_SchemaNS.getGlobalTypeDecl(SchemaSymbols.ATTVAL_STRING));
    public static XSParticleDecl fEmptyParticle = null;

    public static Object ElementDefaultValidImmediate(XSTypeDefinition xSTypeDefinition, String str, ValidationContext validationContext, ValidatedInfo validatedInfo) {
        XSSimpleType xSSimpleType;
        if (xSTypeDefinition.getTypeCategory() == 16) {
            xSSimpleType = (XSSimpleType) xSTypeDefinition;
        } else {
            XSComplexTypeDecl xSComplexTypeDecl = (XSComplexTypeDecl) xSTypeDefinition;
            short s = xSComplexTypeDecl.fContentType;
            if (s == 1) {
                xSSimpleType = xSComplexTypeDecl.fXSSimpleType;
            } else if (s != 3 || !((XSParticleDecl) xSComplexTypeDecl.getParticle()).emptiable()) {
                return null;
            } else {
                xSSimpleType = null;
            }
        }
        if (xSSimpleType == null) {
            xSSimpleType = STRING_TYPE;
        }
        try {
            return validatedInfo != null ? xSSimpleType.validate(validatedInfo.stringValue(), validationContext, validatedInfo) : xSSimpleType.validate(str, validationContext, validatedInfo);
        } catch (InvalidDatatypeValueException unused) {
            return null;
        }
    }

    public static void addElementToParticleVector(Vector vector, XSElementDecl xSElementDecl) {
        XSParticleDecl xSParticleDecl = new XSParticleDecl();
        xSParticleDecl.fValue = xSElementDecl;
        xSParticleDecl.fType = 1;
        vector.addElement(xSParticleDecl);
    }

    public static boolean checkComplexDerivation(XSComplexTypeDecl xSComplexTypeDecl, XSTypeDefinition xSTypeDefinition, short s) {
        if (xSComplexTypeDecl == xSTypeDefinition) {
            return true;
        }
        if ((xSComplexTypeDecl.fDerivedBy & s) != 0) {
            return false;
        }
        XSTypeDefinition xSTypeDefinition2 = xSComplexTypeDecl.fBaseType;
        if (xSTypeDefinition2 == xSTypeDefinition) {
            return true;
        }
        if (!(xSTypeDefinition2 == SchemaGrammar.fAnyType || xSTypeDefinition2 == SchemaGrammar.fAnySimpleType)) {
            if (xSTypeDefinition2.getTypeCategory() == 15) {
                return checkComplexDerivation((XSComplexTypeDecl) xSTypeDefinition2, xSTypeDefinition, s);
            }
            if (xSTypeDefinition2.getTypeCategory() == 16) {
                if (xSTypeDefinition.getTypeCategory() == 15) {
                    if (xSTypeDefinition != SchemaGrammar.fAnyType) {
                        return false;
                    }
                    xSTypeDefinition = SchemaGrammar.fAnySimpleType;
                }
                return checkSimpleDerivation((XSSimpleType) xSTypeDefinition2, (XSSimpleType) xSTypeDefinition, s);
            }
        }
        return false;
    }

    public static boolean checkComplexDerivationOk(XSComplexTypeDecl xSComplexTypeDecl, XSTypeDefinition xSTypeDefinition, short s) {
        return xSComplexTypeDecl == SchemaGrammar.fAnyType ? xSComplexTypeDecl == xSTypeDefinition : checkComplexDerivation(xSComplexTypeDecl, xSTypeDefinition, s);
    }

    public static void checkElementDeclsConsistent(XSComplexTypeDecl xSComplexTypeDecl, XSParticleDecl xSParticleDecl, SymbolHash symbolHash, SubstitutionGroupHandler substitutionGroupHandler) {
        short s = xSParticleDecl.fType;
        if (s != 2) {
            int i2 = 0;
            XSTerm xSTerm = xSParticleDecl.fValue;
            if (s == 1) {
                XSElementDecl xSElementDecl = (XSElementDecl) xSTerm;
                findElemInTable(xSComplexTypeDecl, xSElementDecl, symbolHash);
                if (xSElementDecl.fScope == 1) {
                    XSElementDecl[] substitutionGroup = substitutionGroupHandler.getSubstitutionGroup(xSElementDecl);
                    while (i2 < substitutionGroup.length) {
                        findElemInTable(xSComplexTypeDecl, substitutionGroup[i2], symbolHash);
                        i2++;
                    }
                    return;
                }
                return;
            }
            XSModelGroupImpl xSModelGroupImpl = (XSModelGroupImpl) xSTerm;
            while (i2 < xSModelGroupImpl.fParticleCount) {
                checkElementDeclsConsistent(xSComplexTypeDecl, xSModelGroupImpl.fParticles[i2], symbolHash, substitutionGroupHandler);
                i2++;
            }
        }
    }

    public static void checkIDConstraintRestriction(XSElementDecl xSElementDecl, XSElementDecl xSElementDecl2) {
    }

    public static void checkMapAndSum(Vector vector, int i2, int i3, SubstitutionGroupHandler substitutionGroupHandler, Vector vector2, int i4, int i5, SubstitutionGroupHandler substitutionGroupHandler2) {
        if (!checkOccurrenceRange(i2, i3, i4, i5)) {
            Object[] objArr = new Object[4];
            objArr[0] = Integer.toString(i2);
            String str = SchemaSymbols.ATTVAL_UNBOUNDED;
            objArr[1] = i3 == -1 ? str : Integer.toString(i3);
            objArr[2] = Integer.toString(i4);
            if (i5 != -1) {
                str = Integer.toString(i5);
            }
            objArr[3] = str;
            throw new XMLSchemaException("rcase-MapAndSum.2", objArr);
        }
        int size = vector.size();
        int size2 = vector2.size();
        for (int i6 = 0; i6 < size; i6++) {
            XSParticleDecl xSParticleDecl = (XSParticleDecl) vector.elementAt(i6);
            for (int i7 = 0; i7 < size2; i7++) {
                try {
                    particleValidRestriction(xSParticleDecl, substitutionGroupHandler, (XSParticleDecl) vector2.elementAt(i7), substitutionGroupHandler2);
                } catch (XMLSchemaException unused) {
                }
            }
            throw new XMLSchemaException(XmlErrorCodes.PARTICLE_DERIVATION_MAP_AND_SUM$MAP, null);
        }
    }

    public static void checkNSCompat(XSElementDecl xSElementDecl, int i2, int i3, XSWildcardDecl xSWildcardDecl, int i4, int i5, boolean z) {
        if (z && !checkOccurrenceRange(i2, i3, i4, i5)) {
            Object[] objArr = new Object[5];
            objArr[0] = xSElementDecl.fName;
            objArr[1] = Integer.toString(i2);
            String str = SchemaSymbols.ATTVAL_UNBOUNDED;
            objArr[2] = i3 == -1 ? str : Integer.toString(i3);
            objArr[3] = Integer.toString(i4);
            if (i5 != -1) {
                str = Integer.toString(i5);
            }
            objArr[4] = str;
            throw new XMLSchemaException("rcase-NSCompat.2", objArr);
        } else if (!xSWildcardDecl.allowNamespace(xSElementDecl.fTargetNamespace)) {
            throw new XMLSchemaException(XmlErrorCodes.PARTICLE_DERIVATION_NS_COMPAT$WILDCARD_VALID, new Object[]{xSElementDecl.fName, xSElementDecl.fTargetNamespace});
        }
    }

    public static void checkNSRecurseCheckCardinality(Vector vector, int i2, int i3, SubstitutionGroupHandler substitutionGroupHandler, XSParticleDecl xSParticleDecl, int i4, int i5, boolean z) {
        if (!z || checkOccurrenceRange(i2, i3, i4, i5)) {
            int size = vector.size();
            for (int i6 = 0; i6 < size; i6++) {
                try {
                    particleValidRestriction((XSParticleDecl) vector.elementAt(i6), substitutionGroupHandler, xSParticleDecl, null, false);
                } catch (XMLSchemaException unused) {
                    throw new XMLSchemaException("rcase-NSRecurseCheckCardinality.1", null);
                }
            }
            return;
        }
        Object[] objArr = new Object[4];
        objArr[0] = Integer.toString(i2);
        String str = SchemaSymbols.ATTVAL_UNBOUNDED;
        objArr[1] = i3 == -1 ? str : Integer.toString(i3);
        objArr[2] = Integer.toString(i4);
        if (i5 != -1) {
            str = Integer.toString(i5);
        }
        objArr[3] = str;
        throw new XMLSchemaException("rcase-NSRecurseCheckCardinality.2", objArr);
    }

    public static void checkNSSubset(XSWildcardDecl xSWildcardDecl, int i2, int i3, XSWildcardDecl xSWildcardDecl2, int i4, int i5) {
        if (!checkOccurrenceRange(i2, i3, i4, i5)) {
            Object[] objArr = new Object[4];
            objArr[0] = Integer.toString(i2);
            String str = SchemaSymbols.ATTVAL_UNBOUNDED;
            objArr[1] = i3 == -1 ? str : Integer.toString(i3);
            objArr[2] = Integer.toString(i4);
            if (i5 != -1) {
                str = Integer.toString(i5);
            }
            objArr[3] = str;
            throw new XMLSchemaException(XmlErrorCodes.PARTICLE_DERIVATION_NS_SUBST$WILDCARD_SUBSET, objArr);
        } else if (!xSWildcardDecl.isSubsetOf(xSWildcardDecl2)) {
            throw new XMLSchemaException("rcase-NSSubset.1", null);
        } else if (xSWildcardDecl.weakerProcessContents(xSWildcardDecl2)) {
            throw new XMLSchemaException("rcase-NSSubset.3", new Object[]{xSWildcardDecl.getProcessContentsAsString(), xSWildcardDecl2.getProcessContentsAsString()});
        }
    }

    public static void checkNameAndTypeOK(XSElementDecl xSElementDecl, int i2, int i3, XSElementDecl xSElementDecl2, int i4, int i5) {
        if (xSElementDecl.fName != xSElementDecl2.fName || xSElementDecl.fTargetNamespace != xSElementDecl2.fTargetNamespace) {
            throw new XMLSchemaException(XmlErrorCodes.PARTICLE_RESTRICTION_NAME_AND_TYPE$NAME, new Object[]{xSElementDecl.fName, xSElementDecl.fTargetNamespace, xSElementDecl2.fName, xSElementDecl2.fTargetNamespace});
        } else if (!xSElementDecl2.getNillable() && xSElementDecl.getNillable()) {
            throw new XMLSchemaException(XmlErrorCodes.PARTICLE_RESTRICTION_NAME_AND_TYPE$NILLABLE, new Object[]{xSElementDecl.fName});
        } else if (!checkOccurrenceRange(i2, i3, i4, i5)) {
            Object[] objArr = new Object[5];
            objArr[0] = xSElementDecl.fName;
            objArr[1] = Integer.toString(i2);
            String str = SchemaSymbols.ATTVAL_UNBOUNDED;
            objArr[2] = i3 == -1 ? str : Integer.toString(i3);
            objArr[3] = Integer.toString(i4);
            if (i5 != -1) {
                str = Integer.toString(i5);
            }
            objArr[4] = str;
            throw new XMLSchemaException("rcase-NameAndTypeOK.3", objArr);
        } else {
            if (xSElementDecl2.getConstraintType() == 2) {
                if (xSElementDecl.getConstraintType() == 2) {
                    boolean z = xSElementDecl.fType.getTypeCategory() == 16 || ((XSComplexTypeDecl) xSElementDecl.fType).fContentType == 1;
                    if ((!z && !xSElementDecl2.fDefault.normalizedValue.equals(xSElementDecl.fDefault.normalizedValue)) || (z && !xSElementDecl2.fDefault.actualValue.equals(xSElementDecl.fDefault.actualValue))) {
                        throw new XMLSchemaException("rcase-NameAndTypeOK.4.b", new Object[]{xSElementDecl.fName, xSElementDecl.fDefault.stringValue(), xSElementDecl2.fDefault.stringValue()});
                    }
                } else {
                    throw new XMLSchemaException("rcase-NameAndTypeOK.4.a", new Object[]{xSElementDecl.fName, xSElementDecl2.fDefault.stringValue()});
                }
            }
            checkIDConstraintRestriction(xSElementDecl, xSElementDecl2);
            short s = xSElementDecl.fBlock;
            short s2 = xSElementDecl2.fBlock;
            if ((s & s2) != s2 || (s == 0 && s2 != 0)) {
                throw new XMLSchemaException(XmlErrorCodes.PARTICLE_RESTRICTION_NAME_AND_TYPE$DISALLOWED_SUBSTITUTIONS, new Object[]{xSElementDecl.fName});
            } else if (!checkTypeDerivationOk(xSElementDecl.fType, xSElementDecl2.fType, 25)) {
                throw new XMLSchemaException("rcase-NameAndTypeOK.7", new Object[]{xSElementDecl.fName, xSElementDecl.fType.getName(), xSElementDecl2.fType.getName()});
            }
        }
    }

    public static boolean checkOccurrenceRange(int i2, int i3, int i4, int i5) {
        if (i2 < i4) {
            return false;
        }
        if (i5 != -1) {
            return i3 != -1 && i3 <= i5;
        }
        return true;
    }

    public static void checkRecurse(Vector vector, int i2, int i3, SubstitutionGroupHandler substitutionGroupHandler, Vector vector2, int i4, int i5, SubstitutionGroupHandler substitutionGroupHandler2) {
        int i6 = 0;
        if (!checkOccurrenceRange(i2, i3, i4, i5)) {
            Object[] objArr = new Object[4];
            objArr[0] = Integer.toString(i2);
            String str = SchemaSymbols.ATTVAL_UNBOUNDED;
            objArr[1] = i3 == -1 ? str : Integer.toString(i3);
            objArr[2] = Integer.toString(i4);
            if (i5 != -1) {
                str = Integer.toString(i5);
            }
            objArr[3] = str;
            throw new XMLSchemaException("rcase-Recurse.1", objArr);
        }
        int size = vector.size();
        int size2 = vector2.size();
        int i7 = 0;
        while (i6 < size) {
            XSParticleDecl xSParticleDecl = (XSParticleDecl) vector.elementAt(i6);
            int i8 = i7;
            while (i7 < size2) {
                XSParticleDecl xSParticleDecl2 = (XSParticleDecl) vector2.elementAt(i7);
                i8++;
                try {
                    particleValidRestriction(xSParticleDecl, substitutionGroupHandler, xSParticleDecl2, substitutionGroupHandler2);
                    i6++;
                    i7 = i8;
                } catch (XMLSchemaException unused) {
                    if (xSParticleDecl2.emptiable()) {
                        i7++;
                    } else {
                        throw new XMLSchemaException(XmlErrorCodes.PARTICLE_DERIVATION_RECURSE$MAP, null);
                    }
                }
            }
            throw new XMLSchemaException(XmlErrorCodes.PARTICLE_DERIVATION_RECURSE$MAP, null);
        }
        while (i7 < size2) {
            if (((XSParticleDecl) vector2.elementAt(i7)).emptiable()) {
                i7++;
            } else {
                throw new XMLSchemaException(XmlErrorCodes.PARTICLE_DERIVATION_RECURSE$MAP, null);
            }
        }
    }

    public static void checkRecurseLax(Vector vector, int i2, int i3, SubstitutionGroupHandler substitutionGroupHandler, Vector vector2, int i4, int i5, SubstitutionGroupHandler substitutionGroupHandler2) {
        if (!checkOccurrenceRange(i2, i3, i4, i5)) {
            Object[] objArr = new Object[4];
            objArr[0] = Integer.toString(i2);
            String str = SchemaSymbols.ATTVAL_UNBOUNDED;
            objArr[1] = i3 == -1 ? str : Integer.toString(i3);
            objArr[2] = Integer.toString(i4);
            if (i5 != -1) {
                str = Integer.toString(i5);
            }
            objArr[3] = str;
            throw new XMLSchemaException("rcase-RecurseLax.1", objArr);
        }
        int size = vector.size();
        int size2 = vector2.size();
        int i6 = 0;
        for (int i7 = 0; i7 < size; i7++) {
            XSParticleDecl xSParticleDecl = (XSParticleDecl) vector.elementAt(i7);
            int i8 = i6;
            while (i6 < size2) {
                i8++;
                try {
                    if (particleValidRestriction(xSParticleDecl, substitutionGroupHandler, (XSParticleDecl) vector2.elementAt(i6), substitutionGroupHandler2)) {
                        i8--;
                    }
                    i6 = i8;
                } catch (XMLSchemaException unused) {
                    i6++;
                }
            }
            throw new XMLSchemaException(XmlErrorCodes.PARTICLE_DERIVATION_RECURSE_LAX$MAP, null);
        }
    }

    public static void checkRecurseUnordered(Vector vector, int i2, int i3, SubstitutionGroupHandler substitutionGroupHandler, Vector vector2, int i4, int i5, SubstitutionGroupHandler substitutionGroupHandler2) {
        if (!checkOccurrenceRange(i2, i3, i4, i5)) {
            Object[] objArr = new Object[4];
            objArr[0] = Integer.toString(i2);
            String str = SchemaSymbols.ATTVAL_UNBOUNDED;
            objArr[1] = i3 == -1 ? str : Integer.toString(i3);
            objArr[2] = Integer.toString(i4);
            if (i5 != -1) {
                str = Integer.toString(i5);
            }
            objArr[3] = str;
            throw new XMLSchemaException("rcase-RecurseUnordered.1", objArr);
        }
        int size = vector.size();
        int size2 = vector2.size();
        boolean[] zArr = new boolean[size2];
        for (int i6 = 0; i6 < size; i6++) {
            XSParticleDecl xSParticleDecl = (XSParticleDecl) vector.elementAt(i6);
            for (int i7 = 0; i7 < size2; i7++) {
                try {
                    particleValidRestriction(xSParticleDecl, substitutionGroupHandler, (XSParticleDecl) vector2.elementAt(i7), substitutionGroupHandler2);
                    if (!zArr[i7]) {
                        zArr[i7] = true;
                    } else {
                        throw new XMLSchemaException(XmlErrorCodes.PARTICLE_DERIVATION_RECURSE_UNORDERED$MAP, null);
                    }
                } catch (XMLSchemaException unused) {
                }
            }
            throw new XMLSchemaException(XmlErrorCodes.PARTICLE_DERIVATION_RECURSE_UNORDERED$MAP, null);
        }
        for (int i8 = 0; i8 < size2; i8++) {
            XSParticleDecl xSParticleDecl2 = (XSParticleDecl) vector2.elementAt(i8);
            if (!zArr[i8] && !xSParticleDecl2.emptiable()) {
                throw new XMLSchemaException(XmlErrorCodes.PARTICLE_DERIVATION_RECURSE_UNORDERED$MAP, null);
            }
        }
    }

    public static boolean checkSimpleDerivation(XSSimpleType xSSimpleType, XSSimpleType xSSimpleType2, short s) {
        if (xSSimpleType == xSSimpleType2) {
            return true;
        }
        if ((s & 2) == 0 && (xSSimpleType.getBaseType().getFinal() & 2) == 0) {
            XSSimpleType xSSimpleType3 = (XSSimpleType) xSSimpleType.getBaseType();
            if (xSSimpleType3 == xSSimpleType2) {
                return true;
            }
            if (xSSimpleType3 != SchemaGrammar.fAnySimpleType && checkSimpleDerivation(xSSimpleType3, xSSimpleType2, s)) {
                return true;
            }
            if ((xSSimpleType.getVariety() == 2 || xSSimpleType.getVariety() == 3) && xSSimpleType2 == SchemaGrammar.fAnySimpleType) {
                return true;
            }
            if (xSSimpleType2.getVariety() == 3) {
                XSObjectList memberTypes = xSSimpleType2.getMemberTypes();
                int length = memberTypes.getLength();
                for (int i2 = 0; i2 < length; i2++) {
                    if (checkSimpleDerivation(xSSimpleType, (XSSimpleType) memberTypes.item(i2), s)) {
                        return true;
                    }
                }
            }
        }
        return false;
    }

    public static boolean checkSimpleDerivationOk(XSSimpleType xSSimpleType, XSTypeDefinition xSTypeDefinition, short s) {
        if (xSSimpleType == SchemaGrammar.fAnySimpleType) {
            return xSTypeDefinition == SchemaGrammar.fAnyType || xSTypeDefinition == SchemaGrammar.fAnySimpleType;
        }
        if (xSTypeDefinition.getTypeCategory() == 15) {
            if (xSTypeDefinition != SchemaGrammar.fAnyType) {
                return false;
            }
            xSTypeDefinition = SchemaGrammar.fAnySimpleType;
        }
        return checkSimpleDerivation(xSSimpleType, (XSSimpleType) xSTypeDefinition, s);
    }

    public static boolean checkTypeDerivationOk(XSTypeDefinition xSTypeDefinition, XSTypeDefinition xSTypeDefinition2, short s) {
        if (xSTypeDefinition == SchemaGrammar.fAnyType) {
            return xSTypeDefinition == xSTypeDefinition2;
        }
        if (xSTypeDefinition == SchemaGrammar.fAnySimpleType) {
            return xSTypeDefinition2 == SchemaGrammar.fAnyType || xSTypeDefinition2 == SchemaGrammar.fAnySimpleType;
        }
        if (xSTypeDefinition.getTypeCategory() != 16) {
            return checkComplexDerivation((XSComplexTypeDecl) xSTypeDefinition, xSTypeDefinition2, s);
        }
        if (xSTypeDefinition2.getTypeCategory() == 15) {
            if (xSTypeDefinition2 != SchemaGrammar.fAnyType) {
                return false;
            }
            xSTypeDefinition2 = SchemaGrammar.fAnySimpleType;
        }
        return checkSimpleDerivation((XSSimpleType) xSTypeDefinition, (XSSimpleType) xSTypeDefinition2, s);
    }

    public static void findElemInTable(XSComplexTypeDecl xSComplexTypeDecl, XSElementDecl xSElementDecl, SymbolHash symbolHash) {
        StringBuffer stringBuffer = new StringBuffer();
        stringBuffer.append(xSElementDecl.fName);
        stringBuffer.append(XSSFDataValidationConstraint.LIST_SEPARATOR);
        stringBuffer.append(xSElementDecl.fTargetNamespace);
        String stringBuffer2 = stringBuffer.toString();
        XSElementDecl xSElementDecl2 = (XSElementDecl) symbolHash.get(stringBuffer2);
        if (xSElementDecl2 == null) {
            symbolHash.put(stringBuffer2, xSElementDecl);
        } else if (xSElementDecl != xSElementDecl2 && xSElementDecl.fType != xSElementDecl2.fType) {
            throw new XMLSchemaException(XmlErrorCodes.ELEM_CONSISTANT, new Object[]{xSComplexTypeDecl.fName, xSElementDecl.fName});
        }
    }

    /* JADX DEBUG: Multi-variable search result rejected for r4v2, resolved type: int */
    /* JADX WARN: Multi-variable type inference failed */
    /* JADX WARN: Type inference failed for: r4v16 */
    /* JADX WARN: Type inference failed for: r4v17 */
    public static void fullSchemaChecking(XSGrammarBucket xSGrammarBucket, SubstitutionGroupHandler substitutionGroupHandler, CMBuilder cMBuilder, XMLErrorReporter xMLErrorReporter) {
        int i2;
        boolean z;
        SchemaGrammar[] grammars = xSGrammarBucket.getGrammars();
        boolean z2 = true;
        int length = grammars.length - 1;
        while (length >= 0) {
            substitutionGroupHandler.addSubstitutionGroup(grammars[length].getSubstitutionGroups());
            length--;
            z2 = true;
        }
        XSParticleDecl xSParticleDecl = new XSParticleDecl();
        XSParticleDecl xSParticleDecl2 = new XSParticleDecl();
        xSParticleDecl.fType = 3;
        xSParticleDecl2.fType = 3;
        int length2 = grammars.length - (z2 ? 1 : 0);
        int i3 = z2;
        while (true) {
            i2 = 2;
            if (length2 < 0) {
                break;
            }
            XSGroupDecl[] redefinedGroupDecls = grammars[length2].getRedefinedGroupDecls();
            SimpleLocator[] rGLocators = grammars[length2].getRGLocators();
            int i4 = 0;
            int i5 = i3;
            while (i4 < redefinedGroupDecls.length) {
                int i6 = i4 + 1;
                XSGroupDecl xSGroupDecl = redefinedGroupDecls[i4];
                XSModelGroupImpl xSModelGroupImpl = xSGroupDecl.fModelGroup;
                int i7 = i6 + 1;
                XSModelGroupImpl xSModelGroupImpl2 = redefinedGroupDecls[i6].fModelGroup;
                xSParticleDecl.fValue = xSModelGroupImpl;
                xSParticleDecl2.fValue = xSModelGroupImpl2;
                if (xSModelGroupImpl2 == null) {
                    if (xSModelGroupImpl != null) {
                        reportSchemaError(xMLErrorReporter, rGLocators[(i7 / 2) - i5], "src-redefine.6.2.2", new Object[]{xSGroupDecl.fName, XmlErrorCodes.PARTICLE_DERIVATION_RECURSE$MAP});
                    }
                } else if (xSModelGroupImpl != null) {
                    try {
                        particleValidRestriction(xSParticleDecl, substitutionGroupHandler, xSParticleDecl2, substitutionGroupHandler);
                    } catch (XMLSchemaException e2) {
                        String key = e2.getKey();
                        int i8 = (i7 / 2) - 1;
                        reportSchemaError(xMLErrorReporter, rGLocators[i8], key, e2.getArgs());
                        reportSchemaError(xMLErrorReporter, rGLocators[i8], "src-redefine.6.2.2", new Object[]{xSGroupDecl.fName, key});
                    }
                } else if (!xSParticleDecl2.emptiable()) {
                    reportSchemaError(xMLErrorReporter, rGLocators[(i7 / 2) - 1], "src-redefine.6.2.2", new Object[]{xSGroupDecl.fName, XmlErrorCodes.PARTICLE_DERIVATION_RECURSE$MAP});
                }
                i4 = i7;
                i5 = 1;
            }
            length2--;
            i3 = i5;
        }
        SymbolHash symbolHash = new SymbolHash();
        for (int length3 = grammars.length - i3; length3 >= 0; length3--) {
            boolean z3 = grammars[length3].fFullChecked;
            XSComplexTypeDecl[] uncheckedComplexTypeDecls = grammars[length3].getUncheckedComplexTypeDecls();
            SimpleLocator[] uncheckedCTLocators = grammars[length3].getUncheckedCTLocators();
            int i9 = 0;
            int i10 = 0;
            while (i9 < uncheckedComplexTypeDecls.length) {
                if (!z3 && uncheckedComplexTypeDecls[i9].fParticle != null) {
                    symbolHash.clear();
                    try {
                        checkElementDeclsConsistent(uncheckedComplexTypeDecls[i9], uncheckedComplexTypeDecls[i9].fParticle, symbolHash, substitutionGroupHandler);
                    } catch (XMLSchemaException e3) {
                        reportSchemaError(xMLErrorReporter, uncheckedCTLocators[i9], e3.getKey(), e3.getArgs());
                    }
                }
                if (uncheckedComplexTypeDecls[i9].fBaseType != null && uncheckedComplexTypeDecls[i9].fBaseType != SchemaGrammar.fAnyType && uncheckedComplexTypeDecls[i9].fDerivedBy == i2 && (uncheckedComplexTypeDecls[i9].fBaseType instanceof XSComplexTypeDecl)) {
                    XSParticleDecl xSParticleDecl3 = uncheckedComplexTypeDecls[i9].fParticle;
                    XSParticleDecl xSParticleDecl4 = ((XSComplexTypeDecl) uncheckedComplexTypeDecls[i9].fBaseType).fParticle;
                    if (xSParticleDecl3 == null) {
                        if (xSParticleDecl4 != null && !xSParticleDecl4.emptiable()) {
                            SimpleLocator simpleLocator = uncheckedCTLocators[i9];
                            Object[] objArr = new Object[i2];
                            objArr[0] = uncheckedComplexTypeDecls[i9].fName;
                            objArr[i3] = uncheckedComplexTypeDecls[i9].fBaseType.getName();
                            reportSchemaError(xMLErrorReporter, simpleLocator, "derivation-ok-restriction.5.3.2", objArr);
                        }
                    } else if (xSParticleDecl4 != null) {
                        try {
                            particleValidRestriction(uncheckedComplexTypeDecls[i9].fParticle, substitutionGroupHandler, ((XSComplexTypeDecl) uncheckedComplexTypeDecls[i9].fBaseType).fParticle, substitutionGroupHandler);
                        } catch (XMLSchemaException e4) {
                            reportSchemaError(xMLErrorReporter, uncheckedCTLocators[i9], e4.getKey(), e4.getArgs());
                            SimpleLocator simpleLocator2 = uncheckedCTLocators[i9];
                            Object[] objArr2 = new Object[i3];
                            objArr2[0] = uncheckedComplexTypeDecls[i9].fName;
                            reportSchemaError(xMLErrorReporter, simpleLocator2, "derivation-ok-restriction.5.4.2", objArr2);
                        }
                    } else {
                        SimpleLocator simpleLocator3 = uncheckedCTLocators[i9];
                        Object[] objArr3 = new Object[i3];
                        objArr3[0] = uncheckedComplexTypeDecls[i9].fName;
                        reportSchemaError(xMLErrorReporter, simpleLocator3, "derivation-ok-restriction.5.4.2", objArr3);
                    }
                }
                XSCMValidator contentModel = uncheckedComplexTypeDecls[i9].getContentModel(cMBuilder, i3);
                if (contentModel != null) {
                    try {
                        z = contentModel.checkUniqueParticleAttribution(substitutionGroupHandler);
                    } catch (XMLSchemaException e5) {
                        reportSchemaError(xMLErrorReporter, uncheckedCTLocators[i9], e5.getKey(), e5.getArgs());
                    }
                    if (!z3 && z) {
                        uncheckedComplexTypeDecls[i10] = uncheckedComplexTypeDecls[i9];
                        i10++;
                    }
                    i9++;
                    i2 = 2;
                }
                z = false;
                uncheckedComplexTypeDecls[i10] = uncheckedComplexTypeDecls[i9];
                i10++;
                i9++;
                i2 = 2;
            }
            if (!z3) {
                grammars[length3].setUncheckedTypeNum(i10);
                grammars[length3].fFullChecked = i3;
            }
        }
    }

    public static void gatherChildren(int i2, XSParticleDecl xSParticleDecl, Vector vector) {
        int i3 = xSParticleDecl.fMinOccurs;
        int i4 = xSParticleDecl.fMaxOccurs;
        short s = xSParticleDecl.fType;
        if (s == 3) {
            s = ((XSModelGroupImpl) xSParticleDecl.fValue).fCompositor;
        }
        if (s == 1 || s == 2) {
            vector.addElement(xSParticleDecl);
            return;
        }
        if (i3 == 1 && i4 == 1) {
            if (i2 == s) {
                XSModelGroupImpl xSModelGroupImpl = (XSModelGroupImpl) xSParticleDecl.fValue;
                for (int i5 = 0; i5 < xSModelGroupImpl.fParticleCount; i5++) {
                    gatherChildren(s, xSModelGroupImpl.fParticles[i5], vector);
                }
                return;
            } else if (xSParticleDecl.isEmpty()) {
                return;
            }
        }
        vector.addElement(xSParticleDecl);
    }

    public static XSParticleDecl getEmptySequence() {
        if (fEmptyParticle == null) {
            XSModelGroupImpl xSModelGroupImpl = new XSModelGroupImpl();
            xSModelGroupImpl.fCompositor = 102;
            xSModelGroupImpl.fParticleCount = 0;
            xSModelGroupImpl.fParticles = null;
            xSModelGroupImpl.fAnnotations = XSObjectListImpl.EMPTY_LIST;
            XSParticleDecl xSParticleDecl = new XSParticleDecl();
            xSParticleDecl.fType = 3;
            xSParticleDecl.fValue = xSModelGroupImpl;
            xSParticleDecl.fAnnotations = XSObjectListImpl.EMPTY_LIST;
            fEmptyParticle = xSParticleDecl;
        }
        return fEmptyParticle;
    }

    public static XSParticleDecl getNonUnaryGroup(XSParticleDecl xSParticleDecl) {
        XSTerm xSTerm;
        short s = xSParticleDecl.fType;
        return (s == 1 || s == 2 || xSParticleDecl.fMinOccurs != 1 || xSParticleDecl.fMaxOccurs != 1 || (xSTerm = xSParticleDecl.fValue) == null || ((XSModelGroupImpl) xSTerm).fParticleCount != 1) ? xSParticleDecl : getNonUnaryGroup(((XSModelGroupImpl) xSTerm).fParticles[0]);
    }

    public static boolean overlapUPA(Object obj, Object obj2, SubstitutionGroupHandler substitutionGroupHandler) {
        if (!(obj instanceof XSElementDecl)) {
            return obj2 instanceof XSElementDecl ? overlapUPA((XSElementDecl) obj2, (XSWildcardDecl) obj, substitutionGroupHandler) : overlapUPA((XSWildcardDecl) obj, (XSWildcardDecl) obj2);
        }
        XSElementDecl xSElementDecl = (XSElementDecl) obj;
        return obj2 instanceof XSElementDecl ? overlapUPA(xSElementDecl, (XSElementDecl) obj2, substitutionGroupHandler) : overlapUPA(xSElementDecl, (XSWildcardDecl) obj2, substitutionGroupHandler);
    }

    public static boolean overlapUPA(XSElementDecl xSElementDecl, XSElementDecl xSElementDecl2, SubstitutionGroupHandler substitutionGroupHandler) {
        if (xSElementDecl.fName == xSElementDecl2.fName && xSElementDecl.fTargetNamespace == xSElementDecl2.fTargetNamespace) {
            return true;
        }
        XSElementDecl[] substitutionGroup = substitutionGroupHandler.getSubstitutionGroup(xSElementDecl);
        for (int length = substitutionGroup.length - 1; length >= 0; length--) {
            if (substitutionGroup[length].fName == xSElementDecl2.fName && substitutionGroup[length].fTargetNamespace == xSElementDecl2.fTargetNamespace) {
                return true;
            }
        }
        XSElementDecl[] substitutionGroup2 = substitutionGroupHandler.getSubstitutionGroup(xSElementDecl2);
        for (int length2 = substitutionGroup2.length - 1; length2 >= 0; length2--) {
            if (substitutionGroup2[length2].fName == xSElementDecl.fName && substitutionGroup2[length2].fTargetNamespace == xSElementDecl.fTargetNamespace) {
                return true;
            }
        }
        return false;
    }

    public static boolean overlapUPA(XSElementDecl xSElementDecl, XSWildcardDecl xSWildcardDecl, SubstitutionGroupHandler substitutionGroupHandler) {
        if (xSWildcardDecl.allowNamespace(xSElementDecl.fTargetNamespace)) {
            return true;
        }
        XSElementDecl[] substitutionGroup = substitutionGroupHandler.getSubstitutionGroup(xSElementDecl);
        for (int length = substitutionGroup.length - 1; length >= 0; length--) {
            if (xSWildcardDecl.allowNamespace(substitutionGroup[length].fTargetNamespace)) {
                return true;
            }
        }
        return false;
    }

    public static boolean overlapUPA(XSWildcardDecl xSWildcardDecl, XSWildcardDecl xSWildcardDecl2) {
        XSWildcardDecl performIntersectionWith = xSWildcardDecl.performIntersectionWith(xSWildcardDecl2, xSWildcardDecl.fProcessContents);
        return (performIntersectionWith != null && performIntersectionWith.fType == 3 && performIntersectionWith.fNamespaceList.length == 0) ? false : true;
    }

    public static boolean particleValidRestriction(XSParticleDecl xSParticleDecl, SubstitutionGroupHandler substitutionGroupHandler, XSParticleDecl xSParticleDecl2, SubstitutionGroupHandler substitutionGroupHandler2) {
        return particleValidRestriction(xSParticleDecl, substitutionGroupHandler, xSParticleDecl2, substitutionGroupHandler2, true);
    }

    /* JADX WARNING: Removed duplicated region for block: B:139:0x025f  */
    /* JADX WARNING: Removed duplicated region for block: B:38:0x00a4  */
    /* JADX WARNING: Removed duplicated region for block: B:46:0x00c2  */
    /* JADX WARNING: Removed duplicated region for block: B:52:0x00d4  */
    /* JADX WARNING: Removed duplicated region for block: B:62:0x010c  */
    public static boolean particleValidRestriction(XSParticleDecl xSParticleDecl, SubstitutionGroupHandler substitutionGroupHandler, XSParticleDecl xSParticleDecl2, SubstitutionGroupHandler substitutionGroupHandler2, boolean z) {
        short s;
        Vector vector;
        SubstitutionGroupHandler substitutionGroupHandler3;
        Vector vector2;
        int i2;
        int i3;
        short s2;
        XSParticleDecl xSParticleDecl3;
        Vector vector3;
        SubstitutionGroupHandler substitutionGroupHandler4;
        Vector vector4;
        short s3;
        boolean z2;
        XSElementDecl xSElementDecl;
        XSParticleDecl xSParticleDecl4 = xSParticleDecl;
        if (xSParticleDecl.isEmpty() && !xSParticleDecl2.emptiable()) {
            throw new XMLSchemaException("cos-particle-restrict.a", null);
        } else if (xSParticleDecl.isEmpty() || !xSParticleDecl2.isEmpty()) {
            short s4 = xSParticleDecl4.fType;
            if (s4 == 3) {
                short s5 = ((XSModelGroupImpl) xSParticleDecl4.fValue).fCompositor;
                XSParticleDecl nonUnaryGroup = getNonUnaryGroup(xSParticleDecl);
                if (nonUnaryGroup != xSParticleDecl4) {
                    short s6 = nonUnaryGroup.fType;
                    if (s6 == 3) {
                        s6 = ((XSModelGroupImpl) nonUnaryGroup.fValue).fCompositor;
                    }
                    s5 = s6;
                } else {
                    nonUnaryGroup = xSParticleDecl4;
                }
                vector = removePointlessChildren(nonUnaryGroup);
                xSParticleDecl4 = nonUnaryGroup;
                s = s5;
            } else {
                s = s4;
                vector = null;
            }
            int i4 = xSParticleDecl4.fMinOccurs;
            int i5 = xSParticleDecl4.fMaxOccurs;
            if (substitutionGroupHandler != null && s == 1) {
                XSElementDecl xSElementDecl2 = (XSElementDecl) xSParticleDecl4.fValue;
                if (xSElementDecl2.fScope == 1) {
                    XSElementDecl[] substitutionGroup = substitutionGroupHandler.getSubstitutionGroup(xSElementDecl2);
                    if (substitutionGroup.length > 0) {
                        Vector vector5 = new Vector(substitutionGroup.length + 1);
                        for (XSElementDecl xSElementDecl3 : substitutionGroup) {
                            addElementToParticleVector(vector5, xSElementDecl3);
                        }
                        addElementToParticleVector(vector5, xSElementDecl2);
                        Collections.sort(vector5, ELEMENT_PARTICLE_COMPARATOR);
                        vector2 = vector5;
                        i3 = i4;
                        i2 = i5;
                        s = 101;
                        substitutionGroupHandler3 = null;
                        s2 = xSParticleDecl2.fType;
                        if (s2 != 3) {
                            s2 = ((XSModelGroupImpl) xSParticleDecl2.fValue).fCompositor;
                            xSParticleDecl3 = getNonUnaryGroup(xSParticleDecl2);
                            if (xSParticleDecl3 != xSParticleDecl2) {
                                short s7 = xSParticleDecl3.fType;
                                if (s7 == 3) {
                                    s7 = ((XSModelGroupImpl) xSParticleDecl3.fValue).fCompositor;
                                }
                                s2 = s7;
                            } else {
                                xSParticleDecl3 = xSParticleDecl2;
                            }
                            vector3 = removePointlessChildren(xSParticleDecl3);
                        } else {
                            xSParticleDecl3 = xSParticleDecl2;
                            vector3 = null;
                        }
                        int i6 = xSParticleDecl3.fMinOccurs;
                        int i7 = xSParticleDecl3.fMaxOccurs;
                        if (substitutionGroupHandler2 != null && s2 == 1) {
                            xSElementDecl = (XSElementDecl) xSParticleDecl3.fValue;
                            if (xSElementDecl.fScope == 1) {
                                XSElementDecl[] substitutionGroup2 = substitutionGroupHandler2.getSubstitutionGroup(xSElementDecl);
                                if (substitutionGroup2.length > 0) {
                                    Vector vector6 = new Vector(substitutionGroup2.length + 1);
                                    for (XSElementDecl xSElementDecl4 : substitutionGroup2) {
                                        addElementToParticleVector(vector6, xSElementDecl4);
                                    }
                                    addElementToParticleVector(vector6, xSElementDecl);
                                    Collections.sort(vector6, ELEMENT_PARTICLE_COMPARATOR);
                                    vector4 = vector6;
                                    z2 = true;
                                    s3 = 101;
                                    substitutionGroupHandler4 = null;
                                    if (s != 1) {
                                        if (s != 2) {
                                            switch (s) {
                                                case 101:
                                                    if (s3 != 1) {
                                                        if (s3 != 2) {
                                                            switch (s3) {
                                                                case 101:
                                                                    checkRecurseLax(vector2, i4, i5, substitutionGroupHandler3, vector4, i6, i7, substitutionGroupHandler4);
                                                                    return z2;
                                                                case 102:
                                                                case 103:
                                                                    break;
                                                                default:
                                                                    throw new XMLSchemaException("Internal-Error", new Object[]{"in particleValidRestriction"});
                                                            }
                                                        } else {
                                                            if (i3 == -2) {
                                                                i3 = xSParticleDecl4.minEffectiveTotalRange();
                                                            }
                                                            checkNSRecurseCheckCardinality(vector2, i3, i2 == -2 ? xSParticleDecl4.maxEffectiveTotalRange() : i2, substitutionGroupHandler3, xSParticleDecl3, i6, i7, z);
                                                            return z2;
                                                        }
                                                    }
                                                    throw new XMLSchemaException(XmlErrorCodes.PARTICLE_RESTRICTION$INVALID_RESTRICTION, new Object[]{"choice:all,sequence,elt"});
                                                case 102:
                                                    if (s3 == 1) {
                                                        throw new XMLSchemaException(XmlErrorCodes.PARTICLE_RESTRICTION$INVALID_RESTRICTION, new Object[]{"seq:elt"});
                                                    } else if (s3 != 2) {
                                                        switch (s3) {
                                                            case 101:
                                                                int size = vector2.size() * i4;
                                                                if (i5 != -1) {
                                                                    i5 *= vector2.size();
                                                                }
                                                                checkMapAndSum(vector2, size, i5, substitutionGroupHandler3, vector4, i6, i7, substitutionGroupHandler4);
                                                                return z2;
                                                            case 102:
                                                                checkRecurse(vector2, i4, i5, substitutionGroupHandler3, vector4, i6, i7, substitutionGroupHandler4);
                                                                return z2;
                                                            case 103:
                                                                checkRecurseUnordered(vector2, i4, i5, substitutionGroupHandler3, vector4, i6, i7, substitutionGroupHandler4);
                                                                return z2;
                                                            default:
                                                                throw new XMLSchemaException("Internal-Error", new Object[]{"in particleValidRestriction"});
                                                        }
                                                    } else {
                                                        if (i3 == -2) {
                                                            i3 = xSParticleDecl4.minEffectiveTotalRange();
                                                        }
                                                        checkNSRecurseCheckCardinality(vector2, i3, i2 == -2 ? xSParticleDecl4.maxEffectiveTotalRange() : i2, substitutionGroupHandler3, xSParticleDecl3, i6, i7, z);
                                                        return z2;
                                                    }
                                                case 103:
                                                    if (s3 != 1) {
                                                        if (s3 != 2) {
                                                            switch (s3) {
                                                                case 101:
                                                                case 102:
                                                                    break;
                                                                case 103:
                                                                    checkRecurse(vector2, i4, i5, substitutionGroupHandler3, vector4, i6, i7, substitutionGroupHandler4);
                                                                    return z2;
                                                                default:
                                                                    throw new XMLSchemaException("Internal-Error", new Object[]{"in particleValidRestriction"});
                                                            }
                                                        } else {
                                                            if (i3 == -2) {
                                                                i3 = xSParticleDecl4.minEffectiveTotalRange();
                                                            }
                                                            checkNSRecurseCheckCardinality(vector2, i3, i2 == -2 ? xSParticleDecl4.maxEffectiveTotalRange() : i2, substitutionGroupHandler3, xSParticleDecl3, i6, i7, z);
                                                            return z2;
                                                        }
                                                    }
                                                    throw new XMLSchemaException(XmlErrorCodes.PARTICLE_RESTRICTION$INVALID_RESTRICTION, new Object[]{"all:choice,sequence,elt"});
                                                default:
                                                    return z2;
                                            }
                                        } else {
                                            if (s3 != 1) {
                                                if (s3 != 2) {
                                                    switch (s3) {
                                                        case 101:
                                                        case 102:
                                                        case 103:
                                                            break;
                                                        default:
                                                            throw new XMLSchemaException("Internal-Error", new Object[]{"in particleValidRestriction"});
                                                    }
                                                } else {
                                                    checkNSSubset((XSWildcardDecl) xSParticleDecl4.fValue, i4, i5, (XSWildcardDecl) xSParticleDecl3.fValue, i6, i7);
                                                    return z2;
                                                }
                                            }
                                            throw new XMLSchemaException(XmlErrorCodes.PARTICLE_RESTRICTION$INVALID_RESTRICTION, new Object[]{"any:choice,sequence,all,elt"});
                                        }
                                    } else if (s3 == 1) {
                                        checkNameAndTypeOK((XSElementDecl) xSParticleDecl4.fValue, i4, i5, (XSElementDecl) xSParticleDecl3.fValue, i6, i7);
                                        return z2;
                                    } else if (s3 != 2) {
                                        switch (s3) {
                                            case 101:
                                                Vector vector7 = new Vector();
                                                vector7.addElement(xSParticleDecl4);
                                                checkRecurseLax(vector7, 1, 1, substitutionGroupHandler3, vector4, i6, i7, substitutionGroupHandler4);
                                                return z2;
                                            case 102:
                                            case 103:
                                                Vector vector8 = new Vector();
                                                vector8.addElement(xSParticleDecl4);
                                                checkRecurse(vector8, 1, 1, substitutionGroupHandler3, vector4, i6, i7, substitutionGroupHandler4);
                                                return z2;
                                            default:
                                                throw new XMLSchemaException("Internal-Error", new Object[]{"in particleValidRestriction"});
                                        }
                                    } else {
                                        checkNSCompat((XSElementDecl) xSParticleDecl4.fValue, i4, i5, (XSWildcardDecl) xSParticleDecl3.fValue, i6, i7, z);
                                        return z2;
                                    }
                                }
                            }
                        }
                        vector4 = vector3;
                        substitutionGroupHandler4 = substitutionGroupHandler2;
                        s3 = s2;
                        z2 = false;
                        if (s != 1) {
                        }
                    }
                }
            }
            substitutionGroupHandler3 = substitutionGroupHandler;
            vector2 = vector;
            i3 = -2;
            i2 = -2;
            s2 = xSParticleDecl2.fType;
            if (s2 != 3) {
            }
            int i62 = xSParticleDecl3.fMinOccurs;
            int i72 = xSParticleDecl3.fMaxOccurs;
            xSElementDecl = (XSElementDecl) xSParticleDecl3.fValue;
            if (xSElementDecl.fScope == 1) {
            }
            vector4 = vector3;
            substitutionGroupHandler4 = substitutionGroupHandler2;
            s3 = s2;
            z2 = false;
            if (s != 1) {
            }
        } else {
            throw new XMLSchemaException("cos-particle-restrict.b", null);
        }
    }

    public static Vector removePointlessChildren(XSParticleDecl xSParticleDecl) {
        short s = xSParticleDecl.fType;
        if (s == 1 || s == 2) {
            return null;
        }
        Vector vector = new Vector();
        XSModelGroupImpl xSModelGroupImpl = (XSModelGroupImpl) xSParticleDecl.fValue;
        for (int i2 = 0; i2 < xSModelGroupImpl.fParticleCount; i2++) {
            gatherChildren(xSModelGroupImpl.fCompositor, xSModelGroupImpl.fParticles[i2], vector);
        }
        return vector;
    }

    public static void reportSchemaError(XMLErrorReporter xMLErrorReporter, SimpleLocator simpleLocator, String str, Object[] objArr) {
        if (simpleLocator != null) {
            xMLErrorReporter.reportError((XMLLocator) simpleLocator, XSMessageFormatter.SCHEMA_DOMAIN, str, objArr, (short) 1);
        } else {
            xMLErrorReporter.reportError(XSMessageFormatter.SCHEMA_DOMAIN, str, objArr, 1);
        }
    }
}
