package org.apache.xerces.impl.xs;

import org.apache.xerces.impl.dv.xs.SchemaDVFactoryImpl;
import org.apache.xerces.impl.dv.xs.XSSimpleTypeDecl;

public final class XSDeclarationPool {
    public static final int CHUNK_MASK = 255;
    public static final int CHUNK_SHIFT = 8;
    public static final int CHUNK_SIZE = 256;
    public static final int INITIAL_CHUNK_COUNT = 4;
    public SchemaDVFactoryImpl dvFactory;
    public XSAttributeDecl[][] fAttrDecl = new XSAttributeDecl[4][];
    public int fAttrDeclIndex = 0;
    public XSAttributeUseImpl[][] fAttributeUse = new XSAttributeUseImpl[4][];
    public int fAttributeUseIndex = 0;
    public XSComplexTypeDecl[][] fCTDecl = new XSComplexTypeDecl[4][];
    public int fCTDeclIndex = 0;
    public XSElementDecl[][] fElementDecl = new XSElementDecl[4][];
    public int fElementDeclIndex = 0;
    public XSModelGroupImpl[][] fModelGroup = new XSModelGroupImpl[4][];
    public int fModelGroupIndex = 0;
    public XSParticleDecl[][] fParticleDecl = new XSParticleDecl[4][];
    public int fParticleDeclIndex = 0;
    public XSSimpleTypeDecl[][] fSTDecl = new XSSimpleTypeDecl[4][];
    public int fSTDeclIndex = 0;

    private boolean ensureAttrDeclCapacity(int i2) {
        XSAttributeDecl[][] xSAttributeDeclArr = this.fAttrDecl;
        if (i2 >= xSAttributeDeclArr.length) {
            this.fAttrDecl = resize(xSAttributeDeclArr, xSAttributeDeclArr.length * 2);
        } else if (xSAttributeDeclArr[i2] != null) {
            return false;
        }
        this.fAttrDecl[i2] = new XSAttributeDecl[256];
        return true;
    }

    private boolean ensureAttributeUseCapacity(int i2) {
        XSAttributeUseImpl[][] xSAttributeUseImplArr = this.fAttributeUse;
        if (i2 >= xSAttributeUseImplArr.length) {
            this.fAttributeUse = resize(xSAttributeUseImplArr, xSAttributeUseImplArr.length * 2);
        } else if (xSAttributeUseImplArr[i2] != null) {
            return false;
        }
        this.fAttributeUse[i2] = new XSAttributeUseImpl[256];
        return true;
    }

    private boolean ensureCTDeclCapacity(int i2) {
        XSComplexTypeDecl[][] xSComplexTypeDeclArr = this.fCTDecl;
        if (i2 >= xSComplexTypeDeclArr.length) {
            this.fCTDecl = resize(xSComplexTypeDeclArr, xSComplexTypeDeclArr.length * 2);
        } else if (xSComplexTypeDeclArr[i2] != null) {
            return false;
        }
        this.fCTDecl[i2] = new XSComplexTypeDecl[256];
        return true;
    }

    private boolean ensureElementDeclCapacity(int i2) {
        XSElementDecl[][] xSElementDeclArr = this.fElementDecl;
        if (i2 >= xSElementDeclArr.length) {
            this.fElementDecl = resize(xSElementDeclArr, xSElementDeclArr.length * 2);
        } else if (xSElementDeclArr[i2] != null) {
            return false;
        }
        this.fElementDecl[i2] = new XSElementDecl[256];
        return true;
    }

    private boolean ensureModelGroupCapacity(int i2) {
        XSModelGroupImpl[][] xSModelGroupImplArr = this.fModelGroup;
        if (i2 >= xSModelGroupImplArr.length) {
            this.fModelGroup = resize(xSModelGroupImplArr, xSModelGroupImplArr.length * 2);
        } else if (xSModelGroupImplArr[i2] != null) {
            return false;
        }
        this.fModelGroup[i2] = new XSModelGroupImpl[256];
        return true;
    }

    private boolean ensureParticleDeclCapacity(int i2) {
        XSParticleDecl[][] xSParticleDeclArr = this.fParticleDecl;
        if (i2 >= xSParticleDeclArr.length) {
            this.fParticleDecl = resize(xSParticleDeclArr, xSParticleDeclArr.length * 2);
        } else if (xSParticleDeclArr[i2] != null) {
            return false;
        }
        this.fParticleDecl[i2] = new XSParticleDecl[256];
        return true;
    }

    private boolean ensureSTDeclCapacity(int i2) {
        XSSimpleTypeDecl[][] xSSimpleTypeDeclArr = this.fSTDecl;
        if (i2 >= xSSimpleTypeDeclArr.length) {
            this.fSTDecl = resize(xSSimpleTypeDeclArr, xSSimpleTypeDeclArr.length * 2);
        } else if (xSSimpleTypeDeclArr[i2] != null) {
            return false;
        }
        this.fSTDecl[i2] = new XSSimpleTypeDecl[256];
        return true;
    }

    public static XSSimpleTypeDecl[][] resize(XSSimpleTypeDecl[][] xSSimpleTypeDeclArr, int i2) {
        XSSimpleTypeDecl[][] xSSimpleTypeDeclArr2 = new XSSimpleTypeDecl[i2][];
        System.arraycopy(xSSimpleTypeDeclArr, 0, xSSimpleTypeDeclArr2, 0, xSSimpleTypeDeclArr.length);
        return xSSimpleTypeDeclArr2;
    }

    public static XSAttributeDecl[][] resize(XSAttributeDecl[][] xSAttributeDeclArr, int i2) {
        XSAttributeDecl[][] xSAttributeDeclArr2 = new XSAttributeDecl[i2][];
        System.arraycopy(xSAttributeDeclArr, 0, xSAttributeDeclArr2, 0, xSAttributeDeclArr.length);
        return xSAttributeDeclArr2;
    }

    public static XSAttributeUseImpl[][] resize(XSAttributeUseImpl[][] xSAttributeUseImplArr, int i2) {
        XSAttributeUseImpl[][] xSAttributeUseImplArr2 = new XSAttributeUseImpl[i2][];
        System.arraycopy(xSAttributeUseImplArr, 0, xSAttributeUseImplArr2, 0, xSAttributeUseImplArr.length);
        return xSAttributeUseImplArr2;
    }

    public static XSComplexTypeDecl[][] resize(XSComplexTypeDecl[][] xSComplexTypeDeclArr, int i2) {
        XSComplexTypeDecl[][] xSComplexTypeDeclArr2 = new XSComplexTypeDecl[i2][];
        System.arraycopy(xSComplexTypeDeclArr, 0, xSComplexTypeDeclArr2, 0, xSComplexTypeDeclArr.length);
        return xSComplexTypeDeclArr2;
    }

    public static XSElementDecl[][] resize(XSElementDecl[][] xSElementDeclArr, int i2) {
        XSElementDecl[][] xSElementDeclArr2 = new XSElementDecl[i2][];
        System.arraycopy(xSElementDeclArr, 0, xSElementDeclArr2, 0, xSElementDeclArr.length);
        return xSElementDeclArr2;
    }

    public static XSModelGroupImpl[][] resize(XSModelGroupImpl[][] xSModelGroupImplArr, int i2) {
        XSModelGroupImpl[][] xSModelGroupImplArr2 = new XSModelGroupImpl[i2][];
        System.arraycopy(xSModelGroupImplArr, 0, xSModelGroupImplArr2, 0, xSModelGroupImplArr.length);
        return xSModelGroupImplArr2;
    }

    public static XSParticleDecl[][] resize(XSParticleDecl[][] xSParticleDeclArr, int i2) {
        XSParticleDecl[][] xSParticleDeclArr2 = new XSParticleDecl[i2][];
        System.arraycopy(xSParticleDeclArr, 0, xSParticleDeclArr2, 0, xSParticleDeclArr.length);
        return xSParticleDeclArr2;
    }

    public final XSAttributeDecl getAttributeDecl() {
        int i2 = this.fAttrDeclIndex;
        int i3 = i2 >> 8;
        int i4 = i2 & 255;
        ensureAttrDeclCapacity(i3);
        XSAttributeDecl[][] xSAttributeDeclArr = this.fAttrDecl;
        if (xSAttributeDeclArr[i3][i4] == null) {
            xSAttributeDeclArr[i3][i4] = new XSAttributeDecl();
        } else {
            xSAttributeDeclArr[i3][i4].reset();
        }
        this.fAttrDeclIndex++;
        return this.fAttrDecl[i3][i4];
    }

    public final XSAttributeUseImpl getAttributeUse() {
        int i2 = this.fAttributeUseIndex;
        int i3 = i2 >> 8;
        int i4 = i2 & 255;
        ensureAttributeUseCapacity(i3);
        XSAttributeUseImpl[][] xSAttributeUseImplArr = this.fAttributeUse;
        if (xSAttributeUseImplArr[i3][i4] == null) {
            xSAttributeUseImplArr[i3][i4] = new XSAttributeUseImpl();
        } else {
            xSAttributeUseImplArr[i3][i4].reset();
        }
        this.fAttributeUseIndex++;
        return this.fAttributeUse[i3][i4];
    }

    public final XSComplexTypeDecl getComplexTypeDecl() {
        int i2 = this.fCTDeclIndex;
        int i3 = i2 >> 8;
        int i4 = i2 & 255;
        ensureCTDeclCapacity(i3);
        XSComplexTypeDecl[][] xSComplexTypeDeclArr = this.fCTDecl;
        if (xSComplexTypeDeclArr[i3][i4] == null) {
            xSComplexTypeDeclArr[i3][i4] = new XSComplexTypeDecl();
        } else {
            xSComplexTypeDeclArr[i3][i4].reset();
        }
        this.fCTDeclIndex++;
        return this.fCTDecl[i3][i4];
    }

    public final XSElementDecl getElementDecl() {
        int i2 = this.fElementDeclIndex;
        int i3 = i2 >> 8;
        int i4 = i2 & 255;
        ensureElementDeclCapacity(i3);
        XSElementDecl[][] xSElementDeclArr = this.fElementDecl;
        if (xSElementDeclArr[i3][i4] == null) {
            xSElementDeclArr[i3][i4] = new XSElementDecl();
        } else {
            xSElementDeclArr[i3][i4].reset();
        }
        this.fElementDeclIndex++;
        return this.fElementDecl[i3][i4];
    }

    public final XSModelGroupImpl getModelGroup() {
        int i2 = this.fModelGroupIndex;
        int i3 = i2 >> 8;
        int i4 = i2 & 255;
        ensureModelGroupCapacity(i3);
        XSModelGroupImpl[][] xSModelGroupImplArr = this.fModelGroup;
        if (xSModelGroupImplArr[i3][i4] == null) {
            xSModelGroupImplArr[i3][i4] = new XSModelGroupImpl();
        } else {
            xSModelGroupImplArr[i3][i4].reset();
        }
        this.fModelGroupIndex++;
        return this.fModelGroup[i3][i4];
    }

    public final XSParticleDecl getParticleDecl() {
        int i2 = this.fParticleDeclIndex;
        int i3 = i2 >> 8;
        int i4 = i2 & 255;
        ensureParticleDeclCapacity(i3);
        XSParticleDecl[][] xSParticleDeclArr = this.fParticleDecl;
        if (xSParticleDeclArr[i3][i4] == null) {
            xSParticleDeclArr[i3][i4] = new XSParticleDecl();
        } else {
            xSParticleDeclArr[i3][i4].reset();
        }
        this.fParticleDeclIndex++;
        return this.fParticleDecl[i3][i4];
    }

    public final XSSimpleTypeDecl getSimpleTypeDecl() {
        int i2 = this.fSTDeclIndex;
        int i3 = i2 >> 8;
        int i4 = i2 & 255;
        ensureSTDeclCapacity(i3);
        XSSimpleTypeDecl[][] xSSimpleTypeDeclArr = this.fSTDecl;
        if (xSSimpleTypeDeclArr[i3][i4] == null) {
            xSSimpleTypeDeclArr[i3][i4] = this.dvFactory.newXSSimpleTypeDecl();
        } else {
            xSSimpleTypeDeclArr[i3][i4].reset();
        }
        this.fSTDeclIndex++;
        return this.fSTDecl[i3][i4];
    }

    public void reset() {
        this.fElementDeclIndex = 0;
        this.fParticleDeclIndex = 0;
        this.fModelGroupIndex = 0;
        this.fSTDeclIndex = 0;
        this.fCTDeclIndex = 0;
        this.fAttrDeclIndex = 0;
        this.fAttributeUseIndex = 0;
    }

    public void setDVFactory(SchemaDVFactoryImpl schemaDVFactoryImpl) {
        this.dvFactory = schemaDVFactoryImpl;
    }
}
