package org.apache.xerces.impl.xs;

import org.apache.xerces.impl.xs.util.XSGrammarPool;
import org.apache.xerces.xni.grammars.Grammar;
import org.apache.xerces.xni.grammars.XMLGrammarDescription;
import org.apache.xerces.xni.grammars.XSGrammar;
import org.apache.xerces.xni.parser.XMLInputSource;
import org.apache.xerces.xs.LSInputList;
import org.apache.xerces.xs.StringList;
import org.apache.xerces.xs.XSLoader;
import org.apache.xerces.xs.XSModel;
import org.apache.xerces.xs.XSNamedMap;
import org.apache.xerces.xs.XSObjectList;
import org.apache.xerces.xs.XSTypeDefinition;
import org.w3c.dom.DOMConfiguration;
import org.w3c.dom.DOMStringList;
import org.w3c.dom.ls.LSInput;

public final class XSLoaderImpl implements XSLoader, DOMConfiguration {
    public final XSGrammarPool fGrammarPool = new XSGrammarMerger();
    public final XMLSchemaLoader fSchemaLoader;

    public static final class XSGrammarMerger extends XSGrammarPool {
        private void mergeSchemaGrammars(SchemaGrammar schemaGrammar, SchemaGrammar schemaGrammar2) {
            XSNamedMap components = schemaGrammar2.getComponents(2);
            int length = components.getLength();
            for (int i2 = 0; i2 < length; i2++) {
                XSElementDecl xSElementDecl = (XSElementDecl) components.item(i2);
                if (schemaGrammar.getGlobalElementDecl(xSElementDecl.getName()) == null) {
                    schemaGrammar.addGlobalElementDecl(xSElementDecl);
                }
            }
            XSNamedMap components2 = schemaGrammar2.getComponents(1);
            int length2 = components2.getLength();
            for (int i3 = 0; i3 < length2; i3++) {
                XSAttributeDecl xSAttributeDecl = (XSAttributeDecl) components2.item(i3);
                if (schemaGrammar.getGlobalAttributeDecl(xSAttributeDecl.getName()) == null) {
                    schemaGrammar.addGlobalAttributeDecl(xSAttributeDecl);
                }
            }
            XSNamedMap components3 = schemaGrammar2.getComponents(3);
            int length3 = components3.getLength();
            for (int i4 = 0; i4 < length3; i4++) {
                XSTypeDefinition xSTypeDefinition = (XSTypeDefinition) components3.item(i4);
                if (schemaGrammar.getGlobalTypeDecl(xSTypeDefinition.getName()) == null) {
                    schemaGrammar.addGlobalTypeDecl(xSTypeDefinition);
                }
            }
            XSNamedMap components4 = schemaGrammar2.getComponents(5);
            int length4 = components4.getLength();
            for (int i5 = 0; i5 < length4; i5++) {
                XSAttributeGroupDecl xSAttributeGroupDecl = (XSAttributeGroupDecl) components4.item(i5);
                if (schemaGrammar.getGlobalAttributeGroupDecl(xSAttributeGroupDecl.getName()) == null) {
                    schemaGrammar.addGlobalAttributeGroupDecl(xSAttributeGroupDecl);
                }
            }
            XSNamedMap components5 = schemaGrammar2.getComponents(7);
            int length5 = components5.getLength();
            for (int i6 = 0; i6 < length5; i6++) {
                XSGroupDecl xSGroupDecl = (XSGroupDecl) components5.item(i6);
                if (schemaGrammar.getGlobalGroupDecl(xSGroupDecl.getName()) == null) {
                    schemaGrammar.addGlobalGroupDecl(xSGroupDecl);
                }
            }
            XSNamedMap components6 = schemaGrammar2.getComponents(11);
            int length6 = components6.getLength();
            for (int i7 = 0; i7 < length6; i7++) {
                XSNotationDecl xSNotationDecl = (XSNotationDecl) components6.item(i7);
                if (schemaGrammar.getGlobalNotationDecl(xSNotationDecl.getName()) == null) {
                    schemaGrammar.addGlobalNotationDecl(xSNotationDecl);
                }
            }
            XSObjectList annotations = schemaGrammar2.getAnnotations();
            int length7 = annotations.getLength();
            for (int i8 = 0; i8 < length7; i8++) {
                schemaGrammar.addAnnotation((XSAnnotationImpl) annotations.item(i8));
            }
        }

        private SchemaGrammar toSchemaGrammar(Grammar grammar) {
            if (grammar instanceof SchemaGrammar) {
                return (SchemaGrammar) grammar;
            }
            return null;
        }

        @Override // org.apache.xerces.util.XMLGrammarPoolImpl
        public boolean containsGrammar(XMLGrammarDescription xMLGrammarDescription) {
            return false;
        }

        @Override // org.apache.xerces.util.XMLGrammarPoolImpl
        public Grammar getGrammar(XMLGrammarDescription xMLGrammarDescription) {
            return null;
        }

        @Override // org.apache.xerces.util.XMLGrammarPoolImpl
        public void putGrammar(Grammar grammar) {
            SchemaGrammar schemaGrammar = toSchemaGrammar(super.getGrammar(grammar.getGrammarDescription()));
            if (schemaGrammar != null) {
                SchemaGrammar schemaGrammar2 = toSchemaGrammar(grammar);
                if (schemaGrammar2 != null) {
                    mergeSchemaGrammars(schemaGrammar, schemaGrammar2);
                    return;
                }
                return;
            }
            super.putGrammar(grammar);
        }

        @Override // org.apache.xerces.util.XMLGrammarPoolImpl, org.apache.xerces.xni.grammars.XMLGrammarPool
        public Grammar retrieveGrammar(XMLGrammarDescription xMLGrammarDescription) {
            return null;
        }

        @Override // org.apache.xerces.util.XMLGrammarPoolImpl, org.apache.xerces.xni.grammars.XMLGrammarPool
        public Grammar[] retrieveInitialGrammarSet(String str) {
            return new Grammar[0];
        }
    }

    public XSLoaderImpl() {
        XMLSchemaLoader xMLSchemaLoader = new XMLSchemaLoader();
        this.fSchemaLoader = xMLSchemaLoader;
        xMLSchemaLoader.setProperty("http://apache.org/xml/properties/internal/grammar-pool", this.fGrammarPool);
    }

    @Override // org.w3c.dom.DOMConfiguration
    public boolean canSetParameter(String str, Object obj) {
        return this.fSchemaLoader.canSetParameter(str, obj);
    }

    @Override // org.apache.xerces.xs.XSLoader
    public DOMConfiguration getConfig() {
        return this;
    }

    @Override // org.w3c.dom.DOMConfiguration
    public Object getParameter(String str) {
        return this.fSchemaLoader.getParameter(str);
    }

    @Override // org.w3c.dom.DOMConfiguration
    public DOMStringList getParameterNames() {
        return this.fSchemaLoader.getParameterNames();
    }

    @Override // org.apache.xerces.xs.XSLoader
    public XSModel load(LSInput lSInput) {
        try {
            this.fGrammarPool.clear();
            return ((XSGrammar) this.fSchemaLoader.loadGrammar(this.fSchemaLoader.dom2xmlInputSource(lSInput))).toXSModel();
        } catch (Exception e2) {
            this.fSchemaLoader.reportDOMFatalError(e2);
            return null;
        }
    }

    @Override // org.apache.xerces.xs.XSLoader
    public XSModel loadInputList(LSInputList lSInputList) {
        int length = lSInputList.getLength();
        try {
            this.fGrammarPool.clear();
            for (int i2 = 0; i2 < length; i2++) {
                this.fSchemaLoader.loadGrammar(this.fSchemaLoader.dom2xmlInputSource(lSInputList.item(i2)));
            }
            return this.fGrammarPool.toXSModel();
        } catch (Exception e2) {
            this.fSchemaLoader.reportDOMFatalError(e2);
            return null;
        }
    }

    @Override // org.apache.xerces.xs.XSLoader
    public XSModel loadURI(String str) {
        try {
            this.fGrammarPool.clear();
            return ((XSGrammar) this.fSchemaLoader.loadGrammar(new XMLInputSource(null, str, null))).toXSModel();
        } catch (Exception e2) {
            this.fSchemaLoader.reportDOMFatalError(e2);
            return null;
        }
    }

    @Override // org.apache.xerces.xs.XSLoader
    public XSModel loadURIList(StringList stringList) {
        int length = stringList.getLength();
        try {
            this.fGrammarPool.clear();
            for (int i2 = 0; i2 < length; i2++) {
                this.fSchemaLoader.loadGrammar(new XMLInputSource(null, stringList.item(i2), null));
            }
            return this.fGrammarPool.toXSModel();
        } catch (Exception e2) {
            this.fSchemaLoader.reportDOMFatalError(e2);
            return null;
        }
    }

    @Override // org.w3c.dom.DOMConfiguration
    public void setParameter(String str, Object obj) {
        this.fSchemaLoader.setParameter(str, obj);
    }
}
