package org.apache.xerces.impl.xs;

import org.apache.xerces.impl.xs.util.XSObjectListImpl;
import org.apache.xerces.xs.XSAnnotation;
import org.apache.xerces.xs.XSModelGroup;
import org.apache.xerces.xs.XSNamespaceItem;
import org.apache.xerces.xs.XSObjectList;

public class XSModelGroupImpl implements XSModelGroup {
    public static final short MODELGROUP_ALL = 103;
    public static final short MODELGROUP_CHOICE = 101;
    public static final short MODELGROUP_SEQUENCE = 102;
    public XSObjectList fAnnotations = null;
    public short fCompositor;
    public String fDescription = null;
    public int fParticleCount = 0;
    public XSParticleDecl[] fParticles = null;

    private int maxEffectiveTotalRangeAllSeq() {
        int i2 = 0;
        for (int i3 = 0; i3 < this.fParticleCount; i3++) {
            int maxEffectiveTotalRange = this.fParticles[i3].maxEffectiveTotalRange();
            if (maxEffectiveTotalRange == -1) {
                return -1;
            }
            i2 += maxEffectiveTotalRange;
        }
        return i2;
    }

    private int maxEffectiveTotalRangeChoice() {
        int i2 = 0;
        if (this.fParticleCount > 0 && (i2 = this.fParticles[0].maxEffectiveTotalRange()) == -1) {
            return -1;
        }
        for (int i3 = 1; i3 < this.fParticleCount; i3++) {
            int maxEffectiveTotalRange = this.fParticles[i3].maxEffectiveTotalRange();
            if (maxEffectiveTotalRange == -1) {
                return -1;
            }
            if (maxEffectiveTotalRange > i2) {
                i2 = maxEffectiveTotalRange;
            }
        }
        return i2;
    }

    private int minEffectiveTotalRangeAllSeq() {
        int i2 = 0;
        for (int i3 = 0; i3 < this.fParticleCount; i3++) {
            i2 += this.fParticles[i3].minEffectiveTotalRange();
        }
        return i2;
    }

    private int minEffectiveTotalRangeChoice() {
        int i2 = 0;
        if (this.fParticleCount > 0) {
            i2 = this.fParticles[0].minEffectiveTotalRange();
        }
        for (int i3 = 1; i3 < this.fParticleCount; i3++) {
            int minEffectiveTotalRange = this.fParticles[i3].minEffectiveTotalRange();
            if (minEffectiveTotalRange < i2) {
                i2 = minEffectiveTotalRange;
            }
        }
        return i2;
    }

    @Override // org.apache.xerces.xs.XSModelGroup
    public XSAnnotation getAnnotation() {
        XSObjectList xSObjectList = this.fAnnotations;
        if (xSObjectList != null) {
            return (XSAnnotation) xSObjectList.item(0);
        }
        return null;
    }

    @Override // org.apache.xerces.xs.XSModelGroup
    public XSObjectList getAnnotations() {
        XSObjectList xSObjectList = this.fAnnotations;
        return xSObjectList != null ? xSObjectList : XSObjectListImpl.EMPTY_LIST;
    }

    @Override // org.apache.xerces.xs.XSModelGroup
    public short getCompositor() {
        short s = this.fCompositor;
        if (s == 101) {
            return 2;
        }
        return s == 102 ? (short) 1 : 3;
    }

    @Override // org.apache.xerces.xs.XSObject
    public String getName() {
        return null;
    }

    @Override // org.apache.xerces.xs.XSObject
    public String getNamespace() {
        return null;
    }

    @Override // org.apache.xerces.xs.XSObject
    public XSNamespaceItem getNamespaceItem() {
        return null;
    }

    @Override // org.apache.xerces.xs.XSModelGroup
    public XSObjectList getParticles() {
        return new XSObjectListImpl(this.fParticles, this.fParticleCount);
    }

    @Override // org.apache.xerces.xs.XSObject
    public short getType() {
        return 7;
    }

    public boolean isEmpty() {
        for (int i2 = 0; i2 < this.fParticleCount; i2++) {
            if (!this.fParticles[i2].isEmpty()) {
                return false;
            }
        }
        return true;
    }

    public int maxEffectiveTotalRange() {
        return this.fCompositor == 101 ? maxEffectiveTotalRangeChoice() : maxEffectiveTotalRangeAllSeq();
    }

    public int minEffectiveTotalRange() {
        return this.fCompositor == 101 ? minEffectiveTotalRangeChoice() : minEffectiveTotalRangeAllSeq();
    }

    public void reset() {
        this.fCompositor = 102;
        this.fParticles = null;
        this.fParticleCount = 0;
        this.fDescription = null;
        this.fAnnotations = null;
    }

    public String toString() {
        if (this.fDescription == null) {
            StringBuffer stringBuffer = new StringBuffer();
            if (this.fCompositor == 103) {
                stringBuffer.append("all(");
            } else {
                stringBuffer.append('(');
            }
            if (this.fParticleCount > 0) {
                stringBuffer.append(this.fParticles[0].toString());
            }
            for (int i2 = 1; i2 < this.fParticleCount; i2++) {
                stringBuffer.append(this.fCompositor == 101 ? '|' : ',');
                stringBuffer.append(this.fParticles[i2].toString());
            }
            stringBuffer.append(')');
            this.fDescription = stringBuffer.toString();
        }
        return this.fDescription;
    }
}
