package org.apache.xerces.impl.xs.identity;

import org.apache.poi.openxml4j.opc.internal.ZipHelper;
import org.apache.xerces.impl.xpath.XPath;
import org.apache.xerces.impl.xpath.XPathException;
import org.apache.xerces.util.SymbolTable;
import org.apache.xerces.util.XMLChar;
import org.apache.xerces.xni.NamespaceContext;
import org.apache.xerces.xni.QName;
import org.apache.xerces.xni.XMLAttributes;
import org.apache.xerces.xs.ShortList;
import org.apache.xerces.xs.XSTypeDefinition;
import org.apache.xmlbeans.XmlErrorCodes;

public class Selector {
    public IdentityConstraint fIDConstraint;
    public final IdentityConstraint fIdentityConstraint;
    public final XPath fXPath;

    public class Matcher extends XPathMatcher {
        public int fElementDepth;
        public final FieldActivator fFieldActivator;
        public final int fInitialDepth;
        public int fMatchedDepth;
        public final /* synthetic */ Selector this$0;

        public Matcher(Selector selector, XPath xPath, FieldActivator fieldActivator, int i2) {
            super(xPath);
            this.this$0 = selector;
            this.fFieldActivator = fieldActivator;
            this.fInitialDepth = i2;
        }

        @Override // org.apache.xerces.impl.xs.identity.XPathMatcher
        public void endElement(QName qName, XSTypeDefinition xSTypeDefinition, boolean z, Object obj, short s, ShortList shortList) {
            super.endElement(qName, xSTypeDefinition, z, obj, s, shortList);
            int i2 = this.fElementDepth;
            this.fElementDepth = i2 - 1;
            if (i2 == this.fMatchedDepth) {
                this.fMatchedDepth = -1;
                this.fFieldActivator.endValueScopeFor(this.this$0.fIdentityConstraint, this.fInitialDepth);
            }
        }

        public IdentityConstraint getIdentityConstraint() {
            return this.this$0.fIdentityConstraint;
        }

        public int getInitialDepth() {
            return this.fInitialDepth;
        }

        @Override // org.apache.xerces.impl.xs.identity.XPathMatcher
        public void startDocumentFragment() {
            super.startDocumentFragment();
            this.fElementDepth = 0;
            this.fMatchedDepth = -1;
        }

        @Override // org.apache.xerces.impl.xs.identity.XPathMatcher
        public void startElement(QName qName, XMLAttributes xMLAttributes) {
            super.startElement(qName, xMLAttributes);
            this.fElementDepth++;
            if (isMatched()) {
                this.fMatchedDepth = this.fElementDepth;
                this.fFieldActivator.startValueScopeFor(this.this$0.fIdentityConstraint, this.fInitialDepth);
                int fieldCount = this.this$0.fIdentityConstraint.getFieldCount();
                for (int i2 = 0; i2 < fieldCount; i2++) {
                    this.fFieldActivator.activateField(this.this$0.fIdentityConstraint.getFieldAt(i2), this.fInitialDepth).startElement(qName, xMLAttributes);
                }
            }
        }
    }

    public static class XPath extends org.apache.xerces.impl.xpath.XPath {
        public XPath(String str, SymbolTable symbolTable, NamespaceContext namespaceContext) {
            super(normalize(str), symbolTable, namespaceContext);
            int i2 = 0;
            while (true) {
                XPath.LocationPath[] locationPathArr = this.fLocationPaths;
                if (i2 < locationPathArr.length) {
                    if (locationPathArr[i2].steps[locationPathArr[i2].steps.length - 1].axis.type != 2) {
                        i2++;
                    } else {
                        throw new XPathException(XmlErrorCodes.SELECTOR_XPATH);
                    }
                } else {
                    return;
                }
            }
        }

        public static String normalize(String str) {
            StringBuffer stringBuffer = new StringBuffer(str.length() + 5);
            while (true) {
                if (!XMLChar.trim(str).startsWith(ZipHelper.FORWARD_SLASH) && !XMLChar.trim(str).startsWith(".")) {
                    stringBuffer.append("./");
                }
                int indexOf = str.indexOf(124);
                if (indexOf == -1) {
                    stringBuffer.append(str);
                    return stringBuffer.toString();
                }
                int i2 = indexOf + 1;
                stringBuffer.append(str.substring(0, i2));
                str = str.substring(i2, str.length());
            }
        }
    }

    public Selector(XPath xPath, IdentityConstraint identityConstraint) {
        this.fXPath = xPath;
        this.fIdentityConstraint = identityConstraint;
    }

    public XPathMatcher createMatcher(FieldActivator fieldActivator, int i2) {
        return new Matcher(this, this.fXPath, fieldActivator, i2);
    }

    public IdentityConstraint getIDConstraint() {
        return this.fIdentityConstraint;
    }

    public org.apache.xerces.impl.xpath.XPath getXPath() {
        return this.fXPath;
    }

    public String toString() {
        return this.fXPath.toString();
    }
}
