package org.apache.xerces.impl.xs.identity;

import org.apache.xerces.impl.Constants;
import org.apache.xerces.impl.xpath.XPath;
import org.apache.xerces.util.IntStack;
import org.apache.xerces.xni.QName;
import org.apache.xerces.xni.XMLAttributes;
import org.apache.xerces.xs.AttributePSVI;
import org.apache.xerces.xs.ShortList;
import org.apache.xerces.xs.XSTypeDefinition;
import org.apache.xmlbeans.impl.common.JarHelper;

public class XPathMatcher {
    public static final boolean DEBUG_ALL = false;
    public static final boolean DEBUG_ANY = false;
    public static final boolean DEBUG_MATCH = false;
    public static final boolean DEBUG_METHODS = false;
    public static final boolean DEBUG_METHODS2 = false;
    public static final boolean DEBUG_METHODS3 = false;
    public static final boolean DEBUG_STACK = false;
    public static final int MATCHED = 1;
    public static final int MATCHED_ATTRIBUTE = 3;
    public static final int MATCHED_DESCENDANT = 5;
    public static final int MATCHED_DESCENDANT_PREVIOUS = 13;
    public final int[] fCurrentStep;
    public final XPath.LocationPath[] fLocationPaths;
    public final int[] fMatched;
    public Object fMatchedString;
    public final int[] fNoMatchDepth;
    public final QName fQName = new QName();
    public final IntStack[] fStepIndexes;

    public XPathMatcher(XPath xPath) {
        XPath.LocationPath[] locationPaths = xPath.getLocationPaths();
        this.fLocationPaths = locationPaths;
        this.fStepIndexes = new IntStack[locationPaths.length];
        int i2 = 0;
        while (true) {
            IntStack[] intStackArr = this.fStepIndexes;
            if (i2 >= intStackArr.length) {
                XPath.LocationPath[] locationPathArr = this.fLocationPaths;
                this.fCurrentStep = new int[locationPathArr.length];
                this.fNoMatchDepth = new int[locationPathArr.length];
                this.fMatched = new int[locationPathArr.length];
                return;
            }
            intStackArr[i2] = new IntStack();
            i2++;
        }
    }

    public static boolean matches(XPath.NodeTest nodeTest, QName qName) {
        short s = nodeTest.type;
        return s == 1 ? nodeTest.name.equals(qName) : s != 4 || nodeTest.name.uri == qName.uri;
    }

    private String normalize(String str) {
        StringBuffer stringBuffer = new StringBuffer();
        int length = str.length();
        for (int i2 = 0; i2 < length; i2++) {
            char charAt = str.charAt(i2);
            if (charAt != '\n') {
                stringBuffer.append(charAt);
            } else {
                stringBuffer.append("\\n");
            }
        }
        return stringBuffer.toString();
    }

    public void endElement(QName qName, XSTypeDefinition xSTypeDefinition, boolean z, Object obj, short s, ShortList shortList) {
        for (int i2 = 0; i2 < this.fLocationPaths.length; i2++) {
            this.fCurrentStep[i2] = this.fStepIndexes[i2].pop();
            int[] iArr = this.fNoMatchDepth;
            if (iArr[i2] > 0) {
                iArr[i2] = iArr[i2] - 1;
            } else {
                int i3 = 0;
                while (i3 < i2 && (this.fMatched[i3] & 1) != 1) {
                    i3++;
                }
                if (i3 >= i2) {
                    int[] iArr2 = this.fMatched;
                    if (iArr2[i3] != 0) {
                        if ((iArr2[i3] & 3) == 3) {
                            iArr2[i2] = 0;
                        } else {
                            handleContent(xSTypeDefinition, z, obj, s, shortList);
                            this.fMatched[i2] = 0;
                        }
                    }
                }
            }
        }
    }

    public void handleContent(XSTypeDefinition xSTypeDefinition, boolean z, Object obj, short s, ShortList shortList) {
    }

    public boolean isMatched() {
        for (int i2 = 0; i2 < this.fLocationPaths.length; i2++) {
            int[] iArr = this.fMatched;
            if ((iArr[i2] & 1) == 1 && (iArr[i2] & 13) != 13 && (this.fNoMatchDepth[i2] == 0 || (iArr[i2] & 5) == 5)) {
                return true;
            }
        }
        return false;
    }

    public void matched(Object obj, short s, ShortList shortList, boolean z) {
    }

    public void startDocumentFragment() {
        this.fMatchedString = null;
        for (int i2 = 0; i2 < this.fLocationPaths.length; i2++) {
            this.fStepIndexes[i2].clear();
            this.fCurrentStep[i2] = 0;
            this.fNoMatchDepth[i2] = 0;
            this.fMatched[i2] = 0;
        }
    }

    public void startElement(QName qName, XMLAttributes xMLAttributes) {
        for (int i2 = 0; i2 < this.fLocationPaths.length; i2++) {
            int i3 = this.fCurrentStep[i2];
            this.fStepIndexes[i2].push(i3);
            int[] iArr = this.fMatched;
            if ((iArr[i2] & 5) == 1 || this.fNoMatchDepth[i2] > 0) {
                int[] iArr2 = this.fNoMatchDepth;
                iArr2[i2] = iArr2[i2] + 1;
            } else {
                if ((iArr[i2] & 5) == 5) {
                    iArr[i2] = 13;
                }
                XPath.Step[] stepArr = this.fLocationPaths[i2].steps;
                while (true) {
                    int[] iArr3 = this.fCurrentStep;
                    if (iArr3[i2] >= stepArr.length || stepArr[iArr3[i2]].axis.type != 3) {
                        int[] iArr4 = this.fCurrentStep;
                    } else {
                        iArr3[i2] = iArr3[i2] + 1;
                    }
                }
                int[] iArr42 = this.fCurrentStep;
                if (iArr42[i2] == stepArr.length) {
                    this.fMatched[i2] = 1;
                } else {
                    int i4 = iArr42[i2];
                    while (true) {
                        int[] iArr5 = this.fCurrentStep;
                        if (iArr5[i2] < stepArr.length && stepArr[iArr5[i2]].axis.type == 4) {
                            iArr5[i2] = iArr5[i2] + 1;
                        }
                    }
                    boolean z = this.fCurrentStep[i2] > i4;
                    int[] iArr6 = this.fCurrentStep;
                    if (iArr6[i2] == stepArr.length) {
                        int[] iArr7 = this.fNoMatchDepth;
                        iArr7[i2] = iArr7[i2] + 1;
                    } else {
                        if (iArr6[i2] == i3 || iArr6[i2] > i4) {
                            int[] iArr8 = this.fCurrentStep;
                            if (stepArr[iArr8[i2]].axis.type == 1) {
                                if (!matches(stepArr[iArr8[i2]].nodeTest, qName)) {
                                    int[] iArr9 = this.fCurrentStep;
                                    if (iArr9[i2] > i4) {
                                        iArr9[i2] = i4;
                                    } else {
                                        int[] iArr10 = this.fNoMatchDepth;
                                        iArr10[i2] = iArr10[i2] + 1;
                                    }
                                } else {
                                    int[] iArr11 = this.fCurrentStep;
                                    iArr11[i2] = iArr11[i2] + 1;
                                }
                            }
                        }
                        int[] iArr12 = this.fCurrentStep;
                        if (iArr12[i2] == stepArr.length) {
                            if (z) {
                                iArr12[i2] = i4;
                                this.fMatched[i2] = 5;
                            } else {
                                this.fMatched[i2] = 1;
                            }
                        } else if (iArr12[i2] < stepArr.length && stepArr[iArr12[i2]].axis.type == 2) {
                            int length = xMLAttributes.getLength();
                            if (length > 0) {
                                XPath.NodeTest nodeTest = stepArr[this.fCurrentStep[i2]].nodeTest;
                                int i5 = 0;
                                while (true) {
                                    if (i5 >= length) {
                                        break;
                                    }
                                    xMLAttributes.getName(i5, this.fQName);
                                    if (matches(nodeTest, this.fQName)) {
                                        int[] iArr13 = this.fCurrentStep;
                                        iArr13[i2] = iArr13[i2] + 1;
                                        if (iArr13[i2] == stepArr.length) {
                                            this.fMatched[i2] = 3;
                                            int i6 = 0;
                                            while (i6 < i2 && (this.fMatched[i6] & 1) != 1) {
                                                i6++;
                                            }
                                            if (i6 == i2) {
                                                AttributePSVI attributePSVI = (AttributePSVI) xMLAttributes.getAugmentations(i5).getItem(Constants.ATTRIBUTE_PSVI);
                                                Object actualNormalizedValue = attributePSVI.getActualNormalizedValue();
                                                this.fMatchedString = actualNormalizedValue;
                                                matched(actualNormalizedValue, attributePSVI.getActualNormalizedValueType(), attributePSVI.getItemValueTypes(), false);
                                            }
                                        }
                                    } else {
                                        i5++;
                                    }
                                }
                            }
                            if ((this.fMatched[i2] & 1) != 1) {
                                int[] iArr14 = this.fCurrentStep;
                                if (iArr14[i2] > i4) {
                                    iArr14[i2] = i4;
                                } else {
                                    int[] iArr15 = this.fNoMatchDepth;
                                    iArr15[i2] = iArr15[i2] + 1;
                                }
                            }
                        }
                    }
                }
            }
        }
    }

    public String toString() {
        StringBuffer stringBuffer = new StringBuffer();
        String obj = super.toString();
        int lastIndexOf = obj.lastIndexOf(46);
        if (lastIndexOf != -1) {
            obj = obj.substring(lastIndexOf + 1);
        }
        stringBuffer.append(obj);
        for (int i2 = 0; i2 < this.fLocationPaths.length; i2++) {
            stringBuffer.append('[');
            XPath.Step[] stepArr = this.fLocationPaths[i2].steps;
            for (int i3 = 0; i3 < stepArr.length; i3++) {
                if (i3 == this.fCurrentStep[i2]) {
                    stringBuffer.append('^');
                }
                stringBuffer.append(stepArr[i3].toString());
                if (i3 < stepArr.length - 1) {
                    stringBuffer.append(JarHelper.SEP);
                }
            }
            if (this.fCurrentStep[i2] == stepArr.length) {
                stringBuffer.append('^');
            }
            stringBuffer.append(']');
            stringBuffer.append(',');
        }
        return stringBuffer.toString();
    }
}
