package org.apache.xerces.impl.xs.models;

import org.apache.xerces.impl.Constants;
import org.apache.xerces.impl.XMLErrorReporter;
import org.apache.xerces.impl.dtd.models.CMNode;
import org.apache.xerces.impl.xs.XSMessageFormatter;
import org.apache.xerces.util.SecurityManager;
import org.apache.xerces.xni.parser.XMLComponentManager;
import org.apache.xerces.xni.parser.XMLConfigurationException;

public class CMNodeFactory {
    public static final boolean DEBUG = false;
    public static final String ERROR_REPORTER = "http://apache.org/xml/properties/internal/error-reporter";
    public static final int MULTIPLICITY = 1;
    public static final String SECURITY_MANAGER = "http://apache.org/xml/properties/security-manager";
    public XMLErrorReporter fErrorReporter;
    public SecurityManager fSecurityManager = null;
    public int maxNodeLimit;
    public int nodeCount = 0;

    public CMNode getCMBinOpNode(int i2, CMNode cMNode, CMNode cMNode2) {
        nodeCountCheck();
        return new XSCMBinOp(i2, cMNode, cMNode2);
    }

    public CMNode getCMLeafNode(int i2, Object obj, int i3, int i4) {
        nodeCountCheck();
        return new XSCMLeaf(i2, obj, i3, i4);
    }

    public CMNode getCMRepeatingLeafNode(int i2, Object obj, int i3, int i4, int i5, int i6) {
        nodeCountCheck();
        return new XSCMRepeatingLeaf(i2, obj, i3, i4, i5, i6);
    }

    public CMNode getCMUniOpNode(int i2, CMNode cMNode) {
        nodeCountCheck();
        return new XSCMUniOp(i2, cMNode);
    }

    public void nodeCountCheck() {
        if (this.fSecurityManager != null) {
            int i2 = this.nodeCount;
            this.nodeCount = i2 + 1;
            if (i2 > this.maxNodeLimit) {
                this.fErrorReporter.reportError(XSMessageFormatter.SCHEMA_DOMAIN, "maxOccurLimit", new Object[]{new Integer(this.maxNodeLimit)}, 2);
                this.nodeCount = 0;
            }
        }
    }

    public void reset() {
        SecurityManager securityManager = this.fSecurityManager;
        if (securityManager != null) {
            this.maxNodeLimit = securityManager.getMaxOccurNodeLimit() * 1;
        }
    }

    public void reset(XMLComponentManager xMLComponentManager) {
        this.fErrorReporter = (XMLErrorReporter) xMLComponentManager.getProperty("http://apache.org/xml/properties/internal/error-reporter");
        try {
            this.fSecurityManager = (SecurityManager) xMLComponentManager.getProperty("http://apache.org/xml/properties/security-manager");
            reset();
        } catch (XMLConfigurationException unused) {
            this.fSecurityManager = null;
        }
    }

    public void resetNodeCount() {
        this.nodeCount = 0;
    }

    public void setProperty(String str, Object obj) {
        if (str.startsWith(Constants.XERCES_PROPERTY_PREFIX)) {
            int length = str.length() - 33;
            if (length == 16 && str.endsWith(Constants.SECURITY_MANAGER_PROPERTY)) {
                SecurityManager securityManager = (SecurityManager) obj;
                this.fSecurityManager = securityManager;
                this.maxNodeLimit = securityManager != null ? securityManager.getMaxOccurNodeLimit() * 1 : 0;
            } else if (length == 23 && str.endsWith(Constants.ERROR_REPORTER_PROPERTY)) {
                this.fErrorReporter = (XMLErrorReporter) obj;
            }
        }
    }
}
