package org.apache.xerces.impl.xs.models;

import java.util.Vector;
import org.apache.xerces.impl.xs.SubstitutionGroupHandler;
import org.apache.xerces.impl.xs.XMLSchemaException;
import org.apache.xerces.impl.xs.XSConstraints;
import org.apache.xerces.impl.xs.XSElementDecl;
import org.apache.xerces.xni.QName;
import org.apache.xmlbeans.XmlErrorCodes;

public class XSAllCM implements XSCMValidator {
    public static final short STATE_CHILD = 1;
    public static final short STATE_START = 0;
    public static final short STATE_VALID = 1;
    public final XSElementDecl[] fAllElements;
    public final boolean fHasOptionalContent;
    public final boolean[] fIsOptionalElement;
    public int fNumElements = 0;

    public XSAllCM(boolean z, int i2) {
        this.fHasOptionalContent = z;
        this.fAllElements = new XSElementDecl[i2];
        this.fIsOptionalElement = new boolean[i2];
    }

    public void addElement(XSElementDecl xSElementDecl, boolean z) {
        XSElementDecl[] xSElementDeclArr = this.fAllElements;
        int i2 = this.fNumElements;
        xSElementDeclArr[i2] = xSElementDecl;
        this.fIsOptionalElement[i2] = z;
        this.fNumElements = i2 + 1;
    }

    @Override // org.apache.xerces.impl.xs.models.XSCMValidator
    public boolean checkUniqueParticleAttribution(SubstitutionGroupHandler substitutionGroupHandler) {
        int i2 = 0;
        while (i2 < this.fNumElements) {
            int i3 = i2 + 1;
            for (int i4 = i3; i4 < this.fNumElements; i4++) {
                XSElementDecl[] xSElementDeclArr = this.fAllElements;
                if (XSConstraints.overlapUPA(xSElementDeclArr[i2], xSElementDeclArr[i4], substitutionGroupHandler)) {
                    throw new XMLSchemaException(XmlErrorCodes.UNIQUE_PARTICLE_ATTRIBUTION, new Object[]{this.fAllElements[i2].toString(), this.fAllElements[i4].toString()});
                }
            }
            i2 = i3;
        }
        return false;
    }

    @Override // org.apache.xerces.impl.xs.models.XSCMValidator
    public boolean endContentModel(int[] iArr) {
        int i2 = iArr[0];
        if (i2 == -1 || i2 == -2) {
            return false;
        }
        if (this.fHasOptionalContent && i2 == 0) {
            return true;
        }
        for (int i3 = 0; i3 < this.fNumElements; i3++) {
            if (!this.fIsOptionalElement[i3] && iArr[i3 + 1] == 0) {
                return false;
            }
        }
        return true;
    }

    public Object findMatchingDecl(QName qName, SubstitutionGroupHandler substitutionGroupHandler) {
        XSElementDecl xSElementDecl = null;
        int i2 = 0;
        while (i2 < this.fNumElements && (xSElementDecl = substitutionGroupHandler.getMatchingElemDecl(qName, this.fAllElements[i2])) == null) {
            i2++;
        }
        return xSElementDecl;
    }

    @Override // org.apache.xerces.impl.xs.models.XSCMValidator
    public String getTermName(int i2) {
        return null;
    }

    @Override // org.apache.xerces.impl.xs.models.XSCMValidator
    public boolean isCompactedForUPA() {
        return false;
    }

    @Override // org.apache.xerces.impl.xs.models.XSCMValidator
    public int[] occurenceInfo(int[] iArr) {
        return null;
    }

    @Override // org.apache.xerces.impl.xs.models.XSCMValidator
    public Object oneTransition(QName qName, int[] iArr, SubstitutionGroupHandler substitutionGroupHandler) {
        XSElementDecl matchingElemDecl;
        if (iArr[0] < 0) {
            iArr[0] = -2;
        } else {
            iArr[0] = 1;
            int i2 = 0;
            while (i2 < this.fNumElements) {
                int i3 = i2 + 1;
                if (iArr[i3] == 0 && (matchingElemDecl = substitutionGroupHandler.getMatchingElemDecl(qName, this.fAllElements[i2])) != null) {
                    iArr[i3] = 1;
                    return matchingElemDecl;
                }
                i2 = i3;
            }
            iArr[0] = -1;
        }
        return findMatchingDecl(qName, substitutionGroupHandler);
    }

    @Override // org.apache.xerces.impl.xs.models.XSCMValidator
    public int[] startContentModel() {
        int[] iArr = new int[(this.fNumElements + 1)];
        for (int i2 = 0; i2 <= this.fNumElements; i2++) {
            iArr[i2] = 0;
        }
        return iArr;
    }

    @Override // org.apache.xerces.impl.xs.models.XSCMValidator
    public Vector whatCanGoHere(int[] iArr) {
        Vector vector = new Vector();
        int i2 = 0;
        while (i2 < this.fNumElements) {
            int i3 = i2 + 1;
            if (iArr[i3] == 0) {
                vector.addElement(this.fAllElements[i2]);
            }
            i2 = i3;
        }
        return vector;
    }
}
