package org.apache.xerces.impl.xs.opti;

import org.w3c.dom.Attr;
import org.w3c.dom.Document;
import org.w3c.dom.NamedNodeMap;
import org.w3c.dom.Node;

public class ElementImpl extends DefaultElement {
    public Attr[] attrs;
    public int charOffset;
    public int col;
    public int column;
    public String fAnnotation;
    public String fSyntheticAnnotation;
    public int line;
    public int parentRow;
    public int row;
    public SchemaDOM schemaDOM;

    public ElementImpl(int i2, int i3) {
        this(i2, i3, -1);
    }

    public ElementImpl(int i2, int i3, int i4) {
        this.row = -1;
        this.col = -1;
        this.parentRow = -1;
        this.nodeType = 1;
        this.line = i2;
        this.column = i3;
        this.charOffset = i4;
    }

    public ElementImpl(String str, String str2, String str3, String str4, int i2, int i3) {
        this(str, str2, str3, str4, i2, i3, -1);
    }

    public ElementImpl(String str, String str2, String str3, String str4, int i2, int i3, int i4) {
        super(str, str2, str3, str4, 1);
        this.row = -1;
        this.col = -1;
        this.parentRow = -1;
        this.line = i2;
        this.column = i3;
        this.charOffset = i4;
    }

    public static boolean nsEquals(String str, String str2) {
        return str == null ? str2 == null : str.equals(str2);
    }

    public String getAnnotation() {
        return this.fAnnotation;
    }

    @Override // org.apache.xerces.impl.xs.opti.DefaultElement, org.w3c.dom.Element
    public String getAttribute(String str) {
        int i2 = 0;
        while (true) {
            Attr[] attrArr = this.attrs;
            if (i2 >= attrArr.length) {
                return "";
            }
            if (attrArr[i2].getName().equals(str)) {
                return this.attrs[i2].getValue();
            }
            i2++;
        }
    }

    @Override // org.apache.xerces.impl.xs.opti.DefaultElement, org.w3c.dom.Element
    public String getAttributeNS(String str, String str2) {
        int i2 = 0;
        while (true) {
            Attr[] attrArr = this.attrs;
            if (i2 >= attrArr.length) {
                return "";
            }
            if (attrArr[i2].getLocalName().equals(str2) && nsEquals(this.attrs[i2].getNamespaceURI(), str)) {
                return this.attrs[i2].getValue();
            }
            i2++;
        }
    }

    @Override // org.apache.xerces.impl.xs.opti.DefaultElement, org.w3c.dom.Element
    public Attr getAttributeNode(String str) {
        int i2 = 0;
        while (true) {
            Attr[] attrArr = this.attrs;
            if (i2 >= attrArr.length) {
                return null;
            }
            if (attrArr[i2].getName().equals(str)) {
                return this.attrs[i2];
            }
            i2++;
        }
    }

    @Override // org.apache.xerces.impl.xs.opti.DefaultElement, org.w3c.dom.Element
    public Attr getAttributeNodeNS(String str, String str2) {
        int i2 = 0;
        while (true) {
            Attr[] attrArr = this.attrs;
            if (i2 >= attrArr.length) {
                return null;
            }
            if (attrArr[i2].getName().equals(str2) && nsEquals(this.attrs[i2].getNamespaceURI(), str)) {
                return this.attrs[i2];
            }
            i2++;
        }
    }

    @Override // org.apache.xerces.impl.xs.opti.DefaultNode, org.w3c.dom.Node
    public NamedNodeMap getAttributes() {
        return new NamedNodeMapImpl(this.attrs);
    }

    public int getCharacterOffset() {
        return this.charOffset;
    }

    public int getColumnNumber() {
        return this.column;
    }

    @Override // org.apache.xerces.impl.xs.opti.DefaultNode, org.w3c.dom.Node
    public Node getFirstChild() {
        int i2 = this.parentRow;
        if (i2 == -1) {
            return null;
        }
        return this.schemaDOM.relations[i2][1];
    }

    @Override // org.apache.xerces.impl.xs.opti.DefaultNode, org.w3c.dom.Node
    public Node getLastChild() {
        if (this.parentRow == -1) {
            return null;
        }
        int i2 = 1;
        while (true) {
            NodeImpl[][] nodeImplArr = this.schemaDOM.relations;
            int i3 = this.parentRow;
            if (i2 >= nodeImplArr[i3].length) {
                if (i2 == 1) {
                    i2++;
                }
                return this.schemaDOM.relations[this.parentRow][i2 - 1];
            } else if (nodeImplArr[i3][i2] == null) {
                return nodeImplArr[i3][i2 - 1];
            } else {
                i2++;
            }
        }
    }

    public int getLineNumber() {
        return this.line;
    }

    @Override // org.apache.xerces.impl.xs.opti.DefaultNode, org.w3c.dom.Node
    public Node getNextSibling() {
        int i2 = this.col;
        NodeImpl[][] nodeImplArr = this.schemaDOM.relations;
        int i3 = this.row;
        if (i2 == nodeImplArr[i3].length - 1) {
            return null;
        }
        return nodeImplArr[i3][i2 + 1];
    }

    @Override // org.apache.xerces.impl.xs.opti.DefaultNode, org.w3c.dom.Node
    public Document getOwnerDocument() {
        return this.schemaDOM;
    }

    @Override // org.apache.xerces.impl.xs.opti.DefaultNode, org.w3c.dom.Node
    public Node getParentNode() {
        return this.schemaDOM.relations[this.row][0];
    }

    @Override // org.apache.xerces.impl.xs.opti.DefaultNode, org.w3c.dom.Node
    public Node getPreviousSibling() {
        int i2 = this.col;
        if (i2 == 1) {
            return null;
        }
        return this.schemaDOM.relations[this.row][i2 - 1];
    }

    public String getSyntheticAnnotation() {
        return this.fSyntheticAnnotation;
    }

    @Override // org.apache.xerces.impl.xs.opti.DefaultElement, org.w3c.dom.Element
    public String getTagName() {
        return this.rawname;
    }

    @Override // org.apache.xerces.impl.xs.opti.DefaultElement, org.w3c.dom.Element
    public boolean hasAttribute(String str) {
        int i2 = 0;
        while (true) {
            Attr[] attrArr = this.attrs;
            if (i2 >= attrArr.length) {
                return false;
            }
            if (attrArr[i2].getName().equals(str)) {
                return true;
            }
            i2++;
        }
    }

    @Override // org.apache.xerces.impl.xs.opti.DefaultElement, org.w3c.dom.Element
    public boolean hasAttributeNS(String str, String str2) {
        int i2 = 0;
        while (true) {
            Attr[] attrArr = this.attrs;
            if (i2 >= attrArr.length) {
                return false;
            }
            if (attrArr[i2].getName().equals(str2) && nsEquals(this.attrs[i2].getNamespaceURI(), str)) {
                return true;
            }
            i2++;
        }
    }

    @Override // org.apache.xerces.impl.xs.opti.DefaultNode, org.w3c.dom.Node
    public boolean hasAttributes() {
        return this.attrs.length != 0;
    }

    @Override // org.apache.xerces.impl.xs.opti.DefaultNode, org.w3c.dom.Node
    public boolean hasChildNodes() {
        return this.parentRow != -1;
    }

    @Override // org.apache.xerces.impl.xs.opti.DefaultElement, org.w3c.dom.Element
    public void setAttribute(String str, String str2) {
        int i2 = 0;
        while (true) {
            Attr[] attrArr = this.attrs;
            if (i2 < attrArr.length) {
                if (attrArr[i2].getName().equals(str)) {
                    this.attrs[i2].setValue(str2);
                    return;
                }
                i2++;
            } else {
                return;
            }
        }
    }
}
