package org.apache.xerces.impl.xs.opti;

import org.apache.xerces.impl.XMLErrorReporter;
import org.apache.xerces.impl.xs.SchemaSymbols;
import org.apache.xerces.impl.xs.XSMessageFormatter;
import org.apache.xerces.util.XMLAttributesImpl;
import org.apache.xerces.util.XMLChar;
import org.apache.xerces.xni.Augmentations;
import org.apache.xerces.xni.NamespaceContext;
import org.apache.xerces.xni.QName;
import org.apache.xerces.xni.XMLAttributes;
import org.apache.xerces.xni.XMLLocator;
import org.apache.xerces.xni.XMLString;
import org.apache.xerces.xni.parser.XMLEntityResolver;
import org.apache.xerces.xni.parser.XMLInputSource;
import org.apache.xerces.xni.parser.XMLParserConfiguration;
import org.w3c.dom.Document;

public class SchemaDOMParser extends DefaultXMLDocumentHandler {
    public static final String ERROR_REPORTER = "http://apache.org/xml/properties/internal/error-reporter";
    public static final String GENERATE_SYNTHETIC_ANNOTATION = "http://apache.org/xml/features/generate-synthetic-annotations";
    public XMLParserConfiguration config;
    public int fAnnotationDepth = -1;
    public ElementImpl fCurrentAnnotationElement;
    public int fDepth = -1;
    public XMLAttributes fEmptyAttr = new XMLAttributesImpl();
    public XMLErrorReporter fErrorReporter;
    public boolean fGenerateSyntheticAnnotation = false;
    public BooleanStack fHasNonSchemaAttributes = new BooleanStack();
    public int fInnerAnnotationDepth = -1;
    public XMLLocator fLocator;
    public NamespaceContext fNamespaceContext = null;
    public BooleanStack fSawAnnotation = new BooleanStack();
    public SchemaDOM schemaDOM;

    public static final class BooleanStack {
        public boolean[] fData;
        public int fDepth;

        private void ensureCapacity(int i2) {
            boolean[] zArr = this.fData;
            if (zArr == null) {
                this.fData = new boolean[32];
            } else if (zArr.length <= i2) {
                boolean[] zArr2 = new boolean[(zArr.length * 2)];
                System.arraycopy(zArr, 0, zArr2, 0, zArr.length);
                this.fData = zArr2;
            }
        }

        public void clear() {
            this.fDepth = 0;
        }

        public boolean pop() {
            boolean[] zArr = this.fData;
            int i2 = this.fDepth - 1;
            this.fDepth = i2;
            return zArr[i2];
        }

        public void push(boolean z) {
            ensureCapacity(this.fDepth + 1);
            boolean[] zArr = this.fData;
            int i2 = this.fDepth;
            this.fDepth = i2 + 1;
            zArr[i2] = z;
        }

        public int size() {
            return this.fDepth;
        }
    }

    public SchemaDOMParser(XMLParserConfiguration xMLParserConfiguration) {
        this.config = xMLParserConfiguration;
        xMLParserConfiguration.setDocumentHandler(this);
        xMLParserConfiguration.setDTDHandler(this);
        xMLParserConfiguration.setDTDContentModelHandler(this);
    }

    private boolean hasNonSchemaAttributes(QName qName, XMLAttributes xMLAttributes) {
        int length = xMLAttributes.getLength();
        for (int i2 = 0; i2 < length; i2++) {
            String uri = xMLAttributes.getURI(i2);
            if (!(uri == null || uri == SchemaSymbols.URI_SCHEMAFORSCHEMA || uri == NamespaceContext.XMLNS_URI || (uri == NamespaceContext.XML_URI && xMLAttributes.getQName(i2) == SchemaSymbols.ATT_XML_LANG && qName.localpart == SchemaSymbols.ELT_SCHEMA))) {
                return true;
            }
        }
        return false;
    }

    @Override // org.apache.xerces.xni.XMLDocumentHandler, org.apache.xerces.impl.xs.opti.DefaultXMLDocumentHandler
    public void characters(XMLString xMLString, Augmentations augmentations) {
        if (this.fInnerAnnotationDepth == -1) {
            for (int i2 = xMLString.offset; i2 < xMLString.offset + xMLString.length; i2++) {
                if (!XMLChar.isSpace(xMLString.ch[i2])) {
                    String str = new String(xMLString.ch, i2, (xMLString.length + xMLString.offset) - i2);
                    this.fErrorReporter.reportError(this.fLocator, XSMessageFormatter.SCHEMA_DOMAIN, "s4s-elt-character", new Object[]{str}, (short) 1);
                    return;
                }
            }
            return;
        }
        this.schemaDOM.characters(xMLString);
    }

    @Override // org.apache.xerces.xni.XMLDocumentHandler, org.apache.xerces.xni.XMLDTDHandler, org.apache.xerces.impl.xs.opti.DefaultXMLDocumentHandler
    public void comment(XMLString xMLString, Augmentations augmentations) {
        if (this.fAnnotationDepth > -1) {
            this.schemaDOM.comment(xMLString);
        }
    }

    @Override // org.apache.xerces.xni.XMLDocumentHandler, org.apache.xerces.impl.xs.opti.DefaultXMLDocumentHandler
    public void emptyElement(QName qName, XMLAttributes xMLAttributes, Augmentations augmentations) {
        String str;
        String str2;
        if (!this.fGenerateSyntheticAnnotation || this.fAnnotationDepth != -1 || qName.uri != SchemaSymbols.URI_SCHEMAFORSCHEMA || qName.localpart == SchemaSymbols.ELT_ANNOTATION || !hasNonSchemaAttributes(qName, xMLAttributes)) {
            if (this.fAnnotationDepth != -1) {
                this.schemaDOM.startAnnotationElement(qName, xMLAttributes);
            } else if (qName.uri == SchemaSymbols.URI_SCHEMAFORSCHEMA && qName.localpart == SchemaSymbols.ELT_ANNOTATION) {
                this.schemaDOM.startAnnotation(qName, xMLAttributes, this.fNamespaceContext);
            }
            ElementImpl emptyElement = this.schemaDOM.emptyElement(qName, xMLAttributes, this.fLocator.getLineNumber(), this.fLocator.getColumnNumber(), this.fLocator.getCharacterOffset());
            if (this.fAnnotationDepth != -1) {
                this.schemaDOM.endAnnotationElement(qName);
            } else if (qName.uri == SchemaSymbols.URI_SCHEMAFORSCHEMA && qName.localpart == SchemaSymbols.ELT_ANNOTATION) {
                this.schemaDOM.endAnnotation(qName, emptyElement);
            }
        } else {
            this.schemaDOM.startElement(qName, xMLAttributes, this.fLocator.getLineNumber(), this.fLocator.getColumnNumber(), this.fLocator.getCharacterOffset());
            xMLAttributes.removeAllAttributes();
            String prefix = this.fNamespaceContext.getPrefix(SchemaSymbols.URI_SCHEMAFORSCHEMA);
            if (prefix.length() == 0) {
                str = SchemaSymbols.ELT_ANNOTATION;
            } else {
                StringBuffer stringBuffer = new StringBuffer();
                stringBuffer.append(prefix);
                stringBuffer.append(':');
                stringBuffer.append(SchemaSymbols.ELT_ANNOTATION);
                str = stringBuffer.toString();
            }
            this.schemaDOM.startAnnotation(str, xMLAttributes, this.fNamespaceContext);
            if (prefix.length() == 0) {
                str2 = SchemaSymbols.ELT_DOCUMENTATION;
            } else {
                StringBuffer stringBuffer2 = new StringBuffer();
                stringBuffer2.append(prefix);
                stringBuffer2.append(':');
                stringBuffer2.append(SchemaSymbols.ELT_DOCUMENTATION);
                str2 = stringBuffer2.toString();
            }
            this.schemaDOM.startAnnotationElement(str2, xMLAttributes);
            this.schemaDOM.charactersRaw("SYNTHETIC_ANNOTATION");
            this.schemaDOM.endSyntheticAnnotationElement(str2, false);
            this.schemaDOM.endSyntheticAnnotationElement(str, true);
            this.schemaDOM.endElement();
        }
    }

    @Override // org.apache.xerces.xni.XMLDocumentHandler, org.apache.xerces.impl.xs.opti.DefaultXMLDocumentHandler
    public void endCDATA(Augmentations augmentations) {
        if (this.fAnnotationDepth != -1) {
            this.schemaDOM.endAnnotationCDATA();
        }
    }

    @Override // org.apache.xerces.xni.XMLDocumentHandler, org.apache.xerces.impl.xs.opti.DefaultXMLDocumentHandler
    public void endDocument(Augmentations augmentations) {
    }

    @Override // org.apache.xerces.xni.XMLDocumentHandler, org.apache.xerces.impl.xs.opti.DefaultXMLDocumentHandler
    public void endElement(QName qName, Augmentations augmentations) {
        String str;
        String str2;
        int i2 = this.fAnnotationDepth;
        if (i2 > -1) {
            int i3 = this.fInnerAnnotationDepth;
            int i4 = this.fDepth;
            if (i3 == i4) {
                this.fInnerAnnotationDepth = -1;
                this.schemaDOM.endAnnotationElement(qName);
            } else if (i2 == i4) {
                this.fAnnotationDepth = -1;
                this.schemaDOM.endAnnotation(qName, this.fCurrentAnnotationElement);
            } else {
                this.schemaDOM.endAnnotationElement(qName);
                this.fDepth--;
            }
        } else if (qName.uri == SchemaSymbols.URI_SCHEMAFORSCHEMA && this.fGenerateSyntheticAnnotation) {
            boolean pop = this.fHasNonSchemaAttributes.pop();
            boolean pop2 = this.fSawAnnotation.pop();
            if (pop && !pop2) {
                String prefix = this.fNamespaceContext.getPrefix(SchemaSymbols.URI_SCHEMAFORSCHEMA);
                if (prefix.length() == 0) {
                    str = SchemaSymbols.ELT_ANNOTATION;
                } else {
                    StringBuffer stringBuffer = new StringBuffer();
                    stringBuffer.append(prefix);
                    stringBuffer.append(':');
                    stringBuffer.append(SchemaSymbols.ELT_ANNOTATION);
                    str = stringBuffer.toString();
                }
                this.schemaDOM.startAnnotation(str, this.fEmptyAttr, this.fNamespaceContext);
                if (prefix.length() == 0) {
                    str2 = SchemaSymbols.ELT_DOCUMENTATION;
                } else {
                    StringBuffer stringBuffer2 = new StringBuffer();
                    stringBuffer2.append(prefix);
                    stringBuffer2.append(':');
                    stringBuffer2.append(SchemaSymbols.ELT_DOCUMENTATION);
                    str2 = stringBuffer2.toString();
                }
                this.schemaDOM.startAnnotationElement(str2, this.fEmptyAttr);
                this.schemaDOM.charactersRaw("SYNTHETIC_ANNOTATION");
                this.schemaDOM.endSyntheticAnnotationElement(str2, false);
                this.schemaDOM.endSyntheticAnnotationElement(str, true);
            }
        }
        this.schemaDOM.endElement();
        this.fDepth--;
    }

    public Document getDocument() {
        return this.schemaDOM;
    }

    public boolean getFeature(String str) {
        return this.config.getFeature(str);
    }

    public Object getProperty(String str) {
        return this.config.getProperty(str);
    }

    @Override // org.apache.xerces.xni.XMLDocumentHandler, org.apache.xerces.impl.xs.opti.DefaultXMLDocumentHandler
    public void ignorableWhitespace(XMLString xMLString, Augmentations augmentations) {
        if (this.fAnnotationDepth != -1) {
            this.schemaDOM.characters(xMLString);
        }
    }

    public void parse(XMLInputSource xMLInputSource) {
        this.config.parse(xMLInputSource);
    }

    @Override // org.apache.xerces.xni.XMLDocumentHandler, org.apache.xerces.xni.XMLDTDHandler, org.apache.xerces.impl.xs.opti.DefaultXMLDocumentHandler
    public void processingInstruction(String str, XMLString xMLString, Augmentations augmentations) {
        if (this.fAnnotationDepth > -1) {
            this.schemaDOM.processingInstruction(str, xMLString);
        }
    }

    public void reset() {
        ((SchemaParsingConfig) this.config).reset();
    }

    public void resetNodePool() {
        ((SchemaParsingConfig) this.config).resetNodePool();
    }

    public void setEntityResolver(XMLEntityResolver xMLEntityResolver) {
        this.config.setEntityResolver(xMLEntityResolver);
    }

    public void setFeature(String str, boolean z) {
        this.config.setFeature(str, z);
    }

    public void setProperty(String str, Object obj) {
        this.config.setProperty(str, obj);
    }

    @Override // org.apache.xerces.xni.XMLDocumentHandler, org.apache.xerces.impl.xs.opti.DefaultXMLDocumentHandler
    public void startCDATA(Augmentations augmentations) {
        if (this.fAnnotationDepth != -1) {
            this.schemaDOM.startAnnotationCDATA();
        }
    }

    @Override // org.apache.xerces.xni.XMLDocumentHandler, org.apache.xerces.impl.xs.opti.DefaultXMLDocumentHandler
    public void startDocument(XMLLocator xMLLocator, String str, NamespaceContext namespaceContext, Augmentations augmentations) {
        this.fErrorReporter = (XMLErrorReporter) this.config.getProperty("http://apache.org/xml/properties/internal/error-reporter");
        this.fGenerateSyntheticAnnotation = this.config.getFeature("http://apache.org/xml/features/generate-synthetic-annotations");
        this.fHasNonSchemaAttributes.clear();
        this.fSawAnnotation.clear();
        SchemaDOM schemaDOM2 = new SchemaDOM();
        this.schemaDOM = schemaDOM2;
        this.fCurrentAnnotationElement = null;
        this.fAnnotationDepth = -1;
        this.fInnerAnnotationDepth = -1;
        this.fDepth = -1;
        this.fLocator = xMLLocator;
        this.fNamespaceContext = namespaceContext;
        schemaDOM2.setDocumentURI(xMLLocator.getExpandedSystemId());
    }

    @Override // org.apache.xerces.xni.XMLDocumentHandler, org.apache.xerces.impl.xs.opti.DefaultXMLDocumentHandler
    public void startElement(QName qName, XMLAttributes xMLAttributes, Augmentations augmentations) {
        int i2 = this.fDepth + 1;
        this.fDepth = i2;
        int i3 = this.fAnnotationDepth;
        if (i3 == -1) {
            if (qName.uri == SchemaSymbols.URI_SCHEMAFORSCHEMA && qName.localpart == SchemaSymbols.ELT_ANNOTATION) {
                if (this.fGenerateSyntheticAnnotation) {
                    if (this.fSawAnnotation.size() > 0) {
                        this.fSawAnnotation.pop();
                    }
                    this.fSawAnnotation.push(true);
                }
                this.fAnnotationDepth = this.fDepth;
                this.schemaDOM.startAnnotation(qName, xMLAttributes, this.fNamespaceContext);
                this.fCurrentAnnotationElement = this.schemaDOM.startElement(qName, xMLAttributes, this.fLocator.getLineNumber(), this.fLocator.getColumnNumber(), this.fLocator.getCharacterOffset());
                return;
            } else if (qName.uri == SchemaSymbols.URI_SCHEMAFORSCHEMA && this.fGenerateSyntheticAnnotation) {
                this.fSawAnnotation.push(false);
                this.fHasNonSchemaAttributes.push(hasNonSchemaAttributes(qName, xMLAttributes));
            }
        } else if (i2 == i3 + 1) {
            this.fInnerAnnotationDepth = i2;
            this.schemaDOM.startAnnotationElement(qName, xMLAttributes);
        } else {
            this.schemaDOM.startAnnotationElement(qName, xMLAttributes);
            return;
        }
        this.schemaDOM.startElement(qName, xMLAttributes, this.fLocator.getLineNumber(), this.fLocator.getColumnNumber(), this.fLocator.getCharacterOffset());
    }
}
