package org.apache.xerces.impl.xs.traversers;

import org.apache.xerces.impl.xs.opti.SchemaDOMParser;
import org.apache.xerces.util.NamespaceSupport;
import org.apache.xerces.util.SAXLocatorWrapper;
import org.apache.xerces.util.SymbolTable;
import org.apache.xerces.util.XMLAttributesImpl;
import org.apache.xerces.util.XMLStringBuffer;
import org.apache.xerces.util.XMLSymbols;
import org.apache.xerces.xni.NamespaceContext;
import org.apache.xerces.xni.QName;
import org.apache.xerces.xni.XMLString;
import org.apache.xerces.xni.XNIException;
import org.apache.xerces.xni.parser.XMLParseException;
import org.w3c.dom.Document;
import org.xml.sax.Attributes;
import org.xml.sax.ContentHandler;
import org.xml.sax.Locator;
import org.xml.sax.SAXException;
import org.xml.sax.SAXParseException;
import org.xml.sax.helpers.LocatorImpl;

public final class SchemaContentHandler implements ContentHandler {
    public final QName fAttributeQName = new QName();
    public final XMLAttributesImpl fAttributes = new XMLAttributesImpl();
    public final QName fElementQName = new QName();
    public NamespaceSupport fNamespaceContext = new NamespaceSupport();
    public boolean fNamespacePrefixes = false;
    public boolean fNeedPushNSContext;
    public final SAXLocatorWrapper fSAXLocatorWrapper = new SAXLocatorWrapper();
    public SchemaDOMParser fSchemaDOMParser;
    public final XMLStringBuffer fStringBuffer = new XMLStringBuffer();
    public boolean fStringsInternalized = false;
    public SymbolTable fSymbolTable;
    public final XMLString fTempString = new XMLString();

    private void addNamespaceDeclarations(int i2) {
        String str;
        String str2;
        for (int i3 = 0; i3 < i2; i3++) {
            String declaredPrefixAt = this.fNamespaceContext.getDeclaredPrefixAt(i3);
            String uri = this.fNamespaceContext.getURI(declaredPrefixAt);
            if (declaredPrefixAt.length() > 0) {
                str2 = XMLSymbols.PREFIX_XMLNS;
                this.fStringBuffer.clear();
                this.fStringBuffer.append(str2);
                this.fStringBuffer.append(':');
                this.fStringBuffer.append(declaredPrefixAt);
                SymbolTable symbolTable = this.fSymbolTable;
                XMLStringBuffer xMLStringBuffer = this.fStringBuffer;
                str = symbolTable.addSymbol(xMLStringBuffer.ch, xMLStringBuffer.offset, xMLStringBuffer.length);
            } else {
                str2 = XMLSymbols.EMPTY_STRING;
                declaredPrefixAt = XMLSymbols.PREFIX_XMLNS;
                str = declaredPrefixAt;
            }
            this.fAttributeQName.setValues(str2, declaredPrefixAt, str, NamespaceContext.XMLNS_URI);
            XMLAttributesImpl xMLAttributesImpl = this.fAttributes;
            QName qName = this.fAttributeQName;
            String str3 = XMLSymbols.fCDATASymbol;
            if (uri == null) {
                uri = XMLSymbols.EMPTY_STRING;
            }
            xMLAttributesImpl.addAttribute(qName, str3, uri);
        }
    }

    public static void convertToSAXException(XNIException xNIException) {
        Exception exception = xNIException.getException();
        if (exception == null) {
            throw new SAXException(xNIException.getMessage());
        } else if (exception instanceof SAXException) {
            throw ((SAXException) exception);
        } else {
            throw new SAXException(exception);
        }
    }

    public static void convertToSAXParseException(XMLParseException xMLParseException) {
        Exception exception = xMLParseException.getException();
        if (exception == null) {
            LocatorImpl locatorImpl = new LocatorImpl();
            locatorImpl.setPublicId(xMLParseException.getPublicId());
            locatorImpl.setSystemId(xMLParseException.getExpandedSystemId());
            locatorImpl.setLineNumber(xMLParseException.getLineNumber());
            locatorImpl.setColumnNumber(xMLParseException.getColumnNumber());
            throw new SAXParseException(xMLParseException.getMessage(), locatorImpl);
        } else if (exception instanceof SAXException) {
            throw ((SAXException) exception);
        } else {
            throw new SAXException(exception);
        }
    }

    private void fillQName(QName qName, String str, String str2, String str3) {
        String str4;
        String str5 = null;
        if (!this.fStringsInternalized) {
            if (str != null && str.length() > 0) {
                str5 = this.fSymbolTable.addSymbol(str);
            }
            str4 = str2 != null ? this.fSymbolTable.addSymbol(str2) : XMLSymbols.EMPTY_STRING;
            str3 = str3 != null ? this.fSymbolTable.addSymbol(str3) : XMLSymbols.EMPTY_STRING;
        } else {
            if (str != null && str.length() == 0) {
                str = null;
            }
            if (str2 == null) {
                str2 = XMLSymbols.EMPTY_STRING;
            }
            if (str3 == null) {
                str3 = XMLSymbols.EMPTY_STRING;
            }
            str5 = str;
            str4 = str2;
        }
        String str6 = XMLSymbols.EMPTY_STRING;
        int indexOf = str3.indexOf(58);
        if (indexOf != -1) {
            str6 = this.fSymbolTable.addSymbol(str3.substring(0, indexOf));
            if (str4 == XMLSymbols.EMPTY_STRING) {
                str4 = this.fSymbolTable.addSymbol(str3.substring(indexOf + 1));
            }
        } else if (str4 == XMLSymbols.EMPTY_STRING) {
            str4 = str3;
        }
        qName.setValues(str6, str4, str3, str5);
    }

    private void fillXMLAttributes(Attributes attributes) {
        this.fAttributes.removeAllAttributes();
        int length = attributes.getLength();
        for (int i2 = 0; i2 < length; i2++) {
            fillQName(this.fAttributeQName, attributes.getURI(i2), attributes.getLocalName(i2), attributes.getQName(i2));
            String type = attributes.getType(i2);
            XMLAttributesImpl xMLAttributesImpl = this.fAttributes;
            QName qName = this.fAttributeQName;
            if (type == null) {
                type = XMLSymbols.fCDATASymbol;
            }
            xMLAttributesImpl.addAttributeNS(qName, type, attributes.getValue(i2));
            this.fAttributes.setSpecified(i2, true);
        }
    }

    @Override // org.xml.sax.ContentHandler
    public void characters(char[] cArr, int i2, int i3) {
        try {
            this.fTempString.setValues(cArr, i2, i3);
            this.fSchemaDOMParser.characters(this.fTempString, null);
        } catch (XMLParseException e2) {
            convertToSAXParseException(e2);
        } catch (XNIException e3) {
            convertToSAXException(e3);
        }
    }

    @Override // org.xml.sax.ContentHandler
    public void endDocument() {
        this.fSAXLocatorWrapper.setLocator(null);
        try {
            this.fSchemaDOMParser.endDocument(null);
        } catch (XMLParseException e2) {
            convertToSAXParseException(e2);
        } catch (XNIException e3) {
            convertToSAXException(e3);
        }
    }

    @Override // org.xml.sax.ContentHandler
    public void endElement(String str, String str2, String str3) {
        fillQName(this.fElementQName, str, str2, str3);
        try {
            this.fSchemaDOMParser.endElement(this.fElementQName, null);
        } catch (XMLParseException e2) {
            convertToSAXParseException(e2);
        } catch (XNIException e3) {
            convertToSAXException(e3);
        } catch (Throwable th) {
            this.fNamespaceContext.popContext();
            throw th;
        }
        this.fNamespaceContext.popContext();
    }

    @Override // org.xml.sax.ContentHandler
    public void endPrefixMapping(String str) {
    }

    public Document getDocument() {
        return this.fSchemaDOMParser.getDocument();
    }

    @Override // org.xml.sax.ContentHandler
    public void ignorableWhitespace(char[] cArr, int i2, int i3) {
        try {
            this.fTempString.setValues(cArr, i2, i3);
            this.fSchemaDOMParser.ignorableWhitespace(this.fTempString, null);
        } catch (XMLParseException e2) {
            convertToSAXParseException(e2);
        } catch (XNIException e3) {
            convertToSAXException(e3);
        }
    }

    @Override // org.xml.sax.ContentHandler
    public void processingInstruction(String str, String str2) {
        try {
            this.fTempString.setValues(str2.toCharArray(), 0, str2.length());
            this.fSchemaDOMParser.processingInstruction(str, this.fTempString, null);
        } catch (XMLParseException e2) {
            convertToSAXParseException(e2);
        } catch (XNIException e3) {
            convertToSAXException(e3);
        }
    }

    public void reset(SchemaDOMParser schemaDOMParser, SymbolTable symbolTable, boolean z, boolean z2) {
        this.fSchemaDOMParser = schemaDOMParser;
        this.fSymbolTable = symbolTable;
        this.fNamespacePrefixes = z;
        this.fStringsInternalized = z2;
    }

    @Override // org.xml.sax.ContentHandler
    public void setDocumentLocator(Locator locator) {
        this.fSAXLocatorWrapper.setLocator(locator);
    }

    @Override // org.xml.sax.ContentHandler
    public void skippedEntity(String str) {
    }

    @Override // org.xml.sax.ContentHandler
    public void startDocument() {
        this.fNeedPushNSContext = true;
        this.fNamespaceContext.reset();
        try {
            this.fSchemaDOMParser.startDocument(this.fSAXLocatorWrapper, null, this.fNamespaceContext, null);
        } catch (XMLParseException e2) {
            convertToSAXParseException(e2);
        } catch (XNIException e3) {
            convertToSAXException(e3);
        }
    }

    @Override // org.xml.sax.ContentHandler
    public void startElement(String str, String str2, String str3, Attributes attributes) {
        int declaredPrefixCount;
        if (this.fNeedPushNSContext) {
            this.fNamespaceContext.pushContext();
        }
        this.fNeedPushNSContext = true;
        fillQName(this.fElementQName, str, str2, str3);
        fillXMLAttributes(attributes);
        if (!this.fNamespacePrefixes && (declaredPrefixCount = this.fNamespaceContext.getDeclaredPrefixCount()) > 0) {
            addNamespaceDeclarations(declaredPrefixCount);
        }
        try {
            this.fSchemaDOMParser.startElement(this.fElementQName, this.fAttributes, null);
        } catch (XMLParseException e2) {
            convertToSAXParseException(e2);
        } catch (XNIException e3) {
            convertToSAXException(e3);
        }
    }

    /* JADX WARNING: Code restructure failed: missing block: B:16:0x0035, code lost:
        if (r4.length() == 0) goto L_0x0037;
     */
    @Override // org.xml.sax.ContentHandler
    public void startPrefixMapping(String str, String str2) {
        if (this.fNeedPushNSContext) {
            this.fNeedPushNSContext = false;
            this.fNamespaceContext.pushContext();
        }
        if (!this.fStringsInternalized) {
            str = str != null ? this.fSymbolTable.addSymbol(str) : XMLSymbols.EMPTY_STRING;
            if (str2 != null && str2.length() > 0) {
                str2 = this.fSymbolTable.addSymbol(str2);
                this.fNamespaceContext.declarePrefix(str, str2);
            }
        } else {
            if (str == null) {
                str = XMLSymbols.EMPTY_STRING;
            }
            if (str2 != null) {
            }
            this.fNamespaceContext.declarePrefix(str, str2);
        }
        str2 = null;
        this.fNamespaceContext.declarePrefix(str, str2);
    }
}
