package org.apache.xerces.impl.xs.traversers;

import java.util.Locale;
import java.util.Vector;
import org.apache.xerces.impl.dv.InvalidDatatypeValueException;
import org.apache.xerces.impl.dv.ValidatedInfo;
import org.apache.xerces.impl.dv.ValidationContext;
import org.apache.xerces.impl.dv.XSFacets;
import org.apache.xerces.impl.dv.XSSimpleType;
import org.apache.xerces.impl.validation.ValidationState;
import org.apache.xerces.impl.xs.SchemaGrammar;
import org.apache.xerces.impl.xs.SchemaSymbols;
import org.apache.xerces.impl.xs.XSAnnotationImpl;
import org.apache.xerces.impl.xs.XSAttributeGroupDecl;
import org.apache.xerces.impl.xs.XSAttributeUseImpl;
import org.apache.xerces.impl.xs.XSComplexTypeDecl;
import org.apache.xerces.impl.xs.XSElementDecl;
import org.apache.xerces.impl.xs.XSParticleDecl;
import org.apache.xerces.impl.xs.XSWildcardDecl;
import org.apache.xerces.impl.xs.util.XInt;
import org.apache.xerces.impl.xs.util.XSObjectListImpl;
import org.apache.xerces.util.DOMUtil;
import org.apache.xerces.util.NamespaceSupport;
import org.apache.xerces.util.SymbolTable;
import org.apache.xerces.xni.QName;
import org.apache.xerces.xs.XSAttributeUse;
import org.apache.xerces.xs.XSObjectList;
import org.apache.xerces.xs.XSSimpleTypeDefinition;
import org.apache.xerces.xs.XSTypeDefinition;
import org.apache.xmlbeans.XmlErrorCodes;
import org.w3c.dom.Element;

public abstract class XSDAbstractTraverser {
    public static final int CHILD_OF_GROUP = 4;
    public static final int GROUP_REF_WITH_ALL = 2;
    public static final int NOT_ALL_CONTEXT = 0;
    public static final String NO_NAME = "(no name)";
    public static final int PROCESSING_ALL_EL = 1;
    public static final int PROCESSING_ALL_GP = 8;
    public static final XSSimpleType fQNameDV = ((XSSimpleType) SchemaGrammar.SG_SchemaNS.getGlobalTypeDecl("QName"));
    public XSAttributeChecker fAttrChecker = null;
    public StringBuffer fPattern = new StringBuffer();
    public XSDHandler fSchemaHandler = null;
    public SymbolTable fSymbolTable = null;
    public boolean fValidateAnnotations = false;
    public ValidationState fValidationState = new ValidationState();
    public final XSFacets xsFacets = new XSFacets();

    public static final class FacetInfo {
        public final short fFixedFacets;
        public final short fPresentFacets;
        public final XSFacets facetdata;
        public final Element nodeAfterFacets;

        public FacetInfo(XSFacets xSFacets, Element element, short s, short s2) {
            this.facetdata = xSFacets;
            this.nodeAfterFacets = element;
            this.fPresentFacets = s;
            this.fFixedFacets = s2;
        }
    }

    public XSDAbstractTraverser(XSDHandler xSDHandler, XSAttributeChecker xSAttributeChecker) {
        this.fSchemaHandler = xSDHandler;
        this.fAttrChecker = xSAttributeChecker;
    }

    private boolean containsQName(XSSimpleType xSSimpleType) {
        if (xSSimpleType.getVariety() == 1) {
            short primitiveKind = xSSimpleType.getPrimitiveKind();
            return primitiveKind == 18 || primitiveKind == 20;
        } else if (xSSimpleType.getVariety() == 2) {
            return containsQName((XSSimpleType) xSSimpleType.getItemType());
        } else {
            if (xSSimpleType.getVariety() == 3) {
                XSObjectList memberTypes = xSSimpleType.getMemberTypes();
                for (int i2 = 0; i2 < memberTypes.getLength(); i2++) {
                    if (containsQName((XSSimpleType) memberTypes.item(i2))) {
                        return true;
                    }
                }
            }
            return false;
        }
    }

    public static String escapeAttValue(String str, int i2) {
        String str2;
        int length = str.length();
        StringBuffer stringBuffer = new StringBuffer(length);
        stringBuffer.append(str.substring(0, i2));
        while (i2 < length) {
            char charAt = str.charAt(i2);
            if (charAt == '\"') {
                str2 = "&quot;";
            } else if (charAt == '<') {
                str2 = "&lt;";
            } else if (charAt == '&') {
                str2 = "&amp;";
            } else if (charAt == '\t') {
                str2 = "&#x9;";
            } else if (charAt == '\n') {
                str2 = "&#xA;";
            } else if (charAt == '\r') {
                str2 = "&#xD;";
            } else {
                stringBuffer.append(charAt);
                i2++;
            }
            stringBuffer.append(str2);
            i2++;
        }
        return stringBuffer.toString();
    }

    public static String processAttValue(String str) {
        int length = str.length();
        for (int i2 = 0; i2 < length; i2++) {
            char charAt = str.charAt(i2);
            if (charAt == '\"' || charAt == '<' || charAt == '&' || charAt == '\t' || charAt == '\n' || charAt == '\r') {
                return escapeAttValue(str, i2);
            }
        }
        return str;
    }

    public void checkNotationType(String str, XSTypeDefinition xSTypeDefinition, Element element) {
        if (xSTypeDefinition.getTypeCategory() == 16) {
            XSSimpleType xSSimpleType = (XSSimpleType) xSTypeDefinition;
            if (xSSimpleType.getVariety() == 1 && xSSimpleType.getPrimitiveKind() == 20 && (xSSimpleType.getDefinedFacets() & 2048) == 0) {
                reportSchemaError(XmlErrorCodes.DATATYPE_ENUM_NOTATION, new Object[]{xSTypeDefinition.getName(), str, DOMUtil.getLocalName(element)}, element);
            }
        }
    }

    /* JADX WARNING: Code restructure failed: missing block: B:43:0x0092, code lost:
        if (r3 > 1) goto L_0x00a4;
     */
    public XSParticleDecl checkOccurrences(XSParticleDecl xSParticleDecl, String str, Element element, int i2, long j) {
        int i3 = xSParticleDecl.fMinOccurs;
        int i4 = xSParticleDecl.fMaxOccurs;
        int i5 = 1;
        boolean z = (j & ((long) (1 << XSAttributeChecker.ATTIDX_MINOCCURS))) != 0;
        boolean z2 = (j & ((long) (1 << XSAttributeChecker.ATTIDX_MAXOCCURS))) != 0;
        boolean z3 = (i2 & 1) != 0;
        boolean z4 = (i2 & 8) != 0;
        boolean z5 = (i2 & 2) != 0;
        if ((i2 & 4) != 0) {
            if (!z) {
                reportSchemaError("s4s-att-not-allowed", new Object[]{str, "minOccurs"}, element);
                i3 = 1;
            }
            if (!z2) {
                reportSchemaError("s4s-att-not-allowed", new Object[]{str, "maxOccurs"}, element);
                i4 = 1;
            }
        }
        if (i3 == 0 && i4 == 0) {
            xSParticleDecl.fType = 0;
            return null;
        }
        if (z3) {
            if (i4 != 1) {
                Object[] objArr = new Object[2];
                objArr[0] = i4 == -1 ? SchemaSymbols.ATTVAL_UNBOUNDED : Integer.toString(i4);
                objArr[1] = ((XSElementDecl) xSParticleDecl.fValue).getName();
                reportSchemaError(XmlErrorCodes.ALL_GROUP_LIMITED$CHILD_PARTICLES_MAX_LTE_1, objArr, element);
            }
            i5 = i3;
            xSParticleDecl.fMinOccurs = i5;
            xSParticleDecl.fMaxOccurs = i4;
            return xSParticleDecl;
        }
        if ((z4 || z5) && i4 != 1) {
            reportSchemaError("cos-all-limited.1.2", null, element);
            if (i3 > 1) {
                i3 = 1;
            }
        }
        i5 = i3;
        xSParticleDecl.fMinOccurs = i5;
        xSParticleDecl.fMaxOccurs = i4;
        return xSParticleDecl;
        i5 = i3;
        i4 = 1;
        xSParticleDecl.fMinOccurs = i5;
        xSParticleDecl.fMaxOccurs = i4;
        return xSParticleDecl;
    }

    public void reportSchemaError(String str, Object[] objArr, Element element) {
        this.fSchemaHandler.reportSchemaError(str, objArr, element);
    }

    public void reset(SymbolTable symbolTable, boolean z, Locale locale) {
        this.fSymbolTable = symbolTable;
        this.fValidateAnnotations = z;
        this.fValidationState.setExtraChecking(false);
        this.fValidationState.setSymbolTable(symbolTable);
        this.fValidationState.setLocale(locale);
    }

    public XSAnnotationImpl traverseAnnotationDecl(Element element, Object[] objArr, boolean z, XSDocumentInfo xSDocumentInfo) {
        String str;
        String str2;
        this.fAttrChecker.returnAttrArray(this.fAttrChecker.checkAttributes(element, z, xSDocumentInfo), xSDocumentInfo);
        String annotation = DOMUtil.getAnnotation(element);
        Element firstChildElement = DOMUtil.getFirstChildElement(element);
        if (firstChildElement != null) {
            do {
                String localName = DOMUtil.getLocalName(firstChildElement);
                if (localName.equals(SchemaSymbols.ELT_APPINFO) || localName.equals(SchemaSymbols.ELT_DOCUMENTATION)) {
                    this.fAttrChecker.returnAttrArray(this.fAttrChecker.checkAttributes(firstChildElement, true, xSDocumentInfo), xSDocumentInfo);
                } else {
                    reportSchemaError(XmlErrorCodes.SCHEMA_ANNOTATION, new Object[]{localName}, firstChildElement);
                }
                firstChildElement = DOMUtil.getNextSiblingElement(firstChildElement);
            } while (firstChildElement != null);
        }
        if (annotation == null) {
            return null;
        }
        SchemaGrammar grammar = this.fSchemaHandler.getGrammar(xSDocumentInfo.fTargetNamespace);
        Vector vector = (Vector) objArr[XSAttributeChecker.ATTIDX_NONSCHEMA];
        if (vector == null || vector.isEmpty()) {
            if (this.fValidateAnnotations) {
                xSDocumentInfo.addAnnotation(new XSAnnotationInfo(annotation, element));
            }
            return new XSAnnotationImpl(annotation, grammar);
        }
        StringBuffer stringBuffer = new StringBuffer(64);
        stringBuffer.append(" ");
        int i2 = 0;
        while (i2 < vector.size()) {
            int i3 = i2 + 1;
            String str3 = (String) vector.elementAt(i2);
            int indexOf = str3.indexOf(58);
            if (indexOf == -1) {
                str2 = "";
                str = str3;
            } else {
                str2 = str3.substring(0, indexOf);
                str = str3.substring(indexOf + 1);
            }
            if (element.getAttributeNS(xSDocumentInfo.fNamespaceSupport.getURI(this.fSymbolTable.addSymbol(str2)), str).length() != 0) {
                i2 = i3 + 1;
            } else {
                stringBuffer.append(str3);
                stringBuffer.append("=\"");
                i2 = i3 + 1;
                stringBuffer.append(processAttValue((String) vector.elementAt(i3)));
                stringBuffer.append("\" ");
            }
        }
        StringBuffer stringBuffer2 = new StringBuffer(stringBuffer.length() + annotation.length());
        int indexOf2 = annotation.indexOf(SchemaSymbols.ELT_ANNOTATION);
        if (indexOf2 == -1) {
            return null;
        }
        int length = SchemaSymbols.ELT_ANNOTATION.length() + indexOf2;
        stringBuffer2.append(annotation.substring(0, length));
        stringBuffer2.append(stringBuffer.toString());
        stringBuffer2.append(annotation.substring(length, annotation.length()));
        String stringBuffer3 = stringBuffer2.toString();
        if (this.fValidateAnnotations) {
            xSDocumentInfo.addAnnotation(new XSAnnotationInfo(stringBuffer3, element));
        }
        return new XSAnnotationImpl(stringBuffer3, grammar);
    }

    public Element traverseAttrsAndAttrGrps(Element element, XSAttributeGroupDecl xSAttributeGroupDecl, XSDocumentInfo xSDocumentInfo, SchemaGrammar schemaGrammar, XSComplexTypeDecl xSComplexTypeDecl) {
        String str;
        String str2;
        int i2;
        XSAttributeGroupDecl xSAttributeGroupDecl2;
        XSObjectList xSObjectList;
        Element element2 = element;
        while (true) {
            str = "src-attribute_group.2";
            str2 = "src-ct.4";
            char c = 0;
            if (element2 == null) {
                break;
            }
            String localName = DOMUtil.getLocalName(element2);
            boolean equals = localName.equals(SchemaSymbols.ELT_ATTRIBUTE);
            String str3 = XmlErrorCodes.ATTR_GROUP_PROPERTIES$TWO_IDS;
            String str4 = XmlErrorCodes.ATTR_GROUP_PROPERTIES$2;
            if (!equals) {
                if (!localName.equals(SchemaSymbols.ELT_ATTRIBUTEGROUP)) {
                    break;
                }
                XSAttributeGroupDecl traverseLocal = this.fSchemaHandler.fAttributeGroupTraverser.traverseLocal(element2, xSDocumentInfo, schemaGrammar);
                if (traverseLocal != null) {
                    XSObjectList attributeUses = traverseLocal.getAttributeUses();
                    int length = attributeUses.getLength();
                    int i3 = 0;
                    while (i3 < length) {
                        XSAttributeUseImpl xSAttributeUseImpl = (XSAttributeUseImpl) attributeUses.item(i3);
                        if (xSAttributeUseImpl.fUse == 2) {
                            xSAttributeGroupDecl.addAttributeUse(xSAttributeUseImpl);
                            xSAttributeGroupDecl2 = traverseLocal;
                            xSObjectList = attributeUses;
                            i2 = length;
                        } else {
                            XSAttributeUse attributeUseNoProhibited = xSAttributeGroupDecl.getAttributeUseNoProhibited(xSAttributeUseImpl.fAttrDecl.getNamespace(), xSAttributeUseImpl.fAttrDecl.getName());
                            if (attributeUseNoProhibited == null) {
                                String addAttributeUse = xSAttributeGroupDecl.addAttributeUse(xSAttributeUseImpl);
                                if (addAttributeUse != null) {
                                    xSAttributeGroupDecl2 = traverseLocal;
                                    xSObjectList = attributeUses;
                                    i2 = length;
                                    reportSchemaError(xSComplexTypeDecl == null ? str3 : "ct-props-correct.5", new Object[]{xSComplexTypeDecl == null ? xSAttributeGroupDecl.fName : xSComplexTypeDecl.getName(), xSAttributeUseImpl.fAttrDecl.getName(), addAttributeUse}, element2);
                                } else {
                                    xSAttributeGroupDecl2 = traverseLocal;
                                    xSObjectList = attributeUses;
                                    i2 = length;
                                }
                            } else {
                                xSAttributeGroupDecl2 = traverseLocal;
                                xSObjectList = attributeUses;
                                i2 = length;
                                if (xSAttributeUseImpl != attributeUseNoProhibited) {
                                    reportSchemaError(xSComplexTypeDecl == null ? str4 : XmlErrorCodes.COMPLEX_TYPE_PROPERTIES$DUPLICATE_ATTRIBUTE, new Object[]{xSComplexTypeDecl == null ? xSAttributeGroupDecl.fName : xSComplexTypeDecl.getName(), xSAttributeUseImpl.fAttrDecl.getName()}, element2);
                                }
                            }
                        }
                        i3++;
                        attributeUses = xSObjectList;
                        str = str;
                        str2 = str2;
                        traverseLocal = xSAttributeGroupDecl2;
                        length = i2;
                        c = 0;
                    }
                    XSWildcardDecl xSWildcardDecl = traverseLocal.fAttributeWC;
                    if (xSWildcardDecl != null) {
                        XSWildcardDecl xSWildcardDecl2 = xSAttributeGroupDecl.fAttributeWC;
                        if (xSWildcardDecl2 == null) {
                            xSAttributeGroupDecl.fAttributeWC = xSWildcardDecl;
                        } else {
                            XSWildcardDecl performIntersectionWith = xSWildcardDecl2.performIntersectionWith(xSWildcardDecl, xSWildcardDecl2.fProcessContents);
                            xSAttributeGroupDecl.fAttributeWC = performIntersectionWith;
                            if (performIntersectionWith == null) {
                                if (xSComplexTypeDecl != null) {
                                    str = str2;
                                }
                                Object[] objArr = new Object[1];
                                objArr[c] = xSComplexTypeDecl == null ? xSAttributeGroupDecl.fName : xSComplexTypeDecl.getName();
                                reportSchemaError(str, objArr, element2);
                            }
                        }
                    }
                }
            } else {
                XSAttributeUseImpl traverseLocal2 = this.fSchemaHandler.fAttributeTraverser.traverseLocal(element2, xSDocumentInfo, schemaGrammar, xSComplexTypeDecl);
                if (traverseLocal2 != null) {
                    if (traverseLocal2.fUse == 2) {
                        xSAttributeGroupDecl.addAttributeUse(traverseLocal2);
                    } else {
                        XSAttributeUse attributeUseNoProhibited2 = xSAttributeGroupDecl.getAttributeUseNoProhibited(traverseLocal2.fAttrDecl.getNamespace(), traverseLocal2.fAttrDecl.getName());
                        if (attributeUseNoProhibited2 == null) {
                            String addAttributeUse2 = xSAttributeGroupDecl.addAttributeUse(traverseLocal2);
                            if (addAttributeUse2 != null) {
                                if (xSComplexTypeDecl != null) {
                                    str3 = "ct-props-correct.5";
                                }
                                reportSchemaError(str3, new Object[]{xSComplexTypeDecl == null ? xSAttributeGroupDecl.fName : xSComplexTypeDecl.getName(), traverseLocal2.fAttrDecl.getName(), addAttributeUse2}, element2);
                            }
                        } else if (attributeUseNoProhibited2 != traverseLocal2) {
                            if (xSComplexTypeDecl != null) {
                                str4 = XmlErrorCodes.COMPLEX_TYPE_PROPERTIES$DUPLICATE_ATTRIBUTE;
                            }
                            reportSchemaError(str4, new Object[]{xSComplexTypeDecl == null ? xSAttributeGroupDecl.fName : xSComplexTypeDecl.getName(), traverseLocal2.fAttrDecl.getName()}, element2);
                        }
                    }
                }
            }
            element2 = DOMUtil.getNextSiblingElement(element2);
        }
        if (element2 == null || !DOMUtil.getLocalName(element2).equals(SchemaSymbols.ELT_ANYATTRIBUTE)) {
            return element2;
        }
        XSWildcardDecl traverseAnyAttribute = this.fSchemaHandler.fWildCardTraverser.traverseAnyAttribute(element2, xSDocumentInfo, schemaGrammar);
        XSWildcardDecl xSWildcardDecl3 = xSAttributeGroupDecl.fAttributeWC;
        if (xSWildcardDecl3 == null) {
            xSAttributeGroupDecl.fAttributeWC = traverseAnyAttribute;
        } else {
            XSWildcardDecl performIntersectionWith2 = traverseAnyAttribute.performIntersectionWith(xSWildcardDecl3, traverseAnyAttribute.fProcessContents);
            xSAttributeGroupDecl.fAttributeWC = performIntersectionWith2;
            if (performIntersectionWith2 == null) {
                reportSchemaError(xSComplexTypeDecl == null ? str : str2, new Object[]{xSComplexTypeDecl == null ? xSAttributeGroupDecl.fName : xSComplexTypeDecl.getName()}, element2);
            }
        }
        return DOMUtil.getNextSiblingElement(element2);
    }

    /* JADX DEBUG: Multi-variable search result rejected for r20v0, resolved type: boolean */
    /* JADX WARN: Multi-variable type inference failed */
    /* JADX WARNING: Removed duplicated region for block: B:40:0x0133  */
    /* JADX WARNING: Removed duplicated region for block: B:65:0x01ff  */
    public FacetInfo traverseFacets(Element element, XSSimpleType xSSimpleType, XSDocumentInfo xSDocumentInfo) {
        short s;
        XSObjectListImpl xSObjectListImpl;
        Vector vector;
        short s2;
        boolean z;
        Object[] objArr;
        short s3;
        String str;
        short s4;
        short s5;
        XSAnnotationImpl xSAnnotationImpl;
        XSObjectListImpl xSObjectListImpl2;
        String str2;
        Vector vector2;
        int i2;
        XSObjectListImpl xSObjectListImpl3;
        String str3;
        short s6;
        short s7;
        Object[] objArr2;
        char c;
        Object obj;
        boolean containsQName = containsQName(xSSimpleType);
        Vector vector3 = containsQName ? new Vector() : null;
        this.xsFacets.reset();
        boolean z2 = false;
        Element element2 = element;
        short s8 = 0;
        short s9 = 0;
        XSObjectListImpl xSObjectListImpl4 = null;
        Vector vector4 = null;
        XSObjectListImpl xSObjectListImpl5 = null;
        while (true) {
            if (element2 == null) {
                s = s9;
                xSObjectListImpl = xSObjectListImpl4;
                vector = vector4;
                break;
            }
            String localName = DOMUtil.getLocalName(element2);
            if (localName.equals(SchemaSymbols.ELT_ENUMERATION)) {
                Object[] checkAttributes = this.fAttrChecker.checkAttributes(element2, z2, xSDocumentInfo, containsQName);
                String str4 = (String) checkAttributes[XSAttributeChecker.ATTIDX_VALUE];
                if (str4 == null) {
                    Object[] objArr3 = new Object[2];
                    Object obj2 = SchemaSymbols.ELT_ENUMERATION;
                    char c2 = z2 ? 1 : 0;
                    char c3 = z2 ? 1 : 0;
                    char c4 = z2 ? 1 : 0;
                    char c5 = z2 ? 1 : 0;
                    objArr3[c2] = obj2;
                    objArr3[1] = SchemaSymbols.ATT_VALUE;
                    reportSchemaError("s4s-att-must-appear", objArr3, element2);
                    this.fAttrChecker.returnAttrArray(checkAttributes, xSDocumentInfo);
                    element2 = DOMUtil.getNextSiblingElement(element2);
                    xSObjectListImpl4 = xSObjectListImpl4;
                } else {
                    NamespaceSupport namespaceSupport = (NamespaceSupport) checkAttributes[XSAttributeChecker.ATTIDX_ENUMNSDECLS];
                    if (xSSimpleType.getVariety() == 1 && xSSimpleType.getPrimitiveKind() == 20) {
                        xSDocumentInfo.fValidationContext.setNamespaceSupport(namespaceSupport);
                        try {
                            obj = this.fSchemaHandler.getGlobalDecl(xSDocumentInfo, 6, (QName) fQNameDV.validate(str4, (ValidationContext) xSDocumentInfo.fValidationContext, (ValidatedInfo) null), element2);
                        } catch (InvalidDatatypeValueException e2) {
                            reportSchemaError(e2.getKey(), e2.getArgs(), element2);
                            obj = null;
                        }
                        if (obj == null) {
                            this.fAttrChecker.returnAttrArray(checkAttributes, xSDocumentInfo);
                            element2 = DOMUtil.getNextSiblingElement(element2);
                            xSObjectListImpl4 = xSObjectListImpl4;
                        } else {
                            xSDocumentInfo.fValidationContext.setNamespaceSupport(xSDocumentInfo.fNamespaceSupport);
                        }
                    }
                    if (vector4 == null) {
                        vector4 = new Vector();
                        xSObjectListImpl3 = new XSObjectListImpl();
                    } else {
                        xSObjectListImpl3 = xSObjectListImpl4;
                    }
                    vector4.addElement(str4);
                    xSObjectListImpl3.addXSObject(null);
                    if (containsQName) {
                        vector3.addElement(namespaceSupport);
                    }
                    Element firstChildElement = DOMUtil.getFirstChildElement(element2);
                    if (firstChildElement == null || !DOMUtil.getLocalName(firstChildElement).equals(SchemaSymbols.ELT_ANNOTATION)) {
                        String syntheticAnnotation = DOMUtil.getSyntheticAnnotation(element2);
                        if (syntheticAnnotation != null) {
                            objArr2 = checkAttributes;
                            s7 = s8;
                            s6 = s9;
                            str3 = "s4s-elt-must-match.1";
                            c = 2;
                            xSObjectListImpl3.addXSObject(xSObjectListImpl3.getLength() - 1, traverseSyntheticAnnotation(element2, syntheticAnnotation, objArr2, false, xSDocumentInfo));
                            if (firstChildElement != null) {
                                Object[] objArr4 = new Object[3];
                                objArr4[0] = "enumeration";
                                objArr4[1] = "(annotation?)";
                                objArr4[c] = DOMUtil.getLocalName(firstChildElement);
                                reportSchemaError(str3, objArr4, firstChildElement);
                            }
                            xSObjectListImpl4 = xSObjectListImpl3;
                            z = containsQName;
                            vector4 = vector4;
                            objArr = objArr2;
                            s8 = s7;
                            s9 = s6;
                            this.fAttrChecker.returnAttrArray(objArr, xSDocumentInfo);
                            element2 = DOMUtil.getNextSiblingElement(element2);
                            containsQName = z;
                        }
                    } else {
                        xSObjectListImpl3.addXSObject(xSObjectListImpl3.getLength() - 1, traverseAnnotationDecl(firstChildElement, checkAttributes, false, xSDocumentInfo));
                        firstChildElement = DOMUtil.getNextSiblingElement(firstChildElement);
                    }
                    objArr2 = checkAttributes;
                    s7 = s8;
                    s6 = s9;
                    str3 = "s4s-elt-must-match.1";
                    c = 2;
                    if (firstChildElement != null) {
                    }
                    xSObjectListImpl4 = xSObjectListImpl3;
                    z = containsQName;
                    vector4 = vector4;
                    objArr = objArr2;
                    s8 = s7;
                    s9 = s6;
                    this.fAttrChecker.returnAttrArray(objArr, xSDocumentInfo);
                    element2 = DOMUtil.getNextSiblingElement(element2);
                    containsQName = z;
                }
            } else if (localName.equals(SchemaSymbols.ELT_PATTERN)) {
                Object[] checkAttributes2 = this.fAttrChecker.checkAttributes(element2, false, xSDocumentInfo);
                String str5 = (String) checkAttributes2[XSAttributeChecker.ATTIDX_VALUE];
                if (str5 == null) {
                    reportSchemaError("s4s-att-must-appear", new Object[]{SchemaSymbols.ELT_PATTERN, SchemaSymbols.ATT_VALUE}, element2);
                    this.fAttrChecker.returnAttrArray(checkAttributes2, xSDocumentInfo);
                    element2 = DOMUtil.getNextSiblingElement(element2);
                    xSObjectListImpl4 = xSObjectListImpl4;
                    s8 = s8;
                    s9 = s9;
                } else {
                    if (this.fPattern.length() != 0) {
                        this.fPattern.append("|");
                    }
                    this.fPattern.append(str5);
                    Element firstChildElement2 = DOMUtil.getFirstChildElement(element2);
                    if (firstChildElement2 == null || !DOMUtil.getLocalName(firstChildElement2).equals(SchemaSymbols.ELT_ANNOTATION)) {
                        String syntheticAnnotation2 = DOMUtil.getSyntheticAnnotation(element2);
                        if (syntheticAnnotation2 != null) {
                            if (xSObjectListImpl5 == null) {
                                xSObjectListImpl5 = new XSObjectListImpl();
                            }
                            str2 = "s4s-elt-must-match.1";
                            xSObjectListImpl2 = xSObjectListImpl4;
                            i2 = 3;
                            vector2 = vector4;
                            xSObjectListImpl5.addXSObject(traverseSyntheticAnnotation(element2, syntheticAnnotation2, checkAttributes2, false, xSDocumentInfo));
                            if (firstChildElement2 != null) {
                                Object[] objArr5 = new Object[i2];
                                objArr5[0] = "pattern";
                                objArr5[1] = "(annotation?)";
                                objArr5[2] = DOMUtil.getLocalName(firstChildElement2);
                                reportSchemaError(str2, objArr5, firstChildElement2);
                            }
                            objArr = checkAttributes2;
                            z = containsQName;
                            vector4 = vector2;
                            s8 = s8;
                            s9 = s9;
                            xSObjectListImpl4 = xSObjectListImpl2;
                            this.fAttrChecker.returnAttrArray(objArr, xSDocumentInfo);
                            element2 = DOMUtil.getNextSiblingElement(element2);
                            containsQName = z;
                        }
                    } else {
                        if (xSObjectListImpl5 == null) {
                            xSObjectListImpl5 = new XSObjectListImpl();
                        }
                        xSObjectListImpl5.addXSObject(traverseAnnotationDecl(firstChildElement2, checkAttributes2, false, xSDocumentInfo));
                        firstChildElement2 = DOMUtil.getNextSiblingElement(firstChildElement2);
                    }
                    xSObjectListImpl2 = xSObjectListImpl4;
                    str2 = "s4s-elt-must-match.1";
                    vector2 = vector4;
                    i2 = 3;
                    if (firstChildElement2 != null) {
                    }
                    objArr = checkAttributes2;
                    z = containsQName;
                    vector4 = vector2;
                    s8 = s8;
                    s9 = s9;
                    xSObjectListImpl4 = xSObjectListImpl2;
                    this.fAttrChecker.returnAttrArray(objArr, xSDocumentInfo);
                    element2 = DOMUtil.getNextSiblingElement(element2);
                    containsQName = z;
                }
            } else {
                xSObjectListImpl = xSObjectListImpl4;
                vector = vector4;
                if (!localName.equals(SchemaSymbols.ELT_MINLENGTH)) {
                    if (!localName.equals(SchemaSymbols.ELT_MAXLENGTH)) {
                        if (!localName.equals(SchemaSymbols.ELT_MAXEXCLUSIVE)) {
                            if (!localName.equals(SchemaSymbols.ELT_MAXINCLUSIVE)) {
                                if (!localName.equals(SchemaSymbols.ELT_MINEXCLUSIVE)) {
                                    if (!localName.equals(SchemaSymbols.ELT_MININCLUSIVE)) {
                                        if (!localName.equals(SchemaSymbols.ELT_TOTALDIGITS)) {
                                            if (!localName.equals(SchemaSymbols.ELT_FRACTIONDIGITS)) {
                                                if (!localName.equals(SchemaSymbols.ELT_WHITESPACE)) {
                                                    if (!localName.equals(SchemaSymbols.ELT_LENGTH)) {
                                                        s8 = s8;
                                                        s = s9;
                                                        break;
                                                    }
                                                    s3 = 1;
                                                } else {
                                                    s3 = 16;
                                                }
                                            } else {
                                                s3 = XSSimpleTypeDefinition.FACET_FRACTIONDIGITS;
                                            }
                                        } else {
                                            s3 = 512;
                                        }
                                    } else {
                                        s3 = 256;
                                    }
                                } else {
                                    s3 = 128;
                                }
                            } else {
                                s3 = 32;
                            }
                        } else {
                            s3 = 64;
                        }
                    } else {
                        s3 = 4;
                    }
                } else {
                    s3 = 2;
                }
                Object[] checkAttributes3 = this.fAttrChecker.checkAttributes(element2, false, xSDocumentInfo);
                if ((s9 & s3) != 0) {
                    reportSchemaError(XmlErrorCodes.DATATYPE_SINGLE_FACET_VALUE, new Object[]{localName}, element2);
                } else if (checkAttributes3[XSAttributeChecker.ATTIDX_VALUE] != null) {
                    short s10 = (short) (s9 | s3);
                    short s11 = s8;
                    if (((Boolean) checkAttributes3[XSAttributeChecker.ATTIDX_FIXED]).booleanValue()) {
                        s11 = (short) (s11 | s3);
                    }
                    if (s3 == 1) {
                        this.xsFacets.length = ((XInt) checkAttributes3[XSAttributeChecker.ATTIDX_VALUE]).intValue();
                    } else if (s3 == 2) {
                        this.xsFacets.minLength = ((XInt) checkAttributes3[XSAttributeChecker.ATTIDX_VALUE]).intValue();
                    } else if (s3 == 4) {
                        this.xsFacets.maxLength = ((XInt) checkAttributes3[XSAttributeChecker.ATTIDX_VALUE]).intValue();
                    } else if (s3 == 16) {
                        this.xsFacets.whiteSpace = ((XInt) checkAttributes3[XSAttributeChecker.ATTIDX_VALUE]).shortValue();
                    } else if (s3 == 32) {
                        this.xsFacets.maxInclusive = (String) checkAttributes3[XSAttributeChecker.ATTIDX_VALUE];
                    } else if (s3 == 64) {
                        this.xsFacets.maxExclusive = (String) checkAttributes3[XSAttributeChecker.ATTIDX_VALUE];
                    } else if (s3 == 128) {
                        this.xsFacets.minExclusive = (String) checkAttributes3[XSAttributeChecker.ATTIDX_VALUE];
                    } else if (s3 == 256) {
                        this.xsFacets.minInclusive = (String) checkAttributes3[XSAttributeChecker.ATTIDX_VALUE];
                    } else if (s3 == 512) {
                        this.xsFacets.totalDigits = ((XInt) checkAttributes3[XSAttributeChecker.ATTIDX_VALUE]).intValue();
                    } else if (s3 == 1024) {
                        this.xsFacets.fractionDigits = ((XInt) checkAttributes3[XSAttributeChecker.ATTIDX_VALUE]).intValue();
                    }
                    Element firstChildElement3 = DOMUtil.getFirstChildElement(element2);
                    if (firstChildElement3 == null || !DOMUtil.getLocalName(firstChildElement3).equals(SchemaSymbols.ELT_ANNOTATION)) {
                        String syntheticAnnotation3 = DOMUtil.getSyntheticAnnotation(element2);
                        if (syntheticAnnotation3 != null) {
                            s4 = s3;
                            z = containsQName;
                            s5 = 4;
                            str = "s4s-elt-must-match.1";
                            xSAnnotationImpl = traverseSyntheticAnnotation(element2, syntheticAnnotation3, checkAttributes3, false, xSDocumentInfo);
                            firstChildElement3 = firstChildElement3;
                        } else {
                            s4 = s3;
                            str = "s4s-elt-must-match.1";
                            z = containsQName;
                            s5 = 4;
                            xSAnnotationImpl = null;
                        }
                    } else {
                        XSAnnotationImpl traverseAnnotationDecl = traverseAnnotationDecl(firstChildElement3, checkAttributes3, false, xSDocumentInfo);
                        firstChildElement3 = DOMUtil.getNextSiblingElement(firstChildElement3);
                        s4 = s3;
                        xSAnnotationImpl = traverseAnnotationDecl;
                        str = "s4s-elt-must-match.1";
                        z = containsQName;
                        s5 = 4;
                    }
                    if (s4 == 1) {
                        this.xsFacets.lengthAnnotation = xSAnnotationImpl;
                    } else if (s4 == 2) {
                        this.xsFacets.minLengthAnnotation = xSAnnotationImpl;
                    } else if (s4 == s5) {
                        this.xsFacets.maxLengthAnnotation = xSAnnotationImpl;
                    } else if (s4 == 16) {
                        this.xsFacets.whiteSpaceAnnotation = xSAnnotationImpl;
                    } else if (s4 == 32) {
                        this.xsFacets.maxInclusiveAnnotation = xSAnnotationImpl;
                    } else if (s4 == 64) {
                        this.xsFacets.maxExclusiveAnnotation = xSAnnotationImpl;
                    } else if (s4 == 128) {
                        this.xsFacets.minExclusiveAnnotation = xSAnnotationImpl;
                    } else if (s4 == 256) {
                        this.xsFacets.minInclusiveAnnotation = xSAnnotationImpl;
                    } else if (s4 == 512) {
                        this.xsFacets.totalDigitsAnnotation = xSAnnotationImpl;
                    } else if (s4 == 1024) {
                        this.xsFacets.fractionDigitsAnnotation = xSAnnotationImpl;
                    }
                    if (firstChildElement3 != null) {
                        reportSchemaError(str, new Object[]{localName, "(annotation?)", DOMUtil.getLocalName(firstChildElement3)}, firstChildElement3);
                    }
                    objArr = checkAttributes3;
                    s9 = s10;
                    vector4 = vector;
                    s8 = s11;
                    xSObjectListImpl4 = xSObjectListImpl;
                    this.fAttrChecker.returnAttrArray(objArr, xSDocumentInfo);
                    element2 = DOMUtil.getNextSiblingElement(element2);
                    containsQName = z;
                } else if (element2.getAttributeNodeNS(null, "value") == null) {
                    reportSchemaError("s4s-att-must-appear", new Object[]{element2.getLocalName(), SchemaSymbols.ATT_VALUE}, element2);
                }
                this.fAttrChecker.returnAttrArray(checkAttributes3, xSDocumentInfo);
                element2 = DOMUtil.getNextSiblingElement(element2);
                s9 = s9;
                vector4 = vector;
                s8 = s8;
                xSObjectListImpl4 = xSObjectListImpl;
            }
            z2 = false;
        }
        if (vector != null) {
            s2 = (short) (s | 2048);
            XSFacets xSFacets = this.xsFacets;
            xSFacets.enumeration = vector;
            xSFacets.enumNSDecls = vector3;
            xSFacets.enumAnnotations = xSObjectListImpl;
        } else {
            s2 = s;
        }
        if (this.fPattern.length() != 0) {
            s2 = (short) (s2 | 8);
            this.xsFacets.pattern = this.fPattern.toString();
            this.xsFacets.patternAnnotations = xSObjectListImpl5;
        }
        this.fPattern.setLength(0);
        return new FacetInfo(this.xsFacets, element2, s2, s8);
    }

    public XSAnnotationImpl traverseSyntheticAnnotation(Element element, String str, Object[] objArr, boolean z, XSDocumentInfo xSDocumentInfo) {
        String str2;
        SchemaGrammar grammar = this.fSchemaHandler.getGrammar(xSDocumentInfo.fTargetNamespace);
        Vector vector = (Vector) objArr[XSAttributeChecker.ATTIDX_NONSCHEMA];
        if (vector == null || vector.isEmpty()) {
            if (this.fValidateAnnotations) {
                xSDocumentInfo.addAnnotation(new XSAnnotationInfo(str, element));
            }
            return new XSAnnotationImpl(str, grammar);
        }
        StringBuffer stringBuffer = new StringBuffer(64);
        stringBuffer.append(" ");
        int i2 = 0;
        while (i2 < vector.size()) {
            int i3 = i2 + 1;
            String str3 = (String) vector.elementAt(i2);
            int indexOf = str3.indexOf(58);
            if (indexOf == -1) {
                str2 = "";
            } else {
                str2 = str3.substring(0, indexOf);
                str3.substring(indexOf + 1);
            }
            xSDocumentInfo.fNamespaceSupport.getURI(this.fSymbolTable.addSymbol(str2));
            stringBuffer.append(str3);
            stringBuffer.append("=\"");
            i2 = i3 + 1;
            stringBuffer.append(processAttValue((String) vector.elementAt(i3)));
            stringBuffer.append("\" ");
        }
        StringBuffer stringBuffer2 = new StringBuffer(stringBuffer.length() + str.length());
        int indexOf2 = str.indexOf(SchemaSymbols.ELT_ANNOTATION);
        if (indexOf2 == -1) {
            return null;
        }
        int length = SchemaSymbols.ELT_ANNOTATION.length() + indexOf2;
        stringBuffer2.append(str.substring(0, length));
        stringBuffer2.append(stringBuffer.toString());
        stringBuffer2.append(str.substring(length, str.length()));
        String stringBuffer3 = stringBuffer2.toString();
        if (this.fValidateAnnotations) {
            xSDocumentInfo.addAnnotation(new XSAnnotationInfo(stringBuffer3, element));
        }
        return new XSAnnotationImpl(stringBuffer3, grammar);
    }
}
