package org.apache.xerces.impl.xs.traversers;

import org.apache.xerces.impl.dv.InvalidDatatypeValueException;
import org.apache.xerces.impl.dv.ValidatedInfo;
import org.apache.xerces.impl.dv.ValidationContext;
import org.apache.xerces.impl.dv.XSSimpleType;
import org.apache.xerces.impl.xs.SchemaGrammar;
import org.apache.xerces.impl.xs.SchemaSymbols;
import org.apache.xerces.impl.xs.XSAnnotationImpl;
import org.apache.xerces.impl.xs.XSAttributeDecl;
import org.apache.xerces.impl.xs.XSAttributeUseImpl;
import org.apache.xerces.impl.xs.XSComplexTypeDecl;
import org.apache.xerces.impl.xs.XSDeclarationPool;
import org.apache.xerces.impl.xs.util.XInt;
import org.apache.xerces.impl.xs.util.XSObjectListImpl;
import org.apache.xerces.util.DOMUtil;
import org.apache.xerces.util.XMLSymbols;
import org.apache.xerces.xni.QName;
import org.apache.xerces.xs.XSTypeDefinition;
import org.apache.xmlbeans.XmlErrorCodes;
import org.w3c.dom.Element;

public class XSDAttributeTraverser extends XSDAbstractTraverser {
    public XSDAttributeTraverser(XSDHandler xSDHandler, XSAttributeChecker xSAttributeChecker) {
        super(xSDHandler, xSAttributeChecker);
    }

    public void checkDefaultValid(XSAttributeDecl xSAttributeDecl) {
        ((XSSimpleType) xSAttributeDecl.getTypeDefinition()).validate(xSAttributeDecl.getValInfo().normalizedValue, (ValidationContext) this.fValidationState, xSAttributeDecl.getValInfo());
        ((XSSimpleType) xSAttributeDecl.getTypeDefinition()).validate(xSAttributeDecl.getValInfo().stringValue(), (ValidationContext) this.fValidationState, xSAttributeDecl.getValInfo());
    }

    public void checkDefaultValid(XSAttributeUseImpl xSAttributeUseImpl) {
        ValidatedInfo validatedInfo = xSAttributeUseImpl.fDefault;
        ((XSSimpleType) xSAttributeUseImpl.fAttrDecl.getTypeDefinition()).validate(validatedInfo.normalizedValue, (ValidationContext) this.fValidationState, validatedInfo);
        ((XSSimpleType) xSAttributeUseImpl.fAttrDecl.getTypeDefinition()).validate(xSAttributeUseImpl.fDefault.stringValue(), (ValidationContext) this.fValidationState, xSAttributeUseImpl.fDefault);
    }

    public XSAttributeDecl traverseGlobal(Element element, XSDocumentInfo xSDocumentInfo, SchemaGrammar schemaGrammar) {
        Object[] checkAttributes = this.fAttrChecker.checkAttributes(element, true, xSDocumentInfo);
        XSAttributeDecl traverseNamedAttr = traverseNamedAttr(element, checkAttributes, xSDocumentInfo, schemaGrammar, true, null);
        this.fAttrChecker.returnAttrArray(checkAttributes, xSDocumentInfo);
        return traverseNamedAttr;
    }

    public XSAttributeUseImpl traverseLocal(Element element, XSDocumentInfo xSDocumentInfo, SchemaGrammar schemaGrammar, XSComplexTypeDecl xSComplexTypeDecl) {
        int i2;
        XSAttributeDecl xSAttributeDecl;
        XSAnnotationImpl xSAnnotationImpl;
        String str;
        short s;
        XSAttributeUseImpl xSAttributeUseImpl;
        short s2;
        ValidatedInfo validatedInfo;
        short s3;
        short s4;
        XSObjectListImpl xSObjectListImpl;
        XSAnnotationImpl xSAnnotationImpl2;
        Object[] checkAttributes = this.fAttrChecker.checkAttributes(element, false, xSDocumentInfo);
        String str2 = (String) checkAttributes[XSAttributeChecker.ATTIDX_DEFAULT];
        String str3 = (String) checkAttributes[XSAttributeChecker.ATTIDX_FIXED];
        Object obj = (String) checkAttributes[XSAttributeChecker.ATTIDX_NAME];
        QName qName = (QName) checkAttributes[XSAttributeChecker.ATTIDX_REF];
        XInt xInt = (XInt) checkAttributes[XSAttributeChecker.ATTIDX_USE];
        if (element.getAttributeNode(SchemaSymbols.ATT_REF) == null) {
            i2 = 1;
            xSAttributeDecl = traverseNamedAttr(element, checkAttributes, xSDocumentInfo, schemaGrammar, false, xSComplexTypeDecl);
            xSAnnotationImpl = null;
        } else if (qName != null) {
            XSAttributeDecl xSAttributeDecl2 = (XSAttributeDecl) this.fSchemaHandler.getGlobalDecl(xSDocumentInfo, 1, qName, element);
            Element firstChildElement = DOMUtil.getFirstChildElement(element);
            if (firstChildElement == null || !DOMUtil.getLocalName(firstChildElement).equals(SchemaSymbols.ELT_ANNOTATION)) {
                String syntheticAnnotation = DOMUtil.getSyntheticAnnotation(element);
                if (syntheticAnnotation != null) {
                    i2 = 1;
                    xSAnnotationImpl2 = traverseSyntheticAnnotation(element, syntheticAnnotation, checkAttributes, false, xSDocumentInfo);
                    firstChildElement = firstChildElement;
                } else {
                    i2 = 1;
                    xSAnnotationImpl2 = null;
                }
            } else {
                XSAnnotationImpl traverseAnnotationDecl = traverseAnnotationDecl(firstChildElement, checkAttributes, false, xSDocumentInfo);
                firstChildElement = DOMUtil.getNextSiblingElement(firstChildElement);
                xSAnnotationImpl2 = traverseAnnotationDecl;
                i2 = 1;
            }
            if (firstChildElement != null) {
                Object[] objArr = new Object[i2];
                objArr[0] = qName.rawname;
                reportSchemaError(XmlErrorCodes.SCHEMA_ATTR$REF_FEATURES, objArr, firstChildElement);
            }
            obj = qName.localpart;
            xSAnnotationImpl = xSAnnotationImpl2;
            xSAttributeDecl = xSAttributeDecl2;
        } else {
            i2 = 1;
            xSAnnotationImpl = null;
            xSAttributeDecl = null;
        }
        if (str2 != null) {
            str = str3;
            str3 = str2;
            s = 1;
        } else if (str3 != null) {
            s = 2;
            str = null;
        } else {
            str = str3;
            str3 = str2;
            s = 0;
        }
        if (xSAttributeDecl != null) {
            XSDeclarationPool xSDeclarationPool = this.fSchemaHandler.fDeclPool;
            xSAttributeUseImpl = xSDeclarationPool != null ? xSDeclarationPool.getAttributeUse() : new XSAttributeUseImpl();
            xSAttributeUseImpl.fAttrDecl = xSAttributeDecl;
            xSAttributeUseImpl.fUse = xInt.shortValue();
            xSAttributeUseImpl.fConstraintType = s;
            if (str3 != null) {
                ValidatedInfo validatedInfo2 = new ValidatedInfo();
                xSAttributeUseImpl.fDefault = validatedInfo2;
                validatedInfo2.normalizedValue = str3;
            }
            if (element.getAttributeNode(SchemaSymbols.ATT_REF) == null) {
                xSAttributeUseImpl.fAnnotations = xSAttributeDecl.getAnnotations();
            } else {
                if (xSAnnotationImpl != null) {
                    xSObjectListImpl = new XSObjectListImpl();
                    xSObjectListImpl.addXSObject(xSAnnotationImpl);
                } else {
                    xSObjectListImpl = XSObjectListImpl.EMPTY_LIST;
                }
                xSAttributeUseImpl.fAnnotations = xSObjectListImpl;
            }
        } else {
            xSAttributeUseImpl = null;
        }
        if (str3 == null || str == null) {
            s2 = 0;
        } else {
            Object[] objArr2 = new Object[i2];
            s2 = 0;
            objArr2[0] = obj;
            reportSchemaError(XmlErrorCodes.SCHEMA_ATTR$DEFAULT_OR_FIXED, objArr2, element);
        }
        if (!(s != i2 || xInt == null || xInt.intValue() == 0)) {
            Object[] objArr3 = new Object[i2];
            objArr3[s2] = obj;
            reportSchemaError(XmlErrorCodes.SCHEMA_ATTR$DEFAULT_AND_USE_OPTIONAL, objArr3, element);
            xSAttributeUseImpl.fUse = s2;
        }
        if (!(str3 == null || xSAttributeUseImpl == null)) {
            this.fValidationState.setNamespaceSupport(xSDocumentInfo.fNamespaceSupport);
            try {
                checkDefaultValid(xSAttributeUseImpl);
                s3 = 0;
                validatedInfo = null;
            } catch (InvalidDatatypeValueException e2) {
                reportSchemaError(e2.getKey(), e2.getArgs(), element);
                Object[] objArr4 = new Object[2];
                s3 = 0;
                objArr4[0] = obj;
                objArr4[i2] = str3;
                reportSchemaError(XmlErrorCodes.ATTR_PROPERTIES$CONSTRAINT_VALID, objArr4, element);
                validatedInfo = null;
                xSAttributeUseImpl.fDefault = null;
                xSAttributeUseImpl.fConstraintType = 0;
            }
            if (((XSSimpleType) xSAttributeDecl.getTypeDefinition()).isIDType()) {
                Object[] objArr5 = new Object[i2];
                objArr5[s3] = obj;
                reportSchemaError(XmlErrorCodes.ATTR_PROPERTIES$ID_FIXED_OR_DEFAULT, objArr5, element);
                xSAttributeUseImpl.fDefault = validatedInfo;
                xSAttributeUseImpl.fConstraintType = s3;
            }
            if (xSAttributeUseImpl.fAttrDecl.getConstraintType() == 2 && (s4 = xSAttributeUseImpl.fConstraintType) != 0 && (s4 != 2 || !xSAttributeUseImpl.fAttrDecl.getValInfo().actualValue.equals(xSAttributeUseImpl.fDefault.actualValue))) {
                Object[] objArr6 = new Object[2];
                objArr6[0] = obj;
                objArr6[i2] = xSAttributeUseImpl.fAttrDecl.getValInfo().stringValue();
                reportSchemaError("au-props-correct.2", objArr6, element);
                xSAttributeUseImpl.fDefault = xSAttributeUseImpl.fAttrDecl.getValInfo();
                xSAttributeUseImpl.fConstraintType = 2;
            }
        }
        this.fAttrChecker.returnAttrArray(checkAttributes, xSDocumentInfo);
        return xSAttributeUseImpl;
    }

    /* JADX DEBUG: Multi-variable search result rejected for r28v0, resolved type: org.apache.xerces.impl.xs.traversers.XSDAttributeTraverser */
    /* JADX WARN: Multi-variable type inference failed */
    /* JADX WARN: Type inference failed for: r5v2, types: [java.lang.Object[], org.apache.xerces.impl.xs.XSAttributeDecl] */
    /* JADX WARN: Type inference failed for: r5v3 */
    /* JADX WARN: Type inference failed for: r5v8 */
    /* JADX WARNING: Removed duplicated region for block: B:33:0x00bc  */
    /* JADX WARNING: Removed duplicated region for block: B:34:0x00d6  */
    /* JADX WARNING: Removed duplicated region for block: B:50:0x012d  */
    /* JADX WARNING: Removed duplicated region for block: B:52:0x0131  */
    /* JADX WARNING: Removed duplicated region for block: B:55:0x0136  */
    /* JADX WARNING: Removed duplicated region for block: B:56:0x013f  */
    /* JADX WARNING: Removed duplicated region for block: B:59:0x015a  */
    /* JADX WARNING: Removed duplicated region for block: B:63:0x0177  */
    /* JADX WARNING: Removed duplicated region for block: B:65:0x017c  */
    /* JADX WARNING: Removed duplicated region for block: B:74:0x01b6  */
    /* JADX WARNING: Removed duplicated region for block: B:86:0x0222  */
    /* JADX WARNING: Removed duplicated region for block: B:88:0x0229  */
    /* JADX WARNING: Unknown variable types count: 1 */
    public XSAttributeDecl traverseNamedAttr(Element element, Object[] objArr, XSDocumentInfo xSDocumentInfo, SchemaGrammar schemaGrammar, boolean z, XSComplexTypeDecl xSComplexTypeDecl) {
        XSComplexTypeDecl xSComplexTypeDecl2;
        short s;
        String str;
        short s2;
        ValidatedInfo validatedInfo;
        Element firstChildElement;
        ValidatedInfo validatedInfo2;
        char c;
        String str2;
        XSAnnotationImpl xSAnnotationImpl;
        boolean z2;
        XSSimpleType xSSimpleType;
        int i2;
        XSObjectListImpl xSObjectListImpl;
        String str3;
        Object obj;
        ?? r5;
        ValidatedInfo validatedInfo3;
        XSTypeDefinition xSTypeDefinition;
        String syntheticAnnotation;
        short s3;
        XSComplexTypeDecl xSComplexTypeDecl3;
        String str4 = (String) objArr[XSAttributeChecker.ATTIDX_DEFAULT];
        String str5 = (String) objArr[XSAttributeChecker.ATTIDX_FIXED];
        XInt xInt = (XInt) objArr[XSAttributeChecker.ATTIDX_FORM];
        String str6 = (String) objArr[XSAttributeChecker.ATTIDX_NAME];
        QName qName = (QName) objArr[XSAttributeChecker.ATTIDX_TYPE];
        XSDeclarationPool xSDeclarationPool = this.fSchemaHandler.fDeclPool;
        XSAttributeDecl attributeDecl = xSDeclarationPool != null ? xSDeclarationPool.getAttributeDecl() : new XSAttributeDecl();
        if (str6 != null) {
            str6 = this.fSymbolTable.addSymbol(str6);
        }
        if (z) {
            str = xSDocumentInfo.fTargetNamespace;
            s = 1;
            xSComplexTypeDecl2 = null;
        } else {
            if (xSComplexTypeDecl != null) {
                xSComplexTypeDecl3 = xSComplexTypeDecl;
                s3 = 2;
            } else {
                xSComplexTypeDecl3 = null;
                s3 = 0;
            }
            if (xInt == null ? !xSDocumentInfo.fAreLocalAttributesQualified : xInt.intValue() != 1) {
                xSComplexTypeDecl2 = xSComplexTypeDecl3;
                s = s3;
                str = null;
            } else {
                xSComplexTypeDecl2 = xSComplexTypeDecl3;
                s = s3;
                str = xSDocumentInfo.fTargetNamespace;
            }
        }
        if (z) {
            if (str5 != null) {
                ValidatedInfo validatedInfo4 = new ValidatedInfo();
                validatedInfo4.normalizedValue = str5;
                validatedInfo = validatedInfo4;
                s2 = 2;
            } else if (str4 != null) {
                ValidatedInfo validatedInfo5 = new ValidatedInfo();
                validatedInfo5.normalizedValue = str4;
                validatedInfo = validatedInfo5;
                s2 = 1;
            }
            firstChildElement = DOMUtil.getFirstChildElement(element);
            if (firstChildElement != null || !DOMUtil.getLocalName(firstChildElement).equals(SchemaSymbols.ELT_ANNOTATION)) {
                syntheticAnnotation = DOMUtil.getSyntheticAnnotation(element);
                if (syntheticAnnotation == null) {
                    validatedInfo2 = validatedInfo;
                    str2 = str;
                    c = 0;
                    xSAnnotationImpl = traverseSyntheticAnnotation(element, syntheticAnnotation, objArr, false, xSDocumentInfo);
                    firstChildElement = firstChildElement;
                } else {
                    validatedInfo2 = validatedInfo;
                    str2 = str;
                    c = 0;
                    xSAnnotationImpl = null;
                }
            } else {
                XSAnnotationImpl traverseAnnotationDecl = traverseAnnotationDecl(firstChildElement, objArr, false, xSDocumentInfo);
                firstChildElement = DOMUtil.getNextSiblingElement(firstChildElement);
                xSAnnotationImpl = traverseAnnotationDecl;
                validatedInfo2 = validatedInfo;
                str2 = str;
                c = 0;
            }
            if (firstChildElement != null || !DOMUtil.getLocalName(firstChildElement).equals(SchemaSymbols.ELT_SIMPLETYPE)) {
                xSSimpleType = null;
                z2 = false;
            } else {
                xSSimpleType = this.fSchemaHandler.fSimpleTypeTraverser.traverseLocal(firstChildElement, xSDocumentInfo, schemaGrammar);
                firstChildElement = DOMUtil.getNextSiblingElement(firstChildElement);
                z2 = true;
            }
            if (xSSimpleType == null && qName != null) {
                xSTypeDefinition = (XSTypeDefinition) this.fSchemaHandler.getGlobalDecl(xSDocumentInfo, 7, qName, element);
                if (xSTypeDefinition == null && xSTypeDefinition.getTypeCategory() == 16) {
                    xSSimpleType = (XSSimpleType) xSTypeDefinition;
                } else {
                    Object[] objArr2 = new Object[2];
                    objArr2[c] = qName.rawname;
                    i2 = 1;
                    objArr2[1] = "simpleType definition";
                    reportSchemaError(XmlErrorCodes.SCHEMA_QNAME_RESOLVE, objArr2, element);
                    if (xSTypeDefinition == null) {
                        attributeDecl.fUnresolvedTypeName = qName;
                    }
                    if (xSSimpleType == null) {
                        xSSimpleType = SchemaGrammar.fAnySimpleType;
                    }
                    if (xSAnnotationImpl != null) {
                        xSObjectListImpl = new XSObjectListImpl();
                        xSObjectListImpl.addXSObject(xSAnnotationImpl);
                    } else {
                        xSObjectListImpl = XSObjectListImpl.EMPTY_LIST;
                    }
                    attributeDecl.setValues(str6, str2, xSSimpleType, s2, s, validatedInfo2, xSComplexTypeDecl2, xSObjectListImpl);
                    if (str6 == null) {
                        if (z) {
                            Object[] objArr3 = new Object[2];
                            objArr3[c] = SchemaSymbols.ELT_ATTRIBUTE;
                            objArr3[i2] = SchemaSymbols.ATT_NAME;
                            reportSchemaError("s4s-att-must-appear", objArr3, element);
                        } else {
                            reportSchemaError("src-attribute.3.1", null, element);
                        }
                        str3 = XSDAbstractTraverser.NO_NAME;
                    } else {
                        str3 = str6;
                    }
                    if (firstChildElement != null) {
                        Object[] objArr4 = new Object[3];
                        objArr4[c] = str3;
                        objArr4[i2] = "(annotation?, (simpleType?))";
                        objArr4[2] = DOMUtil.getLocalName(firstChildElement);
                        reportSchemaError("s4s-elt-must-match.1", objArr4, firstChildElement);
                    }
                    if (!(str4 == null || str5 == null)) {
                        Object[] objArr5 = new Object[i2];
                        objArr5[c] = str3;
                        reportSchemaError(XmlErrorCodes.SCHEMA_ATTR$DEFAULT_OR_FIXED, objArr5, element);
                    }
                    if (z2 && qName != null) {
                        Object[] objArr6 = new Object[i2];
                        objArr6[c] = str3;
                        reportSchemaError(XmlErrorCodes.SCHEMA_ATTR$TYPE_ATTR_OR_NESTED_TYPE, objArr6, element);
                    }
                    checkNotationType(str3, xSSimpleType, element);
                    if (validatedInfo2 != null) {
                        this.fValidationState.setNamespaceSupport(xSDocumentInfo.fNamespaceSupport);
                        try {
                            checkDefaultValid(attributeDecl);
                        } catch (InvalidDatatypeValueException e2) {
                            reportSchemaError(e2.getKey(), e2.getArgs(), element);
                            Object[] objArr7 = new Object[2];
                            objArr7[c] = str3;
                            objArr7[i2] = validatedInfo2.normalizedValue;
                            reportSchemaError(XmlErrorCodes.ATTR_PROPERTIES$CONSTRAINT_VALID, objArr7, element);
                            validatedInfo3 = null;
                            r5 = 0;
                            obj = XSDAbstractTraverser.NO_NAME;
                            attributeDecl.setValues(str3, str2, xSSimpleType, 0, s, null, xSComplexTypeDecl2, xSObjectListImpl);
                        }
                    }
                    obj = XSDAbstractTraverser.NO_NAME;
                    r5 = 0;
                    validatedInfo3 = validatedInfo2;
                    if (validatedInfo3 != null && xSSimpleType.isIDType()) {
                        Object[] objArr8 = new Object[i2];
                        objArr8[c] = str3;
                        reportSchemaError(XmlErrorCodes.ATTR_PROPERTIES$ID_FIXED_OR_DEFAULT, objArr8, element);
                        attributeDecl.setValues(str3, str2, xSSimpleType, 0, s, null, xSComplexTypeDecl2, xSObjectListImpl);
                    }
                    if (str3.equals(XMLSymbols.PREFIX_XMLNS)) {
                        reportSchemaError(XmlErrorCodes.NO_XMLNS, r5, element);
                        return r5;
                    } else if (str2 != null && str2.equals(SchemaSymbols.URI_XSI)) {
                        Object[] objArr9 = new Object[i2];
                        objArr9[c] = SchemaSymbols.URI_XSI;
                        reportSchemaError(XmlErrorCodes.NO_XSI, objArr9, element);
                        return r5;
                    } else if (str3.equals(obj)) {
                        return r5;
                    } else {
                        if (z) {
                            if (schemaGrammar.getGlobalAttributeDecl(str3) == null) {
                                schemaGrammar.addGlobalAttributeDecl(attributeDecl);
                            }
                            String schemaDocument2SystemId = this.fSchemaHandler.schemaDocument2SystemId(xSDocumentInfo);
                            XSAttributeDecl globalAttributeDecl = schemaGrammar.getGlobalAttributeDecl(str3, schemaDocument2SystemId);
                            if (globalAttributeDecl == null) {
                                schemaGrammar.addGlobalAttributeDecl(attributeDecl, schemaDocument2SystemId);
                            }
                            if (this.fSchemaHandler.fTolerateDuplicates) {
                                XSAttributeDecl xSAttributeDecl = globalAttributeDecl != null ? globalAttributeDecl : attributeDecl;
                                this.fSchemaHandler.addGlobalAttributeDecl(xSAttributeDecl);
                                return xSAttributeDecl;
                            }
                        }
                        return attributeDecl;
                    }
                }
            }
            i2 = 1;
            if (xSSimpleType == null) {
            }
            if (xSAnnotationImpl != null) {
            }
            attributeDecl.setValues(str6, str2, xSSimpleType, s2, s, validatedInfo2, xSComplexTypeDecl2, xSObjectListImpl);
            if (str6 == null) {
            }
            if (firstChildElement != null) {
            }
            Object[] objArr52 = new Object[i2];
            objArr52[c] = str3;
            reportSchemaError(XmlErrorCodes.SCHEMA_ATTR$DEFAULT_OR_FIXED, objArr52, element);
            Object[] objArr62 = new Object[i2];
            objArr62[c] = str3;
            reportSchemaError(XmlErrorCodes.SCHEMA_ATTR$TYPE_ATTR_OR_NESTED_TYPE, objArr62, element);
            checkNotationType(str3, xSSimpleType, element);
            if (validatedInfo2 != null) {
            }
            obj = XSDAbstractTraverser.NO_NAME;
            r5 = 0;
            validatedInfo3 = validatedInfo2;
            Object[] objArr82 = new Object[i2];
            objArr82[c] = str3;
            reportSchemaError(XmlErrorCodes.ATTR_PROPERTIES$ID_FIXED_OR_DEFAULT, objArr82, element);
            attributeDecl.setValues(str3, str2, xSSimpleType, 0, s, null, xSComplexTypeDecl2, xSObjectListImpl);
            if (str3.equals(XMLSymbols.PREFIX_XMLNS)) {
            }
        }
        validatedInfo = null;
        s2 = 0;
        firstChildElement = DOMUtil.getFirstChildElement(element);
        if (firstChildElement != null) {
        }
        syntheticAnnotation = DOMUtil.getSyntheticAnnotation(element);
        if (syntheticAnnotation == null) {
        }
        if (firstChildElement != null) {
        }
        xSSimpleType = null;
        z2 = false;
        xSTypeDefinition = (XSTypeDefinition) this.fSchemaHandler.getGlobalDecl(xSDocumentInfo, 7, qName, element);
        if (xSTypeDefinition == null) {
        }
        Object[] objArr22 = new Object[2];
        objArr22[c] = qName.rawname;
        i2 = 1;
        objArr22[1] = "simpleType definition";
        reportSchemaError(XmlErrorCodes.SCHEMA_QNAME_RESOLVE, objArr22, element);
        if (xSTypeDefinition == null) {
        }
        if (xSSimpleType == null) {
        }
        if (xSAnnotationImpl != null) {
        }
        attributeDecl.setValues(str6, str2, xSSimpleType, s2, s, validatedInfo2, xSComplexTypeDecl2, xSObjectListImpl);
        if (str6 == null) {
        }
        if (firstChildElement != null) {
        }
        Object[] objArr522 = new Object[i2];
        objArr522[c] = str3;
        reportSchemaError(XmlErrorCodes.SCHEMA_ATTR$DEFAULT_OR_FIXED, objArr522, element);
        Object[] objArr622 = new Object[i2];
        objArr622[c] = str3;
        reportSchemaError(XmlErrorCodes.SCHEMA_ATTR$TYPE_ATTR_OR_NESTED_TYPE, objArr622, element);
        checkNotationType(str3, xSSimpleType, element);
        if (validatedInfo2 != null) {
        }
        obj = XSDAbstractTraverser.NO_NAME;
        r5 = 0;
        validatedInfo3 = validatedInfo2;
        Object[] objArr822 = new Object[i2];
        objArr822[c] = str3;
        reportSchemaError(XmlErrorCodes.ATTR_PROPERTIES$ID_FIXED_OR_DEFAULT, objArr822, element);
        attributeDecl.setValues(str3, str2, xSSimpleType, 0, s, null, xSComplexTypeDecl2, xSObjectListImpl);
        if (str3.equals(XMLSymbols.PREFIX_XMLNS)) {
        }
    }
}
