package org.apache.xerces.impl.xs.traversers;

import org.apache.xerces.impl.dv.InvalidDatatypeFacetException;
import org.apache.xerces.impl.dv.XSFacets;
import org.apache.xerces.impl.dv.XSSimpleType;
import org.apache.xerces.impl.dv.xs.XSSimpleTypeDecl;
import org.apache.xerces.impl.xs.SchemaGrammar;
import org.apache.xerces.impl.xs.SchemaSymbols;
import org.apache.xerces.impl.xs.XSAnnotationImpl;
import org.apache.xerces.impl.xs.XSAttributeGroupDecl;
import org.apache.xerces.impl.xs.XSAttributeUseImpl;
import org.apache.xerces.impl.xs.XSComplexTypeDecl;
import org.apache.xerces.impl.xs.XSConstraints;
import org.apache.xerces.impl.xs.XSModelGroupImpl;
import org.apache.xerces.impl.xs.XSParticleDecl;
import org.apache.xerces.impl.xs.XSWildcardDecl;
import org.apache.xerces.impl.xs.traversers.XSDAbstractTraverser;
import org.apache.xerces.impl.xs.util.XInt;
import org.apache.xerces.impl.xs.util.XSObjectListImpl;
import org.apache.xerces.util.DOMUtil;
import org.apache.xerces.xni.QName;
import org.apache.xerces.xs.XSAttributeUse;
import org.apache.xerces.xs.XSObjectList;
import org.apache.xerces.xs.XSTypeDefinition;
import org.apache.xmlbeans.XmlErrorCodes;
import org.w3c.dom.Element;

public class XSDComplexTypeTraverser extends XSDAbstractParticleTraverser {
    public static final boolean DEBUG = false;
    public static final int GLOBAL_NUM = 11;
    public static XSParticleDecl fErrorContent;
    public static XSWildcardDecl fErrorWildcard;
    public XSAnnotationImpl[] fAnnotations = null;
    public XSAttributeGroupDecl fAttrGrp = null;
    public XSTypeDefinition fBaseType = null;
    public short fBlock = 0;
    public XSComplexTypeDecl fComplexTypeDecl = null;
    public short fContentType = 0;
    public short fDerivedBy = 2;
    public short fFinal = 0;
    public Object[] fGlobalStore = null;
    public int fGlobalStorePos = 0;
    public boolean fIsAbstract = false;
    public String fName = null;
    public XSParticleDecl fParticle = null;
    public String fTargetNamespace = null;
    public XSSimpleType fXSSimpleType = null;

    public static final class ComplexTypeRecoverableError extends Exception {
        public static final long serialVersionUID = 6802729912091130335L;
        public Element errorElem = null;
        public Object[] errorSubstText = null;

        public ComplexTypeRecoverableError() {
        }

        public ComplexTypeRecoverableError(String str, Object[] objArr, Element element) {
            super(str);
            this.errorSubstText = objArr;
            this.errorElem = element;
        }
    }

    public XSDComplexTypeTraverser(XSDHandler xSDHandler, XSAttributeChecker xSAttributeChecker) {
        super(xSDHandler, xSAttributeChecker);
    }

    private void addAnnotation(XSAnnotationImpl xSAnnotationImpl) {
        if (xSAnnotationImpl != null) {
            XSAnnotationImpl[] xSAnnotationImplArr = this.fAnnotations;
            if (xSAnnotationImplArr == null) {
                this.fAnnotations = new XSAnnotationImpl[1];
            } else {
                XSAnnotationImpl[] xSAnnotationImplArr2 = new XSAnnotationImpl[(xSAnnotationImplArr.length + 1)];
                System.arraycopy(xSAnnotationImplArr, 0, xSAnnotationImplArr2, 0, xSAnnotationImplArr.length);
                this.fAnnotations = xSAnnotationImplArr2;
            }
            XSAnnotationImpl[] xSAnnotationImplArr3 = this.fAnnotations;
            xSAnnotationImplArr3[xSAnnotationImplArr3.length - 1] = xSAnnotationImpl;
        }
    }

    private void contentBackup() {
        if (this.fGlobalStore == null) {
            this.fGlobalStore = new Object[11];
            this.fGlobalStorePos = 0;
        }
        int i2 = this.fGlobalStorePos;
        Object[] objArr = this.fGlobalStore;
        if (i2 == objArr.length) {
            Object[] objArr2 = new Object[(i2 + 11)];
            System.arraycopy(objArr, 0, objArr2, 0, i2);
            this.fGlobalStore = objArr2;
        }
        Object[] objArr3 = this.fGlobalStore;
        int i3 = this.fGlobalStorePos;
        int i4 = i3 + 1;
        this.fGlobalStorePos = i4;
        objArr3[i3] = this.fComplexTypeDecl;
        this.fGlobalStorePos = i4 + 1;
        objArr3[i4] = this.fIsAbstract ? Boolean.TRUE : Boolean.FALSE;
        Object[] objArr4 = this.fGlobalStore;
        int i5 = this.fGlobalStorePos;
        int i6 = i5 + 1;
        this.fGlobalStorePos = i6;
        objArr4[i5] = this.fName;
        int i7 = i6 + 1;
        this.fGlobalStorePos = i7;
        objArr4[i6] = this.fTargetNamespace;
        this.fGlobalStorePos = i7 + 1;
        objArr4[i7] = new Integer((this.fDerivedBy << 16) + this.fFinal);
        Object[] objArr5 = this.fGlobalStore;
        int i8 = this.fGlobalStorePos;
        this.fGlobalStorePos = i8 + 1;
        objArr5[i8] = new Integer((this.fBlock << 16) + this.fContentType);
        Object[] objArr6 = this.fGlobalStore;
        int i9 = this.fGlobalStorePos;
        int i10 = i9 + 1;
        this.fGlobalStorePos = i10;
        objArr6[i9] = this.fBaseType;
        int i11 = i10 + 1;
        this.fGlobalStorePos = i11;
        objArr6[i10] = this.fAttrGrp;
        int i12 = i11 + 1;
        this.fGlobalStorePos = i12;
        objArr6[i11] = this.fParticle;
        int i13 = i12 + 1;
        this.fGlobalStorePos = i13;
        objArr6[i12] = this.fXSSimpleType;
        this.fGlobalStorePos = i13 + 1;
        objArr6[i13] = this.fAnnotations;
    }

    private void contentRestore() {
        Object[] objArr = this.fGlobalStore;
        int i2 = this.fGlobalStorePos - 1;
        this.fGlobalStorePos = i2;
        this.fAnnotations = (XSAnnotationImpl[]) objArr[i2];
        int i3 = i2 - 1;
        this.fGlobalStorePos = i3;
        this.fXSSimpleType = (XSSimpleType) objArr[i3];
        int i4 = i3 - 1;
        this.fGlobalStorePos = i4;
        this.fParticle = (XSParticleDecl) objArr[i4];
        int i5 = i4 - 1;
        this.fGlobalStorePos = i5;
        this.fAttrGrp = (XSAttributeGroupDecl) objArr[i5];
        int i6 = i5 - 1;
        this.fGlobalStorePos = i6;
        this.fBaseType = (XSTypeDefinition) objArr[i6];
        int i7 = i6 - 1;
        this.fGlobalStorePos = i7;
        int intValue = ((Integer) objArr[i7]).intValue();
        this.fBlock = (short) (intValue >> 16);
        this.fContentType = (short) intValue;
        Object[] objArr2 = this.fGlobalStore;
        int i8 = this.fGlobalStorePos - 1;
        this.fGlobalStorePos = i8;
        int intValue2 = ((Integer) objArr2[i8]).intValue();
        this.fDerivedBy = (short) (intValue2 >> 16);
        this.fFinal = (short) intValue2;
        Object[] objArr3 = this.fGlobalStore;
        int i9 = this.fGlobalStorePos - 1;
        this.fGlobalStorePos = i9;
        this.fTargetNamespace = (String) objArr3[i9];
        int i10 = i9 - 1;
        this.fGlobalStorePos = i10;
        this.fName = (String) objArr3[i10];
        int i11 = i10 - 1;
        this.fGlobalStorePos = i11;
        this.fIsAbstract = ((Boolean) objArr3[i11]).booleanValue();
        Object[] objArr4 = this.fGlobalStore;
        int i12 = this.fGlobalStorePos - 1;
        this.fGlobalStorePos = i12;
        this.fComplexTypeDecl = (XSComplexTypeDecl) objArr4[i12];
    }

    private String genAnonTypeName(Element element) {
        StringBuffer stringBuffer = new StringBuffer("#AnonType_");
        while (true) {
            element = DOMUtil.getParent(element);
            if (element != null && element != DOMUtil.getRoot(DOMUtil.getDocument(element))) {
                stringBuffer.append(element.getAttribute(SchemaSymbols.ATT_NAME));
            }
        }
        return stringBuffer.toString();
    }

    public static XSParticleDecl getErrorContent() {
        if (fErrorContent == null) {
            XSParticleDecl xSParticleDecl = new XSParticleDecl();
            xSParticleDecl.fType = 2;
            xSParticleDecl.fValue = getErrorWildcard();
            xSParticleDecl.fMinOccurs = 0;
            xSParticleDecl.fMaxOccurs = -1;
            XSModelGroupImpl xSModelGroupImpl = new XSModelGroupImpl();
            xSModelGroupImpl.fCompositor = 102;
            xSModelGroupImpl.fParticleCount = 1;
            XSParticleDecl[] xSParticleDeclArr = new XSParticleDecl[1];
            xSModelGroupImpl.fParticles = xSParticleDeclArr;
            xSParticleDeclArr[0] = xSParticleDecl;
            XSParticleDecl xSParticleDecl2 = new XSParticleDecl();
            xSParticleDecl2.fType = 3;
            xSParticleDecl2.fValue = xSModelGroupImpl;
            fErrorContent = xSParticleDecl2;
        }
        return fErrorContent;
    }

    public static XSWildcardDecl getErrorWildcard() {
        if (fErrorWildcard == null) {
            XSWildcardDecl xSWildcardDecl = new XSWildcardDecl();
            xSWildcardDecl.fProcessContents = 2;
            fErrorWildcard = xSWildcardDecl;
        }
        return fErrorWildcard;
    }

    private void handleComplexTypeError(String str, Object[] objArr, Element element) {
        if (str != null) {
            reportSchemaError(str, objArr, element);
        }
        this.fBaseType = SchemaGrammar.fAnyType;
        this.fContentType = 3;
        this.fXSSimpleType = null;
        this.fParticle = getErrorContent();
        this.fAttrGrp.fAttributeWC = getErrorWildcard();
    }

    private boolean isAttrOrAttrGroup(Element element) {
        String localName = DOMUtil.getLocalName(element);
        return localName.equals(SchemaSymbols.ELT_ATTRIBUTE) || localName.equals(SchemaSymbols.ELT_ATTRIBUTEGROUP) || localName.equals(SchemaSymbols.ELT_ANYATTRIBUTE);
    }

    private void mergeAttributes(XSAttributeGroupDecl xSAttributeGroupDecl, XSAttributeGroupDecl xSAttributeGroupDecl2, String str, boolean z, Element element) {
        XSObjectList attributeUses = xSAttributeGroupDecl.getAttributeUses();
        int length = attributeUses.getLength();
        for (int i2 = 0; i2 < length; i2++) {
            XSAttributeUseImpl xSAttributeUseImpl = (XSAttributeUseImpl) attributeUses.item(i2);
            XSAttributeUse attributeUse = xSAttributeGroupDecl2.getAttributeUse(xSAttributeUseImpl.fAttrDecl.getNamespace(), xSAttributeUseImpl.fAttrDecl.getName());
            if (attributeUse == null) {
                String addAttributeUse = xSAttributeGroupDecl2.addAttributeUse(xSAttributeUseImpl);
                if (addAttributeUse != null) {
                    throw new ComplexTypeRecoverableError("ct-props-correct.5", new Object[]{str, addAttributeUse, xSAttributeUseImpl.fAttrDecl.getName()}, element);
                }
            } else if (attributeUse != xSAttributeUseImpl && z) {
                reportSchemaError(XmlErrorCodes.COMPLEX_TYPE_PROPERTIES$DUPLICATE_ATTRIBUTE, new Object[]{str, xSAttributeUseImpl.fAttrDecl.getName()}, element);
                xSAttributeGroupDecl2.replaceAttributeUse(attributeUse, xSAttributeUseImpl);
            }
        }
        if (z) {
            XSWildcardDecl xSWildcardDecl = xSAttributeGroupDecl2.fAttributeWC;
            XSWildcardDecl xSWildcardDecl2 = xSAttributeGroupDecl.fAttributeWC;
            if (xSWildcardDecl == null) {
                xSAttributeGroupDecl2.fAttributeWC = xSWildcardDecl2;
            } else if (xSWildcardDecl2 != null) {
                XSWildcardDecl performUnionWith = xSWildcardDecl.performUnionWith(xSWildcardDecl2, xSWildcardDecl.fProcessContents);
                xSAttributeGroupDecl2.fAttributeWC = performUnionWith;
                if (performUnionWith == null) {
                    throw new ComplexTypeRecoverableError("src-ct.5", new Object[]{str}, element);
                }
            }
        }
    }

    /* JADX WARNING: Code restructure failed: missing block: B:10:0x0047, code lost:
        if (((org.apache.xerces.impl.xs.XSModelGroupImpl) r0.fValue).fParticleCount == 0) goto L_0x0049;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:21:0x0072, code lost:
        if (((org.apache.xerces.impl.xs.XSModelGroupImpl) r0.fValue).fParticleCount == 0) goto L_0x0049;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:27:0x0093, code lost:
        if (((org.apache.xerces.impl.xs.XSModelGroupImpl) r0.fValue).fParticleCount == 0) goto L_0x0049;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:37:0x00b8, code lost:
        if (r1 == null) goto L_0x00bc;
     */
    /* JADX WARNING: Removed duplicated region for block: B:32:0x00a2  */
    /* JADX WARNING: Removed duplicated region for block: B:44:0x00c9  */
    /* JADX WARNING: Removed duplicated region for block: B:45:0x00cc  */
    /* JADX WARNING: Removed duplicated region for block: B:49:0x00d6  */
    /* JADX WARNING: Removed duplicated region for block: B:59:? A[ORIG_RETURN, RETURN, SYNTHETIC] */
    private void processComplexContent(Element element, boolean z, boolean z2, XSDocumentInfo xSDocumentInfo, SchemaGrammar schemaGrammar) {
        Element element2;
        boolean z3;
        XSParticleDecl xSParticleDecl;
        XSParticleDecl xSParticleDecl2 = null;
        if (element != null) {
            String localName = DOMUtil.getLocalName(element);
            if (localName.equals(SchemaSymbols.ELT_GROUP)) {
                xSParticleDecl = this.fSchemaHandler.fGroupTraverser.traverseLocal(element, xSDocumentInfo, schemaGrammar);
                element2 = DOMUtil.getNextSiblingElement(element);
            } else {
                if (localName.equals(SchemaSymbols.ELT_SEQUENCE)) {
                    xSParticleDecl = traverseSequence(element, xSDocumentInfo, schemaGrammar, 0, this.fComplexTypeDecl);
                    if (xSParticleDecl != null) {
                    }
                    z3 = false;
                    element2 = DOMUtil.getNextSiblingElement(element);
                    if (z3) {
                        Element firstChildElement = DOMUtil.getFirstChildElement(element);
                        if (firstChildElement != null && DOMUtil.getLocalName(firstChildElement).equals(SchemaSymbols.ELT_ANNOTATION)) {
                            firstChildElement = DOMUtil.getNextSiblingElement(firstChildElement);
                        }
                    }
                    xSParticleDecl2 = xSParticleDecl;
                    if (xSParticleDecl2 == null && z) {
                        xSParticleDecl2 = XSConstraints.getEmptySequence();
                    }
                    this.fParticle = xSParticleDecl2;
                    if (xSParticleDecl2 == null) {
                        this.fContentType = 0;
                    } else if (z) {
                        this.fContentType = 3;
                    } else {
                        this.fContentType = 2;
                    }
                    if (element2 == null) {
                        return;
                    }
                    if (isAttrOrAttrGroup(element2)) {
                        Element traverseAttrsAndAttrGrps = traverseAttrsAndAttrGrps(element2, this.fAttrGrp, xSDocumentInfo, schemaGrammar, this.fComplexTypeDecl);
                        if (traverseAttrsAndAttrGrps != null) {
                            throw new ComplexTypeRecoverableError("s4s-elt-invalid-content.1", new Object[]{this.fName, DOMUtil.getLocalName(traverseAttrsAndAttrGrps)}, traverseAttrsAndAttrGrps);
                        } else if (!z2) {
                            this.fAttrGrp.removeProhibitedAttrs();
                            return;
                        } else {
                            return;
                        }
                    } else {
                        throw new ComplexTypeRecoverableError("s4s-elt-invalid-content.1", new Object[]{this.fName, DOMUtil.getLocalName(element2)}, element2);
                    }
                } else if (localName.equals(SchemaSymbols.ELT_CHOICE)) {
                    xSParticleDecl = traverseChoice(element, xSDocumentInfo, schemaGrammar, 0, this.fComplexTypeDecl);
                    if (xSParticleDecl != null) {
                        if (xSParticleDecl.fMinOccurs == 0) {
                        }
                    }
                    z3 = false;
                    element2 = DOMUtil.getNextSiblingElement(element);
                    if (z3) {
                    }
                    xSParticleDecl2 = xSParticleDecl;
                    xSParticleDecl2 = XSConstraints.getEmptySequence();
                    this.fParticle = xSParticleDecl2;
                    if (xSParticleDecl2 == null) {
                    }
                    if (element2 == null) {
                    }
                } else if (localName.equals(SchemaSymbols.ELT_ALL)) {
                    xSParticleDecl = traverseAll(element, xSDocumentInfo, schemaGrammar, 8, this.fComplexTypeDecl);
                    if (xSParticleDecl != null) {
                    }
                    z3 = false;
                    element2 = DOMUtil.getNextSiblingElement(element);
                    if (z3) {
                    }
                    xSParticleDecl2 = xSParticleDecl;
                    xSParticleDecl2 = XSConstraints.getEmptySequence();
                    this.fParticle = xSParticleDecl2;
                    if (xSParticleDecl2 == null) {
                    }
                    if (element2 == null) {
                    }
                } else {
                    element2 = element;
                    xSParticleDecl = null;
                }
                z3 = true;
                element2 = DOMUtil.getNextSiblingElement(element);
                if (z3) {
                }
                xSParticleDecl2 = xSParticleDecl;
                xSParticleDecl2 = XSConstraints.getEmptySequence();
                this.fParticle = xSParticleDecl2;
                if (xSParticleDecl2 == null) {
                }
                if (element2 == null) {
                }
            }
        } else {
            xSParticleDecl = null;
            element2 = null;
        }
        z3 = false;
        if (z3) {
        }
        xSParticleDecl2 = xSParticleDecl;
        xSParticleDecl2 = XSConstraints.getEmptySequence();
        this.fParticle = xSParticleDecl2;
        if (xSParticleDecl2 == null) {
        }
        if (element2 == null) {
        }
    }

    private void traverseComplexContent(Element element, boolean z, XSDocumentInfo xSDocumentInfo, SchemaGrammar schemaGrammar) {
        Object[] objArr;
        Object[] validRestrictionOf;
        Object[] checkAttributes = this.fAttrChecker.checkAttributes(element, false, xSDocumentInfo);
        Boolean bool = (Boolean) checkAttributes[XSAttributeChecker.ATTIDX_MIXED];
        boolean booleanValue = bool != null ? bool.booleanValue() : z;
        this.fXSSimpleType = null;
        Element firstChildElement = DOMUtil.getFirstChildElement(element);
        if (firstChildElement == null || !DOMUtil.getLocalName(firstChildElement).equals(SchemaSymbols.ELT_ANNOTATION)) {
            String syntheticAnnotation = DOMUtil.getSyntheticAnnotation(element);
            if (syntheticAnnotation != null) {
                addAnnotation(traverseSyntheticAnnotation(element, syntheticAnnotation, checkAttributes, false, xSDocumentInfo));
            }
        } else {
            addAnnotation(traverseAnnotationDecl(firstChildElement, checkAttributes, false, xSDocumentInfo));
            firstChildElement = DOMUtil.getNextSiblingElement(firstChildElement);
        }
        if (firstChildElement != null) {
            String localName = DOMUtil.getLocalName(firstChildElement);
            if (localName.equals(SchemaSymbols.ELT_RESTRICTION)) {
                this.fDerivedBy = 2;
            } else if (localName.equals(SchemaSymbols.ELT_EXTENSION)) {
                this.fDerivedBy = 1;
            } else {
                this.fAttrChecker.returnAttrArray(checkAttributes, xSDocumentInfo);
                throw new ComplexTypeRecoverableError("s4s-elt-invalid-content.1", new Object[]{this.fName, localName}, firstChildElement);
            }
            Element nextSiblingElement = DOMUtil.getNextSiblingElement(firstChildElement);
            if (nextSiblingElement == null) {
                Object[] checkAttributes2 = this.fAttrChecker.checkAttributes(firstChildElement, false, xSDocumentInfo);
                QName qName = (QName) checkAttributes2[XSAttributeChecker.ATTIDX_BASE];
                if (qName != null) {
                    XSTypeDefinition xSTypeDefinition = (XSTypeDefinition) this.fSchemaHandler.getGlobalDecl(xSDocumentInfo, 7, qName, firstChildElement);
                    if (xSTypeDefinition == null) {
                        this.fAttrChecker.returnAttrArray(checkAttributes, xSDocumentInfo);
                        this.fAttrChecker.returnAttrArray(checkAttributes2, xSDocumentInfo);
                        throw new ComplexTypeRecoverableError();
                    } else if (xSTypeDefinition instanceof XSComplexTypeDecl) {
                        XSComplexTypeDecl xSComplexTypeDecl = (XSComplexTypeDecl) xSTypeDefinition;
                        this.fBaseType = xSComplexTypeDecl;
                        if ((xSComplexTypeDecl.getFinal() & this.fDerivedBy) != 0) {
                            this.fAttrChecker.returnAttrArray(checkAttributes, xSDocumentInfo);
                            this.fAttrChecker.returnAttrArray(checkAttributes2, xSDocumentInfo);
                            throw new ComplexTypeRecoverableError(this.fDerivedBy == 1 ? XmlErrorCodes.COMPLEX_TYPE_EXTENSION$FINAL : XmlErrorCodes.COMPLEX_TYPE_RESTRICTION$FINAL, new Object[]{this.fName, this.fBaseType.getName()}, firstChildElement);
                        }
                        Element firstChildElement2 = DOMUtil.getFirstChildElement(firstChildElement);
                        if (firstChildElement2 != null) {
                            if (DOMUtil.getLocalName(firstChildElement2).equals(SchemaSymbols.ELT_ANNOTATION)) {
                                addAnnotation(traverseAnnotationDecl(firstChildElement2, checkAttributes2, false, xSDocumentInfo));
                                firstChildElement2 = DOMUtil.getNextSiblingElement(firstChildElement2);
                            } else {
                                String syntheticAnnotation2 = DOMUtil.getSyntheticAnnotation(firstChildElement2);
                                if (syntheticAnnotation2 != null) {
                                    objArr = checkAttributes2;
                                    addAnnotation(traverseSyntheticAnnotation(firstChildElement2, syntheticAnnotation2, checkAttributes2, false, xSDocumentInfo));
                                    if (firstChildElement2 != null && DOMUtil.getLocalName(firstChildElement2).equals(SchemaSymbols.ELT_ANNOTATION)) {
                                        this.fAttrChecker.returnAttrArray(checkAttributes, xSDocumentInfo);
                                        this.fAttrChecker.returnAttrArray(objArr, xSDocumentInfo);
                                        throw new ComplexTypeRecoverableError("s4s-elt-invalid-content.1", new Object[]{this.fName, SchemaSymbols.ELT_ANNOTATION}, firstChildElement2);
                                    }
                                }
                            }
                            objArr = checkAttributes2;
                            this.fAttrChecker.returnAttrArray(checkAttributes, xSDocumentInfo);
                            this.fAttrChecker.returnAttrArray(objArr, xSDocumentInfo);
                            throw new ComplexTypeRecoverableError("s4s-elt-invalid-content.1", new Object[]{this.fName, SchemaSymbols.ELT_ANNOTATION}, firstChildElement2);
                        }
                        objArr = checkAttributes2;
                        String syntheticAnnotation3 = DOMUtil.getSyntheticAnnotation(firstChildElement2);
                        if (syntheticAnnotation3 != null) {
                            addAnnotation(traverseSyntheticAnnotation(firstChildElement2, syntheticAnnotation3, objArr, false, xSDocumentInfo));
                        }
                        try {
                            processComplexContent(firstChildElement2, booleanValue, true, xSDocumentInfo, schemaGrammar);
                            XSParticleDecl xSParticleDecl = (XSParticleDecl) xSComplexTypeDecl.getParticle();
                            if (this.fDerivedBy != 2) {
                                if (this.fParticle == null) {
                                    this.fContentType = xSComplexTypeDecl.getContentType();
                                    this.fXSSimpleType = (XSSimpleType) xSComplexTypeDecl.getSimpleType();
                                    this.fParticle = xSParticleDecl;
                                } else if (xSComplexTypeDecl.getContentType() != 0) {
                                    if (this.fContentType == 2 && xSComplexTypeDecl.getContentType() != 2) {
                                        this.fAttrChecker.returnAttrArray(checkAttributes, xSDocumentInfo);
                                        this.fAttrChecker.returnAttrArray(objArr, xSDocumentInfo);
                                        throw new ComplexTypeRecoverableError("cos-ct-extends.1.4.3.2.2.1.a", new Object[]{this.fName}, firstChildElement2);
                                    } else if (this.fContentType != 3 || xSComplexTypeDecl.getContentType() == 3) {
                                        XSParticleDecl xSParticleDecl2 = this.fParticle;
                                        if ((xSParticleDecl2.fType == 3 && ((XSModelGroupImpl) xSParticleDecl2.fValue).fCompositor == 103) || (((XSParticleDecl) xSComplexTypeDecl.getParticle()).fType == 3 && ((XSModelGroupImpl) ((XSParticleDecl) xSComplexTypeDecl.getParticle()).fValue).fCompositor == 103)) {
                                            this.fAttrChecker.returnAttrArray(checkAttributes, xSDocumentInfo);
                                            this.fAttrChecker.returnAttrArray(objArr, xSDocumentInfo);
                                            throw new ComplexTypeRecoverableError("cos-all-limited.1.2", new Object[0], firstChildElement2);
                                        }
                                        XSModelGroupImpl xSModelGroupImpl = new XSModelGroupImpl();
                                        xSModelGroupImpl.fCompositor = 102;
                                        xSModelGroupImpl.fParticleCount = 2;
                                        XSParticleDecl[] xSParticleDeclArr = new XSParticleDecl[2];
                                        xSModelGroupImpl.fParticles = xSParticleDeclArr;
                                        xSParticleDeclArr[0] = (XSParticleDecl) xSComplexTypeDecl.getParticle();
                                        xSModelGroupImpl.fParticles[1] = this.fParticle;
                                        xSModelGroupImpl.fAnnotations = XSObjectListImpl.EMPTY_LIST;
                                        XSParticleDecl xSParticleDecl3 = new XSParticleDecl();
                                        xSParticleDecl3.fType = 3;
                                        xSParticleDecl3.fValue = xSModelGroupImpl;
                                        xSParticleDecl3.fAnnotations = XSObjectListImpl.EMPTY_LIST;
                                        this.fParticle = xSParticleDecl3;
                                    } else {
                                        this.fAttrChecker.returnAttrArray(checkAttributes, xSDocumentInfo);
                                        this.fAttrChecker.returnAttrArray(objArr, xSDocumentInfo);
                                        throw new ComplexTypeRecoverableError("cos-ct-extends.1.4.3.2.2.1.b", new Object[]{this.fName}, firstChildElement2);
                                    }
                                }
                                this.fAttrGrp.removeProhibitedAttrs();
                                try {
                                    mergeAttributes(xSComplexTypeDecl.getAttrGrp(), this.fAttrGrp, this.fName, true, firstChildElement2);
                                } catch (ComplexTypeRecoverableError e2) {
                                    this.fAttrChecker.returnAttrArray(checkAttributes, xSDocumentInfo);
                                    this.fAttrChecker.returnAttrArray(objArr, xSDocumentInfo);
                                    throw e2;
                                }
                            } else if (this.fContentType != 3 || xSComplexTypeDecl.getContentType() == 3) {
                                try {
                                    mergeAttributes(xSComplexTypeDecl.getAttrGrp(), this.fAttrGrp, this.fName, false, firstChildElement2);
                                    this.fAttrGrp.removeProhibitedAttrs();
                                    if (!(xSComplexTypeDecl == SchemaGrammar.fAnyType || (validRestrictionOf = this.fAttrGrp.validRestrictionOf(this.fName, xSComplexTypeDecl.getAttrGrp())) == null)) {
                                        this.fAttrChecker.returnAttrArray(checkAttributes, xSDocumentInfo);
                                        this.fAttrChecker.returnAttrArray(objArr, xSDocumentInfo);
                                        throw new ComplexTypeRecoverableError((String) validRestrictionOf[validRestrictionOf.length - 1], validRestrictionOf, firstChildElement2);
                                    }
                                } catch (ComplexTypeRecoverableError e3) {
                                    this.fAttrChecker.returnAttrArray(checkAttributes, xSDocumentInfo);
                                    this.fAttrChecker.returnAttrArray(objArr, xSDocumentInfo);
                                    throw e3;
                                }
                            } else {
                                this.fAttrChecker.returnAttrArray(checkAttributes, xSDocumentInfo);
                                this.fAttrChecker.returnAttrArray(objArr, xSDocumentInfo);
                                throw new ComplexTypeRecoverableError("derivation-ok-restriction.5.4.1.2", new Object[]{this.fName, xSComplexTypeDecl.getName()}, firstChildElement2);
                            }
                            this.fAttrChecker.returnAttrArray(checkAttributes, xSDocumentInfo);
                            this.fAttrChecker.returnAttrArray(objArr, xSDocumentInfo);
                        } catch (ComplexTypeRecoverableError e4) {
                            this.fAttrChecker.returnAttrArray(checkAttributes, xSDocumentInfo);
                            this.fAttrChecker.returnAttrArray(objArr, xSDocumentInfo);
                            throw e4;
                        }
                    } else {
                        this.fAttrChecker.returnAttrArray(checkAttributes, xSDocumentInfo);
                        this.fAttrChecker.returnAttrArray(checkAttributes2, xSDocumentInfo);
                        throw new ComplexTypeRecoverableError(XmlErrorCodes.SCHEMA_COMPLEX_TYPE$COMPLEX_CONTENT, new Object[]{this.fName, xSTypeDefinition.getName()}, firstChildElement);
                    }
                } else {
                    this.fAttrChecker.returnAttrArray(checkAttributes, xSDocumentInfo);
                    this.fAttrChecker.returnAttrArray(checkAttributes2, xSDocumentInfo);
                    throw new ComplexTypeRecoverableError("s4s-att-must-appear", new Object[]{localName, "base"}, firstChildElement);
                }
            } else {
                this.fAttrChecker.returnAttrArray(checkAttributes, xSDocumentInfo);
                throw new ComplexTypeRecoverableError("s4s-elt-invalid-content.1", new Object[]{this.fName, DOMUtil.getLocalName(nextSiblingElement)}, nextSiblingElement);
            }
        } else {
            this.fAttrChecker.returnAttrArray(checkAttributes, xSDocumentInfo);
            throw new ComplexTypeRecoverableError("s4s-elt-invalid-content.2", new Object[]{this.fName, SchemaSymbols.ELT_COMPLEXCONTENT}, element);
        }
    }

    private void traverseComplexContentDecl(Element element, boolean z) {
    }

    /* JADX WARNING: Removed duplicated region for block: B:54:0x017f  */
    private XSComplexTypeDecl traverseComplexTypeDecl(Element element, String str, Object[] objArr, XSDocumentInfo xSDocumentInfo, SchemaGrammar schemaGrammar) {
        XSAnnotationImpl[] xSAnnotationImplArr;
        boolean booleanValue;
        this.fComplexTypeDecl = new XSComplexTypeDecl();
        this.fAttrGrp = new XSAttributeGroupDecl();
        Boolean bool = (Boolean) objArr[XSAttributeChecker.ATTIDX_ABSTRACT];
        XInt xInt = (XInt) objArr[XSAttributeChecker.ATTIDX_BLOCK];
        Boolean bool2 = (Boolean) objArr[XSAttributeChecker.ATTIDX_MIXED];
        XInt xInt2 = (XInt) objArr[XSAttributeChecker.ATTIDX_FINAL];
        this.fName = str;
        this.fComplexTypeDecl.setName(str);
        this.fTargetNamespace = xSDocumentInfo.fTargetNamespace;
        this.fBlock = xInt == null ? xSDocumentInfo.fBlockDefault : xInt.shortValue();
        short shortValue = xInt2 == null ? xSDocumentInfo.fFinalDefault : xInt2.shortValue();
        this.fFinal = shortValue;
        this.fBlock = (short) (this.fBlock & 3);
        this.fFinal = (short) (shortValue & 3);
        int i2 = 0;
        this.fIsAbstract = bool != null && bool.booleanValue();
        this.fAnnotations = null;
        try {
            Element firstChildElement = DOMUtil.getFirstChildElement(element);
            if (firstChildElement != null) {
                if (DOMUtil.getLocalName(firstChildElement).equals(SchemaSymbols.ELT_ANNOTATION)) {
                    addAnnotation(traverseAnnotationDecl(firstChildElement, objArr, false, xSDocumentInfo));
                    firstChildElement = DOMUtil.getNextSiblingElement(firstChildElement);
                } else {
                    String syntheticAnnotation = DOMUtil.getSyntheticAnnotation(element);
                    if (syntheticAnnotation != null) {
                        addAnnotation(traverseSyntheticAnnotation(element, syntheticAnnotation, objArr, false, xSDocumentInfo));
                    }
                }
                if (firstChildElement != null && DOMUtil.getLocalName(firstChildElement).equals(SchemaSymbols.ELT_ANNOTATION)) {
                    throw new ComplexTypeRecoverableError("s4s-elt-invalid-content.1", new Object[]{this.fName, SchemaSymbols.ELT_ANNOTATION}, firstChildElement);
                }
            } else {
                String syntheticAnnotation2 = DOMUtil.getSyntheticAnnotation(element);
                if (syntheticAnnotation2 != null) {
                    addAnnotation(traverseSyntheticAnnotation(element, syntheticAnnotation2, objArr, false, xSDocumentInfo));
                }
            }
            if (firstChildElement == null) {
                this.fBaseType = SchemaGrammar.fAnyType;
                this.fDerivedBy = 2;
                booleanValue = bool2.booleanValue();
            } else {
                if (DOMUtil.getLocalName(firstChildElement).equals(SchemaSymbols.ELT_SIMPLECONTENT)) {
                    traverseSimpleContent(firstChildElement, xSDocumentInfo, schemaGrammar);
                    Element nextSiblingElement = DOMUtil.getNextSiblingElement(firstChildElement);
                    if (nextSiblingElement != null) {
                        throw new ComplexTypeRecoverableError("s4s-elt-invalid-content.1", new Object[]{this.fName, DOMUtil.getLocalName(nextSiblingElement)}, nextSiblingElement);
                    }
                } else if (DOMUtil.getLocalName(firstChildElement).equals(SchemaSymbols.ELT_COMPLEXCONTENT)) {
                    traverseComplexContent(firstChildElement, bool2.booleanValue(), xSDocumentInfo, schemaGrammar);
                    Element nextSiblingElement2 = DOMUtil.getNextSiblingElement(firstChildElement);
                    if (nextSiblingElement2 != null) {
                        throw new ComplexTypeRecoverableError("s4s-elt-invalid-content.1", new Object[]{this.fName, DOMUtil.getLocalName(nextSiblingElement2)}, nextSiblingElement2);
                    }
                } else {
                    this.fBaseType = SchemaGrammar.fAnyType;
                    this.fDerivedBy = 2;
                    booleanValue = bool2.booleanValue();
                }
                XSComplexTypeDecl xSComplexTypeDecl = this.fComplexTypeDecl;
                String str2 = this.fName;
                String str3 = this.fTargetNamespace;
                XSTypeDefinition xSTypeDefinition = this.fBaseType;
                short s = this.fDerivedBy;
                short s2 = this.fFinal;
                short s3 = this.fBlock;
                short s4 = this.fContentType;
                boolean z = this.fIsAbstract;
                XSAttributeGroupDecl xSAttributeGroupDecl = this.fAttrGrp;
                XSSimpleType xSSimpleType = this.fXSSimpleType;
                XSParticleDecl xSParticleDecl = this.fParticle;
                xSAnnotationImplArr = this.fAnnotations;
                if (xSAnnotationImplArr != null) {
                    i2 = xSAnnotationImplArr.length;
                }
                xSComplexTypeDecl.setValues(str2, str3, xSTypeDefinition, s, s2, s3, s4, z, xSAttributeGroupDecl, xSSimpleType, xSParticleDecl, new XSObjectListImpl(xSAnnotationImplArr, i2));
                return this.fComplexTypeDecl;
            }
            processComplexContent(firstChildElement, booleanValue, false, xSDocumentInfo, schemaGrammar);
        } catch (ComplexTypeRecoverableError e2) {
            handleComplexTypeError(e2.getMessage(), e2.errorSubstText, e2.errorElem);
        }
        XSComplexTypeDecl xSComplexTypeDecl2 = this.fComplexTypeDecl;
        String str22 = this.fName;
        String str32 = this.fTargetNamespace;
        XSTypeDefinition xSTypeDefinition2 = this.fBaseType;
        short s5 = this.fDerivedBy;
        short s22 = this.fFinal;
        short s32 = this.fBlock;
        short s42 = this.fContentType;
        boolean z2 = this.fIsAbstract;
        XSAttributeGroupDecl xSAttributeGroupDecl2 = this.fAttrGrp;
        XSSimpleType xSSimpleType2 = this.fXSSimpleType;
        XSParticleDecl xSParticleDecl2 = this.fParticle;
        xSAnnotationImplArr = this.fAnnotations;
        if (xSAnnotationImplArr != null) {
        }
        xSComplexTypeDecl2.setValues(str22, str32, xSTypeDefinition2, s5, s22, s32, s42, z2, xSAttributeGroupDecl2, xSSimpleType2, xSParticleDecl2, new XSObjectListImpl(xSAnnotationImplArr, i2));
        return this.fComplexTypeDecl;
    }

    /* JADX WARNING: Removed duplicated region for block: B:43:0x00f2  */
    /* JADX WARNING: Removed duplicated region for block: B:49:0x0119  */
    private void traverseSimpleContent(Element element, XSDocumentInfo xSDocumentInfo, SchemaGrammar schemaGrammar) {
        Element element2;
        XSComplexTypeDecl xSComplexTypeDecl;
        XSSimpleType xSSimpleType;
        short s;
        Element element3;
        XSSimpleType xSSimpleType2;
        XSSimpleType xSSimpleType3;
        Element element4;
        short s2;
        short s3;
        XSFacets xSFacets;
        Element element5;
        Element element6;
        Element element7;
        XSSimpleType xSSimpleType4;
        Object[] checkAttributes = this.fAttrChecker.checkAttributes(element, false, xSDocumentInfo);
        this.fContentType = 1;
        this.fParticle = null;
        Element firstChildElement = DOMUtil.getFirstChildElement(element);
        if (firstChildElement == null || !DOMUtil.getLocalName(firstChildElement).equals(SchemaSymbols.ELT_ANNOTATION)) {
            String syntheticAnnotation = DOMUtil.getSyntheticAnnotation(element);
            if (syntheticAnnotation != null) {
                addAnnotation(traverseSyntheticAnnotation(element, syntheticAnnotation, checkAttributes, false, xSDocumentInfo));
            }
            element2 = firstChildElement;
        } else {
            addAnnotation(traverseAnnotationDecl(firstChildElement, checkAttributes, false, xSDocumentInfo));
            element2 = DOMUtil.getNextSiblingElement(firstChildElement);
        }
        if (element2 != null) {
            String localName = DOMUtil.getLocalName(element2);
            if (localName.equals(SchemaSymbols.ELT_RESTRICTION)) {
                this.fDerivedBy = 2;
            } else if (localName.equals(SchemaSymbols.ELT_EXTENSION)) {
                this.fDerivedBy = 1;
            } else {
                this.fAttrChecker.returnAttrArray(checkAttributes, xSDocumentInfo);
                throw new ComplexTypeRecoverableError("s4s-elt-invalid-content.1", new Object[]{this.fName, localName}, element2);
            }
            Element nextSiblingElement = DOMUtil.getNextSiblingElement(element2);
            if (nextSiblingElement == null) {
                Object[] checkAttributes2 = this.fAttrChecker.checkAttributes(element2, false, xSDocumentInfo);
                QName qName = (QName) checkAttributes2[XSAttributeChecker.ATTIDX_BASE];
                if (qName != null) {
                    XSTypeDefinition xSTypeDefinition = (XSTypeDefinition) this.fSchemaHandler.getGlobalDecl(xSDocumentInfo, 7, qName, element2);
                    if (xSTypeDefinition != null) {
                        this.fBaseType = xSTypeDefinition;
                        if (xSTypeDefinition.getTypeCategory() == 15) {
                            XSComplexTypeDecl xSComplexTypeDecl2 = (XSComplexTypeDecl) xSTypeDefinition;
                            s = xSComplexTypeDecl2.getFinal();
                            if (xSComplexTypeDecl2.getContentType() == 1) {
                                xSSimpleType4 = (XSSimpleType) xSComplexTypeDecl2.getSimpleType();
                                xSComplexTypeDecl = xSComplexTypeDecl2;
                            } else if (this.fDerivedBy == 2 && xSComplexTypeDecl2.getContentType() == 3 && ((XSParticleDecl) xSComplexTypeDecl2.getParticle()).emptiable()) {
                                xSSimpleType = null;
                                xSComplexTypeDecl = xSComplexTypeDecl2;
                                if ((this.fDerivedBy & s) == 0) {
                                    this.fAttrChecker.returnAttrArray(checkAttributes, xSDocumentInfo);
                                    this.fAttrChecker.returnAttrArray(checkAttributes2, xSDocumentInfo);
                                    throw new ComplexTypeRecoverableError(this.fDerivedBy == 1 ? XmlErrorCodes.COMPLEX_TYPE_EXTENSION$FINAL : XmlErrorCodes.COMPLEX_TYPE_RESTRICTION$FINAL, new Object[]{this.fName, this.fBaseType.getName()}, element2);
                                }
                                Element firstChildElement2 = DOMUtil.getFirstChildElement(element2);
                                if (firstChildElement2 != null) {
                                    if (DOMUtil.getLocalName(firstChildElement2).equals(SchemaSymbols.ELT_ANNOTATION)) {
                                        addAnnotation(traverseAnnotationDecl(firstChildElement2, checkAttributes2, false, xSDocumentInfo));
                                        element6 = DOMUtil.getNextSiblingElement(firstChildElement2);
                                        xSSimpleType2 = xSSimpleType;
                                    } else {
                                        String syntheticAnnotation2 = DOMUtil.getSyntheticAnnotation(element2);
                                        if (syntheticAnnotation2 != null) {
                                            element7 = firstChildElement2;
                                            xSSimpleType2 = xSSimpleType;
                                            addAnnotation(traverseSyntheticAnnotation(element2, syntheticAnnotation2, checkAttributes2, false, xSDocumentInfo));
                                        } else {
                                            element7 = firstChildElement2;
                                            xSSimpleType2 = xSSimpleType;
                                        }
                                        element6 = element7;
                                    }
                                    if (element6 == null || !DOMUtil.getLocalName(element6).equals(SchemaSymbols.ELT_ANNOTATION)) {
                                        element3 = element6;
                                    } else {
                                        this.fAttrChecker.returnAttrArray(checkAttributes, xSDocumentInfo);
                                        this.fAttrChecker.returnAttrArray(checkAttributes2, xSDocumentInfo);
                                        throw new ComplexTypeRecoverableError("s4s-elt-invalid-content.1", new Object[]{this.fName, SchemaSymbols.ELT_ANNOTATION}, element6);
                                    }
                                } else {
                                    xSSimpleType2 = xSSimpleType;
                                    String syntheticAnnotation3 = DOMUtil.getSyntheticAnnotation(element2);
                                    if (syntheticAnnotation3 != null) {
                                        addAnnotation(traverseSyntheticAnnotation(element2, syntheticAnnotation3, checkAttributes2, false, xSDocumentInfo));
                                    }
                                    element3 = firstChildElement2;
                                }
                                if (this.fDerivedBy == 2) {
                                    if (element3 == null || !DOMUtil.getLocalName(element3).equals(SchemaSymbols.ELT_SIMPLETYPE)) {
                                        xSSimpleType3 = xSSimpleType2;
                                    } else {
                                        xSSimpleType3 = this.fSchemaHandler.fSimpleTypeTraverser.traverseLocal(element3, xSDocumentInfo, schemaGrammar);
                                        if (xSSimpleType3 == null) {
                                            this.fAttrChecker.returnAttrArray(checkAttributes, xSDocumentInfo);
                                            this.fAttrChecker.returnAttrArray(checkAttributes2, xSDocumentInfo);
                                            throw new ComplexTypeRecoverableError();
                                        } else if (xSSimpleType2 == null || XSConstraints.checkSimpleDerivationOk(xSSimpleType3, xSSimpleType2, xSSimpleType2.getFinal())) {
                                            element3 = DOMUtil.getNextSiblingElement(element3);
                                        } else {
                                            this.fAttrChecker.returnAttrArray(checkAttributes, xSDocumentInfo);
                                            this.fAttrChecker.returnAttrArray(checkAttributes2, xSDocumentInfo);
                                            throw new ComplexTypeRecoverableError(XmlErrorCodes.COMPLEX_TYPE_RESTRICTION$SC_NOT_DERIVED, new Object[]{this.fName, xSSimpleType3.getName(), xSSimpleType2.getName()}, element3);
                                        }
                                    }
                                    if (xSSimpleType3 != null) {
                                        if (element3 != null) {
                                            XSDAbstractTraverser.FacetInfo traverseFacets = traverseFacets(element3, xSSimpleType3, xSDocumentInfo);
                                            Element element8 = traverseFacets.nodeAfterFacets;
                                            XSFacets xSFacets2 = traverseFacets.facetdata;
                                            short s4 = traverseFacets.fPresentFacets;
                                            s3 = traverseFacets.fFixedFacets;
                                            xSFacets = xSFacets2;
                                            s2 = s4;
                                            element4 = element8;
                                        } else {
                                            xSFacets = null;
                                            s3 = 0;
                                            s2 = 0;
                                            element4 = null;
                                        }
                                        String genAnonTypeName = genAnonTypeName(element);
                                        this.fXSSimpleType = this.fSchemaHandler.fDVFactory.createTypeRestriction(genAnonTypeName, xSDocumentInfo.fTargetNamespace, 0, xSSimpleType3, null);
                                        try {
                                            this.fValidationState.setNamespaceSupport(xSDocumentInfo.fNamespaceSupport);
                                            this.fXSSimpleType.applyFacets(xSFacets, s2, s3, this.fValidationState);
                                        } catch (InvalidDatatypeFacetException e2) {
                                            reportSchemaError(e2.getKey(), e2.getArgs(), element3);
                                            this.fXSSimpleType = this.fSchemaHandler.fDVFactory.createTypeRestriction(genAnonTypeName, xSDocumentInfo.fTargetNamespace, 0, xSSimpleType3, null);
                                        }
                                        XSSimpleType xSSimpleType5 = this.fXSSimpleType;
                                        if (xSSimpleType5 instanceof XSSimpleTypeDecl) {
                                            ((XSSimpleTypeDecl) xSSimpleType5).setAnonymous(true);
                                        }
                                        if (element4 == null) {
                                            element5 = element4;
                                        } else if (isAttrOrAttrGroup(element4)) {
                                            element5 = element4;
                                            Element traverseAttrsAndAttrGrps = traverseAttrsAndAttrGrps(element4, this.fAttrGrp, xSDocumentInfo, schemaGrammar, this.fComplexTypeDecl);
                                            if (traverseAttrsAndAttrGrps != null) {
                                                this.fAttrChecker.returnAttrArray(checkAttributes, xSDocumentInfo);
                                                this.fAttrChecker.returnAttrArray(checkAttributes2, xSDocumentInfo);
                                                throw new ComplexTypeRecoverableError("s4s-elt-invalid-content.1", new Object[]{this.fName, DOMUtil.getLocalName(traverseAttrsAndAttrGrps)}, traverseAttrsAndAttrGrps);
                                            }
                                        } else {
                                            this.fAttrChecker.returnAttrArray(checkAttributes, xSDocumentInfo);
                                            this.fAttrChecker.returnAttrArray(checkAttributes2, xSDocumentInfo);
                                            throw new ComplexTypeRecoverableError("s4s-elt-invalid-content.1", new Object[]{this.fName, DOMUtil.getLocalName(element4)}, element4);
                                        }
                                        try {
                                            mergeAttributes(xSComplexTypeDecl.getAttrGrp(), this.fAttrGrp, this.fName, false, element);
                                            this.fAttrGrp.removeProhibitedAttrs();
                                            Object[] validRestrictionOf = this.fAttrGrp.validRestrictionOf(this.fName, xSComplexTypeDecl.getAttrGrp());
                                            if (validRestrictionOf != null) {
                                                this.fAttrChecker.returnAttrArray(checkAttributes, xSDocumentInfo);
                                                this.fAttrChecker.returnAttrArray(checkAttributes2, xSDocumentInfo);
                                                throw new ComplexTypeRecoverableError((String) validRestrictionOf[validRestrictionOf.length - 1], validRestrictionOf, element5);
                                            }
                                        } catch (ComplexTypeRecoverableError e3) {
                                            this.fAttrChecker.returnAttrArray(checkAttributes, xSDocumentInfo);
                                            this.fAttrChecker.returnAttrArray(checkAttributes2, xSDocumentInfo);
                                            throw e3;
                                        }
                                    } else {
                                        this.fAttrChecker.returnAttrArray(checkAttributes, xSDocumentInfo);
                                        this.fAttrChecker.returnAttrArray(checkAttributes2, xSDocumentInfo);
                                        throw new ComplexTypeRecoverableError("src-ct.2.2", new Object[]{this.fName}, element3);
                                    }
                                } else {
                                    this.fXSSimpleType = xSSimpleType2;
                                    if (element3 != null) {
                                        if (isAttrOrAttrGroup(element3)) {
                                            Element traverseAttrsAndAttrGrps2 = traverseAttrsAndAttrGrps(element3, this.fAttrGrp, xSDocumentInfo, schemaGrammar, this.fComplexTypeDecl);
                                            if (traverseAttrsAndAttrGrps2 == null) {
                                                this.fAttrGrp.removeProhibitedAttrs();
                                            } else {
                                                this.fAttrChecker.returnAttrArray(checkAttributes, xSDocumentInfo);
                                                this.fAttrChecker.returnAttrArray(checkAttributes2, xSDocumentInfo);
                                                throw new ComplexTypeRecoverableError("s4s-elt-invalid-content.1", new Object[]{this.fName, DOMUtil.getLocalName(traverseAttrsAndAttrGrps2)}, traverseAttrsAndAttrGrps2);
                                            }
                                        } else {
                                            this.fAttrChecker.returnAttrArray(checkAttributes, xSDocumentInfo);
                                            this.fAttrChecker.returnAttrArray(checkAttributes2, xSDocumentInfo);
                                            throw new ComplexTypeRecoverableError("s4s-elt-invalid-content.1", new Object[]{this.fName, DOMUtil.getLocalName(element3)}, element3);
                                        }
                                    }
                                    if (xSComplexTypeDecl != null) {
                                        try {
                                            mergeAttributes(xSComplexTypeDecl.getAttrGrp(), this.fAttrGrp, this.fName, true, element);
                                        } catch (ComplexTypeRecoverableError e4) {
                                            this.fAttrChecker.returnAttrArray(checkAttributes, xSDocumentInfo);
                                            this.fAttrChecker.returnAttrArray(checkAttributes2, xSDocumentInfo);
                                            throw e4;
                                        }
                                    }
                                }
                                this.fAttrChecker.returnAttrArray(checkAttributes, xSDocumentInfo);
                                this.fAttrChecker.returnAttrArray(checkAttributes2, xSDocumentInfo);
                                return;
                            } else {
                                this.fAttrChecker.returnAttrArray(checkAttributes, xSDocumentInfo);
                                this.fAttrChecker.returnAttrArray(checkAttributes2, xSDocumentInfo);
                                throw new ComplexTypeRecoverableError("src-ct.2.1", new Object[]{this.fName, xSComplexTypeDecl2.getName()}, element2);
                            }
                        } else {
                            xSSimpleType4 = (XSSimpleType) xSTypeDefinition;
                            if (this.fDerivedBy != 2) {
                                s = xSSimpleType4.getFinal();
                                xSComplexTypeDecl = null;
                            } else {
                                this.fAttrChecker.returnAttrArray(checkAttributes, xSDocumentInfo);
                                this.fAttrChecker.returnAttrArray(checkAttributes2, xSDocumentInfo);
                                throw new ComplexTypeRecoverableError("src-ct.2.1", new Object[]{this.fName, xSSimpleType4.getName()}, element2);
                            }
                        }
                        xSSimpleType = xSSimpleType4;
                        if ((this.fDerivedBy & s) == 0) {
                        }
                    } else {
                        this.fAttrChecker.returnAttrArray(checkAttributes, xSDocumentInfo);
                        this.fAttrChecker.returnAttrArray(checkAttributes2, xSDocumentInfo);
                        throw new ComplexTypeRecoverableError();
                    }
                } else {
                    this.fAttrChecker.returnAttrArray(checkAttributes, xSDocumentInfo);
                    this.fAttrChecker.returnAttrArray(checkAttributes2, xSDocumentInfo);
                    throw new ComplexTypeRecoverableError("s4s-att-must-appear", new Object[]{localName, "base"}, element2);
                }
            } else {
                this.fAttrChecker.returnAttrArray(checkAttributes, xSDocumentInfo);
                throw new ComplexTypeRecoverableError("s4s-elt-invalid-content.1", new Object[]{this.fName, DOMUtil.getLocalName(nextSiblingElement)}, nextSiblingElement);
            }
        } else {
            this.fAttrChecker.returnAttrArray(checkAttributes, xSDocumentInfo);
            throw new ComplexTypeRecoverableError("s4s-elt-invalid-content.2", new Object[]{this.fName, SchemaSymbols.ELT_SIMPLECONTENT}, element);
        }
    }

    private void traverseSimpleContentDecl(Element element) {
    }

    public XSComplexTypeDecl traverseGlobal(Element element, XSDocumentInfo xSDocumentInfo, SchemaGrammar schemaGrammar) {
        Object[] checkAttributes = this.fAttrChecker.checkAttributes(element, true, xSDocumentInfo);
        String str = (String) checkAttributes[XSAttributeChecker.ATTIDX_NAME];
        contentBackup();
        XSComplexTypeDecl traverseComplexTypeDecl = traverseComplexTypeDecl(element, str, checkAttributes, xSDocumentInfo, schemaGrammar);
        contentRestore();
        schemaGrammar.addComplexTypeDecl(traverseComplexTypeDecl, this.fSchemaHandler.element2Locator(element));
        if (str == null) {
            reportSchemaError("s4s-att-must-appear", new Object[]{SchemaSymbols.ELT_COMPLEXTYPE, SchemaSymbols.ATT_NAME}, element);
            traverseComplexTypeDecl = null;
        } else {
            if (schemaGrammar.getGlobalTypeDecl(traverseComplexTypeDecl.getName()) == null) {
                schemaGrammar.addGlobalComplexTypeDecl(traverseComplexTypeDecl);
            }
            String schemaDocument2SystemId = this.fSchemaHandler.schemaDocument2SystemId(xSDocumentInfo);
            XSTypeDefinition globalTypeDecl = schemaGrammar.getGlobalTypeDecl(traverseComplexTypeDecl.getName(), schemaDocument2SystemId);
            if (globalTypeDecl == null) {
                schemaGrammar.addGlobalComplexTypeDecl(traverseComplexTypeDecl, schemaDocument2SystemId);
            }
            if (this.fSchemaHandler.fTolerateDuplicates) {
                if (globalTypeDecl != null && (globalTypeDecl instanceof XSComplexTypeDecl)) {
                    traverseComplexTypeDecl = (XSComplexTypeDecl) globalTypeDecl;
                }
                this.fSchemaHandler.addGlobalTypeDecl(traverseComplexTypeDecl);
            }
        }
        this.fAttrChecker.returnAttrArray(checkAttributes, xSDocumentInfo);
        return traverseComplexTypeDecl;
    }

    public XSComplexTypeDecl traverseLocal(Element element, XSDocumentInfo xSDocumentInfo, SchemaGrammar schemaGrammar) {
        Object[] checkAttributes = this.fAttrChecker.checkAttributes(element, false, xSDocumentInfo);
        String genAnonTypeName = genAnonTypeName(element);
        contentBackup();
        XSComplexTypeDecl traverseComplexTypeDecl = traverseComplexTypeDecl(element, genAnonTypeName, checkAttributes, xSDocumentInfo, schemaGrammar);
        contentRestore();
        schemaGrammar.addComplexTypeDecl(traverseComplexTypeDecl, this.fSchemaHandler.element2Locator(element));
        traverseComplexTypeDecl.setIsAnonymous();
        this.fAttrChecker.returnAttrArray(checkAttributes, xSDocumentInfo);
        return traverseComplexTypeDecl;
    }
}
