package org.apache.xerces.impl.xs.traversers;

import b.b.a.a.a;
import java.util.Locale;
import org.apache.poi.xssf.usermodel.XSSFDataValidationConstraint;
import org.apache.xerces.impl.dv.ValidatedInfo;
import org.apache.xerces.impl.dv.XSSimpleType;
import org.apache.xerces.impl.xs.SchemaGrammar;
import org.apache.xerces.impl.xs.SchemaSymbols;
import org.apache.xerces.impl.xs.XSAnnotationImpl;
import org.apache.xerces.impl.xs.XSComplexTypeDecl;
import org.apache.xerces.impl.xs.XSConstraints;
import org.apache.xerces.impl.xs.XSDeclarationPool;
import org.apache.xerces.impl.xs.XSElementDecl;
import org.apache.xerces.impl.xs.XSParticleDecl;
import org.apache.xerces.impl.xs.util.XInt;
import org.apache.xerces.impl.xs.util.XSObjectListImpl;
import org.apache.xerces.util.DOMUtil;
import org.apache.xerces.util.SymbolTable;
import org.apache.xerces.util.XMLChar;
import org.apache.xerces.xni.QName;
import org.apache.xerces.xs.XSObject;
import org.apache.xerces.xs.XSTypeDefinition;
import org.apache.xmlbeans.XmlErrorCodes;
import org.w3c.dom.Attr;
import org.w3c.dom.Element;

public class XSDElementTraverser extends XSDAbstractTraverser {
    public boolean fDeferTraversingLocalElements;
    public final XSElementDecl fTempElementDecl = new XSElementDecl();

    public XSDElementTraverser(XSDHandler xSDHandler, XSAttributeChecker xSAttributeChecker) {
        super(xSDHandler, xSAttributeChecker);
    }

    @Override // org.apache.xerces.impl.xs.traversers.XSDAbstractTraverser
    public void reset(SymbolTable symbolTable, boolean z, Locale locale) {
        super.reset(symbolTable, z, locale);
        this.fDeferTraversingLocalElements = true;
    }

    public XSElementDecl traverseGlobal(Element element, XSDocumentInfo xSDocumentInfo, SchemaGrammar schemaGrammar) {
        Object[] checkAttributes = this.fAttrChecker.checkAttributes(element, true, xSDocumentInfo);
        XSElementDecl traverseNamedElement = traverseNamedElement(element, checkAttributes, xSDocumentInfo, schemaGrammar, true, null);
        this.fAttrChecker.returnAttrArray(checkAttributes, xSDocumentInfo);
        return traverseNamedElement;
    }

    public XSParticleDecl traverseLocal(Element element, XSDocumentInfo xSDocumentInfo, SchemaGrammar schemaGrammar, int i2, XSObject xSObject) {
        XSDeclarationPool xSDeclarationPool = this.fSchemaHandler.fDeclPool;
        XSParticleDecl particleDecl = xSDeclarationPool != null ? xSDeclarationPool.getParticleDecl() : new XSParticleDecl();
        if (this.fDeferTraversingLocalElements) {
            particleDecl.fType = 1;
            Attr attributeNode = element.getAttributeNode(SchemaSymbols.ATT_MINOCCURS);
            if (attributeNode != null) {
                try {
                    int parseInt = Integer.parseInt(XMLChar.trim(attributeNode.getValue()));
                    if (parseInt >= 0) {
                        particleDecl.fMinOccurs = parseInt;
                    }
                } catch (NumberFormatException unused) {
                }
            }
            this.fSchemaHandler.fillInLocalElemInfo(element, xSDocumentInfo, i2, xSObject, particleDecl);
            return particleDecl;
        }
        traverseLocal(particleDecl, element, xSDocumentInfo, schemaGrammar, i2, xSObject, null);
        if (particleDecl.fType == 0) {
            return null;
        }
        return particleDecl;
    }

    public void traverseLocal(XSParticleDecl xSParticleDecl, Element element, XSDocumentInfo xSDocumentInfo, SchemaGrammar schemaGrammar, int i2, XSObject xSObject, String[] strArr) {
        short s;
        XSAnnotationImpl xSAnnotationImpl;
        XSElementDecl xSElementDecl;
        XSObjectListImpl xSObjectListImpl;
        if (strArr != null) {
            xSDocumentInfo.fNamespaceSupport.setEffectiveContext(strArr);
        }
        Object[] checkAttributes = this.fAttrChecker.checkAttributes(element, false, xSDocumentInfo);
        QName qName = (QName) checkAttributes[XSAttributeChecker.ATTIDX_REF];
        XInt xInt = (XInt) checkAttributes[XSAttributeChecker.ATTIDX_MINOCCURS];
        XInt xInt2 = (XInt) checkAttributes[XSAttributeChecker.ATTIDX_MAXOCCURS];
        XSAnnotationImpl xSAnnotationImpl2 = null;
        if (element.getAttributeNode(SchemaSymbols.ATT_REF) != null) {
            if (qName != null) {
                XSElementDecl xSElementDecl2 = (XSElementDecl) this.fSchemaHandler.getGlobalDecl(xSDocumentInfo, 3, qName, element);
                Element firstChildElement = DOMUtil.getFirstChildElement(element);
                if (firstChildElement == null || !DOMUtil.getLocalName(firstChildElement).equals(SchemaSymbols.ELT_ANNOTATION)) {
                    String syntheticAnnotation = DOMUtil.getSyntheticAnnotation(element);
                    if (syntheticAnnotation != null) {
                        xSAnnotationImpl2 = traverseSyntheticAnnotation(element, syntheticAnnotation, checkAttributes, false, xSDocumentInfo);
                        firstChildElement = firstChildElement;
                    }
                } else {
                    xSAnnotationImpl2 = traverseAnnotationDecl(firstChildElement, checkAttributes, false, xSDocumentInfo);
                    firstChildElement = DOMUtil.getNextSiblingElement(firstChildElement);
                }
                if (firstChildElement != null) {
                    reportSchemaError(XmlErrorCodes.SCHEMA_ELEM$REF_FEATURES, new Object[]{qName.rawname, DOMUtil.getLocalName(firstChildElement)}, firstChildElement);
                }
                xSAnnotationImpl = xSAnnotationImpl2;
                xSElementDecl = xSElementDecl2;
            } else {
                xSElementDecl = null;
                xSAnnotationImpl = null;
            }
            s = 1;
        } else {
            s = 1;
            xSElementDecl = traverseNamedElement(element, checkAttributes, xSDocumentInfo, schemaGrammar, false, xSObject);
            xSAnnotationImpl = null;
        }
        xSParticleDecl.fMinOccurs = xInt.intValue();
        xSParticleDecl.fMaxOccurs = xInt2.intValue();
        if (xSElementDecl != null) {
            xSParticleDecl.fType = s;
            xSParticleDecl.fValue = xSElementDecl;
        } else {
            xSParticleDecl.fType = 0;
        }
        if (qName != null) {
            if (xSAnnotationImpl != null) {
                XSObjectListImpl xSObjectListImpl2 = new XSObjectListImpl();
                xSObjectListImpl2.addXSObject(xSAnnotationImpl);
                xSObjectListImpl = xSObjectListImpl2;
                xSParticleDecl.fAnnotations = xSObjectListImpl;
                checkOccurrences(xSParticleDecl, SchemaSymbols.ELT_ELEMENT, (Element) element.getParentNode(), i2, ((Long) checkAttributes[XSAttributeChecker.ATTIDX_FROMDEFAULT]).longValue());
                this.fAttrChecker.returnAttrArray(checkAttributes, xSDocumentInfo);
            }
        } else if (xSElementDecl != null) {
            xSObjectListImpl = xSElementDecl.fAnnotations;
            xSParticleDecl.fAnnotations = xSObjectListImpl;
            checkOccurrences(xSParticleDecl, SchemaSymbols.ELT_ELEMENT, (Element) element.getParentNode(), i2, ((Long) checkAttributes[XSAttributeChecker.ATTIDX_FROMDEFAULT]).longValue());
            this.fAttrChecker.returnAttrArray(checkAttributes, xSDocumentInfo);
        }
        xSObjectListImpl = XSObjectListImpl.EMPTY_LIST;
        xSParticleDecl.fAnnotations = xSObjectListImpl;
        checkOccurrences(xSParticleDecl, SchemaSymbols.ELT_ELEMENT, (Element) element.getParentNode(), i2, ((Long) checkAttributes[XSAttributeChecker.ATTIDX_FROMDEFAULT]).longValue());
        this.fAttrChecker.returnAttrArray(checkAttributes, xSDocumentInfo);
    }

    /* JADX DEBUG: Multi-variable search result rejected for r0v67, resolved type: java.lang.String */
    /* JADX DEBUG: Multi-variable search result rejected for r0v68, resolved type: java.lang.String */
    /* JADX DEBUG: Multi-variable search result rejected for r0v70, resolved type: java.lang.String */
    /* JADX WARN: Multi-variable type inference failed */
    /* JADX WARNING: Removed duplicated region for block: B:109:0x0264  */
    /* JADX WARNING: Removed duplicated region for block: B:112:0x0284  */
    /* JADX WARNING: Removed duplicated region for block: B:115:0x0291  */
    /* JADX WARNING: Removed duplicated region for block: B:119:0x02b0  */
    /* JADX WARNING: Removed duplicated region for block: B:121:0x02b5  */
    /* JADX WARNING: Removed duplicated region for block: B:130:0x02ed  */
    /* JADX WARNING: Removed duplicated region for block: B:140:0x0351  */
    /* JADX WARNING: Removed duplicated region for block: B:152:0x0389 A[RETURN] */
    /* JADX WARNING: Removed duplicated region for block: B:153:0x038a  */
    /* JADX WARNING: Removed duplicated region for block: B:169:0x026a A[SYNTHETIC] */
    /* JADX WARNING: Removed duplicated region for block: B:23:0x009c  */
    /* JADX WARNING: Removed duplicated region for block: B:24:0x009f  */
    /* JADX WARNING: Removed duplicated region for block: B:27:0x00a7  */
    /* JADX WARNING: Removed duplicated region for block: B:28:0x00aa  */
    /* JADX WARNING: Removed duplicated region for block: B:31:0x00c2  */
    /* JADX WARNING: Removed duplicated region for block: B:38:0x00d4  */
    /* JADX WARNING: Removed duplicated region for block: B:40:0x00e1  */
    /* JADX WARNING: Removed duplicated region for block: B:44:0x00f3  */
    /* JADX WARNING: Removed duplicated region for block: B:47:0x0103  */
    /* JADX WARNING: Removed duplicated region for block: B:52:0x011e  */
    /* JADX WARNING: Removed duplicated region for block: B:54:0x012f  */
    /* JADX WARNING: Removed duplicated region for block: B:56:0x0133  */
    /* JADX WARNING: Removed duplicated region for block: B:57:0x013c  */
    /* JADX WARNING: Removed duplicated region for block: B:60:0x0142  */
    /* JADX WARNING: Removed duplicated region for block: B:68:0x0173  */
    /* JADX WARNING: Removed duplicated region for block: B:71:0x0178 A[ADDED_TO_REGION] */
    /* JADX WARNING: Removed duplicated region for block: B:81:0x0196  */
    /* JADX WARNING: Removed duplicated region for block: B:84:0x019d  */
    public XSElementDecl traverseNamedElement(Element element, Object[] objArr, XSDocumentInfo xSDocumentInfo, SchemaGrammar schemaGrammar, boolean z, XSObject xSObject) {
        XSTypeDefinition xSTypeDefinition;
        Element firstChildElement;
        int i2;
        XSAnnotationImpl xSAnnotationImpl;
        XSObjectListImpl xSObjectListImpl;
        SchemaGrammar schemaGrammar2;
        boolean z2;
        QName qName;
        String str;
        QName qName2;
        String str2;
        XSElementDecl xSElementDecl;
        String str3;
        QName qName3;
        short s;
        String str4;
        XSElementDecl xSElementDecl2;
        String str5;
        QName qName4;
        String str6;
        String str7;
        XSElementDecl xSElementDecl3;
        String str8;
        QName qName5;
        String str9;
        XSElementDecl xSElementDecl4;
        XSTypeDefinition traverseLocal;
        XSAnnotationImpl xSAnnotationImpl2;
        String syntheticAnnotation;
        String str10;
        Boolean bool = (Boolean) objArr[XSAttributeChecker.ATTIDX_ABSTRACT];
        XInt xInt = (XInt) objArr[XSAttributeChecker.ATTIDX_BLOCK];
        String str11 = (String) objArr[XSAttributeChecker.ATTIDX_DEFAULT];
        XInt xInt2 = (XInt) objArr[XSAttributeChecker.ATTIDX_FINAL];
        String str12 = (String) objArr[XSAttributeChecker.ATTIDX_FIXED];
        XInt xInt3 = (XInt) objArr[XSAttributeChecker.ATTIDX_FORM];
        String str13 = (String) objArr[XSAttributeChecker.ATTIDX_NAME];
        Boolean bool2 = (Boolean) objArr[XSAttributeChecker.ATTIDX_NILLABLE];
        QName qName6 = (QName) objArr[XSAttributeChecker.ATTIDX_SUBSGROUP];
        QName qName7 = (QName) objArr[XSAttributeChecker.ATTIDX_TYPE];
        XSDeclarationPool xSDeclarationPool = this.fSchemaHandler.fDeclPool;
        XSElementDecl elementDecl = xSDeclarationPool != null ? xSDeclarationPool.getElementDecl() : new XSElementDecl();
        if (str13 != null) {
            elementDecl.fName = this.fSymbolTable.addSymbol(str13);
        }
        if (z) {
            elementDecl.fTargetNamespace = xSDocumentInfo.fTargetNamespace;
            elementDecl.setIsGlobal();
        } else {
            if (xSObject instanceof XSComplexTypeDecl) {
                elementDecl.setIsLocal((XSComplexTypeDecl) xSObject);
            }
            if (xInt3 == null) {
                str10 = 0;
                xSTypeDefinition = null;
                if (xSDocumentInfo.fAreLocalElementsQualified) {
                    elementDecl.fTargetNamespace = xSDocumentInfo.fTargetNamespace;
                    XSTypeDefinition xSTypeDefinition2 = xSTypeDefinition;
                    elementDecl.fBlock = xInt == null ? xSDocumentInfo.fBlockDefault : xInt.shortValue();
                    short shortValue = xInt2 == null ? xSDocumentInfo.fFinalDefault : xInt2.shortValue();
                    elementDecl.fFinal = shortValue;
                    elementDecl.fBlock = (short) (elementDecl.fBlock & 7);
                    elementDecl.fFinal = (short) (shortValue & 3);
                    if (bool2.booleanValue()) {
                        elementDecl.setIsNillable();
                    }
                    if (bool != null && bool.booleanValue()) {
                        elementDecl.setIsAbstract();
                    }
                    short s2 = 2;
                    if (str12 != null) {
                        ValidatedInfo validatedInfo = new ValidatedInfo();
                        elementDecl.fDefault = validatedInfo;
                        validatedInfo.normalizedValue = str12;
                    } else if (str11 != null) {
                        ValidatedInfo validatedInfo2 = new ValidatedInfo();
                        elementDecl.fDefault = validatedInfo2;
                        validatedInfo2.normalizedValue = str11;
                        s2 = 1;
                    } else {
                        elementDecl.setConstraintType(0);
                        if (qName6 != null) {
                            elementDecl.fSubGroup = (XSElementDecl) this.fSchemaHandler.getGlobalDecl(xSDocumentInfo, 3, qName6, element);
                        }
                        firstChildElement = DOMUtil.getFirstChildElement(element);
                        if (firstChildElement != null || !DOMUtil.getLocalName(firstChildElement).equals(SchemaSymbols.ELT_ANNOTATION)) {
                            syntheticAnnotation = DOMUtil.getSyntheticAnnotation(element);
                            if (syntheticAnnotation == null) {
                                xSAnnotationImpl2 = traverseSyntheticAnnotation(element, syntheticAnnotation, objArr, false, xSDocumentInfo);
                            } else {
                                i2 = 7;
                                xSAnnotationImpl = xSTypeDefinition2;
                                if (xSAnnotationImpl == null) {
                                    xSObjectListImpl = new XSObjectListImpl();
                                    xSObjectListImpl.addXSObject(xSAnnotationImpl);
                                } else {
                                    xSObjectListImpl = XSObjectListImpl.EMPTY_LIST;
                                }
                                elementDecl.fAnnotations = xSObjectListImpl;
                                if (firstChildElement == null) {
                                    String localName = DOMUtil.getLocalName(firstChildElement);
                                    if (localName.equals(SchemaSymbols.ELT_COMPLEXTYPE)) {
                                        schemaGrammar2 = schemaGrammar;
                                        traverseLocal = this.fSchemaHandler.fComplexTypeTraverser.traverseLocal(firstChildElement, xSDocumentInfo, schemaGrammar2);
                                    } else {
                                        schemaGrammar2 = schemaGrammar;
                                        if (localName.equals(SchemaSymbols.ELT_SIMPLETYPE)) {
                                            traverseLocal = this.fSchemaHandler.fSimpleTypeTraverser.traverseLocal(firstChildElement, xSDocumentInfo, schemaGrammar2);
                                        }
                                    }
                                    xSTypeDefinition2 = traverseLocal;
                                    firstChildElement = DOMUtil.getNextSiblingElement(firstChildElement);
                                    z2 = true;
                                    if (xSTypeDefinition2 == null || qName7 == null) {
                                        qName = qName7;
                                    } else {
                                        qName = qName7;
                                        xSTypeDefinition2 = (XSTypeDefinition) this.fSchemaHandler.getGlobalDecl(xSDocumentInfo, i2, qName, element);
                                        if (xSTypeDefinition2 == null) {
                                            elementDecl.fUnresolvedTypeName = qName;
                                        }
                                    }
                                    if (xSTypeDefinition2 == null && (xSElementDecl4 = elementDecl.fSubGroup) != null) {
                                        xSTypeDefinition2 = xSElementDecl4.fType;
                                    }
                                    if (xSTypeDefinition2 == null) {
                                        xSTypeDefinition2 = SchemaGrammar.fAnyType;
                                    }
                                    elementDecl.fType = xSTypeDefinition2;
                                    if (firstChildElement != null) {
                                        String localName2 = DOMUtil.getLocalName(firstChildElement);
                                        Element element2 = firstChildElement;
                                        while (element2 != null && (localName2.equals(SchemaSymbols.ELT_KEY) || localName2.equals(SchemaSymbols.ELT_KEYREF) || localName2.equals(SchemaSymbols.ELT_UNIQUE))) {
                                            if (localName2.equals(SchemaSymbols.ELT_KEY) || localName2.equals(SchemaSymbols.ELT_UNIQUE)) {
                                                DOMUtil.setHidden(element2, this.fSchemaHandler.fHiddenNodes);
                                                this.fSchemaHandler.fUniqueOrKeyTraverser.traverse(element2, elementDecl, xSDocumentInfo, schemaGrammar2);
                                                if (DOMUtil.getAttrValue(element2, SchemaSymbols.ATT_NAME).length() != 0) {
                                                    XSDHandler xSDHandler = this.fSchemaHandler;
                                                    if (xSDocumentInfo.fTargetNamespace == null) {
                                                        StringBuffer a = a.a(XSSFDataValidationConstraint.LIST_SEPARATOR);
                                                        a.append(DOMUtil.getAttrValue(element2, SchemaSymbols.ATT_NAME));
                                                        str9 = a.toString();
                                                        str7 = localName2;
                                                    } else {
                                                        StringBuffer stringBuffer = new StringBuffer();
                                                        str7 = localName2;
                                                        stringBuffer.append(xSDocumentInfo.fTargetNamespace);
                                                        stringBuffer.append(XSSFDataValidationConstraint.LIST_SEPARATOR);
                                                        stringBuffer.append(DOMUtil.getAttrValue(element2, SchemaSymbols.ATT_NAME));
                                                        str9 = stringBuffer.toString();
                                                    }
                                                    qName4 = qName;
                                                    xSElementDecl3 = elementDecl;
                                                    qName5 = qName6;
                                                    str6 = str13;
                                                    str8 = str12;
                                                    str5 = str11;
                                                    xSDHandler.checkForDuplicateNames(str9, 1, this.fSchemaHandler.getIDRegistry(), this.fSchemaHandler.getIDRegistry_sub(), element2, xSDocumentInfo);
                                                    element2 = DOMUtil.getNextSiblingElement(element2);
                                                    if (element2 == null) {
                                                        str7 = DOMUtil.getLocalName(element2);
                                                    }
                                                    qName6 = qName5;
                                                    str12 = str8;
                                                    elementDecl = xSElementDecl3;
                                                    localName2 = str7;
                                                    str13 = str6;
                                                    qName = qName4;
                                                    str11 = str5;
                                                    schemaGrammar2 = schemaGrammar;
                                                }
                                            } else if (localName2.equals(SchemaSymbols.ELT_KEYREF)) {
                                                this.fSchemaHandler.storeKeyRef(element2, xSDocumentInfo, elementDecl);
                                            }
                                            str7 = localName2;
                                            qName4 = qName;
                                            xSElementDecl3 = elementDecl;
                                            qName5 = qName6;
                                            str6 = str13;
                                            str8 = str12;
                                            str5 = str11;
                                            element2 = DOMUtil.getNextSiblingElement(element2);
                                            if (element2 == null) {
                                            }
                                            qName6 = qName5;
                                            str12 = str8;
                                            elementDecl = xSElementDecl3;
                                            localName2 = str7;
                                            str13 = str6;
                                            qName = qName4;
                                            str11 = str5;
                                            schemaGrammar2 = schemaGrammar;
                                        }
                                        qName2 = qName;
                                        xSElementDecl = elementDecl;
                                        qName3 = qName6;
                                        str2 = str13;
                                        str3 = str12;
                                        str = str11;
                                        firstChildElement = element2;
                                    } else {
                                        qName2 = qName;
                                        xSElementDecl = elementDecl;
                                        qName3 = qName6;
                                        str2 = str13;
                                        str3 = str12;
                                        str = str11;
                                    }
                                    if (str2 == null) {
                                        if (z) {
                                            s = 0;
                                            reportSchemaError("s4s-att-must-appear", new Object[]{SchemaSymbols.ELT_ELEMENT, SchemaSymbols.ATT_NAME}, element);
                                        } else {
                                            s = 0;
                                            reportSchemaError("src-element.2.1", null, element);
                                        }
                                        str4 = XSDAbstractTraverser.NO_NAME;
                                    } else {
                                        s = 0;
                                        str4 = str2;
                                    }
                                    if (firstChildElement != null) {
                                        Object[] objArr2 = new Object[3];
                                        objArr2[s] = str4;
                                        objArr2[1] = "(annotation?, (simpleType | complexType)?, (unique | key | keyref)*))";
                                        objArr2[2] = DOMUtil.getLocalName(firstChildElement);
                                        reportSchemaError("s4s-elt-must-match.1", objArr2, firstChildElement);
                                    }
                                    if (!(str == null || str3 == null)) {
                                        Object[] objArr3 = new Object[1];
                                        objArr3[s] = str4;
                                        reportSchemaError(XmlErrorCodes.SCHEMA_ELEM$DEFAULT_OR_FIXED, objArr3, element);
                                    }
                                    if (z2 && qName2 != null) {
                                        Object[] objArr4 = new Object[1];
                                        objArr4[s] = str4;
                                        reportSchemaError(XmlErrorCodes.SCHEMA_ELEM$TYPE_ATTR_OR_NESTED_TYPE, objArr4, element);
                                    }
                                    checkNotationType(str4, xSTypeDefinition2, element);
                                    if (xSElementDecl.fDefault != null) {
                                        this.fValidationState.setNamespaceSupport(xSDocumentInfo.fNamespaceSupport);
                                        XSTypeDefinition xSTypeDefinition3 = xSElementDecl.fType;
                                        ValidatedInfo validatedInfo3 = xSElementDecl.fDefault;
                                        if (XSConstraints.ElementDefaultValidImmediate(xSTypeDefinition3, validatedInfo3.normalizedValue, this.fValidationState, validatedInfo3) == null) {
                                            Object[] objArr5 = new Object[2];
                                            objArr5[s] = str4;
                                            objArr5[1] = xSElementDecl.fDefault.normalizedValue;
                                            reportSchemaError(XmlErrorCodes.ELEM_PROPERTIES$CONSTRAINT_VALID, objArr5, element);
                                            xSElementDecl.fDefault = null;
                                            xSElementDecl.setConstraintType(s);
                                        }
                                    }
                                    XSElementDecl xSElementDecl5 = xSElementDecl.fSubGroup;
                                    if (xSElementDecl5 != null && !XSConstraints.checkTypeDerivationOk(xSElementDecl.fType, xSElementDecl5.fType, xSElementDecl5.fFinal)) {
                                        Object[] objArr6 = new Object[2];
                                        objArr6[s] = str4;
                                        StringBuffer stringBuffer2 = new StringBuffer();
                                        stringBuffer2.append(qName3.prefix);
                                        stringBuffer2.append(":");
                                        stringBuffer2.append(qName3.localpart);
                                        objArr6[1] = stringBuffer2.toString();
                                        reportSchemaError(XmlErrorCodes.ELEM_PROPERTIES$SUBSTITUTION_VALID, objArr6, element);
                                        xSElementDecl.fSubGroup = null;
                                    }
                                    if (xSElementDecl.fDefault != null || ((xSTypeDefinition2.getTypeCategory() != 16 || !((XSSimpleType) xSTypeDefinition2).isIDType()) && (xSTypeDefinition2.getTypeCategory() != 15 || !((XSComplexTypeDecl) xSTypeDefinition2).containsTypeID()))) {
                                        xSElementDecl2 = null;
                                    } else {
                                        Object[] objArr7 = new Object[1];
                                        objArr7[s] = xSElementDecl.fName;
                                        reportSchemaError("e-props-correct.5", objArr7, element);
                                        xSElementDecl2 = null;
                                        xSElementDecl.fDefault = null;
                                        xSElementDecl.setConstraintType(s);
                                    }
                                    if (xSElementDecl.fName == null) {
                                        return xSElementDecl2;
                                    }
                                    if (z) {
                                        schemaGrammar.addGlobalElementDeclAll(xSElementDecl);
                                        if (schemaGrammar.getGlobalElementDecl(xSElementDecl.fName) == null) {
                                            schemaGrammar.addGlobalElementDecl(xSElementDecl);
                                        }
                                        String schemaDocument2SystemId = this.fSchemaHandler.schemaDocument2SystemId(xSDocumentInfo);
                                        XSElementDecl globalElementDecl = schemaGrammar.getGlobalElementDecl(xSElementDecl.fName, schemaDocument2SystemId);
                                        if (globalElementDecl == null) {
                                            schemaGrammar.addGlobalElementDecl(xSElementDecl, schemaDocument2SystemId);
                                        }
                                        if (this.fSchemaHandler.fTolerateDuplicates) {
                                            if (globalElementDecl == null) {
                                                globalElementDecl = xSElementDecl;
                                            }
                                            this.fSchemaHandler.addGlobalElementDecl(globalElementDecl);
                                            return globalElementDecl;
                                        }
                                    }
                                    return xSElementDecl;
                                }
                                schemaGrammar2 = schemaGrammar;
                                z2 = false;
                                if (xSTypeDefinition2 == null) {
                                }
                                qName = qName7;
                                xSTypeDefinition2 = xSElementDecl4.fType;
                                if (xSTypeDefinition2 == null) {
                                }
                                elementDecl.fType = xSTypeDefinition2;
                                if (firstChildElement != null) {
                                }
                                if (str2 == null) {
                                }
                                if (firstChildElement != null) {
                                }
                                Object[] objArr32 = new Object[1];
                                objArr32[s] = str4;
                                reportSchemaError(XmlErrorCodes.SCHEMA_ELEM$DEFAULT_OR_FIXED, objArr32, element);
                                Object[] objArr42 = new Object[1];
                                objArr42[s] = str4;
                                reportSchemaError(XmlErrorCodes.SCHEMA_ELEM$TYPE_ATTR_OR_NESTED_TYPE, objArr42, element);
                                checkNotationType(str4, xSTypeDefinition2, element);
                                if (xSElementDecl.fDefault != null) {
                                }
                                XSElementDecl xSElementDecl52 = xSElementDecl.fSubGroup;
                                Object[] objArr62 = new Object[2];
                                objArr62[s] = str4;
                                StringBuffer stringBuffer22 = new StringBuffer();
                                stringBuffer22.append(qName3.prefix);
                                stringBuffer22.append(":");
                                stringBuffer22.append(qName3.localpart);
                                objArr62[1] = stringBuffer22.toString();
                                reportSchemaError(XmlErrorCodes.ELEM_PROPERTIES$SUBSTITUTION_VALID, objArr62, element);
                                xSElementDecl.fSubGroup = null;
                                if (xSElementDecl.fDefault != null) {
                                }
                                xSElementDecl2 = null;
                                if (xSElementDecl.fName == null) {
                                }
                            }
                        } else {
                            xSAnnotationImpl2 = traverseAnnotationDecl(firstChildElement, objArr, false, xSDocumentInfo);
                            firstChildElement = DOMUtil.getNextSiblingElement(firstChildElement);
                        }
                        i2 = 7;
                        xSAnnotationImpl = xSAnnotationImpl2;
                        if (xSAnnotationImpl == null) {
                        }
                        elementDecl.fAnnotations = xSObjectListImpl;
                        if (firstChildElement == null) {
                        }
                        z2 = false;
                        if (xSTypeDefinition2 == null) {
                        }
                        qName = qName7;
                        xSTypeDefinition2 = xSElementDecl4.fType;
                        if (xSTypeDefinition2 == null) {
                        }
                        elementDecl.fType = xSTypeDefinition2;
                        if (firstChildElement != null) {
                        }
                        if (str2 == null) {
                        }
                        if (firstChildElement != null) {
                        }
                        Object[] objArr322 = new Object[1];
                        objArr322[s] = str4;
                        reportSchemaError(XmlErrorCodes.SCHEMA_ELEM$DEFAULT_OR_FIXED, objArr322, element);
                        Object[] objArr422 = new Object[1];
                        objArr422[s] = str4;
                        reportSchemaError(XmlErrorCodes.SCHEMA_ELEM$TYPE_ATTR_OR_NESTED_TYPE, objArr422, element);
                        checkNotationType(str4, xSTypeDefinition2, element);
                        if (xSElementDecl.fDefault != null) {
                        }
                        XSElementDecl xSElementDecl522 = xSElementDecl.fSubGroup;
                        Object[] objArr622 = new Object[2];
                        objArr622[s] = str4;
                        StringBuffer stringBuffer222 = new StringBuffer();
                        stringBuffer222.append(qName3.prefix);
                        stringBuffer222.append(":");
                        stringBuffer222.append(qName3.localpart);
                        objArr622[1] = stringBuffer222.toString();
                        reportSchemaError(XmlErrorCodes.ELEM_PROPERTIES$SUBSTITUTION_VALID, objArr622, element);
                        xSElementDecl.fSubGroup = null;
                        if (xSElementDecl.fDefault != null) {
                        }
                        xSElementDecl2 = null;
                        if (xSElementDecl.fName == null) {
                        }
                    }
                    elementDecl.setConstraintType(s2);
                    if (qName6 != null) {
                    }
                    firstChildElement = DOMUtil.getFirstChildElement(element);
                    if (firstChildElement != null) {
                    }
                    syntheticAnnotation = DOMUtil.getSyntheticAnnotation(element);
                    if (syntheticAnnotation == null) {
                    }
                }
            } else if (xInt3.intValue() == 1) {
                elementDecl.fTargetNamespace = xSDocumentInfo.fTargetNamespace;
            } else {
                str10 = 0;
            }
            elementDecl.fTargetNamespace = str10;
            xSTypeDefinition = str10;
            XSTypeDefinition xSTypeDefinition22 = xSTypeDefinition;
            elementDecl.fBlock = xInt == null ? xSDocumentInfo.fBlockDefault : xInt.shortValue();
            if (xInt2 == null) {
            }
            elementDecl.fFinal = shortValue;
            elementDecl.fBlock = (short) (elementDecl.fBlock & 7);
            elementDecl.fFinal = (short) (shortValue & 3);
            if (bool2.booleanValue()) {
            }
            elementDecl.setIsAbstract();
            short s22 = 2;
            if (str12 != null) {
            }
            elementDecl.setConstraintType(s22);
            if (qName6 != null) {
            }
            firstChildElement = DOMUtil.getFirstChildElement(element);
            if (firstChildElement != null) {
            }
            syntheticAnnotation = DOMUtil.getSyntheticAnnotation(element);
            if (syntheticAnnotation == null) {
            }
        }
        xSTypeDefinition = null;
        XSTypeDefinition xSTypeDefinition222 = xSTypeDefinition;
        elementDecl.fBlock = xInt == null ? xSDocumentInfo.fBlockDefault : xInt.shortValue();
        if (xInt2 == null) {
        }
        elementDecl.fFinal = shortValue;
        elementDecl.fBlock = (short) (elementDecl.fBlock & 7);
        elementDecl.fFinal = (short) (shortValue & 3);
        if (bool2.booleanValue()) {
        }
        elementDecl.setIsAbstract();
        short s222 = 2;
        if (str12 != null) {
        }
        elementDecl.setConstraintType(s222);
        if (qName6 != null) {
        }
        firstChildElement = DOMUtil.getFirstChildElement(element);
        if (firstChildElement != null) {
        }
        syntheticAnnotation = DOMUtil.getSyntheticAnnotation(element);
        if (syntheticAnnotation == null) {
        }
    }
}
