package org.apache.xerces.impl.xs.traversers;

import org.apache.xerces.impl.xs.SchemaGrammar;
import org.apache.xerces.impl.xs.SchemaSymbols;
import org.apache.xerces.impl.xs.XSElementDecl;
import org.apache.xerces.impl.xs.identity.IdentityConstraint;
import org.apache.xerces.impl.xs.identity.KeyRef;
import org.apache.xerces.impl.xs.identity.UniqueOrKey;
import org.apache.xerces.xni.QName;
import org.apache.xmlbeans.XmlErrorCodes;
import org.w3c.dom.Element;

public class XSDKeyrefTraverser extends XSDAbstractIDConstraintTraverser {
    public XSDKeyrefTraverser(XSDHandler xSDHandler, XSAttributeChecker xSAttributeChecker) {
        super(xSDHandler, xSAttributeChecker);
    }

    public void traverse(Element element, XSElementDecl xSElementDecl, XSDocumentInfo xSDocumentInfo, SchemaGrammar schemaGrammar) {
        Object[] checkAttributes = this.fAttrChecker.checkAttributes(element, false, xSDocumentInfo);
        String str = (String) checkAttributes[XSAttributeChecker.ATTIDX_NAME];
        if (str == null) {
            reportSchemaError("s4s-att-must-appear", new Object[]{SchemaSymbols.ELT_KEYREF, SchemaSymbols.ATT_NAME}, element);
        } else {
            QName qName = (QName) checkAttributes[XSAttributeChecker.ATTIDX_REFER];
            if (qName == null) {
                reportSchemaError("s4s-att-must-appear", new Object[]{SchemaSymbols.ELT_KEYREF, SchemaSymbols.ATT_REFER}, element);
            } else {
                UniqueOrKey uniqueOrKey = null;
                IdentityConstraint identityConstraint = (IdentityConstraint) this.fSchemaHandler.getGlobalDecl(xSDocumentInfo, 5, qName, element);
                if (identityConstraint != null) {
                    if (identityConstraint.getCategory() == 1 || identityConstraint.getCategory() == 3) {
                        uniqueOrKey = (UniqueOrKey) identityConstraint;
                    } else {
                        reportSchemaError(XmlErrorCodes.SCHEMA_QNAME_RESOLVE, new Object[]{qName.rawname, "identity constraint key/unique"}, element);
                    }
                }
                if (uniqueOrKey != null) {
                    IdentityConstraint keyRef = new KeyRef(xSDocumentInfo.fTargetNamespace, str, xSElementDecl.fName, uniqueOrKey);
                    if (traverseIdentityConstraint(keyRef, element, xSDocumentInfo, checkAttributes)) {
                        if (uniqueOrKey.getFieldCount() != keyRef.getFieldCount()) {
                            reportSchemaError(XmlErrorCodes.IDENTITY_CONSTRAINT_PROPERTIES$KEY_KEYREF_FIELD_COUNT_EQ, new Object[]{str, uniqueOrKey.getIdentityConstraintName()}, element);
                        } else {
                            if (schemaGrammar.getIDConstraintDecl(keyRef.getIdentityConstraintName()) == null) {
                                schemaGrammar.addIDConstraintDecl(xSElementDecl, keyRef);
                            }
                            String schemaDocument2SystemId = this.fSchemaHandler.schemaDocument2SystemId(xSDocumentInfo);
                            IdentityConstraint iDConstraintDecl = schemaGrammar.getIDConstraintDecl(keyRef.getIdentityConstraintName(), schemaDocument2SystemId);
                            if (iDConstraintDecl == null) {
                                schemaGrammar.addIDConstraintDecl(xSElementDecl, keyRef, schemaDocument2SystemId);
                            }
                            if (this.fSchemaHandler.fTolerateDuplicates) {
                                if (iDConstraintDecl != null && (iDConstraintDecl instanceof KeyRef)) {
                                    keyRef = (KeyRef) iDConstraintDecl;
                                }
                                this.fSchemaHandler.addIDConstraintDecl(keyRef);
                            }
                        }
                    }
                }
            }
        }
        this.fAttrChecker.returnAttrArray(checkAttributes, xSDocumentInfo);
    }
}
