package org.apache.xerces.impl.xs.traversers;

import java.util.ArrayList;
import java.util.Vector;
import org.apache.xerces.impl.dv.InvalidDatatypeFacetException;
import org.apache.xerces.impl.dv.SchemaDVFactory;
import org.apache.xerces.impl.dv.XSSimpleType;
import org.apache.xerces.impl.dv.xs.XSSimpleTypeDecl;
import org.apache.xerces.impl.xs.SchemaGrammar;
import org.apache.xerces.impl.xs.SchemaSymbols;
import org.apache.xerces.impl.xs.XSAnnotationImpl;
import org.apache.xerces.impl.xs.traversers.XSDAbstractTraverser;
import org.apache.xerces.impl.xs.util.XInt;
import org.apache.xerces.impl.xs.util.XSObjectListImpl;
import org.apache.xerces.util.DOMUtil;
import org.apache.xerces.xni.QName;
import org.apache.xerces.xs.XSObjectList;
import org.apache.xerces.xs.XSTypeDefinition;
import org.apache.xmlbeans.XmlErrorCodes;
import org.w3c.dom.Element;

public class XSDSimpleTypeTraverser extends XSDAbstractTraverser {
    public boolean fIsBuiltIn = false;

    public XSDSimpleTypeTraverser(XSDHandler xSDHandler, XSAttributeChecker xSAttributeChecker) {
        super(xSDHandler, xSAttributeChecker);
    }

    private final boolean checkBuiltIn(String str, String str2) {
        if (str2 != SchemaSymbols.URI_SCHEMAFORSCHEMA) {
            return false;
        }
        if (SchemaGrammar.SG_SchemaNS.getGlobalTypeDecl(str) != null) {
            this.fIsBuiltIn = true;
        }
        return this.fIsBuiltIn;
    }

    private XSSimpleType errorType(String str, String str2, short s) {
        XSSimpleType xSSimpleType = (XSSimpleType) SchemaGrammar.SG_SchemaNS.getTypeDefinition(SchemaSymbols.ATTVAL_STRING);
        if (s == 2) {
            return this.fSchemaHandler.fDVFactory.createTypeRestriction(str, str2, 0, xSSimpleType, null);
        }
        if (s == 8) {
            return this.fSchemaHandler.fDVFactory.createTypeUnion(str, str2, 0, new XSSimpleType[]{xSSimpleType}, null);
        } else if (s != 16) {
            return null;
        } else {
            return this.fSchemaHandler.fDVFactory.createTypeList(str, str2, 0, xSSimpleType, null);
        }
    }

    private XSSimpleType findDTValidator(Element element, String str, QName qName, short s, XSDocumentInfo xSDocumentInfo) {
        XSTypeDefinition xSTypeDefinition;
        if (qName == null || (xSTypeDefinition = (XSTypeDefinition) this.fSchemaHandler.getGlobalDecl(xSDocumentInfo, 7, qName, element)) == null) {
            return null;
        }
        if (xSTypeDefinition.getTypeCategory() != 16) {
            reportSchemaError(XmlErrorCodes.SIMPLE_TYPE_RESTRICTION$ATOMIC_NOT_SIMPLE, new Object[]{qName.rawname, str}, element);
            return null;
        } else if (xSTypeDefinition == SchemaGrammar.fAnySimpleType && s == 2) {
            if (checkBuiltIn(str, xSDocumentInfo.fTargetNamespace)) {
                return null;
            }
            reportSchemaError(XmlErrorCodes.SIMPLE_TYPE_RESTRICTION$ATOMIC_NOT_SIMPLE, new Object[]{qName.rawname, str}, element);
            return null;
        } else if ((xSTypeDefinition.getFinal() & s) == 0) {
            return (XSSimpleType) xSTypeDefinition;
        } else {
            if (s == 2) {
                reportSchemaError(XmlErrorCodes.SIMPLE_TYPE_PROPERTIES$RESTRICTION_FINAL, new Object[]{str, qName.rawname}, element);
            } else if (s == 16) {
                reportSchemaError("cos-st-restricts.2.3.1.1", new Object[]{qName.rawname, str}, element);
            } else if (s == 8) {
                reportSchemaError("cos-st-restricts.3.3.1.1", new Object[]{qName.rawname, str}, element);
            }
            return null;
        }
    }

    private String genAnonTypeName(Element element) {
        StringBuffer stringBuffer = new StringBuffer("#AnonType_");
        while (true) {
            element = DOMUtil.getParent(element);
            if (element != null && element != DOMUtil.getRoot(DOMUtil.getDocument(element))) {
                stringBuffer.append(element.getAttribute(SchemaSymbols.ATT_NAME));
            }
        }
        return stringBuffer.toString();
    }

    /* JADX WARNING: Removed duplicated region for block: B:128:0x026a  */
    /* JADX WARNING: Removed duplicated region for block: B:129:0x026e  */
    /* JADX WARNING: Removed duplicated region for block: B:144:0x029a  */
    /* JADX WARNING: Removed duplicated region for block: B:145:0x029c  */
    /* JADX WARNING: Removed duplicated region for block: B:20:0x0062  */
    /* JADX WARNING: Removed duplicated region for block: B:22:0x0077  */
    /* JADX WARNING: Removed duplicated region for block: B:34:0x00b4  */
    /* JADX WARNING: Removed duplicated region for block: B:37:0x00cf  */
    /* JADX WARNING: Removed duplicated region for block: B:38:0x00d2  */
    /* JADX WARNING: Removed duplicated region for block: B:52:0x0121  */
    /* JADX WARNING: Removed duplicated region for block: B:56:0x014d  */
    private XSSimpleType getSimpleType(String str, Element element, Object[] objArr, XSDocumentInfo xSDocumentInfo, SchemaGrammar schemaGrammar) {
        XSAnnotationImpl[] xSAnnotationImplArr;
        Element element2;
        boolean z;
        boolean z2;
        boolean z3;
        short s;
        Element nextSiblingElement;
        QName qName;
        Element firstChildElement;
        Object[] objArr2;
        Vector vector;
        Element element3;
        Element element4;
        XSAnnotationImpl[] xSAnnotationImplArr2;
        XSAnnotationImpl[] xSAnnotationImplArr3;
        XSSimpleType xSSimpleType;
        Vector vector2;
        short s2;
        ArrayList arrayList;
        int i2;
        Object[] objArr3;
        Object[] objArr4;
        int i3;
        XSAnnotationImpl[] xSAnnotationImplArr4;
        XSSimpleType xSSimpleType2;
        Object[] objArr5;
        String str2;
        String syntheticAnnotation;
        Element element5;
        XSAnnotationImpl[] xSAnnotationImplArr5;
        XInt xInt = (XInt) objArr[XSAttributeChecker.ATTIDX_FINAL];
        int intValue = xInt == null ? xSDocumentInfo.fFinalDefault : xInt.intValue();
        Element firstChildElement2 = DOMUtil.getFirstChildElement(element);
        if (firstChildElement2 == null || !DOMUtil.getLocalName(firstChildElement2).equals(SchemaSymbols.ELT_ANNOTATION)) {
            String syntheticAnnotation2 = DOMUtil.getSyntheticAnnotation(element);
            if (syntheticAnnotation2 != null) {
                xSAnnotationImplArr5 = new XSAnnotationImpl[]{traverseSyntheticAnnotation(element, syntheticAnnotation2, objArr, false, xSDocumentInfo)};
            } else {
                element2 = firstChildElement2;
                xSAnnotationImplArr = null;
                if (element2 != null) {
                    reportSchemaError("s4s-elt-must-match.2", new Object[]{SchemaSymbols.ELT_SIMPLETYPE, "(annotation?, (restriction | list | union))"}, element);
                    return errorType(str, xSDocumentInfo.fTargetNamespace, 2);
                }
                String localName = DOMUtil.getLocalName(element2);
                if (localName.equals(SchemaSymbols.ELT_RESTRICTION)) {
                    s = 2;
                    z3 = true;
                    z2 = false;
                } else if (localName.equals(SchemaSymbols.ELT_LIST)) {
                    s = 16;
                    z3 = false;
                    z2 = true;
                } else if (localName.equals(SchemaSymbols.ELT_UNION)) {
                    s = 8;
                    z3 = false;
                    z2 = false;
                    z = true;
                    nextSiblingElement = DOMUtil.getNextSiblingElement(element2);
                    if (nextSiblingElement != null) {
                        reportSchemaError("s4s-elt-must-match.1", new Object[]{SchemaSymbols.ELT_SIMPLETYPE, "(annotation?, (restriction | list | union))", DOMUtil.getLocalName(nextSiblingElement)}, nextSiblingElement);
                    }
                    Object[] checkAttributes = this.fAttrChecker.checkAttributes(element2, false, xSDocumentInfo);
                    qName = (QName) checkAttributes[!z3 ? XSAttributeChecker.ATTIDX_BASE : XSAttributeChecker.ATTIDX_ITEMTYPE];
                    Vector vector3 = (Vector) checkAttributes[XSAttributeChecker.ATTIDX_MEMBERTYPES];
                    firstChildElement = DOMUtil.getFirstChildElement(element2);
                    if (firstChildElement != null || !DOMUtil.getLocalName(firstChildElement).equals(SchemaSymbols.ELT_ANNOTATION)) {
                        syntheticAnnotation = DOMUtil.getSyntheticAnnotation(element2);
                        if (syntheticAnnotation == null) {
                            element5 = firstChildElement;
                            vector = vector3;
                            objArr2 = checkAttributes;
                            element3 = element2;
                            XSAnnotationImpl traverseSyntheticAnnotation = traverseSyntheticAnnotation(element2, syntheticAnnotation, objArr2, false, xSDocumentInfo);
                            if (xSAnnotationImplArr == null) {
                                xSAnnotationImplArr2 = new XSAnnotationImpl[]{traverseSyntheticAnnotation};
                                element4 = element5;
                            } else {
                                xSAnnotationImplArr2 = new XSAnnotationImpl[]{xSAnnotationImplArr[0], traverseSyntheticAnnotation};
                            }
                        } else {
                            element5 = firstChildElement;
                            vector = vector3;
                            objArr2 = checkAttributes;
                            element3 = element2;
                            xSAnnotationImplArr2 = xSAnnotationImplArr;
                        }
                        element4 = element5;
                    } else {
                        XSAnnotationImpl traverseAnnotationDecl = traverseAnnotationDecl(firstChildElement, checkAttributes, false, xSDocumentInfo);
                        if (traverseAnnotationDecl != null) {
                            if (xSAnnotationImplArr == null) {
                                xSAnnotationImplArr = new XSAnnotationImpl[]{traverseAnnotationDecl};
                            } else {
                                xSAnnotationImplArr = new XSAnnotationImpl[]{xSAnnotationImplArr[0], traverseAnnotationDecl};
                                vector = vector3;
                                objArr2 = checkAttributes;
                                element3 = element2;
                                xSAnnotationImplArr2 = xSAnnotationImplArr;
                                element4 = DOMUtil.getNextSiblingElement(firstChildElement);
                            }
                        }
                        vector = vector3;
                        objArr2 = checkAttributes;
                        element3 = element2;
                        xSAnnotationImplArr2 = xSAnnotationImplArr;
                        element4 = DOMUtil.getNextSiblingElement(firstChildElement);
                    }
                    if ((!z3 || z2) && qName != null) {
                        xSAnnotationImplArr3 = xSAnnotationImplArr2;
                        xSSimpleType = findDTValidator(element3, str, qName, s, xSDocumentInfo);
                        if (xSSimpleType == null && this.fIsBuiltIn) {
                            this.fIsBuiltIn = false;
                            return null;
                        }
                    } else {
                        xSAnnotationImplArr3 = xSAnnotationImplArr2;
                        xSSimpleType = null;
                    }
                    if (z) {
                        Vector vector4 = vector;
                        if (vector4 == null || vector4.size() <= 0) {
                            vector2 = vector4;
                        } else {
                            int size = vector4.size();
                            ArrayList arrayList2 = new ArrayList(size);
                            int i4 = 0;
                            while (i4 < size) {
                                XSSimpleType findDTValidator = findDTValidator(element3, str, (QName) vector4.elementAt(i4), 8, xSDocumentInfo);
                                if (findDTValidator != null) {
                                    if (findDTValidator.getVariety() == 3) {
                                        XSObjectList memberTypes = findDTValidator.getMemberTypes();
                                        for (int i5 = 0; i5 < memberTypes.getLength(); i5++) {
                                            arrayList2.add(memberTypes.item(i5));
                                        }
                                    } else {
                                        arrayList2.add(findDTValidator);
                                    }
                                }
                                i4++;
                                arrayList2 = arrayList2;
                                size = size;
                                vector4 = vector4;
                            }
                            arrayList = arrayList2;
                            vector2 = vector4;
                            s2 = 3;
                            if (element4 != null || !DOMUtil.getLocalName(element4).equals(SchemaSymbols.ELT_SIMPLETYPE)) {
                                i2 = 2;
                                if ((!z3 || z2) && qName == null) {
                                    str2 = !z2 ? "src-simple-type.3.b" : "src-simple-type.2.b";
                                    objArr5 = null;
                                } else {
                                    objArr3 = null;
                                    objArr3 = null;
                                    objArr5 = null;
                                    if (z && (vector2 == null || vector2.size() == 0)) {
                                        str2 = XmlErrorCodes.SCHEMA_SIMPLE_TYPE$UNION_HAS_MEMBER_TYPES_OR_SIMPLE_TYPES;
                                    }
                                }
                                reportSchemaError(str2, objArr5, element3);
                                objArr3 = objArr5;
                            } else {
                                if (z3 || z2) {
                                    i2 = 2;
                                    if (qName != null) {
                                        reportSchemaError(z2 ? "src-simple-type.3.a" : "src-simple-type.2.a", null, element4);
                                    }
                                    if (xSSimpleType == null) {
                                        xSSimpleType = traverseLocal(element4, xSDocumentInfo, schemaGrammar);
                                    }
                                    element4 = DOMUtil.getNextSiblingElement(element4);
                                } else if (z) {
                                    if (arrayList == null) {
                                        i2 = 2;
                                        arrayList = new ArrayList(2);
                                    } else {
                                        i2 = 2;
                                    }
                                    do {
                                        XSSimpleType traverseLocal = traverseLocal(element4, xSDocumentInfo, schemaGrammar);
                                        if (traverseLocal != null) {
                                            if (traverseLocal.getVariety() == s2) {
                                                XSObjectList memberTypes2 = traverseLocal.getMemberTypes();
                                                for (int i6 = 0; i6 < memberTypes2.getLength(); i6++) {
                                                    arrayList.add(memberTypes2.item(i6));
                                                }
                                            } else {
                                                arrayList.add(traverseLocal);
                                            }
                                        }
                                        element4 = DOMUtil.getNextSiblingElement(element4);
                                        if (element4 == null) {
                                            break;
                                        }
                                    } while (DOMUtil.getLocalName(element4).equals(SchemaSymbols.ELT_SIMPLETYPE));
                                } else {
                                    i2 = 2;
                                }
                                objArr3 = null;
                            }
                            Element element6 = element4;
                            if ((!z3 || z2) && xSSimpleType == null) {
                                this.fAttrChecker.returnAttrArray(objArr2, xSDocumentInfo);
                                return errorType(str, xSDocumentInfo.fTargetNamespace, !z3 ? (short) 2 : 16);
                            } else if (z && (arrayList == null || arrayList.size() == 0)) {
                                this.fAttrChecker.returnAttrArray(objArr2, xSDocumentInfo);
                                return errorType(str, xSDocumentInfo.fTargetNamespace, 8);
                            } else if (!z2 || !isListDatatype(xSSimpleType)) {
                                if (z3) {
                                    SchemaDVFactory schemaDVFactory = this.fSchemaHandler.fDVFactory;
                                    String str3 = xSDocumentInfo.fTargetNamespace;
                                    short s3 = (short) intValue;
                                    XSObjectListImpl xSObjectListImpl = xSAnnotationImplArr3 == null ? objArr3 : new XSObjectListImpl(xSAnnotationImplArr3, xSAnnotationImplArr3.length);
                                    xSAnnotationImplArr4 = xSAnnotationImplArr3;
                                    objArr4 = objArr2;
                                    i3 = 3;
                                    xSSimpleType2 = schemaDVFactory.createTypeRestriction(str, str3, s3, xSSimpleType, xSObjectListImpl);
                                } else {
                                    objArr4 = objArr2;
                                    xSAnnotationImplArr4 = xSAnnotationImplArr3;
                                    i3 = 3;
                                    if (z2) {
                                        xSSimpleType2 = this.fSchemaHandler.fDVFactory.createTypeList(str, xSDocumentInfo.fTargetNamespace, (short) intValue, xSSimpleType, xSAnnotationImplArr4 == null ? null : new XSObjectListImpl(xSAnnotationImplArr4, xSAnnotationImplArr4.length));
                                    } else if (z) {
                                        xSSimpleType2 = this.fSchemaHandler.fDVFactory.createTypeUnion(str, xSDocumentInfo.fTargetNamespace, (short) intValue, (XSSimpleType[]) arrayList.toArray(new XSSimpleType[arrayList.size()]), xSAnnotationImplArr4 == null ? null : new XSObjectListImpl(xSAnnotationImplArr4, xSAnnotationImplArr4.length));
                                    } else {
                                        xSSimpleType2 = null;
                                    }
                                }
                                if (z3 && element6 != null) {
                                    XSDAbstractTraverser.FacetInfo traverseFacets = traverseFacets(element6, xSSimpleType, xSDocumentInfo);
                                    Element element7 = traverseFacets.nodeAfterFacets;
                                    try {
                                        this.fValidationState.setNamespaceSupport(xSDocumentInfo.fNamespaceSupport);
                                        xSSimpleType2.applyFacets(traverseFacets.facetdata, traverseFacets.fPresentFacets, traverseFacets.fFixedFacets, this.fValidationState);
                                        element6 = element7;
                                    } catch (InvalidDatatypeFacetException e2) {
                                        reportSchemaError(e2.getKey(), e2.getArgs(), element3);
                                        xSSimpleType2 = this.fSchemaHandler.fDVFactory.createTypeRestriction(str, xSDocumentInfo.fTargetNamespace, (short) intValue, xSSimpleType, xSAnnotationImplArr4 == null ? null : new XSObjectListImpl(xSAnnotationImplArr4, xSAnnotationImplArr4.length));
                                        element6 = element7;
                                    }
                                }
                                if (element6 != null) {
                                    if (z3) {
                                        Object[] objArr6 = new Object[i3];
                                        objArr6[0] = SchemaSymbols.ELT_RESTRICTION;
                                        objArr6[1] = "(annotation?, (simpleType?, (minExclusive | minInclusive | maxExclusive | maxInclusive | totalDigits | fractionDigits | length | minLength | maxLength | enumeration | whiteSpace | pattern)*))";
                                        objArr6[2] = DOMUtil.getLocalName(element6);
                                        reportSchemaError("s4s-elt-must-match.1", objArr6, element6);
                                    } else if (z2) {
                                        Object[] objArr7 = new Object[i3];
                                        objArr7[0] = SchemaSymbols.ELT_LIST;
                                        objArr7[1] = "(annotation?, (simpleType?))";
                                        objArr7[2] = DOMUtil.getLocalName(element6);
                                        reportSchemaError("s4s-elt-must-match.1", objArr7, element6);
                                    } else if (z) {
                                        Object[] objArr8 = new Object[i3];
                                        objArr8[0] = SchemaSymbols.ELT_UNION;
                                        objArr8[1] = "(annotation?, (simpleType*))";
                                        objArr8[2] = DOMUtil.getLocalName(element6);
                                        reportSchemaError("s4s-elt-must-match.1", objArr8, element6);
                                    }
                                }
                                this.fAttrChecker.returnAttrArray(objArr4, xSDocumentInfo);
                                return xSSimpleType2;
                            } else {
                                Object[] objArr9 = new Object[i2];
                                objArr9[0] = str;
                                objArr9[1] = xSSimpleType.getName();
                                reportSchemaError("cos-st-restricts.2.1", objArr9, element3);
                                this.fAttrChecker.returnAttrArray(objArr2, xSDocumentInfo);
                                return errorType(str, xSDocumentInfo.fTargetNamespace, 16);
                            }
                        }
                    } else {
                        vector2 = vector;
                    }
                    s2 = 3;
                    arrayList = null;
                    if (element4 != null) {
                    }
                    i2 = 2;
                    if (!z3) {
                    }
                    if (!z2) {
                    }
                    objArr5 = null;
                    reportSchemaError(str2, objArr5, element3);
                    objArr3 = objArr5;
                    Element element62 = element4;
                    if (!z3) {
                    }
                    this.fAttrChecker.returnAttrArray(objArr2, xSDocumentInfo);
                    return errorType(str, xSDocumentInfo.fTargetNamespace, !z3 ? (short) 2 : 16);
                } else {
                    reportSchemaError("s4s-elt-must-match.1", new Object[]{SchemaSymbols.ELT_SIMPLETYPE, "(annotation?, (restriction | list | union))", localName}, element);
                    return errorType(str, xSDocumentInfo.fTargetNamespace, 2);
                }
                z = false;
                nextSiblingElement = DOMUtil.getNextSiblingElement(element2);
                if (nextSiblingElement != null) {
                }
                Object[] checkAttributes2 = this.fAttrChecker.checkAttributes(element2, false, xSDocumentInfo);
                qName = (QName) checkAttributes2[!z3 ? XSAttributeChecker.ATTIDX_BASE : XSAttributeChecker.ATTIDX_ITEMTYPE];
                Vector vector32 = (Vector) checkAttributes2[XSAttributeChecker.ATTIDX_MEMBERTYPES];
                firstChildElement = DOMUtil.getFirstChildElement(element2);
                if (firstChildElement != null) {
                }
                syntheticAnnotation = DOMUtil.getSyntheticAnnotation(element2);
                if (syntheticAnnotation == null) {
                }
                element4 = element5;
                if (!z3) {
                }
                xSAnnotationImplArr3 = xSAnnotationImplArr2;
                xSSimpleType = findDTValidator(element3, str, qName, s, xSDocumentInfo);
                this.fIsBuiltIn = false;
                return null;
            }
        } else {
            XSAnnotationImpl traverseAnnotationDecl2 = traverseAnnotationDecl(firstChildElement2, objArr, false, xSDocumentInfo);
            xSAnnotationImplArr5 = traverseAnnotationDecl2 != null ? new XSAnnotationImpl[]{traverseAnnotationDecl2} : null;
            firstChildElement2 = DOMUtil.getNextSiblingElement(firstChildElement2);
        }
        element2 = firstChildElement2;
        xSAnnotationImplArr = xSAnnotationImplArr5;
        if (element2 != null) {
        }
    }

    private boolean isListDatatype(XSSimpleType xSSimpleType) {
        if (xSSimpleType.getVariety() == 2) {
            return true;
        }
        if (xSSimpleType.getVariety() == 3) {
            XSObjectList memberTypes = xSSimpleType.getMemberTypes();
            for (int i2 = 0; i2 < memberTypes.getLength(); i2++) {
                if (((XSSimpleType) memberTypes.item(i2)).getVariety() == 2) {
                    return true;
                }
            }
        }
        return false;
    }

    private XSSimpleType traverseSimpleTypeDecl(Element element, Object[] objArr, XSDocumentInfo xSDocumentInfo, SchemaGrammar schemaGrammar) {
        return getSimpleType((String) objArr[XSAttributeChecker.ATTIDX_NAME], element, objArr, xSDocumentInfo, schemaGrammar);
    }

    public XSSimpleType traverseGlobal(Element element, XSDocumentInfo xSDocumentInfo, SchemaGrammar schemaGrammar) {
        Object[] checkAttributes = this.fAttrChecker.checkAttributes(element, true, xSDocumentInfo);
        int i2 = XSAttributeChecker.ATTIDX_NAME;
        String str = (String) checkAttributes[i2];
        if (str == null) {
            checkAttributes[i2] = XSDAbstractTraverser.NO_NAME;
        }
        XSSimpleType traverseSimpleTypeDecl = traverseSimpleTypeDecl(element, checkAttributes, xSDocumentInfo, schemaGrammar);
        this.fAttrChecker.returnAttrArray(checkAttributes, xSDocumentInfo);
        if (str == null) {
            reportSchemaError("s4s-att-must-appear", new Object[]{SchemaSymbols.ELT_SIMPLETYPE, SchemaSymbols.ATT_NAME}, element);
            traverseSimpleTypeDecl = null;
        }
        if (traverseSimpleTypeDecl != null) {
            if (schemaGrammar.getGlobalTypeDecl(traverseSimpleTypeDecl.getName()) == null) {
                schemaGrammar.addGlobalSimpleTypeDecl(traverseSimpleTypeDecl);
            }
            String schemaDocument2SystemId = this.fSchemaHandler.schemaDocument2SystemId(xSDocumentInfo);
            XSTypeDefinition globalTypeDecl = schemaGrammar.getGlobalTypeDecl(traverseSimpleTypeDecl.getName(), schemaDocument2SystemId);
            if (globalTypeDecl == null) {
                schemaGrammar.addGlobalSimpleTypeDecl(traverseSimpleTypeDecl, schemaDocument2SystemId);
            }
            if (this.fSchemaHandler.fTolerateDuplicates) {
                if (globalTypeDecl != null && (globalTypeDecl instanceof XSSimpleType)) {
                    traverseSimpleTypeDecl = (XSSimpleType) globalTypeDecl;
                }
                this.fSchemaHandler.addGlobalTypeDecl(traverseSimpleTypeDecl);
            }
        }
        return traverseSimpleTypeDecl;
    }

    public XSSimpleType traverseLocal(Element element, XSDocumentInfo xSDocumentInfo, SchemaGrammar schemaGrammar) {
        Object[] checkAttributes = this.fAttrChecker.checkAttributes(element, false, xSDocumentInfo);
        XSSimpleType simpleType = getSimpleType(genAnonTypeName(element), element, checkAttributes, xSDocumentInfo, schemaGrammar);
        if (simpleType instanceof XSSimpleTypeDecl) {
            ((XSSimpleTypeDecl) simpleType).setAnonymous(true);
        }
        this.fAttrChecker.returnAttrArray(checkAttributes, xSDocumentInfo);
        return simpleType;
    }
}
