package org.apache.xerces.impl.xs.traversers;

import java.util.Stack;
import java.util.Vector;
import org.apache.xerces.impl.validation.ValidationState;
import org.apache.xerces.impl.xs.SchemaNamespaceSupport;
import org.apache.xerces.impl.xs.XMLSchemaException;
import org.apache.xerces.impl.xs.opti.SchemaDOM;
import org.apache.xerces.impl.xs.util.XInt;
import org.apache.xerces.util.SymbolTable;
import org.w3c.dom.Document;
import org.w3c.dom.Element;

public class XSDocumentInfo {
    public Stack SchemaNamespaceSupportStack = new Stack();
    public XSAnnotationInfo fAnnotations = null;
    public boolean fAreLocalAttributesQualified;
    public boolean fAreLocalElementsQualified;
    public XSAttributeChecker fAttrChecker;
    public short fBlockDefault;
    public short fFinalDefault;
    public Vector fImportedNS = new Vector();
    public boolean fIsChameleonSchema;
    public SchemaNamespaceSupport fNamespaceSupport;
    public SchemaNamespaceSupport fNamespaceSupportRoot;
    public Vector fReportedTNS = null;
    public Object[] fSchemaAttrs;
    public Element fSchemaElement;
    public SymbolTable fSymbolTable = null;
    public String fTargetNamespace;
    public ValidationState fValidationContext = new ValidationState();

    public XSDocumentInfo(Element element, XSAttributeChecker xSAttributeChecker, SymbolTable symbolTable) {
        this.fSchemaElement = element;
        SchemaNamespaceSupport schemaNamespaceSupport = new SchemaNamespaceSupport(element, symbolTable);
        this.fNamespaceSupport = schemaNamespaceSupport;
        schemaNamespaceSupport.reset();
        boolean z = false;
        this.fIsChameleonSchema = false;
        this.fSymbolTable = symbolTable;
        this.fAttrChecker = xSAttributeChecker;
        if (element != null) {
            Object[] checkAttributes = xSAttributeChecker.checkAttributes(element, true, this);
            this.fSchemaAttrs = checkAttributes;
            if (checkAttributes != null) {
                this.fAreLocalAttributesQualified = ((XInt) checkAttributes[XSAttributeChecker.ATTIDX_AFORMDEFAULT]).intValue() == 1;
                this.fAreLocalElementsQualified = ((XInt) this.fSchemaAttrs[XSAttributeChecker.ATTIDX_EFORMDEFAULT]).intValue() == 1 ? true : z;
                this.fBlockDefault = ((XInt) this.fSchemaAttrs[XSAttributeChecker.ATTIDX_BLOCKDEFAULT]).shortValue();
                this.fFinalDefault = ((XInt) this.fSchemaAttrs[XSAttributeChecker.ATTIDX_FINALDEFAULT]).shortValue();
                String str = (String) this.fSchemaAttrs[XSAttributeChecker.ATTIDX_TARGETNAMESPACE];
                this.fTargetNamespace = str;
                if (str != null) {
                    this.fTargetNamespace = symbolTable.addSymbol(str);
                }
                this.fNamespaceSupportRoot = new SchemaNamespaceSupport(this.fNamespaceSupport);
                this.fValidationContext.setNamespaceSupport(this.fNamespaceSupport);
                this.fValidationContext.setSymbolTable(symbolTable);
                return;
            }
            throw new XMLSchemaException(null, null);
        }
    }

    public void addAllowedNS(String str) {
        Vector vector = this.fImportedNS;
        if (str == null) {
            str = "";
        }
        vector.addElement(str);
    }

    public void addAnnotation(XSAnnotationInfo xSAnnotationInfo) {
        xSAnnotationInfo.next = this.fAnnotations;
        this.fAnnotations = xSAnnotationInfo;
    }

    public void backupNSSupport(SchemaNamespaceSupport schemaNamespaceSupport) {
        this.SchemaNamespaceSupportStack.push(this.fNamespaceSupport);
        if (schemaNamespaceSupport == null) {
            schemaNamespaceSupport = this.fNamespaceSupportRoot;
        }
        SchemaNamespaceSupport schemaNamespaceSupport2 = new SchemaNamespaceSupport(schemaNamespaceSupport);
        this.fNamespaceSupport = schemaNamespaceSupport2;
        this.fValidationContext.setNamespaceSupport(schemaNamespaceSupport2);
    }

    public XSAnnotationInfo getAnnotations() {
        return this.fAnnotations;
    }

    public Object[] getSchemaAttrs() {
        return this.fSchemaAttrs;
    }

    public boolean isAllowedNS(String str) {
        Vector vector = this.fImportedNS;
        if (str == null) {
            str = "";
        }
        return vector.contains(str);
    }

    public final boolean needReportTNSError(String str) {
        Vector vector = this.fReportedTNS;
        if (vector == null) {
            this.fReportedTNS = new Vector();
        } else if (vector.contains(str)) {
            return false;
        }
        this.fReportedTNS.addElement(str);
        return true;
    }

    public void removeAnnotations() {
        this.fAnnotations = null;
    }

    public void restoreNSSupport() {
        SchemaNamespaceSupport schemaNamespaceSupport = (SchemaNamespaceSupport) this.SchemaNamespaceSupportStack.pop();
        this.fNamespaceSupport = schemaNamespaceSupport;
        this.fValidationContext.setNamespaceSupport(schemaNamespaceSupport);
    }

    public void returnSchemaAttrs() {
        this.fAttrChecker.returnAttrArray(this.fSchemaAttrs, null);
        this.fSchemaAttrs = null;
    }

    public String toString() {
        String str;
        String documentURI;
        StringBuffer stringBuffer = new StringBuffer();
        if (this.fTargetNamespace == null) {
            str = "no targetNamspace";
        } else {
            stringBuffer.append("targetNamespace is ");
            str = this.fTargetNamespace;
        }
        stringBuffer.append(str);
        Element element = this.fSchemaElement;
        Document ownerDocument = element != null ? element.getOwnerDocument() : null;
        if ((ownerDocument instanceof SchemaDOM) && (documentURI = ownerDocument.getDocumentURI()) != null && documentURI.length() > 0) {
            stringBuffer.append(" :: schemaLocation is ");
            stringBuffer.append(documentURI);
        }
        return stringBuffer.toString();
    }
}
