package org.apache.xerces.impl.xs.util;

import java.util.AbstractMap;
import java.util.AbstractSet;
import java.util.Iterator;
import java.util.Map;
import java.util.NoSuchElementException;
import java.util.Set;
import javax.xml.namespace.QName;
import org.apache.xerces.impl.dv.util.Base64;
import org.apache.xerces.util.SymbolHash;
import org.apache.xerces.xs.XSNamedMap;
import org.apache.xerces.xs.XSObject;

public class XSNamedMapImpl extends AbstractMap implements XSNamedMap {
    public static final XSNamedMapImpl EMPTY_MAP = new XSNamedMapImpl(new XSObject[0], 0);
    public XSObject[] fArray = null;
    public Set fEntrySet = null;
    public int fLength = -1;
    public final SymbolHash[] fMaps;
    public final int fNSNum;
    public final String[] fNamespaces;

    public static final class XSNamedMapEntry implements Map.Entry {
        public final QName key;
        public final XSObject value;

        public XSNamedMapEntry(QName qName, XSObject xSObject) {
            this.key = qName;
            this.value = xSObject;
        }

        public boolean equals(Object obj) {
            if (!(obj instanceof Map.Entry)) {
                return false;
            }
            Map.Entry entry = (Map.Entry) obj;
            Object key2 = entry.getKey();
            Object value2 = entry.getValue();
            QName qName = this.key;
            if (!(qName == null ? key2 == null : qName.equals(key2))) {
                return false;
            }
            XSObject xSObject = this.value;
            return xSObject == null ? value2 == null : xSObject.equals(value2);
        }

        @Override // java.util.Map.Entry
        public Object getKey() {
            return this.key;
        }

        @Override // java.util.Map.Entry
        public Object getValue() {
            return this.value;
        }

        public int hashCode() {
            QName qName = this.key;
            int i2 = 0;
            int hashCode = qName == null ? 0 : qName.hashCode();
            XSObject xSObject = this.value;
            if (xSObject != null) {
                i2 = xSObject.hashCode();
            }
            return hashCode ^ i2;
        }

        @Override // java.util.Map.Entry
        public Object setValue(Object obj) {
            throw new UnsupportedOperationException();
        }

        public String toString() {
            StringBuffer stringBuffer = new StringBuffer();
            stringBuffer.append(String.valueOf(this.key));
            stringBuffer.append(Base64.PAD);
            stringBuffer.append(String.valueOf(this.value));
            return stringBuffer.toString();
        }
    }

    public XSNamedMapImpl(String str, SymbolHash symbolHash) {
        this.fNamespaces = new String[]{str};
        this.fMaps = new SymbolHash[]{symbolHash};
        this.fNSNum = 1;
    }

    public XSNamedMapImpl(String[] strArr, SymbolHash[] symbolHashArr, int i2) {
        this.fNamespaces = strArr;
        this.fMaps = symbolHashArr;
        this.fNSNum = i2;
    }

    public XSNamedMapImpl(XSObject[] xSObjectArr, int i2) {
        if (i2 == 0) {
            this.fNamespaces = null;
            this.fMaps = null;
            this.fNSNum = 0;
            this.fArray = xSObjectArr;
            this.fLength = 0;
            return;
        }
        this.fNamespaces = new String[]{xSObjectArr[0].getNamespace()};
        this.fMaps = null;
        this.fNSNum = 1;
        this.fArray = xSObjectArr;
        this.fLength = i2;
    }

    public static boolean isEqual(String str, String str2) {
        return str != null ? str.equals(str2) : str2 == null;
    }

    public boolean containsKey(Object obj) {
        return get(obj) != null;
    }

    @Override // java.util.AbstractMap, java.util.Map
    public synchronized Set entrySet() {
        if (this.fEntrySet == null) {
            final int length = getLength();
            final XSNamedMapEntry[] xSNamedMapEntryArr = new XSNamedMapEntry[length];
            for (int i2 = 0; i2 < length; i2++) {
                XSObject item = item(i2);
                xSNamedMapEntryArr[i2] = new XSNamedMapEntry(new QName(item.getNamespace(), item.getName()), item);
            }
            this.fEntrySet = new AbstractSet() {
                /* class org.apache.xerces.impl.xs.util.XSNamedMapImpl.AnonymousClass1 */

                @Override // java.util.AbstractCollection, java.util.Collection, java.util.Set, java.lang.Iterable
                public Iterator iterator() {
                    return new Iterator() {
                        /* class org.apache.xerces.impl.xs.util.XSNamedMapImpl.AnonymousClass2 */
                        public int index = 0;

                        public boolean hasNext() {
                            return this.index < length;
                        }

                        @Override // java.util.Iterator
                        public Object next() {
                            if (this.index < length) {
                                XSNamedMapEntry[] xSNamedMapEntryArr = xSNamedMapEntryArr;
                                int i2 = this.index;
                                this.index = i2 + 1;
                                return xSNamedMapEntryArr[i2];
                            }
                            throw new NoSuchElementException();
                        }

                        public void remove() {
                            throw new UnsupportedOperationException();
                        }
                    };
                }

                public int size() {
                    return length;
                }
            };
        }
        return this.fEntrySet;
    }

    @Override // java.util.AbstractMap, java.util.Map
    public Object get(Object obj) {
        String str = null;
        if (!(obj instanceof QName)) {
            return null;
        }
        QName qName = (QName) obj;
        String namespaceURI = qName.getNamespaceURI();
        if (!"".equals(namespaceURI)) {
            str = namespaceURI;
        }
        return itemByName(str, qName.getLocalPart());
    }

    @Override // org.apache.xerces.xs.XSNamedMap
    public synchronized int getLength() {
        if (this.fLength == -1) {
            this.fLength = 0;
            for (int i2 = 0; i2 < this.fNSNum; i2++) {
                this.fLength += this.fMaps[i2].getLength();
            }
        }
        return this.fLength;
    }

    @Override // org.apache.xerces.xs.XSNamedMap
    public synchronized XSObject item(int i2) {
        if (this.fArray == null) {
            getLength();
            this.fArray = new XSObject[this.fLength];
            int i3 = 0;
            for (int i4 = 0; i4 < this.fNSNum; i4++) {
                i3 += this.fMaps[i4].getValues(this.fArray, i3);
            }
        }
        if (i2 >= 0) {
            if (i2 < this.fLength) {
                return this.fArray[i2];
            }
        }
        return null;
    }

    @Override // org.apache.xerces.xs.XSNamedMap
    public XSObject itemByName(String str, String str2) {
        for (int i2 = 0; i2 < this.fNSNum; i2++) {
            if (isEqual(str, this.fNamespaces[i2])) {
                SymbolHash[] symbolHashArr = this.fMaps;
                if (symbolHashArr != null) {
                    return (XSObject) symbolHashArr[i2].get(str2);
                }
                for (int i3 = 0; i3 < this.fLength; i3++) {
                    XSObject xSObject = this.fArray[i3];
                    if (xSObject.getName().equals(str2)) {
                        return xSObject;
                    }
                }
                return null;
            }
        }
        return null;
    }

    public int size() {
        return getLength();
    }
}
