package org.apache.xerces.jaxp;

import java.util.Hashtable;
import javax.xml.XMLConstants;
import javax.xml.parsers.ParserConfigurationException;
import javax.xml.parsers.SAXParser;
import javax.xml.parsers.SAXParserFactory;
import javax.xml.validation.Schema;
import org.xml.sax.SAXException;
import org.xml.sax.SAXNotRecognizedException;
import org.xml.sax.SAXNotSupportedException;

public class SAXParserFactoryImpl extends SAXParserFactory {
    public static final String NAMESPACES_FEATURE = "http://xml.org/sax/features/namespaces";
    public static final String VALIDATION_FEATURE = "http://xml.org/sax/features/validation";
    public static final String XINCLUDE_FEATURE = "http://apache.org/xml/features/xinclude";
    public boolean fSecureProcess = false;
    public Hashtable features;
    public Schema grammar;
    public boolean isXIncludeAware;

    private SAXParserImpl newSAXParserImpl() {
        try {
            return new SAXParserImpl(this, this.features);
        } catch (SAXNotSupportedException e2) {
            throw e2;
        } catch (SAXNotRecognizedException e3) {
            throw e3;
        } catch (SAXException e4) {
            throw new ParserConfigurationException(e4.getMessage());
        }
    }

    @Override // javax.xml.parsers.SAXParserFactory
    public boolean getFeature(String str) {
        if (str != null) {
            return str.equals(XMLConstants.FEATURE_SECURE_PROCESSING) ? this.fSecureProcess : str.equals("http://xml.org/sax/features/namespaces") ? isNamespaceAware() : str.equals("http://xml.org/sax/features/validation") ? isValidating() : str.equals("http://apache.org/xml/features/xinclude") ? isXIncludeAware() : newSAXParserImpl().getXMLReader().getFeature(str);
        }
        throw null;
    }

    @Override // javax.xml.parsers.SAXParserFactory
    public Schema getSchema() {
        return this.grammar;
    }

    @Override // javax.xml.parsers.SAXParserFactory
    public boolean isXIncludeAware() {
        return this.isXIncludeAware;
    }

    @Override // javax.xml.parsers.SAXParserFactory
    public SAXParser newSAXParser() {
        try {
            return new SAXParserImpl(this, this.features, this.fSecureProcess);
        } catch (SAXException e2) {
            throw new ParserConfigurationException(e2.getMessage());
        }
    }

    @Override // javax.xml.parsers.SAXParserFactory
    public void setFeature(String str, boolean z) {
        if (str == null) {
            throw null;
        } else if (str.equals(XMLConstants.FEATURE_SECURE_PROCESSING)) {
            this.fSecureProcess = z;
        } else if (str.equals("http://xml.org/sax/features/namespaces")) {
            setNamespaceAware(z);
        } else if (str.equals("http://xml.org/sax/features/validation")) {
            setValidating(z);
        } else if (str.equals("http://apache.org/xml/features/xinclude")) {
            setXIncludeAware(z);
        } else {
            if (this.features == null) {
                this.features = new Hashtable();
            }
            this.features.put(str, z ? Boolean.TRUE : Boolean.FALSE);
            try {
                newSAXParserImpl();
            } catch (SAXNotSupportedException e2) {
                this.features.remove(str);
                throw e2;
            } catch (SAXNotRecognizedException e3) {
                this.features.remove(str);
                throw e3;
            }
        }
    }

    @Override // javax.xml.parsers.SAXParserFactory
    public void setSchema(Schema schema) {
        this.grammar = schema;
    }

    @Override // javax.xml.parsers.SAXParserFactory
    public void setXIncludeAware(boolean z) {
        this.isXIncludeAware = z;
    }
}
