package org.apache.xerces.jaxp;

import java.util.HashMap;
import java.util.Hashtable;
import java.util.Map;
import javax.xml.XMLConstants;
import javax.xml.parsers.SAXParser;
import javax.xml.validation.Schema;
import org.apache.xerces.impl.validation.ValidationManager;
import org.apache.xerces.impl.xs.XMLSchemaValidator;
import org.apache.xerces.jaxp.validation.XSGrammarPoolContainer;
import org.apache.xerces.util.SAXMessageFormatter;
import org.apache.xerces.util.SecurityManager;
import org.apache.xerces.xni.parser.XMLComponent;
import org.apache.xerces.xni.parser.XMLComponentManager;
import org.apache.xerces.xni.parser.XMLConfigurationException;
import org.apache.xerces.xni.parser.XMLParserConfiguration;
import org.apache.xerces.xs.AttributePSVI;
import org.apache.xerces.xs.ElementPSVI;
import org.apache.xerces.xs.PSVIProvider;
import org.xml.sax.EntityResolver;
import org.xml.sax.ErrorHandler;
import org.xml.sax.HandlerBase;
import org.xml.sax.InputSource;
import org.xml.sax.Parser;
import org.xml.sax.SAXException;
import org.xml.sax.SAXNotRecognizedException;
import org.xml.sax.SAXNotSupportedException;
import org.xml.sax.XMLReader;
import org.xml.sax.helpers.DefaultHandler;

public class SAXParserImpl extends SAXParser implements JAXPConstants, PSVIProvider {
    public static final String NAMESPACES_FEATURE = "http://xml.org/sax/features/namespaces";
    public static final String NAMESPACE_PREFIXES_FEATURE = "http://xml.org/sax/features/namespace-prefixes";
    public static final String SECURITY_MANAGER = "http://apache.org/xml/properties/security-manager";
    public static final String VALIDATION_FEATURE = "http://xml.org/sax/features/validation";
    public static final String XINCLUDE_FEATURE = "http://apache.org/xml/features/xinclude";
    public static final String XMLSCHEMA_VALIDATION_FEATURE = "http://apache.org/xml/features/validation/schema";
    public final EntityResolver fInitEntityResolver;
    public final ErrorHandler fInitErrorHandler;
    public final ValidationManager fSchemaValidationManager;
    public final XMLComponent fSchemaValidator;
    public final XMLComponentManager fSchemaValidatorComponentManager;
    public final UnparsedEntityHandler fUnparsedEntityHandler;
    public final Schema grammar;
    public String schemaLanguage;
    public final JAXPSAXParser xmlReader;

    public static class JAXPSAXParser extends org.apache.xerces.parsers.SAXParser {
        public final HashMap fInitFeatures;
        public final HashMap fInitProperties;
        public final SAXParserImpl fSAXParser;

        public JAXPSAXParser() {
            this(null);
        }

        public JAXPSAXParser(SAXParserImpl sAXParserImpl) {
            this.fInitFeatures = new HashMap();
            this.fInitProperties = new HashMap();
            this.fSAXParser = sAXParserImpl;
        }

        private void resetSchemaValidator() {
            try {
                this.fSAXParser.fSchemaValidator.reset(this.fSAXParser.fSchemaValidatorComponentManager);
            } catch (XMLConfigurationException e2) {
                throw new SAXException(e2);
            }
        }

        private void setSchemaValidatorFeature(String str, boolean z) {
            try {
                this.fSAXParser.fSchemaValidator.setFeature(str, z);
            } catch (XMLConfigurationException e2) {
                String identifier = e2.getIdentifier();
                if (e2.getType() == 0) {
                    throw new SAXNotRecognizedException(SAXMessageFormatter.formatMessage(this.fConfiguration.getLocale(), "feature-not-recognized", new Object[]{identifier}));
                }
                throw new SAXNotSupportedException(SAXMessageFormatter.formatMessage(this.fConfiguration.getLocale(), "feature-not-supported", new Object[]{identifier}));
            }
        }

        private void setSchemaValidatorProperty(String str, Object obj) {
            try {
                this.fSAXParser.fSchemaValidator.setProperty(str, obj);
            } catch (XMLConfigurationException e2) {
                String identifier = e2.getIdentifier();
                if (e2.getType() == 0) {
                    throw new SAXNotRecognizedException(SAXMessageFormatter.formatMessage(this.fConfiguration.getLocale(), "property-not-recognized", new Object[]{identifier}));
                }
                throw new SAXNotSupportedException(SAXMessageFormatter.formatMessage(this.fConfiguration.getLocale(), "property-not-supported", new Object[]{identifier}));
            }
        }

        @Override // org.xml.sax.XMLReader, org.apache.xerces.parsers.AbstractSAXParser
        public synchronized boolean getFeature(String str) {
            if (str == null) {
                throw new NullPointerException();
            } else if (str.equals(XMLConstants.FEATURE_SECURE_PROCESSING)) {
                boolean z = false;
                try {
                    if (super.getProperty("http://apache.org/xml/properties/security-manager") != null) {
                        z = true;
                    }
                    return z;
                } catch (SAXException unused) {
                    return false;
                }
            } else {
                return super.getFeature(str);
            }
        }

        public boolean getFeature0(String str) {
            return super.getFeature(str);
        }

        @Override // org.xml.sax.XMLReader, org.apache.xerces.parsers.AbstractSAXParser
        public synchronized Object getProperty(String str) {
            if (str == null) {
                throw new NullPointerException();
            } else if (this.fSAXParser == null || !"http://java.sun.com/xml/jaxp/properties/schemaLanguage".equals(str)) {
                return super.getProperty(str);
            } else {
                return this.fSAXParser.schemaLanguage;
            }
        }

        public Object getProperty0(String str) {
            return super.getProperty(str);
        }

        public XMLParserConfiguration getXMLParserConfiguration() {
            return this.fConfiguration;
        }

        @Override // org.xml.sax.Parser, org.xml.sax.XMLReader, org.apache.xerces.parsers.AbstractSAXParser
        public void parse(String str) {
            SAXParserImpl sAXParserImpl = this.fSAXParser;
            if (!(sAXParserImpl == null || sAXParserImpl.fSchemaValidator == null)) {
                if (this.fSAXParser.fSchemaValidationManager != null) {
                    this.fSAXParser.fSchemaValidationManager.reset();
                    this.fSAXParser.fUnparsedEntityHandler.reset();
                }
                resetSchemaValidator();
            }
            super.parse(str);
        }

        @Override // org.xml.sax.Parser, org.xml.sax.XMLReader, org.apache.xerces.parsers.AbstractSAXParser
        public void parse(InputSource inputSource) {
            SAXParserImpl sAXParserImpl = this.fSAXParser;
            if (!(sAXParserImpl == null || sAXParserImpl.fSchemaValidator == null)) {
                if (this.fSAXParser.fSchemaValidationManager != null) {
                    this.fSAXParser.fSchemaValidationManager.reset();
                    this.fSAXParser.fUnparsedEntityHandler.reset();
                }
                resetSchemaValidator();
            }
            super.parse(inputSource);
        }

        public synchronized void restoreInitState() {
            if (!this.fInitFeatures.isEmpty()) {
                for (Map.Entry entry : this.fInitFeatures.entrySet()) {
                    super.setFeature((String) entry.getKey(), ((Boolean) entry.getValue()).booleanValue());
                }
                this.fInitFeatures.clear();
            }
            if (!this.fInitProperties.isEmpty()) {
                for (Map.Entry entry2 : this.fInitProperties.entrySet()) {
                    super.setProperty((String) entry2.getKey(), entry2.getValue());
                }
                this.fInitProperties.clear();
            }
        }

        @Override // org.xml.sax.XMLReader, org.apache.xerces.parsers.AbstractSAXParser
        public synchronized void setFeature(String str, boolean z) {
            SecurityManager securityManager;
            if (str == null) {
                throw new NullPointerException();
            } else if (str.equals(XMLConstants.FEATURE_SECURE_PROCESSING)) {
                if (z) {
                    try {
                        securityManager = new SecurityManager();
                    } catch (SAXNotRecognizedException e2) {
                        if (z) {
                            throw e2;
                        }
                    } catch (SAXNotSupportedException e3) {
                        if (z) {
                            throw e3;
                        }
                    }
                } else {
                    securityManager = null;
                }
                setProperty("http://apache.org/xml/properties/security-manager", securityManager);
            } else {
                if (!this.fInitFeatures.containsKey(str)) {
                    this.fInitFeatures.put(str, super.getFeature(str) ? Boolean.TRUE : Boolean.FALSE);
                }
                if (!(this.fSAXParser == null || this.fSAXParser.fSchemaValidator == null)) {
                    setSchemaValidatorFeature(str, z);
                }
                super.setFeature(str, z);
            }
        }

        public void setFeature0(String str, boolean z) {
            super.setFeature(str, z);
        }

        @Override // org.xml.sax.XMLReader, org.apache.xerces.parsers.AbstractSAXParser
        public synchronized void setProperty(String str, Object obj) {
            if (str != null) {
                if (this.fSAXParser != null) {
                    if ("http://java.sun.com/xml/jaxp/properties/schemaLanguage".equals(str)) {
                        if (this.fSAXParser.grammar == null) {
                            if ("http://www.w3.org/2001/XMLSchema".equals(obj)) {
                                if (this.fSAXParser.isValidating()) {
                                    this.fSAXParser.schemaLanguage = "http://www.w3.org/2001/XMLSchema";
                                    setFeature("http://apache.org/xml/features/validation/schema", true);
                                    if (!this.fInitProperties.containsKey("http://java.sun.com/xml/jaxp/properties/schemaLanguage")) {
                                        this.fInitProperties.put("http://java.sun.com/xml/jaxp/properties/schemaLanguage", super.getProperty("http://java.sun.com/xml/jaxp/properties/schemaLanguage"));
                                    }
                                    super.setProperty("http://java.sun.com/xml/jaxp/properties/schemaLanguage", "http://www.w3.org/2001/XMLSchema");
                                }
                            } else if (obj == null) {
                                this.fSAXParser.schemaLanguage = null;
                                setFeature("http://apache.org/xml/features/validation/schema", false);
                            } else {
                                throw new SAXNotSupportedException(SAXMessageFormatter.formatMessage(this.fConfiguration.getLocale(), "schema-not-supported", null));
                            }
                            return;
                        }
                        throw new SAXNotSupportedException(SAXMessageFormatter.formatMessage(this.fConfiguration.getLocale(), "schema-already-specified", new Object[]{str}));
                    } else if ("http://java.sun.com/xml/jaxp/properties/schemaSource".equals(str)) {
                        if (this.fSAXParser.grammar == null) {
                            String str2 = (String) getProperty("http://java.sun.com/xml/jaxp/properties/schemaLanguage");
                            if (str2 == null || !"http://www.w3.org/2001/XMLSchema".equals(str2)) {
                                throw new SAXNotSupportedException(SAXMessageFormatter.formatMessage(this.fConfiguration.getLocale(), "jaxp-order-not-supported", new Object[]{"http://java.sun.com/xml/jaxp/properties/schemaLanguage", "http://java.sun.com/xml/jaxp/properties/schemaSource"}));
                            }
                            if (!this.fInitProperties.containsKey("http://java.sun.com/xml/jaxp/properties/schemaSource")) {
                                this.fInitProperties.put("http://java.sun.com/xml/jaxp/properties/schemaSource", super.getProperty("http://java.sun.com/xml/jaxp/properties/schemaSource"));
                            }
                            super.setProperty(str, obj);
                            return;
                        }
                        throw new SAXNotSupportedException(SAXMessageFormatter.formatMessage(this.fConfiguration.getLocale(), "schema-already-specified", new Object[]{str}));
                    }
                }
                if (!this.fInitProperties.containsKey(str)) {
                    this.fInitProperties.put(str, super.getProperty(str));
                }
                if (!(this.fSAXParser == null || this.fSAXParser.fSchemaValidator == null)) {
                    setSchemaValidatorProperty(str, obj);
                }
                super.setProperty(str, obj);
                return;
            }
            throw new NullPointerException();
        }

        public void setProperty0(String str, Object obj) {
            super.setProperty(str, obj);
        }
    }

    public SAXParserImpl(SAXParserFactoryImpl sAXParserFactoryImpl, Hashtable hashtable) {
        this(sAXParserFactoryImpl, hashtable, false);
    }

    /* JADX WARN: Multi-variable type inference failed */
    /* JADX WARN: Type inference failed for: r7v7, types: [org.apache.xerces.impl.xs.XMLSchemaValidator] */
    /* JADX WARNING: Unknown variable types count: 1 */
    public SAXParserImpl(SAXParserFactoryImpl sAXParserFactoryImpl, Hashtable hashtable, boolean z) {
        JAXPValidatorComponent jAXPValidatorComponent;
        this.schemaLanguage = null;
        JAXPSAXParser jAXPSAXParser = new JAXPSAXParser(this);
        this.xmlReader = jAXPSAXParser;
        jAXPSAXParser.setFeature0("http://xml.org/sax/features/namespaces", sAXParserFactoryImpl.isNamespaceAware());
        this.xmlReader.setFeature0("http://xml.org/sax/features/namespace-prefixes", !sAXParserFactoryImpl.isNamespaceAware());
        if (sAXParserFactoryImpl.isXIncludeAware()) {
            this.xmlReader.setFeature0("http://apache.org/xml/features/xinclude", true);
        }
        if (z) {
            this.xmlReader.setProperty0("http://apache.org/xml/properties/security-manager", new SecurityManager());
        }
        setFeatures(hashtable);
        if (sAXParserFactoryImpl.isValidating()) {
            DefaultValidationErrorHandler defaultValidationErrorHandler = new DefaultValidationErrorHandler();
            this.fInitErrorHandler = defaultValidationErrorHandler;
            this.xmlReader.setErrorHandler(defaultValidationErrorHandler);
        } else {
            this.fInitErrorHandler = this.xmlReader.getErrorHandler();
        }
        this.xmlReader.setFeature0("http://xml.org/sax/features/validation", sAXParserFactoryImpl.isValidating());
        Schema schema = sAXParserFactoryImpl.getSchema();
        this.grammar = schema;
        if (schema != null) {
            XMLParserConfiguration xMLParserConfiguration = this.xmlReader.getXMLParserConfiguration();
            if (this.grammar instanceof XSGrammarPoolContainer) {
                ?? xMLSchemaValidator = new XMLSchemaValidator();
                ValidationManager validationManager = new ValidationManager();
                this.fSchemaValidationManager = validationManager;
                UnparsedEntityHandler unparsedEntityHandler = new UnparsedEntityHandler(validationManager);
                this.fUnparsedEntityHandler = unparsedEntityHandler;
                xMLParserConfiguration.setDTDHandler(unparsedEntityHandler);
                this.fUnparsedEntityHandler.setDTDHandler(this.xmlReader);
                this.xmlReader.setDTDSource(this.fUnparsedEntityHandler);
                this.fSchemaValidatorComponentManager = new SchemaValidatorConfiguration(xMLParserConfiguration, (XSGrammarPoolContainer) this.grammar, this.fSchemaValidationManager);
                jAXPValidatorComponent = xMLSchemaValidator;
            } else {
                JAXPValidatorComponent jAXPValidatorComponent2 = new JAXPValidatorComponent(this.grammar.newValidatorHandler());
                this.fSchemaValidationManager = null;
                this.fUnparsedEntityHandler = null;
                this.fSchemaValidatorComponentManager = xMLParserConfiguration;
                jAXPValidatorComponent = jAXPValidatorComponent2;
            }
            xMLParserConfiguration.addRecognizedFeatures(jAXPValidatorComponent.getRecognizedFeatures());
            xMLParserConfiguration.addRecognizedProperties(jAXPValidatorComponent.getRecognizedProperties());
            xMLParserConfiguration.setDocumentHandler(jAXPValidatorComponent);
            jAXPValidatorComponent.setDocumentHandler(this.xmlReader);
            this.xmlReader.setDocumentSource(jAXPValidatorComponent);
            this.fSchemaValidator = jAXPValidatorComponent;
        } else {
            this.fSchemaValidationManager = null;
            this.fUnparsedEntityHandler = null;
            this.fSchemaValidatorComponentManager = null;
            this.fSchemaValidator = null;
        }
        this.fInitEntityResolver = this.xmlReader.getEntityResolver();
    }

    private void setFeatures(Hashtable hashtable) {
        if (hashtable != null) {
            for (Map.Entry entry : hashtable.entrySet()) {
                boolean booleanValue = ((Boolean) entry.getValue()).booleanValue();
                this.xmlReader.setFeature0((String) entry.getKey(), booleanValue);
            }
        }
    }

    @Override // org.apache.xerces.xs.PSVIProvider
    public AttributePSVI getAttributePSVI(int i2) {
        return this.xmlReader.getAttributePSVI(i2);
    }

    @Override // org.apache.xerces.xs.PSVIProvider
    public AttributePSVI getAttributePSVIByName(String str, String str2) {
        return this.xmlReader.getAttributePSVIByName(str, str2);
    }

    @Override // org.apache.xerces.xs.PSVIProvider
    public ElementPSVI getElementPSVI() {
        return this.xmlReader.getElementPSVI();
    }

    @Override // javax.xml.parsers.SAXParser
    public Parser getParser() {
        return this.xmlReader;
    }

    @Override // javax.xml.parsers.SAXParser
    public Object getProperty(String str) {
        return this.xmlReader.getProperty(str);
    }

    @Override // javax.xml.parsers.SAXParser
    public Schema getSchema() {
        return this.grammar;
    }

    @Override // javax.xml.parsers.SAXParser
    public XMLReader getXMLReader() {
        return this.xmlReader;
    }

    @Override // javax.xml.parsers.SAXParser
    public boolean isNamespaceAware() {
        try {
            return this.xmlReader.getFeature("http://xml.org/sax/features/namespaces");
        } catch (SAXException e2) {
            throw new IllegalStateException(e2.getMessage());
        }
    }

    @Override // javax.xml.parsers.SAXParser
    public boolean isValidating() {
        try {
            return this.xmlReader.getFeature("http://xml.org/sax/features/validation");
        } catch (SAXException e2) {
            throw new IllegalStateException(e2.getMessage());
        }
    }

    @Override // javax.xml.parsers.SAXParser
    public boolean isXIncludeAware() {
        try {
            return this.xmlReader.getFeature("http://apache.org/xml/features/xinclude");
        } catch (SAXException unused) {
            return false;
        }
    }

    @Override // javax.xml.parsers.SAXParser
    public void parse(InputSource inputSource, HandlerBase handlerBase) {
        if (inputSource != null) {
            if (handlerBase != null) {
                this.xmlReader.setDocumentHandler(handlerBase);
                this.xmlReader.setEntityResolver(handlerBase);
                this.xmlReader.setErrorHandler(handlerBase);
                this.xmlReader.setDTDHandler(handlerBase);
                this.xmlReader.setContentHandler(null);
            }
            this.xmlReader.parse(inputSource);
            return;
        }
        throw new IllegalArgumentException();
    }

    @Override // javax.xml.parsers.SAXParser
    public void parse(InputSource inputSource, DefaultHandler defaultHandler) {
        if (inputSource != null) {
            if (defaultHandler != null) {
                this.xmlReader.setContentHandler(defaultHandler);
                this.xmlReader.setEntityResolver(defaultHandler);
                this.xmlReader.setErrorHandler(defaultHandler);
                this.xmlReader.setDTDHandler(defaultHandler);
                this.xmlReader.setDocumentHandler(null);
            }
            this.xmlReader.parse(inputSource);
            return;
        }
        throw new IllegalArgumentException();
    }

    @Override // javax.xml.parsers.SAXParser
    public void reset() {
        try {
            this.xmlReader.restoreInitState();
        } catch (SAXException unused) {
        }
        this.xmlReader.setContentHandler(null);
        this.xmlReader.setDTDHandler(null);
        ErrorHandler errorHandler = this.xmlReader.getErrorHandler();
        ErrorHandler errorHandler2 = this.fInitErrorHandler;
        if (errorHandler != errorHandler2) {
            this.xmlReader.setErrorHandler(errorHandler2);
        }
        EntityResolver entityResolver = this.xmlReader.getEntityResolver();
        EntityResolver entityResolver2 = this.fInitEntityResolver;
        if (entityResolver != entityResolver2) {
            this.xmlReader.setEntityResolver(entityResolver2);
        }
    }

    @Override // javax.xml.parsers.SAXParser
    public void setProperty(String str, Object obj) {
        this.xmlReader.setProperty(str, obj);
    }
}
