package org.apache.xerces.jaxp.datatype;

import b.b.a.a.a;
import java.io.Serializable;
import java.math.BigDecimal;
import java.math.BigInteger;
import java.util.Calendar;
import java.util.Date;
import java.util.GregorianCalendar;
import javax.xml.datatype.DatatypeConstants;
import javax.xml.datatype.Duration;
import javax.xml.datatype.XMLGregorianCalendar;
import org.apache.poi.ss.usermodel.DateUtil;
import org.apache.poi.ss.util.SheetUtil;
import org.apache.xerces.util.DatatypeMessageFormatter;
import org.apache.xmlbeans.impl.common.NameUtil;

public class DurationImpl extends Duration implements Serializable {
    public static final BigDecimal[] FACTORS = {BigDecimal.valueOf(12L), null, BigDecimal.valueOf(24L), BigDecimal.valueOf(60L), BigDecimal.valueOf(60L)};
    public static final DatatypeConstants.Field[] FIELDS = {DatatypeConstants.YEARS, DatatypeConstants.MONTHS, DatatypeConstants.DAYS, DatatypeConstants.HOURS, DatatypeConstants.MINUTES, DatatypeConstants.SECONDS};
    public static final XMLGregorianCalendar[] TEST_POINTS = {XMLGregorianCalendarImpl.parse("1696-09-01T00:00:00Z"), XMLGregorianCalendarImpl.parse("1697-02-01T00:00:00Z"), XMLGregorianCalendarImpl.parse("1903-03-01T00:00:00Z"), XMLGregorianCalendarImpl.parse("1903-07-01T00:00:00Z")};
    public static final BigDecimal ZERO = BigDecimal.valueOf(0L);
    public static final long serialVersionUID = -2650025807136350131L;
    public final BigInteger days;
    public final BigInteger hours;
    public final BigInteger minutes;
    public final BigInteger months;
    public final BigDecimal seconds;
    public final int signum;
    public final BigInteger years;

    public DurationImpl(long j) {
        long j2 = 1;
        boolean z = true;
        boolean z2 = false;
        int i2 = (j > 0 ? 1 : (j == 0 ? 0 : -1));
        if (i2 > 0) {
            this.signum = 1;
        } else if (i2 < 0) {
            this.signum = -1;
            if (j == Long.MIN_VALUE) {
                j++;
            } else {
                z = false;
            }
            j *= -1;
            z2 = z;
        } else {
            this.signum = 0;
        }
        BigInteger bigInteger = null;
        this.years = null;
        this.months = null;
        this.seconds = BigDecimal.valueOf((j % 60000) + (!z2 ? 0 : j2), 3);
        long j3 = j / 60000;
        this.minutes = j3 == 0 ? null : BigInteger.valueOf(j3 % 60);
        long j4 = j3 / 60;
        this.hours = j4 == 0 ? null : BigInteger.valueOf(j4 % 24);
        long j5 = j4 / 24;
        this.days = j5 != 0 ? BigInteger.valueOf(j5) : bigInteger;
    }

    public DurationImpl(String str) {
        boolean z;
        boolean z2;
        if (str != null) {
            int length = str.length();
            int[] iArr = {0};
            if (length == iArr[0] || str.charAt(iArr[0]) != '-') {
                z = true;
            } else {
                iArr[0] = iArr[0] + 1;
                z = false;
            }
            if (length != iArr[0]) {
                int i2 = iArr[0];
                iArr[0] = i2 + 1;
                if (str.charAt(i2) != 'P') {
                    throw new IllegalArgumentException(str);
                }
            }
            String[] strArr = new String[3];
            int[] iArr2 = new int[3];
            int i3 = 0;
            while (length != iArr[0] && isDigit(str.charAt(iArr[0])) && i3 < 3) {
                iArr2[i3] = iArr[0];
                strArr[i3] = parsePiece(str, iArr);
                i3++;
            }
            if (length != iArr[0]) {
                int i4 = iArr[0];
                iArr[0] = i4 + 1;
                if (str.charAt(i4) == 'T') {
                    z2 = true;
                } else {
                    throw new IllegalArgumentException(str);
                }
            } else {
                z2 = false;
            }
            String[] strArr2 = new String[3];
            int[] iArr3 = new int[3];
            int i5 = 0;
            while (length != iArr[0] && isDigitOrPeriod(str.charAt(iArr[0])) && i5 < 3) {
                iArr3[i5] = iArr[0];
                strArr2[i5] = parsePiece(str, iArr);
                i5++;
            }
            if (z2 && i5 == 0) {
                throw new IllegalArgumentException(str);
            } else if (length != iArr[0]) {
                throw new IllegalArgumentException(str);
            } else if (i3 == 0 && i5 == 0) {
                throw new IllegalArgumentException(str);
            } else {
                organizeParts(str, strArr, iArr2, i3, "YMD");
                organizeParts(str, strArr2, iArr3, i5, "HMS");
                this.years = parseBigInteger(str, strArr[0], iArr2[0]);
                this.months = parseBigInteger(str, strArr[1], iArr2[1]);
                this.days = parseBigInteger(str, strArr[2], iArr2[2]);
                this.hours = parseBigInteger(str, strArr2[0], iArr3[0]);
                this.minutes = parseBigInteger(str, strArr2[1], iArr3[1]);
                this.seconds = parseBigDecimal(str, strArr2[2], iArr3[2]);
                this.signum = calcSignum(z);
            }
        } else {
            throw null;
        }
    }

    /* JADX INFO: this call moved to the top of the method (can break code semantics) */
    public DurationImpl(boolean z, int i2, int i3, int i4, int i5, int i6, int i7) {
        this(z, wrap(i2), wrap(i3), wrap(i4), wrap(i5), wrap(i6), i7 != 0 ? BigDecimal.valueOf((long) i7) : null);
    }

    public DurationImpl(boolean z, BigInteger bigInteger, BigInteger bigInteger2, BigInteger bigInteger3, BigInteger bigInteger4, BigInteger bigInteger5, BigDecimal bigDecimal) {
        this.years = bigInteger;
        this.months = bigInteger2;
        this.days = bigInteger3;
        this.hours = bigInteger4;
        this.minutes = bigInteger5;
        this.seconds = bigDecimal;
        this.signum = calcSignum(z);
        if (bigInteger == null && bigInteger2 == null && bigInteger3 == null && bigInteger4 == null && bigInteger5 == null && bigDecimal == null) {
            throw new IllegalArgumentException(DatatypeMessageFormatter.formatMessage(null, "AllFieldsNull", null));
        }
        testNonNegative(bigInteger, DatatypeConstants.YEARS);
        testNonNegative(bigInteger2, DatatypeConstants.MONTHS);
        testNonNegative(bigInteger3, DatatypeConstants.DAYS);
        testNonNegative(bigInteger4, DatatypeConstants.HOURS);
        testNonNegative(bigInteger5, DatatypeConstants.MINUTES);
        testNonNegative(bigDecimal, DatatypeConstants.SECONDS);
    }

    public static void alignSigns(BigDecimal[] bigDecimalArr, int i2, int i3) {
        boolean z;
        do {
            int i4 = 0;
            z = false;
            for (int i5 = i2; i5 < i3; i5++) {
                if (bigDecimalArr[i5].signum() * i4 < 0) {
                    int i6 = i5 - 1;
                    BigDecimal divide = bigDecimalArr[i5].abs().divide(FACTORS[i6], 0);
                    if (bigDecimalArr[i5].signum() > 0) {
                        divide = divide.negate();
                    }
                    bigDecimalArr[i6] = bigDecimalArr[i6].subtract(divide);
                    bigDecimalArr[i5] = bigDecimalArr[i5].add(divide.multiply(FACTORS[i6]));
                    z = true;
                }
                if (bigDecimalArr[i5].signum() != 0) {
                    i4 = bigDecimalArr[i5].signum();
                }
            }
        } while (z);
    }

    private int calcSignum(boolean z) {
        BigInteger bigInteger;
        BigInteger bigInteger2;
        BigInteger bigInteger3;
        BigInteger bigInteger4;
        BigDecimal bigDecimal;
        BigInteger bigInteger5 = this.years;
        if ((bigInteger5 == null || bigInteger5.signum() == 0) && (((bigInteger = this.months) == null || bigInteger.signum() == 0) && (((bigInteger2 = this.days) == null || bigInteger2.signum() == 0) && (((bigInteger3 = this.hours) == null || bigInteger3.signum() == 0) && (((bigInteger4 = this.minutes) == null || bigInteger4.signum() == 0) && ((bigDecimal = this.seconds) == null || bigDecimal.signum() == 0)))))) {
            return 0;
        }
        return z ? 1 : -1;
    }

    private int compareDates(Duration duration, Duration duration2) {
        XMLGregorianCalendar xMLGregorianCalendar = (XMLGregorianCalendar) TEST_POINTS[0].clone();
        XMLGregorianCalendar xMLGregorianCalendar2 = (XMLGregorianCalendar) TEST_POINTS[0].clone();
        xMLGregorianCalendar.add(duration);
        xMLGregorianCalendar2.add(duration2);
        int compare = xMLGregorianCalendar.compare(xMLGregorianCalendar2);
        if (compare == 2) {
            return 2;
        }
        XMLGregorianCalendar xMLGregorianCalendar3 = (XMLGregorianCalendar) TEST_POINTS[1].clone();
        XMLGregorianCalendar xMLGregorianCalendar4 = (XMLGregorianCalendar) TEST_POINTS[1].clone();
        xMLGregorianCalendar3.add(duration);
        xMLGregorianCalendar4.add(duration2);
        int compareResults = compareResults(compare, xMLGregorianCalendar3.compare(xMLGregorianCalendar4));
        if (compareResults == 2) {
            return 2;
        }
        XMLGregorianCalendar xMLGregorianCalendar5 = (XMLGregorianCalendar) TEST_POINTS[2].clone();
        XMLGregorianCalendar xMLGregorianCalendar6 = (XMLGregorianCalendar) TEST_POINTS[2].clone();
        xMLGregorianCalendar5.add(duration);
        xMLGregorianCalendar6.add(duration2);
        int compareResults2 = compareResults(compareResults, xMLGregorianCalendar5.compare(xMLGregorianCalendar6));
        if (compareResults2 == 2) {
            return 2;
        }
        XMLGregorianCalendar xMLGregorianCalendar7 = (XMLGregorianCalendar) TEST_POINTS[3].clone();
        XMLGregorianCalendar xMLGregorianCalendar8 = (XMLGregorianCalendar) TEST_POINTS[3].clone();
        xMLGregorianCalendar7.add(duration);
        xMLGregorianCalendar8.add(duration2);
        return compareResults(compareResults2, xMLGregorianCalendar7.compare(xMLGregorianCalendar8));
    }

    private int compareResults(int i2, int i3) {
        if (i3 != 2 && i2 == i3) {
            return i2;
        }
        return 2;
    }

    public static long getCalendarTimeInMillis(Calendar calendar) {
        return calendar.getTime().getTime();
    }

    private BigDecimal getFieldAsBigDecimal(DatatypeConstants.Field field) {
        if (field == DatatypeConstants.SECONDS) {
            BigDecimal bigDecimal = this.seconds;
            return bigDecimal != null ? bigDecimal : ZERO;
        }
        BigInteger bigInteger = (BigInteger) getField(field);
        return bigInteger == null ? ZERO : new BigDecimal(bigInteger);
    }

    private int getInt(DatatypeConstants.Field field) {
        Number field2 = getField(field);
        if (field2 == null) {
            return 0;
        }
        return field2.intValue();
    }

    public static boolean isDigit(char c) {
        return '0' <= c && c <= '9';
    }

    public static boolean isDigitOrPeriod(char c) {
        return isDigit(c) || c == '.';
    }

    public static void organizeParts(String str, String[] strArr, int[] iArr, int i2, String str2) {
        int length = str2.length();
        int i3 = i2 - 1;
        while (i3 >= 0) {
            if (strArr[i3] != null) {
                int lastIndexOf = str2.lastIndexOf(strArr[i3].charAt(strArr[i3].length() - 1), length - 1);
                if (lastIndexOf != -1) {
                    for (int i4 = lastIndexOf + 1; i4 < length; i4++) {
                        strArr[i4] = null;
                    }
                    strArr[lastIndexOf] = strArr[i3];
                    iArr[lastIndexOf] = iArr[i3];
                    i3--;
                    length = lastIndexOf;
                } else {
                    throw new IllegalArgumentException(str);
                }
            } else {
                throw new IllegalArgumentException(str);
            }
        }
        for (int i5 = length - 1; i5 >= 0; i5--) {
            strArr[i5] = null;
        }
    }

    public static BigDecimal parseBigDecimal(String str, String str2, int i2) {
        if (str2 == null) {
            return null;
        }
        return new BigDecimal(str2.substring(0, str2.length() - 1));
    }

    public static BigInteger parseBigInteger(String str, String str2, int i2) {
        if (str2 == null) {
            return null;
        }
        return new BigInteger(str2.substring(0, str2.length() - 1));
    }

    public static String parsePiece(String str, int[] iArr) {
        int i2 = iArr[0];
        while (iArr[0] < str.length() && isDigitOrPeriod(str.charAt(iArr[0]))) {
            iArr[0] = iArr[0] + 1;
        }
        if (iArr[0] != str.length()) {
            iArr[0] = iArr[0] + 1;
            return str.substring(i2, iArr[0]);
        }
        throw new IllegalArgumentException(str);
    }

    public static BigDecimal sanitize(BigDecimal bigDecimal, int i2) {
        return (i2 == 0 || bigDecimal == null) ? ZERO : i2 > 0 ? bigDecimal : bigDecimal.negate();
    }

    public static BigDecimal sanitize(BigInteger bigInteger, int i2) {
        return (i2 == 0 || bigInteger == null) ? ZERO : i2 > 0 ? new BigDecimal(bigInteger) : new BigDecimal(bigInteger.negate());
    }

    public static void testNonNegative(BigDecimal bigDecimal, DatatypeConstants.Field field) {
        if (bigDecimal != null && bigDecimal.signum() < 0) {
            throw new IllegalArgumentException(DatatypeMessageFormatter.formatMessage(null, "NegativeField", new Object[]{field.toString()}));
        }
    }

    public static void testNonNegative(BigInteger bigInteger, DatatypeConstants.Field field) {
        if (bigInteger != null && bigInteger.signum() < 0) {
            throw new IllegalArgumentException(DatatypeMessageFormatter.formatMessage(null, "NegativeField", new Object[]{field.toString()}));
        }
    }

    public static BigInteger toBigInteger(BigDecimal bigDecimal, boolean z) {
        if (!z || bigDecimal.signum() != 0) {
            return bigDecimal.unscaledValue();
        }
        return null;
    }

    private String toString(BigDecimal bigDecimal) {
        StringBuffer stringBuffer;
        String bigInteger = bigDecimal.unscaledValue().toString();
        int scale = bigDecimal.scale();
        if (scale == 0) {
            return bigInteger;
        }
        int length = bigInteger.length() - scale;
        if (length == 0) {
            return a.a("0.", bigInteger);
        }
        if (length > 0) {
            stringBuffer = new StringBuffer(bigInteger);
            stringBuffer.insert(length, NameUtil.PERIOD);
        } else {
            StringBuffer stringBuffer2 = new StringBuffer(bigInteger.length() + (3 - length));
            stringBuffer2.append("0.");
            for (int i2 = 0; i2 < (-length); i2++) {
                stringBuffer2.append(SheetUtil.defaultChar);
            }
            stringBuffer2.append(bigInteger);
            stringBuffer = stringBuffer2;
        }
        return stringBuffer.toString();
    }

    public static BigInteger wrap(int i2) {
        if (i2 == Integer.MIN_VALUE) {
            return null;
        }
        return BigInteger.valueOf((long) i2);
    }

    private Object writeReplace() {
        return new SerializedDuration(toString());
    }

    @Override // javax.xml.datatype.Duration
    public Duration add(Duration duration) {
        boolean z = false;
        BigDecimal[] bigDecimalArr = {sanitize((BigInteger) getField(DatatypeConstants.YEARS), getSign()).add(sanitize((BigInteger) duration.getField(DatatypeConstants.YEARS), duration.getSign())), sanitize((BigInteger) getField(DatatypeConstants.MONTHS), getSign()).add(sanitize((BigInteger) duration.getField(DatatypeConstants.MONTHS), duration.getSign())), sanitize((BigInteger) getField(DatatypeConstants.DAYS), getSign()).add(sanitize((BigInteger) duration.getField(DatatypeConstants.DAYS), duration.getSign())), sanitize((BigInteger) getField(DatatypeConstants.HOURS), getSign()).add(sanitize((BigInteger) duration.getField(DatatypeConstants.HOURS), duration.getSign())), sanitize((BigInteger) getField(DatatypeConstants.MINUTES), getSign()).add(sanitize((BigInteger) duration.getField(DatatypeConstants.MINUTES), duration.getSign())), sanitize((BigDecimal) getField(DatatypeConstants.SECONDS), getSign()).add(sanitize((BigDecimal) duration.getField(DatatypeConstants.SECONDS), duration.getSign()))};
        alignSigns(bigDecimalArr, 0, 2);
        alignSigns(bigDecimalArr, 2, 6);
        int i2 = 0;
        for (int i3 = 0; i3 < 6; i3++) {
            if (bigDecimalArr[i3].signum() * i2 >= 0) {
                if (i2 == 0) {
                    i2 = bigDecimalArr[i3].signum();
                }
            } else {
                throw new IllegalStateException();
            }
        }
        boolean z2 = i2 >= 0;
        BigInteger bigInteger = toBigInteger(sanitize(bigDecimalArr[0], i2), getField(DatatypeConstants.YEARS) == null && duration.getField(DatatypeConstants.YEARS) == null);
        BigInteger bigInteger2 = toBigInteger(sanitize(bigDecimalArr[1], i2), getField(DatatypeConstants.MONTHS) == null && duration.getField(DatatypeConstants.MONTHS) == null);
        BigInteger bigInteger3 = toBigInteger(sanitize(bigDecimalArr[2], i2), getField(DatatypeConstants.DAYS) == null && duration.getField(DatatypeConstants.DAYS) == null);
        BigInteger bigInteger4 = toBigInteger(sanitize(bigDecimalArr[3], i2), getField(DatatypeConstants.HOURS) == null && duration.getField(DatatypeConstants.HOURS) == null);
        BigDecimal sanitize = sanitize(bigDecimalArr[4], i2);
        if (getField(DatatypeConstants.MINUTES) == null && duration.getField(DatatypeConstants.MINUTES) == null) {
            z = true;
        }
        return new DurationImpl(z2, bigInteger, bigInteger2, bigInteger3, bigInteger4, toBigInteger(sanitize, z), (bigDecimalArr[5].signum() == 0 && getField(DatatypeConstants.SECONDS) == null && duration.getField(DatatypeConstants.SECONDS) == null) ? null : sanitize(bigDecimalArr[5], i2));
    }

    @Override // javax.xml.datatype.Duration
    public void addTo(Calendar calendar) {
        calendar.add(1, getYears() * this.signum);
        calendar.add(2, getMonths() * this.signum);
        calendar.add(5, getDays() * this.signum);
        calendar.add(10, getHours() * this.signum);
        calendar.add(12, getMinutes() * this.signum);
        calendar.add(13, getSeconds() * this.signum);
        BigDecimal bigDecimal = this.seconds;
        if (bigDecimal != null) {
            calendar.add(14, bigDecimal.subtract(bigDecimal.setScale(0, 1)).movePointRight(3).intValue() * this.signum);
        }
    }

    @Override // javax.xml.datatype.Duration
    public void addTo(Date date) {
        GregorianCalendar gregorianCalendar = new GregorianCalendar();
        gregorianCalendar.setTime(date);
        addTo(gregorianCalendar);
        date.setTime(getCalendarTimeInMillis(gregorianCalendar));
    }

    @Override // javax.xml.datatype.Duration
    public int compare(Duration duration) {
        BigInteger valueOf = BigInteger.valueOf(2147483647L);
        BigInteger bigInteger = this.years;
        if (bigInteger == null || bigInteger.compareTo(valueOf) != 1) {
            BigInteger bigInteger2 = this.months;
            if (bigInteger2 == null || bigInteger2.compareTo(valueOf) != 1) {
                BigInteger bigInteger3 = this.days;
                if (bigInteger3 == null || bigInteger3.compareTo(valueOf) != 1) {
                    BigInteger bigInteger4 = this.hours;
                    if (bigInteger4 == null || bigInteger4.compareTo(valueOf) != 1) {
                        BigInteger bigInteger5 = this.minutes;
                        if (bigInteger5 == null || bigInteger5.compareTo(valueOf) != 1) {
                            BigDecimal bigDecimal = this.seconds;
                            if (bigDecimal == null || bigDecimal.toBigInteger().compareTo(valueOf) != 1) {
                                BigInteger bigInteger6 = (BigInteger) duration.getField(DatatypeConstants.YEARS);
                                if (bigInteger6 == null || bigInteger6.compareTo(valueOf) != 1) {
                                    BigInteger bigInteger7 = (BigInteger) duration.getField(DatatypeConstants.MONTHS);
                                    if (bigInteger7 == null || bigInteger7.compareTo(valueOf) != 1) {
                                        BigInteger bigInteger8 = (BigInteger) duration.getField(DatatypeConstants.DAYS);
                                        if (bigInteger8 == null || bigInteger8.compareTo(valueOf) != 1) {
                                            BigInteger bigInteger9 = (BigInteger) duration.getField(DatatypeConstants.HOURS);
                                            if (bigInteger9 == null || bigInteger9.compareTo(valueOf) != 1) {
                                                BigInteger bigInteger10 = (BigInteger) duration.getField(DatatypeConstants.MINUTES);
                                                if (bigInteger10 == null || bigInteger10.compareTo(valueOf) != 1) {
                                                    BigDecimal bigDecimal2 = (BigDecimal) duration.getField(DatatypeConstants.SECONDS);
                                                    BigInteger bigInteger11 = bigDecimal2 != null ? bigDecimal2.toBigInteger() : null;
                                                    if (bigInteger11 == null || bigInteger11.compareTo(valueOf) != 1) {
                                                        GregorianCalendar gregorianCalendar = new GregorianCalendar(1970, 1, 1, 0, 0, 0);
                                                        gregorianCalendar.add(1, getSign() * getYears());
                                                        gregorianCalendar.add(2, getSign() * getMonths());
                                                        gregorianCalendar.add(6, getSign() * getDays());
                                                        gregorianCalendar.add(11, getSign() * getHours());
                                                        gregorianCalendar.add(12, getSign() * getMinutes());
                                                        gregorianCalendar.add(13, getSign() * getSeconds());
                                                        GregorianCalendar gregorianCalendar2 = new GregorianCalendar(1970, 1, 1, 0, 0, 0);
                                                        gregorianCalendar2.add(1, duration.getSign() * duration.getYears());
                                                        gregorianCalendar2.add(2, duration.getSign() * duration.getMonths());
                                                        gregorianCalendar2.add(6, duration.getSign() * duration.getDays());
                                                        gregorianCalendar2.add(11, duration.getSign() * duration.getHours());
                                                        gregorianCalendar2.add(12, duration.getSign() * duration.getMinutes());
                                                        gregorianCalendar2.add(13, duration.getSign() * duration.getSeconds());
                                                        if (gregorianCalendar.equals(gregorianCalendar2)) {
                                                            return 0;
                                                        }
                                                        return compareDates(this, duration);
                                                    }
                                                    StringBuffer stringBuffer = new StringBuffer();
                                                    a.a(DurationImpl.class, stringBuffer, "#compare(Duration duration)");
                                                    stringBuffer.append(DatatypeConstants.SECONDS.toString());
                                                    throw new UnsupportedOperationException(DatatypeMessageFormatter.formatMessage(null, "TooLarge", new Object[]{stringBuffer.toString(), bigInteger11.toString()}));
                                                }
                                                StringBuffer stringBuffer2 = new StringBuffer();
                                                a.a(DurationImpl.class, stringBuffer2, "#compare(Duration duration)");
                                                stringBuffer2.append(DatatypeConstants.MINUTES.toString());
                                                throw new UnsupportedOperationException(DatatypeMessageFormatter.formatMessage(null, "TooLarge", new Object[]{stringBuffer2.toString(), bigInteger10.toString()}));
                                            }
                                            StringBuffer stringBuffer3 = new StringBuffer();
                                            a.a(DurationImpl.class, stringBuffer3, "#compare(Duration duration)");
                                            stringBuffer3.append(DatatypeConstants.HOURS.toString());
                                            throw new UnsupportedOperationException(DatatypeMessageFormatter.formatMessage(null, "TooLarge", new Object[]{stringBuffer3.toString(), bigInteger9.toString()}));
                                        }
                                        StringBuffer stringBuffer4 = new StringBuffer();
                                        a.a(DurationImpl.class, stringBuffer4, "#compare(Duration duration)");
                                        stringBuffer4.append(DatatypeConstants.DAYS.toString());
                                        throw new UnsupportedOperationException(DatatypeMessageFormatter.formatMessage(null, "TooLarge", new Object[]{stringBuffer4.toString(), bigInteger8.toString()}));
                                    }
                                    StringBuffer stringBuffer5 = new StringBuffer();
                                    a.a(DurationImpl.class, stringBuffer5, "#compare(Duration duration)");
                                    stringBuffer5.append(DatatypeConstants.MONTHS.toString());
                                    throw new UnsupportedOperationException(DatatypeMessageFormatter.formatMessage(null, "TooLarge", new Object[]{stringBuffer5.toString(), bigInteger7.toString()}));
                                }
                                StringBuffer stringBuffer6 = new StringBuffer();
                                a.a(DurationImpl.class, stringBuffer6, "#compare(Duration duration)");
                                stringBuffer6.append(DatatypeConstants.YEARS.toString());
                                throw new UnsupportedOperationException(DatatypeMessageFormatter.formatMessage(null, "TooLarge", new Object[]{stringBuffer6.toString(), bigInteger6.toString()}));
                            }
                            StringBuffer stringBuffer7 = new StringBuffer();
                            a.a(DurationImpl.class, stringBuffer7, "#compare(Duration duration)");
                            stringBuffer7.append(DatatypeConstants.SECONDS.toString());
                            throw new UnsupportedOperationException(DatatypeMessageFormatter.formatMessage(null, "TooLarge", new Object[]{stringBuffer7.toString(), toString(this.seconds)}));
                        }
                        StringBuffer stringBuffer8 = new StringBuffer();
                        a.a(DurationImpl.class, stringBuffer8, "#compare(Duration duration)");
                        stringBuffer8.append(DatatypeConstants.MINUTES.toString());
                        throw new UnsupportedOperationException(DatatypeMessageFormatter.formatMessage(null, "TooLarge", new Object[]{stringBuffer8.toString(), this.minutes.toString()}));
                    }
                    StringBuffer stringBuffer9 = new StringBuffer();
                    a.a(DurationImpl.class, stringBuffer9, "#compare(Duration duration)");
                    stringBuffer9.append(DatatypeConstants.HOURS.toString());
                    throw new UnsupportedOperationException(DatatypeMessageFormatter.formatMessage(null, "TooLarge", new Object[]{stringBuffer9.toString(), this.hours.toString()}));
                }
                StringBuffer stringBuffer10 = new StringBuffer();
                a.a(DurationImpl.class, stringBuffer10, "#compare(Duration duration)");
                stringBuffer10.append(DatatypeConstants.DAYS.toString());
                throw new UnsupportedOperationException(DatatypeMessageFormatter.formatMessage(null, "TooLarge", new Object[]{stringBuffer10.toString(), this.days.toString()}));
            }
            StringBuffer stringBuffer11 = new StringBuffer();
            a.a(DurationImpl.class, stringBuffer11, "#compare(Duration duration)");
            stringBuffer11.append(DatatypeConstants.MONTHS.toString());
            throw new UnsupportedOperationException(DatatypeMessageFormatter.formatMessage(null, "TooLarge", new Object[]{stringBuffer11.toString(), this.months.toString()}));
        }
        StringBuffer stringBuffer12 = new StringBuffer();
        a.a(DurationImpl.class, stringBuffer12, "#compare(Duration duration)");
        stringBuffer12.append(DatatypeConstants.YEARS.toString());
        throw new UnsupportedOperationException(DatatypeMessageFormatter.formatMessage(null, "TooLarge", new Object[]{stringBuffer12.toString(), this.years.toString()}));
    }

    @Override // javax.xml.datatype.Duration
    public int getDays() {
        return getInt(DatatypeConstants.DAYS);
    }

    @Override // javax.xml.datatype.Duration
    public Number getField(DatatypeConstants.Field field) {
        if (field == null) {
            throw new NullPointerException(DatatypeMessageFormatter.formatMessage(null, "FieldCannotBeNull", new Object[]{"javax.xml.datatype.Duration#isSet(DatatypeConstants.Field field) "}));
        } else if (field == DatatypeConstants.YEARS) {
            return this.years;
        } else {
            if (field == DatatypeConstants.MONTHS) {
                return this.months;
            }
            if (field == DatatypeConstants.DAYS) {
                return this.days;
            }
            if (field == DatatypeConstants.HOURS) {
                return this.hours;
            }
            if (field == DatatypeConstants.MINUTES) {
                return this.minutes;
            }
            if (field == DatatypeConstants.SECONDS) {
                return this.seconds;
            }
            throw new IllegalArgumentException(DatatypeMessageFormatter.formatMessage(null, "UnknownField", new Object[]{"javax.xml.datatype.Duration#(getSet(DatatypeConstants.Field field)", field.toString()}));
        }
    }

    @Override // javax.xml.datatype.Duration
    public int getHours() {
        return getInt(DatatypeConstants.HOURS);
    }

    @Override // javax.xml.datatype.Duration
    public int getMinutes() {
        return getInt(DatatypeConstants.MINUTES);
    }

    @Override // javax.xml.datatype.Duration
    public int getMonths() {
        return getInt(DatatypeConstants.MONTHS);
    }

    @Override // javax.xml.datatype.Duration
    public int getSeconds() {
        return getInt(DatatypeConstants.SECONDS);
    }

    @Override // javax.xml.datatype.Duration
    public int getSign() {
        return this.signum;
    }

    @Override // javax.xml.datatype.Duration
    public long getTimeInMillis(Calendar calendar) {
        Calendar calendar2 = (Calendar) calendar.clone();
        addTo(calendar2);
        return getCalendarTimeInMillis(calendar2) - getCalendarTimeInMillis(calendar);
    }

    @Override // javax.xml.datatype.Duration
    public long getTimeInMillis(Date date) {
        GregorianCalendar gregorianCalendar = new GregorianCalendar();
        gregorianCalendar.setTime(date);
        addTo(gregorianCalendar);
        return getCalendarTimeInMillis(gregorianCalendar) - date.getTime();
    }

    @Override // javax.xml.datatype.Duration
    public int getYears() {
        return getInt(DatatypeConstants.YEARS);
    }

    @Override // javax.xml.datatype.Duration
    public int hashCode() {
        GregorianCalendar gregorianCalendar = TEST_POINTS[0].toGregorianCalendar();
        addTo(gregorianCalendar);
        return (int) getCalendarTimeInMillis(gregorianCalendar);
    }

    @Override // javax.xml.datatype.Duration
    public boolean isSet(DatatypeConstants.Field field) {
        if (field == null) {
            throw new NullPointerException(DatatypeMessageFormatter.formatMessage(null, "FieldCannotBeNull", new Object[]{"javax.xml.datatype.Duration#isSet(DatatypeConstants.Field field)"}));
        } else if (field == DatatypeConstants.YEARS) {
            return this.years != null;
        } else {
            if (field == DatatypeConstants.MONTHS) {
                return this.months != null;
            }
            if (field == DatatypeConstants.DAYS) {
                return this.days != null;
            }
            if (field == DatatypeConstants.HOURS) {
                return this.hours != null;
            }
            if (field == DatatypeConstants.MINUTES) {
                return this.minutes != null;
            }
            if (field == DatatypeConstants.SECONDS) {
                return this.seconds != null;
            }
            throw new IllegalArgumentException(DatatypeMessageFormatter.formatMessage(null, "UnknownField", new Object[]{"javax.xml.datatype.Duration#isSet(DatatypeConstants.Field field)", field.toString()}));
        }
    }

    @Override // javax.xml.datatype.Duration
    public Duration multiply(int i2) {
        return multiply(BigDecimal.valueOf((long) i2));
    }

    @Override // javax.xml.datatype.Duration
    public Duration multiply(BigDecimal bigDecimal) {
        BigDecimal bigDecimal2 = ZERO;
        int signum2 = bigDecimal.signum();
        BigDecimal abs = bigDecimal.abs();
        BigDecimal[] bigDecimalArr = new BigDecimal[6];
        boolean z = false;
        for (int i2 = 0; i2 < 5; i2++) {
            BigDecimal add = getFieldAsBigDecimal(FIELDS[i2]).multiply(abs).add(bigDecimal2);
            bigDecimalArr[i2] = add.setScale(0, 1);
            BigDecimal subtract = add.subtract(bigDecimalArr[i2]);
            if (i2 != 1) {
                bigDecimal2 = subtract.multiply(FACTORS[i2]);
            } else if (subtract.signum() == 0) {
                bigDecimal2 = ZERO;
            } else {
                throw new IllegalStateException();
            }
        }
        BigDecimal bigDecimal3 = this.seconds;
        if (bigDecimal3 != null) {
            bigDecimalArr[5] = bigDecimal3.multiply(abs).add(bigDecimal2);
        } else {
            bigDecimalArr[5] = bigDecimal2;
        }
        boolean z2 = this.signum * signum2 >= 0;
        BigInteger bigInteger = toBigInteger(bigDecimalArr[0], this.years == null);
        BigInteger bigInteger2 = toBigInteger(bigDecimalArr[1], this.months == null);
        BigInteger bigInteger3 = toBigInteger(bigDecimalArr[2], this.days == null);
        BigInteger bigInteger4 = toBigInteger(bigDecimalArr[3], this.hours == null);
        BigDecimal bigDecimal4 = bigDecimalArr[4];
        if (this.minutes == null) {
            z = true;
        }
        return new DurationImpl(z2, bigInteger, bigInteger2, bigInteger3, bigInteger4, toBigInteger(bigDecimal4, z), (bigDecimalArr[5].signum() == 0 && this.seconds == null) ? null : bigDecimalArr[5]);
    }

    @Override // javax.xml.datatype.Duration
    public Duration negate() {
        return new DurationImpl(this.signum <= 0, this.years, this.months, this.days, this.hours, this.minutes, this.seconds);
    }

    @Override // javax.xml.datatype.Duration
    public Duration normalizeWith(Calendar calendar) {
        Calendar calendar2 = (Calendar) calendar.clone();
        calendar2.add(1, getYears() * this.signum);
        calendar2.add(2, getMonths() * this.signum);
        calendar2.add(5, getDays() * this.signum);
        int calendarTimeInMillis = (int) ((getCalendarTimeInMillis(calendar2) - getCalendarTimeInMillis(calendar)) / DateUtil.DAY_MILLISECONDS);
        return new DurationImpl(calendarTimeInMillis >= 0, (BigInteger) null, (BigInteger) null, wrap(Math.abs(calendarTimeInMillis)), (BigInteger) getField(DatatypeConstants.HOURS), (BigInteger) getField(DatatypeConstants.MINUTES), (BigDecimal) getField(DatatypeConstants.SECONDS));
    }

    public int signum() {
        return this.signum;
    }

    @Override // javax.xml.datatype.Duration
    public Duration subtract(Duration duration) {
        return add(duration.negate());
    }

    @Override // javax.xml.datatype.Duration
    public String toString() {
        StringBuffer stringBuffer = new StringBuffer();
        if (this.signum < 0) {
            stringBuffer.append(NameUtil.HYPHEN);
        }
        stringBuffer.append('P');
        BigInteger bigInteger = this.years;
        if (bigInteger != null) {
            stringBuffer.append(bigInteger);
            stringBuffer.append('Y');
        }
        BigInteger bigInteger2 = this.months;
        if (bigInteger2 != null) {
            stringBuffer.append(bigInteger2);
            stringBuffer.append('M');
        }
        BigInteger bigInteger3 = this.days;
        if (bigInteger3 != null) {
            stringBuffer.append(bigInteger3);
            stringBuffer.append('D');
        }
        if (!(this.hours == null && this.minutes == null && this.seconds == null)) {
            stringBuffer.append('T');
            BigInteger bigInteger4 = this.hours;
            if (bigInteger4 != null) {
                stringBuffer.append(bigInteger4);
                stringBuffer.append('H');
            }
            BigInteger bigInteger5 = this.minutes;
            if (bigInteger5 != null) {
                stringBuffer.append(bigInteger5);
                stringBuffer.append('M');
            }
            BigDecimal bigDecimal = this.seconds;
            if (bigDecimal != null) {
                stringBuffer.append(toString(bigDecimal));
                stringBuffer.append('S');
            }
        }
        return stringBuffer.toString();
    }
}
