package org.apache.xerces.jaxp.validation;

import java.util.ArrayList;
import javax.xml.transform.dom.DOMResult;
import org.apache.xerces.dom.AttrImpl;
import org.apache.xerces.dom.CoreDocumentImpl;
import org.apache.xerces.dom.DOMMessageFormatter;
import org.apache.xerces.dom.DocumentTypeImpl;
import org.apache.xerces.dom.ElementImpl;
import org.apache.xerces.dom.ElementNSImpl;
import org.apache.xerces.dom.EntityImpl;
import org.apache.xerces.dom.NotationImpl;
import org.apache.xerces.dom.PSVIAttrNSImpl;
import org.apache.xerces.dom.PSVIDocumentImpl;
import org.apache.xerces.dom.PSVIElementNSImpl;
import org.apache.xerces.impl.Constants;
import org.apache.xerces.impl.dv.XSSimpleType;
import org.apache.xerces.xni.Augmentations;
import org.apache.xerces.xni.NamespaceContext;
import org.apache.xerces.xni.QName;
import org.apache.xerces.xni.XMLAttributes;
import org.apache.xerces.xni.XMLLocator;
import org.apache.xerces.xni.XMLResourceIdentifier;
import org.apache.xerces.xni.XMLString;
import org.apache.xerces.xni.XNIException;
import org.apache.xerces.xni.parser.XMLDocumentSource;
import org.apache.xerces.xs.AttributePSVI;
import org.apache.xerces.xs.ElementPSVI;
import org.apache.xerces.xs.XSSimpleTypeDefinition;
import org.apache.xerces.xs.XSTypeDefinition;
import org.w3c.dom.CDATASection;
import org.w3c.dom.Comment;
import org.w3c.dom.Document;
import org.w3c.dom.DocumentType;
import org.w3c.dom.Element;
import org.w3c.dom.Entity;
import org.w3c.dom.NamedNodeMap;
import org.w3c.dom.Node;
import org.w3c.dom.Notation;
import org.w3c.dom.ProcessingInstruction;
import org.w3c.dom.Text;

public final class DOMResultBuilder implements DOMDocumentHandler {
    public static final int[] kidOK;
    public final QName fAttributeQName = new QName();
    public Node fCurrentNode;
    public Document fDocument;
    public CoreDocumentImpl fDocumentImpl;
    public Node fFragmentRoot;
    public boolean fIgnoreChars;
    public Node fNextSibling;
    public boolean fStorePSVI;
    public Node fTarget;
    public final ArrayList fTargetChildren = new ArrayList();

    static {
        int[] iArr = new int[13];
        kidOK = iArr;
        iArr[9] = 1410;
        iArr[1] = 442;
        iArr[5] = 442;
        iArr[6] = 442;
        iArr[11] = 442;
        iArr[2] = 40;
        iArr[10] = 0;
        iArr[7] = 0;
        iArr[8] = 0;
        iArr[3] = 0;
        iArr[4] = 0;
        iArr[12] = 0;
    }

    private void append(Node node) {
        Node node2 = this.fCurrentNode;
        if (node2 != null) {
            node2.appendChild(node);
        } else if ((kidOK[this.fTarget.getNodeType()] & (1 << node.getNodeType())) != 0) {
            this.fTargetChildren.add(node);
        } else {
            throw new XNIException(DOMMessageFormatter.formatMessage(DOMMessageFormatter.DOM_DOMAIN, "HIERARCHY_REQUEST_ERR", null));
        }
    }

    @Override // org.apache.xerces.jaxp.validation.DOMDocumentHandler
    public void cdata(CDATASection cDATASection) {
        append(this.fDocument.createCDATASection(cDATASection.getNodeValue()));
    }

    @Override // org.apache.xerces.xni.XMLDocumentHandler
    public void characters(XMLString xMLString, Augmentations augmentations) {
        if (!this.fIgnoreChars) {
            append(this.fDocument.createTextNode(xMLString.toString()));
        }
    }

    @Override // org.apache.xerces.jaxp.validation.DOMDocumentHandler
    public void characters(Text text) {
        append(this.fDocument.createTextNode(text.getNodeValue()));
    }

    @Override // org.apache.xerces.xni.XMLDocumentHandler
    public void comment(XMLString xMLString, Augmentations augmentations) {
    }

    @Override // org.apache.xerces.jaxp.validation.DOMDocumentHandler
    public void comment(Comment comment) {
        append(this.fDocument.createComment(comment.getNodeValue()));
    }

    @Override // org.apache.xerces.xni.XMLDocumentHandler
    public void doctypeDecl(String str, String str2, String str3, Augmentations augmentations) {
    }

    @Override // org.apache.xerces.jaxp.validation.DOMDocumentHandler
    public void doctypeDecl(DocumentType documentType) {
        CoreDocumentImpl coreDocumentImpl = this.fDocumentImpl;
        if (coreDocumentImpl != null) {
            DocumentType createDocumentType = coreDocumentImpl.createDocumentType(documentType.getName(), documentType.getPublicId(), documentType.getSystemId());
            String internalSubset = documentType.getInternalSubset();
            if (internalSubset != null) {
                ((DocumentTypeImpl) createDocumentType).setInternalSubset(internalSubset);
            }
            NamedNodeMap entities = documentType.getEntities();
            NamedNodeMap entities2 = createDocumentType.getEntities();
            int length = entities.getLength();
            for (int i2 = 0; i2 < length; i2++) {
                Entity entity = (Entity) entities.item(i2);
                EntityImpl entityImpl = (EntityImpl) this.fDocumentImpl.createEntity(entity.getNodeName());
                entityImpl.setPublicId(entity.getPublicId());
                entityImpl.setSystemId(entity.getSystemId());
                entityImpl.setNotationName(entity.getNotationName());
                entities2.setNamedItem(entityImpl);
            }
            NamedNodeMap notations = documentType.getNotations();
            NamedNodeMap notations2 = createDocumentType.getNotations();
            int length2 = notations.getLength();
            for (int i3 = 0; i3 < length2; i3++) {
                Notation notation = (Notation) notations.item(i3);
                NotationImpl notationImpl = (NotationImpl) this.fDocumentImpl.createNotation(notation.getNodeName());
                notationImpl.setPublicId(notation.getPublicId());
                notationImpl.setSystemId(notation.getSystemId());
                notations2.setNamedItem(notationImpl);
            }
            append(createDocumentType);
        }
    }

    @Override // org.apache.xerces.xni.XMLDocumentHandler
    public void emptyElement(QName qName, XMLAttributes xMLAttributes, Augmentations augmentations) {
        startElement(qName, xMLAttributes, augmentations);
        endElement(qName, augmentations);
    }

    @Override // org.apache.xerces.xni.XMLDocumentHandler
    public void endCDATA(Augmentations augmentations) {
    }

    @Override // org.apache.xerces.xni.XMLDocumentHandler
    public void endDocument(Augmentations augmentations) {
        int size = this.fTargetChildren.size();
        int i2 = 0;
        if (this.fNextSibling == null) {
            while (i2 < size) {
                this.fTarget.appendChild((Node) this.fTargetChildren.get(i2));
                i2++;
            }
            return;
        }
        while (i2 < size) {
            this.fTarget.insertBefore((Node) this.fTargetChildren.get(i2), this.fNextSibling);
            i2++;
        }
    }

    @Override // org.apache.xerces.xni.XMLDocumentHandler
    public void endElement(QName qName, Augmentations augmentations) {
        ElementPSVI elementPSVI;
        if (!(augmentations == null || this.fDocumentImpl == null || (elementPSVI = (ElementPSVI) augmentations.getItem(Constants.ELEMENT_PSVI)) == null)) {
            if (this.fStorePSVI) {
                ((PSVIElementNSImpl) this.fCurrentNode).setPSVI(elementPSVI);
            }
            XSTypeDefinition memberTypeDefinition = elementPSVI.getMemberTypeDefinition();
            if (memberTypeDefinition == null) {
                memberTypeDefinition = elementPSVI.getTypeDefinition();
            }
            ((ElementNSImpl) this.fCurrentNode).setType(memberTypeDefinition);
        }
        Node node = this.fCurrentNode;
        if (node == this.fFragmentRoot) {
            this.fCurrentNode = null;
            this.fFragmentRoot = null;
            return;
        }
        this.fCurrentNode = node.getParentNode();
    }

    @Override // org.apache.xerces.xni.XMLDocumentHandler
    public void endGeneralEntity(String str, Augmentations augmentations) {
    }

    @Override // org.apache.xerces.xni.XMLDocumentHandler
    public XMLDocumentSource getDocumentSource() {
        return null;
    }

    @Override // org.apache.xerces.xni.XMLDocumentHandler
    public void ignorableWhitespace(XMLString xMLString, Augmentations augmentations) {
        characters(xMLString, augmentations);
    }

    @Override // org.apache.xerces.xni.XMLDocumentHandler
    public void processingInstruction(String str, XMLString xMLString, Augmentations augmentations) {
    }

    @Override // org.apache.xerces.jaxp.validation.DOMDocumentHandler
    public void processingInstruction(ProcessingInstruction processingInstruction) {
        append(this.fDocument.createProcessingInstruction(processingInstruction.getTarget(), processingInstruction.getData()));
    }

    @Override // org.apache.xerces.jaxp.validation.DOMDocumentHandler
    public void setDOMResult(DOMResult dOMResult) {
        CoreDocumentImpl coreDocumentImpl = null;
        this.fCurrentNode = null;
        this.fFragmentRoot = null;
        this.fIgnoreChars = false;
        this.fTargetChildren.clear();
        if (dOMResult != null) {
            this.fTarget = dOMResult.getNode();
            this.fNextSibling = dOMResult.getNextSibling();
            Document ownerDocument = this.fTarget.getNodeType() == 9 ? (Document) this.fTarget : this.fTarget.getOwnerDocument();
            this.fDocument = ownerDocument;
            if (ownerDocument instanceof CoreDocumentImpl) {
                coreDocumentImpl = (CoreDocumentImpl) ownerDocument;
            }
            this.fDocumentImpl = coreDocumentImpl;
            this.fStorePSVI = this.fDocument instanceof PSVIDocumentImpl;
            return;
        }
        this.fTarget = null;
        this.fNextSibling = null;
        this.fDocument = null;
        this.fDocumentImpl = null;
        this.fStorePSVI = false;
    }

    @Override // org.apache.xerces.xni.XMLDocumentHandler
    public void setDocumentSource(XMLDocumentSource xMLDocumentSource) {
    }

    @Override // org.apache.xerces.jaxp.validation.DOMDocumentHandler
    public void setIgnoringCharacters(boolean z) {
        this.fIgnoreChars = z;
    }

    @Override // org.apache.xerces.xni.XMLDocumentHandler
    public void startCDATA(Augmentations augmentations) {
    }

    @Override // org.apache.xerces.xni.XMLDocumentHandler
    public void startDocument(XMLLocator xMLLocator, String str, NamespaceContext namespaceContext, Augmentations augmentations) {
    }

    @Override // org.apache.xerces.xni.XMLDocumentHandler
    public void startElement(QName qName, XMLAttributes xMLAttributes, Augmentations augmentations) {
        Element element;
        int length = xMLAttributes.getLength();
        CoreDocumentImpl coreDocumentImpl = this.fDocumentImpl;
        int i2 = 0;
        if (coreDocumentImpl == null) {
            element = this.fDocument.createElementNS(qName.uri, qName.rawname);
            while (i2 < length) {
                xMLAttributes.getName(i2, this.fAttributeQName);
                QName qName2 = this.fAttributeQName;
                element.setAttributeNS(qName2.uri, qName2.rawname, xMLAttributes.getValue(i2));
                i2++;
            }
        } else {
            element = coreDocumentImpl.createElementNS(qName.uri, qName.rawname, qName.localpart);
            while (i2 < length) {
                xMLAttributes.getName(i2, this.fAttributeQName);
                CoreDocumentImpl coreDocumentImpl2 = this.fDocumentImpl;
                QName qName3 = this.fAttributeQName;
                AttrImpl attrImpl = (AttrImpl) coreDocumentImpl2.createAttributeNS(qName3.uri, qName3.rawname, qName3.localpart);
                attrImpl.setValue(xMLAttributes.getValue(i2));
                element.setAttributeNodeNS(attrImpl);
                AttributePSVI attributePSVI = (AttributePSVI) xMLAttributes.getAugmentations(i2).getItem(Constants.ATTRIBUTE_PSVI);
                if (attributePSVI != null) {
                    if (this.fStorePSVI) {
                        ((PSVIAttrNSImpl) attrImpl).setPSVI(attributePSVI);
                    }
                    XSSimpleTypeDefinition memberTypeDefinition = attributePSVI.getMemberTypeDefinition();
                    if (memberTypeDefinition == null) {
                        XSTypeDefinition typeDefinition = attributePSVI.getTypeDefinition();
                        if (typeDefinition != null) {
                            attrImpl.setType(typeDefinition);
                            if (!((XSSimpleType) typeDefinition).isIDType()) {
                            }
                        }
                    } else {
                        attrImpl.setType(memberTypeDefinition);
                        if (!((XSSimpleType) memberTypeDefinition).isIDType()) {
                        }
                    }
                    ((ElementImpl) element).setIdAttributeNode(attrImpl, true);
                }
                attrImpl.setSpecified(xMLAttributes.isSpecified(i2));
                i2++;
            }
        }
        append(element);
        this.fCurrentNode = element;
        if (this.fFragmentRoot == null) {
            this.fFragmentRoot = element;
        }
    }

    @Override // org.apache.xerces.xni.XMLDocumentHandler
    public void startGeneralEntity(String str, XMLResourceIdentifier xMLResourceIdentifier, String str2, Augmentations augmentations) {
    }

    @Override // org.apache.xerces.xni.XMLDocumentHandler
    public void textDecl(String str, String str2, Augmentations augmentations) {
    }

    @Override // org.apache.xerces.xni.XMLDocumentHandler
    public void xmlDecl(String str, String str2, String str3, Augmentations augmentations) {
    }
}
