package org.apache.xerces.jaxp.validation;

import java.util.Enumeration;
import javax.xml.parsers.DocumentBuilderFactory;
import javax.xml.parsers.ParserConfigurationException;
import javax.xml.transform.Result;
import javax.xml.transform.Source;
import javax.xml.transform.dom.DOMResult;
import javax.xml.transform.dom.DOMSource;
import org.apache.xerces.dom.NodeImpl;
import org.apache.xerces.impl.XMLErrorReporter;
import org.apache.xerces.impl.validation.EntityState;
import org.apache.xerces.impl.validation.ValidationManager;
import org.apache.xerces.impl.xs.XMLSchemaValidator;
import org.apache.xerces.impl.xs.util.SimpleLocator;
import org.apache.xerces.util.NamespaceSupport;
import org.apache.xerces.util.SymbolTable;
import org.apache.xerces.util.XMLAttributesImpl;
import org.apache.xerces.util.XMLSymbols;
import org.apache.xerces.xni.NamespaceContext;
import org.apache.xerces.xni.QName;
import org.apache.xerces.xni.XMLString;
import org.apache.xerces.xni.XNIException;
import org.apache.xerces.xni.parser.XMLParseException;
import org.w3c.dom.Attr;
import org.w3c.dom.CDATASection;
import org.w3c.dom.Comment;
import org.w3c.dom.Document;
import org.w3c.dom.DocumentType;
import org.w3c.dom.Entity;
import org.w3c.dom.NamedNodeMap;
import org.w3c.dom.Node;
import org.w3c.dom.ProcessingInstruction;
import org.w3c.dom.Text;
import org.xml.sax.SAXException;

public final class DOMValidatorHelper implements ValidatorHelper, EntityState {
    public static final int CHUNK_MASK = 1023;
    public static final int CHUNK_SIZE = 1024;
    public static final String ERROR_REPORTER = "http://apache.org/xml/properties/internal/error-reporter";
    public static final String NAMESPACE_CONTEXT = "http://apache.org/xml/properties/internal/namespace-context";
    public static final String SCHEMA_VALIDATOR = "http://apache.org/xml/properties/internal/validator/schema";
    public static final String SYMBOL_TABLE = "http://apache.org/xml/properties/internal/symbol-table";
    public static final String VALIDATION_MANAGER = "http://apache.org/xml/properties/internal/validation-manager";
    public final QName fAttributeQName = new QName();
    public final XMLAttributesImpl fAttributes = new XMLAttributesImpl();
    public final char[] fCharBuffer = new char[1024];
    public final XMLSchemaValidatorComponentManager fComponentManager;
    public Node fCurrentElement;
    public final DOMNamespaceContext fDOMNamespaceContext = new DOMNamespaceContext();
    public final DOMResultAugmentor fDOMResultAugmentor = new DOMResultAugmentor(this);
    public final DOMResultBuilder fDOMResultBuilder = new DOMResultBuilder();
    public DOMDocumentHandler fDOMValidatorHandler;
    public final QName fElementQName = new QName();
    public NamedNodeMap fEntities = null;
    public final XMLErrorReporter fErrorReporter;
    public final NamespaceSupport fNamespaceContext;
    public Node fRoot;
    public final XMLSchemaValidator fSchemaValidator;
    public final SymbolTable fSymbolTable;
    public final XMLString fTempString = new XMLString();
    public final ValidationManager fValidationManager;
    public final SimpleLocator fXMLLocator = new SimpleLocator(null, null, -1, -1, -1);

    public final class DOMNamespaceContext implements NamespaceContext {
        public boolean fDOMContextBuilt = false;
        public String[] fNamespace = new String[32];
        public int fNamespaceSize = 0;

        public DOMNamespaceContext() {
        }

        private void declarePrefix0(String str, String str2) {
            int i2 = this.fNamespaceSize;
            String[] strArr = this.fNamespace;
            if (i2 == strArr.length) {
                String[] strArr2 = new String[(i2 * 2)];
                System.arraycopy(strArr, 0, strArr2, 0, i2);
                this.fNamespace = strArr2;
            }
            String[] strArr3 = this.fNamespace;
            int i3 = this.fNamespaceSize;
            int i4 = i3 + 1;
            this.fNamespaceSize = i4;
            strArr3[i3] = str;
            this.fNamespaceSize = i4 + 1;
            strArr3[i4] = str2;
        }

        /* JADX WARNING: Code restructure failed: missing block: B:17:0x0054, code lost:
            if (r5.length() != 0) goto L_0x005f;
         */
        /* JADX WARNING: Code restructure failed: missing block: B:19:0x005d, code lost:
            if (r5.length() != 0) goto L_0x005f;
         */
        private void fillNamespaceContext() {
            String str;
            if (DOMValidatorHelper.this.fRoot != null) {
                Node node = DOMValidatorHelper.this.fRoot;
                while (true) {
                    node = node.getParentNode();
                    if (node == null) {
                        return;
                    }
                    if (1 == node.getNodeType()) {
                        NamedNodeMap attributes = node.getAttributes();
                        int length = attributes.getLength();
                        for (int i2 = 0; i2 < length; i2++) {
                            Attr attr = (Attr) attributes.item(i2);
                            String value = attr.getValue();
                            if (value == null) {
                                value = XMLSymbols.EMPTY_STRING;
                            }
                            DOMValidatorHelper dOMValidatorHelper = DOMValidatorHelper.this;
                            dOMValidatorHelper.fillQName(dOMValidatorHelper.fAttributeQName, attr);
                            QName qName = DOMValidatorHelper.this.fAttributeQName;
                            if (qName.uri == NamespaceContext.XMLNS_URI) {
                                String str2 = null;
                                if (qName.prefix == XMLSymbols.PREFIX_XMLNS) {
                                    str = qName.localpart;
                                } else {
                                    str = XMLSymbols.EMPTY_STRING;
                                }
                                str2 = DOMValidatorHelper.this.fSymbolTable.addSymbol(value);
                                declarePrefix0(str, str2);
                            }
                        }
                    }
                }
            }
        }

        private String getURI0(String str) {
            for (int i2 = 0; i2 < this.fNamespaceSize; i2 += 2) {
                String[] strArr = this.fNamespace;
                if (strArr[i2] == str) {
                    return strArr[i2 + 1];
                }
            }
            return null;
        }

        @Override // org.apache.xerces.xni.NamespaceContext
        public boolean declarePrefix(String str, String str2) {
            return DOMValidatorHelper.this.fNamespaceContext.declarePrefix(str, str2);
        }

        @Override // org.apache.xerces.xni.NamespaceContext
        public Enumeration getAllPrefixes() {
            return DOMValidatorHelper.this.fNamespaceContext.getAllPrefixes();
        }

        @Override // org.apache.xerces.xni.NamespaceContext
        public String getDeclaredPrefixAt(int i2) {
            return DOMValidatorHelper.this.fNamespaceContext.getDeclaredPrefixAt(i2);
        }

        @Override // org.apache.xerces.xni.NamespaceContext
        public int getDeclaredPrefixCount() {
            return DOMValidatorHelper.this.fNamespaceContext.getDeclaredPrefixCount();
        }

        @Override // org.apache.xerces.xni.NamespaceContext
        public String getPrefix(String str) {
            return DOMValidatorHelper.this.fNamespaceContext.getPrefix(str);
        }

        @Override // org.apache.xerces.xni.NamespaceContext
        public String getURI(String str) {
            String uri = DOMValidatorHelper.this.fNamespaceContext.getURI(str);
            if (uri != null) {
                return uri;
            }
            if (!this.fDOMContextBuilt) {
                fillNamespaceContext();
                this.fDOMContextBuilt = true;
            }
            return (this.fNamespaceSize <= 0 || DOMValidatorHelper.this.fNamespaceContext.containsPrefix(str)) ? uri : getURI0(str);
        }

        @Override // org.apache.xerces.xni.NamespaceContext
        public void popContext() {
            DOMValidatorHelper.this.fNamespaceContext.popContext();
        }

        @Override // org.apache.xerces.xni.NamespaceContext
        public void pushContext() {
            DOMValidatorHelper.this.fNamespaceContext.pushContext();
        }

        @Override // org.apache.xerces.xni.NamespaceContext
        public void reset() {
            this.fDOMContextBuilt = false;
            this.fNamespaceSize = 0;
        }
    }

    public DOMValidatorHelper(XMLSchemaValidatorComponentManager xMLSchemaValidatorComponentManager) {
        this.fComponentManager = xMLSchemaValidatorComponentManager;
        this.fErrorReporter = (XMLErrorReporter) xMLSchemaValidatorComponentManager.getProperty("http://apache.org/xml/properties/internal/error-reporter");
        this.fNamespaceContext = (NamespaceSupport) this.fComponentManager.getProperty("http://apache.org/xml/properties/internal/namespace-context");
        this.fSchemaValidator = (XMLSchemaValidator) this.fComponentManager.getProperty("http://apache.org/xml/properties/internal/validator/schema");
        this.fSymbolTable = (SymbolTable) this.fComponentManager.getProperty("http://apache.org/xml/properties/internal/symbol-table");
        this.fValidationManager = (ValidationManager) this.fComponentManager.getProperty("http://apache.org/xml/properties/internal/validation-manager");
    }

    private void beginNode(Node node) {
        DOMDocumentHandler dOMDocumentHandler;
        short nodeType = node.getNodeType();
        if (nodeType == 1) {
            this.fCurrentElement = node;
            this.fNamespaceContext.pushContext();
            fillQName(this.fElementQName, node);
            processAttributes(node.getAttributes());
            this.fSchemaValidator.startElement(this.fElementQName, this.fAttributes, null);
        } else if (nodeType == 10) {
            DOMDocumentHandler dOMDocumentHandler2 = this.fDOMValidatorHandler;
            if (dOMDocumentHandler2 != null) {
                dOMDocumentHandler2.doctypeDecl((DocumentType) node);
            }
        } else if (nodeType == 3) {
            DOMDocumentHandler dOMDocumentHandler3 = this.fDOMValidatorHandler;
            if (dOMDocumentHandler3 != null) {
                dOMDocumentHandler3.setIgnoringCharacters(true);
                sendCharactersToValidator(node.getNodeValue());
                this.fDOMValidatorHandler.setIgnoringCharacters(false);
                this.fDOMValidatorHandler.characters((Text) node);
                return;
            }
            sendCharactersToValidator(node.getNodeValue());
        } else if (nodeType == 4) {
            DOMDocumentHandler dOMDocumentHandler4 = this.fDOMValidatorHandler;
            if (dOMDocumentHandler4 != null) {
                dOMDocumentHandler4.setIgnoringCharacters(true);
                this.fSchemaValidator.startCDATA(null);
                sendCharactersToValidator(node.getNodeValue());
                this.fSchemaValidator.endCDATA(null);
                this.fDOMValidatorHandler.setIgnoringCharacters(false);
                this.fDOMValidatorHandler.cdata((CDATASection) node);
                return;
            }
            this.fSchemaValidator.startCDATA(null);
            sendCharactersToValidator(node.getNodeValue());
            this.fSchemaValidator.endCDATA(null);
        } else if (nodeType == 7) {
            DOMDocumentHandler dOMDocumentHandler5 = this.fDOMValidatorHandler;
            if (dOMDocumentHandler5 != null) {
                dOMDocumentHandler5.processingInstruction((ProcessingInstruction) node);
            }
        } else if (nodeType == 8 && (dOMDocumentHandler = this.fDOMValidatorHandler) != null) {
            dOMDocumentHandler.comment((Comment) node);
        }
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private void fillQName(QName qName, Node node) {
        String prefix = node.getPrefix();
        String localName = node.getLocalName();
        String nodeName = node.getNodeName();
        String namespaceURI = node.getNamespaceURI();
        qName.prefix = prefix != null ? this.fSymbolTable.addSymbol(prefix) : XMLSymbols.EMPTY_STRING;
        qName.localpart = localName != null ? this.fSymbolTable.addSymbol(localName) : XMLSymbols.EMPTY_STRING;
        qName.rawname = nodeName != null ? this.fSymbolTable.addSymbol(nodeName) : XMLSymbols.EMPTY_STRING;
        qName.uri = (namespaceURI == null || namespaceURI.length() <= 0) ? null : this.fSymbolTable.addSymbol(namespaceURI);
    }

    private void finishNode(Node node) {
        if (node.getNodeType() == 1) {
            this.fCurrentElement = node;
            fillQName(this.fElementQName, node);
            this.fSchemaValidator.endElement(this.fElementQName, null);
            this.fNamespaceContext.popContext();
        }
    }

    private void processAttributes(NamedNodeMap namedNodeMap) {
        int length = namedNodeMap.getLength();
        this.fAttributes.removeAllAttributes();
        for (int i2 = 0; i2 < length; i2++) {
            Attr attr = (Attr) namedNodeMap.item(i2);
            String value = attr.getValue();
            if (value == null) {
                value = XMLSymbols.EMPTY_STRING;
            }
            fillQName(this.fAttributeQName, attr);
            this.fAttributes.addAttributeNS(this.fAttributeQName, XMLSymbols.fCDATASymbol, value);
            this.fAttributes.setSpecified(i2, attr.getSpecified());
            QName qName = this.fAttributeQName;
            if (qName.uri == NamespaceContext.XMLNS_URI) {
                String str = null;
                if (qName.prefix == XMLSymbols.PREFIX_XMLNS) {
                    NamespaceSupport namespaceSupport = this.fNamespaceContext;
                    String str2 = qName.localpart;
                    if (value.length() != 0) {
                        str = this.fSymbolTable.addSymbol(value);
                    }
                    namespaceSupport.declarePrefix(str2, str);
                } else {
                    NamespaceSupport namespaceSupport2 = this.fNamespaceContext;
                    String str3 = XMLSymbols.EMPTY_STRING;
                    if (value.length() != 0) {
                        str = this.fSymbolTable.addSymbol(value);
                    }
                    namespaceSupport2.declarePrefix(str3, str);
                }
            }
        }
    }

    private void sendCharactersToValidator(String str) {
        if (str != null) {
            int length = str.length();
            int i2 = length & 1023;
            if (i2 > 0) {
                str.getChars(0, i2, this.fCharBuffer, 0);
                this.fTempString.setValues(this.fCharBuffer, 0, i2);
                this.fSchemaValidator.characters(this.fTempString, null);
            }
            while (i2 < length) {
                int i3 = i2 + 1024;
                str.getChars(i2, i3, this.fCharBuffer, 0);
                this.fTempString.setValues(this.fCharBuffer, 0, 1024);
                this.fSchemaValidator.characters(this.fTempString, null);
                i2 = i3;
            }
        }
    }

    private void setupDOMResultHandler(DOMSource dOMSource, DOMResult dOMResult) {
        if (dOMResult == null) {
            this.fDOMValidatorHandler = null;
            this.fSchemaValidator.setDocumentHandler(null);
            return;
        }
        if (dOMSource.getNode() == dOMResult.getNode()) {
            DOMResultAugmentor dOMResultAugmentor = this.fDOMResultAugmentor;
            this.fDOMValidatorHandler = dOMResultAugmentor;
            dOMResultAugmentor.setDOMResult(dOMResult);
            this.fSchemaValidator.setDocumentHandler(this.fDOMResultAugmentor);
            return;
        }
        if (dOMResult.getNode() == null) {
            try {
                DocumentBuilderFactory newInstance = DocumentBuilderFactory.newInstance();
                newInstance.setNamespaceAware(true);
                dOMResult.setNode(newInstance.newDocumentBuilder().newDocument());
            } catch (ParserConfigurationException e2) {
                throw new SAXException(e2);
            }
        }
        DOMResultBuilder dOMResultBuilder = this.fDOMResultBuilder;
        this.fDOMValidatorHandler = dOMResultBuilder;
        dOMResultBuilder.setDOMResult(dOMResult);
        this.fSchemaValidator.setDocumentHandler(this.fDOMResultBuilder);
    }

    private void setupEntityMap(Document document) {
        DocumentType doctype;
        this.fEntities = (document == null || (doctype = document.getDoctype()) == null) ? null : doctype.getEntities();
    }

    private boolean useIsSameNode(Node node) {
        if (node instanceof NodeImpl) {
            return false;
        }
        Document ownerDocument = node.getNodeType() == 9 ? (Document) node : node.getOwnerDocument();
        return ownerDocument != null && ownerDocument.getImplementation().hasFeature("Core", "3.0");
    }

    /* JADX WARNING: Code restructure failed: missing block: B:18:0x0033, code lost:
        if (r1 == null) goto L_0x0038;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:19:0x0035, code lost:
        finishNode(r1);
     */
    /* JADX WARNING: Code restructure failed: missing block: B:20:0x0038, code lost:
        r1 = null;
     */
    private void validate(Node node) {
        boolean useIsSameNode = useIsSameNode(node);
        Node node2 = node;
        while (node2 != null) {
            beginNode(node2);
            Node firstChild = node2.getFirstChild();
            while (true) {
                if (firstChild != null) {
                    break;
                }
                finishNode(node2);
                if (node == node2) {
                    break;
                }
                firstChild = node2.getNextSibling();
                if (firstChild == null) {
                    node2 = node2.getParentNode();
                    if (node2 == null) {
                        break;
                    }
                    if (useIsSameNode ? node.isSameNode(node2) : node == node2) {
                        break;
                    }
                }
            }
            node2 = firstChild;
        }
    }

    public Node getCurrentElement() {
        return this.fCurrentElement;
    }

    @Override // org.apache.xerces.impl.validation.EntityState
    public boolean isEntityDeclared(String str) {
        return false;
    }

    @Override // org.apache.xerces.impl.validation.EntityState
    public boolean isEntityUnparsed(String str) {
        Entity entity;
        NamedNodeMap namedNodeMap = this.fEntities;
        return (namedNodeMap == null || (entity = (Entity) namedNodeMap.getNamedItem(str)) == null || entity.getNotationName() == null) ? false : true;
    }

    @Override // org.apache.xerces.jaxp.validation.ValidatorHelper
    public void validate(Source source, Result result) {
        if ((result instanceof DOMResult) || result == null) {
            DOMSource dOMSource = (DOMSource) source;
            DOMResult dOMResult = (DOMResult) result;
            Node node = dOMSource.getNode();
            this.fRoot = node;
            if (node != null) {
                this.fComponentManager.reset();
                this.fValidationManager.setEntityState(this);
                this.fDOMNamespaceContext.reset();
                String systemId = dOMSource.getSystemId();
                this.fXMLLocator.setLiteralSystemId(systemId);
                this.fXMLLocator.setExpandedSystemId(systemId);
                this.fErrorReporter.setDocumentLocator(this.fXMLLocator);
                try {
                    setupEntityMap(node.getNodeType() == 9 ? (Document) node : node.getOwnerDocument());
                    setupDOMResultHandler(dOMSource, dOMResult);
                    this.fSchemaValidator.startDocument(this.fXMLLocator, null, this.fDOMNamespaceContext, null);
                    validate(node);
                    this.fSchemaValidator.endDocument(null);
                    this.fRoot = null;
                    this.fCurrentElement = null;
                    this.fEntities = null;
                    DOMDocumentHandler dOMDocumentHandler = this.fDOMValidatorHandler;
                    if (dOMDocumentHandler != null) {
                        dOMDocumentHandler.setDOMResult(null);
                    }
                } catch (XMLParseException e2) {
                    throw Util.toSAXParseException(e2);
                } catch (XNIException e3) {
                    throw Util.toSAXException(e3);
                } catch (Throwable th) {
                    this.fRoot = null;
                    this.fCurrentElement = null;
                    this.fEntities = null;
                    DOMDocumentHandler dOMDocumentHandler2 = this.fDOMValidatorHandler;
                    if (dOMDocumentHandler2 != null) {
                        dOMDocumentHandler2.setDOMResult(null);
                    }
                    throw th;
                }
            }
        } else {
            throw new IllegalArgumentException(JAXPValidationMessageFormatter.formatMessage(this.fComponentManager.getLocale(), "SourceResultMismatch", new Object[]{source.getClass().getName(), result.getClass().getName()}));
        }
    }
}
