package org.apache.xerces.jaxp.validation;

import java.util.Iterator;
import java.util.NoSuchElementException;
import javax.xml.namespace.NamespaceContext;
import javax.xml.stream.XMLEventFactory;
import javax.xml.stream.XMLEventWriter;
import javax.xml.stream.XMLStreamException;
import javax.xml.stream.XMLStreamReader;
import javax.xml.stream.events.Characters;
import javax.xml.stream.events.Comment;
import javax.xml.stream.events.DTD;
import javax.xml.stream.events.EndDocument;
import javax.xml.stream.events.EntityReference;
import javax.xml.stream.events.ProcessingInstruction;
import javax.xml.stream.events.StartDocument;
import javax.xml.stream.events.XMLEvent;
import javax.xml.transform.stax.StAXResult;
import org.apache.xerces.util.JAXPNamespaceContextWrapper;
import org.apache.xerces.xni.Augmentations;
import org.apache.xerces.xni.QName;
import org.apache.xerces.xni.XMLAttributes;
import org.apache.xerces.xni.XMLLocator;
import org.apache.xerces.xni.XMLResourceIdentifier;
import org.apache.xerces.xni.XMLString;
import org.apache.xerces.xni.XNIException;
import org.apache.xerces.xni.parser.XMLDocumentSource;

public final class StAXEventResultBuilder implements StAXDocumentHandler {
    public static final Iterator EMPTY_COLLECTION_ITERATOR = new Iterator() {
        /* class org.apache.xerces.jaxp.validation.StAXEventResultBuilder.AnonymousClass1 */

        public boolean hasNext() {
            return false;
        }

        @Override // java.util.Iterator
        public Object next() {
            throw new NoSuchElementException();
        }

        public void remove() {
            throw new UnsupportedOperationException();
        }
    };
    public final QName fAttrName = new QName();
    public final XMLEventFactory fEventFactory;
    public XMLEventWriter fEventWriter;
    public boolean fIgnoreChars;
    public boolean fInCDATA;
    public final JAXPNamespaceContextWrapper fNamespaceContext;
    public final StAXValidatorHelper fStAXValidatorHelper;

    public final class AttributeIterator implements Iterator {
        public XMLAttributes fAttributes;
        public int fEnd;
        public int fIndex = 0;

        public AttributeIterator(XMLAttributes xMLAttributes, int i2) {
            this.fAttributes = xMLAttributes;
            this.fEnd = i2;
        }

        public boolean hasNext() {
            if (this.fIndex < this.fEnd) {
                return true;
            }
            this.fAttributes = null;
            return false;
        }

        @Override // java.util.Iterator
        public Object next() {
            if (hasNext()) {
                this.fAttributes.getName(this.fIndex, StAXEventResultBuilder.this.fAttrName);
                XMLEventFactory xMLEventFactory = StAXEventResultBuilder.this.fEventFactory;
                String str = StAXEventResultBuilder.this.fAttrName.prefix;
                String str2 = StAXEventResultBuilder.this.fAttrName.uri != null ? StAXEventResultBuilder.this.fAttrName.uri : "";
                String str3 = StAXEventResultBuilder.this.fAttrName.localpart;
                XMLAttributes xMLAttributes = this.fAttributes;
                int i2 = this.fIndex;
                this.fIndex = i2 + 1;
                return xMLEventFactory.createAttribute(str, str2, str3, xMLAttributes.getValue(i2));
            }
            throw new NoSuchElementException();
        }

        public void remove() {
            throw new UnsupportedOperationException();
        }
    }

    public final class NamespaceIterator implements Iterator {
        public int fEnd;
        public int fIndex = 0;
        public NamespaceContext fNC;

        public NamespaceIterator(int i2) {
            this.fNC = StAXEventResultBuilder.this.fNamespaceContext.getNamespaceContext();
            this.fEnd = i2;
        }

        public boolean hasNext() {
            if (this.fIndex < this.fEnd) {
                return true;
            }
            this.fNC = null;
            return false;
        }

        @Override // java.util.Iterator
        public Object next() {
            if (hasNext()) {
                JAXPNamespaceContextWrapper jAXPNamespaceContextWrapper = StAXEventResultBuilder.this.fNamespaceContext;
                int i2 = this.fIndex;
                this.fIndex = i2 + 1;
                String declaredPrefixAt = jAXPNamespaceContextWrapper.getDeclaredPrefixAt(i2);
                String namespaceURI = this.fNC.getNamespaceURI(declaredPrefixAt);
                if (declaredPrefixAt.length() == 0) {
                    XMLEventFactory xMLEventFactory = StAXEventResultBuilder.this.fEventFactory;
                    if (namespaceURI == null) {
                        namespaceURI = "";
                    }
                    return xMLEventFactory.createNamespace(namespaceURI);
                }
                XMLEventFactory xMLEventFactory2 = StAXEventResultBuilder.this.fEventFactory;
                if (namespaceURI == null) {
                    namespaceURI = "";
                }
                return xMLEventFactory2.createNamespace(declaredPrefixAt, namespaceURI);
            }
            throw new NoSuchElementException();
        }

        public void remove() {
            throw new UnsupportedOperationException();
        }
    }

    public StAXEventResultBuilder(StAXValidatorHelper stAXValidatorHelper, JAXPNamespaceContextWrapper jAXPNamespaceContextWrapper) {
        this.fStAXValidatorHelper = stAXValidatorHelper;
        this.fNamespaceContext = jAXPNamespaceContextWrapper;
        this.fEventFactory = XMLEventFactory.newInstance();
    }

    private Iterator getAttributeIterator(XMLAttributes xMLAttributes, int i2) {
        return i2 > 0 ? new AttributeIterator(xMLAttributes, i2) : EMPTY_COLLECTION_ITERATOR;
    }

    private Iterator getNamespaceIterator() {
        int declaredPrefixCount = this.fNamespaceContext.getDeclaredPrefixCount();
        return declaredPrefixCount > 0 ? new NamespaceIterator(declaredPrefixCount) : EMPTY_COLLECTION_ITERATOR;
    }

    @Override // org.apache.xerces.jaxp.validation.StAXDocumentHandler
    public void cdata(Characters characters) {
        this.fEventWriter.add(characters);
    }

    @Override // org.apache.xerces.jaxp.validation.StAXDocumentHandler
    public void characters(Characters characters) {
        this.fEventWriter.add(characters);
    }

    @Override // org.apache.xerces.xni.XMLDocumentHandler
    public void characters(XMLString xMLString, Augmentations augmentations) {
        XMLEventWriter xMLEventWriter;
        Characters createCData;
        if (!this.fIgnoreChars) {
            try {
                if (!this.fInCDATA) {
                    xMLEventWriter = this.fEventWriter;
                    createCData = this.fEventFactory.createCharacters(xMLString.toString());
                } else {
                    xMLEventWriter = this.fEventWriter;
                    createCData = this.fEventFactory.createCData(xMLString.toString());
                }
                xMLEventWriter.add(createCData);
            } catch (XMLStreamException e2) {
                throw new XNIException(e2);
            }
        }
    }

    @Override // org.apache.xerces.jaxp.validation.StAXDocumentHandler
    public void comment(XMLStreamReader xMLStreamReader) {
        this.fEventWriter.add(this.fEventFactory.createComment(xMLStreamReader.getText()));
    }

    @Override // org.apache.xerces.jaxp.validation.StAXDocumentHandler
    public void comment(Comment comment) {
        this.fEventWriter.add(comment);
    }

    @Override // org.apache.xerces.xni.XMLDocumentHandler
    public void comment(XMLString xMLString, Augmentations augmentations) {
    }

    @Override // org.apache.xerces.xni.XMLDocumentHandler
    public void doctypeDecl(String str, String str2, String str3, Augmentations augmentations) {
    }

    @Override // org.apache.xerces.jaxp.validation.StAXDocumentHandler
    public void doctypeDecl(DTD dtd) {
        this.fEventWriter.add(dtd);
    }

    @Override // org.apache.xerces.xni.XMLDocumentHandler
    public void emptyElement(QName qName, XMLAttributes xMLAttributes, Augmentations augmentations) {
        startElement(qName, xMLAttributes, augmentations);
        endElement(qName, augmentations);
    }

    @Override // org.apache.xerces.xni.XMLDocumentHandler
    public void endCDATA(Augmentations augmentations) {
        this.fInCDATA = false;
    }

    @Override // org.apache.xerces.jaxp.validation.StAXDocumentHandler
    public void endDocument(XMLStreamReader xMLStreamReader) {
        this.fEventWriter.add(this.fEventFactory.createEndDocument());
        this.fEventWriter.flush();
    }

    @Override // org.apache.xerces.jaxp.validation.StAXDocumentHandler
    public void endDocument(EndDocument endDocument) {
        this.fEventWriter.add(endDocument);
        this.fEventWriter.flush();
    }

    @Override // org.apache.xerces.xni.XMLDocumentHandler
    public void endDocument(Augmentations augmentations) {
    }

    @Override // org.apache.xerces.xni.XMLDocumentHandler
    public void endElement(QName qName, Augmentations augmentations) {
        try {
            XMLEvent currentEvent = this.fStAXValidatorHelper.getCurrentEvent();
            if (currentEvent != null) {
                this.fEventWriter.add(currentEvent);
            } else {
                this.fEventWriter.add(this.fEventFactory.createEndElement(qName.prefix, qName.uri, qName.localpart, getNamespaceIterator()));
            }
        } catch (XMLStreamException e2) {
            throw new XNIException(e2);
        }
    }

    @Override // org.apache.xerces.xni.XMLDocumentHandler
    public void endGeneralEntity(String str, Augmentations augmentations) {
    }

    @Override // org.apache.xerces.jaxp.validation.StAXDocumentHandler
    public void entityReference(XMLStreamReader xMLStreamReader) {
        String localName = xMLStreamReader.getLocalName();
        this.fEventWriter.add(this.fEventFactory.createEntityReference(localName, this.fStAXValidatorHelper.getEntityDeclaration(localName)));
    }

    @Override // org.apache.xerces.jaxp.validation.StAXDocumentHandler
    public void entityReference(EntityReference entityReference) {
        this.fEventWriter.add(entityReference);
    }

    @Override // org.apache.xerces.xni.XMLDocumentHandler
    public XMLDocumentSource getDocumentSource() {
        return null;
    }

    @Override // org.apache.xerces.xni.XMLDocumentHandler
    public void ignorableWhitespace(XMLString xMLString, Augmentations augmentations) {
        characters(xMLString, augmentations);
    }

    @Override // org.apache.xerces.xni.XMLDocumentHandler
    public void processingInstruction(String str, XMLString xMLString, Augmentations augmentations) {
    }

    @Override // org.apache.xerces.jaxp.validation.StAXDocumentHandler
    public void processingInstruction(XMLStreamReader xMLStreamReader) {
        String pIData = xMLStreamReader.getPIData();
        XMLEventWriter xMLEventWriter = this.fEventWriter;
        XMLEventFactory xMLEventFactory = this.fEventFactory;
        String pITarget = xMLStreamReader.getPITarget();
        if (pIData == null) {
            pIData = "";
        }
        xMLEventWriter.add(xMLEventFactory.createProcessingInstruction(pITarget, pIData));
    }

    @Override // org.apache.xerces.jaxp.validation.StAXDocumentHandler
    public void processingInstruction(ProcessingInstruction processingInstruction) {
        this.fEventWriter.add(processingInstruction);
    }

    @Override // org.apache.xerces.xni.XMLDocumentHandler
    public void setDocumentSource(XMLDocumentSource xMLDocumentSource) {
    }

    @Override // org.apache.xerces.jaxp.validation.StAXDocumentHandler
    public void setIgnoringCharacters(boolean z) {
        this.fIgnoreChars = z;
    }

    @Override // org.apache.xerces.jaxp.validation.StAXDocumentHandler
    public void setStAXResult(StAXResult stAXResult) {
        this.fIgnoreChars = false;
        this.fInCDATA = false;
        this.fEventWriter = stAXResult != null ? stAXResult.getXMLEventWriter() : null;
    }

    @Override // org.apache.xerces.xni.XMLDocumentHandler
    public void startCDATA(Augmentations augmentations) {
        this.fInCDATA = true;
    }

    @Override // org.apache.xerces.jaxp.validation.StAXDocumentHandler
    public void startDocument(XMLStreamReader xMLStreamReader) {
        String version = xMLStreamReader.getVersion();
        String characterEncodingScheme = xMLStreamReader.getCharacterEncodingScheme();
        boolean standaloneSet = xMLStreamReader.standaloneSet();
        XMLEventWriter xMLEventWriter = this.fEventWriter;
        XMLEventFactory xMLEventFactory = this.fEventFactory;
        if (characterEncodingScheme == null) {
            characterEncodingScheme = "UTF-8";
        }
        if (version == null) {
            version = "1.0";
        }
        xMLEventWriter.add(xMLEventFactory.createStartDocument(characterEncodingScheme, version, standaloneSet));
    }

    @Override // org.apache.xerces.jaxp.validation.StAXDocumentHandler
    public void startDocument(StartDocument startDocument) {
        this.fEventWriter.add(startDocument);
    }

    @Override // org.apache.xerces.xni.XMLDocumentHandler
    public void startDocument(XMLLocator xMLLocator, String str, org.apache.xerces.xni.NamespaceContext namespaceContext, Augmentations augmentations) {
    }

    @Override // org.apache.xerces.xni.XMLDocumentHandler
    public void startElement(QName qName, XMLAttributes xMLAttributes, Augmentations augmentations) {
        XMLEvent currentEvent;
        try {
            int length = xMLAttributes.getLength();
            if (length != 0 || (currentEvent = this.fStAXValidatorHelper.getCurrentEvent()) == null) {
                this.fEventWriter.add(this.fEventFactory.createStartElement(qName.prefix, qName.uri != null ? qName.uri : "", qName.localpart, getAttributeIterator(xMLAttributes, length), getNamespaceIterator(), this.fNamespaceContext.getNamespaceContext()));
            } else {
                this.fEventWriter.add(currentEvent);
            }
        } catch (XMLStreamException e2) {
            throw new XNIException(e2);
        }
    }

    @Override // org.apache.xerces.xni.XMLDocumentHandler
    public void startGeneralEntity(String str, XMLResourceIdentifier xMLResourceIdentifier, String str2, Augmentations augmentations) {
    }

    @Override // org.apache.xerces.xni.XMLDocumentHandler
    public void textDecl(String str, String str2, Augmentations augmentations) {
    }

    @Override // org.apache.xerces.xni.XMLDocumentHandler
    public void xmlDecl(String str, String str2, String str3, Augmentations augmentations) {
    }
}
