package org.apache.xerces.jaxp.validation;

import java.util.ArrayList;
import java.util.HashMap;
import java.util.Iterator;
import java.util.List;
import javax.xml.stream.Location;
import javax.xml.stream.XMLEventReader;
import javax.xml.stream.XMLStreamException;
import javax.xml.stream.XMLStreamReader;
import javax.xml.stream.events.Attribute;
import javax.xml.stream.events.Characters;
import javax.xml.stream.events.Comment;
import javax.xml.stream.events.DTD;
import javax.xml.stream.events.EndDocument;
import javax.xml.stream.events.EndElement;
import javax.xml.stream.events.EntityDeclaration;
import javax.xml.stream.events.EntityReference;
import javax.xml.stream.events.Namespace;
import javax.xml.stream.events.ProcessingInstruction;
import javax.xml.stream.events.StartDocument;
import javax.xml.stream.events.StartElement;
import javax.xml.stream.events.XMLEvent;
import javax.xml.transform.Result;
import javax.xml.transform.Source;
import javax.xml.transform.stax.StAXResult;
import javax.xml.transform.stax.StAXSource;
import org.apache.xerces.impl.XMLErrorReporter;
import org.apache.xerces.impl.validation.EntityState;
import org.apache.xerces.impl.validation.ValidationManager;
import org.apache.xerces.impl.xs.XMLSchemaValidator;
import org.apache.xerces.util.JAXPNamespaceContextWrapper;
import org.apache.xerces.util.StAXLocationWrapper;
import org.apache.xerces.util.SymbolTable;
import org.apache.xerces.util.XMLAttributesImpl;
import org.apache.xerces.util.XMLStringBuffer;
import org.apache.xerces.util.XMLSymbols;
import org.apache.xerces.xni.QName;
import org.apache.xerces.xni.XMLString;
import org.apache.xerces.xni.XNIException;
import org.apache.xerces.xni.parser.XMLParseException;
import org.xml.sax.SAXException;

public final class StAXValidatorHelper implements ValidatorHelper, EntityState {
    public static final String ERROR_REPORTER = "http://apache.org/xml/properties/internal/error-reporter";
    public static final String SCHEMA_VALIDATOR = "http://apache.org/xml/properties/internal/validator/schema";
    public static final String STRING_INTERNING = "javax.xml.stream.isInterning";
    public static final String SYMBOL_TABLE = "http://apache.org/xml/properties/internal/symbol-table";
    public static final String VALIDATION_MANAGER = "http://apache.org/xml/properties/internal/validation-manager";
    public final QName fAttributeQName = new QName();
    public final XMLAttributesImpl fAttributes = new XMLAttributesImpl();
    public final XMLSchemaValidatorComponentManager fComponentManager;
    public XMLEvent fCurrentEvent = null;
    public final ArrayList fDeclaredPrefixes = new ArrayList();
    public int fDepth = 0;
    public final QName fElementQName = new QName();
    public HashMap fEntities = null;
    public final XMLErrorReporter fErrorReporter;
    public EventHelper fEventHelper;
    public final JAXPNamespaceContextWrapper fNamespaceContext;
    public final XMLSchemaValidator fSchemaValidator;
    public StAXEventResultBuilder fStAXEventResultBuilder;
    public final StAXLocationWrapper fStAXLocationWrapper = new StAXLocationWrapper();
    public StAXStreamResultBuilder fStAXStreamResultBuilder;
    public StAXDocumentHandler fStAXValidatorHandler;
    public StreamHelper fStreamHelper;
    public final XMLStringBuffer fStringBuffer = new XMLStringBuffer();
    public boolean fStringsInternalized = false;
    public final SymbolTable fSymbolTable;
    public final XMLString fTempString = new XMLString();
    public final ValidationManager fValidationManager;
    public final XMLStreamReaderLocation fXMLStreamReaderLocation = new XMLStreamReaderLocation();

    public final class EventHelper {
        public static final int CHUNK_MASK = 1023;
        public static final int CHUNK_SIZE = 1024;
        public final char[] fCharBuffer = new char[1024];

        public EventHelper() {
        }

        private void fillDeclaredPrefixes(Iterator it) {
            StAXValidatorHelper.this.fDeclaredPrefixes.clear();
            while (it.hasNext()) {
                String prefix = ((Namespace) it.next()).getPrefix();
                ArrayList arrayList = StAXValidatorHelper.this.fDeclaredPrefixes;
                if (prefix == null) {
                    prefix = "";
                }
                arrayList.add(prefix);
            }
        }

        private void fillDeclaredPrefixes(EndElement endElement) {
            fillDeclaredPrefixes(endElement.getNamespaces());
        }

        private void fillDeclaredPrefixes(StartElement startElement) {
            fillDeclaredPrefixes(startElement.getNamespaces());
        }

        private void fillQName(QName qName, javax.xml.namespace.QName qName2) {
            StAXValidatorHelper.this.fillQName(qName, qName2.getNamespaceURI(), qName2.getLocalPart(), qName2.getPrefix());
        }

        private void fillXMLAttributes(StartElement startElement) {
            StAXValidatorHelper.this.fAttributes.removeAllAttributes();
            Iterator attributes = startElement.getAttributes();
            while (attributes.hasNext()) {
                Attribute attribute = (Attribute) attributes.next();
                fillQName(StAXValidatorHelper.this.fAttributeQName, attribute.getName());
                String dTDType = attribute.getDTDType();
                int length = StAXValidatorHelper.this.fAttributes.getLength();
                StAXValidatorHelper stAXValidatorHelper = StAXValidatorHelper.this;
                XMLAttributesImpl xMLAttributesImpl = stAXValidatorHelper.fAttributes;
                QName qName = stAXValidatorHelper.fAttributeQName;
                if (dTDType == null) {
                    dTDType = XMLSymbols.fCDATASymbol;
                }
                xMLAttributesImpl.addAttributeNS(qName, dTDType, attribute.getValue());
                StAXValidatorHelper.this.fAttributes.setSpecified(length, attribute.isSpecified());
            }
        }

        private void sendCharactersToValidator(String str) {
            if (str != null) {
                int length = str.length();
                int i2 = length & 1023;
                if (i2 > 0) {
                    str.getChars(0, i2, this.fCharBuffer, 0);
                    StAXValidatorHelper.this.fTempString.setValues(this.fCharBuffer, 0, i2);
                    StAXValidatorHelper.this.fSchemaValidator.characters(StAXValidatorHelper.this.fTempString, null);
                }
                while (i2 < length) {
                    int i3 = i2 + 1024;
                    str.getChars(i2, i3, this.fCharBuffer, 0);
                    StAXValidatorHelper.this.fTempString.setValues(this.fCharBuffer, 0, 1024);
                    StAXValidatorHelper.this.fSchemaValidator.characters(StAXValidatorHelper.this.fTempString, null);
                    i2 = i3;
                }
            }
        }

        public final void validate(XMLEventReader xMLEventReader, StAXResult stAXResult) {
            StAXValidatorHelper.this.fCurrentEvent = xMLEventReader.peek();
            if (StAXValidatorHelper.this.fCurrentEvent != null) {
                int eventType = StAXValidatorHelper.this.fCurrentEvent.getEventType();
                if (eventType == 7 || eventType == 1) {
                    StAXValidatorHelper.this.setup(null, stAXResult, false);
                    StAXValidatorHelper.this.fSchemaValidator.startDocument(StAXValidatorHelper.this.fStAXLocationWrapper, null, StAXValidatorHelper.this.fNamespaceContext, null);
                    while (xMLEventReader.hasNext()) {
                        StAXValidatorHelper.this.fCurrentEvent = xMLEventReader.nextEvent();
                        switch (StAXValidatorHelper.this.fCurrentEvent.getEventType()) {
                            case 1:
                                StAXValidatorHelper.access$504(StAXValidatorHelper.this);
                                StartElement asStartElement = StAXValidatorHelper.this.fCurrentEvent.asStartElement();
                                fillQName(StAXValidatorHelper.this.fElementQName, asStartElement.getName());
                                fillXMLAttributes(asStartElement);
                                fillDeclaredPrefixes(asStartElement);
                                StAXValidatorHelper.this.fNamespaceContext.setNamespaceContext(asStartElement.getNamespaceContext());
                                StAXValidatorHelper.this.fStAXLocationWrapper.setLocation(asStartElement.getLocation());
                                XMLSchemaValidator xMLSchemaValidator = StAXValidatorHelper.this.fSchemaValidator;
                                StAXValidatorHelper stAXValidatorHelper = StAXValidatorHelper.this;
                                xMLSchemaValidator.startElement(stAXValidatorHelper.fElementQName, stAXValidatorHelper.fAttributes, null);
                                break;
                            case 2:
                                EndElement asEndElement = StAXValidatorHelper.this.fCurrentEvent.asEndElement();
                                fillQName(StAXValidatorHelper.this.fElementQName, asEndElement.getName());
                                fillDeclaredPrefixes(asEndElement);
                                StAXValidatorHelper.this.fStAXLocationWrapper.setLocation(asEndElement.getLocation());
                                StAXValidatorHelper.this.fSchemaValidator.endElement(StAXValidatorHelper.this.fElementQName, null);
                                if (StAXValidatorHelper.access$506(StAXValidatorHelper.this) > 0) {
                                    break;
                                } else {
                                    StAXValidatorHelper.this.fSchemaValidator.endDocument(null);
                                    return;
                                }
                            case 3:
                                if (StAXValidatorHelper.this.fStAXValidatorHandler == null) {
                                    break;
                                } else {
                                    StAXValidatorHelper.this.fStAXValidatorHandler.processingInstruction((ProcessingInstruction) StAXValidatorHelper.this.fCurrentEvent);
                                    break;
                                }
                            case 4:
                            case 6:
                                if (StAXValidatorHelper.this.fStAXValidatorHandler == null) {
                                    sendCharactersToValidator(StAXValidatorHelper.this.fCurrentEvent.asCharacters().getData());
                                    break;
                                } else {
                                    Characters asCharacters = StAXValidatorHelper.this.fCurrentEvent.asCharacters();
                                    StAXValidatorHelper.this.fStAXValidatorHandler.setIgnoringCharacters(true);
                                    sendCharactersToValidator(asCharacters.getData());
                                    StAXValidatorHelper.this.fStAXValidatorHandler.setIgnoringCharacters(false);
                                    StAXValidatorHelper.this.fStAXValidatorHandler.characters(asCharacters);
                                    break;
                                }
                            case 5:
                                if (StAXValidatorHelper.this.fStAXValidatorHandler == null) {
                                    break;
                                } else {
                                    StAXValidatorHelper.this.fStAXValidatorHandler.comment((Comment) StAXValidatorHelper.this.fCurrentEvent);
                                    break;
                                }
                            case 7:
                                StAXValidatorHelper.access$504(StAXValidatorHelper.this);
                                if (StAXValidatorHelper.this.fStAXValidatorHandler == null) {
                                    break;
                                } else {
                                    StAXValidatorHelper.this.fStAXValidatorHandler.startDocument((StartDocument) StAXValidatorHelper.this.fCurrentEvent);
                                    break;
                                }
                            case 8:
                                if (StAXValidatorHelper.this.fStAXValidatorHandler == null) {
                                    break;
                                } else {
                                    StAXValidatorHelper.this.fStAXValidatorHandler.endDocument((EndDocument) StAXValidatorHelper.this.fCurrentEvent);
                                    break;
                                }
                            case 9:
                                if (StAXValidatorHelper.this.fStAXValidatorHandler == null) {
                                    break;
                                } else {
                                    StAXValidatorHelper.this.fStAXValidatorHandler.entityReference((EntityReference) StAXValidatorHelper.this.fCurrentEvent);
                                    break;
                                }
                            case 11:
                                DTD dtd = (DTD) StAXValidatorHelper.this.fCurrentEvent;
                                StAXValidatorHelper.this.processEntityDeclarations(dtd.getEntities());
                                if (StAXValidatorHelper.this.fStAXValidatorHandler == null) {
                                    break;
                                } else {
                                    StAXValidatorHelper.this.fStAXValidatorHandler.doctypeDecl(dtd);
                                    break;
                                }
                            case 12:
                                if (StAXValidatorHelper.this.fStAXValidatorHandler == null) {
                                    StAXValidatorHelper.this.fSchemaValidator.startCDATA(null);
                                    sendCharactersToValidator(StAXValidatorHelper.this.fCurrentEvent.asCharacters().getData());
                                    StAXValidatorHelper.this.fSchemaValidator.endCDATA(null);
                                    break;
                                } else {
                                    Characters asCharacters2 = StAXValidatorHelper.this.fCurrentEvent.asCharacters();
                                    StAXValidatorHelper.this.fStAXValidatorHandler.setIgnoringCharacters(true);
                                    StAXValidatorHelper.this.fSchemaValidator.startCDATA(null);
                                    sendCharactersToValidator(StAXValidatorHelper.this.fCurrentEvent.asCharacters().getData());
                                    StAXValidatorHelper.this.fSchemaValidator.endCDATA(null);
                                    StAXValidatorHelper.this.fStAXValidatorHandler.setIgnoringCharacters(false);
                                    StAXValidatorHelper.this.fStAXValidatorHandler.cdata(asCharacters2);
                                    break;
                                }
                        }
                    }
                    StAXValidatorHelper.this.fSchemaValidator.endDocument(null);
                    return;
                }
                throw new SAXException(JAXPValidationMessageFormatter.formatMessage(StAXValidatorHelper.this.fComponentManager.getLocale(), "StAXIllegalInitialState", null));
            }
        }
    }

    public final class StreamHelper {
        public StreamHelper() {
        }

        private void fillDeclaredPrefixes(XMLStreamReader xMLStreamReader) {
            StAXValidatorHelper.this.fDeclaredPrefixes.clear();
            int namespaceCount = xMLStreamReader.getNamespaceCount();
            for (int i2 = 0; i2 < namespaceCount; i2++) {
                String namespacePrefix = xMLStreamReader.getNamespacePrefix(i2);
                ArrayList arrayList = StAXValidatorHelper.this.fDeclaredPrefixes;
                if (namespacePrefix == null) {
                    namespacePrefix = "";
                }
                arrayList.add(namespacePrefix);
            }
        }

        private void fillXMLAttributes(XMLStreamReader xMLStreamReader) {
            StAXValidatorHelper.this.fAttributes.removeAllAttributes();
            int attributeCount = xMLStreamReader.getAttributeCount();
            for (int i2 = 0; i2 < attributeCount; i2++) {
                StAXValidatorHelper stAXValidatorHelper = StAXValidatorHelper.this;
                stAXValidatorHelper.fillQName(stAXValidatorHelper.fAttributeQName, xMLStreamReader.getAttributeNamespace(i2), xMLStreamReader.getAttributeLocalName(i2), xMLStreamReader.getAttributePrefix(i2));
                String attributeType = xMLStreamReader.getAttributeType(i2);
                StAXValidatorHelper stAXValidatorHelper2 = StAXValidatorHelper.this;
                XMLAttributesImpl xMLAttributesImpl = stAXValidatorHelper2.fAttributes;
                QName qName = stAXValidatorHelper2.fAttributeQName;
                if (attributeType == null) {
                    attributeType = XMLSymbols.fCDATASymbol;
                }
                xMLAttributesImpl.addAttributeNS(qName, attributeType, xMLStreamReader.getAttributeValue(i2));
                StAXValidatorHelper.this.fAttributes.setSpecified(i2, xMLStreamReader.isAttributeSpecified(i2));
            }
        }

        /* JADX WARNING: Removed duplicated region for block: B:29:0x0191  */
        /* JADX WARNING: Removed duplicated region for block: B:33:0x01a6  */
        /* JADX WARNING: Removed duplicated region for block: B:36:0x0199 A[SYNTHETIC] */
        /* JADX WARNING: Removed duplicated region for block: B:40:? A[ADDED_TO_REGION, RETURN, SYNTHETIC] */
        public final void validate(XMLStreamReader xMLStreamReader, StAXResult stAXResult) {
            if (xMLStreamReader.hasNext()) {
                int eventType = xMLStreamReader.getEventType();
                if (eventType == 7 || eventType == 1) {
                    StAXValidatorHelper.this.fXMLStreamReaderLocation.setXMLStreamReader(xMLStreamReader);
                    StAXValidatorHelper stAXValidatorHelper = StAXValidatorHelper.this;
                    stAXValidatorHelper.setup(stAXValidatorHelper.fXMLStreamReaderLocation, stAXResult, Boolean.TRUE.equals(xMLStreamReader.getProperty(StAXValidatorHelper.STRING_INTERNING)));
                    StAXValidatorHelper.this.fSchemaValidator.startDocument(StAXValidatorHelper.this.fStAXLocationWrapper, null, StAXValidatorHelper.this.fNamespaceContext, null);
                    do {
                        switch (eventType) {
                            case 1:
                                StAXValidatorHelper.access$504(StAXValidatorHelper.this);
                                StAXValidatorHelper stAXValidatorHelper2 = StAXValidatorHelper.this;
                                stAXValidatorHelper2.fillQName(stAXValidatorHelper2.fElementQName, xMLStreamReader.getNamespaceURI(), xMLStreamReader.getLocalName(), xMLStreamReader.getPrefix());
                                fillXMLAttributes(xMLStreamReader);
                                fillDeclaredPrefixes(xMLStreamReader);
                                StAXValidatorHelper.this.fNamespaceContext.setNamespaceContext(xMLStreamReader.getNamespaceContext());
                                XMLSchemaValidator xMLSchemaValidator = StAXValidatorHelper.this.fSchemaValidator;
                                StAXValidatorHelper stAXValidatorHelper3 = StAXValidatorHelper.this;
                                xMLSchemaValidator.startElement(stAXValidatorHelper3.fElementQName, stAXValidatorHelper3.fAttributes, null);
                                eventType = xMLStreamReader.next();
                                if (!xMLStreamReader.hasNext()) {
                                    break;
                                }
                                StAXValidatorHelper.this.fSchemaValidator.endDocument(null);
                                if (eventType != 8 && StAXValidatorHelper.this.fStAXValidatorHandler != null) {
                                    StAXValidatorHelper.this.fStAXValidatorHandler.endDocument(xMLStreamReader);
                                    return;
                                }
                                return;
                            case 2:
                                StAXValidatorHelper stAXValidatorHelper4 = StAXValidatorHelper.this;
                                stAXValidatorHelper4.fillQName(stAXValidatorHelper4.fElementQName, xMLStreamReader.getNamespaceURI(), xMLStreamReader.getLocalName(), xMLStreamReader.getPrefix());
                                fillDeclaredPrefixes(xMLStreamReader);
                                StAXValidatorHelper.this.fNamespaceContext.setNamespaceContext(xMLStreamReader.getNamespaceContext());
                                StAXValidatorHelper.this.fSchemaValidator.endElement(StAXValidatorHelper.this.fElementQName, null);
                                StAXValidatorHelper.access$506(StAXValidatorHelper.this);
                                eventType = xMLStreamReader.next();
                                if (!xMLStreamReader.hasNext()) {
                                }
                                StAXValidatorHelper.this.fSchemaValidator.endDocument(null);
                                if (eventType != 8) {
                                    return;
                                }
                                return;
                            case 3:
                                if (StAXValidatorHelper.this.fStAXValidatorHandler != null) {
                                    StAXValidatorHelper.this.fStAXValidatorHandler.processingInstruction(xMLStreamReader);
                                }
                                eventType = xMLStreamReader.next();
                                if (!xMLStreamReader.hasNext()) {
                                }
                                StAXValidatorHelper.this.fSchemaValidator.endDocument(null);
                                if (eventType != 8) {
                                }
                                break;
                            case 4:
                            case 6:
                                StAXValidatorHelper.this.fTempString.setValues(xMLStreamReader.getTextCharacters(), xMLStreamReader.getTextStart(), xMLStreamReader.getTextLength());
                                StAXValidatorHelper.this.fSchemaValidator.characters(StAXValidatorHelper.this.fTempString, null);
                                eventType = xMLStreamReader.next();
                                if (!xMLStreamReader.hasNext()) {
                                }
                                StAXValidatorHelper.this.fSchemaValidator.endDocument(null);
                                if (eventType != 8) {
                                }
                                break;
                            case 5:
                                if (StAXValidatorHelper.this.fStAXValidatorHandler != null) {
                                    StAXValidatorHelper.this.fStAXValidatorHandler.comment(xMLStreamReader);
                                }
                                eventType = xMLStreamReader.next();
                                if (!xMLStreamReader.hasNext()) {
                                }
                                StAXValidatorHelper.this.fSchemaValidator.endDocument(null);
                                if (eventType != 8) {
                                }
                                break;
                            case 7:
                                StAXValidatorHelper.access$504(StAXValidatorHelper.this);
                                if (StAXValidatorHelper.this.fStAXValidatorHandler != null) {
                                    StAXValidatorHelper.this.fStAXValidatorHandler.startDocument(xMLStreamReader);
                                }
                                eventType = xMLStreamReader.next();
                                if (!xMLStreamReader.hasNext()) {
                                }
                                StAXValidatorHelper.this.fSchemaValidator.endDocument(null);
                                if (eventType != 8) {
                                }
                                break;
                            case 8:
                            case 10:
                            default:
                                eventType = xMLStreamReader.next();
                                if (!xMLStreamReader.hasNext()) {
                                }
                                StAXValidatorHelper.this.fSchemaValidator.endDocument(null);
                                if (eventType != 8) {
                                }
                                break;
                            case 9:
                                if (StAXValidatorHelper.this.fStAXValidatorHandler != null) {
                                    StAXValidatorHelper.this.fStAXValidatorHandler.entityReference(xMLStreamReader);
                                }
                                eventType = xMLStreamReader.next();
                                if (!xMLStreamReader.hasNext()) {
                                }
                                StAXValidatorHelper.this.fSchemaValidator.endDocument(null);
                                if (eventType != 8) {
                                }
                                break;
                            case 11:
                                StAXValidatorHelper.this.processEntityDeclarations((List) xMLStreamReader.getProperty("javax.xml.stream.entities"));
                                eventType = xMLStreamReader.next();
                                if (!xMLStreamReader.hasNext()) {
                                }
                                StAXValidatorHelper.this.fSchemaValidator.endDocument(null);
                                if (eventType != 8) {
                                }
                                break;
                            case 12:
                                StAXValidatorHelper.this.fSchemaValidator.startCDATA(null);
                                StAXValidatorHelper.this.fTempString.setValues(xMLStreamReader.getTextCharacters(), xMLStreamReader.getTextStart(), xMLStreamReader.getTextLength());
                                StAXValidatorHelper.this.fSchemaValidator.characters(StAXValidatorHelper.this.fTempString, null);
                                StAXValidatorHelper.this.fSchemaValidator.endCDATA(null);
                                eventType = xMLStreamReader.next();
                                if (!xMLStreamReader.hasNext()) {
                                }
                                StAXValidatorHelper.this.fSchemaValidator.endDocument(null);
                                if (eventType != 8) {
                                }
                                break;
                        }
                    } while (StAXValidatorHelper.this.fDepth > 0);
                    StAXValidatorHelper.this.fSchemaValidator.endDocument(null);
                    if (eventType != 8) {
                    }
                } else {
                    throw new SAXException(JAXPValidationMessageFormatter.formatMessage(StAXValidatorHelper.this.fComponentManager.getLocale(), "StAXIllegalInitialState", null));
                }
            }
        }
    }

    public static final class XMLStreamReaderLocation implements Location {
        public XMLStreamReader reader;

        private Location getLocation() {
            XMLStreamReader xMLStreamReader = this.reader;
            if (xMLStreamReader != null) {
                return xMLStreamReader.getLocation();
            }
            return null;
        }

        @Override // javax.xml.stream.Location
        public int getCharacterOffset() {
            Location location = getLocation();
            if (location != null) {
                return location.getCharacterOffset();
            }
            return -1;
        }

        @Override // javax.xml.stream.Location
        public int getColumnNumber() {
            Location location = getLocation();
            if (location != null) {
                return location.getColumnNumber();
            }
            return -1;
        }

        @Override // javax.xml.stream.Location
        public int getLineNumber() {
            Location location = getLocation();
            if (location != null) {
                return location.getLineNumber();
            }
            return -1;
        }

        @Override // javax.xml.stream.Location
        public String getPublicId() {
            Location location = getLocation();
            if (location != null) {
                return location.getPublicId();
            }
            return null;
        }

        @Override // javax.xml.stream.Location
        public String getSystemId() {
            Location location = getLocation();
            if (location != null) {
                return location.getSystemId();
            }
            return null;
        }

        public void setXMLStreamReader(XMLStreamReader xMLStreamReader) {
            this.reader = xMLStreamReader;
        }
    }

    public StAXValidatorHelper(XMLSchemaValidatorComponentManager xMLSchemaValidatorComponentManager) {
        this.fComponentManager = xMLSchemaValidatorComponentManager;
        this.fErrorReporter = (XMLErrorReporter) xMLSchemaValidatorComponentManager.getProperty("http://apache.org/xml/properties/internal/error-reporter");
        this.fSchemaValidator = (XMLSchemaValidator) this.fComponentManager.getProperty("http://apache.org/xml/properties/internal/validator/schema");
        this.fSymbolTable = (SymbolTable) this.fComponentManager.getProperty("http://apache.org/xml/properties/internal/symbol-table");
        this.fValidationManager = (ValidationManager) this.fComponentManager.getProperty("http://apache.org/xml/properties/internal/validation-manager");
        JAXPNamespaceContextWrapper jAXPNamespaceContextWrapper = new JAXPNamespaceContextWrapper(this.fSymbolTable);
        this.fNamespaceContext = jAXPNamespaceContextWrapper;
        jAXPNamespaceContextWrapper.setDeclaredPrefixes(this.fDeclaredPrefixes);
    }

    public static /* synthetic */ int access$504(StAXValidatorHelper stAXValidatorHelper) {
        int i2 = stAXValidatorHelper.fDepth + 1;
        stAXValidatorHelper.fDepth = i2;
        return i2;
    }

    public static /* synthetic */ int access$506(StAXValidatorHelper stAXValidatorHelper) {
        int i2 = stAXValidatorHelper.fDepth - 1;
        stAXValidatorHelper.fDepth = i2;
        return i2;
    }

    private void setupStAXResultHandler(StAXResult stAXResult) {
        if (stAXResult == null) {
            this.fStAXValidatorHandler = null;
            this.fSchemaValidator.setDocumentHandler(null);
            return;
        }
        if (stAXResult.getXMLStreamWriter() != null) {
            if (this.fStAXStreamResultBuilder == null) {
                this.fStAXStreamResultBuilder = new StAXStreamResultBuilder(this.fNamespaceContext);
            }
            StAXStreamResultBuilder stAXStreamResultBuilder = this.fStAXStreamResultBuilder;
            this.fStAXValidatorHandler = stAXStreamResultBuilder;
            stAXStreamResultBuilder.setStAXResult(stAXResult);
        } else {
            if (this.fStAXEventResultBuilder == null) {
                this.fStAXEventResultBuilder = new StAXEventResultBuilder(this, this.fNamespaceContext);
            }
            StAXEventResultBuilder stAXEventResultBuilder = this.fStAXEventResultBuilder;
            this.fStAXValidatorHandler = stAXEventResultBuilder;
            stAXEventResultBuilder.setStAXResult(stAXResult);
        }
        this.fSchemaValidator.setDocumentHandler(this.fStAXValidatorHandler);
    }

    public final void fillQName(QName qName, String str, String str2, String str3) {
        String str4;
        String str5;
        String str6 = null;
        if (!this.fStringsInternalized) {
            if (str != null && str.length() > 0) {
                str6 = this.fSymbolTable.addSymbol(str);
            }
            str4 = str2 != null ? this.fSymbolTable.addSymbol(str2) : XMLSymbols.EMPTY_STRING;
            str3 = (str3 == null || str3.length() <= 0) ? XMLSymbols.EMPTY_STRING : this.fSymbolTable.addSymbol(str3);
        } else {
            if (str != null && str.length() == 0) {
                str = null;
            }
            if (str2 == null) {
                str2 = XMLSymbols.EMPTY_STRING;
            }
            if (str3 == null) {
                str3 = XMLSymbols.EMPTY_STRING;
            }
            str6 = str;
            str4 = str2;
        }
        if (str3 != XMLSymbols.EMPTY_STRING) {
            this.fStringBuffer.clear();
            this.fStringBuffer.append(str3);
            this.fStringBuffer.append(':');
            this.fStringBuffer.append(str4);
            SymbolTable symbolTable = this.fSymbolTable;
            XMLStringBuffer xMLStringBuffer = this.fStringBuffer;
            str5 = symbolTable.addSymbol(xMLStringBuffer.ch, xMLStringBuffer.offset, xMLStringBuffer.length);
        } else {
            str5 = str4;
        }
        qName.setValues(str3, str4, str5, str6);
    }

    public final XMLEvent getCurrentEvent() {
        return this.fCurrentEvent;
    }

    public final EntityDeclaration getEntityDeclaration(String str) {
        HashMap hashMap = this.fEntities;
        if (hashMap != null) {
            return (EntityDeclaration) hashMap.get(str);
        }
        return null;
    }

    @Override // org.apache.xerces.impl.validation.EntityState
    public boolean isEntityDeclared(String str) {
        HashMap hashMap = this.fEntities;
        if (hashMap != null) {
            return hashMap.containsKey(str);
        }
        return false;
    }

    @Override // org.apache.xerces.impl.validation.EntityState
    public boolean isEntityUnparsed(String str) {
        EntityDeclaration entityDeclaration;
        HashMap hashMap = this.fEntities;
        return (hashMap == null || (entityDeclaration = (EntityDeclaration) hashMap.get(str)) == null || entityDeclaration.getNotationName() == null) ? false : true;
    }

    public final void processEntityDeclarations(List list) {
        int size = list != null ? list.size() : 0;
        if (size > 0) {
            if (this.fEntities == null) {
                this.fEntities = new HashMap();
            }
            for (int i2 = 0; i2 < size; i2++) {
                EntityDeclaration entityDeclaration = (EntityDeclaration) list.get(i2);
                this.fEntities.put(entityDeclaration.getName(), entityDeclaration);
            }
        }
    }

    public final void setup(Location location, StAXResult stAXResult, boolean z) {
        this.fDepth = 0;
        this.fComponentManager.reset();
        setupStAXResultHandler(stAXResult);
        this.fValidationManager.setEntityState(this);
        HashMap hashMap = this.fEntities;
        if (hashMap != null && !hashMap.isEmpty()) {
            this.fEntities.clear();
        }
        this.fStAXLocationWrapper.setLocation(location);
        this.fErrorReporter.setDocumentLocator(this.fStAXLocationWrapper);
        this.fStringsInternalized = z;
    }

    @Override // org.apache.xerces.jaxp.validation.ValidatorHelper
    public void validate(Source source, Result result) {
        if ((result instanceof StAXResult) || result == null) {
            StAXSource stAXSource = (StAXSource) source;
            StAXResult stAXResult = (StAXResult) result;
            try {
                XMLStreamReader xMLStreamReader = stAXSource.getXMLStreamReader();
                if (xMLStreamReader != null) {
                    if (this.fStreamHelper == null) {
                        this.fStreamHelper = new StreamHelper();
                    }
                    this.fStreamHelper.validate(xMLStreamReader, stAXResult);
                } else {
                    if (this.fEventHelper == null) {
                        this.fEventHelper = new EventHelper();
                    }
                    this.fEventHelper.validate(stAXSource.getXMLEventReader(), stAXResult);
                }
                this.fCurrentEvent = null;
                this.fStAXLocationWrapper.setLocation(null);
                this.fXMLStreamReaderLocation.setXMLStreamReader(null);
                StAXDocumentHandler stAXDocumentHandler = this.fStAXValidatorHandler;
                if (stAXDocumentHandler != null) {
                    stAXDocumentHandler.setStAXResult(null);
                }
            } catch (XMLStreamException e2) {
                throw new SAXException(e2);
            } catch (XMLParseException e3) {
                throw Util.toSAXParseException(e3);
            } catch (XNIException e4) {
                throw Util.toSAXException(e4);
            } catch (Throwable th) {
                this.fCurrentEvent = null;
                this.fStAXLocationWrapper.setLocation(null);
                this.fXMLStreamReaderLocation.setXMLStreamReader(null);
                StAXDocumentHandler stAXDocumentHandler2 = this.fStAXValidatorHandler;
                if (stAXDocumentHandler2 != null) {
                    stAXDocumentHandler2.setStAXResult(null);
                }
                throw th;
            }
        } else {
            throw new IllegalArgumentException(JAXPValidationMessageFormatter.formatMessage(this.fComponentManager.getLocale(), "SourceResultMismatch", new Object[]{source.getClass().getName(), result.getClass().getName()}));
        }
    }
}
