package org.apache.xerces.jaxp.validation;

import i.a.c.a.a;
import i.a.c.a.j;
import i.a.c.a.m;
import i.a.c.a.n;
import java.io.OutputStream;
import java.io.Writer;
import java.lang.ref.SoftReference;
import javax.xml.transform.Result;
import javax.xml.transform.Source;
import javax.xml.transform.stream.StreamResult;
import javax.xml.transform.stream.StreamSource;
import org.apache.xerces.impl.XMLEntityManager;
import org.apache.xerces.impl.XMLErrorReporter;
import org.apache.xerces.impl.msg.XMLMessageFormatter;
import org.apache.xerces.impl.xs.XMLSchemaValidator;
import org.apache.xerces.parsers.SAXParser;
import org.apache.xerces.parsers.XML11Configuration;
import org.apache.xerces.xni.XNIException;
import org.apache.xerces.xni.parser.XMLInputSource;
import org.apache.xerces.xni.parser.XMLParseException;
import org.apache.xerces.xni.parser.XMLParserConfiguration;

public final class StreamValidatorHelper implements ValidatorHelper {
    public static final String ENTITY_RESOLVER = "http://apache.org/xml/properties/internal/entity-resolver";
    public static final String ERROR_HANDLER = "http://apache.org/xml/properties/internal/error-handler";
    public static final String ERROR_REPORTER = "http://apache.org/xml/properties/internal/error-reporter";
    public static final String PARSER_SETTINGS = "http://apache.org/xml/features/internal/parser-settings";
    public static final String SCHEMA_VALIDATOR = "http://apache.org/xml/properties/internal/validator/schema";
    public static final String SECURITY_MANAGER = "http://apache.org/xml/properties/security-manager";
    public static final String SYMBOL_TABLE = "http://apache.org/xml/properties/internal/symbol-table";
    public static final String VALIDATION_MANAGER = "http://apache.org/xml/properties/internal/validation-manager";
    public final XMLSchemaValidatorComponentManager fComponentManager;
    public SoftReference fConfiguration = new SoftReference(null);
    public SoftReference fParser = new SoftReference(null);
    public final XMLSchemaValidator fSchemaValidator;
    public m fSerializerFactory;

    public StreamValidatorHelper(XMLSchemaValidatorComponentManager xMLSchemaValidatorComponentManager) {
        this.fComponentManager = xMLSchemaValidatorComponentManager;
        this.fSchemaValidator = (XMLSchemaValidator) xMLSchemaValidatorComponentManager.getProperty("http://apache.org/xml/properties/internal/validator/schema");
    }

    private XMLParserConfiguration initialize() {
        XML11Configuration xML11Configuration = new XML11Configuration();
        xML11Configuration.setProperty("http://apache.org/xml/properties/internal/entity-resolver", this.fComponentManager.getProperty("http://apache.org/xml/properties/internal/entity-resolver"));
        xML11Configuration.setProperty("http://apache.org/xml/properties/internal/error-handler", this.fComponentManager.getProperty("http://apache.org/xml/properties/internal/error-handler"));
        XMLErrorReporter xMLErrorReporter = (XMLErrorReporter) this.fComponentManager.getProperty("http://apache.org/xml/properties/internal/error-reporter");
        xML11Configuration.setProperty("http://apache.org/xml/properties/internal/error-reporter", xMLErrorReporter);
        if (xMLErrorReporter.getMessageFormatter("http://www.w3.org/TR/1998/REC-xml-19980210") == null) {
            XMLMessageFormatter xMLMessageFormatter = new XMLMessageFormatter();
            xMLErrorReporter.putMessageFormatter("http://www.w3.org/TR/1998/REC-xml-19980210", xMLMessageFormatter);
            xMLErrorReporter.putMessageFormatter(XMLMessageFormatter.XMLNS_DOMAIN, xMLMessageFormatter);
        }
        xML11Configuration.setProperty("http://apache.org/xml/properties/internal/symbol-table", this.fComponentManager.getProperty("http://apache.org/xml/properties/internal/symbol-table"));
        xML11Configuration.setProperty("http://apache.org/xml/properties/internal/validation-manager", this.fComponentManager.getProperty("http://apache.org/xml/properties/internal/validation-manager"));
        xML11Configuration.setProperty("http://apache.org/xml/properties/security-manager", this.fComponentManager.getProperty("http://apache.org/xml/properties/security-manager"));
        xML11Configuration.setDocumentHandler(this.fSchemaValidator);
        xML11Configuration.setDTDHandler(null);
        xML11Configuration.setDTDContentModelHandler(null);
        this.fConfiguration = new SoftReference(xML11Configuration);
        return xML11Configuration;
    }

    @Override // org.apache.xerces.jaxp.validation.ValidatorHelper
    public void validate(Source source, Result result) {
        a aVar;
        OutputStream outputStream;
        j jVar;
        m mVar;
        boolean z = false;
        if ((result instanceof StreamResult) || result == null) {
            StreamSource streamSource = (StreamSource) source;
            StreamResult streamResult = (StreamResult) result;
            XMLInputSource xMLInputSource = new XMLInputSource(streamSource.getPublicId(), streamSource.getSystemId(), null);
            xMLInputSource.setByteStream(streamSource.getInputStream());
            xMLInputSource.setCharacterStream(streamSource.getReader());
            XMLParserConfiguration xMLParserConfiguration = (XMLParserConfiguration) this.fConfiguration.get();
            if (xMLParserConfiguration == null) {
                xMLParserConfiguration = initialize();
                z = true;
            } else if (this.fComponentManager.getFeature("http://apache.org/xml/features/internal/parser-settings")) {
                xMLParserConfiguration.setProperty("http://apache.org/xml/properties/internal/entity-resolver", this.fComponentManager.getProperty("http://apache.org/xml/properties/internal/entity-resolver"));
                xMLParserConfiguration.setProperty("http://apache.org/xml/properties/internal/error-handler", this.fComponentManager.getProperty("http://apache.org/xml/properties/internal/error-handler"));
                xMLParserConfiguration.setProperty("http://apache.org/xml/properties/security-manager", this.fComponentManager.getProperty("http://apache.org/xml/properties/security-manager"));
            }
            this.fComponentManager.reset();
            if (streamResult != null) {
                if (this.fSerializerFactory == null) {
                    this.fSerializerFactory = (m) m.a.get("xml");
                }
                if (streamResult.getWriter() != null) {
                    m mVar2 = this.fSerializerFactory;
                    Writer writer = streamResult.getWriter();
                    aVar = ((n) mVar2).a(new j());
                    aVar.a(writer);
                } else {
                    if (streamResult.getOutputStream() != null) {
                        mVar = this.fSerializerFactory;
                        outputStream = streamResult.getOutputStream();
                        jVar = new j();
                    } else if (streamResult.getSystemId() != null) {
                        outputStream = XMLEntityManager.createOutputStream(streamResult.getSystemId());
                        mVar = this.fSerializerFactory;
                        jVar = new j();
                    } else {
                        throw new IllegalArgumentException(JAXPValidationMessageFormatter.formatMessage(this.fComponentManager.getLocale(), "StreamResultNotInitialized", null));
                    }
                    aVar = ((n) mVar).a(jVar);
                    aVar.a(outputStream);
                }
                SAXParser sAXParser = (SAXParser) this.fParser.get();
                if (z || sAXParser == null) {
                    sAXParser = new SAXParser(xMLParserConfiguration);
                    this.fParser = new SoftReference(sAXParser);
                } else {
                    sAXParser.reset();
                }
                xMLParserConfiguration.setDocumentHandler(this.fSchemaValidator);
                this.fSchemaValidator.setDocumentHandler(sAXParser);
                aVar.e();
                sAXParser.setContentHandler(aVar);
            } else {
                this.fSchemaValidator.setDocumentHandler(null);
            }
            try {
                xMLParserConfiguration.parse(xMLInputSource);
                this.fSchemaValidator.setDocumentHandler(null);
            } catch (XMLParseException e2) {
                throw Util.toSAXParseException(e2);
            } catch (XNIException e3) {
                throw Util.toSAXException(e3);
            } catch (Throwable th) {
                this.fSchemaValidator.setDocumentHandler(null);
                throw th;
            }
        } else {
            throw new IllegalArgumentException(JAXPValidationMessageFormatter.formatMessage(this.fComponentManager.getLocale(), "SourceResultMismatch", new Object[]{source.getClass().getName(), result.getClass().getName()}));
        }
    }
}
