package org.apache.xerces.parsers;

import java.util.Locale;
import java.util.Stack;
import org.apache.poi.ss.formula.ptg.PercentPtg;
import org.apache.poi.ss.formula.ptg.StringPtg;
import org.apache.xerces.dom.AttrImpl;
import org.apache.xerces.dom.CoreDocumentImpl;
import org.apache.xerces.dom.DOMErrorImpl;
import org.apache.xerces.dom.DOMMessageFormatter;
import org.apache.xerces.dom.DeferredDocumentImpl;
import org.apache.xerces.dom.DocumentImpl;
import org.apache.xerces.dom.DocumentTypeImpl;
import org.apache.xerces.dom.ElementDefinitionImpl;
import org.apache.xerces.dom.ElementImpl;
import org.apache.xerces.dom.ElementNSImpl;
import org.apache.xerces.dom.EntityImpl;
import org.apache.xerces.dom.EntityReferenceImpl;
import org.apache.xerces.dom.NodeImpl;
import org.apache.xerces.dom.NotationImpl;
import org.apache.xerces.dom.PSVIAttrNSImpl;
import org.apache.xerces.dom.PSVIDocumentImpl;
import org.apache.xerces.dom.PSVIElementNSImpl;
import org.apache.xerces.dom.TextImpl;
import org.apache.xerces.impl.Constants;
import org.apache.xerces.impl.dv.XSSimpleType;
import org.apache.xerces.impl.xs.SchemaSymbols;
import org.apache.xerces.util.DOMErrorHandlerWrapper;
import org.apache.xerces.xni.Augmentations;
import org.apache.xerces.xni.NamespaceContext;
import org.apache.xerces.xni.QName;
import org.apache.xerces.xni.XMLAttributes;
import org.apache.xerces.xni.XMLLocator;
import org.apache.xerces.xni.XMLResourceIdentifier;
import org.apache.xerces.xni.XMLString;
import org.apache.xerces.xni.parser.XMLParserConfiguration;
import org.apache.xerces.xs.AttributePSVI;
import org.apache.xerces.xs.ElementPSVI;
import org.apache.xerces.xs.XSSimpleTypeDefinition;
import org.apache.xerces.xs.XSTypeDefinition;
import org.apache.xmlbeans.impl.common.Sax2Dom;
import org.w3c.dom.Attr;
import org.w3c.dom.CDATASection;
import org.w3c.dom.Comment;
import org.w3c.dom.Document;
import org.w3c.dom.DocumentType;
import org.w3c.dom.Element;
import org.w3c.dom.EntityReference;
import org.w3c.dom.NamedNodeMap;
import org.w3c.dom.Node;
import org.w3c.dom.NodeList;
import org.w3c.dom.ProcessingInstruction;
import org.w3c.dom.Text;
import org.w3c.dom.ls.LSParserFilter;

public class AbstractDOMParser extends AbstractXMLDocumentParser {
    public static final String CORE_DOCUMENT_CLASS_NAME = "org.apache.xerces.dom.CoreDocumentImpl";
    public static final String CREATE_CDATA_NODES_FEATURE = "http://apache.org/xml/features/create-cdata-nodes";
    public static final String CREATE_ENTITY_REF_NODES = "http://apache.org/xml/features/dom/create-entity-ref-nodes";
    public static final String CURRENT_ELEMENT_NODE = "http://apache.org/xml/properties/dom/current-element-node";
    public static final boolean DEBUG_BASEURI = false;
    public static final boolean DEBUG_EVENTS = false;
    public static final String DEFAULT_DOCUMENT_CLASS_NAME = "org.apache.xerces.dom.DocumentImpl";
    public static final String DEFER_NODE_EXPANSION = "http://apache.org/xml/features/dom/defer-node-expansion";
    public static final String DOCUMENT_CLASS_NAME = "http://apache.org/xml/properties/dom/document-class-name";
    public static final String INCLUDE_COMMENTS_FEATURE = "http://apache.org/xml/features/include-comments";
    public static final String INCLUDE_IGNORABLE_WHITESPACE = "http://apache.org/xml/features/dom/include-ignorable-whitespace";
    public static final String NAMESPACES = "http://xml.org/sax/features/namespaces";
    public static final String PSVI_DOCUMENT_CLASS_NAME = "org.apache.xerces.dom.PSVIDocumentImpl";
    public static final String[] RECOGNIZED_FEATURES = {"http://xml.org/sax/features/namespaces", "http://apache.org/xml/features/dom/create-entity-ref-nodes", "http://apache.org/xml/features/include-comments", "http://apache.org/xml/features/create-cdata-nodes", "http://apache.org/xml/features/dom/include-ignorable-whitespace", DEFER_NODE_EXPANSION};
    public static final String[] RECOGNIZED_PROPERTIES = {DOCUMENT_CLASS_NAME, "http://apache.org/xml/properties/dom/current-element-node"};
    public static /* synthetic */ Class class$org$w3c$dom$Document;
    public final QName fAttrQName = new QName();
    public final Stack fBaseURIStack = new Stack();
    public boolean fCreateCDATANodes;
    public boolean fCreateEntityRefNodes;
    public CDATASection fCurrentCDATASection;
    public int fCurrentCDATASectionIndex;
    public EntityImpl fCurrentEntityDecl;
    public Node fCurrentNode;
    public int fCurrentNodeIndex;
    public LSParserFilter fDOMFilter = null;
    public boolean fDeferNodeExpansion;
    public DeferredDocumentImpl fDeferredDocumentImpl;
    public int fDeferredEntityDecl;
    public Document fDocument;
    public String fDocumentClassName;
    public CoreDocumentImpl fDocumentImpl;
    public int fDocumentIndex;
    public DocumentType fDocumentType;
    public int fDocumentTypeIndex;
    public DOMErrorHandlerWrapper fErrorHandler = null;
    public boolean fFilterReject = false;
    public boolean fFirstChunk = false;
    public boolean fInCDATASection;
    public boolean fInDTD;
    public boolean fInDTDExternalSubset;
    public boolean fInEntityRef = false;
    public boolean fIncludeComments;
    public boolean fIncludeIgnorableWhitespace;
    public StringBuffer fInternalSubset;
    public XMLLocator fLocator;
    public boolean fNamespaceAware;
    public int fRejectedElementDepth = 0;
    public Node fRoot;
    public Stack fSkippedElemStack = null;
    public boolean fStorePSVI;
    public final StringBuffer fStringBuffer = new StringBuffer(50);

    public static final class Abort extends RuntimeException {
        public static final Abort INSTANCE = new Abort();
        public static final long serialVersionUID = 1687848994976808490L;

        public Throwable fillInStackTrace() {
            return this;
        }
    }

    public AbstractDOMParser(XMLParserConfiguration xMLParserConfiguration) {
        super(xMLParserConfiguration);
        this.fConfiguration.addRecognizedFeatures(RECOGNIZED_FEATURES);
        this.fConfiguration.setFeature("http://apache.org/xml/features/dom/create-entity-ref-nodes", true);
        this.fConfiguration.setFeature("http://apache.org/xml/features/dom/include-ignorable-whitespace", true);
        this.fConfiguration.setFeature(DEFER_NODE_EXPANSION, true);
        this.fConfiguration.setFeature("http://apache.org/xml/features/include-comments", true);
        this.fConfiguration.setFeature("http://apache.org/xml/features/create-cdata-nodes", true);
        this.fConfiguration.addRecognizedProperties(RECOGNIZED_PROPERTIES);
        this.fConfiguration.setProperty(DOCUMENT_CLASS_NAME, DEFAULT_DOCUMENT_CLASS_NAME);
    }

    public static /* synthetic */ Class class$(String str) {
        try {
            return Class.forName(str);
        } catch (ClassNotFoundException e2) {
            throw new NoClassDefFoundError(e2.getMessage());
        }
    }

    public void abort() {
        throw Abort.INSTANCE;
    }

    @Override // org.apache.xerces.xni.XMLDTDHandler, org.apache.xerces.parsers.AbstractXMLDocumentParser
    public void attributeDecl(String str, String str2, String str3, String[] strArr, String str4, XMLString xMLString, XMLString xMLString2, Augmentations augmentations) {
        Attr attr;
        StringBuffer stringBuffer = this.fInternalSubset;
        if (stringBuffer != null && !this.fInDTDExternalSubset) {
            stringBuffer.append("<!ATTLIST ");
            this.fInternalSubset.append(str);
            this.fInternalSubset.append(' ');
            this.fInternalSubset.append(str2);
            this.fInternalSubset.append(' ');
            if (str3.equals("ENUMERATION")) {
                this.fInternalSubset.append('(');
                for (int i2 = 0; i2 < strArr.length; i2++) {
                    if (i2 > 0) {
                        this.fInternalSubset.append('|');
                    }
                    this.fInternalSubset.append(strArr[i2]);
                }
                this.fInternalSubset.append(')');
            } else {
                this.fInternalSubset.append(str3);
            }
            if (str4 != null) {
                this.fInternalSubset.append(' ');
                this.fInternalSubset.append(str4);
            }
            if (xMLString != null) {
                this.fInternalSubset.append(" '");
                for (int i3 = 0; i3 < xMLString.length; i3++) {
                    char c = xMLString.ch[xMLString.offset + i3];
                    if (c == '\'') {
                        this.fInternalSubset.append("&apos;");
                    } else {
                        this.fInternalSubset.append(c);
                    }
                }
                this.fInternalSubset.append('\'');
            }
            this.fInternalSubset.append(">\n");
        }
        DeferredDocumentImpl deferredDocumentImpl = this.fDeferredDocumentImpl;
        String str5 = null;
        if (deferredDocumentImpl != null) {
            if (xMLString != null) {
                int lookupElementDefinition = deferredDocumentImpl.lookupElementDefinition(str);
                if (lookupElementDefinition == -1) {
                    lookupElementDefinition = this.fDeferredDocumentImpl.createDeferredElementDefinition(str);
                    this.fDeferredDocumentImpl.appendChild(this.fDocumentTypeIndex, lookupElementDefinition);
                }
                if (this.fNamespaceAware) {
                    if (str2.startsWith(Sax2Dom.XMLNS_STRING) || str2.equals("xmlns")) {
                        str5 = NamespaceContext.XMLNS_URI;
                    } else if (str2.startsWith("xml:")) {
                        str5 = NamespaceContext.XML_URI;
                    }
                }
                int createDeferredAttribute = this.fDeferredDocumentImpl.createDeferredAttribute(str2, str5, xMLString.toString(), false);
                if (SchemaSymbols.ATTVAL_ID.equals(str3)) {
                    this.fDeferredDocumentImpl.setIdAttribute(createDeferredAttribute);
                }
                this.fDeferredDocumentImpl.appendChild(lookupElementDefinition, createDeferredAttribute);
            }
        } else if (this.fDocumentImpl != null && xMLString != null) {
            ElementDefinitionImpl elementDefinitionImpl = (ElementDefinitionImpl) ((DocumentTypeImpl) this.fDocumentType).getElements().getNamedItem(str);
            if (elementDefinitionImpl == null) {
                elementDefinitionImpl = this.fDocumentImpl.createElementDefinition(str);
                ((DocumentTypeImpl) this.fDocumentType).getElements().setNamedItem(elementDefinitionImpl);
            }
            boolean z = this.fNamespaceAware;
            if (z) {
                if (str2.startsWith(Sax2Dom.XMLNS_STRING) || str2.equals("xmlns")) {
                    str5 = NamespaceContext.XMLNS_URI;
                } else if (str2.startsWith("xml:")) {
                    str5 = NamespaceContext.XML_URI;
                }
                attr = this.fDocumentImpl.createAttributeNS(str5, str2);
            } else {
                attr = this.fDocumentImpl.createAttribute(str2);
            }
            AttrImpl attrImpl = (AttrImpl) attr;
            attrImpl.setValue(xMLString.toString());
            attrImpl.setSpecified(false);
            attrImpl.setIdAttribute(SchemaSymbols.ATTVAL_ID.equals(str3));
            if (z) {
                elementDefinitionImpl.getAttributes().setNamedItemNS(attrImpl);
            } else {
                elementDefinitionImpl.getAttributes().setNamedItem(attrImpl);
            }
        }
    }

    @Override // org.apache.xerces.xni.XMLDocumentHandler, org.apache.xerces.parsers.AbstractXMLDocumentParser
    public void characters(XMLString xMLString, Augmentations augmentations) {
        DeferredDocumentImpl deferredDocumentImpl;
        String str;
        if (this.fDeferNodeExpansion) {
            if (!this.fInCDATASection || !this.fCreateCDATANodes) {
                if (!this.fInDTD && xMLString.length != 0) {
                    str = xMLString.toString();
                    deferredDocumentImpl = this.fDeferredDocumentImpl;
                } else {
                    return;
                }
            } else if (this.fCurrentCDATASectionIndex == -1) {
                int createDeferredCDATASection = this.fDeferredDocumentImpl.createDeferredCDATASection(xMLString.toString());
                this.fDeferredDocumentImpl.appendChild(this.fCurrentNodeIndex, createDeferredCDATASection);
                this.fCurrentCDATASectionIndex = createDeferredCDATASection;
                this.fCurrentNodeIndex = createDeferredCDATASection;
                return;
            } else {
                deferredDocumentImpl = this.fDeferredDocumentImpl;
                str = xMLString.toString();
            }
            this.fDeferredDocumentImpl.appendChild(this.fCurrentNodeIndex, deferredDocumentImpl.createDeferredTextNode(str, false));
        } else if (!this.fFilterReject) {
            if (this.fInCDATASection && this.fCreateCDATANodes) {
                CDATASection cDATASection = this.fCurrentCDATASection;
                if (cDATASection == null) {
                    CDATASection createCDATASection = this.fDocument.createCDATASection(xMLString.toString());
                    this.fCurrentCDATASection = createCDATASection;
                    this.fCurrentNode.appendChild(createCDATASection);
                    this.fCurrentNode = this.fCurrentCDATASection;
                    return;
                }
                cDATASection.appendData(xMLString.toString());
            } else if (!this.fInDTD && xMLString.length != 0) {
                Node lastChild = this.fCurrentNode.getLastChild();
                if (lastChild == null || lastChild.getNodeType() != 3) {
                    this.fFirstChunk = true;
                    this.fCurrentNode.appendChild(this.fDocument.createTextNode(xMLString.toString()));
                    return;
                }
                if (this.fFirstChunk) {
                    if (this.fDocumentImpl != null) {
                        this.fStringBuffer.append(((TextImpl) lastChild).removeData());
                    } else {
                        Text text = (Text) lastChild;
                        this.fStringBuffer.append(text.getData());
                        text.setNodeValue(null);
                    }
                    this.fFirstChunk = false;
                }
                int i2 = xMLString.length;
                if (i2 > 0) {
                    this.fStringBuffer.append(xMLString.ch, xMLString.offset, i2);
                }
            }
        }
    }

    @Override // org.apache.xerces.xni.XMLDocumentHandler, org.apache.xerces.xni.XMLDTDHandler, org.apache.xerces.parsers.AbstractXMLDocumentParser
    public void comment(XMLString xMLString, Augmentations augmentations) {
        if (this.fInDTD) {
            StringBuffer stringBuffer = this.fInternalSubset;
            if (stringBuffer != null && !this.fInDTDExternalSubset) {
                stringBuffer.append("<!--");
                int i2 = xMLString.length;
                if (i2 > 0) {
                    this.fInternalSubset.append(xMLString.ch, xMLString.offset, i2);
                }
                this.fInternalSubset.append("-->");
            }
        } else if (this.fIncludeComments && !this.fFilterReject) {
            if (!this.fDeferNodeExpansion) {
                Comment createComment = this.fDocument.createComment(xMLString.toString());
                setCharacterData(false);
                this.fCurrentNode.appendChild(createComment);
                LSParserFilter lSParserFilter = this.fDOMFilter;
                if (lSParserFilter != null && !this.fInEntityRef && (lSParserFilter.getWhatToShow() & 128) != 0) {
                    short acceptNode = this.fDOMFilter.acceptNode(createComment);
                    if (acceptNode == 2 || acceptNode == 3) {
                        this.fCurrentNode.removeChild(createComment);
                        this.fFirstChunk = true;
                    } else if (acceptNode == 4) {
                        throw Abort.INSTANCE;
                    }
                }
            } else {
                this.fDeferredDocumentImpl.appendChild(this.fCurrentNodeIndex, this.fDeferredDocumentImpl.createDeferredComment(xMLString.toString()));
            }
        }
    }

    public Attr createAttrNode(QName qName) {
        if (!this.fNamespaceAware) {
            return this.fDocument.createAttribute(qName.rawname);
        }
        CoreDocumentImpl coreDocumentImpl = this.fDocumentImpl;
        return coreDocumentImpl != null ? coreDocumentImpl.createAttributeNS(qName.uri, qName.rawname, qName.localpart) : this.fDocument.createAttributeNS(qName.uri, qName.rawname);
    }

    public Element createElementNode(QName qName) {
        if (!this.fNamespaceAware) {
            return this.fDocument.createElement(qName.rawname);
        }
        CoreDocumentImpl coreDocumentImpl = this.fDocumentImpl;
        return coreDocumentImpl != null ? coreDocumentImpl.createElementNS(qName.uri, qName.rawname, qName.localpart) : this.fDocument.createElementNS(qName.uri, qName.rawname);
    }

    @Override // org.apache.xerces.xni.XMLDocumentHandler, org.apache.xerces.parsers.AbstractXMLDocumentParser
    public void doctypeDecl(String str, String str2, String str3, Augmentations augmentations) {
        if (!this.fDeferNodeExpansion) {
            CoreDocumentImpl coreDocumentImpl = this.fDocumentImpl;
            if (coreDocumentImpl != null) {
                DocumentType createDocumentType = coreDocumentImpl.createDocumentType(str, str2, str3);
                this.fDocumentType = createDocumentType;
                this.fCurrentNode.appendChild(createDocumentType);
                return;
            }
            return;
        }
        int createDeferredDocumentType = this.fDeferredDocumentImpl.createDeferredDocumentType(str, str2, str3);
        this.fDocumentTypeIndex = createDeferredDocumentType;
        this.fDeferredDocumentImpl.appendChild(this.fCurrentNodeIndex, createDeferredDocumentType);
    }

    public final void dropDocumentReferences() {
        this.fDocument = null;
        this.fDocumentImpl = null;
        this.fDeferredDocumentImpl = null;
        this.fDocumentType = null;
        this.fCurrentNode = null;
        this.fCurrentCDATASection = null;
        this.fCurrentEntityDecl = null;
        this.fRoot = null;
    }

    @Override // org.apache.xerces.xni.XMLDTDHandler, org.apache.xerces.parsers.AbstractXMLDocumentParser
    public void elementDecl(String str, String str2, Augmentations augmentations) {
        StringBuffer stringBuffer = this.fInternalSubset;
        if (stringBuffer != null && !this.fInDTDExternalSubset) {
            stringBuffer.append("<!ELEMENT ");
            this.fInternalSubset.append(str);
            this.fInternalSubset.append(' ');
            this.fInternalSubset.append(str2);
            this.fInternalSubset.append(">\n");
        }
    }

    @Override // org.apache.xerces.xni.XMLDocumentHandler, org.apache.xerces.parsers.AbstractXMLDocumentParser
    public void emptyElement(QName qName, XMLAttributes xMLAttributes, Augmentations augmentations) {
        startElement(qName, xMLAttributes, augmentations);
        endElement(qName, augmentations);
    }

    @Override // org.apache.xerces.xni.XMLDTDHandler, org.apache.xerces.parsers.AbstractXMLDocumentParser
    public void endAttlist(Augmentations augmentations) {
    }

    @Override // org.apache.xerces.xni.XMLDocumentHandler, org.apache.xerces.parsers.AbstractXMLDocumentParser
    public void endCDATA(Augmentations augmentations) {
        this.fInCDATASection = false;
        if (!this.fDeferNodeExpansion) {
            if (!this.fFilterReject && this.fCurrentCDATASection != null) {
                LSParserFilter lSParserFilter = this.fDOMFilter;
                if (!(lSParserFilter == null || this.fInEntityRef || (lSParserFilter.getWhatToShow() & 8) == 0)) {
                    short acceptNode = this.fDOMFilter.acceptNode(this.fCurrentCDATASection);
                    if (acceptNode == 2 || acceptNode == 3) {
                        Node parentNode = this.fCurrentNode.getParentNode();
                        parentNode.removeChild(this.fCurrentCDATASection);
                        this.fCurrentNode = parentNode;
                        return;
                    } else if (acceptNode == 4) {
                        throw Abort.INSTANCE;
                    }
                }
                this.fCurrentNode = this.fCurrentNode.getParentNode();
                this.fCurrentCDATASection = null;
            }
        } else if (this.fCurrentCDATASectionIndex != -1) {
            this.fCurrentNodeIndex = this.fDeferredDocumentImpl.getParentNode(this.fCurrentNodeIndex, false);
            this.fCurrentCDATASectionIndex = -1;
        }
    }

    @Override // org.apache.xerces.xni.XMLDTDHandler, org.apache.xerces.parsers.AbstractXMLDocumentParser
    public void endConditional(Augmentations augmentations) {
    }

    @Override // org.apache.xerces.xni.XMLDTDHandler, org.apache.xerces.parsers.AbstractXMLDocumentParser
    public void endDTD(Augmentations augmentations) {
        this.fInDTD = false;
        if (!this.fBaseURIStack.isEmpty()) {
            this.fBaseURIStack.pop();
        }
        StringBuffer stringBuffer = this.fInternalSubset;
        String stringBuffer2 = (stringBuffer == null || stringBuffer.length() <= 0) ? null : this.fInternalSubset.toString();
        if (this.fDeferNodeExpansion) {
            if (stringBuffer2 != null) {
                this.fDeferredDocumentImpl.setInternalSubset(this.fDocumentTypeIndex, stringBuffer2);
            }
        } else if (this.fDocumentImpl != null && stringBuffer2 != null) {
            ((DocumentTypeImpl) this.fDocumentType).setInternalSubset(stringBuffer2);
        }
    }

    @Override // org.apache.xerces.xni.XMLDocumentHandler, org.apache.xerces.parsers.AbstractXMLDocumentParser
    public void endDocument(Augmentations augmentations) {
        if (!this.fDeferNodeExpansion) {
            CoreDocumentImpl coreDocumentImpl = this.fDocumentImpl;
            if (coreDocumentImpl != null) {
                XMLLocator xMLLocator = this.fLocator;
                if (xMLLocator != null) {
                    coreDocumentImpl.setInputEncoding(xMLLocator.getEncoding());
                }
                this.fDocumentImpl.setStrictErrorChecking(true);
            }
            this.fCurrentNode = null;
            return;
        }
        XMLLocator xMLLocator2 = this.fLocator;
        if (xMLLocator2 != null) {
            this.fDeferredDocumentImpl.setInputEncoding(xMLLocator2.getEncoding());
        }
        this.fCurrentNodeIndex = -1;
    }

    @Override // org.apache.xerces.xni.XMLDocumentHandler, org.apache.xerces.parsers.AbstractXMLDocumentParser
    public void endElement(QName qName, Augmentations augmentations) {
        ElementPSVI elementPSVI;
        Node parentNode;
        ElementPSVI elementPSVI2;
        if (!this.fDeferNodeExpansion) {
            if (!(augmentations == null || this.fDocumentImpl == null || (!(this.fNamespaceAware || this.fStorePSVI) || (elementPSVI2 = (ElementPSVI) augmentations.getItem(Constants.ELEMENT_PSVI)) == null))) {
                if (this.fNamespaceAware) {
                    XSTypeDefinition memberTypeDefinition = elementPSVI2.getMemberTypeDefinition();
                    if (memberTypeDefinition == null) {
                        memberTypeDefinition = elementPSVI2.getTypeDefinition();
                    }
                    ((ElementNSImpl) this.fCurrentNode).setType(memberTypeDefinition);
                }
                if (this.fStorePSVI) {
                    ((PSVIElementNSImpl) this.fCurrentNode).setPSVI(elementPSVI2);
                }
            }
            if (this.fDOMFilter == null) {
                setCharacterData(false);
            } else if (this.fFilterReject) {
                int i2 = this.fRejectedElementDepth;
                this.fRejectedElementDepth = i2 - 1;
                if (i2 == 0) {
                    this.fFilterReject = false;
                    return;
                }
                return;
            } else if (this.fSkippedElemStack.isEmpty() || this.fSkippedElemStack.pop() != Boolean.TRUE) {
                setCharacterData(false);
                if (!(this.fCurrentNode == this.fRoot || this.fInEntityRef || (this.fDOMFilter.getWhatToShow() & 1) == 0)) {
                    short acceptNode = this.fDOMFilter.acceptNode(this.fCurrentNode);
                    if (acceptNode == 2) {
                        parentNode = this.fCurrentNode.getParentNode();
                    } else if (acceptNode == 3) {
                        this.fFirstChunk = true;
                        parentNode = this.fCurrentNode.getParentNode();
                        NodeList childNodes = this.fCurrentNode.getChildNodes();
                        int length = childNodes.getLength();
                        for (int i3 = 0; i3 < length; i3++) {
                            parentNode.appendChild(childNodes.item(0));
                        }
                    } else if (acceptNode == 4) {
                        throw Abort.INSTANCE;
                    }
                    parentNode.removeChild(this.fCurrentNode);
                    this.fCurrentNode = parentNode;
                    return;
                }
            } else {
                return;
            }
            this.fCurrentNode = this.fCurrentNode.getParentNode();
            return;
        }
        if (!(augmentations == null || (elementPSVI = (ElementPSVI) augmentations.getItem(Constants.ELEMENT_PSVI)) == null)) {
            XSTypeDefinition memberTypeDefinition2 = elementPSVI.getMemberTypeDefinition();
            if (memberTypeDefinition2 == null) {
                memberTypeDefinition2 = elementPSVI.getTypeDefinition();
            }
            this.fDeferredDocumentImpl.setTypeInfo(this.fCurrentNodeIndex, memberTypeDefinition2);
        }
        this.fCurrentNodeIndex = this.fDeferredDocumentImpl.getParentNode(this.fCurrentNodeIndex, false);
    }

    @Override // org.apache.xerces.xni.XMLDTDHandler, org.apache.xerces.parsers.AbstractXMLDocumentParser
    public void endExternalSubset(Augmentations augmentations) {
        this.fInDTDExternalSubset = false;
        this.fBaseURIStack.pop();
    }

    /* JADX WARNING: Removed duplicated region for block: B:43:0x00b1  */
    @Override // org.apache.xerces.xni.XMLDocumentHandler, org.apache.xerces.parsers.AbstractXMLDocumentParser
    public void endGeneralEntity(String str, Augmentations augmentations) {
        boolean z;
        int length;
        if (this.fDeferNodeExpansion) {
            int i2 = this.fDocumentTypeIndex;
            if (i2 != -1) {
                int lastChild = this.fDeferredDocumentImpl.getLastChild(i2, false);
                while (true) {
                    if (lastChild == -1) {
                        break;
                    }
                    if (this.fDeferredDocumentImpl.getNodeType(lastChild, false) == 6 && this.fDeferredDocumentImpl.getNodeName(lastChild, false).equals(str)) {
                        this.fDeferredEntityDecl = lastChild;
                        break;
                    }
                    lastChild = this.fDeferredDocumentImpl.getRealPrevSibling(lastChild, false);
                }
            }
            int i3 = this.fDeferredEntityDecl;
            if (i3 != -1 && this.fDeferredDocumentImpl.getLastChild(i3, false) == -1) {
                int lastChild2 = this.fDeferredDocumentImpl.getLastChild(this.fCurrentNodeIndex, false);
                int i4 = -1;
                while (lastChild2 != -1) {
                    int cloneNode = this.fDeferredDocumentImpl.cloneNode(lastChild2, true);
                    this.fDeferredDocumentImpl.insertBefore(this.fDeferredEntityDecl, cloneNode, i4);
                    lastChild2 = this.fDeferredDocumentImpl.getRealPrevSibling(lastChild2, false);
                    i4 = cloneNode;
                }
            }
            if (this.fCreateEntityRefNodes) {
                this.fCurrentNodeIndex = this.fDeferredDocumentImpl.getParentNode(this.fCurrentNodeIndex, false);
            } else {
                int lastChild3 = this.fDeferredDocumentImpl.getLastChild(this.fCurrentNodeIndex, false);
                int parentNode = this.fDeferredDocumentImpl.getParentNode(this.fCurrentNodeIndex, false);
                int i5 = this.fCurrentNodeIndex;
                int i6 = lastChild3;
                while (i6 != -1) {
                    handleBaseURI(i6);
                    int realPrevSibling = this.fDeferredDocumentImpl.getRealPrevSibling(i6, false);
                    this.fDeferredDocumentImpl.insertBefore(parentNode, i6, i5);
                    i5 = i6;
                    i6 = realPrevSibling;
                }
                if (lastChild3 == -1) {
                    lastChild3 = this.fDeferredDocumentImpl.getRealPrevSibling(i5, false);
                }
                this.fDeferredDocumentImpl.setAsLastChild(parentNode, lastChild3);
                this.fCurrentNodeIndex = parentNode;
            }
            this.fDeferredEntityDecl = -1;
        } else if (!this.fFilterReject) {
            setCharacterData(true);
            DocumentType documentType = this.fDocumentType;
            if (documentType != null) {
                EntityImpl entityImpl = (EntityImpl) documentType.getEntities().getNamedItem(str);
                this.fCurrentEntityDecl = entityImpl;
                if (entityImpl != null) {
                    if (entityImpl != null && entityImpl.getFirstChild() == null) {
                        this.fCurrentEntityDecl.setReadOnly(false, true);
                        for (Node firstChild = this.fCurrentNode.getFirstChild(); firstChild != null; firstChild = firstChild.getNextSibling()) {
                            this.fCurrentEntityDecl.appendChild(firstChild.cloneNode(true));
                        }
                        this.fCurrentEntityDecl.setReadOnly(true, true);
                    }
                    this.fCurrentEntityDecl = null;
                }
            }
            this.fInEntityRef = false;
            if (this.fCreateEntityRefNodes) {
                if (this.fDocumentImpl != null) {
                    ((NodeImpl) this.fCurrentNode).setReadOnly(true, true);
                }
                LSParserFilter lSParserFilter = this.fDOMFilter;
                if (!(lSParserFilter == null || (lSParserFilter.getWhatToShow() & 16) == 0)) {
                    short acceptNode = this.fDOMFilter.acceptNode(this.fCurrentNode);
                    if (acceptNode == 2) {
                        Node parentNode2 = this.fCurrentNode.getParentNode();
                        parentNode2.removeChild(this.fCurrentNode);
                        this.fCurrentNode = parentNode2;
                        return;
                    } else if (acceptNode == 3) {
                        this.fFirstChunk = true;
                        z = true;
                        if (this.fCreateEntityRefNodes || z) {
                            NodeList childNodes = this.fCurrentNode.getChildNodes();
                            Node parentNode3 = this.fCurrentNode.getParentNode();
                            length = childNodes.getLength();
                            if (length > 0) {
                                Node previousSibling = this.fCurrentNode.getPreviousSibling();
                                Node item = childNodes.item(0);
                                if (previousSibling != null && previousSibling.getNodeType() == 3 && item.getNodeType() == 3) {
                                    ((Text) previousSibling).appendData(item.getNodeValue());
                                    this.fCurrentNode.removeChild(item);
                                } else {
                                    handleBaseURI(parentNode3.insertBefore(item, this.fCurrentNode));
                                }
                                for (int i7 = 1; i7 < length; i7++) {
                                    handleBaseURI(parentNode3.insertBefore(childNodes.item(0), this.fCurrentNode));
                                }
                            }
                            parentNode3.removeChild(this.fCurrentNode);
                            this.fCurrentNode = parentNode3;
                        }
                        return;
                    } else if (acceptNode == 4) {
                        throw Abort.INSTANCE;
                    }
                }
                this.fCurrentNode = this.fCurrentNode.getParentNode();
            }
            z = false;
            if (this.fCreateEntityRefNodes) {
            }
            NodeList childNodes2 = this.fCurrentNode.getChildNodes();
            Node parentNode32 = this.fCurrentNode.getParentNode();
            length = childNodes2.getLength();
            if (length > 0) {
            }
            parentNode32.removeChild(this.fCurrentNode);
            this.fCurrentNode = parentNode32;
        }
    }

    @Override // org.apache.xerces.xni.XMLDTDHandler, org.apache.xerces.parsers.AbstractXMLDocumentParser
    public void endParameterEntity(String str, Augmentations augmentations) {
        this.fBaseURIStack.pop();
    }

    @Override // org.apache.xerces.xni.XMLDTDHandler, org.apache.xerces.parsers.AbstractXMLDocumentParser
    public void externalEntityDecl(String str, XMLResourceIdentifier xMLResourceIdentifier, Augmentations augmentations) {
        String str2;
        String publicId = xMLResourceIdentifier.getPublicId();
        String literalSystemId = xMLResourceIdentifier.getLiteralSystemId();
        StringBuffer stringBuffer = this.fInternalSubset;
        boolean z = true;
        if (stringBuffer != null && !this.fInDTDExternalSubset) {
            stringBuffer.append("<!ENTITY ");
            if (str.startsWith(PercentPtg.PERCENT)) {
                this.fInternalSubset.append("% ");
                this.fInternalSubset.append(str.substring(1));
            } else {
                this.fInternalSubset.append(str);
            }
            this.fInternalSubset.append(' ');
            StringBuffer stringBuffer2 = this.fInternalSubset;
            if (publicId != null) {
                stringBuffer2.append("PUBLIC '");
                this.fInternalSubset.append(publicId);
                stringBuffer2 = this.fInternalSubset;
                str2 = "' '";
            } else {
                str2 = "SYSTEM '";
            }
            stringBuffer2.append(str2);
            this.fInternalSubset.append(literalSystemId);
            this.fInternalSubset.append("'>\n");
        }
        if (!str.startsWith(PercentPtg.PERCENT)) {
            DocumentType documentType = this.fDocumentType;
            if (documentType != null) {
                NamedNodeMap entities = documentType.getEntities();
                if (((EntityImpl) entities.getNamedItem(str)) == null) {
                    EntityImpl entityImpl = (EntityImpl) this.fDocumentImpl.createEntity(str);
                    entityImpl.setPublicId(publicId);
                    entityImpl.setSystemId(literalSystemId);
                    entityImpl.setBaseURI(xMLResourceIdentifier.getBaseSystemId());
                    entities.setNamedItem(entityImpl);
                }
            }
            int i2 = this.fDocumentTypeIndex;
            if (i2 != -1) {
                int lastChild = this.fDeferredDocumentImpl.getLastChild(i2, false);
                while (true) {
                    if (lastChild != -1) {
                        if (this.fDeferredDocumentImpl.getNodeType(lastChild, false) == 6 && this.fDeferredDocumentImpl.getNodeName(lastChild, false).equals(str)) {
                            break;
                        }
                        lastChild = this.fDeferredDocumentImpl.getRealPrevSibling(lastChild, false);
                    } else {
                        z = false;
                        break;
                    }
                }
                if (!z) {
                    this.fDeferredDocumentImpl.appendChild(this.fDocumentTypeIndex, this.fDeferredDocumentImpl.createDeferredEntity(str, publicId, literalSystemId, null, xMLResourceIdentifier.getBaseSystemId()));
                }
            }
        }
    }

    public Document getDocument() {
        return this.fDocument;
    }

    public String getDocumentClassName() {
        return this.fDocumentClassName;
    }

    public final void handleBaseURI(int i2) {
        short nodeType = this.fDeferredDocumentImpl.getNodeType(i2, false);
        if (nodeType == 1) {
            String nodeValueString = this.fDeferredDocumentImpl.getNodeValueString(this.fCurrentNodeIndex, false);
            if (nodeValueString == null) {
                nodeValueString = this.fDeferredDocumentImpl.getDeferredEntityBaseURI(this.fDeferredEntityDecl);
            }
            if (nodeValueString != null && !nodeValueString.equals(this.fDeferredDocumentImpl.getDocumentURI())) {
                this.fDeferredDocumentImpl.setDeferredAttribute(i2, "xml:base", "http://www.w3.org/XML/1998/namespace", nodeValueString, true);
            }
        } else if (nodeType == 7) {
            String nodeValueString2 = this.fDeferredDocumentImpl.getNodeValueString(this.fCurrentNodeIndex, false);
            if (nodeValueString2 == null) {
                nodeValueString2 = this.fDeferredDocumentImpl.getDeferredEntityBaseURI(this.fDeferredEntityDecl);
            }
            if (nodeValueString2 != null && this.fErrorHandler != null) {
                DOMErrorImpl dOMErrorImpl = new DOMErrorImpl();
                dOMErrorImpl.fType = "pi-base-uri-not-preserved";
                dOMErrorImpl.fRelatedData = nodeValueString2;
                dOMErrorImpl.fSeverity = 1;
                this.fErrorHandler.getErrorHandler().handleError(dOMErrorImpl);
            }
        }
    }

    public final void handleBaseURI(Node node) {
        String baseURI;
        if (this.fDocumentImpl != null) {
            short nodeType = node.getNodeType();
            if (nodeType == 1) {
                if (this.fNamespaceAware) {
                    if (((Element) node).getAttributeNodeNS("http://www.w3.org/XML/1998/namespace", "base") != null) {
                        return;
                    }
                } else if (((Element) node).getAttributeNode("xml:base") != null) {
                    return;
                }
                String baseURI2 = ((EntityReferenceImpl) this.fCurrentNode).getBaseURI();
                if (baseURI2 != null && !baseURI2.equals(this.fDocumentImpl.getDocumentURI())) {
                    Element element = (Element) node;
                    if (this.fNamespaceAware) {
                        element.setAttributeNS("http://www.w3.org/XML/1998/namespace", "xml:base", baseURI2);
                    } else {
                        element.setAttribute("xml:base", baseURI2);
                    }
                }
            } else if (nodeType == 7 && (baseURI = ((EntityReferenceImpl) this.fCurrentNode).getBaseURI()) != null && this.fErrorHandler != null) {
                DOMErrorImpl dOMErrorImpl = new DOMErrorImpl();
                dOMErrorImpl.fType = "pi-base-uri-not-preserved";
                dOMErrorImpl.fRelatedData = baseURI;
                dOMErrorImpl.fSeverity = 1;
                this.fErrorHandler.getErrorHandler().handleError(dOMErrorImpl);
            }
        }
    }

    @Override // org.apache.xerces.xni.XMLDocumentHandler, org.apache.xerces.parsers.AbstractXMLDocumentParser
    public void ignorableWhitespace(XMLString xMLString, Augmentations augmentations) {
        if (this.fIncludeIgnorableWhitespace && !this.fFilterReject) {
            if (!this.fDeferNodeExpansion) {
                Node lastChild = this.fCurrentNode.getLastChild();
                if (lastChild == null || lastChild.getNodeType() != 3) {
                    Text createTextNode = this.fDocument.createTextNode(xMLString.toString());
                    if (this.fDocumentImpl != null) {
                        ((TextImpl) createTextNode).setIgnorableWhitespace(true);
                    }
                    this.fCurrentNode.appendChild(createTextNode);
                    return;
                }
                ((Text) lastChild).appendData(xMLString.toString());
                return;
            }
            this.fDeferredDocumentImpl.appendChild(this.fCurrentNodeIndex, this.fDeferredDocumentImpl.createDeferredTextNode(xMLString.toString(), true));
        }
    }

    @Override // org.apache.xerces.xni.XMLDTDHandler, org.apache.xerces.parsers.AbstractXMLDocumentParser
    public void ignoredCharacters(XMLString xMLString, Augmentations augmentations) {
    }

    @Override // org.apache.xerces.xni.XMLDTDHandler, org.apache.xerces.parsers.AbstractXMLDocumentParser
    public void internalEntityDecl(String str, XMLString xMLString, XMLString xMLString2, Augmentations augmentations) {
        StringBuffer stringBuffer = this.fInternalSubset;
        boolean z = true;
        if (stringBuffer != null && !this.fInDTDExternalSubset) {
            stringBuffer.append("<!ENTITY ");
            if (str.startsWith(PercentPtg.PERCENT)) {
                this.fInternalSubset.append("% ");
                this.fInternalSubset.append(str.substring(1));
            } else {
                this.fInternalSubset.append(str);
            }
            this.fInternalSubset.append(' ');
            String xMLString3 = xMLString2.toString();
            char c = '\'';
            boolean z2 = xMLString3.indexOf(39) == -1;
            this.fInternalSubset.append(z2 ? '\'' : StringPtg.FORMULA_DELIMITER);
            this.fInternalSubset.append(xMLString3);
            StringBuffer stringBuffer2 = this.fInternalSubset;
            if (!z2) {
                c = StringPtg.FORMULA_DELIMITER;
            }
            stringBuffer2.append(c);
            this.fInternalSubset.append(">\n");
        }
        if (!str.startsWith(PercentPtg.PERCENT)) {
            DocumentType documentType = this.fDocumentType;
            if (documentType != null) {
                NamedNodeMap entities = documentType.getEntities();
                if (((EntityImpl) entities.getNamedItem(str)) == null) {
                    EntityImpl entityImpl = (EntityImpl) this.fDocumentImpl.createEntity(str);
                    entityImpl.setBaseURI((String) this.fBaseURIStack.peek());
                    entities.setNamedItem(entityImpl);
                }
            }
            int i2 = this.fDocumentTypeIndex;
            if (i2 != -1) {
                int lastChild = this.fDeferredDocumentImpl.getLastChild(i2, false);
                while (true) {
                    if (lastChild != -1) {
                        if (this.fDeferredDocumentImpl.getNodeType(lastChild, false) == 6 && this.fDeferredDocumentImpl.getNodeName(lastChild, false).equals(str)) {
                            break;
                        }
                        lastChild = this.fDeferredDocumentImpl.getRealPrevSibling(lastChild, false);
                    } else {
                        z = false;
                        break;
                    }
                }
                if (!z) {
                    this.fDeferredDocumentImpl.appendChild(this.fDocumentTypeIndex, this.fDeferredDocumentImpl.createDeferredEntity(str, null, null, null, (String) this.fBaseURIStack.peek()));
                }
            }
        }
    }

    @Override // org.apache.xerces.xni.XMLDTDHandler, org.apache.xerces.parsers.AbstractXMLDocumentParser
    public void notationDecl(String str, XMLResourceIdentifier xMLResourceIdentifier, Augmentations augmentations) {
        DocumentType documentType;
        String str2;
        String publicId = xMLResourceIdentifier.getPublicId();
        String literalSystemId = xMLResourceIdentifier.getLiteralSystemId();
        StringBuffer stringBuffer = this.fInternalSubset;
        if (stringBuffer != null && !this.fInDTDExternalSubset) {
            stringBuffer.append("<!NOTATION ");
            this.fInternalSubset.append(str);
            StringBuffer stringBuffer2 = this.fInternalSubset;
            if (publicId != null) {
                stringBuffer2.append(" PUBLIC '");
                this.fInternalSubset.append(publicId);
                if (literalSystemId != null) {
                    stringBuffer2 = this.fInternalSubset;
                    str2 = "' '";
                }
                this.fInternalSubset.append("'>\n");
            } else {
                str2 = " SYSTEM '";
            }
            stringBuffer2.append(str2);
            this.fInternalSubset.append(literalSystemId);
            this.fInternalSubset.append("'>\n");
        }
        if (!(this.fDocumentImpl == null || (documentType = this.fDocumentType) == null)) {
            NamedNodeMap notations = documentType.getNotations();
            if (notations.getNamedItem(str) == null) {
                NotationImpl notationImpl = (NotationImpl) this.fDocumentImpl.createNotation(str);
                notationImpl.setPublicId(publicId);
                notationImpl.setSystemId(literalSystemId);
                notationImpl.setBaseURI(xMLResourceIdentifier.getBaseSystemId());
                notations.setNamedItem(notationImpl);
            }
        }
        int i2 = this.fDocumentTypeIndex;
        if (i2 != -1) {
            boolean z = false;
            int lastChild = this.fDeferredDocumentImpl.getLastChild(i2, false);
            while (true) {
                if (lastChild != -1) {
                    if (this.fDeferredDocumentImpl.getNodeType(lastChild, false) == 12 && this.fDeferredDocumentImpl.getNodeName(lastChild, false).equals(str)) {
                        z = true;
                        break;
                    }
                    lastChild = this.fDeferredDocumentImpl.getPrevSibling(lastChild, false);
                } else {
                    break;
                }
            }
            if (!z) {
                this.fDeferredDocumentImpl.appendChild(this.fDocumentTypeIndex, this.fDeferredDocumentImpl.createDeferredNotation(str, publicId, literalSystemId, xMLResourceIdentifier.getBaseSystemId()));
            }
        }
    }

    @Override // org.apache.xerces.xni.XMLDocumentHandler, org.apache.xerces.xni.XMLDTDHandler, org.apache.xerces.parsers.AbstractXMLDocumentParser
    public void processingInstruction(String str, XMLString xMLString, Augmentations augmentations) {
        if (this.fInDTD) {
            StringBuffer stringBuffer = this.fInternalSubset;
            if (stringBuffer != null && !this.fInDTDExternalSubset) {
                stringBuffer.append("<?");
                this.fInternalSubset.append(str);
                if (xMLString.length > 0) {
                    StringBuffer stringBuffer2 = this.fInternalSubset;
                    stringBuffer2.append(' ');
                    stringBuffer2.append(xMLString.ch, xMLString.offset, xMLString.length);
                }
                this.fInternalSubset.append("?>");
            }
        } else if (this.fDeferNodeExpansion) {
            this.fDeferredDocumentImpl.appendChild(this.fCurrentNodeIndex, this.fDeferredDocumentImpl.createDeferredProcessingInstruction(str, xMLString.toString()));
        } else if (!this.fFilterReject) {
            ProcessingInstruction createProcessingInstruction = this.fDocument.createProcessingInstruction(str, xMLString.toString());
            setCharacterData(false);
            this.fCurrentNode.appendChild(createProcessingInstruction);
            LSParserFilter lSParserFilter = this.fDOMFilter;
            if (lSParserFilter != null && !this.fInEntityRef && (lSParserFilter.getWhatToShow() & 64) != 0) {
                short acceptNode = this.fDOMFilter.acceptNode(createProcessingInstruction);
                if (acceptNode == 2 || acceptNode == 3) {
                    this.fCurrentNode.removeChild(createProcessingInstruction);
                    this.fFirstChunk = true;
                } else if (acceptNode == 4) {
                    throw Abort.INSTANCE;
                }
            }
        }
    }

    @Override // org.apache.xerces.parsers.AbstractXMLDocumentParser, org.apache.xerces.parsers.XMLParser
    public void reset() {
        super.reset();
        this.fCreateEntityRefNodes = this.fConfiguration.getFeature("http://apache.org/xml/features/dom/create-entity-ref-nodes");
        this.fIncludeIgnorableWhitespace = this.fConfiguration.getFeature("http://apache.org/xml/features/dom/include-ignorable-whitespace");
        this.fDeferNodeExpansion = this.fConfiguration.getFeature(DEFER_NODE_EXPANSION);
        this.fNamespaceAware = this.fConfiguration.getFeature("http://xml.org/sax/features/namespaces");
        this.fIncludeComments = this.fConfiguration.getFeature("http://apache.org/xml/features/include-comments");
        this.fCreateCDATANodes = this.fConfiguration.getFeature("http://apache.org/xml/features/create-cdata-nodes");
        setDocumentClassName((String) this.fConfiguration.getProperty(DOCUMENT_CLASS_NAME));
        this.fDocument = null;
        this.fDocumentImpl = null;
        this.fStorePSVI = false;
        this.fDocumentType = null;
        this.fDocumentTypeIndex = -1;
        this.fDeferredDocumentImpl = null;
        this.fCurrentNode = null;
        this.fStringBuffer.setLength(0);
        this.fRoot = null;
        this.fInDTD = false;
        this.fInDTDExternalSubset = false;
        this.fInCDATASection = false;
        this.fFirstChunk = false;
        this.fCurrentCDATASection = null;
        this.fCurrentCDATASectionIndex = -1;
        this.fBaseURIStack.removeAllElements();
    }

    public void setCharacterData(boolean z) {
        this.fFirstChunk = z;
        Node lastChild = this.fCurrentNode.getLastChild();
        if (lastChild != null) {
            if (this.fStringBuffer.length() > 0) {
                if (lastChild.getNodeType() == 3) {
                    if (this.fDocumentImpl != null) {
                        ((TextImpl) lastChild).replaceData(this.fStringBuffer.toString());
                    } else {
                        ((Text) lastChild).setData(this.fStringBuffer.toString());
                    }
                }
                this.fStringBuffer.setLength(0);
            }
            if (this.fDOMFilter != null && !this.fInEntityRef && lastChild.getNodeType() == 3 && (this.fDOMFilter.getWhatToShow() & 4) != 0) {
                short acceptNode = this.fDOMFilter.acceptNode(lastChild);
                if (acceptNode == 2 || acceptNode == 3) {
                    this.fCurrentNode.removeChild(lastChild);
                } else if (acceptNode == 4) {
                    throw Abort.INSTANCE;
                }
            }
        }
    }

    public void setDocumentClassName(String str) {
        Class cls;
        if (str == null) {
            str = DEFAULT_DOCUMENT_CLASS_NAME;
        }
        if (!str.equals(DEFAULT_DOCUMENT_CLASS_NAME) && !str.equals(PSVI_DOCUMENT_CLASS_NAME)) {
            try {
                Class<?> findProviderClass = ObjectFactory.findProviderClass(str, ObjectFactory.findClassLoader(), true);
                if (class$org$w3c$dom$Document == null) {
                    cls = class$("org.w3c.dom.Document");
                    class$org$w3c$dom$Document = cls;
                } else {
                    cls = class$org$w3c$dom$Document;
                }
                if (!cls.isAssignableFrom(findProviderClass)) {
                    throw new IllegalArgumentException(DOMMessageFormatter.formatMessage(DOMMessageFormatter.DOM_DOMAIN, "InvalidDocumentClassName", new Object[]{str}));
                }
            } catch (ClassNotFoundException unused) {
                throw new IllegalArgumentException(DOMMessageFormatter.formatMessage(DOMMessageFormatter.DOM_DOMAIN, "MissingDocumentClassName", new Object[]{str}));
            }
        }
        this.fDocumentClassName = str;
        if (!str.equals(DEFAULT_DOCUMENT_CLASS_NAME)) {
            this.fDeferNodeExpansion = false;
        }
    }

    public void setLocale(Locale locale) {
        this.fConfiguration.setLocale(locale);
    }

    @Override // org.apache.xerces.xni.XMLDTDHandler, org.apache.xerces.parsers.AbstractXMLDocumentParser
    public void startAttlist(String str, Augmentations augmentations) {
    }

    @Override // org.apache.xerces.xni.XMLDocumentHandler, org.apache.xerces.parsers.AbstractXMLDocumentParser
    public void startCDATA(Augmentations augmentations) {
        this.fInCDATASection = true;
        if (!this.fDeferNodeExpansion && !this.fFilterReject && this.fCreateCDATANodes) {
            setCharacterData(false);
        }
    }

    @Override // org.apache.xerces.xni.XMLDTDHandler, org.apache.xerces.parsers.AbstractXMLDocumentParser
    public void startConditional(short s, Augmentations augmentations) {
    }

    @Override // org.apache.xerces.xni.XMLDTDHandler, org.apache.xerces.parsers.AbstractXMLDocumentParser
    public void startDTD(XMLLocator xMLLocator, Augmentations augmentations) {
        this.fInDTD = true;
        if (xMLLocator != null) {
            this.fBaseURIStack.push(xMLLocator.getBaseSystemId());
        }
        if (this.fDeferNodeExpansion || this.fDocumentImpl != null) {
            this.fInternalSubset = new StringBuffer(1024);
        }
    }

    @Override // org.apache.xerces.xni.XMLDocumentHandler, org.apache.xerces.parsers.AbstractXMLDocumentParser
    public void startDocument(XMLLocator xMLLocator, String str, NamespaceContext namespaceContext, Augmentations augmentations) {
        PSVIDocumentImpl pSVIDocumentImpl;
        this.fLocator = xMLLocator;
        if (!this.fDeferNodeExpansion) {
            if (this.fDocumentClassName.equals(DEFAULT_DOCUMENT_CLASS_NAME)) {
                DocumentImpl documentImpl = new DocumentImpl();
                this.fDocument = documentImpl;
                pSVIDocumentImpl = documentImpl;
                this.fDocumentImpl = pSVIDocumentImpl;
            } else if (this.fDocumentClassName.equals(PSVI_DOCUMENT_CLASS_NAME)) {
                PSVIDocumentImpl pSVIDocumentImpl2 = new PSVIDocumentImpl();
                this.fDocument = pSVIDocumentImpl2;
                pSVIDocumentImpl = pSVIDocumentImpl2;
                this.fDocumentImpl = pSVIDocumentImpl;
                this.fStorePSVI = true;
            } else {
                try {
                    ClassLoader findClassLoader = ObjectFactory.findClassLoader();
                    Class<?> findProviderClass = ObjectFactory.findProviderClass(this.fDocumentClassName, findClassLoader, true);
                    this.fDocument = (Document) findProviderClass.newInstance();
                    if (ObjectFactory.findProviderClass(CORE_DOCUMENT_CLASS_NAME, findClassLoader, true).isAssignableFrom(findProviderClass)) {
                        this.fDocumentImpl = (CoreDocumentImpl) this.fDocument;
                        if (ObjectFactory.findProviderClass(PSVI_DOCUMENT_CLASS_NAME, findClassLoader, true).isAssignableFrom(findProviderClass)) {
                            this.fStorePSVI = true;
                        }
                        this.fDocumentImpl.setStrictErrorChecking(false);
                        this.fDocumentImpl.setInputEncoding(str);
                        if (xMLLocator != null) {
                            this.fDocumentImpl.setDocumentURI(xMLLocator.getExpandedSystemId());
                        }
                    }
                } catch (ClassNotFoundException unused) {
                } catch (Exception unused2) {
                    throw new RuntimeException(DOMMessageFormatter.formatMessage(DOMMessageFormatter.DOM_DOMAIN, "CannotCreateDocumentClass", new Object[]{this.fDocumentClassName}));
                }
                this.fCurrentNode = this.fDocument;
                return;
            }
            pSVIDocumentImpl.setStrictErrorChecking(false);
            this.fDocumentImpl.setInputEncoding(str);
            this.fDocumentImpl.setDocumentURI(xMLLocator.getExpandedSystemId());
            this.fCurrentNode = this.fDocument;
            return;
        }
        DeferredDocumentImpl deferredDocumentImpl = new DeferredDocumentImpl(this.fNamespaceAware);
        this.fDeferredDocumentImpl = deferredDocumentImpl;
        this.fDocument = deferredDocumentImpl;
        this.fDocumentIndex = deferredDocumentImpl.createDeferredDocument();
        this.fDeferredDocumentImpl.setInputEncoding(str);
        this.fDeferredDocumentImpl.setDocumentURI(xMLLocator.getExpandedSystemId());
        this.fCurrentNodeIndex = this.fDocumentIndex;
    }

    /* JADX WARNING: Removed duplicated region for block: B:74:0x011e  */
    @Override // org.apache.xerces.xni.XMLDocumentHandler, org.apache.xerces.parsers.AbstractXMLDocumentParser
    public void startElement(QName qName, XMLAttributes xMLAttributes, Augmentations augmentations) {
        boolean z;
        XSSimpleTypeDefinition xSSimpleTypeDefinition;
        boolean z2;
        ElementPSVI elementPSVI;
        boolean z3;
        Object obj;
        QName qName2;
        String str;
        boolean z4 = false;
        boolean z5 = true;
        if (this.fDeferNodeExpansion) {
            int createDeferredElement = this.fDeferredDocumentImpl.createDeferredElement(this.fNamespaceAware ? qName.uri : null, qName.rawname);
            int length = xMLAttributes.getLength() - 1;
            Object obj2 = null;
            while (length >= 0) {
                AttributePSVI attributePSVI = (AttributePSVI) xMLAttributes.getAugmentations(length).getItem(Constants.ATTRIBUTE_PSVI);
                if (attributePSVI != null && this.fNamespaceAware) {
                    XSSimpleTypeDefinition memberTypeDefinition = attributePSVI.getMemberTypeDefinition();
                    if (memberTypeDefinition == null) {
                        xSSimpleTypeDefinition = attributePSVI.getTypeDefinition();
                        if (xSSimpleTypeDefinition != null) {
                            z2 = ((XSSimpleType) xSSimpleTypeDefinition).isIDType();
                        }
                        z = false;
                        this.fDeferredDocumentImpl.setDeferredAttribute(createDeferredElement, xMLAttributes.getQName(length), xMLAttributes.getURI(length), xMLAttributes.getValue(length), xMLAttributes.isSpecified(length), z, xSSimpleTypeDefinition);
                        length--;
                        obj2 = xSSimpleTypeDefinition;
                    } else {
                        z = ((XSSimpleType) memberTypeDefinition).isIDType();
                        xSSimpleTypeDefinition = memberTypeDefinition;
                        this.fDeferredDocumentImpl.setDeferredAttribute(createDeferredElement, xMLAttributes.getQName(length), xMLAttributes.getURI(length), xMLAttributes.getValue(length), xMLAttributes.isSpecified(length), z, xSSimpleTypeDefinition);
                        length--;
                        obj2 = xSSimpleTypeDefinition;
                    }
                } else if (Boolean.TRUE.equals(xMLAttributes.getAugmentations(length).getItem(Constants.ATTRIBUTE_DECLARED))) {
                    xSSimpleTypeDefinition = xMLAttributes.getType(length);
                    z2 = SchemaSymbols.ATTVAL_ID.equals(xSSimpleTypeDefinition);
                } else {
                    xSSimpleTypeDefinition = obj2;
                    z = false;
                    this.fDeferredDocumentImpl.setDeferredAttribute(createDeferredElement, xMLAttributes.getQName(length), xMLAttributes.getURI(length), xMLAttributes.getValue(length), xMLAttributes.isSpecified(length), z, xSSimpleTypeDefinition);
                    length--;
                    obj2 = xSSimpleTypeDefinition;
                }
                z = z2;
                this.fDeferredDocumentImpl.setDeferredAttribute(createDeferredElement, xMLAttributes.getQName(length), xMLAttributes.getURI(length), xMLAttributes.getValue(length), xMLAttributes.isSpecified(length), z, xSSimpleTypeDefinition);
                length--;
                obj2 = xSSimpleTypeDefinition;
            }
            this.fDeferredDocumentImpl.appendChild(this.fCurrentNodeIndex, createDeferredElement);
            this.fCurrentNodeIndex = createDeferredElement;
        } else if (this.fFilterReject) {
            this.fRejectedElementDepth++;
        } else {
            Element createElementNode = createElementNode(qName);
            int length2 = xMLAttributes.getLength();
            int i2 = 0;
            boolean z6 = false;
            while (i2 < length2) {
                xMLAttributes.getName(i2, this.fAttrQName);
                Attr createAttrNode = createAttrNode(this.fAttrQName);
                String value = xMLAttributes.getValue(i2);
                AttributePSVI attributePSVI2 = (AttributePSVI) xMLAttributes.getAugmentations(i2).getItem(Constants.ATTRIBUTE_PSVI);
                if (this.fStorePSVI && attributePSVI2 != null) {
                    ((PSVIAttrNSImpl) createAttrNode).setPSVI(attributePSVI2);
                }
                createAttrNode.setValue(value);
                boolean isSpecified = xMLAttributes.isSpecified(i2);
                if (isSpecified || (!z6 && ((str = (qName2 = this.fAttrQName).uri) == null || str == NamespaceContext.XMLNS_URI || qName2.prefix != null))) {
                    createElementNode.setAttributeNode(createAttrNode);
                } else {
                    createElementNode.setAttributeNodeNS(createAttrNode);
                    z6 = true;
                }
                if (this.fDocumentImpl != null) {
                    AttrImpl attrImpl = (AttrImpl) createAttrNode;
                    if (attributePSVI2 != null && this.fNamespaceAware) {
                        obj = attributePSVI2.getMemberTypeDefinition();
                        if (obj == null && (obj = attributePSVI2.getTypeDefinition()) == null) {
                            z3 = false;
                            if (z3) {
                                ((ElementImpl) createElementNode).setIdAttributeNode(createAttrNode, true);
                            }
                            attrImpl.setSpecified(isSpecified);
                        } else {
                            z3 = ((XSSimpleType) obj).isIDType();
                        }
                    } else if (Boolean.TRUE.equals(xMLAttributes.getAugmentations(i2).getItem(Constants.ATTRIBUTE_DECLARED))) {
                        obj = xMLAttributes.getType(i2);
                        z3 = SchemaSymbols.ATTVAL_ID.equals(obj);
                    } else {
                        obj = null;
                        z3 = false;
                    }
                    attrImpl.setType(obj);
                    if (z3) {
                    }
                    attrImpl.setSpecified(isSpecified);
                }
                i2++;
                z4 = false;
                z5 = true;
            }
            setCharacterData(z4);
            if (!(augmentations == null || (elementPSVI = (ElementPSVI) augmentations.getItem(Constants.ELEMENT_PSVI)) == null || !this.fNamespaceAware)) {
                XSTypeDefinition memberTypeDefinition2 = elementPSVI.getMemberTypeDefinition();
                if (memberTypeDefinition2 == null) {
                    memberTypeDefinition2 = elementPSVI.getTypeDefinition();
                }
                ((ElementNSImpl) createElementNode).setType(memberTypeDefinition2);
            }
            LSParserFilter lSParserFilter = this.fDOMFilter;
            if (lSParserFilter != null && !this.fInEntityRef) {
                if (this.fRoot == null) {
                    this.fRoot = createElementNode;
                } else {
                    short startElement = lSParserFilter.startElement(createElementNode);
                    if (startElement == 2) {
                        this.fFilterReject = z5;
                        int i3 = z4 ? 1 : 0;
                        int i4 = z4 ? 1 : 0;
                        int i5 = z4 ? 1 : 0;
                        this.fRejectedElementDepth = i3;
                        return;
                    } else if (startElement == 3) {
                        this.fFirstChunk = z5;
                        this.fSkippedElemStack.push(Boolean.TRUE);
                        return;
                    } else if (startElement == 4) {
                        throw Abort.INSTANCE;
                    } else if (!this.fSkippedElemStack.isEmpty()) {
                        this.fSkippedElemStack.push(Boolean.FALSE);
                    }
                }
            }
            this.fCurrentNode.appendChild(createElementNode);
            this.fCurrentNode = createElementNode;
        }
    }

    @Override // org.apache.xerces.xni.XMLDTDHandler, org.apache.xerces.parsers.AbstractXMLDocumentParser
    public void startExternalSubset(XMLResourceIdentifier xMLResourceIdentifier, Augmentations augmentations) {
        this.fBaseURIStack.push(xMLResourceIdentifier.getBaseSystemId());
        this.fInDTDExternalSubset = true;
    }

    @Override // org.apache.xerces.xni.XMLDocumentHandler, org.apache.xerces.parsers.AbstractXMLDocumentParser
    public void startGeneralEntity(String str, XMLResourceIdentifier xMLResourceIdentifier, String str2, Augmentations augmentations) {
        if (this.fDeferNodeExpansion) {
            int createDeferredEntityReference = this.fDeferredDocumentImpl.createDeferredEntityReference(str, xMLResourceIdentifier.getExpandedSystemId());
            int i2 = this.fDocumentTypeIndex;
            if (i2 != -1) {
                int lastChild = this.fDeferredDocumentImpl.getLastChild(i2, false);
                while (true) {
                    if (lastChild != -1) {
                        if (this.fDeferredDocumentImpl.getNodeType(lastChild, false) == 6 && this.fDeferredDocumentImpl.getNodeName(lastChild, false).equals(str)) {
                            this.fDeferredEntityDecl = lastChild;
                            this.fDeferredDocumentImpl.setInputEncoding(lastChild, str2);
                            break;
                        }
                        lastChild = this.fDeferredDocumentImpl.getRealPrevSibling(lastChild, false);
                    } else {
                        break;
                    }
                }
            }
            this.fDeferredDocumentImpl.appendChild(this.fCurrentNodeIndex, createDeferredEntityReference);
            this.fCurrentNodeIndex = createDeferredEntityReference;
        } else if (!this.fFilterReject) {
            setCharacterData(true);
            EntityReference createEntityReference = this.fDocument.createEntityReference(str);
            if (this.fDocumentImpl != null) {
                EntityReferenceImpl entityReferenceImpl = (EntityReferenceImpl) createEntityReference;
                entityReferenceImpl.setBaseURI(xMLResourceIdentifier.getExpandedSystemId());
                DocumentType documentType = this.fDocumentType;
                if (documentType != null) {
                    EntityImpl entityImpl = (EntityImpl) documentType.getEntities().getNamedItem(str);
                    this.fCurrentEntityDecl = entityImpl;
                    if (entityImpl != null) {
                        entityImpl.setInputEncoding(str2);
                    }
                }
                entityReferenceImpl.needsSyncChildren(false);
            }
            this.fInEntityRef = true;
            this.fCurrentNode.appendChild(createEntityReference);
            this.fCurrentNode = createEntityReference;
        }
    }

    @Override // org.apache.xerces.xni.XMLDTDHandler, org.apache.xerces.parsers.AbstractXMLDocumentParser
    public void startParameterEntity(String str, XMLResourceIdentifier xMLResourceIdentifier, String str2, Augmentations augmentations) {
        if (augmentations != null && this.fInternalSubset != null && !this.fInDTDExternalSubset && Boolean.TRUE.equals(augmentations.getItem(Constants.ENTITY_SKIPPED))) {
            StringBuffer stringBuffer = this.fInternalSubset;
            stringBuffer.append(str);
            stringBuffer.append(";\n");
        }
        this.fBaseURIStack.push(xMLResourceIdentifier.getExpandedSystemId());
    }

    @Override // org.apache.xerces.xni.XMLDocumentHandler, org.apache.xerces.xni.XMLDTDHandler, org.apache.xerces.parsers.AbstractXMLDocumentParser
    public void textDecl(String str, String str2, Augmentations augmentations) {
        if (!this.fInDTD) {
            if (!this.fDeferNodeExpansion) {
                EntityImpl entityImpl = this.fCurrentEntityDecl;
                if (entityImpl != null && !this.fFilterReject) {
                    entityImpl.setXmlEncoding(str2);
                    if (str != null) {
                        this.fCurrentEntityDecl.setXmlVersion(str);
                        return;
                    }
                    return;
                }
                return;
            }
            int i2 = this.fDeferredEntityDecl;
            if (i2 != -1) {
                this.fDeferredDocumentImpl.setEntityInfo(i2, str, str2);
            }
        }
    }

    @Override // org.apache.xerces.xni.XMLDTDHandler, org.apache.xerces.parsers.AbstractXMLDocumentParser
    public void unparsedEntityDecl(String str, XMLResourceIdentifier xMLResourceIdentifier, String str2, Augmentations augmentations) {
        String str3;
        String publicId = xMLResourceIdentifier.getPublicId();
        String literalSystemId = xMLResourceIdentifier.getLiteralSystemId();
        StringBuffer stringBuffer = this.fInternalSubset;
        if (stringBuffer != null && !this.fInDTDExternalSubset) {
            stringBuffer.append("<!ENTITY ");
            this.fInternalSubset.append(str);
            this.fInternalSubset.append(' ');
            StringBuffer stringBuffer2 = this.fInternalSubset;
            if (publicId != null) {
                stringBuffer2.append("PUBLIC '");
                this.fInternalSubset.append(publicId);
                if (literalSystemId != null) {
                    stringBuffer2 = this.fInternalSubset;
                    str3 = "' '";
                }
                this.fInternalSubset.append("' NDATA ");
                this.fInternalSubset.append(str2);
                this.fInternalSubset.append(">\n");
            } else {
                str3 = "SYSTEM '";
            }
            stringBuffer2.append(str3);
            this.fInternalSubset.append(literalSystemId);
            this.fInternalSubset.append("' NDATA ");
            this.fInternalSubset.append(str2);
            this.fInternalSubset.append(">\n");
        }
        DocumentType documentType = this.fDocumentType;
        if (documentType != null) {
            NamedNodeMap entities = documentType.getEntities();
            if (((EntityImpl) entities.getNamedItem(str)) == null) {
                EntityImpl entityImpl = (EntityImpl) this.fDocumentImpl.createEntity(str);
                entityImpl.setPublicId(publicId);
                entityImpl.setSystemId(literalSystemId);
                entityImpl.setNotationName(str2);
                entityImpl.setBaseURI(xMLResourceIdentifier.getBaseSystemId());
                entities.setNamedItem(entityImpl);
            }
        }
        int i2 = this.fDocumentTypeIndex;
        if (i2 != -1) {
            boolean z = false;
            int lastChild = this.fDeferredDocumentImpl.getLastChild(i2, false);
            while (true) {
                if (lastChild != -1) {
                    if (this.fDeferredDocumentImpl.getNodeType(lastChild, false) == 6 && this.fDeferredDocumentImpl.getNodeName(lastChild, false).equals(str)) {
                        z = true;
                        break;
                    }
                    lastChild = this.fDeferredDocumentImpl.getRealPrevSibling(lastChild, false);
                } else {
                    break;
                }
            }
            if (!z) {
                this.fDeferredDocumentImpl.appendChild(this.fDocumentTypeIndex, this.fDeferredDocumentImpl.createDeferredEntity(str, publicId, literalSystemId, str2, xMLResourceIdentifier.getBaseSystemId()));
            }
        }
    }

    @Override // org.apache.xerces.xni.XMLDocumentHandler, org.apache.xerces.parsers.AbstractXMLDocumentParser
    public void xmlDecl(String str, String str2, String str3, Augmentations augmentations) {
        CoreDocumentImpl coreDocumentImpl;
        if (!this.fDeferNodeExpansion) {
            CoreDocumentImpl coreDocumentImpl2 = this.fDocumentImpl;
            if (coreDocumentImpl2 != null) {
                if (str != null) {
                    coreDocumentImpl2.setXmlVersion(str);
                }
                this.fDocumentImpl.setXmlEncoding(str2);
                coreDocumentImpl = this.fDocumentImpl;
            } else {
                return;
            }
        } else {
            if (str != null) {
                this.fDeferredDocumentImpl.setXmlVersion(str);
            }
            this.fDeferredDocumentImpl.setXmlEncoding(str2);
            coreDocumentImpl = this.fDeferredDocumentImpl;
        }
        coreDocumentImpl.setXmlStandalone("yes".equals(str3));
    }
}
