package org.apache.xerces.parsers;

import java.io.CharConversionException;
import java.io.IOException;
import java.util.Locale;
import org.apache.xerces.impl.Constants;
import org.apache.xerces.impl.xs.SchemaSymbols;
import org.apache.xerces.util.EntityResolver2Wrapper;
import org.apache.xerces.util.EntityResolverWrapper;
import org.apache.xerces.util.ErrorHandlerWrapper;
import org.apache.xerces.util.SAXMessageFormatter;
import org.apache.xerces.util.SymbolHash;
import org.apache.xerces.util.XMLSymbols;
import org.apache.xerces.xni.Augmentations;
import org.apache.xerces.xni.NamespaceContext;
import org.apache.xerces.xni.QName;
import org.apache.xerces.xni.XMLAttributes;
import org.apache.xerces.xni.XMLLocator;
import org.apache.xerces.xni.XMLResourceIdentifier;
import org.apache.xerces.xni.XMLString;
import org.apache.xerces.xni.XNIException;
import org.apache.xerces.xni.parser.XMLConfigurationException;
import org.apache.xerces.xni.parser.XMLEntityResolver;
import org.apache.xerces.xni.parser.XMLErrorHandler;
import org.apache.xerces.xni.parser.XMLInputSource;
import org.apache.xerces.xni.parser.XMLParseException;
import org.apache.xerces.xni.parser.XMLParserConfiguration;
import org.apache.xerces.xs.AttributePSVI;
import org.apache.xerces.xs.ElementPSVI;
import org.apache.xerces.xs.PSVIProvider;
import org.xml.sax.AttributeList;
import org.xml.sax.ContentHandler;
import org.xml.sax.DTDHandler;
import org.xml.sax.DocumentHandler;
import org.xml.sax.EntityResolver;
import org.xml.sax.ErrorHandler;
import org.xml.sax.InputSource;
import org.xml.sax.Parser;
import org.xml.sax.SAXException;
import org.xml.sax.SAXNotRecognizedException;
import org.xml.sax.SAXNotSupportedException;
import org.xml.sax.SAXParseException;
import org.xml.sax.XMLReader;
import org.xml.sax.ext.Attributes2;
import org.xml.sax.ext.DeclHandler;
import org.xml.sax.ext.EntityResolver2;
import org.xml.sax.ext.LexicalHandler;
import org.xml.sax.ext.Locator2;
import org.xml.sax.ext.Locator2Impl;

public abstract class AbstractSAXParser extends AbstractXMLDocumentParser implements PSVIProvider, Parser, XMLReader {
    public static final String ALLOW_UE_AND_NOTATION_EVENTS = "http://xml.org/sax/features/allow-dtd-events-after-endDTD";
    public static final String DECLARATION_HANDLER = "http://xml.org/sax/properties/declaration-handler";
    public static final String DOM_NODE = "http://xml.org/sax/properties/dom-node";
    public static final String LEXICAL_HANDLER = "http://xml.org/sax/properties/lexical-handler";
    public static final String NAMESPACES = "http://xml.org/sax/features/namespaces";
    public static final String[] RECOGNIZED_FEATURES = {"http://xml.org/sax/features/namespaces", "http://xml.org/sax/features/string-interning"};
    public static final String[] RECOGNIZED_PROPERTIES = {"http://xml.org/sax/properties/lexical-handler", DECLARATION_HANDLER, DOM_NODE};
    public static final String STRING_INTERNING = "http://xml.org/sax/features/string-interning";
    public final AttributesProxy fAttributesProxy = new AttributesProxy();
    public Augmentations fAugmentations = null;
    public ContentHandler fContentHandler;
    public DTDHandler fDTDHandler;
    public DeclHandler fDeclHandler;
    public SymbolHash fDeclaredAttrs = null;
    public DocumentHandler fDocumentHandler;
    public LexicalHandler fLexicalHandler;
    public boolean fLexicalHandlerParameterEntities = true;
    public NamespaceContext fNamespaceContext;
    public boolean fNamespacePrefixes = false;
    public boolean fNamespaces;
    public boolean fParseInProgress = false;
    public final QName fQName = new QName();
    public boolean fResolveDTDURIs = true;
    public boolean fStandalone;
    public boolean fUseEntityResolver2 = true;
    public String fVersion;
    public boolean fXMLNSURIs = false;

    public static final class AttributesProxy implements AttributeList, Attributes2 {
        public XMLAttributes fAttributes;

        @Override // org.xml.sax.Attributes
        public int getIndex(String str) {
            return this.fAttributes.getIndex(str);
        }

        @Override // org.xml.sax.Attributes
        public int getIndex(String str, String str2) {
            return str.length() == 0 ? this.fAttributes.getIndex(null, str2) : this.fAttributes.getIndex(str, str2);
        }

        @Override // org.xml.sax.AttributeList, org.xml.sax.Attributes
        public int getLength() {
            return this.fAttributes.getLength();
        }

        @Override // org.xml.sax.Attributes
        public String getLocalName(int i2) {
            return this.fAttributes.getLocalName(i2);
        }

        @Override // org.xml.sax.AttributeList
        public String getName(int i2) {
            return this.fAttributes.getQName(i2);
        }

        @Override // org.xml.sax.Attributes
        public String getQName(int i2) {
            return this.fAttributes.getQName(i2);
        }

        @Override // org.xml.sax.AttributeList, org.xml.sax.Attributes
        public String getType(int i2) {
            return this.fAttributes.getType(i2);
        }

        @Override // org.xml.sax.AttributeList, org.xml.sax.Attributes
        public String getType(String str) {
            return this.fAttributes.getType(str);
        }

        @Override // org.xml.sax.Attributes
        public String getType(String str, String str2) {
            return str.length() == 0 ? this.fAttributes.getType(null, str2) : this.fAttributes.getType(str, str2);
        }

        @Override // org.xml.sax.Attributes
        public String getURI(int i2) {
            String uri = this.fAttributes.getURI(i2);
            return uri != null ? uri : "";
        }

        @Override // org.xml.sax.AttributeList, org.xml.sax.Attributes
        public String getValue(int i2) {
            return this.fAttributes.getValue(i2);
        }

        @Override // org.xml.sax.AttributeList, org.xml.sax.Attributes
        public String getValue(String str) {
            return this.fAttributes.getValue(str);
        }

        @Override // org.xml.sax.Attributes
        public String getValue(String str, String str2) {
            return str.length() == 0 ? this.fAttributes.getValue(null, str2) : this.fAttributes.getValue(str, str2);
        }

        @Override // org.xml.sax.ext.Attributes2
        public boolean isDeclared(int i2) {
            if (i2 >= 0 && i2 < this.fAttributes.getLength()) {
                return Boolean.TRUE.equals(this.fAttributes.getAugmentations(i2).getItem(Constants.ATTRIBUTE_DECLARED));
            }
            throw new ArrayIndexOutOfBoundsException(i2);
        }

        @Override // org.xml.sax.ext.Attributes2
        public boolean isDeclared(String str) {
            int index = getIndex(str);
            if (index != -1) {
                return Boolean.TRUE.equals(this.fAttributes.getAugmentations(index).getItem(Constants.ATTRIBUTE_DECLARED));
            }
            throw new IllegalArgumentException(str);
        }

        @Override // org.xml.sax.ext.Attributes2
        public boolean isDeclared(String str, String str2) {
            int index = getIndex(str, str2);
            if (index != -1) {
                return Boolean.TRUE.equals(this.fAttributes.getAugmentations(index).getItem(Constants.ATTRIBUTE_DECLARED));
            }
            throw new IllegalArgumentException(str2);
        }

        @Override // org.xml.sax.ext.Attributes2
        public boolean isSpecified(int i2) {
            if (i2 >= 0 && i2 < this.fAttributes.getLength()) {
                return this.fAttributes.isSpecified(i2);
            }
            throw new ArrayIndexOutOfBoundsException(i2);
        }

        @Override // org.xml.sax.ext.Attributes2
        public boolean isSpecified(String str) {
            int index = getIndex(str);
            if (index != -1) {
                return this.fAttributes.isSpecified(index);
            }
            throw new IllegalArgumentException(str);
        }

        @Override // org.xml.sax.ext.Attributes2
        public boolean isSpecified(String str, String str2) {
            int index = getIndex(str, str2);
            if (index != -1) {
                return this.fAttributes.isSpecified(index);
            }
            throw new IllegalArgumentException(str2);
        }

        public void setAttributes(XMLAttributes xMLAttributes) {
            this.fAttributes = xMLAttributes;
        }
    }

    public static final class LocatorProxy implements Locator2 {
        public XMLLocator fLocator;

        public LocatorProxy(XMLLocator xMLLocator) {
            this.fLocator = xMLLocator;
        }

        @Override // org.xml.sax.Locator
        public int getColumnNumber() {
            return this.fLocator.getColumnNumber();
        }

        @Override // org.xml.sax.ext.Locator2
        public String getEncoding() {
            return this.fLocator.getEncoding();
        }

        @Override // org.xml.sax.Locator
        public int getLineNumber() {
            return this.fLocator.getLineNumber();
        }

        @Override // org.xml.sax.Locator
        public String getPublicId() {
            return this.fLocator.getPublicId();
        }

        @Override // org.xml.sax.Locator
        public String getSystemId() {
            return this.fLocator.getExpandedSystemId();
        }

        @Override // org.xml.sax.ext.Locator2
        public String getXMLVersion() {
            return this.fLocator.getXMLVersion();
        }
    }

    public AbstractSAXParser(XMLParserConfiguration xMLParserConfiguration) {
        super(xMLParserConfiguration);
        xMLParserConfiguration.addRecognizedFeatures(RECOGNIZED_FEATURES);
        xMLParserConfiguration.addRecognizedProperties(RECOGNIZED_PROPERTIES);
        try {
            xMLParserConfiguration.setFeature("http://xml.org/sax/features/allow-dtd-events-after-endDTD", false);
        } catch (XMLConfigurationException unused) {
        }
    }

    /* JADX WARNING: Removed duplicated region for block: B:22:0x0061 A[Catch:{ SAXException -> 0x0084 }] */
    /* JADX WARNING: Removed duplicated region for block: B:23:0x0063 A[Catch:{ SAXException -> 0x0084 }] */
    @Override // org.apache.xerces.xni.XMLDTDHandler, org.apache.xerces.parsers.AbstractXMLDocumentParser
    public void attributeDecl(String str, String str2, String str3, String[] strArr, String str4, XMLString xMLString, XMLString xMLString2, Augmentations augmentations) {
        try {
            if (this.fDeclHandler != null) {
                StringBuffer stringBuffer = new StringBuffer(str);
                stringBuffer.append('<');
                stringBuffer.append(str2);
                String stringBuffer2 = stringBuffer.toString();
                if (this.fDeclaredAttrs.get(stringBuffer2) == null) {
                    this.fDeclaredAttrs.put(stringBuffer2, Boolean.TRUE);
                    if (!str3.equals(SchemaSymbols.ATTVAL_NOTATION)) {
                        if (str3.equals("ENUMERATION")) {
                        }
                        this.fDeclHandler.attributeDecl(str, str2, str3, str4, xMLString != null ? null : xMLString.toString());
                    }
                    StringBuffer stringBuffer3 = new StringBuffer();
                    if (str3.equals(SchemaSymbols.ATTVAL_NOTATION)) {
                        stringBuffer3.append(str3);
                        stringBuffer3.append(" (");
                    } else {
                        stringBuffer3.append('(');
                    }
                    for (int i2 = 0; i2 < strArr.length; i2++) {
                        stringBuffer3.append(strArr[i2]);
                        if (i2 < strArr.length - 1) {
                            stringBuffer3.append('|');
                        }
                    }
                    stringBuffer3.append(')');
                    str3 = stringBuffer3.toString();
                    this.fDeclHandler.attributeDecl(str, str2, str3, str4, xMLString != null ? null : xMLString.toString());
                }
            }
        } catch (SAXException e2) {
            throw new XNIException(e2);
        }
    }

    @Override // org.apache.xerces.xni.XMLDocumentHandler, org.apache.xerces.parsers.AbstractXMLDocumentParser
    public void characters(XMLString xMLString, Augmentations augmentations) {
        int i2 = xMLString.length;
        if (i2 != 0) {
            try {
                if (this.fDocumentHandler != null) {
                    this.fDocumentHandler.characters(xMLString.ch, xMLString.offset, i2);
                }
                if (this.fContentHandler != null) {
                    this.fContentHandler.characters(xMLString.ch, xMLString.offset, xMLString.length);
                }
            } catch (SAXException e2) {
                throw new XNIException(e2);
            }
        }
    }

    @Override // org.apache.xerces.xni.XMLDocumentHandler, org.apache.xerces.xni.XMLDTDHandler, org.apache.xerces.parsers.AbstractXMLDocumentParser
    public void comment(XMLString xMLString, Augmentations augmentations) {
        try {
            if (this.fLexicalHandler != null) {
                this.fLexicalHandler.comment(xMLString.ch, 0, xMLString.length);
            }
        } catch (SAXException e2) {
            throw new XNIException(e2);
        }
    }

    @Override // org.apache.xerces.xni.XMLDocumentHandler, org.apache.xerces.parsers.AbstractXMLDocumentParser
    public void doctypeDecl(String str, String str2, String str3, Augmentations augmentations) {
        this.fInDTD = true;
        try {
            if (this.fLexicalHandler != null) {
                this.fLexicalHandler.startDTD(str, str2, str3);
            }
            if (this.fDeclHandler != null) {
                this.fDeclaredAttrs = new SymbolHash();
            }
        } catch (SAXException e2) {
            throw new XNIException(e2);
        }
    }

    @Override // org.apache.xerces.xni.XMLDTDHandler, org.apache.xerces.parsers.AbstractXMLDocumentParser
    public void elementDecl(String str, String str2, Augmentations augmentations) {
        try {
            if (this.fDeclHandler != null) {
                this.fDeclHandler.elementDecl(str, str2);
            }
        } catch (SAXException e2) {
            throw new XNIException(e2);
        }
    }

    @Override // org.apache.xerces.xni.XMLDocumentHandler, org.apache.xerces.parsers.AbstractXMLDocumentParser
    public void endCDATA(Augmentations augmentations) {
        try {
            if (this.fLexicalHandler != null) {
                this.fLexicalHandler.endCDATA();
            }
        } catch (SAXException e2) {
            throw new XNIException(e2);
        }
    }

    @Override // org.apache.xerces.xni.XMLDTDHandler, org.apache.xerces.parsers.AbstractXMLDocumentParser
    public void endDTD(Augmentations augmentations) {
        this.fInDTD = false;
        try {
            if (this.fLexicalHandler != null) {
                this.fLexicalHandler.endDTD();
            }
            SymbolHash symbolHash = this.fDeclaredAttrs;
            if (symbolHash != null) {
                symbolHash.clear();
            }
        } catch (SAXException e2) {
            throw new XNIException(e2);
        }
    }

    @Override // org.apache.xerces.xni.XMLDocumentHandler, org.apache.xerces.parsers.AbstractXMLDocumentParser
    public void endDocument(Augmentations augmentations) {
        try {
            if (this.fDocumentHandler != null) {
                this.fDocumentHandler.endDocument();
            }
            if (this.fContentHandler != null) {
                this.fContentHandler.endDocument();
            }
        } catch (SAXException e2) {
            throw new XNIException(e2);
        }
    }

    @Override // org.apache.xerces.xni.XMLDocumentHandler, org.apache.xerces.parsers.AbstractXMLDocumentParser
    public void endElement(QName qName, Augmentations augmentations) {
        try {
            if (this.fDocumentHandler != null) {
                this.fDocumentHandler.endElement(qName.rawname);
            }
            if (this.fContentHandler != null) {
                this.fAugmentations = augmentations;
                String str = "";
                String str2 = qName.uri != null ? qName.uri : str;
                if (this.fNamespaces) {
                    str = qName.localpart;
                }
                this.fContentHandler.endElement(str2, str, qName.rawname);
                if (this.fNamespaces) {
                    endNamespaceMapping();
                }
            }
        } catch (SAXException e2) {
            throw new XNIException(e2);
        }
    }

    @Override // org.apache.xerces.xni.XMLDTDHandler, org.apache.xerces.parsers.AbstractXMLDocumentParser
    public void endExternalSubset(Augmentations augmentations) {
        endParameterEntity("[dtd]", augmentations);
    }

    @Override // org.apache.xerces.xni.XMLDocumentHandler, org.apache.xerces.parsers.AbstractXMLDocumentParser
    public void endGeneralEntity(String str, Augmentations augmentations) {
        if (augmentations != null) {
            try {
                if (Boolean.TRUE.equals(augmentations.getItem(Constants.ENTITY_SKIPPED))) {
                    return;
                }
            } catch (SAXException e2) {
                throw new XNIException(e2);
            }
        }
        if (this.fLexicalHandler != null) {
            this.fLexicalHandler.endEntity(str);
        }
    }

    public final void endNamespaceMapping() {
        int declaredPrefixCount = this.fNamespaceContext.getDeclaredPrefixCount();
        if (declaredPrefixCount > 0) {
            for (int i2 = 0; i2 < declaredPrefixCount; i2++) {
                this.fContentHandler.endPrefixMapping(this.fNamespaceContext.getDeclaredPrefixAt(i2));
            }
        }
    }

    @Override // org.apache.xerces.xni.XMLDTDHandler, org.apache.xerces.parsers.AbstractXMLDocumentParser
    public void endParameterEntity(String str, Augmentations augmentations) {
        if (augmentations != null) {
            try {
                if (Boolean.TRUE.equals(augmentations.getItem(Constants.ENTITY_SKIPPED))) {
                    return;
                }
            } catch (SAXException e2) {
                throw new XNIException(e2);
            }
        }
        if (this.fLexicalHandler != null && this.fLexicalHandlerParameterEntities) {
            this.fLexicalHandler.endEntity(str);
        }
    }

    @Override // org.apache.xerces.xni.XMLDTDHandler, org.apache.xerces.parsers.AbstractXMLDocumentParser
    public void externalEntityDecl(String str, XMLResourceIdentifier xMLResourceIdentifier, Augmentations augmentations) {
        try {
            if (this.fDeclHandler != null) {
                this.fDeclHandler.externalEntityDecl(str, xMLResourceIdentifier.getPublicId(), this.fResolveDTDURIs ? xMLResourceIdentifier.getExpandedSystemId() : xMLResourceIdentifier.getLiteralSystemId());
            }
        } catch (SAXException e2) {
            throw new XNIException(e2);
        }
    }

    @Override // org.apache.xerces.xs.PSVIProvider
    public AttributePSVI getAttributePSVI(int i2) {
        return (AttributePSVI) this.fAttributesProxy.fAttributes.getAugmentations(i2).getItem(Constants.ATTRIBUTE_PSVI);
    }

    @Override // org.apache.xerces.xs.PSVIProvider
    public AttributePSVI getAttributePSVIByName(String str, String str2) {
        return (AttributePSVI) this.fAttributesProxy.fAttributes.getAugmentations(str, str2).getItem(Constants.ATTRIBUTE_PSVI);
    }

    @Override // org.xml.sax.XMLReader
    public ContentHandler getContentHandler() {
        return this.fContentHandler;
    }

    @Override // org.xml.sax.XMLReader
    public DTDHandler getDTDHandler() {
        return this.fDTDHandler;
    }

    public DeclHandler getDeclHandler() {
        return this.fDeclHandler;
    }

    @Override // org.apache.xerces.xs.PSVIProvider
    public ElementPSVI getElementPSVI() {
        Augmentations augmentations = this.fAugmentations;
        if (augmentations != null) {
            return (ElementPSVI) augmentations.getItem(Constants.ELEMENT_PSVI);
        }
        return null;
    }

    @Override // org.xml.sax.XMLReader
    public EntityResolver getEntityResolver() {
        try {
            XMLEntityResolver xMLEntityResolver = (XMLEntityResolver) this.fConfiguration.getProperty("http://apache.org/xml/properties/internal/entity-resolver");
            if (xMLEntityResolver == null) {
                return null;
            }
            if (xMLEntityResolver instanceof EntityResolverWrapper) {
                return ((EntityResolverWrapper) xMLEntityResolver).getEntityResolver();
            }
            if (xMLEntityResolver instanceof EntityResolver2Wrapper) {
                return ((EntityResolver2Wrapper) xMLEntityResolver).getEntityResolver();
            }
            return null;
        } catch (XMLConfigurationException unused) {
            return null;
        }
    }

    @Override // org.xml.sax.XMLReader
    public ErrorHandler getErrorHandler() {
        try {
            XMLErrorHandler xMLErrorHandler = (XMLErrorHandler) this.fConfiguration.getProperty("http://apache.org/xml/properties/internal/error-handler");
            if (xMLErrorHandler == null || !(xMLErrorHandler instanceof ErrorHandlerWrapper)) {
                return null;
            }
            return ((ErrorHandlerWrapper) xMLErrorHandler).getErrorHandler();
        } catch (XMLConfigurationException unused) {
            return null;
        }
    }

    @Override // org.xml.sax.XMLReader
    public boolean getFeature(String str) {
        try {
            if (str.startsWith("http://xml.org/sax/features/")) {
                int length = str.length() - 28;
                if (length == 18 && str.endsWith(Constants.NAMESPACE_PREFIXES_FEATURE)) {
                    return this.fNamespacePrefixes;
                }
                if (length == 16 && str.endsWith(Constants.STRING_INTERNING_FEATURE)) {
                    return true;
                }
                if (length == 13 && str.endsWith(Constants.IS_STANDALONE_FEATURE)) {
                    return this.fStandalone;
                }
                if (length == 7 && str.endsWith(Constants.XML_11_FEATURE)) {
                    return this.fConfiguration instanceof XML11Configurable;
                }
                if (length == 34 && str.endsWith(Constants.LEXICAL_HANDLER_PARAMETER_ENTITIES_FEATURE)) {
                    return this.fLexicalHandlerParameterEntities;
                }
                if (length == 16 && str.endsWith(Constants.RESOLVE_DTD_URIS_FEATURE)) {
                    return this.fResolveDTDURIs;
                }
                if (length == 10 && str.endsWith(Constants.XMLNS_URIS_FEATURE)) {
                    return this.fXMLNSURIs;
                }
                if (length == 30 && str.endsWith(Constants.UNICODE_NORMALIZATION_CHECKING_FEATURE)) {
                    return false;
                }
                if (length == 20 && str.endsWith(Constants.USE_ENTITY_RESOLVER2_FEATURE)) {
                    return this.fUseEntityResolver2;
                }
                if ((length == 15 && str.endsWith(Constants.USE_ATTRIBUTES2_FEATURE)) || (length == 12 && str.endsWith(Constants.USE_LOCATOR2_FEATURE))) {
                    return true;
                }
            }
            return this.fConfiguration.getFeature(str);
        } catch (XMLConfigurationException e2) {
            String identifier = e2.getIdentifier();
            if (e2.getType() == 0) {
                throw new SAXNotRecognizedException(SAXMessageFormatter.formatMessage(this.fConfiguration.getLocale(), "feature-not-recognized", new Object[]{identifier}));
            }
            throw new SAXNotSupportedException(SAXMessageFormatter.formatMessage(this.fConfiguration.getLocale(), "feature-not-supported", new Object[]{identifier}));
        }
    }

    public LexicalHandler getLexicalHandler() {
        return this.fLexicalHandler;
    }

    @Override // org.xml.sax.XMLReader
    public Object getProperty(String str) {
        try {
            if (str.startsWith(Constants.SAX_PROPERTY_PREFIX)) {
                int length = str.length() - 30;
                if (length == 20 && str.endsWith(Constants.DOCUMENT_XML_VERSION_PROPERTY)) {
                    return this.fVersion;
                }
                if (length == 15 && str.endsWith(Constants.LEXICAL_HANDLER_PROPERTY)) {
                    return getLexicalHandler();
                }
                if (length == 19 && str.endsWith(Constants.DECLARATION_HANDLER_PROPERTY)) {
                    return getDeclHandler();
                }
                if (length == 8) {
                    if (str.endsWith(Constants.DOM_NODE_PROPERTY)) {
                        throw new SAXNotSupportedException(SAXMessageFormatter.formatMessage(this.fConfiguration.getLocale(), "dom-node-read-not-supported", null));
                    }
                }
            }
            return this.fConfiguration.getProperty(str);
        } catch (XMLConfigurationException e2) {
            String identifier = e2.getIdentifier();
            if (e2.getType() == 0) {
                throw new SAXNotRecognizedException(SAXMessageFormatter.formatMessage(this.fConfiguration.getLocale(), "property-not-recognized", new Object[]{identifier}));
            }
            throw new SAXNotSupportedException(SAXMessageFormatter.formatMessage(this.fConfiguration.getLocale(), "property-not-supported", new Object[]{identifier}));
        }
    }

    @Override // org.apache.xerces.xni.XMLDocumentHandler, org.apache.xerces.parsers.AbstractXMLDocumentParser
    public void ignorableWhitespace(XMLString xMLString, Augmentations augmentations) {
        try {
            if (this.fDocumentHandler != null) {
                this.fDocumentHandler.ignorableWhitespace(xMLString.ch, xMLString.offset, xMLString.length);
            }
            if (this.fContentHandler != null) {
                this.fContentHandler.ignorableWhitespace(xMLString.ch, xMLString.offset, xMLString.length);
            }
        } catch (SAXException e2) {
            throw new XNIException(e2);
        }
    }

    @Override // org.apache.xerces.xni.XMLDTDHandler, org.apache.xerces.parsers.AbstractXMLDocumentParser
    public void internalEntityDecl(String str, XMLString xMLString, XMLString xMLString2, Augmentations augmentations) {
        try {
            if (this.fDeclHandler != null) {
                this.fDeclHandler.internalEntityDecl(str, xMLString.toString());
            }
        } catch (SAXException e2) {
            throw new XNIException(e2);
        }
    }

    @Override // org.apache.xerces.xni.XMLDTDHandler, org.apache.xerces.parsers.AbstractXMLDocumentParser
    public void notationDecl(String str, XMLResourceIdentifier xMLResourceIdentifier, Augmentations augmentations) {
        try {
            if (this.fDTDHandler != null) {
                this.fDTDHandler.notationDecl(str, xMLResourceIdentifier.getPublicId(), this.fResolveDTDURIs ? xMLResourceIdentifier.getExpandedSystemId() : xMLResourceIdentifier.getLiteralSystemId());
            }
        } catch (SAXException e2) {
            throw new XNIException(e2);
        }
    }

    @Override // org.xml.sax.Parser, org.xml.sax.XMLReader
    public void parse(String str) {
        try {
            parse(new XMLInputSource(null, str, null));
        } catch (XMLParseException e2) {
            Exception exception = e2.getException();
            if (exception == null || (exception instanceof CharConversionException)) {
                Locator2Impl locator2Impl = new Locator2Impl();
                locator2Impl.setXMLVersion(this.fVersion);
                locator2Impl.setPublicId(e2.getPublicId());
                locator2Impl.setSystemId(e2.getExpandedSystemId());
                locator2Impl.setLineNumber(e2.getLineNumber());
                locator2Impl.setColumnNumber(e2.getColumnNumber());
                if (exception == null) {
                    throw new SAXParseException(e2.getMessage(), locator2Impl);
                }
                throw new SAXParseException(e2.getMessage(), locator2Impl, exception);
            } else if (exception instanceof SAXException) {
                throw ((SAXException) exception);
            } else if (exception instanceof IOException) {
                throw ((IOException) exception);
            } else {
                throw new SAXException(exception);
            }
        } catch (XNIException e3) {
            Exception exception2 = e3.getException();
            if (exception2 == null) {
                throw new SAXException(e3.getMessage());
            } else if (exception2 instanceof SAXException) {
                throw ((SAXException) exception2);
            } else if (exception2 instanceof IOException) {
                throw ((IOException) exception2);
            } else {
                throw new SAXException(exception2);
            }
        }
    }

    @Override // org.xml.sax.Parser, org.xml.sax.XMLReader
    public void parse(InputSource inputSource) {
        try {
            XMLInputSource xMLInputSource = new XMLInputSource(inputSource.getPublicId(), inputSource.getSystemId(), null);
            xMLInputSource.setByteStream(inputSource.getByteStream());
            xMLInputSource.setCharacterStream(inputSource.getCharacterStream());
            xMLInputSource.setEncoding(inputSource.getEncoding());
            parse(xMLInputSource);
        } catch (XMLParseException e2) {
            Exception exception = e2.getException();
            if (exception == null || (exception instanceof CharConversionException)) {
                Locator2Impl locator2Impl = new Locator2Impl();
                locator2Impl.setXMLVersion(this.fVersion);
                locator2Impl.setPublicId(e2.getPublicId());
                locator2Impl.setSystemId(e2.getExpandedSystemId());
                locator2Impl.setLineNumber(e2.getLineNumber());
                locator2Impl.setColumnNumber(e2.getColumnNumber());
                if (exception == null) {
                    throw new SAXParseException(e2.getMessage(), locator2Impl);
                }
                throw new SAXParseException(e2.getMessage(), locator2Impl, exception);
            } else if (exception instanceof SAXException) {
                throw ((SAXException) exception);
            } else if (exception instanceof IOException) {
                throw ((IOException) exception);
            } else {
                throw new SAXException(exception);
            }
        } catch (XNIException e3) {
            Exception exception2 = e3.getException();
            if (exception2 == null) {
                throw new SAXException(e3.getMessage());
            } else if (exception2 instanceof SAXException) {
                throw ((SAXException) exception2);
            } else if (exception2 instanceof IOException) {
                throw ((IOException) exception2);
            } else {
                throw new SAXException(exception2);
            }
        }
    }

    @Override // org.apache.xerces.xni.XMLDocumentHandler, org.apache.xerces.xni.XMLDTDHandler, org.apache.xerces.parsers.AbstractXMLDocumentParser
    public void processingInstruction(String str, XMLString xMLString, Augmentations augmentations) {
        try {
            if (this.fDocumentHandler != null) {
                this.fDocumentHandler.processingInstruction(str, xMLString.toString());
            }
            if (this.fContentHandler != null) {
                this.fContentHandler.processingInstruction(str, xMLString.toString());
            }
        } catch (SAXException e2) {
            throw new XNIException(e2);
        }
    }

    @Override // org.apache.xerces.parsers.AbstractXMLDocumentParser, org.apache.xerces.parsers.XMLParser
    public void reset() {
        super.reset();
        this.fInDTD = false;
        this.fVersion = "1.0";
        this.fStandalone = false;
        this.fNamespaces = this.fConfiguration.getFeature("http://xml.org/sax/features/namespaces");
        this.fAugmentations = null;
        this.fDeclaredAttrs = null;
    }

    @Override // org.xml.sax.XMLReader
    public void setContentHandler(ContentHandler contentHandler) {
        this.fContentHandler = contentHandler;
    }

    @Override // org.xml.sax.Parser, org.xml.sax.XMLReader
    public void setDTDHandler(DTDHandler dTDHandler) {
        this.fDTDHandler = dTDHandler;
    }

    public void setDeclHandler(DeclHandler declHandler) {
        if (!this.fParseInProgress) {
            this.fDeclHandler = declHandler;
            return;
        }
        throw new SAXNotSupportedException(SAXMessageFormatter.formatMessage(this.fConfiguration.getLocale(), "property-not-parsing-supported", new Object[]{DECLARATION_HANDLER}));
    }

    @Override // org.xml.sax.Parser
    public void setDocumentHandler(DocumentHandler documentHandler) {
        this.fDocumentHandler = documentHandler;
    }

    @Override // org.xml.sax.Parser, org.xml.sax.XMLReader
    public void setEntityResolver(EntityResolver entityResolver) {
        XMLParserConfiguration xMLParserConfiguration;
        Object entityResolverWrapper;
        try {
            XMLEntityResolver xMLEntityResolver = (XMLEntityResolver) this.fConfiguration.getProperty("http://apache.org/xml/properties/internal/entity-resolver");
            if (!this.fUseEntityResolver2 || !(entityResolver instanceof EntityResolver2)) {
                if (xMLEntityResolver instanceof EntityResolverWrapper) {
                    ((EntityResolverWrapper) xMLEntityResolver).setEntityResolver(entityResolver);
                    return;
                } else {
                    xMLParserConfiguration = this.fConfiguration;
                    entityResolverWrapper = new EntityResolverWrapper(entityResolver);
                }
            } else if (xMLEntityResolver instanceof EntityResolver2Wrapper) {
                ((EntityResolver2Wrapper) xMLEntityResolver).setEntityResolver((EntityResolver2) entityResolver);
                return;
            } else {
                xMLParserConfiguration = this.fConfiguration;
                entityResolverWrapper = new EntityResolver2Wrapper((EntityResolver2) entityResolver);
            }
            xMLParserConfiguration.setProperty("http://apache.org/xml/properties/internal/entity-resolver", entityResolverWrapper);
        } catch (XMLConfigurationException unused) {
        }
    }

    @Override // org.xml.sax.Parser, org.xml.sax.XMLReader
    public void setErrorHandler(ErrorHandler errorHandler) {
        try {
            XMLErrorHandler xMLErrorHandler = (XMLErrorHandler) this.fConfiguration.getProperty("http://apache.org/xml/properties/internal/error-handler");
            if (xMLErrorHandler instanceof ErrorHandlerWrapper) {
                ((ErrorHandlerWrapper) xMLErrorHandler).setErrorHandler(errorHandler);
            } else {
                this.fConfiguration.setProperty("http://apache.org/xml/properties/internal/error-handler", new ErrorHandlerWrapper(errorHandler));
            }
        } catch (XMLConfigurationException unused) {
        }
    }

    @Override // org.xml.sax.XMLReader
    public void setFeature(String str, boolean z) {
        try {
            if (str.startsWith("http://xml.org/sax/features/")) {
                int length = str.length() - 28;
                if (length == 10 && str.endsWith("namespaces")) {
                    this.fConfiguration.setFeature(str, z);
                    this.fNamespaces = z;
                    return;
                } else if (length == 18 && str.endsWith(Constants.NAMESPACE_PREFIXES_FEATURE)) {
                    this.fNamespacePrefixes = z;
                    return;
                } else if (length != 16 || !str.endsWith(Constants.STRING_INTERNING_FEATURE)) {
                    if (length == 34 && str.endsWith(Constants.LEXICAL_HANDLER_PARAMETER_ENTITIES_FEATURE)) {
                        this.fLexicalHandlerParameterEntities = z;
                        return;
                    } else if (length == 16 && str.endsWith(Constants.RESOLVE_DTD_URIS_FEATURE)) {
                        this.fResolveDTDURIs = z;
                        return;
                    } else if (length != 30 || !str.endsWith(Constants.UNICODE_NORMALIZATION_CHECKING_FEATURE)) {
                        if (length == 10 && str.endsWith(Constants.XMLNS_URIS_FEATURE)) {
                            this.fXMLNSURIs = z;
                            return;
                        } else if (length != 20 || !str.endsWith(Constants.USE_ENTITY_RESOLVER2_FEATURE)) {
                            if ((length != 13 || !str.endsWith(Constants.IS_STANDALONE_FEATURE)) && ((length != 15 || !str.endsWith(Constants.USE_ATTRIBUTES2_FEATURE)) && (length != 12 || !str.endsWith(Constants.USE_LOCATOR2_FEATURE)))) {
                                if (length == 7) {
                                    if (!str.endsWith(Constants.XML_11_FEATURE)) {
                                    }
                                }
                            }
                            throw new SAXNotSupportedException(SAXMessageFormatter.formatMessage(this.fConfiguration.getLocale(), "feature-read-only", new Object[]{str}));
                        } else if (z != this.fUseEntityResolver2) {
                            this.fUseEntityResolver2 = z;
                            setEntityResolver(getEntityResolver());
                            return;
                        } else {
                            return;
                        }
                    } else if (z) {
                        throw new SAXNotSupportedException(SAXMessageFormatter.formatMessage(this.fConfiguration.getLocale(), "true-not-supported", new Object[]{str}));
                    } else {
                        return;
                    }
                } else if (!z) {
                    throw new SAXNotSupportedException(SAXMessageFormatter.formatMessage(this.fConfiguration.getLocale(), "false-not-supported", new Object[]{str}));
                } else {
                    return;
                }
            }
            this.fConfiguration.setFeature(str, z);
        } catch (XMLConfigurationException e2) {
            String identifier = e2.getIdentifier();
            if (e2.getType() == 0) {
                throw new SAXNotRecognizedException(SAXMessageFormatter.formatMessage(this.fConfiguration.getLocale(), "feature-not-recognized", new Object[]{identifier}));
            }
            throw new SAXNotSupportedException(SAXMessageFormatter.formatMessage(this.fConfiguration.getLocale(), "feature-not-supported", new Object[]{identifier}));
        }
    }

    public void setLexicalHandler(LexicalHandler lexicalHandler) {
        if (!this.fParseInProgress) {
            this.fLexicalHandler = lexicalHandler;
            return;
        }
        throw new SAXNotSupportedException(SAXMessageFormatter.formatMessage(this.fConfiguration.getLocale(), "property-not-parsing-supported", new Object[]{"http://xml.org/sax/properties/lexical-handler"}));
    }

    @Override // org.xml.sax.Parser
    public void setLocale(Locale locale) {
        this.fConfiguration.setLocale(locale);
    }

    @Override // org.xml.sax.XMLReader
    public void setProperty(String str, Object obj) {
        try {
            if (str.startsWith(Constants.SAX_PROPERTY_PREFIX)) {
                int length = str.length() - 30;
                if (length == 15 && str.endsWith(Constants.LEXICAL_HANDLER_PROPERTY)) {
                    try {
                        setLexicalHandler((LexicalHandler) obj);
                        return;
                    } catch (ClassCastException unused) {
                        throw new SAXNotSupportedException(SAXMessageFormatter.formatMessage(this.fConfiguration.getLocale(), "incompatible-class", new Object[]{str, "org.xml.sax.ext.LexicalHandler"}));
                    }
                } else if (length == 19 && str.endsWith(Constants.DECLARATION_HANDLER_PROPERTY)) {
                    try {
                        setDeclHandler((DeclHandler) obj);
                        return;
                    } catch (ClassCastException unused2) {
                        throw new SAXNotSupportedException(SAXMessageFormatter.formatMessage(this.fConfiguration.getLocale(), "incompatible-class", new Object[]{str, "org.xml.sax.ext.DeclHandler"}));
                    }
                } else if ((length == 8 && str.endsWith(Constants.DOM_NODE_PROPERTY)) || (length == 20 && str.endsWith(Constants.DOCUMENT_XML_VERSION_PROPERTY))) {
                    throw new SAXNotSupportedException(SAXMessageFormatter.formatMessage(this.fConfiguration.getLocale(), "property-read-only", new Object[]{str}));
                }
            }
            this.fConfiguration.setProperty(str, obj);
        } catch (XMLConfigurationException e2) {
            String identifier = e2.getIdentifier();
            if (e2.getType() == 0) {
                throw new SAXNotRecognizedException(SAXMessageFormatter.formatMessage(this.fConfiguration.getLocale(), "property-not-recognized", new Object[]{identifier}));
            }
            throw new SAXNotSupportedException(SAXMessageFormatter.formatMessage(this.fConfiguration.getLocale(), "property-not-supported", new Object[]{identifier}));
        }
    }

    @Override // org.apache.xerces.xni.XMLDocumentHandler, org.apache.xerces.parsers.AbstractXMLDocumentParser
    public void startCDATA(Augmentations augmentations) {
        try {
            if (this.fLexicalHandler != null) {
                this.fLexicalHandler.startCDATA();
            }
        } catch (SAXException e2) {
            throw new XNIException(e2);
        }
    }

    @Override // org.apache.xerces.xni.XMLDocumentHandler, org.apache.xerces.parsers.AbstractXMLDocumentParser
    public void startDocument(XMLLocator xMLLocator, String str, NamespaceContext namespaceContext, Augmentations augmentations) {
        this.fNamespaceContext = namespaceContext;
        try {
            if (this.fDocumentHandler != null) {
                if (xMLLocator != null) {
                    this.fDocumentHandler.setDocumentLocator(new LocatorProxy(xMLLocator));
                }
                if (this.fDocumentHandler != null) {
                    this.fDocumentHandler.startDocument();
                }
            }
            if (this.fContentHandler != null) {
                if (xMLLocator != null) {
                    this.fContentHandler.setDocumentLocator(new LocatorProxy(xMLLocator));
                }
                if (this.fContentHandler != null) {
                    this.fContentHandler.startDocument();
                }
            }
        } catch (SAXException e2) {
            throw new XNIException(e2);
        }
    }

    @Override // org.apache.xerces.xni.XMLDocumentHandler, org.apache.xerces.parsers.AbstractXMLDocumentParser
    public void startElement(QName qName, XMLAttributes xMLAttributes, Augmentations augmentations) {
        try {
            if (this.fDocumentHandler != null) {
                this.fAttributesProxy.setAttributes(xMLAttributes);
                this.fDocumentHandler.startElement(qName.rawname, this.fAttributesProxy);
            }
            if (this.fContentHandler != null) {
                String str = "";
                if (this.fNamespaces) {
                    startNamespaceMapping();
                    int length = xMLAttributes.getLength();
                    if (!this.fNamespacePrefixes) {
                        for (int i2 = length - 1; i2 >= 0; i2--) {
                            xMLAttributes.getName(i2, this.fQName);
                            if (this.fQName.prefix == XMLSymbols.PREFIX_XMLNS || this.fQName.rawname == XMLSymbols.PREFIX_XMLNS) {
                                xMLAttributes.removeAttributeAt(i2);
                            }
                        }
                    } else if (!this.fXMLNSURIs) {
                        for (int i3 = length - 1; i3 >= 0; i3--) {
                            xMLAttributes.getName(i3, this.fQName);
                            if (this.fQName.prefix == XMLSymbols.PREFIX_XMLNS || this.fQName.rawname == XMLSymbols.PREFIX_XMLNS) {
                                this.fQName.prefix = str;
                                this.fQName.uri = str;
                                this.fQName.localpart = str;
                                xMLAttributes.setName(i3, this.fQName);
                            }
                        }
                    }
                }
                this.fAugmentations = augmentations;
                String str2 = qName.uri != null ? qName.uri : str;
                if (this.fNamespaces) {
                    str = qName.localpart;
                }
                this.fAttributesProxy.setAttributes(xMLAttributes);
                this.fContentHandler.startElement(str2, str, qName.rawname, this.fAttributesProxy);
            }
        } catch (SAXException e2) {
            throw new XNIException(e2);
        }
    }

    @Override // org.apache.xerces.xni.XMLDTDHandler, org.apache.xerces.parsers.AbstractXMLDocumentParser
    public void startExternalSubset(XMLResourceIdentifier xMLResourceIdentifier, Augmentations augmentations) {
        startParameterEntity("[dtd]", null, null, augmentations);
    }

    @Override // org.apache.xerces.xni.XMLDocumentHandler, org.apache.xerces.parsers.AbstractXMLDocumentParser
    public void startGeneralEntity(String str, XMLResourceIdentifier xMLResourceIdentifier, String str2, Augmentations augmentations) {
        if (augmentations != null) {
            try {
                if (Boolean.TRUE.equals(augmentations.getItem(Constants.ENTITY_SKIPPED))) {
                    if (this.fContentHandler != null) {
                        this.fContentHandler.skippedEntity(str);
                        return;
                    }
                    return;
                }
            } catch (SAXException e2) {
                throw new XNIException(e2);
            }
        }
        if (this.fLexicalHandler != null) {
            this.fLexicalHandler.startEntity(str);
        }
    }

    public final void startNamespaceMapping() {
        int declaredPrefixCount = this.fNamespaceContext.getDeclaredPrefixCount();
        if (declaredPrefixCount > 0) {
            for (int i2 = 0; i2 < declaredPrefixCount; i2++) {
                String declaredPrefixAt = this.fNamespaceContext.getDeclaredPrefixAt(i2);
                String uri = this.fNamespaceContext.getURI(declaredPrefixAt);
                ContentHandler contentHandler = this.fContentHandler;
                if (uri == null) {
                    uri = "";
                }
                contentHandler.startPrefixMapping(declaredPrefixAt, uri);
            }
        }
    }

    @Override // org.apache.xerces.xni.XMLDTDHandler, org.apache.xerces.parsers.AbstractXMLDocumentParser
    public void startParameterEntity(String str, XMLResourceIdentifier xMLResourceIdentifier, String str2, Augmentations augmentations) {
        if (augmentations != null) {
            try {
                if (Boolean.TRUE.equals(augmentations.getItem(Constants.ENTITY_SKIPPED))) {
                    if (this.fContentHandler != null) {
                        this.fContentHandler.skippedEntity(str);
                        return;
                    }
                    return;
                }
            } catch (SAXException e2) {
                throw new XNIException(e2);
            }
        }
        if (this.fLexicalHandler != null && this.fLexicalHandlerParameterEntities) {
            this.fLexicalHandler.startEntity(str);
        }
    }

    @Override // org.apache.xerces.xni.XMLDTDHandler, org.apache.xerces.parsers.AbstractXMLDocumentParser
    public void unparsedEntityDecl(String str, XMLResourceIdentifier xMLResourceIdentifier, String str2, Augmentations augmentations) {
        try {
            if (this.fDTDHandler != null) {
                this.fDTDHandler.unparsedEntityDecl(str, xMLResourceIdentifier.getPublicId(), this.fResolveDTDURIs ? xMLResourceIdentifier.getExpandedSystemId() : xMLResourceIdentifier.getLiteralSystemId(), str2);
            }
        } catch (SAXException e2) {
            throw new XNIException(e2);
        }
    }

    @Override // org.apache.xerces.xni.XMLDocumentHandler, org.apache.xerces.parsers.AbstractXMLDocumentParser
    public void xmlDecl(String str, String str2, String str3, Augmentations augmentations) {
        this.fVersion = str;
        this.fStandalone = "yes".equals(str3);
    }
}
