package org.apache.xerces.util;

import b.b.a.a.a;
import java.io.PrintWriter;
import java.util.Hashtable;
import org.apache.poi.xssf.usermodel.XSSFDataValidationConstraint;
import org.apache.xerces.dom.DOMErrorImpl;
import org.apache.xerces.dom.DOMLocatorImpl;
import org.apache.xerces.xni.parser.XMLErrorHandler;
import org.apache.xerces.xni.parser.XMLParseException;
import org.w3c.dom.DOMError;
import org.w3c.dom.DOMErrorHandler;
import org.w3c.dom.DOMLocator;
import org.w3c.dom.Node;

public class DOMErrorHandlerWrapper implements XMLErrorHandler, DOMErrorHandler {
    public boolean eStatus;
    public Node fCurrentNode;
    public final DOMErrorImpl fDOMError;
    public DOMErrorHandler fDomErrorHandler;
    public final XMLErrorCode fErrorCode;
    public PrintWriter fOut;

    public static class DOMErrorTypeMap {
        public static Hashtable fgDOMErrorTypeTable;

        static {
            Hashtable hashtable = new Hashtable();
            fgDOMErrorTypeTable = hashtable;
            a.a("http://www.w3.org/TR/1998/REC-xml-19980210", "InvalidCharInCDSect", hashtable, "wf-invalid-character");
            a.a("http://www.w3.org/TR/1998/REC-xml-19980210", "InvalidCharInContent", fgDOMErrorTypeTable, "wf-invalid-character");
            a.a("http://www.w3.org/TR/1998/REC-xml-19980210", "TwoColonsInQName", fgDOMErrorTypeTable, "wf-invalid-character-in-node-name");
            a.a("http://www.w3.org/TR/1998/REC-xml-19980210", "ColonNotLegalWithNS", fgDOMErrorTypeTable, "wf-invalid-character-in-node-name");
            a.a("http://www.w3.org/TR/1998/REC-xml-19980210", "InvalidCharInProlog", fgDOMErrorTypeTable, "wf-invalid-character");
            a.a("http://www.w3.org/TR/1998/REC-xml-19980210", "CDEndInContent", fgDOMErrorTypeTable, "wf-invalid-character");
            a.a("http://www.w3.org/TR/1998/REC-xml-19980210", "CDSectUnterminated", fgDOMErrorTypeTable, "wf-invalid-character");
            a.a("http://www.w3.org/TR/1998/REC-xml-19980210", "DoctypeNotAllowed", fgDOMErrorTypeTable, "doctype-not-allowed");
            a.a("http://www.w3.org/TR/1998/REC-xml-19980210", "ETagRequired", fgDOMErrorTypeTable, "wf-invalid-character-in-node-name");
            a.a("http://www.w3.org/TR/1998/REC-xml-19980210", "ElementUnterminated", fgDOMErrorTypeTable, "wf-invalid-character-in-node-name");
            a.a("http://www.w3.org/TR/1998/REC-xml-19980210", "EqRequiredInAttribute", fgDOMErrorTypeTable, "wf-invalid-character");
            a.a("http://www.w3.org/TR/1998/REC-xml-19980210", "OpenQuoteExpected", fgDOMErrorTypeTable, "wf-invalid-character");
            a.a("http://www.w3.org/TR/1998/REC-xml-19980210", "CloseQuoteExpected", fgDOMErrorTypeTable, "wf-invalid-character");
            a.a("http://www.w3.org/TR/1998/REC-xml-19980210", "ETagUnterminated", fgDOMErrorTypeTable, "wf-invalid-character-in-node-name");
            a.a("http://www.w3.org/TR/1998/REC-xml-19980210", "MarkupNotRecognizedInContent", fgDOMErrorTypeTable, "wf-invalid-character");
            a.a("http://www.w3.org/TR/1998/REC-xml-19980210", "DoctypeIllegalInContent", fgDOMErrorTypeTable, "doctype-not-allowed");
            a.a("http://www.w3.org/TR/1998/REC-xml-19980210", "InvalidCharInAttValue", fgDOMErrorTypeTable, "wf-invalid-character");
            a.a("http://www.w3.org/TR/1998/REC-xml-19980210", "InvalidCharInPI", fgDOMErrorTypeTable, "wf-invalid-character");
            a.a("http://www.w3.org/TR/1998/REC-xml-19980210", "InvalidCharInInternalSubset", fgDOMErrorTypeTable, "wf-invalid-character");
            a.a("http://www.w3.org/TR/1998/REC-xml-19980210", "QuoteRequiredInAttValue", fgDOMErrorTypeTable, "wf-invalid-character");
            a.a("http://www.w3.org/TR/1998/REC-xml-19980210", "LessthanInAttValue", fgDOMErrorTypeTable, "wf-invalid-character");
            a.a("http://www.w3.org/TR/1998/REC-xml-19980210", "AttributeValueUnterminated", fgDOMErrorTypeTable, "wf-invalid-character");
            a.a("http://www.w3.org/TR/1998/REC-xml-19980210", "PITargetRequired", fgDOMErrorTypeTable, "wf-invalid-character");
            a.a("http://www.w3.org/TR/1998/REC-xml-19980210", "SpaceRequiredInPI", fgDOMErrorTypeTable, "wf-invalid-character");
            a.a("http://www.w3.org/TR/1998/REC-xml-19980210", "PIUnterminated", fgDOMErrorTypeTable, "wf-invalid-character");
            a.a("http://www.w3.org/TR/1998/REC-xml-19980210", "ReservedPITarget", fgDOMErrorTypeTable, "wf-invalid-character");
            a.a("http://www.w3.org/TR/1998/REC-xml-19980210", "PI_NOT_IN_ONE_ENTITY", fgDOMErrorTypeTable, "wf-invalid-character");
            a.a("http://www.w3.org/TR/1998/REC-xml-19980210", "PINotInOneEntity", fgDOMErrorTypeTable, "wf-invalid-character");
            a.a("http://www.w3.org/TR/1998/REC-xml-19980210", "EncodingDeclInvalid", fgDOMErrorTypeTable, "unsupported-encoding");
            a.a("http://www.w3.org/TR/1998/REC-xml-19980210", "EncodingByteOrderUnsupported", fgDOMErrorTypeTable, "unsupported-encoding");
            a.a("http://www.w3.org/TR/1998/REC-xml-19980210", "InvalidCharInEntityValue", fgDOMErrorTypeTable, "wf-invalid-character-in-node-name");
            a.a("http://www.w3.org/TR/1998/REC-xml-19980210", "InvalidCharInExternalSubset", fgDOMErrorTypeTable, "wf-invalid-character");
            a.a("http://www.w3.org/TR/1998/REC-xml-19980210", "InvalidCharInIgnoreSect", fgDOMErrorTypeTable, "wf-invalid-character");
            a.a("http://www.w3.org/TR/1998/REC-xml-19980210", "InvalidCharInPublicID", fgDOMErrorTypeTable, "wf-invalid-character");
            a.a("http://www.w3.org/TR/1998/REC-xml-19980210", "InvalidCharInSystemID", fgDOMErrorTypeTable, "wf-invalid-character");
            a.a("http://www.w3.org/TR/1998/REC-xml-19980210", "SpaceRequiredAfterSYSTEM", fgDOMErrorTypeTable, "wf-invalid-character");
            a.a("http://www.w3.org/TR/1998/REC-xml-19980210", "QuoteRequiredInSystemID", fgDOMErrorTypeTable, "wf-invalid-character");
            a.a("http://www.w3.org/TR/1998/REC-xml-19980210", "SystemIDUnterminated", fgDOMErrorTypeTable, "wf-invalid-character");
            a.a("http://www.w3.org/TR/1998/REC-xml-19980210", "SpaceRequiredAfterPUBLIC", fgDOMErrorTypeTable, "wf-invalid-character");
            a.a("http://www.w3.org/TR/1998/REC-xml-19980210", "QuoteRequiredInPublicID", fgDOMErrorTypeTable, "wf-invalid-character");
            a.a("http://www.w3.org/TR/1998/REC-xml-19980210", "PublicIDUnterminated", fgDOMErrorTypeTable, "wf-invalid-character");
            a.a("http://www.w3.org/TR/1998/REC-xml-19980210", "PubidCharIllegal", fgDOMErrorTypeTable, "wf-invalid-character");
            a.a("http://www.w3.org/TR/1998/REC-xml-19980210", "SpaceRequiredBetweenPublicAndSystem", fgDOMErrorTypeTable, "wf-invalid-character");
            a.a("http://www.w3.org/TR/1998/REC-xml-19980210", "MSG_SPACE_REQUIRED_BEFORE_ROOT_ELEMENT_TYPE_IN_DOCTYPEDECL", fgDOMErrorTypeTable, "wf-invalid-character-in-node-name");
            a.a("http://www.w3.org/TR/1998/REC-xml-19980210", "MSG_ROOT_ELEMENT_TYPE_REQUIRED", fgDOMErrorTypeTable, "wf-invalid-character-in-node-name");
            a.a("http://www.w3.org/TR/1998/REC-xml-19980210", "DoctypedeclUnterminated", fgDOMErrorTypeTable, "wf-invalid-character-in-node-name");
            a.a("http://www.w3.org/TR/1998/REC-xml-19980210", "PEReferenceWithinMarkup", fgDOMErrorTypeTable, "wf-invalid-character");
            a.a("http://www.w3.org/TR/1998/REC-xml-19980210", "MSG_MARKUP_NOT_RECOGNIZED_IN_DTD", fgDOMErrorTypeTable, "wf-invalid-character");
            a.a("http://www.w3.org/TR/1998/REC-xml-19980210", "MSG_SPACE_REQUIRED_BEFORE_ELEMENT_TYPE_IN_ELEMENTDECL", fgDOMErrorTypeTable, "wf-invalid-character");
            a.a("http://www.w3.org/TR/1998/REC-xml-19980210", "MSG_ELEMENT_TYPE_REQUIRED_IN_ELEMENTDECL", fgDOMErrorTypeTable, "wf-invalid-character");
            a.a("http://www.w3.org/TR/1998/REC-xml-19980210", "MSG_SPACE_REQUIRED_BEFORE_CONTENTSPEC_IN_ELEMENTDECL", fgDOMErrorTypeTable, "wf-invalid-character");
            a.a("http://www.w3.org/TR/1998/REC-xml-19980210", "MSG_CONTENTSPEC_REQUIRED_IN_ELEMENTDECL", fgDOMErrorTypeTable, "wf-invalid-character");
            a.a("http://www.w3.org/TR/1998/REC-xml-19980210", "ElementDeclUnterminated", fgDOMErrorTypeTable, "wf-invalid-character");
            a.a("http://www.w3.org/TR/1998/REC-xml-19980210", "MSG_OPEN_PAREN_OR_ELEMENT_TYPE_REQUIRED_IN_CHILDREN", fgDOMErrorTypeTable, "wf-invalid-character");
            a.a("http://www.w3.org/TR/1998/REC-xml-19980210", "MSG_CLOSE_PAREN_REQUIRED_IN_CHILDREN", fgDOMErrorTypeTable, "wf-invalid-character");
            a.a("http://www.w3.org/TR/1998/REC-xml-19980210", "MSG_ELEMENT_TYPE_REQUIRED_IN_MIXED_CONTENT", fgDOMErrorTypeTable, "wf-invalid-character");
            a.a("http://www.w3.org/TR/1998/REC-xml-19980210", "MSG_CLOSE_PAREN_REQUIRED_IN_MIXED", fgDOMErrorTypeTable, "wf-invalid-character");
            a.a("http://www.w3.org/TR/1998/REC-xml-19980210", "MixedContentUnterminated", fgDOMErrorTypeTable, "wf-invalid-character");
            a.a("http://www.w3.org/TR/1998/REC-xml-19980210", "MSG_SPACE_REQUIRED_BEFORE_ELEMENT_TYPE_IN_ATTLISTDECL", fgDOMErrorTypeTable, "wf-invalid-character");
            a.a("http://www.w3.org/TR/1998/REC-xml-19980210", "MSG_ELEMENT_TYPE_REQUIRED_IN_ATTLISTDECL", fgDOMErrorTypeTable, "wf-invalid-character");
            a.a("http://www.w3.org/TR/1998/REC-xml-19980210", "MSG_SPACE_REQUIRED_BEFORE_ATTRIBUTE_NAME_IN_ATTDEF", fgDOMErrorTypeTable, "wf-invalid-character");
            a.a("http://www.w3.org/TR/1998/REC-xml-19980210", "AttNameRequiredInAttDef", fgDOMErrorTypeTable, "wf-invalid-character");
            a.a("http://www.w3.org/TR/1998/REC-xml-19980210", "MSG_SPACE_REQUIRED_BEFORE_ATTTYPE_IN_ATTDEF", fgDOMErrorTypeTable, "wf-invalid-character");
            a.a("http://www.w3.org/TR/1998/REC-xml-19980210", "AttTypeRequiredInAttDef", fgDOMErrorTypeTable, "wf-invalid-character");
            a.a("http://www.w3.org/TR/1998/REC-xml-19980210", "MSG_SPACE_REQUIRED_BEFORE_DEFAULTDECL_IN_ATTDEF", fgDOMErrorTypeTable, "wf-invalid-character");
            a.a("http://www.w3.org/TR/1998/REC-xml-19980210", "MSG_DUPLICATE_ATTRIBUTE_DEFINITION", fgDOMErrorTypeTable, "wf-invalid-character");
            a.a("http://www.w3.org/TR/1998/REC-xml-19980210", "MSG_SPACE_REQUIRED_AFTER_NOTATION_IN_NOTATIONTYPE", fgDOMErrorTypeTable, "wf-invalid-character");
            a.a("http://www.w3.org/TR/1998/REC-xml-19980210", "MSG_OPEN_PAREN_REQUIRED_IN_NOTATIONTYPE", fgDOMErrorTypeTable, "wf-invalid-character");
            a.a("http://www.w3.org/TR/1998/REC-xml-19980210", "MSG_NAME_REQUIRED_IN_NOTATIONTYPE", fgDOMErrorTypeTable, "wf-invalid-character");
            a.a("http://www.w3.org/TR/1998/REC-xml-19980210", "NotationTypeUnterminated", fgDOMErrorTypeTable, "wf-invalid-character");
            a.a("http://www.w3.org/TR/1998/REC-xml-19980210", "MSG_NMTOKEN_REQUIRED_IN_ENUMERATION", fgDOMErrorTypeTable, "wf-invalid-character");
            a.a("http://www.w3.org/TR/1998/REC-xml-19980210", "EnumerationUnterminated", fgDOMErrorTypeTable, "wf-invalid-character");
            a.a("http://www.w3.org/TR/1998/REC-xml-19980210", "MSG_DISTINCT_TOKENS_IN_ENUMERATION", fgDOMErrorTypeTable, "wf-invalid-character");
            a.a("http://www.w3.org/TR/1998/REC-xml-19980210", "MSG_DISTINCT_NOTATION_IN_ENUMERATION", fgDOMErrorTypeTable, "wf-invalid-character");
            a.a("http://www.w3.org/TR/1998/REC-xml-19980210", "MSG_SPACE_REQUIRED_AFTER_FIXED_IN_DEFAULTDECL", fgDOMErrorTypeTable, "wf-invalid-character");
            a.a("http://www.w3.org/TR/1998/REC-xml-19980210", "IncludeSectUnterminated", fgDOMErrorTypeTable, "wf-invalid-character");
            a.a("http://www.w3.org/TR/1998/REC-xml-19980210", "IgnoreSectUnterminated", fgDOMErrorTypeTable, "wf-invalid-character");
            a.a("http://www.w3.org/TR/1998/REC-xml-19980210", "NameRequiredInPEReference", fgDOMErrorTypeTable, "wf-invalid-character");
            a.a("http://www.w3.org/TR/1998/REC-xml-19980210", "SemicolonRequiredInPEReference", fgDOMErrorTypeTable, "wf-invalid-character");
            a.a("http://www.w3.org/TR/1998/REC-xml-19980210", "MSG_SPACE_REQUIRED_BEFORE_ENTITY_NAME_IN_ENTITYDECL", fgDOMErrorTypeTable, "wf-invalid-character-in-node-name");
            a.a("http://www.w3.org/TR/1998/REC-xml-19980210", "MSG_SPACE_REQUIRED_BEFORE_PERCENT_IN_PEDECL", fgDOMErrorTypeTable, "wf-invalid-character-in-node-name");
            a.a("http://www.w3.org/TR/1998/REC-xml-19980210", "MSG_SPACE_REQUIRED_BEFORE_ENTITY_NAME_IN_PEDECL", fgDOMErrorTypeTable, "wf-invalid-character-in-node-name");
            a.a("http://www.w3.org/TR/1998/REC-xml-19980210", "MSG_ENTITY_NAME_REQUIRED_IN_ENTITYDECL", fgDOMErrorTypeTable, "wf-invalid-character-in-node-name");
            a.a("http://www.w3.org/TR/1998/REC-xml-19980210", "MSG_SPACE_REQUIRED_AFTER_ENTITY_NAME_IN_ENTITYDECL", fgDOMErrorTypeTable, "wf-invalid-character-in-node-name");
            a.a("http://www.w3.org/TR/1998/REC-xml-19980210", "MSG_SPACE_REQUIRED_BEFORE_NOTATION_NAME_IN_UNPARSED_ENTITYDECL", fgDOMErrorTypeTable, "wf-invalid-character");
            a.a("http://www.w3.org/TR/1998/REC-xml-19980210", "MSG_SPACE_REQUIRED_BEFORE_NDATA_IN_UNPARSED_ENTITYDECL", fgDOMErrorTypeTable, "wf-invalid-character");
            a.a("http://www.w3.org/TR/1998/REC-xml-19980210", "MSG_NOTATION_NAME_REQUIRED_FOR_UNPARSED_ENTITYDECL", fgDOMErrorTypeTable, "wf-invalid-character");
            a.a("http://www.w3.org/TR/1998/REC-xml-19980210", "EntityDeclUnterminated", fgDOMErrorTypeTable, "wf-invalid-character-in-node-name");
            a.a("http://www.w3.org/TR/1998/REC-xml-19980210", "MSG_DUPLICATE_ENTITY_DEFINITION", fgDOMErrorTypeTable, "wf-invalid-character-in-node-name");
            a.a("http://www.w3.org/TR/1998/REC-xml-19980210", "ExternalIDRequired", fgDOMErrorTypeTable, "wf-invalid-character");
            a.a("http://www.w3.org/TR/1998/REC-xml-19980210", "MSG_SPACE_REQUIRED_BEFORE_PUBIDLITERAL_IN_EXTERNALID", fgDOMErrorTypeTable, "wf-invalid-character");
            a.a("http://www.w3.org/TR/1998/REC-xml-19980210", "MSG_SPACE_REQUIRED_AFTER_PUBIDLITERAL_IN_EXTERNALID", fgDOMErrorTypeTable, "wf-invalid-character");
            a.a("http://www.w3.org/TR/1998/REC-xml-19980210", "MSG_SPACE_REQUIRED_BEFORE_SYSTEMLITERAL_IN_EXTERNALID", fgDOMErrorTypeTable, "wf-invalid-character");
            a.a("http://www.w3.org/TR/1998/REC-xml-19980210", "MSG_URI_FRAGMENT_IN_SYSTEMID", fgDOMErrorTypeTable, "wf-invalid-character");
            a.a("http://www.w3.org/TR/1998/REC-xml-19980210", "MSG_SPACE_REQUIRED_BEFORE_NOTATION_NAME_IN_NOTATIONDECL", fgDOMErrorTypeTable, "wf-invalid-character-in-node-name");
            a.a("http://www.w3.org/TR/1998/REC-xml-19980210", "MSG_NOTATION_NAME_REQUIRED_IN_NOTATIONDECL", fgDOMErrorTypeTable, "wf-invalid-character-in-node-name");
            a.a("http://www.w3.org/TR/1998/REC-xml-19980210", "MSG_SPACE_REQUIRED_AFTER_NOTATION_NAME_IN_NOTATIONDECL", fgDOMErrorTypeTable, "wf-invalid-character-in-node-name");
            a.a("http://www.w3.org/TR/1998/REC-xml-19980210", "ExternalIDorPublicIDRequired", fgDOMErrorTypeTable, "wf-invalid-character");
            a.a("http://www.w3.org/TR/1998/REC-xml-19980210", "NotationDeclUnterminated", fgDOMErrorTypeTable, "wf-invalid-character-in-node-name");
            a.a("http://www.w3.org/TR/1998/REC-xml-19980210", "ReferenceToExternalEntity", fgDOMErrorTypeTable, "wf-invalid-character");
            a.a("http://www.w3.org/TR/1998/REC-xml-19980210", "ReferenceToUnparsedEntity", fgDOMErrorTypeTable, "wf-invalid-character");
            a.a("http://www.w3.org/TR/1998/REC-xml-19980210", "EncodingNotSupported", fgDOMErrorTypeTable, "unsupported-encoding");
            a.a("http://www.w3.org/TR/1998/REC-xml-19980210", "EncodingRequired", fgDOMErrorTypeTable, "unsupported-encoding");
            a.a("http://www.w3.org/TR/1998/REC-xml-19980210", "IllegalQName", fgDOMErrorTypeTable, "wf-invalid-character-in-node-name");
            a.a("http://www.w3.org/TR/1998/REC-xml-19980210", "ElementXMLNSPrefix", fgDOMErrorTypeTable, "wf-invalid-character-in-node-name");
            a.a("http://www.w3.org/TR/1998/REC-xml-19980210", "ElementPrefixUnbound", fgDOMErrorTypeTable, "wf-invalid-character-in-node-name");
            a.a("http://www.w3.org/TR/1998/REC-xml-19980210", "AttributePrefixUnbound", fgDOMErrorTypeTable, "wf-invalid-character-in-node-name");
            a.a("http://www.w3.org/TR/1998/REC-xml-19980210", "EmptyPrefixedAttName", fgDOMErrorTypeTable, "wf-invalid-character-in-node-name");
            a.a("http://www.w3.org/TR/1998/REC-xml-19980210", "PrefixDeclared", fgDOMErrorTypeTable, "wf-invalid-character-in-node-name");
        }

        public static String getDOMErrorType(XMLErrorCode xMLErrorCode) {
            return (String) fgDOMErrorTypeTable.get(xMLErrorCode);
        }
    }

    public DOMErrorHandlerWrapper() {
        this.eStatus = true;
        this.fErrorCode = new XMLErrorCode(null, null);
        this.fDOMError = new DOMErrorImpl();
        this.fOut = new PrintWriter(System.err);
    }

    public DOMErrorHandlerWrapper(DOMErrorHandler dOMErrorHandler) {
        this.eStatus = true;
        this.fErrorCode = new XMLErrorCode(null, null);
        this.fDOMError = new DOMErrorImpl();
        this.fDomErrorHandler = dOMErrorHandler;
    }

    /* JADX WARNING: Removed duplicated region for block: B:10:0x0037  */
    private void printError(DOMError dOMError) {
        DOMLocator location;
        PrintWriter printWriter;
        String str;
        short severity = dOMError.getSeverity();
        this.fOut.print("[");
        if (severity == 1) {
            printWriter = this.fOut;
            str = "Warning";
        } else if (severity == 2) {
            printWriter = this.fOut;
            str = "Error";
        } else {
            this.fOut.print("FatalError");
            this.eStatus = false;
            this.fOut.print("] ");
            location = dOMError.getLocation();
            if (location != null) {
                this.fOut.print(location.getLineNumber());
                this.fOut.print(":");
                this.fOut.print(location.getColumnNumber());
                this.fOut.print(":");
                this.fOut.print(location.getByteOffset());
                this.fOut.print(XSSFDataValidationConstraint.LIST_SEPARATOR);
                this.fOut.print(location.getUtf16Offset());
                Node relatedNode = location.getRelatedNode();
                if (relatedNode != null) {
                    this.fOut.print("[");
                    this.fOut.print(relatedNode.getNodeName());
                    this.fOut.print("]");
                }
                String uri = location.getUri();
                if (uri != null) {
                    int lastIndexOf = uri.lastIndexOf(47);
                    if (lastIndexOf != -1) {
                        uri = uri.substring(lastIndexOf + 1);
                    }
                    this.fOut.print(": ");
                    this.fOut.print(uri);
                }
            }
            this.fOut.print(":");
            this.fOut.print(dOMError.getMessage());
            this.fOut.println();
            this.fOut.flush();
        }
        printWriter.print(str);
        this.fOut.print("] ");
        location = dOMError.getLocation();
        if (location != null) {
        }
        this.fOut.print(":");
        this.fOut.print(dOMError.getMessage());
        this.fOut.println();
        this.fOut.flush();
    }

    @Override // org.apache.xerces.xni.parser.XMLErrorHandler
    public void error(String str, String str2, XMLParseException xMLParseException) {
        DOMErrorImpl dOMErrorImpl = this.fDOMError;
        dOMErrorImpl.fSeverity = 2;
        dOMErrorImpl.fException = xMLParseException;
        dOMErrorImpl.fType = str2;
        String message = xMLParseException.getMessage();
        dOMErrorImpl.fMessage = message;
        dOMErrorImpl.fRelatedData = message;
        DOMLocatorImpl dOMLocatorImpl = this.fDOMError.fLocator;
        if (dOMLocatorImpl != null) {
            dOMLocatorImpl.fColumnNumber = xMLParseException.getColumnNumber();
            dOMLocatorImpl.fLineNumber = xMLParseException.getLineNumber();
            dOMLocatorImpl.fUtf16Offset = xMLParseException.getCharacterOffset();
            dOMLocatorImpl.fUri = xMLParseException.getExpandedSystemId();
            dOMLocatorImpl.fRelatedNode = this.fCurrentNode;
        }
        DOMErrorHandler dOMErrorHandler = this.fDomErrorHandler;
        if (dOMErrorHandler != null) {
            dOMErrorHandler.handleError(this.fDOMError);
        }
    }

    @Override // org.apache.xerces.xni.parser.XMLErrorHandler
    public void fatalError(String str, String str2, XMLParseException xMLParseException) {
        DOMErrorImpl dOMErrorImpl = this.fDOMError;
        dOMErrorImpl.fSeverity = 3;
        dOMErrorImpl.fException = xMLParseException;
        this.fErrorCode.setValues(str, str2);
        String dOMErrorType = DOMErrorTypeMap.getDOMErrorType(this.fErrorCode);
        DOMErrorImpl dOMErrorImpl2 = this.fDOMError;
        if (dOMErrorType != null) {
            str2 = dOMErrorType;
        }
        dOMErrorImpl2.fType = str2;
        DOMErrorImpl dOMErrorImpl3 = this.fDOMError;
        String message = xMLParseException.getMessage();
        dOMErrorImpl3.fMessage = message;
        dOMErrorImpl3.fRelatedData = message;
        DOMLocatorImpl dOMLocatorImpl = this.fDOMError.fLocator;
        if (dOMLocatorImpl != null) {
            dOMLocatorImpl.fColumnNumber = xMLParseException.getColumnNumber();
            dOMLocatorImpl.fLineNumber = xMLParseException.getLineNumber();
            dOMLocatorImpl.fUtf16Offset = xMLParseException.getCharacterOffset();
            dOMLocatorImpl.fUri = xMLParseException.getExpandedSystemId();
            dOMLocatorImpl.fRelatedNode = this.fCurrentNode;
        }
        DOMErrorHandler dOMErrorHandler = this.fDomErrorHandler;
        if (dOMErrorHandler != null) {
            dOMErrorHandler.handleError(this.fDOMError);
        }
    }

    public DOMErrorHandler getErrorHandler() {
        return this.fDomErrorHandler;
    }

    @Override // org.w3c.dom.DOMErrorHandler
    public boolean handleError(DOMError dOMError) {
        printError(dOMError);
        return this.eStatus;
    }

    public void setErrorHandler(DOMErrorHandler dOMErrorHandler) {
        this.fDomErrorHandler = dOMErrorHandler;
    }

    @Override // org.apache.xerces.xni.parser.XMLErrorHandler
    public void warning(String str, String str2, XMLParseException xMLParseException) {
        DOMErrorImpl dOMErrorImpl = this.fDOMError;
        dOMErrorImpl.fSeverity = 1;
        dOMErrorImpl.fException = xMLParseException;
        dOMErrorImpl.fType = str2;
        String message = xMLParseException.getMessage();
        dOMErrorImpl.fMessage = message;
        dOMErrorImpl.fRelatedData = message;
        DOMLocatorImpl dOMLocatorImpl = this.fDOMError.fLocator;
        if (dOMLocatorImpl != null) {
            dOMLocatorImpl.fColumnNumber = xMLParseException.getColumnNumber();
            dOMLocatorImpl.fLineNumber = xMLParseException.getLineNumber();
            dOMLocatorImpl.fUtf16Offset = xMLParseException.getCharacterOffset();
            dOMLocatorImpl.fUri = xMLParseException.getExpandedSystemId();
            dOMLocatorImpl.fRelatedNode = this.fCurrentNode;
        }
        DOMErrorHandler dOMErrorHandler = this.fDomErrorHandler;
        if (dOMErrorHandler != null) {
            dOMErrorHandler.handleError(this.fDOMError);
        }
    }
}
