package org.apache.xerces.util;

import java.util.Collections;
import java.util.Enumeration;
import java.util.List;
import java.util.TreeSet;
import java.util.Vector;
import org.apache.xerces.xni.NamespaceContext;

public final class JAXPNamespaceContextWrapper implements NamespaceContext {
    public final Vector fAllPrefixes = new Vector();
    public int[] fContext = new int[8];
    public int fCurrentContext;
    public javax.xml.namespace.NamespaceContext fNamespaceContext;
    public List fPrefixes;
    public SymbolTable fSymbolTable;

    public JAXPNamespaceContextWrapper(SymbolTable symbolTable) {
        setSymbolTable(symbolTable);
    }

    @Override // org.apache.xerces.xni.NamespaceContext
    public boolean declarePrefix(String str, String str2) {
        return true;
    }

    @Override // org.apache.xerces.xni.NamespaceContext
    public Enumeration getAllPrefixes() {
        return Collections.enumeration(new TreeSet(this.fAllPrefixes));
    }

    @Override // org.apache.xerces.xni.NamespaceContext
    public String getDeclaredPrefixAt(int i2) {
        return (String) this.fPrefixes.get(i2);
    }

    @Override // org.apache.xerces.xni.NamespaceContext
    public int getDeclaredPrefixCount() {
        List list = this.fPrefixes;
        if (list != null) {
            return list.size();
        }
        return 0;
    }

    public List getDeclaredPrefixes() {
        return this.fPrefixes;
    }

    public javax.xml.namespace.NamespaceContext getNamespaceContext() {
        return this.fNamespaceContext;
    }

    @Override // org.apache.xerces.xni.NamespaceContext
    public String getPrefix(String str) {
        if (this.fNamespaceContext == null) {
            return null;
        }
        String str2 = "";
        if (str == null) {
            str = str2;
        }
        String prefix = this.fNamespaceContext.getPrefix(str);
        if (prefix != null) {
            str2 = prefix;
        }
        SymbolTable symbolTable = this.fSymbolTable;
        return symbolTable != null ? symbolTable.addSymbol(str2) : str2.intern();
    }

    public SymbolTable getSymbolTable() {
        return this.fSymbolTable;
    }

    @Override // org.apache.xerces.xni.NamespaceContext
    public String getURI(String str) {
        String namespaceURI;
        javax.xml.namespace.NamespaceContext namespaceContext = this.fNamespaceContext;
        if (namespaceContext == null || (namespaceURI = namespaceContext.getNamespaceURI(str)) == null || "".equals(namespaceURI)) {
            return null;
        }
        SymbolTable symbolTable = this.fSymbolTable;
        return symbolTable != null ? symbolTable.addSymbol(namespaceURI) : namespaceURI.intern();
    }

    @Override // org.apache.xerces.xni.NamespaceContext
    public void popContext() {
        Vector vector = this.fAllPrefixes;
        int[] iArr = this.fContext;
        int i2 = this.fCurrentContext;
        this.fCurrentContext = i2 - 1;
        vector.setSize(iArr[i2]);
    }

    @Override // org.apache.xerces.xni.NamespaceContext
    public void pushContext() {
        int i2 = this.fCurrentContext + 1;
        int[] iArr = this.fContext;
        if (i2 == iArr.length) {
            int[] iArr2 = new int[(iArr.length * 2)];
            System.arraycopy(iArr, 0, iArr2, 0, iArr.length);
            this.fContext = iArr2;
        }
        int[] iArr3 = this.fContext;
        int i3 = this.fCurrentContext + 1;
        this.fCurrentContext = i3;
        iArr3[i3] = this.fAllPrefixes.size();
        List list = this.fPrefixes;
        if (list != null) {
            this.fAllPrefixes.addAll(list);
        }
    }

    @Override // org.apache.xerces.xni.NamespaceContext
    public void reset() {
        this.fCurrentContext = 0;
        this.fContext[0] = 0;
        this.fAllPrefixes.clear();
    }

    public void setDeclaredPrefixes(List list) {
        this.fPrefixes = list;
    }

    public void setNamespaceContext(javax.xml.namespace.NamespaceContext namespaceContext) {
        this.fNamespaceContext = namespaceContext;
    }

    public void setSymbolTable(SymbolTable symbolTable) {
        this.fSymbolTable = symbolTable;
    }
}
