package org.apache.xerces.util;

import java.util.ArrayList;
import java.util.HashMap;
import org.apache.xerces.xni.parser.XMLComponentManager;
import org.apache.xerces.xni.parser.XMLConfigurationException;

public class ParserConfigurationSettings implements XMLComponentManager {
    public static final String PARSER_SETTINGS = "http://apache.org/xml/features/internal/parser-settings";
    public HashMap fFeatures;
    public XMLComponentManager fParentSettings;
    public HashMap fProperties;
    public ArrayList fRecognizedFeatures;
    public ArrayList fRecognizedProperties;

    public ParserConfigurationSettings() {
        this(null);
    }

    public ParserConfigurationSettings(XMLComponentManager xMLComponentManager) {
        this.fRecognizedFeatures = new ArrayList();
        this.fRecognizedProperties = new ArrayList();
        this.fFeatures = new HashMap();
        this.fProperties = new HashMap();
        this.fParentSettings = xMLComponentManager;
    }

    public void addRecognizedFeatures(String[] strArr) {
        int length = strArr != null ? strArr.length : 0;
        for (int i2 = 0; i2 < length; i2++) {
            String str = strArr[i2];
            if (!this.fRecognizedFeatures.contains(str)) {
                this.fRecognizedFeatures.add(str);
            }
        }
    }

    public void addRecognizedProperties(String[] strArr) {
        int length = strArr != null ? strArr.length : 0;
        for (int i2 = 0; i2 < length; i2++) {
            String str = strArr[i2];
            if (!this.fRecognizedProperties.contains(str)) {
                this.fRecognizedProperties.add(str);
            }
        }
    }

    public void checkFeature(String str) {
        if (!this.fRecognizedFeatures.contains(str)) {
            XMLComponentManager xMLComponentManager = this.fParentSettings;
            if (xMLComponentManager != null) {
                xMLComponentManager.getFeature(str);
                return;
            }
            throw new XMLConfigurationException(0, str);
        }
    }

    public void checkProperty(String str) {
        if (!this.fRecognizedProperties.contains(str)) {
            XMLComponentManager xMLComponentManager = this.fParentSettings;
            if (xMLComponentManager != null) {
                xMLComponentManager.getProperty(str);
                return;
            }
            throw new XMLConfigurationException(0, str);
        }
    }

    @Override // org.apache.xerces.xni.parser.XMLComponentManager
    public boolean getFeature(String str) {
        Boolean bool = (Boolean) this.fFeatures.get(str);
        if (bool != null) {
            return bool.booleanValue();
        }
        checkFeature(str);
        return false;
    }

    @Override // org.apache.xerces.xni.parser.XMLComponentManager
    public Object getProperty(String str) {
        Object obj = this.fProperties.get(str);
        if (obj == null) {
            checkProperty(str);
        }
        return obj;
    }

    public void setFeature(String str, boolean z) {
        checkFeature(str);
        this.fFeatures.put(str, z ? Boolean.TRUE : Boolean.FALSE);
    }

    public void setProperty(String str, Object obj) {
        checkProperty(str);
        this.fProperties.put(str, obj);
    }
}
