package org.apache.xerces.util;

import b.b.a.a.a;
import java.lang.ref.ReferenceQueue;
import java.lang.ref.SoftReference;

public class SoftReferenceSymbolTable extends SymbolTable {
    public SREntry[] fBuckets;
    public final ReferenceQueue fReferenceQueue;

    public static final class SREntry extends SoftReference {
        public int bucket;
        public SREntry next;
        public SREntry prev;

        public SREntry(String str, SREntry sREntry, int i2, ReferenceQueue referenceQueue) {
            super(new SREntryData(str), referenceQueue);
            initialize(sREntry, i2);
        }

        public SREntry(String str, char[] cArr, int i2, int i3, SREntry sREntry, int i4, ReferenceQueue referenceQueue) {
            super(new SREntryData(str, cArr, i2, i3), referenceQueue);
            initialize(sREntry, i4);
        }

        private void initialize(SREntry sREntry, int i2) {
            this.next = sREntry;
            if (sREntry != null) {
                sREntry.prev = this;
            }
            this.prev = null;
            this.bucket = i2;
        }
    }

    public static final class SREntryData {
        public final char[] characters;
        public final String symbol;

        public SREntryData(String str) {
            this.symbol = str;
            char[] cArr = new char[str.length()];
            this.characters = cArr;
            this.symbol.getChars(0, cArr.length, cArr, 0);
        }

        public SREntryData(String str, char[] cArr, int i2, int i3) {
            this.symbol = str;
            char[] cArr2 = new char[i3];
            this.characters = cArr2;
            System.arraycopy(cArr, i2, cArr2, 0, i3);
        }
    }

    public SoftReferenceSymbolTable() {
        this(101, 0.75f);
    }

    public SoftReferenceSymbolTable(int i2) {
        this(i2, 0.75f);
    }

    public SoftReferenceSymbolTable(int i2, float f2) {
        this.fBuckets = null;
        if (i2 < 0) {
            throw new IllegalArgumentException(a.b("Illegal Capacity: ", i2));
        } else if (f2 <= 0.0f || Float.isNaN(f2)) {
            StringBuffer stringBuffer = new StringBuffer();
            stringBuffer.append("Illegal Load: ");
            stringBuffer.append(f2);
            throw new IllegalArgumentException(stringBuffer.toString());
        } else {
            i2 = i2 == 0 ? 1 : i2;
            this.fLoadFactor = f2;
            this.fTableSize = i2;
            this.fBuckets = new SREntry[i2];
            this.fThreshold = (int) (((float) i2) * f2);
            this.fCount = 0;
            this.fReferenceQueue = new ReferenceQueue();
        }
    }

    private void clean() {
        while (true) {
            SREntry sREntry = (SREntry) this.fReferenceQueue.poll();
            if (sREntry != null) {
                removeEntry(sREntry);
            } else {
                return;
            }
        }
    }

    private void removeEntry(SREntry sREntry) {
        SREntry sREntry2 = sREntry.next;
        if (sREntry2 != null) {
            sREntry2.prev = sREntry.prev;
        }
        SREntry sREntry3 = sREntry.prev;
        if (sREntry3 != null) {
            sREntry3.next = sREntry.next;
        } else {
            this.fBuckets[sREntry.bucket] = sREntry.next;
        }
        this.fCount--;
    }

    @Override // org.apache.xerces.util.SymbolTable
    public String addSymbol(String str) {
        clean();
        int hash = hash(str) % this.fTableSize;
        for (SREntry sREntry = this.fBuckets[hash]; sREntry != null; sREntry = sREntry.next) {
            SREntryData sREntryData = (SREntryData) sREntry.get();
            if (sREntryData != null && sREntryData.symbol.equals(str)) {
                return sREntryData.symbol;
            }
        }
        if (this.fCount >= this.fThreshold) {
            rehash();
            hash = hash(str) % this.fTableSize;
        }
        String intern = str.intern();
        this.fBuckets[hash] = new SREntry(intern, this.fBuckets[hash], hash, this.fReferenceQueue);
        this.fCount++;
        return intern;
    }

    @Override // org.apache.xerces.util.SymbolTable
    public String addSymbol(char[] cArr, int i2, int i3) {
        clean();
        int hash = hash(cArr, i2, i3) % this.fTableSize;
        for (SREntry sREntry = this.fBuckets[hash]; sREntry != null; sREntry = sREntry.next) {
            SREntryData sREntryData = (SREntryData) sREntry.get();
            if (sREntryData != null && i3 == sREntryData.characters.length) {
                for (int i4 = 0; i4 < i3; i4++) {
                    if (cArr[i2 + i4] == sREntryData.characters[i4]) {
                    }
                }
                return sREntryData.symbol;
            }
        }
        if (this.fCount >= this.fThreshold) {
            rehash();
            hash = hash(cArr, i2, i3) % this.fTableSize;
        }
        String intern = new String(cArr, i2, i3).intern();
        this.fBuckets[hash] = new SREntry(intern, cArr, i2, i3, this.fBuckets[hash], hash, this.fReferenceQueue);
        this.fCount++;
        return intern;
    }

    @Override // org.apache.xerces.util.SymbolTable
    public boolean containsSymbol(String str) {
        int hash = hash(str) % this.fTableSize;
        int length = str.length();
        SREntry sREntry = this.fBuckets[hash];
        while (true) {
            if (sREntry == null) {
                return false;
            }
            SREntryData sREntryData = (SREntryData) sREntry.get();
            if (sREntryData != null && length == sREntryData.characters.length) {
                for (int i2 = 0; i2 < length; i2++) {
                    if (str.charAt(i2) == sREntryData.characters[i2]) {
                    }
                }
                return true;
            }
            sREntry = sREntry.next;
        }
    }

    @Override // org.apache.xerces.util.SymbolTable
    public boolean containsSymbol(char[] cArr, int i2, int i3) {
        SREntry sREntry = this.fBuckets[hash(cArr, i2, i3) % this.fTableSize];
        while (true) {
            if (sREntry == null) {
                return false;
            }
            SREntryData sREntryData = (SREntryData) sREntry.get();
            if (sREntryData != null && i3 == sREntryData.characters.length) {
                for (int i4 = 0; i4 < i3; i4++) {
                    if (cArr[i2 + i4] == sREntryData.characters[i4]) {
                    }
                }
                return true;
            }
            sREntry = sREntry.next;
        }
    }

    @Override // org.apache.xerces.util.SymbolTable
    public void rehash() {
        SREntry[] sREntryArr = this.fBuckets;
        int length = sREntryArr.length;
        int i2 = (length * 2) + 1;
        SREntry[] sREntryArr2 = new SREntry[i2];
        this.fThreshold = (int) (((float) i2) * this.fLoadFactor);
        this.fBuckets = sREntryArr2;
        this.fTableSize = sREntryArr2.length;
        while (true) {
            int i3 = length - 1;
            if (length > 0) {
                SREntry sREntry = sREntryArr[i3];
                while (sREntry != null) {
                    SREntry sREntry2 = sREntry.next;
                    SREntryData sREntryData = (SREntryData) sREntry.get();
                    if (sREntryData != null) {
                        char[] cArr = sREntryData.characters;
                        int hash = hash(cArr, 0, cArr.length) % i2;
                        if (sREntryArr2[hash] != null) {
                            sREntryArr2[hash].prev = sREntry;
                        }
                        sREntry.next = sREntryArr2[hash];
                        sREntry.prev = null;
                        sREntryArr2[hash] = sREntry;
                    } else {
                        this.fCount--;
                    }
                    sREntry = sREntry2;
                }
                length = i3;
            } else {
                return;
            }
        }
    }
}
