package org.apache.xerces.util;

public class SymbolHash {
    public Entry[] fBuckets;
    public int fNum;
    public int fTableSize;

    public static final class Entry {
        public Object key;
        public Entry next;
        public Object value;

        public Entry() {
            this.key = null;
            this.value = null;
            this.next = null;
        }

        public Entry(Object obj, Object obj2, Entry entry) {
            this.key = obj;
            this.value = obj2;
            this.next = entry;
        }

        public Entry makeClone() {
            Entry entry = new Entry();
            entry.key = this.key;
            entry.value = this.value;
            Entry entry2 = this.next;
            if (entry2 != null) {
                entry.next = entry2.makeClone();
            }
            return entry;
        }
    }

    public SymbolHash() {
        this.fTableSize = 101;
        this.fNum = 0;
        this.fBuckets = new Entry[101];
    }

    public SymbolHash(int i2) {
        this.fTableSize = 101;
        this.fNum = 0;
        this.fTableSize = i2;
        this.fBuckets = new Entry[i2];
    }

    public void clear() {
        for (int i2 = 0; i2 < this.fTableSize; i2++) {
            this.fBuckets[i2] = null;
        }
        this.fNum = 0;
    }

    public Object get(Object obj) {
        Entry search = search(obj, (obj.hashCode() & Integer.MAX_VALUE) % this.fTableSize);
        if (search != null) {
            return search.value;
        }
        return null;
    }

    public Object[] getEntries() {
        Object[] objArr = new Object[(this.fNum << 1)];
        int i2 = 0;
        for (int i3 = 0; i3 < this.fTableSize && i2 < (this.fNum << 1); i3++) {
            for (Entry entry = this.fBuckets[i3]; entry != null; entry = entry.next) {
                objArr[i2] = entry.key;
                int i4 = i2 + 1;
                objArr[i4] = entry.value;
                i2 = i4 + 1;
            }
        }
        return objArr;
    }

    public int getLength() {
        return this.fNum;
    }

    public int getValues(Object[] objArr, int i2) {
        int i3 = 0;
        for (int i4 = 0; i4 < this.fTableSize && i3 < this.fNum; i4++) {
            for (Entry entry = this.fBuckets[i4]; entry != null; entry = entry.next) {
                objArr[i2 + i3] = entry.value;
                i3++;
            }
        }
        return this.fNum;
    }

    public SymbolHash makeClone() {
        SymbolHash symbolHash = new SymbolHash(this.fTableSize);
        symbolHash.fNum = this.fNum;
        for (int i2 = 0; i2 < this.fTableSize; i2++) {
            Entry[] entryArr = this.fBuckets;
            if (entryArr[i2] != null) {
                symbolHash.fBuckets[i2] = entryArr[i2].makeClone();
            }
        }
        return symbolHash;
    }

    public void put(Object obj, Object obj2) {
        int hashCode = (obj.hashCode() & Integer.MAX_VALUE) % this.fTableSize;
        Entry search = search(obj, hashCode);
        if (search != null) {
            search.value = obj2;
            return;
        }
        this.fBuckets[hashCode] = new Entry(obj, obj2, this.fBuckets[hashCode]);
        this.fNum++;
    }

    public Entry search(Object obj, int i2) {
        for (Entry entry = this.fBuckets[i2]; entry != null; entry = entry.next) {
            if (obj.equals(entry.key)) {
                return entry;
            }
        }
        return null;
    }
}
