package org.apache.xerces.util;

import b.b.a.a.a;

public class SymbolTable {
    public static final int TABLE_SIZE = 101;
    public Entry[] fBuckets;
    public transient int fCount;
    public float fLoadFactor;
    public int fTableSize;
    public int fThreshold;

    public static final class Entry {
        public final char[] characters;
        public Entry next;
        public final String symbol;

        public Entry(String str, Entry entry) {
            this.symbol = str.intern();
            char[] cArr = new char[str.length()];
            this.characters = cArr;
            str.getChars(0, cArr.length, cArr, 0);
            this.next = entry;
        }

        public Entry(char[] cArr, int i2, int i3, Entry entry) {
            char[] cArr2 = new char[i3];
            this.characters = cArr2;
            System.arraycopy(cArr, i2, cArr2, 0, i3);
            this.symbol = new String(this.characters).intern();
            this.next = entry;
        }
    }

    public SymbolTable() {
        this(101, 0.75f);
    }

    public SymbolTable(int i2) {
        this(i2, 0.75f);
    }

    public SymbolTable(int i2, float f2) {
        this.fBuckets = null;
        if (i2 < 0) {
            throw new IllegalArgumentException(a.b("Illegal Capacity: ", i2));
        } else if (f2 <= 0.0f || Float.isNaN(f2)) {
            StringBuffer stringBuffer = new StringBuffer();
            stringBuffer.append("Illegal Load: ");
            stringBuffer.append(f2);
            throw new IllegalArgumentException(stringBuffer.toString());
        } else {
            i2 = i2 == 0 ? 1 : i2;
            this.fLoadFactor = f2;
            this.fTableSize = i2;
            this.fBuckets = new Entry[i2];
            this.fThreshold = (int) (((float) i2) * f2);
            this.fCount = 0;
        }
    }

    public String addSymbol(String str) {
        int hash = hash(str) % this.fTableSize;
        for (Entry entry = this.fBuckets[hash]; entry != null; entry = entry.next) {
            if (entry.symbol.equals(str)) {
                return entry.symbol;
            }
        }
        if (this.fCount >= this.fThreshold) {
            rehash();
            hash = hash(str) % this.fTableSize;
        }
        Entry entry2 = new Entry(str, this.fBuckets[hash]);
        this.fBuckets[hash] = entry2;
        this.fCount++;
        return entry2.symbol;
    }

    public String addSymbol(char[] cArr, int i2, int i3) {
        int hash = hash(cArr, i2, i3) % this.fTableSize;
        for (Entry entry = this.fBuckets[hash]; entry != null; entry = entry.next) {
            if (i3 == entry.characters.length) {
                for (int i4 = 0; i4 < i3; i4++) {
                    if (cArr[i2 + i4] == entry.characters[i4]) {
                    }
                }
                return entry.symbol;
            }
        }
        if (this.fCount >= this.fThreshold) {
            rehash();
            hash = hash(cArr, i2, i3) % this.fTableSize;
        }
        Entry entry2 = new Entry(cArr, i2, i3, this.fBuckets[hash]);
        this.fBuckets[hash] = entry2;
        this.fCount++;
        return entry2.symbol;
    }

    public boolean containsSymbol(String str) {
        int hash = hash(str) % this.fTableSize;
        int length = str.length();
        Entry entry = this.fBuckets[hash];
        while (true) {
            if (entry == null) {
                return false;
            }
            if (length == entry.characters.length) {
                for (int i2 = 0; i2 < length; i2++) {
                    if (str.charAt(i2) == entry.characters[i2]) {
                    }
                }
                return true;
            }
            entry = entry.next;
        }
    }

    public boolean containsSymbol(char[] cArr, int i2, int i3) {
        Entry entry = this.fBuckets[hash(cArr, i2, i3) % this.fTableSize];
        while (true) {
            if (entry == null) {
                return false;
            }
            if (i3 == entry.characters.length) {
                for (int i4 = 0; i4 < i3; i4++) {
                    if (cArr[i2 + i4] == entry.characters[i4]) {
                    }
                }
                return true;
            }
            entry = entry.next;
        }
    }

    public int hash(String str) {
        return str.hashCode() & Integer.MAX_VALUE;
    }

    public int hash(char[] cArr, int i2, int i3) {
        int i4 = 0;
        for (int i5 = 0; i5 < i3; i5++) {
            i4 = (i4 * 31) + cArr[i2 + i5];
        }
        return Integer.MAX_VALUE & i4;
    }

    public void rehash() {
        Entry[] entryArr = this.fBuckets;
        int length = entryArr.length;
        int i2 = (length * 2) + 1;
        Entry[] entryArr2 = new Entry[i2];
        this.fThreshold = (int) (((float) i2) * this.fLoadFactor);
        this.fBuckets = entryArr2;
        this.fTableSize = entryArr2.length;
        while (true) {
            int i3 = length - 1;
            if (length > 0) {
                Entry entry = entryArr[i3];
                while (entry != null) {
                    Entry entry2 = entry.next;
                    char[] cArr = entry.characters;
                    int hash = hash(cArr, 0, cArr.length) % i2;
                    entry.next = entryArr2[hash];
                    entryArr2[hash] = entry;
                    entry = entry2;
                }
                length = i3;
            } else {
                return;
            }
        }
    }
}
