package org.apache.xerces.util;

import b.b.a.a.a;
import java.io.IOException;
import java.io.Serializable;
import java.util.Locale;
import org.apache.poi.openxml4j.opc.internal.ZipHelper;
import org.apache.poi.ss.formula.ptg.Ref3DPtg;
import org.apache.poi.ss.formula.ptg.UnaryMinusPtg;
import org.apache.poi.util.LittleEndianCP950Reader;

public class URI implements Serializable {
    public static final int ASCII_ALPHA_CHARACTERS = 16;
    public static final int ASCII_DIGIT_CHARACTERS = 32;
    public static final int ASCII_HEX_CHARACTERS = 64;
    public static boolean DEBUG = false;
    public static final int MARK_CHARACTERS = 2;
    public static final int MASK_ALPHA_NUMERIC = 48;
    public static final int MASK_PATH_CHARACTER = 178;
    public static final int MASK_SCHEME_CHARACTER = 52;
    public static final int MASK_UNRESERVED_MASK = 50;
    public static final int MASK_URI_CHARACTER = 51;
    public static final int MASK_USERINFO_CHARACTER = 58;
    public static final int PATH_CHARACTERS = 128;
    public static final int RESERVED_CHARACTERS = 1;
    public static final int SCHEME_CHARACTERS = 4;
    public static final int USERINFO_CHARACTERS = 8;
    public static final byte[] fgLookupTable = new byte[128];
    public static final long serialVersionUID = 1601921774685357214L;
    public String m_fragment;
    public String m_host;
    public String m_path;
    public int m_port;
    public String m_queryString;
    public String m_regAuthority;
    public String m_scheme;
    public String m_userinfo;

    public static class MalformedURIException extends IOException {
        public static final long serialVersionUID = -6695054834342951930L;

        public MalformedURIException() {
        }

        public MalformedURIException(String str) {
            super(str);
        }
    }

    static {
        for (int i2 = 48; i2 <= 57; i2++) {
            byte[] bArr = fgLookupTable;
            bArr[i2] = (byte) (bArr[i2] | 96);
        }
        for (int i3 = 65; i3 <= 70; i3++) {
            byte[] bArr2 = fgLookupTable;
            bArr2[i3] = (byte) (bArr2[i3] | 80);
            int i4 = i3 + 32;
            bArr2[i4] = (byte) (bArr2[i4] | 80);
        }
        for (int i5 = 71; i5 <= 90; i5++) {
            byte[] bArr3 = fgLookupTable;
            bArr3[i5] = (byte) (bArr3[i5] | 16);
            int i6 = i5 + 32;
            bArr3[i6] = (byte) (bArr3[i6] | 16);
        }
        byte[] bArr4 = fgLookupTable;
        bArr4[59] = (byte) (bArr4[59] | 1);
        bArr4[47] = (byte) (bArr4[47] | 1);
        bArr4[63] = (byte) (bArr4[63] | 1);
        bArr4[58] = (byte) (bArr4[58] | 1);
        bArr4[64] = (byte) (bArr4[64] | 1);
        bArr4[38] = (byte) (bArr4[38] | 1);
        bArr4[61] = (byte) (bArr4[61] | 1);
        bArr4[43] = (byte) (bArr4[43] | 1);
        bArr4[36] = (byte) (bArr4[36] | 1);
        bArr4[44] = (byte) (bArr4[44] | 1);
        bArr4[91] = (byte) (bArr4[91] | 1);
        bArr4[93] = (byte) (bArr4[93] | 1);
        bArr4[45] = (byte) (bArr4[45] | 2);
        bArr4[95] = (byte) (bArr4[95] | 2);
        bArr4[46] = (byte) (bArr4[46] | 2);
        bArr4[33] = (byte) (bArr4[33] | 2);
        bArr4[126] = (byte) (bArr4[126] | 2);
        bArr4[42] = (byte) (bArr4[42] | 2);
        bArr4[39] = (byte) (bArr4[39] | 2);
        bArr4[40] = (byte) (bArr4[40] | 2);
        bArr4[41] = (byte) (bArr4[41] | 2);
        bArr4[43] = (byte) (bArr4[43] | 4);
        bArr4[45] = (byte) (bArr4[45] | 4);
        bArr4[46] = (byte) (bArr4[46] | 4);
        bArr4[59] = (byte) (bArr4[59] | 8);
        bArr4[58] = (byte) (bArr4[58] | 8);
        bArr4[38] = (byte) (bArr4[38] | 8);
        bArr4[61] = (byte) (bArr4[61] | 8);
        bArr4[43] = (byte) (bArr4[43] | 8);
        bArr4[36] = (byte) (bArr4[36] | 8);
        bArr4[44] = (byte) (bArr4[44] | 8);
        bArr4[59] = (byte) (bArr4[59] | 128);
        bArr4[47] = (byte) (bArr4[47] | 128);
        bArr4[58] = (byte) (bArr4[58] | 128);
        bArr4[64] = (byte) (bArr4[64] | 128);
        bArr4[38] = (byte) (bArr4[38] | 128);
        bArr4[61] = (byte) (bArr4[61] | 128);
        bArr4[43] = (byte) (bArr4[43] | 128);
        bArr4[36] = (byte) (bArr4[36] | 128);
        bArr4[44] = (byte) (128 | bArr4[44]);
    }

    public URI() {
        this.m_scheme = null;
        this.m_userinfo = null;
        this.m_host = null;
        this.m_port = -1;
        this.m_regAuthority = null;
        this.m_path = null;
        this.m_queryString = null;
        this.m_fragment = null;
    }

    public URI(String str) {
        this((URI) null, str);
    }

    public URI(String str, String str2) {
        this.m_scheme = null;
        this.m_userinfo = null;
        this.m_host = null;
        this.m_port = -1;
        this.m_regAuthority = null;
        this.m_path = null;
        this.m_queryString = null;
        this.m_fragment = null;
        if (str == null || str.trim().length() == 0) {
            throw new MalformedURIException("Cannot construct URI with null/empty scheme!");
        } else if (str2 == null || str2.trim().length() == 0) {
            throw new MalformedURIException("Cannot construct URI with null/empty scheme-specific part!");
        } else {
            setScheme(str);
            setPath(str2);
        }
    }

    public URI(String str, String str2, String str3, int i2, String str4, String str5, String str6) {
        this.m_scheme = null;
        this.m_userinfo = null;
        this.m_host = null;
        this.m_port = -1;
        this.m_regAuthority = null;
        this.m_path = null;
        this.m_queryString = null;
        this.m_fragment = null;
        if (str == null || str.trim().length() == 0) {
            throw new MalformedURIException("Scheme is required!");
        }
        if (str3 == null) {
            if (str2 != null) {
                throw new MalformedURIException("Userinfo may not be specified if host is not specified!");
            } else if (i2 != -1) {
                throw new MalformedURIException("Port may not be specified if host is not specified!");
            }
        }
        if (str4 != null) {
            if (str4.indexOf(63) != -1 && str5 != null) {
                throw new MalformedURIException("Query string cannot be specified in path and query string!");
            } else if (!(str4.indexOf(35) == -1 || str6 == null)) {
                throw new MalformedURIException("Fragment cannot be specified in both the path and fragment!");
            }
        }
        setScheme(str);
        setHost(str3);
        setPort(i2);
        setUserinfo(str2);
        setPath(str4);
        setQueryString(str5);
        setFragment(str6);
    }

    public URI(String str, String str2, String str3, String str4, String str5) {
        this(str, null, str2, -1, str3, str4, str5);
    }

    public URI(String str, boolean z) {
        this(null, str, z);
    }

    public URI(URI uri) {
        this.m_scheme = null;
        this.m_userinfo = null;
        this.m_host = null;
        this.m_port = -1;
        this.m_regAuthority = null;
        this.m_path = null;
        this.m_queryString = null;
        this.m_fragment = null;
        initialize(uri);
    }

    public URI(URI uri, String str) {
        this.m_scheme = null;
        this.m_userinfo = null;
        this.m_host = null;
        this.m_port = -1;
        this.m_regAuthority = null;
        this.m_path = null;
        this.m_queryString = null;
        this.m_fragment = null;
        initialize(uri, str);
    }

    public URI(URI uri, String str, boolean z) {
        this.m_scheme = null;
        this.m_userinfo = null;
        this.m_host = null;
        this.m_port = -1;
        this.m_regAuthority = null;
        this.m_path = null;
        this.m_queryString = null;
        this.m_fragment = null;
        initialize(uri, str, z);
    }

    private void initialize(URI uri) {
        this.m_scheme = uri.getScheme();
        this.m_userinfo = uri.getUserinfo();
        this.m_host = uri.getHost();
        this.m_port = uri.getPort();
        this.m_regAuthority = uri.getRegBasedAuthority();
        this.m_path = uri.getPath();
        this.m_queryString = uri.getQueryString();
        this.m_fragment = uri.getFragment();
    }

    private void initialize(URI uri, String str) {
        int i2 = 0;
        int length = str != null ? str.length() : 0;
        if (uri == null && length == 0) {
            throw new MalformedURIException("Cannot initialize URI with empty parameters.");
        } else if (length == 0) {
            initialize(uri);
        } else {
            int indexOf = str.indexOf(58);
            if (indexOf != -1) {
                int i3 = indexOf - 1;
                int lastIndexOf = str.lastIndexOf(47, i3);
                int lastIndexOf2 = str.lastIndexOf(63, i3);
                int lastIndexOf3 = str.lastIndexOf(35, i3);
                if (indexOf != 0 && lastIndexOf == -1 && lastIndexOf2 == -1 && lastIndexOf3 == -1) {
                    initializeScheme(str);
                    i2 = this.m_scheme.length() + 1;
                    if (indexOf == length - 1 || str.charAt(indexOf + 1) == '#') {
                        throw new MalformedURIException("Scheme specific part cannot be empty.");
                    }
                } else if (indexOf == 0 || (uri == null && lastIndexOf3 != 0)) {
                    throw new MalformedURIException("No scheme found in URI.");
                }
            } else if (uri == null && str.indexOf(35) != 0) {
                throw new MalformedURIException("No scheme found in URI.");
            }
            int i4 = i2 + 1;
            if (i4 < length && str.charAt(i2) == '/' && str.charAt(i4) == '/') {
                int i5 = i2 + 2;
                int i6 = i5;
                while (i6 < length) {
                    char charAt = str.charAt(i6);
                    if (charAt == '/' || charAt == '?' || charAt == '#') {
                        break;
                    }
                    i6++;
                }
                if (i6 <= i5) {
                    this.m_host = "";
                } else if (!initializeAuthority(str.substring(i5, i6))) {
                    i2 = i5 - 2;
                }
                i2 = i6;
            }
            initializePath(str, i2);
            if (uri != null) {
                absolutize(uri);
            }
        }
    }

    private void initialize(URI uri, String str, boolean z) {
        int i2 = 0;
        int length = str != null ? str.length() : 0;
        if (uri == null && length == 0) {
            if (z) {
                this.m_path = "";
                return;
            }
            throw new MalformedURIException("Cannot initialize URI with empty parameters.");
        } else if (length == 0) {
            initialize(uri);
        } else {
            int indexOf = str.indexOf(58);
            if (indexOf != -1) {
                int i3 = indexOf - 1;
                int lastIndexOf = str.lastIndexOf(47, i3);
                int lastIndexOf2 = str.lastIndexOf(63, i3);
                int lastIndexOf3 = str.lastIndexOf(35, i3);
                if (indexOf != 0 && lastIndexOf == -1 && lastIndexOf2 == -1 && lastIndexOf3 == -1) {
                    initializeScheme(str);
                    i2 = this.m_scheme.length() + 1;
                    if (indexOf == length - 1 || str.charAt(indexOf + 1) == '#') {
                        throw new MalformedURIException("Scheme specific part cannot be empty.");
                    }
                } else if (indexOf == 0 || (uri == null && lastIndexOf3 != 0 && !z)) {
                    throw new MalformedURIException("No scheme found in URI.");
                }
            } else if (uri == null && str.indexOf(35) != 0 && !z) {
                throw new MalformedURIException("No scheme found in URI.");
            }
            int i4 = i2 + 1;
            if (i4 < length && str.charAt(i2) == '/' && str.charAt(i4) == '/') {
                int i5 = i2 + 2;
                int i6 = i5;
                while (i6 < length) {
                    char charAt = str.charAt(i6);
                    if (charAt == '/' || charAt == '?' || charAt == '#') {
                        break;
                    }
                    i6++;
                }
                if (i6 <= i5) {
                    this.m_host = "";
                } else if (!initializeAuthority(str.substring(i5, i6))) {
                    i2 = i5 - 2;
                }
                i2 = i6;
            }
            initializePath(str, i2);
            if (uri != null) {
                absolutize(uri);
            }
        }
    }

    /* JADX WARNING: Code restructure failed: missing block: B:24:0x004f, code lost:
        if (r6 != r0) goto L_0x0043;
     */
    /* JADX WARNING: Removed duplicated region for block: B:34:0x006e A[SYNTHETIC, Splitter:B:34:0x006e] */
    /* JADX WARNING: Removed duplicated region for block: B:41:0x007a A[LOOP:1: B:31:0x0062->B:41:0x007a, LOOP_END] */
    /* JADX WARNING: Removed duplicated region for block: B:44:0x0083  */
    /* JADX WARNING: Removed duplicated region for block: B:46:0x008a  */
    private boolean initializeAuthority(String str) {
        int i2;
        String str2;
        boolean z;
        int i3;
        String substring;
        int i4;
        String substring2;
        int length = str.length();
        int i5 = -1;
        if (str.indexOf(64, 0) != -1) {
            int i6 = 0;
            while (i6 < length && str.charAt(i6) != '@') {
                i6++;
            }
            str2 = str.substring(0, i6);
            i2 = i6 + 1;
        } else {
            str2 = null;
            i2 = 0;
        }
        if (i2 < length) {
            if (str.charAt(i2) == '[') {
                int indexOf = str.indexOf(93, i2);
                if (indexOf == -1) {
                    indexOf = length;
                }
                i3 = indexOf + 1;
                if (i3 >= length || str.charAt(i3) != ':') {
                    i3 = length;
                }
            } else {
                i3 = str.lastIndexOf(58, length);
                if (i3 <= i2) {
                    i3 = length;
                }
            }
            z = true;
            substring = str.substring(i2, i3);
            if (substring.length() > 0 && z) {
                int i7 = i3 + 1;
                i4 = i7;
                while (i4 < length) {
                    i4++;
                }
                substring2 = str.substring(i7, i4);
                if (substring2.length() > 0) {
                    try {
                        int parseInt = Integer.parseInt(substring2);
                        if (parseInt == -1) {
                            parseInt--;
                        }
                        i5 = parseInt;
                    } catch (NumberFormatException unused) {
                        i5 = -2;
                    }
                }
            }
            if (!isValidServerBasedAuthority(substring, i5, str2)) {
                this.m_host = substring;
                this.m_port = i5;
                this.m_userinfo = str2;
                return true;
            } else if (!isValidRegistryBasedAuthority(str)) {
                return false;
            } else {
                this.m_regAuthority = str;
                return true;
            }
        } else {
            i3 = i2;
        }
        z = false;
        substring = str.substring(i2, i3);
        int i72 = i3 + 1;
        i4 = i72;
        while (i4 < length) {
        }
        substring2 = str.substring(i72, i4);
        if (substring2.length() > 0) {
        }
        if (!isValidServerBasedAuthority(substring, i5, str2)) {
        }
    }

    private void initializePath(String str, int i2) {
        int i3;
        if (str != null) {
            int length = str.length();
            char c = 0;
            if (i2 < length) {
                if (getScheme() != null && str.charAt(i2) != '/') {
                    i3 = i2;
                    while (i3 < length) {
                        c = str.charAt(i3);
                        if (c == '?' || c == '#') {
                            break;
                        }
                        if (c == '%') {
                            int i4 = i3 + 2;
                            if (i4 >= length || !isHex(str.charAt(i3 + 1)) || !isHex(str.charAt(i4))) {
                                throw new MalformedURIException("Opaque part contains invalid escape sequence!");
                            }
                            i3 = i4;
                        } else if (!isURICharacter(c)) {
                            StringBuffer stringBuffer = new StringBuffer();
                            stringBuffer.append("Opaque part contains invalid character: ");
                            stringBuffer.append(c);
                            throw new MalformedURIException(stringBuffer.toString());
                        }
                        i3++;
                    }
                } else {
                    i3 = i2;
                    while (true) {
                        if (i3 >= length) {
                            break;
                        }
                        c = str.charAt(i3);
                        if (c == '%') {
                            int i5 = i3 + 2;
                            if (i5 < length && isHex(str.charAt(i3 + 1)) && isHex(str.charAt(i5))) {
                                i3 = i5;
                            }
                        } else if (!isPathCharacter(c)) {
                            if (c != '?' && c != '#') {
                                StringBuffer stringBuffer2 = new StringBuffer();
                                stringBuffer2.append("Path contains invalid character: ");
                                stringBuffer2.append(c);
                                throw new MalformedURIException(stringBuffer2.toString());
                            }
                        }
                        i3++;
                    }
                    throw new MalformedURIException("Path contains invalid escape sequence!");
                }
            } else {
                i3 = i2;
            }
            this.m_path = str.substring(i2, i3);
            if (c == '?') {
                int i6 = i3 + 1;
                int i7 = i6;
                while (i7 < length) {
                    c = str.charAt(i7);
                    if (c == '#') {
                        break;
                    }
                    if (c == '%') {
                        int i8 = i7 + 2;
                        if (i8 >= length || !isHex(str.charAt(i7 + 1)) || !isHex(str.charAt(i8))) {
                            throw new MalformedURIException("Query string contains invalid escape sequence!");
                        }
                        i7 = i8;
                    } else if (!isURICharacter(c)) {
                        StringBuffer stringBuffer3 = new StringBuffer();
                        stringBuffer3.append("Query string contains invalid character: ");
                        stringBuffer3.append(c);
                        throw new MalformedURIException(stringBuffer3.toString());
                    }
                    i7++;
                }
                this.m_queryString = str.substring(i6, i7);
                i3 = i7;
            }
            if (c == '#') {
                int i9 = i3 + 1;
                int i10 = i9;
                while (i10 < length) {
                    char charAt = str.charAt(i10);
                    if (charAt == '%') {
                        int i11 = i10 + 2;
                        if (i11 >= length || !isHex(str.charAt(i10 + 1)) || !isHex(str.charAt(i11))) {
                            throw new MalformedURIException("Fragment contains invalid escape sequence!");
                        }
                        i10 = i11;
                    } else if (!isURICharacter(charAt)) {
                        StringBuffer stringBuffer4 = new StringBuffer();
                        stringBuffer4.append("Fragment contains invalid character: ");
                        stringBuffer4.append(charAt);
                        throw new MalformedURIException(stringBuffer4.toString());
                    }
                    i10++;
                }
                this.m_fragment = str.substring(i9, i10);
                return;
            }
            return;
        }
        throw new MalformedURIException("Cannot initialize path from null string!");
    }

    private void initializeScheme(String str) {
        int length = str.length();
        int i2 = 0;
        while (i2 < length) {
            char charAt = str.charAt(i2);
            if (charAt == ':' || charAt == '/' || charAt == '?' || charAt == '#') {
                break;
            }
            i2++;
        }
        String substring = str.substring(0, i2);
        if (substring.length() != 0) {
            setScheme(substring);
            return;
        }
        throw new MalformedURIException("No scheme found in URI.");
    }

    public static boolean isAlpha(char c) {
        return (c >= 'a' && c <= 'z') || (c >= 'A' && c <= 'Z');
    }

    public static boolean isAlphanum(char c) {
        return c <= 'z' && (fgLookupTable[c] & 48) != 0;
    }

    public static boolean isConformantSchemeName(String str) {
        if (str == null || str.trim().length() == 0 || !isAlpha(str.charAt(0))) {
            return false;
        }
        int length = str.length();
        for (int i2 = 1; i2 < length; i2++) {
            if (!isSchemeCharacter(str.charAt(i2))) {
                return false;
            }
        }
        return true;
    }

    public static boolean isDigit(char c) {
        return c >= '0' && c <= '9';
    }

    public static boolean isHex(char c) {
        return c <= 'f' && (fgLookupTable[c] & 64) != 0;
    }

    public static boolean isPathCharacter(char c) {
        return c <= '~' && (fgLookupTable[c] & 178) != 0;
    }

    public static boolean isReservedCharacter(char c) {
        return c <= ']' && (fgLookupTable[c] & 1) != 0;
    }

    public static boolean isSchemeCharacter(char c) {
        return c <= 'z' && (fgLookupTable[c] & 52) != 0;
    }

    public static boolean isURICharacter(char c) {
        return c <= '~' && (fgLookupTable[c] & 51) != 0;
    }

    public static boolean isURIString(String str) {
        if (str == null) {
            return false;
        }
        int length = str.length();
        int i2 = 0;
        while (i2 < length) {
            char charAt = str.charAt(i2);
            if (charAt == '%') {
                int i3 = i2 + 2;
                if (i3 >= length || !isHex(str.charAt(i2 + 1)) || !isHex(str.charAt(i3))) {
                    return false;
                }
                i2 = i3;
            } else if (!isURICharacter(charAt)) {
                return false;
            }
            i2++;
        }
        return true;
    }

    public static boolean isUnreservedCharacter(char c) {
        return c <= '~' && (fgLookupTable[c] & 50) != 0;
    }

    public static boolean isUserinfoCharacter(char c) {
        return c <= 'z' && (fgLookupTable[c] & Ref3DPtg.sid) != 0;
    }

    private boolean isValidRegistryBasedAuthority(String str) {
        int length = str.length();
        int i2 = 0;
        while (i2 < length) {
            char charAt = str.charAt(i2);
            if (charAt == '%') {
                int i3 = i2 + 2;
                if (i3 >= length || !isHex(str.charAt(i2 + 1)) || !isHex(str.charAt(i3))) {
                    return false;
                }
                i2 = i3;
            } else if (!isPathCharacter(charAt)) {
                return false;
            }
            i2++;
        }
        return true;
    }

    private boolean isValidServerBasedAuthority(String str, int i2, String str2) {
        if (!isWellFormedAddress(str) || i2 < -1 || i2 > 65535) {
            return false;
        }
        if (str2 != null) {
            int length = str2.length();
            int i3 = 0;
            while (i3 < length) {
                char charAt = str2.charAt(i3);
                if (charAt == '%') {
                    int i4 = i3 + 2;
                    if (i4 >= length || !isHex(str2.charAt(i3 + 1)) || !isHex(str2.charAt(i4))) {
                        return false;
                    }
                    i3 = i4;
                } else if (!isUserinfoCharacter(charAt)) {
                    return false;
                }
                i3++;
            }
        }
        return true;
    }

    public static boolean isWellFormedAddress(String str) {
        int length;
        if (str == null || (length = str.length()) == 0) {
            return false;
        }
        if (str.startsWith("[")) {
            return isWellFormedIPv6Reference(str);
        }
        if (str.startsWith(".") || str.startsWith(UnaryMinusPtg.MINUS) || str.endsWith(UnaryMinusPtg.MINUS)) {
            return false;
        }
        int lastIndexOf = str.lastIndexOf(46);
        if (str.endsWith(".")) {
            lastIndexOf = str.substring(0, lastIndexOf).lastIndexOf(46);
        }
        int i2 = lastIndexOf + 1;
        if (i2 < length && isDigit(str.charAt(i2))) {
            return isWellFormedIPv4Address(str);
        }
        if (length > 255) {
            return false;
        }
        int i3 = 0;
        for (int i4 = 0; i4 < length; i4++) {
            char charAt = str.charAt(i4);
            if (charAt == '.') {
                if (!isAlphanum(str.charAt(i4 - 1))) {
                    return false;
                }
                int i5 = i4 + 1;
                if (i5 < length && !isAlphanum(str.charAt(i5))) {
                    return false;
                }
                i3 = 0;
            } else if (!(isAlphanum(charAt) || charAt == '-') || (i3 = i3 + 1) > 63) {
                return false;
            }
        }
        return true;
    }

    /* JADX WARNING: Code restructure failed: missing block: B:14:0x0034, code lost:
        return false;
     */
    public static boolean isWellFormedIPv4Address(String str) {
        int i2;
        int length = str.length();
        int i3 = 0;
        int i4 = 0;
        for (int i5 = 0; i5 < length; i5++) {
            char charAt = str.charAt(i5);
            if (charAt == '.') {
                if ((i5 > 0 && !isDigit(str.charAt(i5 - 1))) || (((i2 = i5 + 1) < length && !isDigit(str.charAt(i2))) || (i3 = i3 + 1) > 3)) {
                    return false;
                }
                i4 = 0;
            } else if (!isDigit(charAt) || (i4 = i4 + 1) > 3) {
                return false;
            } else {
                if (i4 == 3) {
                    char charAt2 = str.charAt(i5 - 2);
                    char charAt3 = str.charAt(i5 - 1);
                    if (charAt2 >= '2' && (charAt2 != '2' || (charAt3 >= '5' && (charAt3 != '5' || charAt > '5')))) {
                        return false;
                    }
                } else {
                    continue;
                }
            }
        }
        return i3 == 3;
    }

    public static boolean isWellFormedIPv6Reference(String str) {
        int[] iArr;
        int scanHexSequence;
        int length = str.length();
        int i2 = length - 1;
        if (length <= 2 || str.charAt(0) != '[' || str.charAt(i2) != ']' || (scanHexSequence = scanHexSequence(str, 1, i2, (iArr = new int[1]))) == -1) {
            return false;
        }
        if (scanHexSequence == i2) {
            return iArr[0] == 8;
        }
        int i3 = scanHexSequence + 1;
        if (i3 >= i2 || str.charAt(scanHexSequence) != ':') {
            return false;
        }
        if (str.charAt(i3) != ':') {
            return iArr[0] == 6 && isWellFormedIPv4Address(str.substring(i3, i2));
        }
        int i4 = iArr[0] + 1;
        iArr[0] = i4;
        if (i4 > 8) {
            return false;
        }
        int i5 = scanHexSequence + 2;
        if (i5 == i2) {
            return true;
        }
        int i6 = iArr[0];
        int scanHexSequence2 = scanHexSequence(str, i5, i2, iArr);
        if (scanHexSequence2 != i2) {
            if (scanHexSequence2 == -1) {
                return false;
            }
            if (iArr[0] > i6) {
                scanHexSequence2++;
            }
            return isWellFormedIPv4Address(str.substring(scanHexSequence2, i2));
        }
    }

    public static int scanHexSequence(String str, int i2, int i3, int[] iArr) {
        int i4;
        int i5 = 0;
        for (int i6 = i2; i6 < i3; i6++) {
            char charAt = str.charAt(i6);
            if (charAt == ':') {
                if (i5 > 0) {
                    int i7 = iArr[0] + 1;
                    iArr[0] = i7;
                    if (i7 > 8) {
                        return -1;
                    }
                }
                if (i5 == 0 || ((i4 = i6 + 1) < i3 && str.charAt(i4) == ':')) {
                    return i6;
                }
                i5 = 0;
            } else if (isHex(charAt)) {
                i5++;
                if (i5 > 4) {
                    return -1;
                }
            } else if (charAt != '.' || i5 >= 4 || i5 <= 0 || iArr[0] > 6) {
                return -1;
            } else {
                int i8 = (i6 - i5) - 1;
                return i8 >= i2 ? i8 : i8 + 1;
            }
        }
        if (i5 > 0) {
            int i9 = iArr[0] + 1;
            iArr[0] = i9;
            if (i9 <= 8) {
                return i3;
            }
        }
        return -1;
    }

    /* JADX WARNING: Code restructure failed: missing block: B:32:0x00ad, code lost:
        if (r7.m_path.length() > 0) goto L_0x00b2;
     */
    /* JADX WARNING: Removed duplicated region for block: B:39:0x00c8  */
    /* JADX WARNING: Removed duplicated region for block: B:50:0x00fc  */
    /* JADX WARNING: Removed duplicated region for block: B:56:0x012b A[LOOP:0: B:35:0x00b8->B:56:0x012b, LOOP_END] */
    /* JADX WARNING: Removed duplicated region for block: B:57:0x00c0 A[EDGE_INSN: B:57:0x00c0->B:37:0x00c0 ?: BREAK  , SYNTHETIC] */
    /* JADX WARNING: Removed duplicated region for block: B:59:0x00db A[EDGE_INSN: B:59:0x00db->B:43:0x00db ?: BREAK  , SYNTHETIC] */
    public void absolutize(URI uri) {
        String concat;
        int indexOf;
        int i2;
        int indexOf2;
        int lastIndexOf;
        if (this.m_path.length() == 0 && this.m_scheme == null && this.m_host == null && this.m_regAuthority == null) {
            this.m_scheme = uri.getScheme();
            this.m_userinfo = uri.getUserinfo();
            this.m_host = uri.getHost();
            this.m_port = uri.getPort();
            this.m_regAuthority = uri.getRegBasedAuthority();
            this.m_path = uri.getPath();
            if (this.m_queryString == null) {
                this.m_queryString = uri.getQueryString();
                if (this.m_fragment == null) {
                    this.m_fragment = uri.getFragment();
                }
            }
        } else if (this.m_scheme == null) {
            this.m_scheme = uri.getScheme();
            if (this.m_host == null && this.m_regAuthority == null) {
                this.m_userinfo = uri.getUserinfo();
                this.m_host = uri.getHost();
                this.m_port = uri.getPort();
                this.m_regAuthority = uri.getRegBasedAuthority();
                int length = this.m_path.length();
                String str = ZipHelper.FORWARD_SLASH;
                if (length <= 0 || !this.m_path.startsWith(str)) {
                    String path = uri.getPath();
                    if (path != null && path.length() > 0) {
                        int lastIndexOf2 = path.lastIndexOf(47);
                        if (lastIndexOf2 != -1) {
                            str = path.substring(0, lastIndexOf2 + 1);
                            concat = str.concat(this.m_path);
                            while (true) {
                                indexOf = concat.indexOf("/./");
                                if (indexOf != -1) {
                                    break;
                                }
                                concat = concat.substring(0, indexOf + 1).concat(concat.substring(indexOf + 3));
                            }
                            if (concat.endsWith("/.")) {
                                concat = concat.substring(0, concat.length() - 1);
                            }
                            i2 = 1;
                            while (true) {
                                indexOf2 = concat.indexOf("/../", i2);
                                if (indexOf2 > 0) {
                                    break;
                                }
                                String substring = concat.substring(0, concat.indexOf("/../"));
                                int lastIndexOf3 = substring.lastIndexOf(47);
                                if (lastIndexOf3 == -1 || substring.substring(lastIndexOf3).equals("..")) {
                                    i2 = indexOf2 + 4;
                                } else {
                                    concat = concat.substring(0, lastIndexOf3 + 1).concat(concat.substring(indexOf2 + 4));
                                    i2 = lastIndexOf3;
                                }
                            }
                            if (concat.endsWith("/..") && (lastIndexOf = concat.substring(0, concat.length() - 3).lastIndexOf(47)) != -1) {
                                concat = concat.substring(0, lastIndexOf + 1);
                            }
                            this.m_path = concat;
                        }
                    }
                    str = "";
                    concat = str.concat(this.m_path);
                    while (true) {
                        indexOf = concat.indexOf("/./");
                        if (indexOf != -1) {
                        }
                        concat = concat.substring(0, indexOf + 1).concat(concat.substring(indexOf + 3));
                    }
                    if (concat.endsWith("/.")) {
                    }
                    i2 = 1;
                    while (true) {
                        indexOf2 = concat.indexOf("/../", i2);
                        if (indexOf2 > 0) {
                        }
                    }
                    concat = concat.substring(0, lastIndexOf + 1);
                    this.m_path = concat;
                }
            }
        }
    }

    public void appendPath(String str) {
        String str2;
        if (str != null && str.trim().length() != 0) {
            if (isURIString(str)) {
                String str3 = this.m_path;
                if (str3 != null && str3.trim().length() != 0) {
                    if (this.m_path.endsWith(ZipHelper.FORWARD_SLASH)) {
                        if (str.startsWith(ZipHelper.FORWARD_SLASH)) {
                            str2 = this.m_path;
                            str = str.substring(1);
                            str = str2.concat(str);
                        }
                    } else if (!str.startsWith(ZipHelper.FORWARD_SLASH)) {
                        str2 = this.m_path;
                        str = a.a(ZipHelper.FORWARD_SLASH, str);
                        str = str2.concat(str);
                    }
                    str2 = this.m_path;
                    str = str2.concat(str);
                } else if (!str.startsWith(ZipHelper.FORWARD_SLASH)) {
                    str = a.a(ZipHelper.FORWARD_SLASH, str);
                }
                this.m_path = str;
                return;
            }
            throw new MalformedURIException("Path contains invalid character!");
        }
    }

    public boolean equals(Object obj) {
        String str;
        String str2;
        String str3;
        String str4;
        String str5;
        String str6;
        String str7;
        String str8;
        String str9;
        String str10;
        String str11;
        if (!(obj instanceof URI)) {
            return false;
        }
        URI uri = (URI) obj;
        if ((this.m_scheme != null || uri.m_scheme != null) && ((str10 = this.m_scheme) == null || (str11 = uri.m_scheme) == null || !str10.equals(str11))) {
            return false;
        }
        if ((this.m_userinfo != null || uri.m_userinfo != null) && ((str8 = this.m_userinfo) == null || (str9 = uri.m_userinfo) == null || !str8.equals(str9))) {
            return false;
        }
        if (((this.m_host != null || uri.m_host != null) && ((str6 = this.m_host) == null || (str7 = uri.m_host) == null || !str6.equals(str7))) || this.m_port != uri.m_port) {
            return false;
        }
        if ((this.m_path != null || uri.m_path != null) && ((str4 = this.m_path) == null || (str5 = uri.m_path) == null || !str4.equals(str5))) {
            return false;
        }
        if ((this.m_queryString != null || uri.m_queryString != null) && ((str2 = this.m_queryString) == null || (str3 = uri.m_queryString) == null || !str2.equals(str3))) {
            return false;
        }
        if (this.m_fragment == null && uri.m_fragment == null) {
            return true;
        }
        String str12 = this.m_fragment;
        return (str12 == null || (str = uri.m_fragment) == null || !str12.equals(str)) ? false : true;
    }

    public String getAuthority() {
        StringBuffer stringBuffer = new StringBuffer();
        if (!(this.m_host == null && this.m_regAuthority == null)) {
            stringBuffer.append("//");
            if (this.m_host != null) {
                String str = this.m_userinfo;
                if (str != null) {
                    stringBuffer.append(str);
                    stringBuffer.append('@');
                }
                stringBuffer.append(this.m_host);
                if (this.m_port != -1) {
                    stringBuffer.append(':');
                    stringBuffer.append(this.m_port);
                }
            } else {
                stringBuffer.append(this.m_regAuthority);
            }
        }
        return stringBuffer.toString();
    }

    public String getFragment() {
        return this.m_fragment;
    }

    public String getHost() {
        return this.m_host;
    }

    public String getPath() {
        return this.m_path;
    }

    public String getPath(boolean z, boolean z2) {
        StringBuffer stringBuffer = new StringBuffer(this.m_path);
        if (z && this.m_queryString != null) {
            stringBuffer.append(LittleEndianCP950Reader.UNMAPPABLE);
            stringBuffer.append(this.m_queryString);
        }
        if (z2 && this.m_fragment != null) {
            stringBuffer.append('#');
            stringBuffer.append(this.m_fragment);
        }
        return stringBuffer.toString();
    }

    public int getPort() {
        return this.m_port;
    }

    public String getQueryString() {
        return this.m_queryString;
    }

    public String getRegBasedAuthority() {
        return this.m_regAuthority;
    }

    public String getScheme() {
        return this.m_scheme;
    }

    public String getSchemeSpecificPart() {
        StringBuffer stringBuffer = new StringBuffer();
        if (!(this.m_host == null && this.m_regAuthority == null)) {
            stringBuffer.append("//");
            if (this.m_host != null) {
                String str = this.m_userinfo;
                if (str != null) {
                    stringBuffer.append(str);
                    stringBuffer.append('@');
                }
                stringBuffer.append(this.m_host);
                if (this.m_port != -1) {
                    stringBuffer.append(':');
                    stringBuffer.append(this.m_port);
                }
            } else {
                stringBuffer.append(this.m_regAuthority);
            }
        }
        String str2 = this.m_path;
        if (str2 != null) {
            stringBuffer.append(str2);
        }
        if (this.m_queryString != null) {
            stringBuffer.append(LittleEndianCP950Reader.UNMAPPABLE);
            stringBuffer.append(this.m_queryString);
        }
        if (this.m_fragment != null) {
            stringBuffer.append('#');
            stringBuffer.append(this.m_fragment);
        }
        return stringBuffer.toString();
    }

    public String getUserinfo() {
        return this.m_userinfo;
    }

    public boolean isAbsoluteURI() {
        return this.m_scheme != null;
    }

    public boolean isGenericURI() {
        return this.m_host != null;
    }

    public void setFragment(String str) {
        if (str == null) {
            str = null;
        } else if (!isGenericURI()) {
            throw new MalformedURIException("Fragment can only be set for a generic URI!");
        } else if (getPath() == null) {
            throw new MalformedURIException("Fragment cannot be set when path is null!");
        } else if (!isURIString(str)) {
            throw new MalformedURIException("Fragment contains invalid character!");
        }
        this.m_fragment = str;
    }

    public void setHost(String str) {
        if (str == null || str.length() == 0) {
            if (str != null) {
                this.m_regAuthority = null;
            }
            this.m_host = str;
            this.m_userinfo = null;
            this.m_port = -1;
        } else if (isWellFormedAddress(str)) {
            this.m_host = str;
            this.m_regAuthority = null;
        } else {
            throw new MalformedURIException("Host is not a well formed address!");
        }
    }

    public void setPath(String str) {
        if (str == null) {
            this.m_path = null;
            this.m_queryString = null;
            this.m_fragment = null;
            return;
        }
        initializePath(str, 0);
    }

    public void setPort(int i2) {
        if (i2 < 0 || i2 > 65535) {
            if (i2 != -1) {
                throw new MalformedURIException("Invalid port number!");
            }
        } else if (this.m_host == null) {
            throw new MalformedURIException("Port cannot be set when host is null!");
        }
        this.m_port = i2;
    }

    public void setQueryString(String str) {
        if (str == null) {
            str = null;
        } else if (!isGenericURI()) {
            throw new MalformedURIException("Query string can only be set for a generic URI!");
        } else if (getPath() == null) {
            throw new MalformedURIException("Query string cannot be set when path is null!");
        } else if (!isURIString(str)) {
            throw new MalformedURIException("Query string contains invalid character!");
        }
        this.m_queryString = str;
    }

    public void setRegBasedAuthority(String str) {
        if (str == null) {
            this.m_regAuthority = null;
        } else if (str.length() < 1 || !isValidRegistryBasedAuthority(str) || str.indexOf(47) != -1) {
            throw new MalformedURIException("Registry based authority is not well formed.");
        } else {
            this.m_regAuthority = str;
            this.m_host = null;
            this.m_userinfo = null;
            this.m_port = -1;
        }
    }

    public void setScheme(String str) {
        if (str == null) {
            throw new MalformedURIException("Cannot set scheme from null string!");
        } else if (isConformantSchemeName(str)) {
            this.m_scheme = str.toLowerCase(Locale.ENGLISH);
        } else {
            throw new MalformedURIException("The scheme is not conformant.");
        }
    }

    public void setUserinfo(String str) {
        if (str == null) {
            this.m_userinfo = null;
        } else if (this.m_host != null) {
            int length = str.length();
            for (int i2 = 0; i2 < length; i2++) {
                char charAt = str.charAt(i2);
                if (charAt == '%') {
                    int i3 = i2 + 2;
                    if (i3 >= length || !isHex(str.charAt(i2 + 1)) || !isHex(str.charAt(i3))) {
                        throw new MalformedURIException("Userinfo contains invalid escape sequence!");
                    }
                } else if (!isUserinfoCharacter(charAt)) {
                    StringBuffer stringBuffer = new StringBuffer();
                    stringBuffer.append("Userinfo contains invalid character:");
                    stringBuffer.append(charAt);
                    throw new MalformedURIException(stringBuffer.toString());
                }
            }
            this.m_userinfo = str;
        } else {
            throw new MalformedURIException("Userinfo cannot be set when host is null!");
        }
    }

    public String toString() {
        StringBuffer stringBuffer = new StringBuffer();
        String str = this.m_scheme;
        if (str != null) {
            stringBuffer.append(str);
            stringBuffer.append(':');
        }
        stringBuffer.append(getSchemeSpecificPart());
        return stringBuffer.toString();
    }
}
