package org.apache.xerces.util;

import java.util.Arrays;
import org.apache.poi.hssf.usermodel.HSSFShapeTypes;

public class XML11Char {
    public static final int MASK_XML11_CONTENT = 32;
    public static final int MASK_XML11_CONTENT_INTERNAL = 48;
    public static final int MASK_XML11_CONTROL = 16;
    public static final int MASK_XML11_NAME = 8;
    public static final int MASK_XML11_NAME_START = 4;
    public static final int MASK_XML11_NCNAME = 128;
    public static final int MASK_XML11_NCNAME_START = 64;
    public static final int MASK_XML11_SPACE = 2;
    public static final int MASK_XML11_VALID = 1;
    public static final byte[] XML11CHARS;

    static {
        byte[] bArr = new byte[65536];
        XML11CHARS = bArr;
        Arrays.fill(bArr, 1, 9, (byte) 17);
        byte[] bArr2 = XML11CHARS;
        bArr2[9] = 35;
        bArr2[10] = 3;
        Arrays.fill(bArr2, 11, 13, (byte) 17);
        byte[] bArr3 = XML11CHARS;
        bArr3[13] = 3;
        Arrays.fill(bArr3, 14, 32, (byte) 17);
        byte[] bArr4 = XML11CHARS;
        bArr4[32] = 35;
        Arrays.fill(bArr4, 33, 38, (byte) 33);
        byte[] bArr5 = XML11CHARS;
        bArr5[38] = 1;
        Arrays.fill(bArr5, 39, 45, (byte) 33);
        Arrays.fill(XML11CHARS, 45, 47, (byte) -87);
        byte[] bArr6 = XML11CHARS;
        bArr6[47] = 33;
        Arrays.fill(bArr6, 48, 58, (byte) -87);
        byte[] bArr7 = XML11CHARS;
        bArr7[58] = 45;
        bArr7[59] = 33;
        bArr7[60] = 1;
        Arrays.fill(bArr7, 61, 65, (byte) 33);
        Arrays.fill(XML11CHARS, 65, 91, (byte) -19);
        Arrays.fill(XML11CHARS, 91, 93, (byte) 33);
        byte[] bArr8 = XML11CHARS;
        bArr8[93] = 1;
        bArr8[94] = 33;
        bArr8[95] = -19;
        bArr8[96] = 33;
        Arrays.fill(bArr8, 97, 123, (byte) -19);
        Arrays.fill(XML11CHARS, 123, 127, (byte) 33);
        Arrays.fill(XML11CHARS, 127, 133, (byte) 17);
        byte[] bArr9 = XML11CHARS;
        bArr9[133] = 35;
        Arrays.fill(bArr9, 134, 160, (byte) 17);
        Arrays.fill(XML11CHARS, 160, 183, (byte) 33);
        byte[] bArr10 = XML11CHARS;
        bArr10[183] = -87;
        Arrays.fill(bArr10, 184, (int) HSSFShapeTypes.ActionButtonInformation, (byte) 33);
        Arrays.fill(XML11CHARS, (int) HSSFShapeTypes.ActionButtonInformation, 215, (byte) -19);
        byte[] bArr11 = XML11CHARS;
        bArr11[215] = 33;
        Arrays.fill(bArr11, 216, 247, (byte) -19);
        byte[] bArr12 = XML11CHARS;
        bArr12[247] = 33;
        Arrays.fill(bArr12, 248, 768, (byte) -19);
        Arrays.fill(XML11CHARS, 768, 880, (byte) -87);
        Arrays.fill(XML11CHARS, 880, 894, (byte) -19);
        byte[] bArr13 = XML11CHARS;
        bArr13[894] = 33;
        Arrays.fill(bArr13, 895, 8192, (byte) -19);
        Arrays.fill(XML11CHARS, 8192, 8204, (byte) 33);
        Arrays.fill(XML11CHARS, 8204, 8206, (byte) -19);
        Arrays.fill(XML11CHARS, 8206, 8232, (byte) 33);
        byte[] bArr14 = XML11CHARS;
        bArr14[8232] = 35;
        Arrays.fill(bArr14, 8233, 8255, (byte) 33);
        Arrays.fill(XML11CHARS, 8255, 8257, (byte) -87);
        Arrays.fill(XML11CHARS, 8257, 8304, (byte) 33);
        Arrays.fill(XML11CHARS, 8304, 8592, (byte) -19);
        Arrays.fill(XML11CHARS, 8592, 11264, (byte) 33);
        Arrays.fill(XML11CHARS, 11264, 12272, (byte) -19);
        Arrays.fill(XML11CHARS, 12272, 12289, (byte) 33);
        Arrays.fill(XML11CHARS, 12289, 55296, (byte) -19);
        Arrays.fill(XML11CHARS, 57344, 63744, (byte) 33);
        Arrays.fill(XML11CHARS, 63744, 64976, (byte) -19);
        Arrays.fill(XML11CHARS, 64976, 65008, (byte) 33);
        Arrays.fill(XML11CHARS, 65008, 65534, (byte) -19);
    }

    public static boolean isXML11Content(int i2) {
        return (i2 < 65536 && (XML11CHARS[i2] & 32) != 0) || (65536 <= i2 && i2 <= 1114111);
    }

    public static boolean isXML11InternalEntityContent(int i2) {
        return (i2 < 65536 && (XML11CHARS[i2] & 48) != 0) || (65536 <= i2 && i2 <= 1114111);
    }

    public static boolean isXML11Invalid(int i2) {
        return !isXML11Valid(i2);
    }

    public static boolean isXML11NCName(int i2) {
        return (i2 < 65536 && (XML11CHARS[i2] & 128) != 0) || (65536 <= i2 && i2 < 983040);
    }

    public static boolean isXML11NCNameStart(int i2) {
        return (i2 < 65536 && (XML11CHARS[i2] & 64) != 0) || (65536 <= i2 && i2 < 983040);
    }

    public static boolean isXML11Name(int i2) {
        return (i2 < 65536 && (XML11CHARS[i2] & 8) != 0) || (i2 >= 65536 && i2 < 983040);
    }

    public static boolean isXML11NameHighSurrogate(int i2) {
        return 55296 <= i2 && i2 <= 56191;
    }

    public static boolean isXML11NameStart(int i2) {
        return (i2 < 65536 && (XML11CHARS[i2] & 4) != 0) || (65536 <= i2 && i2 < 983040);
    }

    public static boolean isXML11Space(int i2) {
        return i2 < 65536 && (XML11CHARS[i2] & 2) != 0;
    }

    public static boolean isXML11Valid(int i2) {
        if (i2 >= 65536 || (XML11CHARS[i2] & 1) == 0) {
            return 65536 <= i2 && i2 <= 1114111;
        }
        return true;
    }

    public static boolean isXML11ValidLiteral(int i2) {
        if (i2 < 65536) {
            byte[] bArr = XML11CHARS;
            if ((bArr[i2] & 1) != 0 && (bArr[i2] & 16) == 0) {
                return true;
            }
        }
        return 65536 <= i2 && i2 <= 1114111;
    }

    public static boolean isXML11ValidNCName(String str) {
        int i2;
        int length = str.length();
        if (length == 0) {
            return false;
        }
        char charAt = str.charAt(0);
        if (!isXML11NCNameStart(charAt)) {
            if (length > 1 && isXML11NameHighSurrogate(charAt)) {
                char charAt2 = str.charAt(1);
                if (XMLChar.isLowSurrogate(charAt2) && isXML11NCNameStart(XMLChar.supplemental(charAt, charAt2))) {
                    i2 = 2;
                }
            }
            return false;
        }
        i2 = 1;
        while (i2 < length) {
            char charAt3 = str.charAt(i2);
            if (!isXML11NCName(charAt3)) {
                i2++;
                if (i2 < length && isXML11NameHighSurrogate(charAt3)) {
                    char charAt4 = str.charAt(i2);
                    if (XMLChar.isLowSurrogate(charAt4) && isXML11NCName(XMLChar.supplemental(charAt3, charAt4))) {
                    }
                }
                return false;
            }
            i2++;
        }
        return true;
    }

    public static boolean isXML11ValidName(String str) {
        int i2;
        int length = str.length();
        if (length == 0) {
            return false;
        }
        char charAt = str.charAt(0);
        if (!isXML11NameStart(charAt)) {
            if (length > 1 && isXML11NameHighSurrogate(charAt)) {
                char charAt2 = str.charAt(1);
                if (XMLChar.isLowSurrogate(charAt2) && isXML11NameStart(XMLChar.supplemental(charAt, charAt2))) {
                    i2 = 2;
                }
            }
            return false;
        }
        i2 = 1;
        while (i2 < length) {
            char charAt3 = str.charAt(i2);
            if (!isXML11Name(charAt3)) {
                i2++;
                if (i2 < length && isXML11NameHighSurrogate(charAt3)) {
                    char charAt4 = str.charAt(i2);
                    if (XMLChar.isLowSurrogate(charAt4) && isXML11Name(XMLChar.supplemental(charAt3, charAt4))) {
                    }
                }
                return false;
            }
            i2++;
        }
        return true;
    }

    public static boolean isXML11ValidNmtoken(String str) {
        int length = str.length();
        if (length == 0) {
            return false;
        }
        int i2 = 0;
        while (i2 < length) {
            char charAt = str.charAt(i2);
            if (!isXML11Name(charAt)) {
                i2++;
                if (i2 < length && isXML11NameHighSurrogate(charAt)) {
                    char charAt2 = str.charAt(i2);
                    if (XMLChar.isLowSurrogate(charAt2) && isXML11Name(XMLChar.supplemental(charAt, charAt2))) {
                    }
                }
                return false;
            }
            i2++;
        }
        return true;
    }
}
