package org.apache.xerces.util;

import org.apache.xerces.xni.Augmentations;
import org.apache.xerces.xni.QName;
import org.apache.xerces.xni.XMLAttributes;

public class XMLAttributesImpl implements XMLAttributes {
    public static final int SIZE_LIMIT = 20;
    public static final int TABLE_SIZE = 101;
    public Attribute[] fAttributeTableView;
    public int[] fAttributeTableViewChainState;
    public Attribute[] fAttributes;
    public boolean fIsTableViewConsistent;
    public int fLargeCount;
    public int fLength;
    public boolean fNamespaces;
    public int fTableViewBuckets;

    public static class Attribute {
        public Augmentations augs = new AugmentationsImpl();
        public final QName name = new QName();
        public Attribute next;
        public String nonNormalizedValue;
        public boolean specified;
        public String type;
        public String value;
    }

    public XMLAttributesImpl() {
        this(101);
    }

    public XMLAttributesImpl(int i2) {
        this.fNamespaces = true;
        this.fLargeCount = 1;
        this.fAttributes = new Attribute[4];
        this.fTableViewBuckets = i2;
        int i3 = 0;
        while (true) {
            Attribute[] attributeArr = this.fAttributes;
            if (i3 < attributeArr.length) {
                attributeArr[i3] = new Attribute();
                i3++;
            } else {
                return;
            }
        }
    }

    private String getReportableType(String str) {
        return str.charAt(0) == '(' ? "NMTOKEN" : str;
    }

    @Override // org.apache.xerces.xni.XMLAttributes
    public int addAttribute(QName qName, String str, String str2) {
        int i2;
        int i3;
        if (this.fLength < 20) {
            String str3 = qName.uri;
            i2 = (str3 == null || str3.length() == 0) ? getIndexFast(qName.rawname) : getIndexFast(qName.uri, qName.localpart);
            if (i2 == -1) {
                i2 = this.fLength;
                this.fLength = i2 + 1;
                Attribute[] attributeArr = this.fAttributes;
                if (i2 == attributeArr.length) {
                    int length = attributeArr.length + 4;
                    Attribute[] attributeArr2 = new Attribute[length];
                    System.arraycopy(attributeArr, 0, attributeArr2, 0, attributeArr.length);
                    for (int length2 = this.fAttributes.length; length2 < length; length2++) {
                        attributeArr2[length2] = new Attribute();
                    }
                    this.fAttributes = attributeArr2;
                }
            }
        } else {
            String str4 = qName.uri;
            if (str4 == null || str4.length() == 0 || (i2 = getIndexFast(qName.uri, qName.localpart)) == -1) {
                if (!this.fIsTableViewConsistent || this.fLength == 20) {
                    prepareAndPopulateTableView();
                    this.fIsTableViewConsistent = true;
                }
                int tableViewBucket = getTableViewBucket(qName.rawname);
                if (this.fAttributeTableViewChainState[tableViewBucket] != this.fLargeCount) {
                    i3 = this.fLength;
                    this.fLength = i3 + 1;
                    Attribute[] attributeArr3 = this.fAttributes;
                    if (i3 == attributeArr3.length) {
                        int length3 = attributeArr3.length << 1;
                        Attribute[] attributeArr4 = new Attribute[length3];
                        System.arraycopy(attributeArr3, 0, attributeArr4, 0, attributeArr3.length);
                        for (int length4 = this.fAttributes.length; length4 < length3; length4++) {
                            attributeArr4[length4] = new Attribute();
                        }
                        this.fAttributes = attributeArr4;
                    }
                    this.fAttributeTableViewChainState[tableViewBucket] = this.fLargeCount;
                    Attribute[] attributeArr5 = this.fAttributes;
                    attributeArr5[i3].next = null;
                    this.fAttributeTableView[tableViewBucket] = attributeArr5[i3];
                } else {
                    Attribute attribute = this.fAttributeTableView[tableViewBucket];
                    while (attribute != null && attribute.name.rawname != qName.rawname) {
                        attribute = attribute.next;
                    }
                    if (attribute == null) {
                        i3 = this.fLength;
                        this.fLength = i3 + 1;
                        Attribute[] attributeArr6 = this.fAttributes;
                        if (i3 == attributeArr6.length) {
                            int length5 = attributeArr6.length << 1;
                            Attribute[] attributeArr7 = new Attribute[length5];
                            System.arraycopy(attributeArr6, 0, attributeArr7, 0, attributeArr6.length);
                            for (int length6 = this.fAttributes.length; length6 < length5; length6++) {
                                attributeArr7[length6] = new Attribute();
                            }
                            this.fAttributes = attributeArr7;
                        }
                        Attribute[] attributeArr8 = this.fAttributes;
                        Attribute attribute2 = attributeArr8[i3];
                        Attribute[] attributeArr9 = this.fAttributeTableView;
                        attribute2.next = attributeArr9[tableViewBucket];
                        attributeArr9[tableViewBucket] = attributeArr8[i3];
                    } else {
                        i2 = getIndexFast(qName.rawname);
                    }
                }
                i2 = i3;
            }
        }
        Attribute attribute3 = this.fAttributes[i2];
        attribute3.name.setValues(qName);
        attribute3.type = str;
        attribute3.value = str2;
        attribute3.nonNormalizedValue = str2;
        attribute3.specified = false;
        attribute3.augs.removeAllItems();
        return i2;
    }

    public void addAttributeNS(QName qName, String str, String str2) {
        int i2 = this.fLength;
        int i3 = i2 + 1;
        this.fLength = i3;
        Attribute[] attributeArr = this.fAttributes;
        if (i2 == attributeArr.length) {
            Attribute[] attributeArr2 = new Attribute[(i3 < 20 ? attributeArr.length + 4 : attributeArr.length << 1)];
            Attribute[] attributeArr3 = this.fAttributes;
            System.arraycopy(attributeArr3, 0, attributeArr2, 0, attributeArr3.length);
            for (int length = this.fAttributes.length; length < attributeArr2.length; length++) {
                attributeArr2[length] = new Attribute();
            }
            this.fAttributes = attributeArr2;
        }
        Attribute attribute = this.fAttributes[i2];
        attribute.name.setValues(qName);
        attribute.type = str;
        attribute.value = str2;
        attribute.nonNormalizedValue = str2;
        attribute.specified = false;
        attribute.augs.removeAllItems();
    }

    public QName checkDuplicatesNS() {
        int i2 = 0;
        if (this.fLength <= 20) {
            while (i2 < this.fLength - 1) {
                Attribute attribute = this.fAttributes[i2];
                int i3 = i2 + 1;
                for (int i4 = i3; i4 < this.fLength; i4++) {
                    Attribute attribute2 = this.fAttributes[i4];
                    QName qName = attribute.name;
                    String str = qName.localpart;
                    QName qName2 = attribute2.name;
                    if (str == qName2.localpart && qName.uri == qName2.uri) {
                        return qName2;
                    }
                }
                i2 = i3;
            }
        } else {
            this.fIsTableViewConsistent = false;
            prepareTableView();
            for (int i5 = this.fLength - 1; i5 >= 0; i5--) {
                Attribute attribute3 = this.fAttributes[i5];
                QName qName3 = attribute3.name;
                int tableViewBucket = getTableViewBucket(qName3.localpart, qName3.uri);
                int[] iArr = this.fAttributeTableViewChainState;
                int i6 = iArr[tableViewBucket];
                int i7 = this.fLargeCount;
                if (i6 != i7) {
                    iArr[tableViewBucket] = i7;
                    attribute3.next = null;
                    this.fAttributeTableView[tableViewBucket] = attribute3;
                } else {
                    for (Attribute attribute4 = this.fAttributeTableView[tableViewBucket]; attribute4 != null; attribute4 = attribute4.next) {
                        QName qName4 = attribute4.name;
                        String str2 = qName4.localpart;
                        QName qName5 = attribute3.name;
                        if (str2 == qName5.localpart && qName4.uri == qName5.uri) {
                            return qName5;
                        }
                    }
                    Attribute[] attributeArr = this.fAttributeTableView;
                    attribute3.next = attributeArr[tableViewBucket];
                    attributeArr[tableViewBucket] = attribute3;
                }
            }
        }
        return null;
    }

    public void cleanTableView() {
        int i2 = this.fLargeCount + 1;
        this.fLargeCount = i2;
        if (i2 < 0) {
            if (this.fAttributeTableViewChainState != null) {
                for (int i3 = this.fTableViewBuckets - 1; i3 >= 0; i3--) {
                    this.fAttributeTableViewChainState[i3] = 0;
                }
            }
            this.fLargeCount = 1;
        }
    }

    @Override // org.apache.xerces.xni.XMLAttributes
    public Augmentations getAugmentations(int i2) {
        if (i2 < 0 || i2 >= this.fLength) {
            return null;
        }
        return this.fAttributes[i2].augs;
    }

    @Override // org.apache.xerces.xni.XMLAttributes
    public Augmentations getAugmentations(String str) {
        int index = getIndex(str);
        if (index != -1) {
            return this.fAttributes[index].augs;
        }
        return null;
    }

    @Override // org.apache.xerces.xni.XMLAttributes
    public Augmentations getAugmentations(String str, String str2) {
        int index = getIndex(str, str2);
        if (index != -1) {
            return this.fAttributes[index].augs;
        }
        return null;
    }

    @Override // org.apache.xerces.xni.XMLAttributes
    public int getIndex(String str) {
        for (int i2 = 0; i2 < this.fLength; i2++) {
            String str2 = this.fAttributes[i2].name.rawname;
            if (str2 != null && str2.equals(str)) {
                return i2;
            }
        }
        return -1;
    }

    @Override // org.apache.xerces.xni.XMLAttributes
    public int getIndex(String str, String str2) {
        String str3;
        for (int i2 = 0; i2 < this.fLength; i2++) {
            Attribute attribute = this.fAttributes[i2];
            String str4 = attribute.name.localpart;
            if (str4 != null && str4.equals(str2) && (str == (str3 = attribute.name.uri) || !(str == null || str3 == null || !str3.equals(str)))) {
                return i2;
            }
        }
        return -1;
    }

    public int getIndexFast(String str) {
        for (int i2 = 0; i2 < this.fLength; i2++) {
            if (this.fAttributes[i2].name.rawname == str) {
                return i2;
            }
        }
        return -1;
    }

    public int getIndexFast(String str, String str2) {
        for (int i2 = 0; i2 < this.fLength; i2++) {
            QName qName = this.fAttributes[i2].name;
            if (qName.localpart == str2 && qName.uri == str) {
                return i2;
            }
        }
        return -1;
    }

    @Override // org.apache.xerces.xni.XMLAttributes
    public int getLength() {
        return this.fLength;
    }

    @Override // org.apache.xerces.xni.XMLAttributes
    public String getLocalName(int i2) {
        if (!this.fNamespaces) {
            return "";
        }
        if (i2 < 0 || i2 >= this.fLength) {
            return null;
        }
        return this.fAttributes[i2].name.localpart;
    }

    public String getName(int i2) {
        if (i2 < 0 || i2 >= this.fLength) {
            return null;
        }
        return this.fAttributes[i2].name.rawname;
    }

    @Override // org.apache.xerces.xni.XMLAttributes
    public void getName(int i2, QName qName) {
        qName.setValues(this.fAttributes[i2].name);
    }

    @Override // org.apache.xerces.xni.XMLAttributes
    public String getNonNormalizedValue(int i2) {
        return this.fAttributes[i2].nonNormalizedValue;
    }

    @Override // org.apache.xerces.xni.XMLAttributes
    public String getPrefix(int i2) {
        if (i2 < 0 || i2 >= this.fLength) {
            return null;
        }
        String str = this.fAttributes[i2].name.prefix;
        return str != null ? str : "";
    }

    @Override // org.apache.xerces.xni.XMLAttributes
    public String getQName(int i2) {
        if (i2 < 0 || i2 >= this.fLength) {
            return null;
        }
        String str = this.fAttributes[i2].name.rawname;
        return str != null ? str : "";
    }

    public int getTableViewBucket(String str) {
        return (str.hashCode() & Integer.MAX_VALUE) % this.fTableViewBuckets;
    }

    public int getTableViewBucket(String str, String str2) {
        int hashCode = str.hashCode();
        return (str2 == null ? hashCode & Integer.MAX_VALUE : (str2.hashCode() + hashCode) & Integer.MAX_VALUE) % this.fTableViewBuckets;
    }

    @Override // org.apache.xerces.xni.XMLAttributes
    public String getType(int i2) {
        if (i2 < 0 || i2 >= this.fLength) {
            return null;
        }
        return getReportableType(this.fAttributes[i2].type);
    }

    @Override // org.apache.xerces.xni.XMLAttributes
    public String getType(String str) {
        int index = getIndex(str);
        if (index != -1) {
            return getReportableType(this.fAttributes[index].type);
        }
        return null;
    }

    @Override // org.apache.xerces.xni.XMLAttributes
    public String getType(String str, String str2) {
        int index;
        if (this.fNamespaces && (index = getIndex(str, str2)) != -1) {
            return getReportableType(this.fAttributes[index].type);
        }
        return null;
    }

    @Override // org.apache.xerces.xni.XMLAttributes
    public String getURI(int i2) {
        if (i2 < 0 || i2 >= this.fLength) {
            return null;
        }
        return this.fAttributes[i2].name.uri;
    }

    @Override // org.apache.xerces.xni.XMLAttributes
    public String getValue(int i2) {
        if (i2 < 0 || i2 >= this.fLength) {
            return null;
        }
        return this.fAttributes[i2].value;
    }

    @Override // org.apache.xerces.xni.XMLAttributes
    public String getValue(String str) {
        int index = getIndex(str);
        if (index != -1) {
            return this.fAttributes[index].value;
        }
        return null;
    }

    @Override // org.apache.xerces.xni.XMLAttributes
    public String getValue(String str, String str2) {
        int index = getIndex(str, str2);
        if (index != -1) {
            return getValue(index);
        }
        return null;
    }

    @Override // org.apache.xerces.xni.XMLAttributes
    public boolean isSpecified(int i2) {
        return this.fAttributes[i2].specified;
    }

    public void prepareAndPopulateTableView() {
        prepareTableView();
        for (int i2 = 0; i2 < this.fLength; i2++) {
            Attribute attribute = this.fAttributes[i2];
            int tableViewBucket = getTableViewBucket(attribute.name.rawname);
            int[] iArr = this.fAttributeTableViewChainState;
            int i3 = iArr[tableViewBucket];
            int i4 = this.fLargeCount;
            if (i3 != i4) {
                iArr[tableViewBucket] = i4;
                attribute.next = null;
                this.fAttributeTableView[tableViewBucket] = attribute;
            } else {
                Attribute[] attributeArr = this.fAttributeTableView;
                attribute.next = attributeArr[tableViewBucket];
                attributeArr[tableViewBucket] = attribute;
            }
        }
    }

    public void prepareTableView() {
        if (this.fAttributeTableView == null) {
            int i2 = this.fTableViewBuckets;
            this.fAttributeTableView = new Attribute[i2];
            this.fAttributeTableViewChainState = new int[i2];
            return;
        }
        cleanTableView();
    }

    @Override // org.apache.xerces.xni.XMLAttributes
    public void removeAllAttributes() {
        this.fLength = 0;
    }

    @Override // org.apache.xerces.xni.XMLAttributes
    public void removeAttributeAt(int i2) {
        this.fIsTableViewConsistent = false;
        int i3 = this.fLength;
        if (i2 < i3 - 1) {
            Attribute[] attributeArr = this.fAttributes;
            Attribute attribute = attributeArr[i2];
            System.arraycopy(attributeArr, i2 + 1, attributeArr, i2, (i3 - i2) - 1);
            this.fAttributes[this.fLength - 1] = attribute;
        }
        this.fLength--;
    }

    @Override // org.apache.xerces.xni.XMLAttributes
    public void setAugmentations(int i2, Augmentations augmentations) {
        this.fAttributes[i2].augs = augmentations;
    }

    @Override // org.apache.xerces.xni.XMLAttributes
    public void setName(int i2, QName qName) {
        this.fAttributes[i2].name.setValues(qName);
    }

    public void setNamespaces(boolean z) {
        this.fNamespaces = z;
    }

    @Override // org.apache.xerces.xni.XMLAttributes
    public void setNonNormalizedValue(int i2, String str) {
        if (str == null) {
            str = this.fAttributes[i2].value;
        }
        this.fAttributes[i2].nonNormalizedValue = str;
    }

    @Override // org.apache.xerces.xni.XMLAttributes
    public void setSpecified(int i2, boolean z) {
        this.fAttributes[i2].specified = z;
    }

    @Override // org.apache.xerces.xni.XMLAttributes
    public void setType(int i2, String str) {
        this.fAttributes[i2].type = str;
    }

    public void setURI(int i2, String str) {
        this.fAttributes[i2].name.uri = str;
    }

    @Override // org.apache.xerces.xni.XMLAttributes
    public void setValue(int i2, String str) {
        Attribute attribute = this.fAttributes[i2];
        attribute.value = str;
        attribute.nonNormalizedValue = str;
    }
}
