package org.apache.xerces.util;

import org.apache.xerces.xni.grammars.Grammar;
import org.apache.xerces.xni.grammars.XMLGrammarDescription;
import org.apache.xerces.xni.grammars.XMLGrammarPool;

public class XMLGrammarPoolImpl implements XMLGrammarPool {
    public static final boolean DEBUG = false;
    public static final int TABLE_SIZE = 11;
    public int fGrammarCount;
    public Entry[] fGrammars;
    public boolean fPoolIsLocked;

    public static final class Entry {
        public XMLGrammarDescription desc;
        public Grammar grammar;
        public int hash;
        public Entry next;

        public Entry(int i2, XMLGrammarDescription xMLGrammarDescription, Grammar grammar2, Entry entry) {
            this.hash = i2;
            this.desc = xMLGrammarDescription;
            this.grammar = grammar2;
            this.next = entry;
        }

        public void clear() {
            this.desc = null;
            this.grammar = null;
            Entry entry = this.next;
            if (entry != null) {
                entry.clear();
                this.next = null;
            }
        }
    }

    public XMLGrammarPoolImpl() {
        this.fGrammars = null;
        this.fGrammarCount = 0;
        this.fGrammars = new Entry[11];
        this.fPoolIsLocked = false;
    }

    public XMLGrammarPoolImpl(int i2) {
        this.fGrammars = null;
        this.fGrammarCount = 0;
        this.fGrammars = new Entry[i2];
        this.fPoolIsLocked = false;
    }

    @Override // org.apache.xerces.xni.grammars.XMLGrammarPool
    public void cacheGrammars(String str, Grammar[] grammarArr) {
        if (!this.fPoolIsLocked) {
            for (Grammar grammar : grammarArr) {
                putGrammar(grammar);
            }
        }
    }

    @Override // org.apache.xerces.xni.grammars.XMLGrammarPool
    public void clear() {
        int i2 = 0;
        while (true) {
            Entry[] entryArr = this.fGrammars;
            if (i2 >= entryArr.length) {
                this.fGrammarCount = 0;
                return;
            }
            if (entryArr[i2] != null) {
                entryArr[i2].clear();
                this.fGrammars[i2] = null;
            }
            i2++;
        }
    }

    public boolean containsGrammar(XMLGrammarDescription xMLGrammarDescription) {
        synchronized (this.fGrammars) {
            int hashCode = hashCode(xMLGrammarDescription);
            for (Entry entry = this.fGrammars[(Integer.MAX_VALUE & hashCode) % this.fGrammars.length]; entry != null; entry = entry.next) {
                if (entry.hash == hashCode && equals(entry.desc, xMLGrammarDescription)) {
                    return true;
                }
            }
            return false;
        }
    }

    public boolean equals(XMLGrammarDescription xMLGrammarDescription, XMLGrammarDescription xMLGrammarDescription2) {
        return xMLGrammarDescription.equals(xMLGrammarDescription2);
    }

    public Grammar getGrammar(XMLGrammarDescription xMLGrammarDescription) {
        synchronized (this.fGrammars) {
            int hashCode = hashCode(xMLGrammarDescription);
            for (Entry entry = this.fGrammars[(Integer.MAX_VALUE & hashCode) % this.fGrammars.length]; entry != null; entry = entry.next) {
                if (entry.hash == hashCode && equals(entry.desc, xMLGrammarDescription)) {
                    return entry.grammar;
                }
            }
            return null;
        }
    }

    public int hashCode(XMLGrammarDescription xMLGrammarDescription) {
        return xMLGrammarDescription.hashCode();
    }

    @Override // org.apache.xerces.xni.grammars.XMLGrammarPool
    public void lockPool() {
        this.fPoolIsLocked = true;
    }

    public void putGrammar(Grammar grammar) {
        if (!this.fPoolIsLocked) {
            synchronized (this.fGrammars) {
                XMLGrammarDescription grammarDescription = grammar.getGrammarDescription();
                int hashCode = hashCode(grammarDescription);
                int length = (Integer.MAX_VALUE & hashCode) % this.fGrammars.length;
                for (Entry entry = this.fGrammars[length]; entry != null; entry = entry.next) {
                    if (entry.hash == hashCode && equals(entry.desc, grammarDescription)) {
                        entry.grammar = grammar;
                        return;
                    }
                }
                this.fGrammars[length] = new Entry(hashCode, grammarDescription, grammar, this.fGrammars[length]);
                this.fGrammarCount++;
            }
        }
    }

    public Grammar removeGrammar(XMLGrammarDescription xMLGrammarDescription) {
        synchronized (this.fGrammars) {
            int hashCode = hashCode(xMLGrammarDescription);
            int length = (Integer.MAX_VALUE & hashCode) % this.fGrammars.length;
            Entry entry = null;
            for (Entry entry2 = this.fGrammars[length]; entry2 != null; entry2 = entry2.next) {
                if (entry2.hash != hashCode || !equals(entry2.desc, xMLGrammarDescription)) {
                    entry = entry2;
                } else {
                    if (entry != null) {
                        entry.next = entry2.next;
                    } else {
                        this.fGrammars[length] = entry2.next;
                    }
                    Grammar grammar = entry2.grammar;
                    entry2.grammar = null;
                    this.fGrammarCount--;
                    return grammar;
                }
            }
            return null;
        }
    }

    @Override // org.apache.xerces.xni.grammars.XMLGrammarPool
    public Grammar retrieveGrammar(XMLGrammarDescription xMLGrammarDescription) {
        return getGrammar(xMLGrammarDescription);
    }

    @Override // org.apache.xerces.xni.grammars.XMLGrammarPool
    public Grammar[] retrieveInitialGrammarSet(String str) {
        Grammar[] grammarArr;
        synchronized (this.fGrammars) {
            int length = this.fGrammars.length;
            Grammar[] grammarArr2 = new Grammar[this.fGrammarCount];
            int i2 = 0;
            for (int i3 = 0; i3 < length; i3++) {
                for (Entry entry = this.fGrammars[i3]; entry != null; entry = entry.next) {
                    if (entry.desc.getGrammarType().equals(str)) {
                        grammarArr2[i2] = entry.grammar;
                        i2++;
                    }
                }
            }
            grammarArr = new Grammar[i2];
            System.arraycopy(grammarArr2, 0, grammarArr, 0, i2);
        }
        return grammarArr;
    }

    @Override // org.apache.xerces.xni.grammars.XMLGrammarPool
    public void unlockPool() {
        this.fPoolIsLocked = false;
    }
}
