package org.apache.xerces.xinclude;

import java.util.Enumeration;
import org.apache.xerces.util.NamespaceSupport;
import org.apache.xerces.util.XMLSymbols;
import org.apache.xerces.xni.NamespaceContext;

public class MultipleScopeNamespaceSupport extends NamespaceSupport {
    public int fCurrentScope = 0;
    public int[] fScope;

    public MultipleScopeNamespaceSupport() {
        int[] iArr = new int[8];
        this.fScope = iArr;
        iArr[0] = 0;
    }

    public MultipleScopeNamespaceSupport(NamespaceContext namespaceContext) {
        super(namespaceContext);
        int[] iArr = new int[8];
        this.fScope = iArr;
        iArr[0] = 0;
    }

    @Override // org.apache.xerces.util.NamespaceSupport, org.apache.xerces.xni.NamespaceContext
    public Enumeration getAllPrefixes() {
        boolean z;
        if (this.fPrefixes.length < this.fNamespace.length / 2) {
            this.fPrefixes = new String[this.fNamespaceSize];
        }
        int i2 = 0;
        for (int i3 = this.fContext[this.fScope[this.fCurrentScope]]; i3 <= this.fNamespaceSize - 2; i3 += 2) {
            String str = this.fNamespace[i3];
            int i4 = 0;
            while (true) {
                if (i4 >= i2) {
                    z = true;
                    break;
                } else if (this.fPrefixes[i4] == str) {
                    z = false;
                    break;
                } else {
                    i4++;
                }
            }
            if (z) {
                this.fPrefixes[i2] = str;
                i2++;
            }
        }
        return new NamespaceSupport.Prefixes(this.fPrefixes, i2);
    }

    @Override // org.apache.xerces.util.NamespaceSupport, org.apache.xerces.xni.NamespaceContext
    public String getPrefix(String str) {
        return getPrefix(str, this.fNamespaceSize, this.fContext[this.fScope[this.fCurrentScope]]);
    }

    public String getPrefix(String str, int i2) {
        int[] iArr = this.fContext;
        return getPrefix(str, iArr[i2 + 1], iArr[this.fScope[getScopeForContext(i2)]]);
    }

    public String getPrefix(String str, int i2, int i3) {
        if (str == NamespaceContext.XML_URI) {
            return XMLSymbols.PREFIX_XML;
        }
        if (str == NamespaceContext.XMLNS_URI) {
            return XMLSymbols.PREFIX_XMLNS;
        }
        while (i2 > i3) {
            String[] strArr = this.fNamespace;
            if (strArr[i2 - 1] == str) {
                int i4 = i2 - 2;
                if (getURI(strArr[i4]) == str) {
                    return this.fNamespace[i4];
                }
            }
            i2 -= 2;
        }
        return null;
    }

    public int getScopeForContext(int i2) {
        int i3 = this.fCurrentScope;
        while (i2 < this.fScope[i3]) {
            i3--;
        }
        return i3;
    }

    @Override // org.apache.xerces.util.NamespaceSupport, org.apache.xerces.xni.NamespaceContext
    public String getURI(String str) {
        return getURI(str, this.fNamespaceSize, this.fContext[this.fScope[this.fCurrentScope]]);
    }

    public String getURI(String str, int i2) {
        int[] iArr = this.fContext;
        return getURI(str, iArr[i2 + 1], iArr[this.fScope[getScopeForContext(i2)]]);
    }

    public String getURI(String str, int i2, int i3) {
        if (str == XMLSymbols.PREFIX_XML) {
            return NamespaceContext.XML_URI;
        }
        if (str == XMLSymbols.PREFIX_XMLNS) {
            return NamespaceContext.XMLNS_URI;
        }
        while (i2 > i3) {
            String[] strArr = this.fNamespace;
            if (strArr[i2 - 2] == str) {
                return strArr[i2 - 1];
            }
            i2 -= 2;
        }
        return null;
    }

    public void popScope() {
        int[] iArr = this.fScope;
        int i2 = this.fCurrentScope;
        this.fCurrentScope = i2 - 1;
        this.fCurrentContext = iArr[i2];
        popContext();
    }

    public void pushScope() {
        int i2 = this.fCurrentScope + 1;
        int[] iArr = this.fScope;
        if (i2 == iArr.length) {
            int[] iArr2 = new int[(iArr.length * 2)];
            System.arraycopy(iArr, 0, iArr2, 0, iArr.length);
            this.fScope = iArr2;
        }
        pushContext();
        int[] iArr3 = this.fScope;
        int i3 = this.fCurrentScope + 1;
        this.fCurrentScope = i3;
        iArr3[i3] = this.fCurrentContext;
    }

    @Override // org.apache.xerces.util.NamespaceSupport, org.apache.xerces.xni.NamespaceContext
    public void reset() {
        int i2 = this.fScope[this.fCurrentScope];
        this.fCurrentContext = i2;
        this.fNamespaceSize = this.fContext[i2];
    }
}
