package org.apache.xerces.xinclude;

import b.b.a.a.a;
import java.io.CharConversionException;
import java.io.IOException;
import java.io.UnsupportedEncodingException;
import java.util.ArrayList;
import java.util.Enumeration;
import java.util.Stack;
import java.util.StringTokenizer;
import javax.xml.transform.OutputKeys;
import org.apache.poi.ss.formula.ptg.StringPtg;
import org.apache.poi.ss.util.SheetUtil;
import org.apache.poi.util.LittleEndianCP950Reader;
import org.apache.xerces.impl.Constants;
import org.apache.xerces.impl.XMLEntityManager;
import org.apache.xerces.impl.XMLErrorReporter;
import org.apache.xerces.impl.io.MalformedByteSequenceException;
import org.apache.xerces.parsers.XPointerParserConfiguration;
import org.apache.xerces.util.AugmentationsImpl;
import org.apache.xerces.util.HTTPInputSource;
import org.apache.xerces.util.IntStack;
import org.apache.xerces.util.ParserConfigurationSettings;
import org.apache.xerces.util.SecurityManager;
import org.apache.xerces.util.SymbolTable;
import org.apache.xerces.util.URI;
import org.apache.xerces.util.XMLAttributesImpl;
import org.apache.xerces.util.XMLChar;
import org.apache.xerces.util.XMLLocatorWrapper;
import org.apache.xerces.util.XMLResourceIdentifierImpl;
import org.apache.xerces.util.XMLSymbols;
import org.apache.xerces.xni.Augmentations;
import org.apache.xerces.xni.NamespaceContext;
import org.apache.xerces.xni.QName;
import org.apache.xerces.xni.XMLAttributes;
import org.apache.xerces.xni.XMLDTDHandler;
import org.apache.xerces.xni.XMLDocumentHandler;
import org.apache.xerces.xni.XMLLocator;
import org.apache.xerces.xni.XMLResourceIdentifier;
import org.apache.xerces.xni.XMLString;
import org.apache.xerces.xni.XNIException;
import org.apache.xerces.xni.parser.XMLComponent;
import org.apache.xerces.xni.parser.XMLComponentManager;
import org.apache.xerces.xni.parser.XMLConfigurationException;
import org.apache.xerces.xni.parser.XMLDTDFilter;
import org.apache.xerces.xni.parser.XMLDTDSource;
import org.apache.xerces.xni.parser.XMLDocumentFilter;
import org.apache.xerces.xni.parser.XMLDocumentSource;
import org.apache.xerces.xni.parser.XMLEntityResolver;
import org.apache.xerces.xni.parser.XMLInputSource;
import org.apache.xerces.xni.parser.XMLParserConfiguration;
import org.apache.xerces.xpointer.XPointerHandler;
import org.apache.xerces.xpointer.XPointerProcessor;
import org.apache.xmlbeans.impl.schema.SoapEncSchemaTypeSystem;

public class XIncludeHandler implements XMLComponent, XMLDocumentFilter, XMLDTDFilter {
    public static final String ALLOW_UE_AND_NOTATION_EVENTS = "http://xml.org/sax/features/allow-dtd-events-after-endDTD";
    public static final String BUFFER_SIZE = "http://apache.org/xml/properties/input-buffer-size";
    public static final String CURRENT_BASE_URI = "currentBaseURI";
    public static final String DYNAMIC_VALIDATION = "http://apache.org/xml/features/validation/dynamic";
    public static final String ENTITY_RESOLVER = "http://apache.org/xml/properties/internal/entity-resolver";
    public static final String ERROR_REPORTER = "http://apache.org/xml/properties/internal/error-reporter";
    public static final Boolean[] FEATURE_DEFAULTS;
    public static final String HTTP_ACCEPT = "Accept";
    public static final String HTTP_ACCEPT_LANGUAGE = "Accept-Language";
    public static final int INITIAL_SIZE = 8;
    public static final String JAXP_SCHEMA_LANGUAGE = "http://java.sun.com/xml/jaxp/properties/schemaLanguage";
    public static final QName NEW_NS_ATTR_QNAME = new QName(XMLSymbols.PREFIX_XMLNS, "", a.a(new StringBuffer(), XMLSymbols.PREFIX_XMLNS, ":"), NamespaceContext.XMLNS_URI);
    public static final String PARSER_SETTINGS = "http://apache.org/xml/features/internal/parser-settings";
    public static final Object[] PROPERTY_DEFAULTS = {null, null, null, new Integer(2048)};
    public static final String[] RECOGNIZED_FEATURES = {"http://xml.org/sax/features/allow-dtd-events-after-endDTD", "http://apache.org/xml/features/xinclude/fixup-base-uris", "http://apache.org/xml/features/xinclude/fixup-language"};
    public static final String[] RECOGNIZED_PROPERTIES = {"http://apache.org/xml/properties/internal/error-reporter", "http://apache.org/xml/properties/internal/entity-resolver", "http://apache.org/xml/properties/security-manager", "http://apache.org/xml/properties/input-buffer-size"};
    public static final String SCHEMA_VALIDATION = "http://apache.org/xml/features/validation/schema";
    public static final String SECURITY_MANAGER = "http://apache.org/xml/properties/security-manager";
    public static final int STATE_EXPECT_FALLBACK = 3;
    public static final int STATE_IGNORE = 2;
    public static final int STATE_NORMAL_PROCESSING = 1;
    public static final String SYMBOL_TABLE = "http://apache.org/xml/properties/internal/symbol-table";
    public static final String VALIDATION = "http://xml.org/sax/features/validation";
    public static final String XINCLUDE_ATTR_ACCEPT = "accept".intern();
    public static final String XINCLUDE_ATTR_ACCEPT_LANGUAGE = "accept-language".intern();
    public static final String XINCLUDE_ATTR_ENCODING = OutputKeys.ENCODING.intern();
    public static final String XINCLUDE_ATTR_HREF = SoapEncSchemaTypeSystem.ATTR_HREF.intern();
    public static final String XINCLUDE_ATTR_PARSE = "parse".intern();
    public static final String XINCLUDE_BASE = "base".intern();
    public static final String XINCLUDE_DEFAULT_CONFIGURATION = "org.apache.xerces.parsers.XIncludeParserConfiguration";
    public static final String XINCLUDE_FALLBACK = "fallback".intern();
    public static final String XINCLUDE_FIXUP_BASE_URIS = "http://apache.org/xml/features/xinclude/fixup-base-uris";
    public static final String XINCLUDE_FIXUP_LANGUAGE = "http://apache.org/xml/features/xinclude/fixup-language";
    public static final String XINCLUDE_INCLUDE = "include".intern();
    public static final String XINCLUDE_INCLUDED = "[included]".intern();
    public static final String XINCLUDE_LANG = "lang".intern();
    public static final String XINCLUDE_NS_URI = "http://www.w3.org/2001/XInclude".intern();
    public static final String XINCLUDE_PARSE_TEXT = "text".intern();
    public static final String XINCLUDE_PARSE_XML = "xml".intern();
    public static final QName XML_BASE_QNAME;
    public static final QName XML_LANG_QNAME;
    public static final String XPOINTER = "xpointer";
    public static final char[] gAfterEscaping1 = new char[128];
    public static final char[] gAfterEscaping2 = new char[128];
    public static final char[] gHexChs = {SheetUtil.defaultChar, '1', '2', '3', '4', '5', '6', '7', '8', '9', 'A', 'B', 'C', 'D', 'E', 'F'};
    public static final boolean[] gNeedEscaping = new boolean[128];
    public final Stack fBaseURI;
    public final IntStack fBaseURIScope;
    public int fBufferSize = 2048;
    public XMLParserConfiguration fChildConfig;
    public final XMLResourceIdentifier fCurrentBaseURI;
    public String fCurrentLanguage;
    public XMLDTDHandler fDTDHandler;
    public XMLDTDSource fDTDSource;
    public int fDepth;
    public XMLLocator fDocLocation;
    public XMLDocumentHandler fDocumentHandler;
    public XMLDocumentSource fDocumentSource;
    public XMLEntityResolver fEntityResolver;
    public XMLErrorReporter fErrorReporter;
    public final Stack fExpandedSystemID;
    public boolean fFixupBaseURIs;
    public boolean fFixupLanguage;
    public boolean fHasIncludeReportedContent;
    public String fHrefFromParent;
    public boolean fInDTD;
    public boolean fIsXML11;
    public final IntStack fLanguageScope;
    public final Stack fLanguageStack;
    public final Stack fLiteralSystemID;
    public XIncludeNamespaceSupport fNamespaceContext;
    public boolean fNeedCopyFeatures;
    public final ArrayList fNotations;
    public String fParentRelativeURI;
    public XIncludeHandler fParentXIncludeHandler;
    public int fResultDepth;
    public boolean[] fSawFallback;
    public boolean[] fSawInclude;
    public SecurityManager fSecurityManager;
    public boolean fSeenRootElement;
    public boolean fSendUEAndNotationEvents;
    public ParserConfigurationSettings fSettings;
    public int[] fState;
    public SymbolTable fSymbolTable;
    public final ArrayList fUnparsedEntities;
    public XIncludeTextReader fXInclude10TextReader;
    public XIncludeTextReader fXInclude11TextReader;
    public XMLParserConfiguration fXIncludeChildConfig;
    public XMLLocatorWrapper fXIncludeLocator = new XMLLocatorWrapper();
    public XIncludeMessageFormatter fXIncludeMessageFormatter = new XIncludeMessageFormatter();
    public XMLParserConfiguration fXPointerChildConfig;
    public XPointerProcessor fXPtrProcessor = null;

    public static class Notation {
        public Augmentations augmentations;
        public String baseURI;
        public String expandedSystemId;
        public String name;
        public String publicId;
        public String systemId;

        private boolean isEqual(String str, String str2) {
            return str == str2 || (str != null && str.equals(str2));
        }

        public boolean equals(Object obj) {
            if (obj != null && (obj instanceof Notation)) {
                return this.name.equals(((Notation) obj).name);
            }
            return false;
        }

        public boolean isDuplicate(Object obj) {
            if (obj == null || !(obj instanceof Notation)) {
                return false;
            }
            Notation notation = (Notation) obj;
            return this.name.equals(notation.name) && isEqual(this.publicId, notation.publicId) && isEqual(this.expandedSystemId, notation.expandedSystemId);
        }
    }

    public static class UnparsedEntity {
        public Augmentations augmentations;
        public String baseURI;
        public String expandedSystemId;
        public String name;
        public String notation;
        public String publicId;
        public String systemId;

        private boolean isEqual(String str, String str2) {
            return str == str2 || (str != null && str.equals(str2));
        }

        public boolean equals(Object obj) {
            if (obj != null && (obj instanceof UnparsedEntity)) {
                return this.name.equals(((UnparsedEntity) obj).name);
            }
            return false;
        }

        public boolean isDuplicate(Object obj) {
            if (obj == null || !(obj instanceof UnparsedEntity)) {
                return false;
            }
            UnparsedEntity unparsedEntity = (UnparsedEntity) obj;
            return this.name.equals(unparsedEntity.name) && isEqual(this.publicId, unparsedEntity.publicId) && isEqual(this.expandedSystemId, unparsedEntity.expandedSystemId) && isEqual(this.notation, unparsedEntity.notation);
        }
    }

    static {
        String str = XMLSymbols.PREFIX_XML;
        String str2 = XINCLUDE_BASE;
        StringBuffer stringBuffer = new StringBuffer();
        stringBuffer.append(XMLSymbols.PREFIX_XML);
        stringBuffer.append(":");
        stringBuffer.append(XINCLUDE_BASE);
        XML_BASE_QNAME = new QName(str, str2, stringBuffer.toString().intern(), NamespaceContext.XML_URI);
        String str3 = XMLSymbols.PREFIX_XML;
        String str4 = XINCLUDE_LANG;
        StringBuffer stringBuffer2 = new StringBuffer();
        stringBuffer2.append(XMLSymbols.PREFIX_XML);
        stringBuffer2.append(":");
        stringBuffer2.append(XINCLUDE_LANG);
        XML_LANG_QNAME = new QName(str3, str4, stringBuffer2.toString().intern(), NamespaceContext.XML_URI);
        Boolean bool = Boolean.TRUE;
        FEATURE_DEFAULTS = new Boolean[]{bool, bool, bool};
        char[] cArr = {' ', '<', '>', StringPtg.FORMULA_DELIMITER, '{', '}', '|', '\\', '^', '`'};
        for (int i2 = 0; i2 < 10; i2++) {
            char c = cArr[i2];
            gNeedEscaping[c] = true;
            char[] cArr2 = gAfterEscaping1;
            char[] cArr3 = gHexChs;
            cArr2[c] = cArr3[c >> 4];
            gAfterEscaping2[c] = cArr3[c & 15];
        }
    }

    public XIncludeHandler() {
        boolean[] zArr = new boolean[8];
        this.fSawInclude = zArr;
        boolean[] zArr2 = new boolean[8];
        this.fSawFallback = zArr2;
        int[] iArr = new int[8];
        this.fState = iArr;
        this.fFixupBaseURIs = true;
        this.fFixupLanguage = true;
        this.fNeedCopyFeatures = true;
        this.fDepth = 0;
        zArr2[0] = false;
        zArr[0] = false;
        iArr[0] = 1;
        this.fNotations = new ArrayList();
        this.fUnparsedEntities = new ArrayList();
        this.fBaseURIScope = new IntStack();
        this.fBaseURI = new Stack();
        this.fLiteralSystemID = new Stack();
        this.fExpandedSystemID = new Stack();
        this.fCurrentBaseURI = new XMLResourceIdentifierImpl();
        this.fLanguageScope = new IntStack();
        this.fLanguageStack = new Stack();
        this.fCurrentLanguage = null;
    }

    private void checkMultipleRootElements() {
        if (getRootElementProcessed()) {
            reportFatalError("MultipleRootElements");
        }
        setRootElementProcessed(true);
    }

    private void checkWhitespace(XMLString xMLString) {
        int i2 = xMLString.offset;
        int i3 = xMLString.length + i2;
        while (i2 < i3) {
            if (!XMLChar.isSpace(xMLString.ch[i2])) {
                reportFatalError("ContentIllegalAtTopLevel");
                return;
            }
            i2++;
        }
    }

    private void copyFeatures1(Enumeration enumeration, String str, XMLComponentManager xMLComponentManager, ParserConfigurationSettings parserConfigurationSettings) {
        while (enumeration.hasMoreElements()) {
            StringBuffer a = a.a(str);
            a.append((String) enumeration.nextElement());
            String stringBuffer = a.toString();
            parserConfigurationSettings.addRecognizedFeatures(new String[]{stringBuffer});
            try {
                parserConfigurationSettings.setFeature(stringBuffer, xMLComponentManager.getFeature(stringBuffer));
            } catch (XMLConfigurationException unused) {
            }
        }
    }

    private void copyFeatures1(Enumeration enumeration, String str, XMLComponentManager xMLComponentManager, XMLParserConfiguration xMLParserConfiguration) {
        while (enumeration.hasMoreElements()) {
            StringBuffer a = a.a(str);
            a.append((String) enumeration.nextElement());
            String stringBuffer = a.toString();
            try {
                xMLParserConfiguration.setFeature(stringBuffer, xMLComponentManager.getFeature(stringBuffer));
            } catch (XMLConfigurationException unused) {
            }
        }
    }

    private XMLInputSource createInputSource(String str, String str2, String str3, String str4, String str5) {
        HTTPInputSource hTTPInputSource = new HTTPInputSource(str, str2, str3);
        if (str4 != null && str4.length() > 0) {
            hTTPInputSource.setHTTPRequestProperty(HTTP_ACCEPT, str4);
        }
        if (str5 != null && str5.length() > 0) {
            hTTPInputSource.setHTTPRequestProperty(HTTP_ACCEPT_LANGUAGE, str5);
        }
        return hTTPInputSource;
    }

    private String escapeHref(String str) {
        int supplemental;
        char c;
        char charAt;
        char c2;
        int length = str.length();
        StringBuffer stringBuffer = new StringBuffer(length * 3);
        int i2 = 0;
        while (i2 < length && (charAt = str.charAt(i2)) <= '~') {
            if (charAt < ' ') {
                return str;
            }
            if (gNeedEscaping[charAt]) {
                stringBuffer.append('%');
                stringBuffer.append(gAfterEscaping1[charAt]);
                c2 = gAfterEscaping2[charAt];
            } else {
                c2 = (char) charAt;
            }
            stringBuffer.append(c2);
            i2++;
        }
        if (i2 < length) {
            int i3 = i2;
            while (i3 < length) {
                char charAt2 = str.charAt(i3);
                if ((charAt2 < ' ' || charAt2 > '~') && ((charAt2 < 160 || charAt2 > 55295) && ((charAt2 < 63744 || charAt2 > 64975) && (charAt2 < 65008 || charAt2 > 65519)))) {
                    if (XMLChar.isHighSurrogate(charAt2) && (i3 = i3 + 1) < length) {
                        char charAt3 = str.charAt(i3);
                        if (XMLChar.isLowSurrogate(charAt3) && (supplemental = XMLChar.supplemental((char) charAt2, (char) charAt3)) < 983040 && (supplemental & 65535) <= 65533) {
                        }
                    }
                    return str;
                }
                i3++;
            }
            try {
                byte[] bytes = str.substring(i2).getBytes("UTF-8");
                int length2 = bytes.length;
                for (byte b2 : bytes) {
                    if (b2 < 0) {
                        int i4 = b2 + 256;
                        stringBuffer.append('%');
                        stringBuffer.append(gHexChs[i4 >> 4]);
                        c = gHexChs[i4 & 15];
                    } else if (gNeedEscaping[b2]) {
                        stringBuffer.append('%');
                        stringBuffer.append(gAfterEscaping1[b2]);
                        c = gAfterEscaping2[b2];
                    } else {
                        c = (char) b2;
                    }
                    stringBuffer.append(c);
                }
                length = length2;
            } catch (UnsupportedEncodingException unused) {
                return str;
            }
        }
        return stringBuffer.length() != length ? stringBuffer.toString() : str;
    }

    private String getIncludeParentBaseURI() {
        int includeParentDepth = getIncludeParentDepth();
        return (isRootDocument() || includeParentDepth != 0) ? getBaseURI(includeParentDepth) : this.fParentXIncludeHandler.getIncludeParentBaseURI();
    }

    private int getIncludeParentDepth() {
        for (int i2 = this.fDepth - 1; i2 >= 0; i2--) {
            if (!(getSawInclude(i2) || getSawFallback(i2))) {
                return i2;
            }
        }
        return 0;
    }

    private String getIncludeParentLanguage() {
        int includeParentDepth = getIncludeParentDepth();
        return (isRootDocument() || includeParentDepth != 0) ? getLanguage(includeParentDepth) : this.fParentXIncludeHandler.getIncludeParentLanguage();
    }

    private int getResultDepth() {
        return this.fResultDepth;
    }

    private boolean getRootElementProcessed() {
        return isRootDocument() ? this.fSeenRootElement : this.fParentXIncludeHandler.getRootElementProcessed();
    }

    private boolean isEqual(String str, String str2) {
        return str == str2 || (str != null && str.equals(str2));
    }

    private boolean isValidInHTTPHeader(String str) {
        for (int length = str.length() - 1; length >= 0; length--) {
            char charAt = str.charAt(length);
            if (charAt < ' ' || charAt > '~') {
                return false;
            }
        }
        return true;
    }

    private void reportError(String str, Object[] objArr, short s, Exception exc) {
        XMLErrorReporter xMLErrorReporter = this.fErrorReporter;
        if (xMLErrorReporter != null) {
            xMLErrorReporter.reportError(XIncludeMessageFormatter.XINCLUDE_DOMAIN, str, objArr, s, exc);
        }
    }

    private int scopeOfBaseURI(int i2) {
        for (int size = this.fBaseURIScope.size() - 1; size >= 0; size--) {
            if (this.fBaseURIScope.elementAt(size) <= i2) {
                return size;
            }
        }
        return -1;
    }

    private int scopeOfLanguage(int i2) {
        for (int size = this.fLanguageScope.size() - 1; size >= 0; size--) {
            if (this.fLanguageScope.elementAt(size) <= i2) {
                return size;
            }
        }
        return -1;
    }

    private void setErrorReporter(XMLErrorReporter xMLErrorReporter) {
        this.fErrorReporter = xMLErrorReporter;
        if (xMLErrorReporter != null) {
            xMLErrorReporter.putMessageFormatter(XIncludeMessageFormatter.XINCLUDE_DOMAIN, this.fXIncludeMessageFormatter);
            XMLLocator xMLLocator = this.fDocLocation;
            if (xMLLocator != null) {
                this.fErrorReporter.setDocumentLocator(xMLLocator);
            }
        }
    }

    private void setRootElementProcessed(boolean z) {
        if (isRootDocument()) {
            this.fSeenRootElement = z;
        } else {
            this.fParentXIncludeHandler.setRootElementProcessed(z);
        }
    }

    public void addNotation(String str, XMLResourceIdentifier xMLResourceIdentifier, Augmentations augmentations) {
        Notation notation = new Notation();
        notation.name = str;
        notation.systemId = xMLResourceIdentifier.getLiteralSystemId();
        notation.publicId = xMLResourceIdentifier.getPublicId();
        notation.baseURI = xMLResourceIdentifier.getBaseSystemId();
        notation.expandedSystemId = xMLResourceIdentifier.getExpandedSystemId();
        notation.augmentations = augmentations;
        this.fNotations.add(notation);
    }

    public void addUnparsedEntity(String str, XMLResourceIdentifier xMLResourceIdentifier, String str2, Augmentations augmentations) {
        UnparsedEntity unparsedEntity = new UnparsedEntity();
        unparsedEntity.name = str;
        unparsedEntity.systemId = xMLResourceIdentifier.getLiteralSystemId();
        unparsedEntity.publicId = xMLResourceIdentifier.getPublicId();
        unparsedEntity.baseURI = xMLResourceIdentifier.getBaseSystemId();
        unparsedEntity.expandedSystemId = xMLResourceIdentifier.getExpandedSystemId();
        unparsedEntity.notation = str2;
        unparsedEntity.augmentations = augmentations;
        this.fUnparsedEntities.add(unparsedEntity);
    }

    @Override // org.apache.xerces.xni.XMLDTDHandler
    public void attributeDecl(String str, String str2, String str3, String[] strArr, String str4, XMLString xMLString, XMLString xMLString2, Augmentations augmentations) {
        XMLDTDHandler xMLDTDHandler = this.fDTDHandler;
        if (xMLDTDHandler != null) {
            xMLDTDHandler.attributeDecl(str, str2, str3, strArr, str4, xMLString, xMLString2, augmentations);
        }
    }

    @Override // org.apache.xerces.xni.XMLDocumentHandler
    public void characters(XMLString xMLString, Augmentations augmentations) {
        if (getState() != 1) {
            return;
        }
        if (this.fResultDepth == 0) {
            checkWhitespace(xMLString);
        } else if (this.fDocumentHandler != null) {
            this.fDepth++;
            this.fDocumentHandler.characters(xMLString, modifyAugmentations(augmentations));
            this.fDepth--;
        }
    }

    public void checkAndSendNotation(Notation notation) {
        XMLDTDHandler xMLDTDHandler;
        if (isRootDocument()) {
            int indexOf = this.fNotations.indexOf(notation);
            if (indexOf == -1) {
                XMLResourceIdentifierImpl xMLResourceIdentifierImpl = new XMLResourceIdentifierImpl(notation.publicId, notation.systemId, notation.baseURI, notation.expandedSystemId);
                addNotation(notation.name, xMLResourceIdentifierImpl, notation.augmentations);
                if (this.fSendUEAndNotationEvents && (xMLDTDHandler = this.fDTDHandler) != null) {
                    xMLDTDHandler.notationDecl(notation.name, xMLResourceIdentifierImpl, notation.augmentations);
                }
            } else if (!notation.isDuplicate((Notation) this.fNotations.get(indexOf))) {
                reportFatalError("NonDuplicateNotation", new Object[]{notation.name});
            }
        } else {
            this.fParentXIncludeHandler.checkAndSendNotation(notation);
        }
    }

    public void checkAndSendUnparsedEntity(UnparsedEntity unparsedEntity) {
        XMLDTDHandler xMLDTDHandler;
        if (isRootDocument()) {
            int indexOf = this.fUnparsedEntities.indexOf(unparsedEntity);
            if (indexOf == -1) {
                XMLResourceIdentifierImpl xMLResourceIdentifierImpl = new XMLResourceIdentifierImpl(unparsedEntity.publicId, unparsedEntity.systemId, unparsedEntity.baseURI, unparsedEntity.expandedSystemId);
                addUnparsedEntity(unparsedEntity.name, xMLResourceIdentifierImpl, unparsedEntity.notation, unparsedEntity.augmentations);
                if (this.fSendUEAndNotationEvents && (xMLDTDHandler = this.fDTDHandler) != null) {
                    xMLDTDHandler.unparsedEntityDecl(unparsedEntity.name, xMLResourceIdentifierImpl, unparsedEntity.notation, unparsedEntity.augmentations);
                }
            } else if (!unparsedEntity.isDuplicate((UnparsedEntity) this.fUnparsedEntities.get(indexOf))) {
                reportFatalError("NonDuplicateUnparsedEntity", new Object[]{unparsedEntity.name});
            }
        } else {
            this.fParentXIncludeHandler.checkAndSendUnparsedEntity(unparsedEntity);
        }
    }

    public void checkNotation(String str) {
        Notation notation = new Notation();
        notation.name = str;
        int indexOf = this.fNotations.indexOf(notation);
        if (indexOf != -1) {
            checkAndSendNotation((Notation) this.fNotations.get(indexOf));
        }
    }

    public void checkUnparsedEntity(String str) {
        UnparsedEntity unparsedEntity = new UnparsedEntity();
        unparsedEntity.name = str;
        int indexOf = this.fUnparsedEntities.indexOf(unparsedEntity);
        if (indexOf != -1) {
            UnparsedEntity unparsedEntity2 = (UnparsedEntity) this.fUnparsedEntities.get(indexOf);
            checkNotation(unparsedEntity2.notation);
            checkAndSendUnparsedEntity(unparsedEntity2);
        }
    }

    @Override // org.apache.xerces.xni.XMLDocumentHandler, org.apache.xerces.xni.XMLDTDHandler
    public void comment(XMLString xMLString, Augmentations augmentations) {
        if (this.fInDTD) {
            XMLDTDHandler xMLDTDHandler = this.fDTDHandler;
            if (xMLDTDHandler != null) {
                xMLDTDHandler.comment(xMLString, augmentations);
            }
        } else if (this.fDocumentHandler != null && getState() == 1) {
            this.fDepth++;
            this.fDocumentHandler.comment(xMLString, modifyAugmentations(augmentations));
            this.fDepth--;
        }
    }

    public void copyFeatures(XMLComponentManager xMLComponentManager, ParserConfigurationSettings parserConfigurationSettings) {
        copyFeatures1(Constants.getXercesFeatures(), Constants.XERCES_FEATURE_PREFIX, xMLComponentManager, parserConfigurationSettings);
        copyFeatures1(Constants.getSAXFeatures(), "http://xml.org/sax/features/", xMLComponentManager, parserConfigurationSettings);
    }

    public void copyFeatures(XMLComponentManager xMLComponentManager, XMLParserConfiguration xMLParserConfiguration) {
        copyFeatures1(Constants.getXercesFeatures(), Constants.XERCES_FEATURE_PREFIX, xMLComponentManager, xMLParserConfiguration);
        copyFeatures1(Constants.getSAXFeatures(), "http://xml.org/sax/features/", xMLComponentManager, xMLParserConfiguration);
    }

    @Override // org.apache.xerces.xni.XMLDocumentHandler
    public void doctypeDecl(String str, String str2, String str3, Augmentations augmentations) {
        XMLDocumentHandler xMLDocumentHandler;
        if (isRootDocument() && (xMLDocumentHandler = this.fDocumentHandler) != null) {
            xMLDocumentHandler.doctypeDecl(str, str2, str3, augmentations);
        }
    }

    @Override // org.apache.xerces.xni.XMLDTDHandler
    public void elementDecl(String str, String str2, Augmentations augmentations) {
        XMLDTDHandler xMLDTDHandler = this.fDTDHandler;
        if (xMLDTDHandler != null) {
            xMLDTDHandler.elementDecl(str, str2, augmentations);
        }
    }

    /* JADX WARNING: Code restructure failed: missing block: B:32:0x0088, code lost:
        if (r5.fDocumentHandler != null) goto L_0x009c;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:39:0x009a, code lost:
        if (r5.fDocumentHandler != null) goto L_0x009c;
     */
    @Override // org.apache.xerces.xni.XMLDocumentHandler
    public void emptyElement(QName qName, XMLAttributes xMLAttributes, Augmentations augmentations) {
        int i2 = this.fDepth + 1;
        this.fDepth = i2;
        int state = getState(i2 - 1);
        if (state == 3 && getState(this.fDepth - 2) == 3) {
            setState(2);
        } else {
            setState(state);
        }
        processXMLBaseAttributes(xMLAttributes);
        if (this.fFixupLanguage) {
            processXMLLangAttributes(xMLAttributes);
        }
        if (isIncludeElement(qName)) {
            if (handleIncludeElement(xMLAttributes)) {
                setState(2);
            } else {
                reportFatalError("NoFallback");
            }
        } else if (isFallbackElement(qName)) {
            handleFallbackElement();
        } else {
            if (hasXIncludeNamespace(qName)) {
                if (getSawInclude(this.fDepth - 1)) {
                    reportFatalError("IncludeChild", new Object[]{qName.rawname});
                }
                if (getSawFallback(this.fDepth - 1)) {
                    reportFatalError("FallbackChild", new Object[]{qName.rawname});
                }
                if (getState() == 1) {
                    if (this.fResultDepth == 0) {
                        checkMultipleRootElements();
                    }
                }
            } else if (getState() == 1) {
                if (this.fResultDepth == 0) {
                    checkMultipleRootElements();
                }
            }
            this.fDocumentHandler.emptyElement(qName, processAttributes(xMLAttributes), modifyAugmentations(augmentations));
        }
        setSawFallback(this.fDepth + 1, false);
        setSawInclude(this.fDepth, false);
        if (this.fBaseURIScope.size() > 0 && this.fDepth == this.fBaseURIScope.peek()) {
            restoreBaseURI();
        }
        this.fDepth--;
    }

    @Override // org.apache.xerces.xni.XMLDTDHandler
    public void endAttlist(Augmentations augmentations) {
        XMLDTDHandler xMLDTDHandler = this.fDTDHandler;
        if (xMLDTDHandler != null) {
            xMLDTDHandler.endAttlist(augmentations);
        }
    }

    @Override // org.apache.xerces.xni.XMLDocumentHandler
    public void endCDATA(Augmentations augmentations) {
        if (this.fDocumentHandler != null && getState() == 1 && this.fResultDepth != 0) {
            this.fDocumentHandler.endCDATA(augmentations);
        }
    }

    @Override // org.apache.xerces.xni.XMLDTDHandler
    public void endConditional(Augmentations augmentations) {
        XMLDTDHandler xMLDTDHandler = this.fDTDHandler;
        if (xMLDTDHandler != null) {
            xMLDTDHandler.endConditional(augmentations);
        }
    }

    @Override // org.apache.xerces.xni.XMLDTDHandler
    public void endDTD(Augmentations augmentations) {
        XMLDTDHandler xMLDTDHandler = this.fDTDHandler;
        if (xMLDTDHandler != null) {
            xMLDTDHandler.endDTD(augmentations);
        }
        this.fInDTD = false;
    }

    @Override // org.apache.xerces.xni.XMLDocumentHandler
    public void endDocument(Augmentations augmentations) {
        if (isRootDocument()) {
            if (!this.fSeenRootElement) {
                reportFatalError("RootElementRequired");
            }
            XMLDocumentHandler xMLDocumentHandler = this.fDocumentHandler;
            if (xMLDocumentHandler != null) {
                xMLDocumentHandler.endDocument(augmentations);
            }
        }
    }

    @Override // org.apache.xerces.xni.XMLDocumentHandler
    public void endElement(QName qName, Augmentations augmentations) {
        if (isIncludeElement(qName) && getState() == 3 && !getSawFallback(this.fDepth + 1)) {
            reportFatalError("NoFallback");
        }
        if (isFallbackElement(qName)) {
            if (getState() == 1) {
                setState(2);
            }
        } else if (getState() == 1) {
            this.fResultDepth--;
            XMLDocumentHandler xMLDocumentHandler = this.fDocumentHandler;
            if (xMLDocumentHandler != null) {
                xMLDocumentHandler.endElement(qName, augmentations);
            }
        }
        setSawFallback(this.fDepth + 1, false);
        setSawInclude(this.fDepth, false);
        if (this.fBaseURIScope.size() > 0 && this.fDepth == this.fBaseURIScope.peek()) {
            restoreBaseURI();
        }
        if (this.fLanguageScope.size() > 0 && this.fDepth == this.fLanguageScope.peek()) {
            this.fCurrentLanguage = restoreLanguage();
        }
        this.fDepth--;
    }

    @Override // org.apache.xerces.xni.XMLDTDHandler
    public void endExternalSubset(Augmentations augmentations) {
        XMLDTDHandler xMLDTDHandler = this.fDTDHandler;
        if (xMLDTDHandler != null) {
            xMLDTDHandler.endExternalSubset(augmentations);
        }
    }

    @Override // org.apache.xerces.xni.XMLDocumentHandler
    public void endGeneralEntity(String str, Augmentations augmentations) {
        if (this.fDocumentHandler != null && getState() == 1 && this.fResultDepth != 0) {
            this.fDocumentHandler.endGeneralEntity(str, augmentations);
        }
    }

    @Override // org.apache.xerces.xni.XMLDTDHandler
    public void endParameterEntity(String str, Augmentations augmentations) {
        XMLDTDHandler xMLDTDHandler = this.fDTDHandler;
        if (xMLDTDHandler != null) {
            xMLDTDHandler.endParameterEntity(str, augmentations);
        }
    }

    @Override // org.apache.xerces.xni.XMLDTDHandler
    public void externalEntityDecl(String str, XMLResourceIdentifier xMLResourceIdentifier, Augmentations augmentations) {
        XMLDTDHandler xMLDTDHandler = this.fDTDHandler;
        if (xMLDTDHandler != null) {
            xMLDTDHandler.externalEntityDecl(str, xMLResourceIdentifier, augmentations);
        }
    }

    public String getBaseURI(int i2) {
        return (String) this.fExpandedSystemID.elementAt(scopeOfBaseURI(i2));
    }

    @Override // org.apache.xerces.xni.parser.XMLDTDSource
    public XMLDTDHandler getDTDHandler() {
        return this.fDTDHandler;
    }

    @Override // org.apache.xerces.xni.XMLDTDHandler
    public XMLDTDSource getDTDSource() {
        return this.fDTDSource;
    }

    @Override // org.apache.xerces.xni.parser.XMLDocumentSource
    public XMLDocumentHandler getDocumentHandler() {
        return this.fDocumentHandler;
    }

    @Override // org.apache.xerces.xni.XMLDocumentHandler
    public XMLDocumentSource getDocumentSource() {
        return this.fDocumentSource;
    }

    @Override // org.apache.xerces.xni.parser.XMLComponent
    public Boolean getFeatureDefault(String str) {
        int i2 = 0;
        while (true) {
            String[] strArr = RECOGNIZED_FEATURES;
            if (i2 >= strArr.length) {
                return null;
            }
            if (strArr[i2].equals(str)) {
                return FEATURE_DEFAULTS[i2];
            }
            i2++;
        }
    }

    public String getLanguage(int i2) {
        return (String) this.fLanguageStack.elementAt(scopeOfLanguage(i2));
    }

    @Override // org.apache.xerces.xni.parser.XMLComponent
    public Object getPropertyDefault(String str) {
        int i2 = 0;
        while (true) {
            String[] strArr = RECOGNIZED_PROPERTIES;
            if (i2 >= strArr.length) {
                return null;
            }
            if (strArr[i2].equals(str)) {
                return PROPERTY_DEFAULTS[i2];
            }
            i2++;
        }
    }

    @Override // org.apache.xerces.xni.parser.XMLComponent
    public String[] getRecognizedFeatures() {
        return (String[]) RECOGNIZED_FEATURES.clone();
    }

    @Override // org.apache.xerces.xni.parser.XMLComponent
    public String[] getRecognizedProperties() {
        return (String[]) RECOGNIZED_PROPERTIES.clone();
    }

    public String getRelativeBaseURI() {
        int includeParentDepth = getIncludeParentDepth();
        String relativeURI = getRelativeURI(includeParentDepth);
        if (isRootDocument()) {
            return relativeURI;
        }
        if (relativeURI.length() == 0) {
            relativeURI = this.fCurrentBaseURI.getLiteralSystemId();
        }
        if (includeParentDepth != 0) {
            return relativeURI;
        }
        if (this.fParentRelativeURI == null) {
            this.fParentRelativeURI = this.fParentXIncludeHandler.getRelativeBaseURI();
        }
        if (this.fParentRelativeURI.length() == 0) {
            return relativeURI;
        }
        URI uri = new URI(this.fParentRelativeURI, true);
        URI uri2 = new URI(uri, relativeURI);
        if (!isEqual(uri.getScheme(), uri2.getScheme())) {
            return relativeURI;
        }
        if (!isEqual(uri.getAuthority(), uri2.getAuthority())) {
            return uri2.getSchemeSpecificPart();
        }
        String path = uri2.getPath();
        String queryString = uri2.getQueryString();
        String fragment = uri2.getFragment();
        if (queryString == null && fragment == null) {
            return path;
        }
        StringBuffer stringBuffer = new StringBuffer();
        if (path != null) {
            stringBuffer.append(path);
        }
        if (queryString != null) {
            stringBuffer.append(LittleEndianCP950Reader.UNMAPPABLE);
            stringBuffer.append(queryString);
        }
        if (fragment != null) {
            stringBuffer.append('#');
            stringBuffer.append(fragment);
        }
        return stringBuffer.toString();
    }

    public String getRelativeURI(int i2) {
        int scopeOfBaseURI = scopeOfBaseURI(i2) + 1;
        if (scopeOfBaseURI == this.fBaseURIScope.size()) {
            return "";
        }
        URI uri = new URI("file", (String) this.fLiteralSystemID.elementAt(scopeOfBaseURI));
        int i3 = scopeOfBaseURI + 1;
        while (i3 < this.fBaseURIScope.size()) {
            i3++;
            uri = new URI(uri, (String) this.fLiteralSystemID.elementAt(i3));
        }
        return uri.getPath();
    }

    public boolean getSawFallback(int i2) {
        boolean[] zArr = this.fSawFallback;
        if (i2 >= zArr.length) {
            return false;
        }
        return zArr[i2];
    }

    public boolean getSawInclude(int i2) {
        boolean[] zArr = this.fSawInclude;
        if (i2 >= zArr.length) {
            return false;
        }
        return zArr[i2];
    }

    public int getState() {
        return this.fState[this.fDepth];
    }

    public int getState(int i2) {
        return this.fState[i2];
    }

    public void handleFallbackElement() {
        if (!getSawInclude(this.fDepth - 1)) {
            if (getState() != 2) {
                reportFatalError("FallbackParent");
            } else {
                return;
            }
        }
        setSawInclude(this.fDepth, false);
        this.fNamespaceContext.setContextInvalid();
        if (getSawFallback(this.fDepth)) {
            reportFatalError("MultipleFallbacks");
        } else {
            setSawFallback(this.fDepth, true);
        }
        if (getState() == 3) {
            setState(1);
        }
    }

    /* JADX WARNING: Removed duplicated region for block: B:198:0x03c3 A[Catch:{ all -> 0x03bb }] */
    /* JADX WARNING: Removed duplicated region for block: B:205:0x03e6  */
    /* JADX WARNING: Removed duplicated region for block: B:211:0x0401 A[SYNTHETIC, Splitter:B:211:0x0401] */
    /* JADX WARNING: Removed duplicated region for block: B:220:0x042f A[SYNTHETIC, Splitter:B:220:0x042f] */
    /* JADX WARNING: Removed duplicated region for block: B:226:0x0445 A[SYNTHETIC, Splitter:B:226:0x0445] */
    public boolean handleIncludeElement(XMLAttributes xMLAttributes) {
        String str;
        String str2;
        String str3;
        String str4;
        XMLInputSource xMLInputSource;
        Throwable th;
        MalformedByteSequenceException malformedByteSequenceException;
        CharConversionException charConversionException;
        IOException e2;
        XIncludeTextReader xIncludeTextReader;
        IOException e3;
        if (getSawInclude(this.fDepth - 1)) {
            reportFatalError("IncludeChild", new Object[]{XINCLUDE_INCLUDE});
        }
        if (getState() == 2) {
            return true;
        }
        setSawInclude(this.fDepth, true);
        this.fNamespaceContext.setContextInvalid();
        String value = xMLAttributes.getValue(XINCLUDE_ATTR_HREF);
        String value2 = xMLAttributes.getValue(XINCLUDE_ATTR_PARSE);
        String value3 = xMLAttributes.getValue(XPOINTER);
        String value4 = xMLAttributes.getValue(XINCLUDE_ATTR_ACCEPT);
        String value5 = xMLAttributes.getValue(XINCLUDE_ATTR_ACCEPT_LANGUAGE);
        if (value2 == null) {
            value2 = XINCLUDE_PARSE_XML;
        }
        if (value == null) {
            value = XMLSymbols.EMPTY_STRING;
        }
        if (value.length() == 0 && XINCLUDE_PARSE_XML.equals(value2)) {
            if (value3 == null) {
                reportFatalError("XpointerMissing");
            } else {
                XMLErrorReporter xMLErrorReporter = this.fErrorReporter;
                reportResourceError("XMLResourceError", new Object[]{value, this.fXIncludeMessageFormatter.formatMessage(xMLErrorReporter != null ? xMLErrorReporter.getLocale() : null, "XPointerStreamability", null)});
                return false;
            }
        }
        try {
            if (new URI(value, true).getFragment() != null) {
                reportFatalError("HrefFragmentIdentifierIllegal", new Object[]{value});
            }
        } catch (URI.MalformedURIException unused) {
            String escapeHref = escapeHref(value);
            if (value != escapeHref) {
                try {
                    if (new URI(escapeHref, true).getFragment() != null) {
                        reportFatalError("HrefFragmentIdentifierIllegal", new Object[]{escapeHref});
                    }
                } catch (URI.MalformedURIException unused2) {
                    reportFatalError("HrefSyntacticallyInvalid", new Object[]{escapeHref});
                }
                str = escapeHref;
            } else {
                reportFatalError("HrefSyntacticallyInvalid", new Object[]{value});
            }
        }
        str = value;
        if (value4 == null || isValidInHTTPHeader(value4)) {
            str2 = value4;
        } else {
            reportFatalError("AcceptMalformed", null);
            str2 = null;
        }
        if (value5 == null || isValidInHTTPHeader(value5)) {
            str3 = value5;
        } else {
            reportFatalError("AcceptLanguageMalformed", null);
            str3 = null;
        }
        if (this.fEntityResolver != null) {
            try {
                xMLInputSource = this.fEntityResolver.resolveEntity(new XMLResourceIdentifierImpl(null, str, this.fCurrentBaseURI.getExpandedSystemId(), XMLEntityManager.expandSystemId(str, this.fCurrentBaseURI.getExpandedSystemId(), false)));
                if (xMLInputSource == null || (xMLInputSource instanceof HTTPInputSource) || !((str2 != null || str3 != null) && xMLInputSource.getCharacterStream() == null && xMLInputSource.getByteStream() == null)) {
                    str4 = str;
                } else {
                    str4 = str;
                    try {
                        xMLInputSource = createInputSource(xMLInputSource.getPublicId(), xMLInputSource.getSystemId(), xMLInputSource.getBaseSystemId(), str2, str3);
                    } catch (IOException e4) {
                        e3 = e4;
                    }
                }
            } catch (IOException e5) {
                e3 = e5;
                str4 = str;
                reportResourceError("XMLResourceError", new Object[]{str4, e3.getMessage()}, e3);
                return false;
            }
        } else {
            str4 = str;
            xMLInputSource = null;
        }
        if (xMLInputSource == null) {
            xMLInputSource = (str2 == null && str3 == null) ? new XMLInputSource(null, str4, this.fCurrentBaseURI.getExpandedSystemId()) : createInputSource(null, str4, this.fCurrentBaseURI.getExpandedSystemId(), str2, str3);
        }
        if (value2.equals(XINCLUDE_PARSE_XML)) {
            if ((value3 != null && this.fXPointerChildConfig == null) || (value3 == null && this.fXIncludeChildConfig == null)) {
                XMLParserConfiguration xMLParserConfiguration = (XMLParserConfiguration) ObjectFactory.newInstance(value3 != null ? "org.apache.xerces.parsers.XPointerParserConfiguration" : XINCLUDE_DEFAULT_CONFIGURATION, ObjectFactory.findClassLoader(), true);
                this.fChildConfig = xMLParserConfiguration;
                SymbolTable symbolTable = this.fSymbolTable;
                if (symbolTable != null) {
                    xMLParserConfiguration.setProperty("http://apache.org/xml/properties/internal/symbol-table", symbolTable);
                }
                XMLErrorReporter xMLErrorReporter2 = this.fErrorReporter;
                if (xMLErrorReporter2 != null) {
                    this.fChildConfig.setProperty("http://apache.org/xml/properties/internal/error-reporter", xMLErrorReporter2);
                }
                XMLEntityResolver xMLEntityResolver = this.fEntityResolver;
                if (xMLEntityResolver != null) {
                    this.fChildConfig.setProperty("http://apache.org/xml/properties/internal/entity-resolver", xMLEntityResolver);
                }
                this.fChildConfig.setProperty("http://apache.org/xml/properties/security-manager", this.fSecurityManager);
                this.fChildConfig.setProperty("http://apache.org/xml/properties/input-buffer-size", new Integer(this.fBufferSize));
                this.fNeedCopyFeatures = true;
                this.fChildConfig.setProperty("http://apache.org/xml/properties/internal/namespace-context", this.fNamespaceContext);
                this.fChildConfig.setFeature("http://apache.org/xml/features/xinclude/fixup-base-uris", this.fFixupBaseURIs);
                this.fChildConfig.setFeature("http://apache.org/xml/features/xinclude/fixup-language", this.fFixupLanguage);
                XMLParserConfiguration xMLParserConfiguration2 = this.fChildConfig;
                if (value3 != null) {
                    XPointerHandler xPointerHandler = (XPointerHandler) xMLParserConfiguration2.getProperty(XPointerParserConfiguration.XPOINTER_HANDLER);
                    this.fXPtrProcessor = xPointerHandler;
                    xPointerHandler.setProperty("http://apache.org/xml/properties/internal/namespace-context", this.fNamespaceContext);
                    ((XPointerHandler) this.fXPtrProcessor).setProperty("http://apache.org/xml/features/xinclude/fixup-base-uris", this.fFixupBaseURIs ? Boolean.TRUE : Boolean.FALSE);
                    ((XPointerHandler) this.fXPtrProcessor).setProperty("http://apache.org/xml/features/xinclude/fixup-language", this.fFixupLanguage ? Boolean.TRUE : Boolean.FALSE);
                    XMLErrorReporter xMLErrorReporter3 = this.fErrorReporter;
                    if (xMLErrorReporter3 != null) {
                        ((XPointerHandler) this.fXPtrProcessor).setProperty("http://apache.org/xml/properties/internal/error-reporter", xMLErrorReporter3);
                    }
                    xPointerHandler.setParent(this);
                    xPointerHandler.setHref(str4);
                    xPointerHandler.setXIncludeLocator(this.fXIncludeLocator);
                    xPointerHandler.setDocumentHandler(getDocumentHandler());
                    this.fXPointerChildConfig = this.fChildConfig;
                } else {
                    XIncludeHandler xIncludeHandler = (XIncludeHandler) xMLParserConfiguration2.getProperty("http://apache.org/xml/properties/internal/xinclude-handler");
                    xIncludeHandler.setParent(this);
                    xIncludeHandler.setHref(str4);
                    xIncludeHandler.setXIncludeLocator(this.fXIncludeLocator);
                    xIncludeHandler.setDocumentHandler(getDocumentHandler());
                    this.fXIncludeChildConfig = this.fChildConfig;
                }
            }
            if (value3 != null) {
                this.fChildConfig = this.fXPointerChildConfig;
                try {
                    this.fXPtrProcessor.parseXPointer(value3);
                } catch (XNIException e6) {
                    reportResourceError("XMLResourceError", new Object[]{str4, e6.getMessage()});
                    return false;
                }
            } else {
                this.fChildConfig = this.fXIncludeChildConfig;
            }
            if (this.fNeedCopyFeatures) {
                copyFeatures(this.fSettings, this.fChildConfig);
            }
            this.fNeedCopyFeatures = false;
            try {
                this.fHasIncludeReportedContent = false;
                this.fNamespaceContext.pushScope();
                this.fChildConfig.parse(xMLInputSource);
                this.fXIncludeLocator.setLocator(this.fDocLocation);
                if (this.fErrorReporter != null) {
                    this.fErrorReporter.setDocumentLocator(this.fDocLocation);
                }
                if (value3 != null && !this.fXPtrProcessor.isXPointerResolved()) {
                    reportResourceError("XMLResourceError", new Object[]{str4, this.fXIncludeMessageFormatter.formatMessage(this.fErrorReporter != null ? this.fErrorReporter.getLocale() : null, "XPointerResolutionUnsuccessful", null)});
                    this.fNamespaceContext.popScope();
                    return false;
                }
            } catch (XNIException unused3) {
                this.fXIncludeLocator.setLocator(this.fDocLocation);
                if (this.fErrorReporter != null) {
                    this.fErrorReporter.setDocumentLocator(this.fDocLocation);
                }
                reportFatalError("XMLParseError", new Object[]{str4});
            } catch (IOException e7) {
                this.fXIncludeLocator.setLocator(this.fDocLocation);
                if (this.fErrorReporter != null) {
                    this.fErrorReporter.setDocumentLocator(this.fDocLocation);
                }
                if (!this.fHasIncludeReportedContent) {
                    reportResourceError("XMLResourceError", new Object[]{str4, e7.getMessage()}, e7);
                    this.fNamespaceContext.popScope();
                    return false;
                }
                throw new XNIException(e7);
            } catch (Throwable th2) {
                this.fNamespaceContext.popScope();
                throw th2;
            }
            this.fNamespaceContext.popScope();
        } else {
            XIncludeTextReader xIncludeTextReader2 = null;
            if (value2.equals(XINCLUDE_PARSE_TEXT)) {
                xMLInputSource.setEncoding(xMLAttributes.getValue(XINCLUDE_ATTR_ENCODING));
                try {
                    this.fHasIncludeReportedContent = false;
                    if (!this.fIsXML11) {
                        if (this.fXInclude10TextReader == null) {
                            this.fXInclude10TextReader = new XIncludeTextReader(xMLInputSource, this, this.fBufferSize);
                        } else {
                            this.fXInclude10TextReader.setInputSource(xMLInputSource);
                        }
                        xIncludeTextReader = this.fXInclude10TextReader;
                    } else {
                        if (this.fXInclude11TextReader == null) {
                            this.fXInclude11TextReader = new XInclude11TextReader(xMLInputSource, this, this.fBufferSize);
                        } else {
                            this.fXInclude11TextReader.setInputSource(xMLInputSource);
                        }
                        xIncludeTextReader = this.fXInclude11TextReader;
                    }
                    try {
                        xIncludeTextReader.setErrorReporter(this.fErrorReporter);
                        xIncludeTextReader.parse();
                        try {
                            xIncludeTextReader.close();
                        } catch (IOException e8) {
                            reportResourceError("TextResourceError", new Object[]{str4, e8.getMessage()}, e8);
                            return false;
                        }
                    } catch (MalformedByteSequenceException e9) {
                        malformedByteSequenceException = e9;
                        xIncludeTextReader2 = xIncludeTextReader;
                        this.fErrorReporter.reportError(malformedByteSequenceException.getDomain(), malformedByteSequenceException.getKey(), malformedByteSequenceException.getArguments(), (short) 2, (Exception) malformedByteSequenceException);
                        if (xIncludeTextReader2 != null) {
                        }
                        return true;
                    } catch (CharConversionException e10) {
                        charConversionException = e10;
                        xIncludeTextReader2 = xIncludeTextReader;
                        this.fErrorReporter.reportError("http://www.w3.org/TR/1998/REC-xml-19980210", "CharConversionFailure", (Object[]) null, (short) 2, (Exception) charConversionException);
                        if (xIncludeTextReader2 != null) {
                        }
                        return true;
                    } catch (IOException e11) {
                        e2 = e11;
                        xIncludeTextReader2 = xIncludeTextReader;
                        try {
                            if (this.fHasIncludeReportedContent) {
                            }
                        } catch (Throwable th3) {
                            th = th3;
                            if (xIncludeTextReader2 != null) {
                            }
                            throw th;
                        }
                    } catch (Throwable th4) {
                        th = th4;
                        xIncludeTextReader2 = xIncludeTextReader;
                        if (xIncludeTextReader2 != null) {
                            try {
                                xIncludeTextReader2.close();
                            } catch (IOException e12) {
                                reportResourceError("TextResourceError", new Object[]{str4, e12.getMessage()}, e12);
                                return false;
                            }
                        }
                        throw th;
                    }
                } catch (MalformedByteSequenceException e13) {
                    malformedByteSequenceException = e13;
                    this.fErrorReporter.reportError(malformedByteSequenceException.getDomain(), malformedByteSequenceException.getKey(), malformedByteSequenceException.getArguments(), (short) 2, (Exception) malformedByteSequenceException);
                    if (xIncludeTextReader2 != null) {
                        try {
                            xIncludeTextReader2.close();
                        } catch (IOException e14) {
                            reportResourceError("TextResourceError", new Object[]{str4, e14.getMessage()}, e14);
                            return false;
                        }
                    }
                    return true;
                } catch (CharConversionException e15) {
                    charConversionException = e15;
                    this.fErrorReporter.reportError("http://www.w3.org/TR/1998/REC-xml-19980210", "CharConversionFailure", (Object[]) null, (short) 2, (Exception) charConversionException);
                    if (xIncludeTextReader2 != null) {
                        try {
                            xIncludeTextReader2.close();
                        } catch (IOException e16) {
                            reportResourceError("TextResourceError", new Object[]{str4, e16.getMessage()}, e16);
                            return false;
                        }
                    }
                    return true;
                } catch (IOException e17) {
                    e2 = e17;
                    if (this.fHasIncludeReportedContent) {
                        reportResourceError("TextResourceError", new Object[]{str4, e2.getMessage()}, e2);
                        if (xIncludeTextReader2 != null) {
                            try {
                                xIncludeTextReader2.close();
                            } catch (IOException e18) {
                                reportResourceError("TextResourceError", new Object[]{str4, e18.getMessage()}, e18);
                            }
                        }
                        return false;
                    }
                    throw new XNIException(e2);
                }
            } else {
                reportFatalError("InvalidParseValue", new Object[]{value2});
            }
        }
        return true;
    }

    public boolean hasXIncludeNamespace(QName qName) {
        return qName.uri == XINCLUDE_NS_URI || this.fNamespaceContext.getURI(qName.prefix) == XINCLUDE_NS_URI;
    }

    @Override // org.apache.xerces.xni.XMLDocumentHandler
    public void ignorableWhitespace(XMLString xMLString, Augmentations augmentations) {
        if (this.fDocumentHandler != null && getState() == 1 && this.fResultDepth != 0) {
            this.fDocumentHandler.ignorableWhitespace(xMLString, augmentations);
        }
    }

    @Override // org.apache.xerces.xni.XMLDTDHandler
    public void ignoredCharacters(XMLString xMLString, Augmentations augmentations) {
        XMLDTDHandler xMLDTDHandler = this.fDTDHandler;
        if (xMLDTDHandler != null) {
            xMLDTDHandler.ignoredCharacters(xMLString, augmentations);
        }
    }

    @Override // org.apache.xerces.xni.XMLDTDHandler
    public void internalEntityDecl(String str, XMLString xMLString, XMLString xMLString2, Augmentations augmentations) {
        XMLDTDHandler xMLDTDHandler = this.fDTDHandler;
        if (xMLDTDHandler != null) {
            xMLDTDHandler.internalEntityDecl(str, xMLString, xMLString2, augmentations);
        }
    }

    public boolean isFallbackElement(QName qName) {
        return qName.localpart.equals(XINCLUDE_FALLBACK) && hasXIncludeNamespace(qName);
    }

    public boolean isIncludeElement(QName qName) {
        return qName.localpart.equals(XINCLUDE_INCLUDE) && hasXIncludeNamespace(qName);
    }

    public boolean isRootDocument() {
        return this.fParentXIncludeHandler == null;
    }

    public boolean isTopLevelIncludedItem() {
        return isTopLevelIncludedItemViaInclude() || isTopLevelIncludedItemViaFallback();
    }

    public boolean isTopLevelIncludedItemViaFallback() {
        return getSawFallback(this.fDepth - 1);
    }

    public boolean isTopLevelIncludedItemViaInclude() {
        return this.fDepth == 1 && !isRootDocument();
    }

    public Augmentations modifyAugmentations(Augmentations augmentations) {
        return modifyAugmentations(augmentations, false);
    }

    public Augmentations modifyAugmentations(Augmentations augmentations, boolean z) {
        if (z || isTopLevelIncludedItem()) {
            if (augmentations == null) {
                augmentations = new AugmentationsImpl();
            }
            augmentations.putItem(XINCLUDE_INCLUDED, Boolean.TRUE);
        }
        return augmentations;
    }

    @Override // org.apache.xerces.xni.XMLDTDHandler
    public void notationDecl(String str, XMLResourceIdentifier xMLResourceIdentifier, Augmentations augmentations) {
        addNotation(str, xMLResourceIdentifier, augmentations);
        XMLDTDHandler xMLDTDHandler = this.fDTDHandler;
        if (xMLDTDHandler != null) {
            xMLDTDHandler.notationDecl(str, xMLResourceIdentifier, augmentations);
        }
    }

    /* JADX WARNING: Code restructure failed: missing block: B:32:0x0093, code lost:
        if (r4 != null) goto L_0x00c8;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:40:0x00c6, code lost:
        if (r4 != null) goto L_0x00c8;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:42:0x00ca, code lost:
        r6 = org.apache.xerces.util.XMLSymbols.EMPTY_STRING;
     */
    public XMLAttributes processAttributes(XMLAttributes xMLAttributes) {
        String str;
        QName qName;
        String str2;
        if (isTopLevelIncludedItem()) {
            if (this.fFixupBaseURIs && !sameBaseURIAsIncludeParent()) {
                if (xMLAttributes == null) {
                    xMLAttributes = new XMLAttributesImpl();
                }
                try {
                    str2 = getRelativeBaseURI();
                } catch (URI.MalformedURIException unused) {
                    str2 = this.fCurrentBaseURI.getExpandedSystemId();
                }
                xMLAttributes.setSpecified(xMLAttributes.addAttribute(XML_BASE_QNAME, XMLSymbols.fCDATASymbol, str2), true);
            }
            if (this.fFixupLanguage && !sameLanguageAsIncludeParent()) {
                if (xMLAttributes == null) {
                    xMLAttributes = new XMLAttributesImpl();
                }
                xMLAttributes.setSpecified(xMLAttributes.addAttribute(XML_LANG_QNAME, XMLSymbols.fCDATASymbol, this.fCurrentLanguage), true);
            }
            Enumeration allPrefixes = this.fNamespaceContext.getAllPrefixes();
            while (allPrefixes.hasMoreElements()) {
                String str3 = (String) allPrefixes.nextElement();
                String uRIFromIncludeParent = this.fNamespaceContext.getURIFromIncludeParent(str3);
                String uri = this.fNamespaceContext.getURI(str3);
                if (!(uRIFromIncludeParent == uri || xMLAttributes == null)) {
                    if (str3 == XMLSymbols.EMPTY_STRING) {
                        if (xMLAttributes.getValue(NamespaceContext.XMLNS_URI, XMLSymbols.PREFIX_XMLNS) == null) {
                            qName = (QName) NEW_NS_ATTR_QNAME.clone();
                            qName.prefix = null;
                            String str4 = XMLSymbols.PREFIX_XMLNS;
                            qName.localpart = str4;
                            qName.rawname = str4;
                            str = XMLSymbols.fCDATASymbol;
                        }
                    } else if (xMLAttributes.getValue(NamespaceContext.XMLNS_URI, str3) == null) {
                        qName = (QName) NEW_NS_ATTR_QNAME.clone();
                        qName.localpart = str3;
                        String a = a.a(new StringBuffer(), qName.rawname, str3);
                        qName.rawname = a;
                        SymbolTable symbolTable = this.fSymbolTable;
                        qName.rawname = symbolTable != null ? symbolTable.addSymbol(a) : a.intern();
                        str = XMLSymbols.fCDATASymbol;
                    }
                    String str5 = uri;
                    xMLAttributes.setSpecified(xMLAttributes.addAttribute(qName, str, str5), true);
                    this.fNamespaceContext.declarePrefix(str3, uri);
                }
            }
            xMLAttributes = xMLAttributes;
        }
        if (xMLAttributes != null) {
            int length = xMLAttributes.getLength();
            for (int i2 = 0; i2 < length; i2++) {
                String type = xMLAttributes.getType(i2);
                String value = xMLAttributes.getValue(i2);
                if (type == XMLSymbols.fENTITYSymbol) {
                    checkUnparsedEntity(value);
                }
                if (type == XMLSymbols.fENTITIESSymbol) {
                    StringTokenizer stringTokenizer = new StringTokenizer(value);
                    while (stringTokenizer.hasMoreTokens()) {
                        checkUnparsedEntity(stringTokenizer.nextToken());
                    }
                } else if (type == XMLSymbols.fNOTATIONSymbol) {
                    checkNotation(value);
                }
            }
        }
        return xMLAttributes;
    }

    public void processXMLBaseAttributes(XMLAttributes xMLAttributes) {
        String value = xMLAttributes.getValue(NamespaceContext.XML_URI, "base");
        if (value != null) {
            try {
                String expandSystemId = XMLEntityManager.expandSystemId(value, this.fCurrentBaseURI.getExpandedSystemId(), false);
                this.fCurrentBaseURI.setLiteralSystemId(value);
                this.fCurrentBaseURI.setBaseSystemId(this.fCurrentBaseURI.getExpandedSystemId());
                this.fCurrentBaseURI.setExpandedSystemId(expandSystemId);
                saveBaseURI();
            } catch (URI.MalformedURIException unused) {
            }
        }
    }

    public void processXMLLangAttributes(XMLAttributes xMLAttributes) {
        String value = xMLAttributes.getValue(NamespaceContext.XML_URI, "lang");
        if (value != null) {
            this.fCurrentLanguage = value;
            saveLanguage(value);
        }
    }

    @Override // org.apache.xerces.xni.XMLDocumentHandler, org.apache.xerces.xni.XMLDTDHandler
    public void processingInstruction(String str, XMLString xMLString, Augmentations augmentations) {
        if (this.fInDTD) {
            XMLDTDHandler xMLDTDHandler = this.fDTDHandler;
            if (xMLDTDHandler != null) {
                xMLDTDHandler.processingInstruction(str, xMLString, augmentations);
            }
        } else if (this.fDocumentHandler != null && getState() == 1) {
            this.fDepth++;
            this.fDocumentHandler.processingInstruction(str, xMLString, modifyAugmentations(augmentations));
            this.fDepth--;
        }
    }

    public void reportFatalError(String str) {
        reportFatalError(str, null);
    }

    public void reportFatalError(String str, Object[] objArr) {
        reportFatalError(str, objArr, null);
    }

    public void reportFatalError(String str, Object[] objArr, Exception exc) {
        reportError(str, objArr, 2, exc);
    }

    public void reportResourceError(String str) {
        reportResourceError(str, null);
    }

    public void reportResourceError(String str, Object[] objArr) {
        reportResourceError(str, objArr, null);
    }

    public void reportResourceError(String str, Object[] objArr, Exception exc) {
        reportError(str, objArr, 0, exc);
    }

    /* JADX WARNING: Failed to process nested try/catch */
    /* JADX WARNING: Missing exception handler attribute for start block: B:24:0x0093 */
    /* JADX WARNING: Removed duplicated region for block: B:105:? A[RETURN, SYNTHETIC] */
    /* JADX WARNING: Removed duplicated region for block: B:27:0x009d A[Catch:{ XMLConfigurationException -> 0x00a3 }] */
    /* JADX WARNING: Removed duplicated region for block: B:33:0x00af A[Catch:{ XMLConfigurationException -> 0x00b5 }] */
    /* JADX WARNING: Removed duplicated region for block: B:39:0x00bf A[Catch:{ XMLConfigurationException -> 0x00cb }] */
    /* JADX WARNING: Removed duplicated region for block: B:47:0x00d5 A[Catch:{ XMLConfigurationException -> 0x00e2 }] */
    /* JADX WARNING: Removed duplicated region for block: B:55:0x00ec A[Catch:{ XMLConfigurationException -> 0x00f8 }] */
    /* JADX WARNING: Removed duplicated region for block: B:63:0x0102 A[Catch:{ XMLConfigurationException -> 0x010e }] */
    /* JADX WARNING: Removed duplicated region for block: B:81:0x014b  */
    /* JADX WARNING: Removed duplicated region for block: B:84:0x0154  */
    /* JADX WARNING: Removed duplicated region for block: B:89:0x0169 A[Catch:{ XMLConfigurationException -> 0x0196 }] */
    @Override // org.apache.xerces.xni.parser.XMLComponent
    public void reset(XMLComponentManager xMLComponentManager) {
        XIncludeTextReader xIncludeTextReader;
        XIncludeTextReader xIncludeTextReader2;
        this.fNamespaceContext = null;
        this.fDepth = 0;
        this.fResultDepth = isRootDocument() ? 0 : this.fParentXIncludeHandler.getResultDepth();
        this.fNotations.clear();
        this.fUnparsedEntities.clear();
        this.fParentRelativeURI = null;
        this.fIsXML11 = false;
        this.fInDTD = false;
        this.fSeenRootElement = false;
        this.fBaseURIScope.clear();
        this.fBaseURI.clear();
        this.fLiteralSystemID.clear();
        this.fExpandedSystemID.clear();
        this.fLanguageScope.clear();
        this.fLanguageStack.clear();
        int i2 = 0;
        while (true) {
            int[] iArr = this.fState;
            if (i2 >= iArr.length) {
                break;
            }
            iArr[i2] = 1;
            i2++;
        }
        int i3 = 0;
        while (true) {
            boolean[] zArr = this.fSawFallback;
            if (i3 >= zArr.length) {
                break;
            }
            zArr[i3] = false;
            i3++;
        }
        int i4 = 0;
        while (true) {
            boolean[] zArr2 = this.fSawInclude;
            if (i4 >= zArr2.length) {
                break;
            }
            zArr2[i4] = false;
            i4++;
        }
        try {
            if (!xMLComponentManager.getFeature("http://apache.org/xml/features/internal/parser-settings")) {
                return;
            }
        } catch (XMLConfigurationException unused) {
        }
        this.fNeedCopyFeatures = true;
        boolean feature = xMLComponentManager.getFeature("http://xml.org/sax/features/allow-dtd-events-after-endDTD");
        this.fSendUEAndNotationEvents = feature;
        if (this.fChildConfig != null) {
            this.fChildConfig.setFeature("http://xml.org/sax/features/allow-dtd-events-after-endDTD", feature);
        }
        try {
            boolean feature2 = xMLComponentManager.getFeature("http://apache.org/xml/features/xinclude/fixup-base-uris");
            this.fFixupBaseURIs = feature2;
            if (this.fChildConfig != null) {
                this.fChildConfig.setFeature("http://apache.org/xml/features/xinclude/fixup-base-uris", feature2);
            }
        } catch (XMLConfigurationException unused2) {
            this.fFixupBaseURIs = true;
        }
        try {
            boolean feature3 = xMLComponentManager.getFeature("http://apache.org/xml/features/xinclude/fixup-language");
            this.fFixupLanguage = feature3;
            if (this.fChildConfig != null) {
                this.fChildConfig.setFeature("http://apache.org/xml/features/xinclude/fixup-language", feature3);
            }
        } catch (XMLConfigurationException unused3) {
            this.fFixupLanguage = true;
        }
        try {
            SymbolTable symbolTable = (SymbolTable) xMLComponentManager.getProperty("http://apache.org/xml/properties/internal/symbol-table");
            if (symbolTable != null) {
                this.fSymbolTable = symbolTable;
                if (this.fChildConfig != null) {
                    this.fChildConfig.setProperty("http://apache.org/xml/properties/internal/symbol-table", symbolTable);
                }
            }
        } catch (XMLConfigurationException unused4) {
            this.fSymbolTable = null;
        }
        try {
            XMLErrorReporter xMLErrorReporter = (XMLErrorReporter) xMLComponentManager.getProperty("http://apache.org/xml/properties/internal/error-reporter");
            if (xMLErrorReporter != null) {
                setErrorReporter(xMLErrorReporter);
                if (this.fChildConfig != null) {
                    this.fChildConfig.setProperty("http://apache.org/xml/properties/internal/error-reporter", xMLErrorReporter);
                }
            }
        } catch (XMLConfigurationException unused5) {
            this.fErrorReporter = null;
        }
        try {
            XMLEntityResolver xMLEntityResolver = (XMLEntityResolver) xMLComponentManager.getProperty("http://apache.org/xml/properties/internal/entity-resolver");
            if (xMLEntityResolver != null) {
                this.fEntityResolver = xMLEntityResolver;
                if (this.fChildConfig != null) {
                    this.fChildConfig.setProperty("http://apache.org/xml/properties/internal/entity-resolver", xMLEntityResolver);
                }
            }
        } catch (XMLConfigurationException unused6) {
            this.fEntityResolver = null;
        }
        try {
            SecurityManager securityManager = (SecurityManager) xMLComponentManager.getProperty("http://apache.org/xml/properties/security-manager");
            if (securityManager != null) {
                this.fSecurityManager = securityManager;
                if (this.fChildConfig != null) {
                    this.fChildConfig.setProperty("http://apache.org/xml/properties/security-manager", securityManager);
                }
            }
        } catch (XMLConfigurationException unused7) {
            this.fSecurityManager = null;
        }
        try {
            Integer num = (Integer) xMLComponentManager.getProperty("http://apache.org/xml/properties/input-buffer-size");
            if (num != null || num.intValue() <= 0) {
                this.fBufferSize = ((Integer) getPropertyDefault("http://apache.org/xml/properties/input-buffer-size")).intValue();
                xIncludeTextReader = this.fXInclude10TextReader;
                if (xIncludeTextReader != null) {
                    xIncludeTextReader.setBufferSize(this.fBufferSize);
                }
                xIncludeTextReader2 = this.fXInclude11TextReader;
                if (xIncludeTextReader2 != null) {
                    xIncludeTextReader2.setBufferSize(this.fBufferSize);
                }
                ParserConfigurationSettings parserConfigurationSettings = new ParserConfigurationSettings();
                this.fSettings = parserConfigurationSettings;
                copyFeatures(xMLComponentManager, parserConfigurationSettings);
                try {
                    if (xMLComponentManager.getFeature("http://apache.org/xml/features/validation/schema")) {
                        this.fSettings.setFeature("http://apache.org/xml/features/validation/schema", false);
                        if (Constants.NS_XMLSCHEMA.equals(xMLComponentManager.getProperty("http://java.sun.com/xml/jaxp/properties/schemaLanguage"))) {
                            this.fSettings.setFeature("http://xml.org/sax/features/validation", false);
                        } else if (xMLComponentManager.getFeature("http://xml.org/sax/features/validation")) {
                            this.fSettings.setFeature("http://apache.org/xml/features/validation/dynamic", true);
                        }
                    }
                } catch (XMLConfigurationException unused8) {
                }
            } else {
                this.fBufferSize = num.intValue();
                if (this.fChildConfig != null) {
                    this.fChildConfig.setProperty("http://apache.org/xml/properties/input-buffer-size", num);
                }
                xIncludeTextReader = this.fXInclude10TextReader;
                if (xIncludeTextReader != null) {
                }
                xIncludeTextReader2 = this.fXInclude11TextReader;
                if (xIncludeTextReader2 != null) {
                }
                ParserConfigurationSettings parserConfigurationSettings2 = new ParserConfigurationSettings();
                this.fSettings = parserConfigurationSettings2;
                copyFeatures(xMLComponentManager, parserConfigurationSettings2);
                if (xMLComponentManager.getFeature("http://apache.org/xml/features/validation/schema")) {
                }
            }
        } catch (XMLConfigurationException unused9) {
            this.fBufferSize = ((Integer) getPropertyDefault("http://apache.org/xml/properties/input-buffer-size")).intValue();
        }
    }

    public void restoreBaseURI() {
        this.fBaseURI.pop();
        this.fLiteralSystemID.pop();
        this.fExpandedSystemID.pop();
        this.fBaseURIScope.pop();
        this.fCurrentBaseURI.setBaseSystemId((String) this.fBaseURI.peek());
        this.fCurrentBaseURI.setLiteralSystemId((String) this.fLiteralSystemID.peek());
        this.fCurrentBaseURI.setExpandedSystemId((String) this.fExpandedSystemID.peek());
    }

    public String restoreLanguage() {
        this.fLanguageStack.pop();
        this.fLanguageScope.pop();
        return (String) this.fLanguageStack.peek();
    }

    public boolean sameBaseURIAsIncludeParent() {
        String includeParentBaseURI = getIncludeParentBaseURI();
        return includeParentBaseURI != null && includeParentBaseURI.equals(this.fCurrentBaseURI.getExpandedSystemId());
    }

    public boolean sameLanguageAsIncludeParent() {
        String includeParentLanguage = getIncludeParentLanguage();
        return includeParentLanguage != null && includeParentLanguage.equalsIgnoreCase(this.fCurrentLanguage);
    }

    public void saveBaseURI() {
        this.fBaseURIScope.push(this.fDepth);
        this.fBaseURI.push(this.fCurrentBaseURI.getBaseSystemId());
        this.fLiteralSystemID.push(this.fCurrentBaseURI.getLiteralSystemId());
        this.fExpandedSystemID.push(this.fCurrentBaseURI.getExpandedSystemId());
    }

    public void saveLanguage(String str) {
        this.fLanguageScope.push(this.fDepth);
        this.fLanguageStack.push(str);
    }

    public boolean searchForRecursiveIncludes(String str) {
        if (str.equals(this.fCurrentBaseURI.getExpandedSystemId())) {
            return true;
        }
        XIncludeHandler xIncludeHandler = this.fParentXIncludeHandler;
        if (xIncludeHandler == null) {
            return false;
        }
        return xIncludeHandler.searchForRecursiveIncludes(str);
    }

    @Override // org.apache.xerces.xni.parser.XMLDTDSource
    public void setDTDHandler(XMLDTDHandler xMLDTDHandler) {
        this.fDTDHandler = xMLDTDHandler;
    }

    @Override // org.apache.xerces.xni.XMLDTDHandler
    public void setDTDSource(XMLDTDSource xMLDTDSource) {
        this.fDTDSource = xMLDTDSource;
    }

    @Override // org.apache.xerces.xni.parser.XMLDocumentSource
    public void setDocumentHandler(XMLDocumentHandler xMLDocumentHandler) {
        if (this.fDocumentHandler != xMLDocumentHandler) {
            this.fDocumentHandler = xMLDocumentHandler;
            XMLParserConfiguration xMLParserConfiguration = this.fXIncludeChildConfig;
            if (xMLParserConfiguration != null) {
                xMLParserConfiguration.setDocumentHandler(xMLDocumentHandler);
            }
            XMLParserConfiguration xMLParserConfiguration2 = this.fXPointerChildConfig;
            if (xMLParserConfiguration2 != null) {
                xMLParserConfiguration2.setDocumentHandler(xMLDocumentHandler);
            }
        }
    }

    @Override // org.apache.xerces.xni.XMLDocumentHandler
    public void setDocumentSource(XMLDocumentSource xMLDocumentSource) {
        this.fDocumentSource = xMLDocumentSource;
    }

    @Override // org.apache.xerces.xni.parser.XMLComponent
    public void setFeature(String str, boolean z) {
        if (str.equals("http://xml.org/sax/features/allow-dtd-events-after-endDTD")) {
            this.fSendUEAndNotationEvents = z;
        }
        ParserConfigurationSettings parserConfigurationSettings = this.fSettings;
        if (parserConfigurationSettings != null) {
            this.fNeedCopyFeatures = true;
            parserConfigurationSettings.setFeature(str, z);
        }
    }

    public void setHref(String str) {
        this.fHrefFromParent = str;
    }

    public void setParent(XIncludeHandler xIncludeHandler) {
        this.fParentXIncludeHandler = xIncludeHandler;
    }

    @Override // org.apache.xerces.xni.parser.XMLComponent
    public void setProperty(String str, Object obj) {
        if (str.equals("http://apache.org/xml/properties/internal/symbol-table")) {
            this.fSymbolTable = (SymbolTable) obj;
            XMLParserConfiguration xMLParserConfiguration = this.fChildConfig;
            if (xMLParserConfiguration != null) {
                xMLParserConfiguration.setProperty(str, obj);
            }
        } else if (str.equals("http://apache.org/xml/properties/internal/error-reporter")) {
            setErrorReporter((XMLErrorReporter) obj);
            XMLParserConfiguration xMLParserConfiguration2 = this.fChildConfig;
            if (xMLParserConfiguration2 != null) {
                xMLParserConfiguration2.setProperty(str, obj);
            }
        } else if (str.equals("http://apache.org/xml/properties/internal/entity-resolver")) {
            this.fEntityResolver = (XMLEntityResolver) obj;
            XMLParserConfiguration xMLParserConfiguration3 = this.fChildConfig;
            if (xMLParserConfiguration3 != null) {
                xMLParserConfiguration3.setProperty(str, obj);
            }
        } else if (str.equals("http://apache.org/xml/properties/security-manager")) {
            this.fSecurityManager = (SecurityManager) obj;
            XMLParserConfiguration xMLParserConfiguration4 = this.fChildConfig;
            if (xMLParserConfiguration4 != null) {
                xMLParserConfiguration4.setProperty(str, obj);
            }
        } else if (str.equals("http://apache.org/xml/properties/input-buffer-size")) {
            Integer num = (Integer) obj;
            XMLParserConfiguration xMLParserConfiguration5 = this.fChildConfig;
            if (xMLParserConfiguration5 != null) {
                xMLParserConfiguration5.setProperty(str, obj);
            }
            if (num != null && num.intValue() > 0) {
                int intValue = num.intValue();
                this.fBufferSize = intValue;
                XIncludeTextReader xIncludeTextReader = this.fXInclude10TextReader;
                if (xIncludeTextReader != null) {
                    xIncludeTextReader.setBufferSize(intValue);
                }
                XIncludeTextReader xIncludeTextReader2 = this.fXInclude11TextReader;
                if (xIncludeTextReader2 != null) {
                    xIncludeTextReader2.setBufferSize(this.fBufferSize);
                }
            }
        }
    }

    public void setSawFallback(int i2, boolean z) {
        boolean[] zArr = this.fSawFallback;
        if (i2 >= zArr.length) {
            boolean[] zArr2 = new boolean[(i2 * 2)];
            System.arraycopy(zArr, 0, zArr2, 0, zArr.length);
            this.fSawFallback = zArr2;
        }
        this.fSawFallback[i2] = z;
    }

    public void setSawInclude(int i2, boolean z) {
        boolean[] zArr = this.fSawInclude;
        if (i2 >= zArr.length) {
            boolean[] zArr2 = new boolean[(i2 * 2)];
            System.arraycopy(zArr, 0, zArr2, 0, zArr.length);
            this.fSawInclude = zArr2;
        }
        this.fSawInclude[i2] = z;
    }

    public void setState(int i2) {
        int i3 = this.fDepth;
        int[] iArr = this.fState;
        if (i3 >= iArr.length) {
            int[] iArr2 = new int[(i3 * 2)];
            System.arraycopy(iArr, 0, iArr2, 0, iArr.length);
            this.fState = iArr2;
        }
        this.fState[this.fDepth] = i2;
    }

    public void setXIncludeLocator(XMLLocatorWrapper xMLLocatorWrapper) {
        this.fXIncludeLocator = xMLLocatorWrapper;
    }

    public void setupCurrentBaseURI(XMLLocator xMLLocator) {
        String str;
        XMLResourceIdentifier xMLResourceIdentifier;
        this.fCurrentBaseURI.setBaseSystemId(xMLLocator.getBaseSystemId());
        if (xMLLocator.getLiteralSystemId() != null) {
            xMLResourceIdentifier = this.fCurrentBaseURI;
            str = xMLLocator.getLiteralSystemId();
        } else {
            xMLResourceIdentifier = this.fCurrentBaseURI;
            str = this.fHrefFromParent;
        }
        xMLResourceIdentifier.setLiteralSystemId(str);
        String expandedSystemId = xMLLocator.getExpandedSystemId();
        if (expandedSystemId == null) {
            try {
                expandedSystemId = XMLEntityManager.expandSystemId(this.fCurrentBaseURI.getLiteralSystemId(), this.fCurrentBaseURI.getBaseSystemId(), false);
                if (expandedSystemId == null) {
                    expandedSystemId = this.fCurrentBaseURI.getLiteralSystemId();
                }
            } catch (URI.MalformedURIException unused) {
                reportFatalError("ExpandedSystemId");
            }
        }
        this.fCurrentBaseURI.setExpandedSystemId(expandedSystemId);
    }

    @Override // org.apache.xerces.xni.XMLDTDHandler
    public void startAttlist(String str, Augmentations augmentations) {
        XMLDTDHandler xMLDTDHandler = this.fDTDHandler;
        if (xMLDTDHandler != null) {
            xMLDTDHandler.startAttlist(str, augmentations);
        }
    }

    @Override // org.apache.xerces.xni.XMLDocumentHandler
    public void startCDATA(Augmentations augmentations) {
        if (this.fDocumentHandler != null && getState() == 1 && this.fResultDepth != 0) {
            this.fDocumentHandler.startCDATA(augmentations);
        }
    }

    @Override // org.apache.xerces.xni.XMLDTDHandler
    public void startConditional(short s, Augmentations augmentations) {
        XMLDTDHandler xMLDTDHandler = this.fDTDHandler;
        if (xMLDTDHandler != null) {
            xMLDTDHandler.startConditional(s, augmentations);
        }
    }

    @Override // org.apache.xerces.xni.XMLDTDHandler
    public void startDTD(XMLLocator xMLLocator, Augmentations augmentations) {
        this.fInDTD = true;
        XMLDTDHandler xMLDTDHandler = this.fDTDHandler;
        if (xMLDTDHandler != null) {
            xMLDTDHandler.startDTD(xMLLocator, augmentations);
        }
    }

    @Override // org.apache.xerces.xni.XMLDocumentHandler
    public void startDocument(XMLLocator xMLLocator, String str, NamespaceContext namespaceContext, Augmentations augmentations) {
        XMLDocumentHandler xMLDocumentHandler;
        this.fErrorReporter.setDocumentLocator(xMLLocator);
        if (!(namespaceContext instanceof XIncludeNamespaceSupport)) {
            reportFatalError("IncompatibleNamespaceContext");
        }
        this.fNamespaceContext = (XIncludeNamespaceSupport) namespaceContext;
        this.fDocLocation = xMLLocator;
        this.fXIncludeLocator.setLocator(xMLLocator);
        setupCurrentBaseURI(xMLLocator);
        saveBaseURI();
        if (augmentations == null) {
            augmentations = new AugmentationsImpl();
        }
        augmentations.putItem(CURRENT_BASE_URI, this.fCurrentBaseURI);
        if (!isRootDocument()) {
            XIncludeHandler xIncludeHandler = this.fParentXIncludeHandler;
            xIncludeHandler.fHasIncludeReportedContent = true;
            if (xIncludeHandler.searchForRecursiveIncludes(this.fCurrentBaseURI.getExpandedSystemId())) {
                reportFatalError("RecursiveInclude", new Object[]{this.fCurrentBaseURI.getExpandedSystemId()});
            }
        }
        String str2 = XMLSymbols.EMPTY_STRING;
        this.fCurrentLanguage = str2;
        saveLanguage(str2);
        if (isRootDocument() && (xMLDocumentHandler = this.fDocumentHandler) != null) {
            xMLDocumentHandler.startDocument(this.fXIncludeLocator, str, namespaceContext, augmentations);
        }
    }

    @Override // org.apache.xerces.xni.XMLDocumentHandler
    public void startElement(QName qName, XMLAttributes xMLAttributes, Augmentations augmentations) {
        int i2 = this.fDepth + 1;
        this.fDepth = i2;
        int state = getState(i2 - 1);
        if (state == 3 && getState(this.fDepth - 2) == 3) {
            setState(2);
        } else {
            setState(state);
        }
        processXMLBaseAttributes(xMLAttributes);
        if (this.fFixupLanguage) {
            processXMLLangAttributes(xMLAttributes);
        }
        if (isIncludeElement(qName)) {
            if (handleIncludeElement(xMLAttributes)) {
                setState(2);
            } else {
                setState(3);
            }
        } else if (isFallbackElement(qName)) {
            handleFallbackElement();
        } else {
            if (hasXIncludeNamespace(qName)) {
                if (getSawInclude(this.fDepth - 1)) {
                    reportFatalError("IncludeChild", new Object[]{qName.rawname});
                }
                if (getSawFallback(this.fDepth - 1)) {
                    reportFatalError("FallbackChild", new Object[]{qName.rawname});
                }
                if (getState() == 1) {
                    int i3 = this.fResultDepth;
                    this.fResultDepth = i3 + 1;
                    if (i3 == 0) {
                        checkMultipleRootElements();
                    }
                    if (this.fDocumentHandler == null) {
                        return;
                    }
                } else {
                    return;
                }
            } else if (getState() == 1) {
                int i4 = this.fResultDepth;
                this.fResultDepth = i4 + 1;
                if (i4 == 0) {
                    checkMultipleRootElements();
                }
                if (this.fDocumentHandler == null) {
                    return;
                }
            } else {
                return;
            }
            Augmentations modifyAugmentations = modifyAugmentations(augmentations);
            this.fDocumentHandler.startElement(qName, processAttributes(xMLAttributes), modifyAugmentations);
        }
    }

    @Override // org.apache.xerces.xni.XMLDTDHandler
    public void startExternalSubset(XMLResourceIdentifier xMLResourceIdentifier, Augmentations augmentations) {
        XMLDTDHandler xMLDTDHandler = this.fDTDHandler;
        if (xMLDTDHandler != null) {
            xMLDTDHandler.startExternalSubset(xMLResourceIdentifier, augmentations);
        }
    }

    @Override // org.apache.xerces.xni.XMLDocumentHandler
    public void startGeneralEntity(String str, XMLResourceIdentifier xMLResourceIdentifier, String str2, Augmentations augmentations) {
        if (getState() != 1) {
            return;
        }
        if (this.fResultDepth != 0) {
            XMLDocumentHandler xMLDocumentHandler = this.fDocumentHandler;
            if (xMLDocumentHandler != null) {
                xMLDocumentHandler.startGeneralEntity(str, xMLResourceIdentifier, str2, augmentations);
            }
        } else if (augmentations != null && Boolean.TRUE.equals(augmentations.getItem(Constants.ENTITY_SKIPPED))) {
            reportFatalError("UnexpandedEntityReferenceIllegal");
        }
    }

    @Override // org.apache.xerces.xni.XMLDTDHandler
    public void startParameterEntity(String str, XMLResourceIdentifier xMLResourceIdentifier, String str2, Augmentations augmentations) {
        XMLDTDHandler xMLDTDHandler = this.fDTDHandler;
        if (xMLDTDHandler != null) {
            xMLDTDHandler.startParameterEntity(str, xMLResourceIdentifier, str2, augmentations);
        }
    }

    @Override // org.apache.xerces.xni.XMLDocumentHandler, org.apache.xerces.xni.XMLDTDHandler
    public void textDecl(String str, String str2, Augmentations augmentations) {
        if (this.fDocumentHandler != null && getState() == 1) {
            this.fDocumentHandler.textDecl(str, str2, augmentations);
        }
    }

    @Override // org.apache.xerces.xni.XMLDTDHandler
    public void unparsedEntityDecl(String str, XMLResourceIdentifier xMLResourceIdentifier, String str2, Augmentations augmentations) {
        addUnparsedEntity(str, xMLResourceIdentifier, str2, augmentations);
        XMLDTDHandler xMLDTDHandler = this.fDTDHandler;
        if (xMLDTDHandler != null) {
            xMLDTDHandler.unparsedEntityDecl(str, xMLResourceIdentifier, str2, augmentations);
        }
    }

    @Override // org.apache.xerces.xni.XMLDocumentHandler
    public void xmlDecl(String str, String str2, String str3, Augmentations augmentations) {
        XMLDocumentHandler xMLDocumentHandler;
        this.fIsXML11 = "1.1".equals(str);
        if (isRootDocument() && (xMLDocumentHandler = this.fDocumentHandler) != null) {
            xMLDocumentHandler.xmlDecl(str, str2, str3, augmentations);
        }
    }
}
