package org.apache.xerces.xpointer;

import java.util.HashMap;
import org.apache.xerces.impl.XMLErrorReporter;
import org.apache.xerces.util.SymbolTable;
import org.apache.xerces.util.XMLChar;
import org.apache.xerces.xni.Augmentations;
import org.apache.xerces.xni.QName;
import org.apache.xerces.xni.XMLAttributes;
import org.apache.xerces.xni.XNIException;
import org.apache.xerces.xni.parser.XMLErrorHandler;

public final class ElementSchemePointer implements XPointerPart {
    public int[] fChildSequence;
    public int fCurrentChildDepth = 0;
    public int fCurrentChildPosition = 1;
    public int[] fCurrentChildSequence;
    public XMLErrorHandler fErrorHandler;
    public XMLErrorReporter fErrorReporter;
    public int fFoundDepth = 0;
    public boolean fIsElementFound = false;
    public boolean fIsFragmentResolved = false;
    public boolean fIsResolveElement = false;
    public boolean fIsShortHand = false;
    public String fSchemeData;
    public String fSchemeName;
    public ShortHandPointer fShortHandPointer;
    public String fShortHandPointerName;
    public SymbolTable fSymbolTable;
    public boolean fWasOnlyEmptyElementFound = false;

    public class Scanner {
        public static final byte CHARTYPE_DIGIT = 5;
        public static final byte CHARTYPE_INVALID = 0;
        public static final byte CHARTYPE_LETTER = 6;
        public static final byte CHARTYPE_MINUS = 2;
        public static final byte CHARTYPE_NONASCII = 8;
        public static final byte CHARTYPE_OTHER = 1;
        public static final byte CHARTYPE_PERIOD = 3;
        public static final byte CHARTYPE_SLASH = 4;
        public static final byte CHARTYPE_UNDERSCORE = 7;
        public final byte[] fASCIICharMap;
        public SymbolTable fSymbolTable;

        public Scanner(SymbolTable symbolTable) {
            this.fASCIICharMap = new byte[]{0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 1, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 2, 2, 4, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 1, 1, 1, 1, 1, 1, 1, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 1, 1, 1, 1, 7, 1, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 1, 1, 1, 1, 1};
            this.fSymbolTable = symbolTable;
        }

        /* access modifiers changed from: private */
        /* access modifiers changed from: public */
        private boolean scanExpr(SymbolTable symbolTable, Tokens tokens, String str, int i2, int i3) {
            while (i2 != i3) {
                char charAt = str.charAt(i2);
                switch (charAt >= 128 ? 8 : this.fASCIICharMap[charAt]) {
                    case 1:
                    case 2:
                    case 3:
                    case 5:
                    case 6:
                    case 7:
                    case 8:
                        int scanNCName = scanNCName(str, i3, i2);
                        if (scanNCName != i2) {
                            if (scanNCName < i3) {
                                str.charAt(scanNCName);
                            }
                            String addSymbol = symbolTable.addSymbol(str.substring(i2, scanNCName));
                            addToken(tokens, 0);
                            tokens.addToken((Tokens) addSymbol);
                            i2 = scanNCName;
                            break;
                        } else {
                            ElementSchemePointer.this.reportError("InvalidNCNameInElementSchemeData", new Object[]{str});
                            return false;
                        }
                    case 4:
                        i2++;
                        if (i2 != i3) {
                            addToken(tokens, 1);
                            char charAt2 = str.charAt(i2);
                            int i4 = 0;
                            while (charAt2 >= '0' && charAt2 <= '9') {
                                i4 = (i4 * 10) + (charAt2 - '0');
                                i2++;
                                if (i2 != i3) {
                                    charAt2 = str.charAt(i2);
                                }
                            }
                            if (i4 != 0) {
                                tokens.addToken((Tokens) i4);
                                break;
                            } else {
                                ElementSchemePointer.this.reportError("InvalidChildSequenceCharacter", new Object[]{new Character((char) charAt2)});
                                return false;
                            }
                        } else {
                            return false;
                        }
                }
            }
            return true;
        }

        private int scanNCName(String str, int i2, int i3) {
            char charAt = str.charAt(i3);
            if (charAt < 128) {
                byte b2 = this.fASCIICharMap[charAt];
                if (!(b2 == 6 || b2 == 7)) {
                    return i3;
                }
            } else if (!XMLChar.isNameStart(charAt)) {
                return i3;
            }
            while (true) {
                i3++;
                if (i3 >= i2) {
                    break;
                }
                char charAt2 = str.charAt(i3);
                if (charAt2 < 128) {
                    byte b3 = this.fASCIICharMap[charAt2];
                    if (!(b3 == 6 || b3 == 5 || b3 == 3 || b3 == 2 || b3 == 7)) {
                        break;
                    }
                } else if (!XMLChar.isName(charAt2)) {
                    break;
                }
            }
            return i3;
        }

        public void addToken(Tokens tokens, int i2) {
            tokens.addToken((Tokens) i2);
        }
    }

    public final class Tokens {
        public static final int INITIAL_TOKEN_COUNT = 256;
        public static final int XPTRTOKEN_ELEM_CHILD = 1;
        public static final int XPTRTOKEN_ELEM_NCNAME = 0;
        public int fCurrentTokenIndex;
        public SymbolTable fSymbolTable;
        public int fTokenCount;
        public HashMap fTokenNames;
        public int[] fTokens;
        public final String[] fgTokenNames;

        public Tokens(SymbolTable symbolTable) {
            this.fgTokenNames = new String[]{"XPTRTOKEN_ELEM_NCNAME", "XPTRTOKEN_ELEM_CHILD"};
            this.fTokens = new int[256];
            this.fTokenCount = 0;
            HashMap hashMap = new HashMap();
            this.fTokenNames = hashMap;
            this.fSymbolTable = symbolTable;
            hashMap.put(new Integer(0), "XPTRTOKEN_ELEM_NCNAME");
            this.fTokenNames.put(new Integer(1), "XPTRTOKEN_ELEM_CHILD");
        }

        /* access modifiers changed from: private */
        /* access modifiers changed from: public */
        private void addToken(int i2) {
            try {
                this.fTokens[this.fTokenCount] = i2;
            } catch (ArrayIndexOutOfBoundsException unused) {
                int[] iArr = this.fTokens;
                int i3 = this.fTokenCount;
                int[] iArr2 = new int[(i3 << 1)];
                this.fTokens = iArr2;
                System.arraycopy(iArr, 0, iArr2, 0, i3);
                this.fTokens[this.fTokenCount] = i2;
            }
            this.fTokenCount++;
        }

        /* access modifiers changed from: private */
        /* access modifiers changed from: public */
        private void addToken(String str) {
            Integer num = (Integer) this.fTokenNames.get(str);
            if (num == null) {
                num = new Integer(this.fTokenNames.size());
                this.fTokenNames.put(num, str);
            }
            addToken(num.intValue());
        }

        private Integer getToken(int i2) {
            return (Integer) this.fTokenNames.get(new Integer(i2));
        }

        /* access modifiers changed from: private */
        /* access modifiers changed from: public */
        private int getTokenCount() {
            return this.fTokenCount;
        }

        /* access modifiers changed from: private */
        /* access modifiers changed from: public */
        private String getTokenString(int i2) {
            return (String) this.fTokenNames.get(new Integer(i2));
        }

        /* access modifiers changed from: private */
        /* access modifiers changed from: public */
        private boolean hasMore() {
            return this.fCurrentTokenIndex < this.fTokenCount;
        }

        /* access modifiers changed from: private */
        /* access modifiers changed from: public */
        private int nextToken() {
            if (this.fCurrentTokenIndex == this.fTokenCount) {
                ElementSchemePointer.this.reportError("XPointerElementSchemeProcessingError", null);
            }
            int[] iArr = this.fTokens;
            int i2 = this.fCurrentTokenIndex;
            this.fCurrentTokenIndex = i2 + 1;
            return iArr[i2];
        }

        private String nextTokenAsString() {
            String tokenString = getTokenString(nextToken());
            if (tokenString == null) {
                ElementSchemePointer.this.reportError("XPointerElementSchemeProcessingError", null);
            }
            return tokenString;
        }

        private int peekToken() {
            if (this.fCurrentTokenIndex == this.fTokenCount) {
                ElementSchemePointer.this.reportError("XPointerElementSchemeProcessingError", null);
            }
            return this.fTokens[this.fCurrentTokenIndex];
        }

        private void rewind() {
            this.fCurrentTokenIndex = 0;
        }
    }

    public ElementSchemePointer() {
    }

    public ElementSchemePointer(SymbolTable symbolTable) {
        this.fSymbolTable = symbolTable;
    }

    public ElementSchemePointer(SymbolTable symbolTable, XMLErrorReporter xMLErrorReporter) {
        this.fSymbolTable = symbolTable;
        this.fErrorReporter = xMLErrorReporter;
    }

    public boolean checkMatch() {
        int[] iArr;
        int i2;
        if (this.fIsShortHand) {
            if (this.fChildSequence.length <= this.fCurrentChildDepth + 1) {
                int i3 = 0;
                do {
                    int[] iArr2 = this.fChildSequence;
                    if (i3 < iArr2.length) {
                        iArr = this.fCurrentChildSequence;
                        if (iArr.length < i3 + 2) {
                            return false;
                        }
                        i2 = iArr2[i3];
                        i3++;
                    }
                } while (i2 == iArr[i3]);
            }
            return false;
        } else if (this.fChildSequence.length > this.fCurrentChildDepth + 1) {
            return false;
        } else {
            int i4 = 0;
            while (true) {
                int[] iArr3 = this.fChildSequence;
                if (i4 >= iArr3.length) {
                    break;
                } else if (iArr3[i4] != this.fCurrentChildSequence[i4]) {
                    return false;
                } else {
                    i4++;
                }
            }
        }
        return true;
    }

    @Override // org.apache.xerces.xpointer.XPointerPart
    public String getSchemeData() {
        return this.fSchemeData;
    }

    @Override // org.apache.xerces.xpointer.XPointerPart
    public String getSchemeName() {
        return this.fSchemeName;
    }

    public void init() {
        this.fSchemeName = null;
        this.fSchemeData = null;
        this.fShortHandPointerName = null;
        this.fIsResolveElement = false;
        this.fIsElementFound = false;
        this.fWasOnlyEmptyElementFound = false;
        this.fFoundDepth = 0;
        this.fCurrentChildPosition = 1;
        this.fCurrentChildDepth = 0;
        this.fIsFragmentResolved = false;
        this.fShortHandPointer = null;
        initErrorReporter();
    }

    public void initErrorReporter() {
        if (this.fErrorReporter == null) {
            this.fErrorReporter = new XMLErrorReporter();
        }
        if (this.fErrorHandler == null) {
            this.fErrorHandler = new XPointerErrorHandler();
        }
        this.fErrorReporter.putMessageFormatter(XPointerMessageFormatter.XPOINTER_DOMAIN, new XPointerMessageFormatter());
    }

    @Override // org.apache.xerces.xpointer.XPointerPart
    public boolean isChildFragmentResolved() {
        ShortHandPointer shortHandPointer;
        if (this.fIsShortHand && (shortHandPointer = this.fShortHandPointer) != null && this.fChildSequence.length <= 0) {
            return shortHandPointer.isChildFragmentResolved();
        }
        boolean z = this.fWasOnlyEmptyElementFound;
        if (!z) {
            return this.fIsFragmentResolved && this.fCurrentChildDepth >= this.fFoundDepth;
        }
        if (!z) {
            return true;
        }
    }

    @Override // org.apache.xerces.xpointer.XPointerPart
    public boolean isFragmentResolved() {
        return this.fIsFragmentResolved;
    }

    public boolean matchChildSequence(QName qName, int i2) {
        int i3;
        int i4 = this.fCurrentChildDepth;
        int[] iArr = this.fCurrentChildSequence;
        if (i4 >= iArr.length) {
            int length = iArr.length;
            int[] iArr2 = new int[length];
            System.arraycopy(iArr, 0, iArr2, 0, iArr.length);
            int[] iArr3 = new int[(this.fCurrentChildDepth * 2)];
            this.fCurrentChildSequence = iArr3;
            System.arraycopy(iArr2, 0, iArr3, 0, length);
        }
        if (this.fIsResolveElement) {
            if (i2 == 0) {
                int[] iArr4 = this.fCurrentChildSequence;
                int i5 = this.fCurrentChildDepth;
                iArr4[i5] = this.fCurrentChildPosition;
                int i6 = i5 + 1;
                this.fCurrentChildDepth = i6;
                this.fCurrentChildPosition = 1;
                int i7 = this.fFoundDepth;
                if (i6 <= i7 || i7 == 0) {
                    if (checkMatch()) {
                        this.fIsElementFound = true;
                        this.fFoundDepth = this.fCurrentChildDepth;
                    } else {
                        this.fIsElementFound = false;
                        this.fFoundDepth = 0;
                    }
                }
            } else if (i2 == 1) {
                int i8 = this.fCurrentChildDepth;
                int i9 = this.fFoundDepth;
                if (i8 == i9) {
                    this.fIsElementFound = true;
                } else if ((i8 < i9 && i9 != 0) || (this.fCurrentChildDepth > (i3 = this.fFoundDepth) && i3 == 0)) {
                    this.fIsElementFound = false;
                }
                int[] iArr5 = this.fCurrentChildSequence;
                int i10 = this.fCurrentChildDepth;
                iArr5[i10] = 0;
                int i11 = i10 - 1;
                this.fCurrentChildDepth = i11;
                this.fCurrentChildPosition = iArr5[i11] + 1;
            } else if (i2 == 2) {
                int[] iArr6 = this.fCurrentChildSequence;
                int i12 = this.fCurrentChildDepth;
                int i13 = this.fCurrentChildPosition;
                iArr6[i12] = i13;
                this.fCurrentChildPosition = i13 + 1;
                if (checkMatch()) {
                    if (!this.fIsElementFound) {
                        this.fWasOnlyEmptyElementFound = true;
                    } else {
                        this.fWasOnlyEmptyElementFound = false;
                    }
                    this.fIsElementFound = true;
                } else {
                    this.fIsElementFound = false;
                    this.fWasOnlyEmptyElementFound = false;
                }
            }
        }
        return this.fIsElementFound;
    }

    @Override // org.apache.xerces.xpointer.XPointerPart
    public void parseXPointer(String str) {
        init();
        Tokens tokens = new Tokens(this.fSymbolTable);
        if (!new Scanner(this, this.fSymbolTable) {
            /* class org.apache.xerces.xpointer.ElementSchemePointer.AnonymousClass1 */
            public final /* synthetic */ ElementSchemePointer this$0;

            {
                this.this$0 = r2;
            }

            @Override // org.apache.xerces.xpointer.ElementSchemePointer.Scanner
            public void addToken(Tokens tokens, int i2) {
                if (i2 == 1 || i2 == 0) {
                    super.addToken(tokens, i2);
                    return;
                }
                this.this$0.reportError("InvalidElementSchemeToken", new Object[]{tokens.getTokenString(i2)});
            }
        }.scanExpr(this.fSymbolTable, tokens, str, 0, str.length())) {
            reportError("InvalidElementSchemeXPointer", new Object[]{str});
        }
        int[] iArr = new int[((tokens.getTokenCount() / 2) + 1)];
        int i2 = 0;
        while (tokens.hasMore()) {
            int nextToken = tokens.nextToken();
            if (nextToken == 0) {
                this.fShortHandPointerName = tokens.getTokenString(tokens.nextToken());
                ShortHandPointer shortHandPointer = new ShortHandPointer(this.fSymbolTable);
                this.fShortHandPointer = shortHandPointer;
                shortHandPointer.setSchemeName(this.fShortHandPointerName);
            } else if (nextToken != 1) {
                reportError("InvalidElementSchemeXPointer", new Object[]{str});
            } else {
                iArr[i2] = tokens.nextToken();
                i2++;
            }
        }
        int[] iArr2 = new int[i2];
        this.fChildSequence = iArr2;
        this.fCurrentChildSequence = new int[i2];
        System.arraycopy(iArr, 0, iArr2, 0, i2);
    }

    public void reportError(String str, Object[] objArr) {
        throw new XNIException(this.fErrorReporter.getMessageFormatter(XPointerMessageFormatter.XPOINTER_DOMAIN).formatMessage(this.fErrorReporter.getLocale(), str, objArr));
    }

    @Override // org.apache.xerces.xpointer.XPointerPart
    public boolean resolveXPointer(QName qName, XMLAttributes xMLAttributes, Augmentations augmentations, int i2) {
        boolean z;
        if (this.fShortHandPointerName != null) {
            z = this.fShortHandPointer.resolveXPointer(qName, xMLAttributes, augmentations, i2);
            if (z) {
                this.fIsResolveElement = true;
                this.fIsShortHand = true;
            } else {
                this.fIsResolveElement = false;
            }
        } else {
            this.fIsResolveElement = true;
            z = false;
        }
        int[] iArr = this.fChildSequence;
        if (iArr.length > 0) {
            this.fIsFragmentResolved = matchChildSequence(qName, i2);
        } else if (!z || iArr.length > 0) {
            this.fIsFragmentResolved = false;
        } else {
            this.fIsFragmentResolved = z;
        }
        return this.fIsFragmentResolved;
    }

    @Override // org.apache.xerces.xpointer.XPointerPart
    public void setSchemeData(String str) {
        this.fSchemeData = str;
    }

    @Override // org.apache.xerces.xpointer.XPointerPart
    public void setSchemeName(String str) {
        this.fSchemeName = str;
    }
}
