package org.apache.xerces.xpointer;

import org.apache.xerces.impl.Constants;
import org.apache.xerces.impl.dv.XSSimpleType;
import org.apache.xerces.impl.xs.SchemaSymbols;
import org.apache.xerces.util.SymbolTable;
import org.apache.xerces.xni.Augmentations;
import org.apache.xerces.xni.QName;
import org.apache.xerces.xni.XMLAttributes;
import org.apache.xerces.xs.AttributePSVI;
import org.apache.xerces.xs.XSTypeDefinition;

public final class ShortHandPointer implements XPointerPart {
    public boolean fIsFragmentResolved = false;
    public int fMatchingChildCount = 0;
    public String fShortHandPointer;
    public SymbolTable fSymbolTable;

    public ShortHandPointer() {
    }

    public ShortHandPointer(SymbolTable symbolTable) {
        this.fSymbolTable = symbolTable;
    }

    private boolean hasMatchingIdentifier(QName qName, XMLAttributes xMLAttributes, Augmentations augmentations, int i2) {
        String str = null;
        if (xMLAttributes != null) {
            int i3 = 0;
            while (i3 < xMLAttributes.getLength() && (str = getSchemaDeterminedID(xMLAttributes, i3)) == null && (str = getChildrenSchemaDeterminedID(xMLAttributes, i3)) == null && (str = getDTDDeterminedID(xMLAttributes, i3)) == null) {
                i3++;
            }
        }
        return str != null && str.equals(this.fShortHandPointer);
    }

    public String getChildrenSchemaDeterminedID(XMLAttributes xMLAttributes, int i2) {
        return null;
    }

    public String getDTDDeterminedID(XMLAttributes xMLAttributes, int i2) {
        if (xMLAttributes.getType(i2).equals(SchemaSymbols.ATTVAL_ID)) {
            return xMLAttributes.getValue(i2);
        }
        return null;
    }

    public String getSchemaDeterminedID(XMLAttributes xMLAttributes, int i2) {
        AttributePSVI attributePSVI = (AttributePSVI) xMLAttributes.getAugmentations(i2).getItem(Constants.ATTRIBUTE_PSVI);
        if (attributePSVI == null) {
            return null;
        }
        XSTypeDefinition memberTypeDefinition = attributePSVI.getMemberTypeDefinition();
        if (memberTypeDefinition != null) {
            memberTypeDefinition = attributePSVI.getTypeDefinition();
        }
        if (memberTypeDefinition == null || !((XSSimpleType) memberTypeDefinition).isIDType()) {
            return null;
        }
        return attributePSVI.getSchemaNormalizedValue();
    }

    @Override // org.apache.xerces.xpointer.XPointerPart
    public String getSchemeData() {
        return null;
    }

    @Override // org.apache.xerces.xpointer.XPointerPart
    public String getSchemeName() {
        return this.fShortHandPointer;
    }

    @Override // org.apache.xerces.xpointer.XPointerPart
    public boolean isChildFragmentResolved() {
        return this.fIsFragmentResolved && this.fMatchingChildCount > 0;
    }

    @Override // org.apache.xerces.xpointer.XPointerPart
    public boolean isFragmentResolved() {
        return this.fIsFragmentResolved;
    }

    @Override // org.apache.xerces.xpointer.XPointerPart
    public void parseXPointer(String str) {
        this.fShortHandPointer = str;
        this.fIsFragmentResolved = false;
    }

    @Override // org.apache.xerces.xpointer.XPointerPart
    public boolean resolveXPointer(QName qName, XMLAttributes xMLAttributes, Augmentations augmentations, int i2) {
        int i3;
        if (this.fMatchingChildCount == 0) {
            this.fIsFragmentResolved = false;
        }
        if (i2 == 0) {
            if (this.fMatchingChildCount == 0) {
                this.fIsFragmentResolved = hasMatchingIdentifier(qName, xMLAttributes, augmentations, i2);
            }
            if (this.fIsFragmentResolved) {
                i3 = this.fMatchingChildCount + 1;
            }
            return this.fIsFragmentResolved;
        }
        if (i2 == 2) {
            if (this.fMatchingChildCount == 0) {
                this.fIsFragmentResolved = hasMatchingIdentifier(qName, xMLAttributes, augmentations, i2);
            }
        } else if (this.fIsFragmentResolved) {
            i3 = this.fMatchingChildCount - 1;
        }
        return this.fIsFragmentResolved;
        this.fMatchingChildCount = i3;
        return this.fIsFragmentResolved;
    }

    @Override // org.apache.xerces.xpointer.XPointerPart
    public void setSchemeData(String str) {
    }

    @Override // org.apache.xerces.xpointer.XPointerPart
    public void setSchemeName(String str) {
        this.fShortHandPointer = str;
    }
}
