package org.apache.xerces.xpointer;

import b.b.a.a.a;
import java.util.ArrayList;
import java.util.HashMap;
import org.apache.xerces.impl.XMLErrorReporter;
import org.apache.xerces.util.SymbolTable;
import org.apache.xerces.util.XMLChar;
import org.apache.xerces.util.XMLSymbols;
import org.apache.xerces.xinclude.XIncludeHandler;
import org.apache.xerces.xinclude.XIncludeNamespaceSupport;
import org.apache.xerces.xni.Augmentations;
import org.apache.xerces.xni.QName;
import org.apache.xerces.xni.XMLAttributes;
import org.apache.xerces.xni.XMLDocumentHandler;
import org.apache.xerces.xni.XMLString;
import org.apache.xerces.xni.XNIException;
import org.apache.xerces.xni.parser.XMLErrorHandler;

public final class XPointerHandler extends XIncludeHandler implements XPointerProcessor {
    public final String ELEMENT_SCHEME_NAME;
    public XMLErrorHandler fErrorHandler;
    public boolean fFixupBase;
    public boolean fFixupLang;
    public boolean fFoundMatchingPtrPart;
    public boolean fIsXPointerResolved;
    public SymbolTable fSymbolTable;
    public XMLErrorReporter fXPointerErrorReporter;
    public XPointerPart fXPointerPart;
    public ArrayList fXPointerParts;

    public class Scanner {
        public static final byte CHARTYPE_CARRET = 3;
        public static final byte CHARTYPE_CLOSE_PAREN = 5;
        public static final byte CHARTYPE_COLON = 10;
        public static final byte CHARTYPE_DIGIT = 9;
        public static final byte CHARTYPE_EQUAL = 11;
        public static final byte CHARTYPE_INVALID = 0;
        public static final byte CHARTYPE_LETTER = 12;
        public static final byte CHARTYPE_MINUS = 6;
        public static final byte CHARTYPE_NONASCII = 14;
        public static final byte CHARTYPE_OPEN_PAREN = 4;
        public static final byte CHARTYPE_OTHER = 1;
        public static final byte CHARTYPE_PERIOD = 7;
        public static final byte CHARTYPE_SLASH = 8;
        public static final byte CHARTYPE_UNDERSCORE = 13;
        public static final byte CHARTYPE_WHITESPACE = 2;
        public final byte[] fASCIICharMap;
        public SymbolTable fSymbolTable;

        public Scanner(SymbolTable symbolTable) {
            this.fASCIICharMap = new byte[]{0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 2, 0, 0, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, 1, 1, 1, 1, 1, 1, 4, 5, 1, 1, 1, 6, 7, 8, 9, 9, 9, 9, 9, 9, 9, 9, 9, 9, 10, 1, 1, 11, 1, 1, 1, 12, 12, 12, 12, 12, 12, 12, 12, 12, 12, 12, 12, 12, 12, 12, 12, 12, 12, 12, 12, 12, 12, 12, 12, 12, 12, 1, 1, 1, 3, 13, 1, 12, 12, 12, 12, 12, 12, 12, 12, 12, 12, 12, 12, 12, 12, 12, 12, 12, 12, 12, 12, 12, 12, 12, 12, 12, 12, 1, 1, 1, 1, 1};
            this.fSymbolTable = symbolTable;
        }

        private int scanData(String str, StringBuffer stringBuffer, int i2, int i3) {
            while (i3 != i2) {
                char charAt = str.charAt(i3);
                byte b2 = 14;
                byte b3 = charAt >= 128 ? 14 : this.fASCIICharMap[charAt];
                if (b3 != 4) {
                    if (b3 != 5) {
                        if (b3 == 3) {
                            i3++;
                            charAt = str.charAt(i3);
                            if (charAt < 128) {
                                b2 = this.fASCIICharMap[charAt];
                            }
                            if (!(b2 == 3 || b2 == 4 || b2 == 5)) {
                                break;
                            }
                        } else {
                            continue;
                        }
                    } else {
                        return i3;
                    }
                } else {
                    stringBuffer.append((int) charAt);
                    i3 = scanData(str, stringBuffer, i2, i3 + 1);
                    if (i3 == i2) {
                        return i3;
                    }
                    charAt = str.charAt(i3);
                    if (charAt < 128) {
                        b2 = this.fASCIICharMap[charAt];
                    }
                    if (b2 != 5) {
                        return i2;
                    }
                }
                stringBuffer.append((char) charAt);
                i3++;
            }
            return i3;
        }

        /* access modifiers changed from: private */
        /* access modifiers changed from: public */
        /* JADX WARNING: Code restructure failed: missing block: B:15:0x0028, code lost:
            return true;
         */
        /* JADX WARNING: Removed duplicated region for block: B:16:0x0029  */
        /* JADX WARNING: Removed duplicated region for block: B:62:0x0028 A[SYNTHETIC] */
        private boolean scanExpr(SymbolTable symbolTable, Tokens tokens, String str, int i2, int i3) {
            int i4;
            StringBuffer stringBuffer = new StringBuffer();
            String str2 = null;
            int i5 = 0;
            while (true) {
                int i6 = 0;
                while (i2 != i3) {
                    do {
                        char charAt = str.charAt(i2);
                        if (charAt == ' ' || charAt == '\n' || charAt == '\t' || charAt == '\r') {
                            i2++;
                        }
                        if (i2 == i3) {
                            switch (charAt >= 128 ? 14 : this.fASCIICharMap[charAt]) {
                                case 1:
                                case 2:
                                case 3:
                                case 6:
                                case 7:
                                case 8:
                                case 9:
                                case 10:
                                case 11:
                                case 12:
                                case 13:
                                case 14:
                                    if (i5 == 0) {
                                        int scanNCName = scanNCName(str, i3, i2);
                                        if (scanNCName == i2) {
                                            XPointerHandler.this.reportError("InvalidShortHandPointer", new Object[]{str});
                                            return false;
                                        }
                                        char charAt2 = scanNCName < i3 ? str.charAt(scanNCName) : 65535;
                                        String addSymbol = symbolTable.addSymbol(str.substring(i2, scanNCName));
                                        String str3 = XMLSymbols.EMPTY_STRING;
                                        if (charAt2 == ':') {
                                            int i7 = scanNCName + 1;
                                            if (i7 == i3) {
                                                return false;
                                            }
                                            str.charAt(i7);
                                            i4 = scanNCName(str, i3, i7);
                                            if (i4 == i7) {
                                                return false;
                                            }
                                            if (i4 < i3) {
                                                str.charAt(i4);
                                            }
                                            str2 = symbolTable.addSymbol(str.substring(i7, i4));
                                        } else {
                                            i4 = scanNCName;
                                            str2 = addSymbol;
                                            addSymbol = str3;
                                        }
                                        if (i4 != i3) {
                                            addToken(tokens, 3);
                                            tokens.addToken((Tokens) addSymbol);
                                        } else if (i4 == i3) {
                                            addToken(tokens, 2);
                                        } else {
                                            i2 = i4;
                                        }
                                        tokens.addToken((Tokens) str2);
                                        i2 = i4;
                                    } else if (i5 <= 0 || i6 != 0 || str2 == null) {
                                        return false;
                                    } else {
                                        int scanData = scanData(str, stringBuffer, i3, i2);
                                        if (scanData == i2) {
                                            XPointerHandler.this.reportError("InvalidSchemeDataInXPointer", new Object[]{str});
                                            return false;
                                        }
                                        if (scanData < i3) {
                                            str.charAt(scanData);
                                        }
                                        String addSymbol2 = symbolTable.addSymbol(stringBuffer.toString());
                                        addToken(tokens, 4);
                                        tokens.addToken((Tokens) addSymbol2);
                                        stringBuffer.delete(0, stringBuffer.length());
                                        i2 = scanData;
                                        i5 = 0;
                                    }
                                    break;
                                case 4:
                                    addToken(tokens, 0);
                                    i5++;
                                    i2++;
                                case 5:
                                    addToken(tokens, 1);
                                    i6++;
                                    i2++;
                            }
                        }
                    } while (i2 != i3);
                    if (i2 == i3) {
                    }
                }
            }
            return false;
        }

        private int scanNCName(String str, int i2, int i3) {
            char charAt = str.charAt(i3);
            if (charAt < 128) {
                byte b2 = this.fASCIICharMap[charAt];
                if (!(b2 == 12 || b2 == 13)) {
                    return i3;
                }
            } else if (!XMLChar.isNameStart(charAt)) {
                return i3;
            }
            while (true) {
                i3++;
                if (i3 >= i2) {
                    break;
                }
                char charAt2 = str.charAt(i3);
                if (charAt2 < 128) {
                    byte b3 = this.fASCIICharMap[charAt2];
                    if (!(b3 == 12 || b3 == 9 || b3 == 7 || b3 == 6 || b3 == 13)) {
                        break;
                    }
                } else if (!XMLChar.isName(charAt2)) {
                    break;
                }
            }
            return i3;
        }

        public void addToken(Tokens tokens, int i2) {
            tokens.addToken((Tokens) i2);
        }
    }

    public final class Tokens {
        public static final int INITIAL_TOKEN_COUNT = 256;
        public static final int XPTRTOKEN_CLOSE_PAREN = 1;
        public static final int XPTRTOKEN_OPEN_PAREN = 0;
        public static final int XPTRTOKEN_SCHEMEDATA = 4;
        public static final int XPTRTOKEN_SCHEMENAME = 3;
        public static final int XPTRTOKEN_SHORTHAND = 2;
        public int fCurrentTokenIndex;
        public SymbolTable fSymbolTable;
        public int fTokenCount;
        public HashMap fTokenNames;
        public int[] fTokens;
        public final String[] fgTokenNames;

        public Tokens(SymbolTable symbolTable) {
            this.fgTokenNames = new String[]{"XPTRTOKEN_OPEN_PAREN", "XPTRTOKEN_CLOSE_PAREN", "XPTRTOKEN_SHORTHAND", "XPTRTOKEN_SCHEMENAME", "XPTRTOKEN_SCHEMEDATA"};
            this.fTokens = new int[256];
            this.fTokenCount = 0;
            HashMap hashMap = new HashMap();
            this.fTokenNames = hashMap;
            this.fSymbolTable = symbolTable;
            hashMap.put(new Integer(0), "XPTRTOKEN_OPEN_PAREN");
            this.fTokenNames.put(new Integer(1), "XPTRTOKEN_CLOSE_PAREN");
            this.fTokenNames.put(new Integer(2), "XPTRTOKEN_SHORTHAND");
            this.fTokenNames.put(new Integer(3), "XPTRTOKEN_SCHEMENAME");
            this.fTokenNames.put(new Integer(4), "XPTRTOKEN_SCHEMEDATA");
        }

        /* access modifiers changed from: private */
        /* access modifiers changed from: public */
        private void addToken(int i2) {
            try {
                this.fTokens[this.fTokenCount] = i2;
            } catch (ArrayIndexOutOfBoundsException unused) {
                int[] iArr = this.fTokens;
                int i3 = this.fTokenCount;
                int[] iArr2 = new int[(i3 << 1)];
                this.fTokens = iArr2;
                System.arraycopy(iArr, 0, iArr2, 0, i3);
                this.fTokens[this.fTokenCount] = i2;
            }
            this.fTokenCount++;
        }

        /* access modifiers changed from: private */
        /* access modifiers changed from: public */
        private void addToken(String str) {
            Integer num = (Integer) this.fTokenNames.get(str);
            if (num == null) {
                num = new Integer(this.fTokenNames.size());
                this.fTokenNames.put(num, str);
            }
            addToken(num.intValue());
        }

        /* access modifiers changed from: private */
        /* access modifiers changed from: public */
        private String getTokenString(int i2) {
            return (String) this.fTokenNames.get(new Integer(i2));
        }

        /* access modifiers changed from: private */
        /* access modifiers changed from: public */
        private boolean hasMore() {
            return this.fCurrentTokenIndex < this.fTokenCount;
        }

        /* access modifiers changed from: private */
        /* access modifiers changed from: public */
        private int nextToken() {
            if (this.fCurrentTokenIndex == this.fTokenCount) {
                XPointerHandler.this.reportError("XPointerProcessingError", null);
            }
            int[] iArr = this.fTokens;
            int i2 = this.fCurrentTokenIndex;
            this.fCurrentTokenIndex = i2 + 1;
            return iArr[i2];
        }

        private String nextTokenAsString() {
            String tokenString = getTokenString(nextToken());
            if (tokenString == null) {
                XPointerHandler.this.reportError("XPointerProcessingError", null);
            }
            return tokenString;
        }

        /* access modifiers changed from: private */
        /* access modifiers changed from: public */
        private int peekToken() {
            if (this.fCurrentTokenIndex == this.fTokenCount) {
                XPointerHandler.this.reportError("XPointerProcessingError", null);
            }
            return this.fTokens[this.fCurrentTokenIndex];
        }

        private void rewind() {
            this.fCurrentTokenIndex = 0;
        }
    }

    public XPointerHandler() {
        this.fXPointerParts = null;
        this.fXPointerPart = null;
        this.fFoundMatchingPtrPart = false;
        this.fSymbolTable = null;
        this.ELEMENT_SCHEME_NAME = "element";
        this.fIsXPointerResolved = false;
        this.fFixupBase = false;
        this.fFixupLang = false;
        this.fXPointerParts = new ArrayList();
        this.fSymbolTable = new SymbolTable();
    }

    public XPointerHandler(SymbolTable symbolTable, XMLErrorHandler xMLErrorHandler, XMLErrorReporter xMLErrorReporter) {
        this.fXPointerParts = null;
        this.fXPointerPart = null;
        this.fFoundMatchingPtrPart = false;
        this.fSymbolTable = null;
        this.ELEMENT_SCHEME_NAME = "element";
        this.fIsXPointerResolved = false;
        this.fFixupBase = false;
        this.fFixupLang = false;
        this.fXPointerParts = new ArrayList();
        this.fSymbolTable = symbolTable;
        this.fErrorHandler = xMLErrorHandler;
        this.fXPointerErrorReporter = xMLErrorReporter;
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private void reportError(String str, Object[] objArr) {
        throw new XNIException(this.fErrorReporter.getMessageFormatter(XPointerMessageFormatter.XPOINTER_DOMAIN).formatMessage(this.fErrorReporter.getLocale(), str, objArr));
    }

    private void reportWarning(String str, Object[] objArr) {
        this.fXPointerErrorReporter.reportError(XPointerMessageFormatter.XPOINTER_DOMAIN, str, objArr, 0);
    }

    @Override // org.apache.xerces.xni.XMLDocumentHandler, org.apache.xerces.xinclude.XIncludeHandler
    public void characters(XMLString xMLString, Augmentations augmentations) {
        if (isChildFragmentResolved()) {
            super.characters(xMLString, augmentations);
        }
    }

    @Override // org.apache.xerces.xni.XMLDocumentHandler, org.apache.xerces.xni.XMLDTDHandler, org.apache.xerces.xinclude.XIncludeHandler
    public void comment(XMLString xMLString, Augmentations augmentations) {
        if (isChildFragmentResolved()) {
            super.comment(xMLString, augmentations);
        }
    }

    @Override // org.apache.xerces.xni.XMLDocumentHandler, org.apache.xerces.xinclude.XIncludeHandler
    public void emptyElement(QName qName, XMLAttributes xMLAttributes, Augmentations augmentations) {
        if (!resolveXPointer(qName, xMLAttributes, augmentations, 2)) {
            if (this.fFixupBase) {
                processXMLBaseAttributes(xMLAttributes);
            }
            if (this.fFixupLang) {
                processXMLLangAttributes(xMLAttributes);
            }
            this.fNamespaceContext.setContextInvalid();
            return;
        }
        super.emptyElement(qName, xMLAttributes, augmentations);
    }

    @Override // org.apache.xerces.xni.XMLDocumentHandler, org.apache.xerces.xinclude.XIncludeHandler
    public void endCDATA(Augmentations augmentations) {
        if (isChildFragmentResolved()) {
            super.endCDATA(augmentations);
        }
    }

    @Override // org.apache.xerces.xni.XMLDocumentHandler, org.apache.xerces.xinclude.XIncludeHandler
    public void endElement(QName qName, Augmentations augmentations) {
        if (resolveXPointer(qName, null, augmentations, 1)) {
            super.endElement(qName, augmentations);
        }
    }

    public ArrayList getPointerParts() {
        return this.fXPointerParts;
    }

    public XPointerPart getXPointerPart() {
        return this.fXPointerPart;
    }

    @Override // org.apache.xerces.xni.XMLDocumentHandler, org.apache.xerces.xinclude.XIncludeHandler
    public void ignorableWhitespace(XMLString xMLString, Augmentations augmentations) {
        if (isChildFragmentResolved()) {
            super.ignorableWhitespace(xMLString, augmentations);
        }
    }

    public void init() {
        this.fXPointerParts.clear();
        this.fXPointerPart = null;
        this.fFoundMatchingPtrPart = false;
        this.fIsXPointerResolved = false;
        initErrorReporter();
    }

    public void initErrorReporter() {
        if (this.fXPointerErrorReporter == null) {
            this.fXPointerErrorReporter = new XMLErrorReporter();
        }
        if (this.fErrorHandler == null) {
            this.fErrorHandler = new XPointerErrorHandler();
        }
        this.fXPointerErrorReporter.putMessageFormatter(XPointerMessageFormatter.XPOINTER_DOMAIN, new XPointerMessageFormatter());
    }

    public boolean isChildFragmentResolved() {
        XPointerPart xPointerPart = this.fXPointerPart;
        if (xPointerPart != null) {
            return xPointerPart.isChildFragmentResolved();
        }
        return false;
    }

    @Override // org.apache.xerces.xpointer.XPointerProcessor
    public boolean isFragmentResolved() {
        XPointerPart xPointerPart = this.fXPointerPart;
        boolean isFragmentResolved = xPointerPart != null ? xPointerPart.isFragmentResolved() : false;
        if (!this.fIsXPointerResolved) {
            this.fIsXPointerResolved = isFragmentResolved;
        }
        return isFragmentResolved;
    }

    @Override // org.apache.xerces.xpointer.XPointerProcessor
    public boolean isXPointerResolved() {
        return this.fIsXPointerResolved;
    }

    @Override // org.apache.xerces.xpointer.XPointerProcessor
    public void parseXPointer(String str) {
        init();
        Tokens tokens = new Tokens(this.fSymbolTable);
        if (!new Scanner(this, this.fSymbolTable) {
            /* class org.apache.xerces.xpointer.XPointerHandler.AnonymousClass1 */
            public final /* synthetic */ XPointerHandler this$0;

            {
                this.this$0 = r2;
            }

            @Override // org.apache.xerces.xpointer.XPointerHandler.Scanner
            public void addToken(Tokens tokens, int i2) {
                if (i2 == 0 || i2 == 1 || i2 == 3 || i2 == 4 || i2 == 2) {
                    super.addToken(tokens, i2);
                    return;
                }
                this.this$0.reportError("InvalidXPointerToken", new Object[]{tokens.getTokenString(i2)});
            }
        }.scanExpr(this.fSymbolTable, tokens, str, 0, str.length())) {
            reportError("InvalidXPointerExpression", new Object[]{str});
        }
        while (tokens.hasMore()) {
            int nextToken = tokens.nextToken();
            if (nextToken == 2) {
                String tokenString = tokens.getTokenString(tokens.nextToken());
                if (tokenString == null) {
                    reportError("InvalidXPointerExpression", new Object[]{str});
                }
                ShortHandPointer shortHandPointer = new ShortHandPointer(this.fSymbolTable);
                shortHandPointer.setSchemeName(tokenString);
                this.fXPointerParts.add(shortHandPointer);
            } else if (nextToken != 3) {
                reportError("InvalidXPointerExpression", new Object[]{str});
            } else {
                String a = a.a(tokens.getTokenString(tokens.nextToken()), tokens.getTokenString(tokens.nextToken()));
                int nextToken2 = tokens.nextToken();
                if (tokens.getTokenString(nextToken2) != "XPTRTOKEN_OPEN_PAREN") {
                    if (nextToken2 == 2) {
                        reportError("MultipleShortHandPointers", new Object[]{str});
                    } else {
                        reportError("InvalidXPointerExpression", new Object[]{str});
                    }
                }
                int i2 = 1;
                while (tokens.hasMore() && tokens.getTokenString(tokens.nextToken()) == "XPTRTOKEN_OPEN_PAREN") {
                    i2++;
                }
                String tokenString2 = tokens.getTokenString(tokens.nextToken());
                if (tokens.getTokenString(tokens.nextToken()) != "XPTRTOKEN_CLOSE_PAREN") {
                    reportError("SchemeDataNotFollowedByCloseParenthesis", new Object[]{str});
                }
                int i3 = 1;
                while (tokens.hasMore() && tokens.getTokenString(tokens.peekToken()) == "XPTRTOKEN_OPEN_PAREN") {
                    i3++;
                }
                if (i2 != i3) {
                    reportError("UnbalancedParenthesisInXPointerExpression", new Object[]{str, new Integer(i2), new Integer(i3)});
                }
                if (a.equals("element")) {
                    ElementSchemePointer elementSchemePointer = new ElementSchemePointer(this.fSymbolTable, this.fErrorReporter);
                    elementSchemePointer.setSchemeName(a);
                    elementSchemePointer.setSchemeData(tokenString2);
                    try {
                        elementSchemePointer.parseXPointer(tokenString2);
                        this.fXPointerParts.add(elementSchemePointer);
                    } catch (XNIException e2) {
                        throw new XNIException(e2);
                    }
                } else {
                    reportWarning("SchemeUnsupported", new Object[]{a});
                }
            }
        }
    }

    @Override // org.apache.xerces.xni.XMLDocumentHandler, org.apache.xerces.xni.XMLDTDHandler, org.apache.xerces.xinclude.XIncludeHandler
    public void processingInstruction(String str, XMLString xMLString, Augmentations augmentations) {
        if (isChildFragmentResolved()) {
            super.processingInstruction(str, xMLString, augmentations);
        }
    }

    @Override // org.apache.xerces.xpointer.XPointerProcessor
    public boolean resolveXPointer(QName qName, XMLAttributes xMLAttributes, Augmentations augmentations, int i2) {
        boolean z = false;
        if (!this.fFoundMatchingPtrPart) {
            boolean z2 = false;
            for (int i3 = 0; i3 < this.fXPointerParts.size(); i3++) {
                XPointerPart xPointerPart = (XPointerPart) this.fXPointerParts.get(i3);
                this.fXPointerPart = xPointerPart;
                if (xPointerPart.resolveXPointer(qName, xMLAttributes, augmentations, i2)) {
                    this.fFoundMatchingPtrPart = true;
                    z2 = true;
                }
            }
            z = z2;
        } else if (this.fXPointerPart.resolveXPointer(qName, xMLAttributes, augmentations, i2)) {
            z = true;
        }
        if (!this.fIsXPointerResolved) {
            this.fIsXPointerResolved = z;
        }
        return z;
    }

    @Override // org.apache.xerces.xni.parser.XMLDocumentSource, org.apache.xerces.xinclude.XIncludeHandler
    public void setDocumentHandler(XMLDocumentHandler xMLDocumentHandler) {
        this.fDocumentHandler = xMLDocumentHandler;
    }

    @Override // org.apache.xerces.xni.parser.XMLComponent, org.apache.xerces.xinclude.XIncludeHandler
    public void setProperty(String str, Object obj) {
        XMLErrorHandler xMLErrorHandler = null;
        if (str == "http://apache.org/xml/properties/internal/error-reporter") {
            if (obj != null) {
                this.fXPointerErrorReporter = (XMLErrorReporter) obj;
            } else {
                this.fXPointerErrorReporter = null;
            }
        }
        if (str == "http://apache.org/xml/properties/internal/error-handler") {
            if (obj != null) {
                xMLErrorHandler = (XMLErrorHandler) obj;
            }
            this.fErrorHandler = xMLErrorHandler;
        }
        boolean z = false;
        if (str == "http://apache.org/xml/features/xinclude/fixup-language") {
            if (obj != null) {
                this.fFixupLang = ((Boolean) obj).booleanValue();
            } else {
                this.fFixupLang = false;
            }
        }
        if (str == "http://apache.org/xml/features/xinclude/fixup-base-uris") {
            if (obj != null) {
                z = ((Boolean) obj).booleanValue();
            }
            this.fFixupBase = z;
        }
        if (str == "http://apache.org/xml/properties/internal/namespace-context") {
            this.fNamespaceContext = (XIncludeNamespaceSupport) obj;
        }
        super.setProperty(str, obj);
    }

    @Override // org.apache.xerces.xni.XMLDocumentHandler, org.apache.xerces.xinclude.XIncludeHandler
    public void startCDATA(Augmentations augmentations) {
        if (isChildFragmentResolved()) {
            super.startCDATA(augmentations);
        }
    }

    @Override // org.apache.xerces.xni.XMLDocumentHandler, org.apache.xerces.xinclude.XIncludeHandler
    public void startElement(QName qName, XMLAttributes xMLAttributes, Augmentations augmentations) {
        if (!resolveXPointer(qName, xMLAttributes, augmentations, 0)) {
            if (this.fFixupBase) {
                processXMLBaseAttributes(xMLAttributes);
            }
            if (this.fFixupLang) {
                processXMLLangAttributes(xMLAttributes);
            }
            this.fNamespaceContext.setContextInvalid();
            return;
        }
        super.startElement(qName, xMLAttributes, augmentations);
    }
}
