package org.apache.xmlbeans;

import java.io.Serializable;
import java.math.BigDecimal;

public final class GDuration implements GDurationSpecification, Serializable {
    public static final int SEEN_DAY = 3;
    public static final int SEEN_HOUR = 4;
    public static final int SEEN_MINUTE = 5;
    public static final int SEEN_MONTH = 2;
    public static final int SEEN_NOTHING = 0;
    public static final int SEEN_SECOND = 6;
    public static final int SEEN_YEAR = 1;
    public static final long serialVersionUID = 1;
    public int _CY;
    public int _D;
    public int _M;
    public BigDecimal _fs;
    public int _h;
    public int _m;
    public int _s;
    public int _sign;

    public GDuration() {
        this._sign = 1;
        this._fs = GDate._zero;
    }

    private GDuration _add(GDurationSpecification gDurationSpecification, int i2) {
        GDuration gDuration = new GDuration(this);
        gDuration._CY = (gDurationSpecification.getYear() * i2) + gDuration._CY;
        gDuration._M = (gDurationSpecification.getMonth() * i2) + gDuration._M;
        gDuration._D = (gDurationSpecification.getDay() * i2) + gDuration._D;
        gDuration._h = (gDurationSpecification.getHour() * i2) + gDuration._h;
        gDuration._m = (gDurationSpecification.getMinute() * i2) + gDuration._m;
        gDuration._s = (gDurationSpecification.getSecond() * i2) + gDuration._s;
        if (gDurationSpecification.getFraction().signum() == 0) {
            return gDuration;
        }
        if (gDuration._fs.signum() == 0 && i2 == 1) {
            gDuration._fs = gDurationSpecification.getFraction();
        } else {
            gDuration._fs = i2 > 0 ? gDuration._fs.add(gDurationSpecification.getFraction()) : gDuration._fs.subtract(gDurationSpecification.getFraction());
        }
        return gDuration;
    }

    public GDuration add(GDurationSpecification gDurationSpecification) {
        return _add(gDurationSpecification, gDurationSpecification.getSign() * this._sign);
    }

    @Override // java.lang.Object
    public Object clone() {
        return new GDuration(this);
    }

    @Override // org.apache.xmlbeans.GDurationSpecification
    public final int compareToGDuration(GDurationSpecification gDurationSpecification) {
        return GDurationBuilder.compareDurations(this, gDurationSpecification);
    }

    public boolean equals(Object obj) {
        if (obj == this) {
            return true;
        }
        if (!(obj instanceof GDuration)) {
            return false;
        }
        GDuration gDuration = (GDuration) obj;
        if (this._sign == gDuration.getSign() && this._CY == gDuration.getYear() && this._M == gDuration.getMonth() && this._D == gDuration.getDay() && this._h == gDuration.getHour() && this._m == gDuration.getMinute() && this._s == gDuration.getSecond() && this._fs.equals(gDuration.getFraction())) {
            return true;
        }
        return false;
    }

    @Override // org.apache.xmlbeans.GDurationSpecification
    public final int getDay() {
        return this._D;
    }

    @Override // org.apache.xmlbeans.GDurationSpecification
    public BigDecimal getFraction() {
        return this._fs;
    }

    @Override // org.apache.xmlbeans.GDurationSpecification
    public final int getHour() {
        return this._h;
    }

    @Override // org.apache.xmlbeans.GDurationSpecification
    public final int getMinute() {
        return this._m;
    }

    @Override // org.apache.xmlbeans.GDurationSpecification
    public final int getMonth() {
        return this._M;
    }

    @Override // org.apache.xmlbeans.GDurationSpecification
    public final int getSecond() {
        return this._s;
    }

    @Override // org.apache.xmlbeans.GDurationSpecification
    public final int getSign() {
        return this._sign;
    }

    @Override // org.apache.xmlbeans.GDurationSpecification
    public final int getYear() {
        return this._CY;
    }

    public int hashCode() {
        return (this._sign * 11917049) + (this._CY * 32140807) + (this._M * 2678407) + (this._D * 86407) + (this._h * 3607) + (this._m * 67) + this._s;
    }

    @Override // org.apache.xmlbeans.GDurationSpecification
    public final boolean isImmutable() {
        return true;
    }

    @Override // org.apache.xmlbeans.GDurationSpecification
    public boolean isValid() {
        return GDurationBuilder.isValidDuration(this);
    }

    public GDuration subtract(GDurationSpecification gDurationSpecification) {
        return _add(gDurationSpecification, gDurationSpecification.getSign() * (-this._sign));
    }

    public String toString() {
        return GDurationBuilder.formatDuration(this);
    }

    /* JADX WARNING: Removed duplicated region for block: B:104:0x0124 A[SYNTHETIC] */
    /* JADX WARNING: Removed duplicated region for block: B:69:0x00f1  */
    /* JADX WARNING: Removed duplicated region for block: B:72:0x00f9  */
    /* JADX WARNING: Removed duplicated region for block: B:77:0x0107  */
    /* JADX WARNING: Removed duplicated region for block: B:82:0x0115  */
    public GDuration(CharSequence charSequence) {
        char charAt;
        int length = charSequence.length();
        while (length > 0 && GDate.isSpace(charSequence.charAt(length - 1))) {
            length--;
        }
        int i2 = 0;
        while (i2 < length && GDate.isSpace(charSequence.charAt(i2))) {
            i2++;
        }
        this._sign = 1;
        if (i2 < length && charSequence.charAt(i2) == '-') {
            this._sign = -1;
            i2++;
        }
        if (i2 >= length || charSequence.charAt(i2) != 'P') {
            throw new IllegalArgumentException("duration must begin with P");
        }
        int i3 = i2 + 1;
        this._fs = GDate._zero;
        char c = 0;
        boolean z = false;
        while (i3 < length) {
            char charAt2 = charSequence.charAt(i3);
            if (charAt2 == 'T') {
                if (z) {
                    throw new IllegalArgumentException("duration must have no more than one T'");
                } else if (c <= 3) {
                    i3++;
                    if (i3 < length) {
                        charAt2 = charSequence.charAt(i3);
                        c = 3;
                        z = true;
                    } else {
                        throw new IllegalArgumentException("illegal duration");
                    }
                } else {
                    throw new IllegalArgumentException("T in duration must precede time fields");
                }
            }
            if (GDate.isDigit(charAt2)) {
                int digitVal = GDate.digitVal(charAt2);
                while (true) {
                    i3++;
                    charAt = i3 < length ? charSequence.charAt(i3) : 0;
                    if (!GDate.isDigit(charAt)) {
                        break;
                    }
                    digitVal = (digitVal * 10) + GDate.digitVal(charAt);
                }
                if (charAt == '.') {
                    int i4 = i3;
                    do {
                        i4++;
                        if (i4 >= length) {
                            break;
                        }
                        charAt = charSequence.charAt(i4);
                    } while (GDate.isDigit(charAt));
                    this._fs = new BigDecimal(charSequence.subSequence(i3, i4).toString());
                    if (i4 >= length || charAt != 'S') {
                        throw new IllegalArgumentException("illegal duration");
                    }
                    i3 = i4;
                }
                if (c != 0) {
                    if (c != 1) {
                        if (c != 2) {
                            if (c != 3) {
                                if (c != 4) {
                                    if (c != 5) {
                                        throw new IllegalArgumentException("duration must specify Y M D T H M S in order");
                                    }
                                    if (charAt != 'S') {
                                        throw new IllegalArgumentException("duration must specify Y M D T H M S in order");
                                    } else if (z) {
                                        this._s = digitVal;
                                        c = 6;
                                        i3++;
                                    } else {
                                        throw new IllegalArgumentException("time in duration must follow T");
                                    }
                                }
                                if (charAt == 'M') {
                                    if (z) {
                                        this._m = digitVal;
                                        c = 5;
                                        i3++;
                                    } else {
                                        throw new IllegalArgumentException("time in duration must follow T");
                                    }
                                }
                                if (charAt != 'S') {
                                }
                            }
                            if (charAt == 'H') {
                                if (z) {
                                    this._h = digitVal;
                                    c = 4;
                                    i3++;
                                } else {
                                    throw new IllegalArgumentException("time in duration must follow T");
                                }
                            }
                            if (charAt == 'M') {
                            }
                            if (charAt != 'S') {
                            }
                        }
                        if (charAt == 'D') {
                            this._D = digitVal;
                            c = 3;
                            i3++;
                        }
                        if (charAt == 'H') {
                        }
                        if (charAt == 'M') {
                        }
                        if (charAt != 'S') {
                        }
                    }
                } else if (charAt == 'Y') {
                    this._CY = digitVal;
                    c = 1;
                    i3++;
                }
                if (charAt == 'M') {
                    this._M = digitVal;
                    c = 2;
                    i3++;
                }
                if (charAt == 'D') {
                }
                if (charAt == 'H') {
                }
                if (charAt == 'M') {
                }
                if (charAt != 'S') {
                }
            } else {
                StringBuffer stringBuffer = new StringBuffer();
                stringBuffer.append("illegal duration at char[");
                stringBuffer.append(i3);
                stringBuffer.append("]: '");
                stringBuffer.append(charAt2);
                stringBuffer.append("'");
                throw new IllegalArgumentException(stringBuffer.toString());
            }
        }
        if (c == 0) {
            StringBuffer stringBuffer2 = new StringBuffer();
            stringBuffer2.append("duration must contain at least one number and its designator: ");
            stringBuffer2.append((Object) charSequence);
            throw new IllegalArgumentException(stringBuffer2.toString());
        }
    }

    public GDuration(int i2, int i3, int i4, int i5, int i6, int i7, int i8, BigDecimal bigDecimal) {
        if (i2 == 1 || i2 == -1) {
            this._sign = i2;
            this._CY = i3;
            this._M = i4;
            this._D = i5;
            this._h = i6;
            this._m = i7;
            this._s = i8;
            this._fs = bigDecimal == null ? GDate._zero : bigDecimal;
            return;
        }
        throw new IllegalArgumentException();
    }

    public GDuration(GDurationSpecification gDurationSpecification) {
        this._sign = gDurationSpecification.getSign();
        this._CY = gDurationSpecification.getYear();
        this._M = gDurationSpecification.getMonth();
        this._D = gDurationSpecification.getDay();
        this._h = gDurationSpecification.getHour();
        this._m = gDurationSpecification.getMinute();
        this._s = gDurationSpecification.getSecond();
        this._fs = gDurationSpecification.getFraction();
    }
}
