package org.apache.xmlbeans;

import b.b.a.a.a;
import java.io.Serializable;
import java.util.Arrays;
import java.util.Collections;
import java.util.HashSet;
import java.util.Set;
import org.apache.poi.javax.xml.namespace.QName;
import org.apache.poi.ss.formula.ptg.UnaryMinusPtg;

public final class QNameSet implements QNameSetSpecification, Serializable {
    public static final QNameSet ALL;
    public static final QNameSet EMPTY;
    public static final QNameSet LOCAL;
    public static final QNameSet NONLOCAL;
    public static final long serialVersionUID = 1;
    public final Set _excludedQNames;
    public final Set _includedQNames;
    public final Set _includedURIs;
    public final boolean _inverted;

    static {
        Set set = Collections.EMPTY_SET;
        EMPTY = new QNameSet(null, set, set, set);
        Set set2 = Collections.EMPTY_SET;
        ALL = new QNameSet(set2, null, set2, set2);
        Set singleton = Collections.singleton("");
        Set set3 = Collections.EMPTY_SET;
        LOCAL = new QNameSet(null, singleton, set3, set3);
        Set singleton2 = Collections.singleton("");
        Set set4 = Collections.EMPTY_SET;
        NONLOCAL = new QNameSet(singleton2, null, set4, set4);
    }

    public QNameSet(Set set, Set set2, Set set3, Set set4) {
        if (set2 != null && set == null) {
            this._inverted = false;
            this._includedURIs = set2;
            this._excludedQNames = set3;
            this._includedQNames = set4;
        } else if (set == null || set2 != null) {
            throw new IllegalArgumentException("Exactly one of excludedURIs and includedURIs must be null");
        } else {
            this._inverted = true;
            this._includedURIs = set;
            this._excludedQNames = set4;
            this._includedQNames = set3;
        }
    }

    public static QNameSet forArray(QName[] qNameArr) {
        if (qNameArr != null) {
            Set set = Collections.EMPTY_SET;
            return new QNameSet(null, set, set, new HashSet(Arrays.asList(qNameArr)));
        }
        throw new IllegalArgumentException("includedQNames cannot be null");
    }

    public static QNameSet forSets(Set set, Set set2, Set set3, Set set4) {
        boolean z = false;
        boolean z2 = set != null;
        if (set2 != null) {
            z = true;
        }
        if (z2 == z) {
            throw new IllegalArgumentException("Exactly one of excludedURIs and includedURIs must be null");
        } else if (set == null && set2.isEmpty() && set4.isEmpty()) {
            return EMPTY;
        } else {
            if (set2 == null && set.isEmpty() && set3.isEmpty()) {
                return ALL;
            }
            if (set == null && set2.size() == 1 && set2.contains("") && set4.isEmpty() && set3.isEmpty()) {
                return LOCAL;
            }
            if (set2 != null || set.size() != 1 || !set.contains("") || !set3.isEmpty() || !set4.isEmpty()) {
                return new QNameSet(minSetCopy(set), minSetCopy(set2), minSetCopy(set3), minSetCopy(set4));
            }
            return NONLOCAL;
        }
    }

    public static QNameSet forSpecification(QNameSetSpecification qNameSetSpecification) {
        if (qNameSetSpecification instanceof QNameSet) {
            return (QNameSet) qNameSetSpecification;
        }
        return forSets(qNameSetSpecification.excludedURIs(), qNameSetSpecification.includedURIs(), qNameSetSpecification.excludedQNamesInIncludedURIs(), qNameSetSpecification.includedQNamesInExcludedURIs());
    }

    public static QNameSet forWildcardNamespaceString(String str, String str2) {
        return forSpecification(new QNameSetBuilder(str, str2));
    }

    private boolean isDisjointImpl(QNameSetSpecification qNameSetSpecification, QNameSetSpecification qNameSetSpecification2) {
        Set<Object> includedURIs = qNameSetSpecification.includedURIs();
        Set includedURIs2 = qNameSetSpecification2.includedURIs();
        if (includedURIs2 != null) {
            for (Object obj : includedURIs) {
                if (includedURIs2.contains(obj)) {
                    return false;
                }
            }
        } else {
            Set excludedURIs = qNameSetSpecification2.excludedURIs();
            for (Object obj2 : includedURIs) {
                if (!excludedURIs.contains(obj2)) {
                    return false;
                }
            }
        }
        for (QName qName : qNameSetSpecification.includedQNamesInExcludedURIs()) {
            if (qNameSetSpecification2.contains(qName)) {
                return false;
            }
        }
        if (includedURIs.size() <= 0) {
            return true;
        }
        for (QName qName2 : qNameSetSpecification2.includedQNamesInExcludedURIs()) {
            if (qNameSetSpecification.contains(qName2)) {
                return false;
            }
        }
        return true;
    }

    public static Set minSetCopy(Set set) {
        if (set == null) {
            return null;
        }
        if (set.isEmpty()) {
            return Collections.EMPTY_SET;
        }
        if (set.size() == 1) {
            return Collections.singleton(set.iterator().next());
        }
        return new HashSet(set);
    }

    public static String nsFromName(QName qName) {
        String namespaceURI = qName.getNamespaceURI();
        return namespaceURI == null ? "" : namespaceURI;
    }

    private String prettyQName(QName qName) {
        if (qName.getNamespaceURI() == null) {
            return qName.getLocalPart();
        }
        StringBuffer stringBuffer = new StringBuffer();
        stringBuffer.append(qName.getLocalPart());
        stringBuffer.append("@");
        stringBuffer.append(qName.getNamespaceURI());
        return stringBuffer.toString();
    }

    public static QNameSet singleton(QName qName) {
        Set set = Collections.EMPTY_SET;
        return new QNameSet(null, set, set, Collections.singleton(qName));
    }

    @Override // org.apache.xmlbeans.QNameSetSpecification
    public boolean contains(QName qName) {
        return (this._includedURIs.contains(nsFromName(qName)) ? !this._excludedQNames.contains(qName) : this._includedQNames.contains(qName)) ^ this._inverted;
    }

    @Override // org.apache.xmlbeans.QNameSetSpecification
    public boolean containsAll(QNameSetSpecification qNameSetSpecification) {
        if (this._inverted || qNameSetSpecification.excludedURIs() == null) {
            return inverse().isDisjoint(qNameSetSpecification);
        }
        return false;
    }

    @Override // org.apache.xmlbeans.QNameSetSpecification
    public Set excludedQNamesInIncludedURIs() {
        return Collections.unmodifiableSet(this._inverted ? this._includedQNames : this._excludedQNames);
    }

    @Override // org.apache.xmlbeans.QNameSetSpecification
    public Set excludedURIs() {
        if (this._inverted) {
            return Collections.unmodifiableSet(this._includedURIs);
        }
        return null;
    }

    @Override // org.apache.xmlbeans.QNameSetSpecification
    public Set includedQNamesInExcludedURIs() {
        return Collections.unmodifiableSet(this._inverted ? this._excludedQNames : this._includedQNames);
    }

    @Override // org.apache.xmlbeans.QNameSetSpecification
    public Set includedURIs() {
        if (!this._inverted) {
            return this._includedURIs;
        }
        return null;
    }

    @Override // org.apache.xmlbeans.QNameSetSpecification
    public QNameSet intersect(QNameSetSpecification qNameSetSpecification) {
        QNameSetBuilder qNameSetBuilder = new QNameSetBuilder(this);
        qNameSetBuilder.restrict(qNameSetSpecification);
        return qNameSetBuilder.toQNameSet();
    }

    @Override // org.apache.xmlbeans.QNameSetSpecification
    public QNameSet inverse() {
        QNameSet qNameSet = EMPTY;
        if (this == qNameSet) {
            return ALL;
        }
        if (this == ALL) {
            return qNameSet;
        }
        QNameSet qNameSet2 = LOCAL;
        if (this == qNameSet2) {
            return NONLOCAL;
        }
        if (this == NONLOCAL) {
            return qNameSet2;
        }
        return new QNameSet(includedURIs(), excludedURIs(), includedQNamesInExcludedURIs(), excludedQNamesInIncludedURIs());
    }

    @Override // org.apache.xmlbeans.QNameSetSpecification
    public boolean isAll() {
        return this._inverted && this._includedURIs.isEmpty() && this._includedQNames.isEmpty();
    }

    @Override // org.apache.xmlbeans.QNameSetSpecification
    public boolean isDisjoint(QNameSetSpecification qNameSetSpecification) {
        if (this._inverted && qNameSetSpecification.excludedURIs() != null) {
            return false;
        }
        if (this._inverted) {
            return isDisjointImpl(qNameSetSpecification, this);
        }
        return isDisjointImpl(this, qNameSetSpecification);
    }

    @Override // org.apache.xmlbeans.QNameSetSpecification
    public boolean isEmpty() {
        return !this._inverted && this._includedURIs.isEmpty() && this._includedQNames.isEmpty();
    }

    public String toString() {
        StringBuffer a = a.a("QNameSet");
        a.append(this._inverted ? "-(" : "+(");
        for (Object obj : this._includedURIs) {
            a.append("+*@");
            a.append(obj);
            a.append(", ");
        }
        for (QName qName : this._excludedQNames) {
            a.append(UnaryMinusPtg.MINUS);
            a.append(prettyQName(qName));
            a.append(", ");
        }
        for (QName qName2 : this._includedQNames) {
            a.append("+");
            a.append(prettyQName(qName2));
            a.append(", ");
        }
        int lastIndexOf = a.lastIndexOf(", ");
        if (lastIndexOf > 0) {
            a.setLength(lastIndexOf);
        }
        a.append(')');
        return a.toString();
    }

    @Override // org.apache.xmlbeans.QNameSetSpecification
    public QNameSet union(QNameSetSpecification qNameSetSpecification) {
        QNameSetBuilder qNameSetBuilder = new QNameSetBuilder(this);
        qNameSetBuilder.addAll(qNameSetSpecification);
        return qNameSetBuilder.toQNameSet();
    }
}
