package org.apache.xmlbeans;

import b.b.a.a.a;
import java.io.Serializable;
import java.util.ArrayList;
import java.util.Collections;
import java.util.HashSet;
import java.util.Iterator;
import java.util.Set;
import org.apache.poi.javax.xml.namespace.QName;
import org.apache.poi.ss.formula.ptg.UnaryMinusPtg;
import org.apache.xerces.impl.xs.SchemaSymbols;

public class QNameSetBuilder implements QNameSetSpecification, Serializable {
    public static final String[] EMPTY_STRINGARRAY = new String[0];
    public static final long serialVersionUID = 1;
    public Set _excludedQNames;
    public Set _includedQNames;
    public Set _includedURIs;
    public boolean _inverted;

    public QNameSetBuilder() {
        this._inverted = false;
        this._includedURIs = new HashSet();
        this._excludedQNames = new HashSet();
        this._includedQNames = new HashSet();
    }

    private void addAllImpl(Set set, Set set2, Set set3, Set set4) {
        boolean z = set2 != null;
        Set set5 = z ? set2 : set;
        Iterator it = this._excludedQNames.iterator();
        while (it.hasNext()) {
            QName qName = (QName) it.next();
            if ((set5.contains(nsFromName(qName)) ^ z) && !set4.contains(qName)) {
                it.remove();
            }
        }
        Iterator it2 = set4.iterator();
        while (it2.hasNext()) {
            QName qName2 = (QName) it2.next();
            if (!this._includedURIs.contains(nsFromName(qName2)) && !this._includedQNames.contains(qName2)) {
                this._excludedQNames.add(qName2);
            }
        }
        Iterator it3 = set3.iterator();
        while (it3.hasNext()) {
            QName qName3 = (QName) it3.next();
            if (!this._includedURIs.contains(nsFromName(qName3))) {
                this._includedQNames.add(qName3);
            } else {
                this._excludedQNames.remove(qName3);
            }
        }
        if (!z) {
            removeAllMatchingFirstOnly(set, this._includedURIs, this._includedQNames);
            this._includedURIs.addAll(set);
            return;
        }
        removeAllMatchingNeither(set2, this._includedURIs, this._includedQNames);
        Iterator it4 = this._includedURIs.iterator();
        while (it4.hasNext()) {
            if (!set2.contains((String) it4.next())) {
                it4.remove();
            }
        }
        Iterator it5 = set2.iterator();
        while (it5.hasNext()) {
            String str = (String) it5.next();
            if (!this._includedURIs.contains(str)) {
                this._includedURIs.add(str);
            } else {
                this._includedURIs.remove(str);
            }
        }
        Set set6 = this._excludedQNames;
        this._excludedQNames = this._includedQNames;
        this._includedQNames = set6;
        this._inverted = !this._inverted;
    }

    private void addImpl(QName qName) {
        if (this._includedURIs.contains(nsFromName(qName))) {
            this._excludedQNames.remove(qName);
        } else {
            this._includedQNames.add(qName);
        }
    }

    private void addNamespaceImpl(String str) {
        if (this._includedURIs.contains(str)) {
            removeAllMatchingNs(str, this._excludedQNames);
            return;
        }
        removeAllMatchingNs(str, this._includedQNames);
        this._includedURIs.add(str);
    }

    private boolean isDisjointImpl(QNameSetSpecification qNameSetSpecification, QNameSetSpecification qNameSetSpecification2) {
        Set<Object> includedURIs = qNameSetSpecification.includedURIs();
        Set includedURIs2 = qNameSetSpecification2.includedURIs();
        if (includedURIs2 != null) {
            for (Object obj : includedURIs) {
                if (includedURIs2.contains(obj)) {
                    return false;
                }
            }
        } else {
            Set excludedURIs = qNameSetSpecification2.excludedURIs();
            for (Object obj2 : includedURIs) {
                if (!excludedURIs.contains(obj2)) {
                    return false;
                }
            }
        }
        for (QName qName : qNameSetSpecification.includedQNamesInExcludedURIs()) {
            if (qNameSetSpecification2.contains(qName)) {
                return false;
            }
        }
        if (includedURIs.size() <= 0) {
            return true;
        }
        for (QName qName2 : qNameSetSpecification2.includedQNamesInExcludedURIs()) {
            if (qNameSetSpecification.contains(qName2)) {
                return false;
            }
        }
        return true;
    }

    public static boolean isSpace(char c) {
        return c == '\t' || c == '\n' || c == '\r' || c == ' ';
    }

    public static String nsFromName(QName qName) {
        String namespaceURI = qName.getNamespaceURI();
        return namespaceURI == null ? "" : namespaceURI;
    }

    private String prettyQName(QName qName) {
        if (qName.getNamespaceURI() == null) {
            return qName.getLocalPart();
        }
        StringBuffer stringBuffer = new StringBuffer();
        stringBuffer.append(qName.getLocalPart());
        stringBuffer.append("@");
        stringBuffer.append(qName.getNamespaceURI());
        return stringBuffer.toString();
    }

    private void removeAllImpl(Set set, Set set2, Set set3, Set set4) {
        boolean z = set2 != null;
        Set set5 = z ? set2 : set;
        Iterator it = this._includedQNames.iterator();
        while (it.hasNext()) {
            QName qName = (QName) it.next();
            if (set5.contains(nsFromName(qName)) ^ z) {
                if (!set4.contains(qName)) {
                    it.remove();
                }
            } else if (set3.contains(qName)) {
                it.remove();
            }
        }
        Iterator it2 = set3.iterator();
        while (it2.hasNext()) {
            QName qName2 = (QName) it2.next();
            if (this._includedURIs.contains(nsFromName(qName2))) {
                this._excludedQNames.add(qName2);
            }
        }
        Iterator it3 = set4.iterator();
        while (it3.hasNext()) {
            QName qName3 = (QName) it3.next();
            if (this._includedURIs.contains(nsFromName(qName3)) && !this._excludedQNames.contains(qName3)) {
                this._includedQNames.add(qName3);
            }
        }
        if (z) {
            removeAllMatchingFirstOnly(this._includedURIs, set2, this._excludedQNames);
        } else {
            removeAllMatchingBoth(this._includedURIs, set, this._excludedQNames);
        }
        Iterator it4 = this._includedURIs.iterator();
        while (it4.hasNext()) {
            if (set5.contains(it4.next()) ^ z) {
                it4.remove();
            }
        }
    }

    public static void removeAllMatchingBoth(Set set, Set set2, Set set3) {
        Iterator it = set3.iterator();
        while (it.hasNext()) {
            String nsFromName = nsFromName((QName) it.next());
            if (set.contains(nsFromName) && set2.contains(nsFromName)) {
                it.remove();
            }
        }
    }

    public static void removeAllMatchingFirstOnly(Set set, Set set2, Set set3) {
        Iterator it = set3.iterator();
        while (it.hasNext()) {
            String nsFromName = nsFromName((QName) it.next());
            if (set.contains(nsFromName) && !set2.contains(nsFromName)) {
                it.remove();
            }
        }
    }

    public static void removeAllMatchingNeither(Set set, Set set2, Set set3) {
        Iterator it = set3.iterator();
        while (it.hasNext()) {
            String nsFromName = nsFromName((QName) it.next());
            if (!set.contains(nsFromName) && !set2.contains(nsFromName)) {
                it.remove();
            }
        }
    }

    public static void removeAllMatchingNs(String str, Set set) {
        Iterator it = set.iterator();
        while (it.hasNext()) {
            if (str.equals(nsFromName((QName) it.next()))) {
                it.remove();
            }
        }
    }

    private void removeImpl(QName qName) {
        if (this._includedURIs.contains(nsFromName(qName))) {
            this._excludedQNames.add(qName);
        } else {
            this._includedQNames.remove(qName);
        }
    }

    private void removeNamespaceImpl(String str) {
        if (this._includedURIs.contains(str)) {
            removeAllMatchingNs(str, this._excludedQNames);
            this._includedURIs.remove(str);
            return;
        }
        removeAllMatchingNs(str, this._includedQNames);
    }

    public static String[] splitList(String str) {
        if (str.length() == 0) {
            return EMPTY_STRINGARRAY;
        }
        ArrayList arrayList = new ArrayList();
        int i2 = 0;
        while (true) {
            if (i2 < str.length() && isSpace(str.charAt(i2))) {
                i2++;
            } else if (i2 >= str.length()) {
                return (String[]) arrayList.toArray(EMPTY_STRINGARRAY);
            } else {
                int i3 = i2;
                while (i3 < str.length() && !isSpace(str.charAt(i3))) {
                    i3++;
                }
                arrayList.add(str.substring(i2, i3));
                i2 = i3;
            }
        }
    }

    public void add(QName qName) {
        if (!this._inverted) {
            addImpl(qName);
        } else {
            removeImpl(qName);
        }
    }

    public void addAll(QNameSetSpecification qNameSetSpecification) {
        if (this._inverted) {
            removeAllImpl(qNameSetSpecification.includedURIs(), qNameSetSpecification.excludedURIs(), qNameSetSpecification.includedQNamesInExcludedURIs(), qNameSetSpecification.excludedQNamesInIncludedURIs());
        } else {
            addAllImpl(qNameSetSpecification.includedURIs(), qNameSetSpecification.excludedURIs(), qNameSetSpecification.includedQNamesInExcludedURIs(), qNameSetSpecification.excludedQNamesInIncludedURIs());
        }
    }

    public void addNamespace(String str) {
        if (!this._inverted) {
            addNamespaceImpl(str);
        } else {
            removeNamespaceImpl(str);
        }
    }

    public void clear() {
        this._inverted = false;
        this._includedURIs.clear();
        this._excludedQNames.clear();
        this._includedQNames.clear();
    }

    @Override // org.apache.xmlbeans.QNameSetSpecification
    public boolean contains(QName qName) {
        return (this._includedURIs.contains(nsFromName(qName)) ? !this._excludedQNames.contains(qName) : this._includedQNames.contains(qName)) ^ this._inverted;
    }

    @Override // org.apache.xmlbeans.QNameSetSpecification
    public boolean containsAll(QNameSetSpecification qNameSetSpecification) {
        if (this._inverted || qNameSetSpecification.excludedURIs() == null) {
            return inverse().isDisjoint(qNameSetSpecification);
        }
        return false;
    }

    @Override // org.apache.xmlbeans.QNameSetSpecification
    public Set excludedQNamesInIncludedURIs() {
        return Collections.unmodifiableSet(this._inverted ? this._includedQNames : this._excludedQNames);
    }

    @Override // org.apache.xmlbeans.QNameSetSpecification
    public Set excludedURIs() {
        if (this._inverted) {
            return Collections.unmodifiableSet(this._includedURIs);
        }
        return null;
    }

    @Override // org.apache.xmlbeans.QNameSetSpecification
    public Set includedQNamesInExcludedURIs() {
        return Collections.unmodifiableSet(this._inverted ? this._excludedQNames : this._includedQNames);
    }

    @Override // org.apache.xmlbeans.QNameSetSpecification
    public Set includedURIs() {
        if (!this._inverted) {
            return this._includedURIs;
        }
        return null;
    }

    @Override // org.apache.xmlbeans.QNameSetSpecification
    public QNameSet intersect(QNameSetSpecification qNameSetSpecification) {
        QNameSetBuilder qNameSetBuilder = new QNameSetBuilder(this);
        qNameSetBuilder.restrict(qNameSetSpecification);
        return qNameSetBuilder.toQNameSet();
    }

    @Override // org.apache.xmlbeans.QNameSetSpecification
    public QNameSet inverse() {
        return QNameSet.forSets(includedURIs(), excludedURIs(), includedQNamesInExcludedURIs(), excludedQNamesInIncludedURIs());
    }

    public void invert() {
        this._inverted = !this._inverted;
    }

    @Override // org.apache.xmlbeans.QNameSetSpecification
    public boolean isAll() {
        return this._inverted && this._includedURIs.size() == 0 && this._includedQNames.size() == 0;
    }

    @Override // org.apache.xmlbeans.QNameSetSpecification
    public boolean isDisjoint(QNameSetSpecification qNameSetSpecification) {
        if (this._inverted && qNameSetSpecification.excludedURIs() != null) {
            return false;
        }
        if (this._inverted) {
            return isDisjointImpl(qNameSetSpecification, this);
        }
        return isDisjointImpl(this, qNameSetSpecification);
    }

    @Override // org.apache.xmlbeans.QNameSetSpecification
    public boolean isEmpty() {
        return !this._inverted && this._includedURIs.size() == 0 && this._includedQNames.size() == 0;
    }

    public void remove(QName qName) {
        if (this._inverted) {
            addImpl(qName);
        } else {
            removeImpl(qName);
        }
    }

    public void removeAll(QNameSetSpecification qNameSetSpecification) {
        if (this._inverted) {
            addAllImpl(qNameSetSpecification.includedURIs(), qNameSetSpecification.excludedURIs(), qNameSetSpecification.includedQNamesInExcludedURIs(), qNameSetSpecification.excludedQNamesInIncludedURIs());
        } else {
            removeAllImpl(qNameSetSpecification.includedURIs(), qNameSetSpecification.excludedURIs(), qNameSetSpecification.includedQNamesInExcludedURIs(), qNameSetSpecification.excludedQNamesInIncludedURIs());
        }
    }

    public void removeNamespace(String str) {
        if (this._inverted) {
            addNamespaceImpl(str);
        } else {
            removeNamespaceImpl(str);
        }
    }

    public void restrict(QNameSetSpecification qNameSetSpecification) {
        if (this._inverted) {
            addAllImpl(qNameSetSpecification.excludedURIs(), qNameSetSpecification.includedURIs(), qNameSetSpecification.excludedQNamesInIncludedURIs(), qNameSetSpecification.includedQNamesInExcludedURIs());
        } else {
            removeAllImpl(qNameSetSpecification.excludedURIs(), qNameSetSpecification.includedURIs(), qNameSetSpecification.excludedQNamesInIncludedURIs(), qNameSetSpecification.includedQNamesInExcludedURIs());
        }
    }

    public QNameSet toQNameSet() {
        return QNameSet.forSpecification(this);
    }

    public String toString() {
        StringBuffer a = a.a("QNameSetBuilder");
        a.append(this._inverted ? "-(" : "+(");
        for (Object obj : this._includedURIs) {
            a.append("+*@");
            a.append(obj);
            a.append(", ");
        }
        for (QName qName : this._excludedQNames) {
            a.append(UnaryMinusPtg.MINUS);
            a.append(prettyQName(qName));
            a.append(", ");
        }
        for (QName qName2 : this._includedQNames) {
            a.append("+");
            a.append(prettyQName(qName2));
            a.append(", ");
        }
        int lastIndexOf = a.lastIndexOf(", ");
        if (lastIndexOf > 0) {
            a.setLength(lastIndexOf);
        }
        a.append(')');
        return a.toString();
    }

    @Override // org.apache.xmlbeans.QNameSetSpecification
    public QNameSet union(QNameSetSpecification qNameSetSpecification) {
        QNameSetBuilder qNameSetBuilder = new QNameSetBuilder(this);
        qNameSetBuilder.addAll(qNameSetSpecification);
        return qNameSetBuilder.toQNameSet();
    }

    public QNameSetBuilder(QNameSetSpecification qNameSetSpecification) {
        Set includedURIs = qNameSetSpecification.includedURIs();
        if (includedURIs != null) {
            this._inverted = false;
            this._includedURIs = new HashSet(includedURIs);
            this._excludedQNames = new HashSet(qNameSetSpecification.excludedQNamesInIncludedURIs());
            this._includedQNames = new HashSet(qNameSetSpecification.includedQNamesInExcludedURIs());
            return;
        }
        this._inverted = true;
        this._includedURIs = new HashSet(qNameSetSpecification.excludedURIs());
        this._excludedQNames = new HashSet(qNameSetSpecification.includedQNamesInExcludedURIs());
        this._includedQNames = new HashSet(qNameSetSpecification.excludedQNamesInIncludedURIs());
    }

    public QNameSetBuilder(Set set, Set set2, Set set3, Set set4) {
        if (set2 != null && set == null) {
            this._inverted = false;
            this._includedURIs = new HashSet(set2);
            this._excludedQNames = new HashSet(set3);
            this._includedQNames = new HashSet(set4);
        } else if (set == null || set2 != null) {
            throw new IllegalArgumentException("Exactly one of excludedURIs and includedURIs must be null");
        } else {
            this._inverted = true;
            this._includedURIs = new HashSet(set);
            this._excludedQNames = new HashSet(set4);
            this._includedQNames = new HashSet(set3);
        }
    }

    public QNameSetBuilder(String str, String str2) {
        this();
        String[] splitList = splitList(str == null ? SchemaSymbols.ATTVAL_TWOPOUNDANY : str);
        for (int i2 = 0; i2 < splitList.length; i2++) {
            String str3 = splitList[i2];
            if (str3.startsWith("##")) {
                if (str3.equals(SchemaSymbols.ATTVAL_TWOPOUNDOTHER)) {
                    if (str2 != null) {
                        QNameSetBuilder qNameSetBuilder = new QNameSetBuilder();
                        qNameSetBuilder.addNamespace(str2);
                        qNameSetBuilder.addNamespace("");
                        qNameSetBuilder.invert();
                        addAll(qNameSetBuilder);
                    } else {
                        throw new IllegalArgumentException();
                    }
                } else if (str3.equals(SchemaSymbols.ATTVAL_TWOPOUNDANY)) {
                    clear();
                    invert();
                } else if (splitList[i2].equals(SchemaSymbols.ATTVAL_TWOPOUNDTARGETNS)) {
                    if (str2 != null) {
                        str3 = str2;
                    } else {
                        throw new IllegalArgumentException();
                    }
                } else if (splitList[i2].equals(SchemaSymbols.ATTVAL_TWOPOUNDLOCAL)) {
                    str3 = "";
                }
            }
            addNamespace(str3);
        }
    }
}
