package org.apache.xmlbeans;

import b.b.a.a.a;
import java.io.File;
import java.io.Serializable;
import java.net.URI;
import java.net.URISyntaxException;
import java.text.MessageFormat;
import java.util.MissingResourceException;
import java.util.PropertyResourceBundle;
import java.util.ResourceBundle;
import org.apache.poi.javax.xml.stream.Location;

public class XmlError implements Serializable {
    public static final int SEVERITY_ERROR = 0;
    public static final int SEVERITY_INFO = 2;
    public static final int SEVERITY_WARNING = 1;
    public static final ResourceBundle _bundle = PropertyResourceBundle.getBundle("org.apache.xmlbeans.message");
    public static /* synthetic */ Class class$org$apache$xmlbeans$XmlCursor = null;
    public static /* synthetic */ Class class$org$apache$xmlbeans$XmlLineNumber = null;
    public static /* synthetic */ Class class$org$apache$xmlbeans$XmlObject = null;
    public static final long serialVersionUID = 1;
    public String _code;
    public int _column;
    public transient XmlCursor _cursor;
    public int _line;
    public String _message;
    public int _offset;
    public int _severity;
    public String _source;

    public XmlError(XmlError xmlError) {
        this._severity = 0;
        this._line = -1;
        this._column = -1;
        this._offset = -1;
        this._message = xmlError.getMessage();
        this._code = xmlError.getErrorCode();
        this._severity = xmlError.getSeverity();
        this._source = xmlError.getSourceName();
        this._line = xmlError.getLine();
        this._column = xmlError.getColumn();
        this._offset = xmlError.getOffset();
        this._cursor = xmlError.getCursorLocation();
    }

    public static /* synthetic */ Class class$(String str) {
        try {
            return Class.forName(str);
        } catch (ClassNotFoundException e2) {
            throw a.a(e2);
        }
    }

    public static XmlError forCursor(String str, XmlCursor xmlCursor) {
        return forCursor(str, 0, xmlCursor);
    }

    public static XmlError forLocation(String str, String str2, Location location) {
        return new XmlError(str, (String) null, 0, str2, location.getLineNumber(), location.getColumnNumber(), -1, (XmlCursor) null);
    }

    public static XmlError forLocationAndCursor(String str, int i2, String str2, int i3, int i4, int i5, XmlCursor xmlCursor) {
        return new XmlError(str, (String) null, i2, str2, i3, i4, i5, xmlCursor);
    }

    public static XmlError forMessage(String str) {
        return forMessage(str, 0);
    }

    public static XmlError forObject(String str, XmlObject xmlObject) {
        return forObject(str, 0, xmlObject);
    }

    public static XmlError forSource(String str, String str2) {
        return forLocation(str, 0, str2, -1, -1, -1);
    }

    public static String formattedFileName(String str, URI uri) {
        URI uri2 = null;
        if (str == null) {
            return null;
        }
        try {
            URI uri3 = new URI(str);
            if (uri3.isAbsolute()) {
                uri2 = uri3;
            }
        } catch (URISyntaxException unused) {
        }
        if (uri2 == null) {
            uri2 = new File(str).toURI();
        }
        if (uri != null) {
            uri2 = uri.relativize(uri2);
        }
        if (!uri2.isAbsolute() ? !(uri == null || !uri.isAbsolute() || uri.getScheme().compareToIgnoreCase("file") != 0) : uri2.getScheme().compareToIgnoreCase("file") == 0) {
            try {
                return new File(uri2).toString();
            } catch (Exception unused2) {
            }
        }
        return uri2.toString();
    }

    public static String formattedMessage(String str, Object[] objArr) {
        if (str == null) {
            return null;
        }
        try {
            return MessageFormat.format(_bundle.getString(str), objArr);
        } catch (MissingResourceException e2) {
            return MessageFormat.format(_bundle.getString("message.missing.resource"), e2.getMessage());
        } catch (IllegalArgumentException e3) {
            return MessageFormat.format(_bundle.getString("message.pattern.invalid"), e3.getMessage());
        }
    }

    public static String severityAsString(int i2) {
        if (i2 == 0) {
            return "error";
        }
        if (i2 == 1) {
            return "warning";
        }
        if (i2 == 2) {
            return "info";
        }
        throw new IllegalArgumentException("unknown severity");
    }

    public int getColumn() {
        return this._column;
    }

    public XmlCursor getCursorLocation() {
        Class cls = class$org$apache$xmlbeans$XmlCursor;
        if (cls == null) {
            cls = class$("org.apache.xmlbeans.XmlCursor");
            class$org$apache$xmlbeans$XmlCursor = cls;
        }
        return (XmlCursor) getLocation(cls);
    }

    public String getErrorCode() {
        return this._code;
    }

    public int getLine() {
        return this._line;
    }

    public Object getLocation(Object obj) {
        XmlCursor xmlCursor;
        Class cls = class$org$apache$xmlbeans$XmlCursor;
        if (cls == null) {
            cls = class$("org.apache.xmlbeans.XmlCursor");
            class$org$apache$xmlbeans$XmlCursor = cls;
        }
        if (obj == cls) {
            return this._cursor;
        }
        Class cls2 = class$org$apache$xmlbeans$XmlObject;
        if (cls2 == null) {
            cls2 = class$("org.apache.xmlbeans.XmlObject");
            class$org$apache$xmlbeans$XmlObject = cls2;
        }
        if (obj != cls2 || (xmlCursor = this._cursor) == null) {
            return null;
        }
        return xmlCursor.getObject();
    }

    public String getMessage() {
        return this._message;
    }

    public XmlObject getObjectLocation() {
        Class cls = class$org$apache$xmlbeans$XmlObject;
        if (cls == null) {
            cls = class$("org.apache.xmlbeans.XmlObject");
            class$org$apache$xmlbeans$XmlObject = cls;
        }
        return (XmlObject) getLocation(cls);
    }

    public int getOffset() {
        return this._offset;
    }

    public int getSeverity() {
        return this._severity;
    }

    public String getSourceName() {
        return this._source;
    }

    public String toString() {
        return toString(null);
    }

    public static XmlError forCursor(String str, Object[] objArr, XmlCursor xmlCursor) {
        return forCursor(str, objArr, 0, xmlCursor);
    }

    public static XmlError forLocation(String str, String str2, int i2, int i3, int i4) {
        return new XmlError(str, (String) null, 0, str2, i2, i3, i4, (XmlCursor) null);
    }

    public static XmlError forMessage(String str, int i2) {
        return forSource(str, i2, null);
    }

    public static XmlError forObject(String str, Object[] objArr, XmlObject xmlObject) {
        return forObject(str, objArr, 0, xmlObject);
    }

    public static XmlError forSource(String str, int i2, String str2) {
        return forLocation(str, i2, str2, -1, -1, -1);
    }

    public String toString(URI uri) {
        StringBuffer stringBuffer = new StringBuffer();
        String formattedFileName = formattedFileName(getSourceName(), uri);
        if (formattedFileName != null) {
            stringBuffer.append(formattedFileName);
            int line = getLine();
            if (line < 0) {
                line = 0;
            }
            stringBuffer.append(':');
            stringBuffer.append(line);
            stringBuffer.append(':');
            if (getColumn() > 0) {
                stringBuffer.append(getColumn());
                stringBuffer.append(':');
            }
            stringBuffer.append(" ");
        }
        int severity = getSeverity();
        if (severity == 0) {
            stringBuffer.append("error: ");
        } else if (severity == 1) {
            stringBuffer.append("warning: ");
        }
        if (getErrorCode() != null) {
            stringBuffer.append(getErrorCode());
            stringBuffer.append(": ");
        }
        String message = getMessage();
        if (message == null) {
            message = "<Unspecified message>";
        }
        stringBuffer.append(message);
        return stringBuffer.toString();
    }

    public static XmlError forCursor(String str, int i2, XmlCursor xmlCursor) {
        return new XmlError(str, (String) null, i2, xmlCursor);
    }

    public static XmlError forLocation(String str, Object[] objArr, int i2, String str2, int i3, int i4, int i5) {
        return new XmlError(str, objArr, i2, str2, i3, i4, i5, (XmlCursor) null);
    }

    public static XmlError forMessage(String str, Object[] objArr) {
        return forSource(str, objArr, 0, null);
    }

    public static XmlError forObject(String str, int i2, XmlObject xmlObject) {
        if (xmlObject == null) {
            return forMessage(str, i2);
        }
        return forCursor(str, i2, xmlObject.newCursor());
    }

    public static XmlError forSource(String str, Object[] objArr, int i2, String str2) {
        return forLocation(str, objArr, i2, str2, -1, -1, -1);
    }

    public static XmlError forCursor(String str, Object[] objArr, int i2, XmlCursor xmlCursor) {
        return new XmlError(str, objArr, i2, xmlCursor);
    }

    public static XmlError forLocation(String str, int i2, String str2, int i3, int i4, int i5) {
        return new XmlError(str, (String) null, i2, str2, i3, i4, i5, (XmlCursor) null);
    }

    public static XmlError forMessage(String str, Object[] objArr, int i2) {
        return forSource(str, objArr, i2, null);
    }

    public static XmlError forObject(String str, Object[] objArr, int i2, XmlObject xmlObject) {
        if (xmlObject == null) {
            return forMessage(str, objArr, i2);
        }
        return forCursor(str, objArr, i2, xmlObject.newCursor());
    }

    public XmlError(String str, String str2, int i2, String str3, int i3, int i4, int i5, XmlCursor xmlCursor) {
        this._severity = 0;
        this._line = -1;
        this._column = -1;
        this._offset = -1;
        this._message = str;
        this._code = str2;
        this._severity = i2;
        this._source = str3;
        this._line = i3;
        this._column = i4;
        this._offset = i5;
        this._cursor = xmlCursor;
    }

    public XmlError(String str, Object[] objArr, int i2, String str2, int i3, int i4, int i5, XmlCursor xmlCursor) {
        this(formattedMessage(str, objArr), str, i2, str2, i3, i4, i5, xmlCursor);
    }

    public XmlError(String str, String str2, int i2, XmlCursor xmlCursor) {
        int i3;
        int i4;
        String str3;
        this._severity = 0;
        int i5 = -1;
        this._line = -1;
        this._column = -1;
        this._offset = -1;
        if (xmlCursor != null) {
            str3 = xmlCursor.documentProperties().getSourceName();
            XmlCursor newCursor = xmlCursor.newCursor();
            Class cls = class$org$apache$xmlbeans$XmlLineNumber;
            if (cls == null) {
                cls = class$("org.apache.xmlbeans.XmlLineNumber");
                class$org$apache$xmlbeans$XmlLineNumber = cls;
            }
            XmlLineNumber xmlLineNumber = (XmlLineNumber) newCursor.getBookmark(cls);
            if (xmlLineNumber == null) {
                Class cls2 = class$org$apache$xmlbeans$XmlLineNumber;
                if (cls2 == null) {
                    cls2 = class$("org.apache.xmlbeans.XmlLineNumber");
                    class$org$apache$xmlbeans$XmlLineNumber = cls2;
                }
                xmlLineNumber = (XmlLineNumber) newCursor.toPrevBookmark(cls2);
            }
            if (xmlLineNumber != null) {
                i5 = xmlLineNumber.getLine();
                i3 = xmlLineNumber.getColumn();
                i4 = xmlLineNumber.getOffset();
            } else {
                i4 = -1;
                i3 = -1;
            }
            newCursor.dispose();
        } else {
            str3 = null;
            i4 = -1;
            i3 = -1;
        }
        this._message = str;
        this._code = str2;
        this._severity = i2;
        this._source = str3;
        this._line = i5;
        this._column = i3;
        this._offset = i4;
        this._cursor = xmlCursor;
    }

    public XmlError(String str, Object[] objArr, int i2, XmlCursor xmlCursor) {
        this(formattedMessage(str, objArr), str, i2, xmlCursor);
    }

    public XmlError(String str, String str2, int i2, Location location) {
        String str3;
        int i3;
        this._severity = 0;
        int i4 = -1;
        this._line = -1;
        this._column = -1;
        this._offset = -1;
        if (location != null) {
            i4 = location.getLineNumber();
            i3 = location.getColumnNumber();
            str3 = location.getPublicId();
            if (str3 == null) {
                str3 = location.getSystemId();
            }
        } else {
            str3 = null;
            i3 = -1;
        }
        this._message = str;
        this._code = str2;
        this._severity = i2;
        this._source = str3;
        this._line = i4;
        this._column = i3;
    }

    public XmlError(String str, Object[] objArr, int i2, Location location) {
        this(formattedMessage(str, objArr), str, i2, location);
    }
}
