package org.apache.xmlbeans;

import java.util.HashMap;
import org.apache.poi.ss.formula.ptg.StringPtg;

public class XmlOptionCharEscapeMap {
    public static final int DECIMAL = 1;
    public static final int HEXADECIMAL = 2;
    public static final int PREDEF_ENTITY = 0;
    public static final HashMap _predefEntities;
    public HashMap _charMap = new HashMap();

    static {
        HashMap hashMap = new HashMap();
        _predefEntities = hashMap;
        hashMap.put(new Character('<'), "&lt;");
        _predefEntities.put(new Character('>'), "&gt;");
        _predefEntities.put(new Character('&'), "&amp;");
        _predefEntities.put(new Character('\''), "&apos;");
        _predefEntities.put(new Character(StringPtg.FORMULA_DELIMITER), "&quot;");
    }

    public void addMapping(char c, int i2) {
        Character ch = new Character(c);
        if (i2 == 0) {
            String str = (String) _predefEntities.get(ch);
            if (str != null) {
                this._charMap.put(ch, str);
                return;
            }
            throw new XmlException("XmlOptionCharEscapeMap.addMapping(): the PREDEF_ENTITY mode can only be used for the following characters: <, >, &, \" and '");
        } else if (i2 == 1) {
            HashMap hashMap = this._charMap;
            StringBuffer stringBuffer = new StringBuffer();
            stringBuffer.append("&#");
            stringBuffer.append((int) c);
            stringBuffer.append(";");
            hashMap.put(ch, stringBuffer.toString());
        } else if (i2 == 2) {
            String hexString = Integer.toHexString(c);
            HashMap hashMap2 = this._charMap;
            StringBuffer stringBuffer2 = new StringBuffer();
            stringBuffer2.append("&#x");
            stringBuffer2.append(hexString);
            stringBuffer2.append(";");
            hashMap2.put(ch, stringBuffer2.toString());
        } else {
            throw new XmlException("XmlOptionCharEscapeMap.addMapping(): mode must be PREDEF_ENTITY, DECIMAL or HEXADECIMAL");
        }
    }

    public void addMappings(char c, char c2, int i2) {
        if (c <= c2) {
            while (c <= c2) {
                addMapping(c, i2);
                c = (char) (c + 1);
            }
            return;
        }
        throw new XmlException("XmlOptionCharEscapeMap.addMappings(): ch1 must be <= ch2");
    }

    public boolean containsChar(char c) {
        return this._charMap.containsKey(new Character(c));
    }

    public String getEscapedString(char c) {
        return (String) this._charMap.get(new Character(c));
    }
}
