package org.apache.xmlbeans;

import java.util.List;
import org.apache.poi.javax.xml.namespace.QName;
import org.apache.poi.javax.xml.stream.Location;

public class XmlValidationError extends XmlError {
    public static final int ATTRIBUTE_TYPE_INVALID = 1001;
    public static final int ELEMENT_NOT_ALLOWED = 2;
    public static final int ELEMENT_TYPE_INVALID = 3;
    public static final int INCORRECT_ATTRIBUTE = 1000;
    public static final int INCORRECT_ELEMENT = 1;
    public static final int LIST_INVALID = 2000;
    public static final int NIL_ELEMENT = 4;
    public static final int UNDEFINED = 10000;
    public static final int UNION_INVALID = 3000;
    public SchemaType _badSchemaType;
    public int _errorType;
    public List _expectedQNames;
    public SchemaType _expectedSchemaType;
    public QName _fieldQName;
    public QName _offendingQName;

    public XmlValidationError(String str, int i2, XmlCursor xmlCursor, QName qName, QName qName2, SchemaType schemaType, List list, int i3, SchemaType schemaType2) {
        super(str, (String) null, i2, xmlCursor);
        setFieldQName(qName);
        setOffendingQName(qName2);
        setExpectedSchemaType(schemaType);
        setExpectedQNames(list);
        setErrorType(i3);
        setBadSchemaType(schemaType2);
    }

    public static XmlValidationError forCursorWithDetails(String str, String str2, Object[] objArr, int i2, XmlCursor xmlCursor, QName qName, QName qName2, SchemaType schemaType, List list, int i3, SchemaType schemaType2) {
        if (str2 == null) {
            return new XmlValidationError(str, i2, xmlCursor, qName, qName2, schemaType, list, i3, schemaType2);
        }
        return new XmlValidationError(str2, objArr, i2, xmlCursor, qName, qName2, schemaType, list, i3, schemaType2);
    }

    public static XmlValidationError forLocationWithDetails(String str, String str2, Object[] objArr, int i2, Location location, QName qName, QName qName2, SchemaType schemaType, List list, int i3, SchemaType schemaType2) {
        if (str2 == null) {
            return new XmlValidationError(str, i2, location, qName, qName2, schemaType, list, i3, schemaType2);
        }
        return new XmlValidationError(str2, objArr, i2, location, qName, qName2, schemaType, list, i3, schemaType2);
    }

    public SchemaType getBadSchemaType() {
        return this._badSchemaType;
    }

    public int getErrorType() {
        return this._errorType;
    }

    public List getExpectedQNames() {
        return this._expectedQNames;
    }

    public SchemaType getExpectedSchemaType() {
        return this._expectedSchemaType;
    }

    public QName getFieldQName() {
        return this._fieldQName;
    }

    @Override // org.apache.xmlbeans.XmlError
    public String getMessage() {
        if (this._fieldQName == null) {
            return super.getMessage();
        }
        String message = super.getMessage();
        StringBuffer stringBuffer = new StringBuffer(message.length() + 100);
        stringBuffer.append(message);
        stringBuffer.append(" in element ");
        stringBuffer.append(this._fieldQName.getLocalPart());
        if (!(this._fieldQName.getNamespaceURI() == null || this._fieldQName.getNamespaceURI().length() == 0)) {
            stringBuffer.append('@');
            stringBuffer.append(this._fieldQName.getNamespaceURI());
        }
        return stringBuffer.toString();
    }

    public QName getOffendingQName() {
        return this._offendingQName;
    }

    public void setBadSchemaType(SchemaType schemaType) {
        this._badSchemaType = schemaType;
    }

    public void setErrorType(int i2) {
        this._errorType = i2;
    }

    public void setExpectedQNames(List list) {
        this._expectedQNames = list;
    }

    public void setExpectedSchemaType(SchemaType schemaType) {
        this._expectedSchemaType = schemaType;
    }

    public void setFieldQName(QName qName) {
        this._fieldQName = qName;
    }

    public void setOffendingQName(QName qName) {
        this._offendingQName = qName;
    }

    public XmlValidationError(String str, Object[] objArr, int i2, XmlCursor xmlCursor, QName qName, QName qName2, SchemaType schemaType, List list, int i3, SchemaType schemaType2) {
        super(str, objArr, i2, xmlCursor);
        setFieldQName(qName);
        setOffendingQName(qName2);
        setExpectedSchemaType(schemaType);
        setExpectedQNames(list);
        setErrorType(i3);
        setBadSchemaType(schemaType2);
    }

    public XmlValidationError(String str, int i2, Location location, QName qName, QName qName2, SchemaType schemaType, List list, int i3, SchemaType schemaType2) {
        super(str, (String) null, i2, location);
        setFieldQName(qName);
        setOffendingQName(qName2);
        setExpectedSchemaType(schemaType);
        setExpectedQNames(list);
        setErrorType(i3);
        setBadSchemaType(schemaType2);
    }

    public XmlValidationError(String str, Object[] objArr, int i2, Location location, QName qName, QName qName2, SchemaType schemaType, List list, int i3, SchemaType schemaType2) {
        super(str, objArr, i2, location);
        setFieldQName(qName);
        setOffendingQName(qName2);
        setExpectedSchemaType(schemaType);
        setExpectedQNames(list);
        setErrorType(i3);
        setBadSchemaType(schemaType2);
    }
}
