package org.apache.xmlbeans.impl.common;

import java.io.ObjectInputStream;
import java.io.ObjectOutputStream;
import java.io.Serializable;
import java.util.AbstractCollection;
import java.util.AbstractMap;
import java.util.AbstractSet;
import java.util.Collection;
import java.util.Enumeration;
import java.util.Iterator;
import java.util.Map;
import java.util.NoSuchElementException;
import java.util.Set;

public class ConcurrentReaderHashMap extends AbstractMap implements Map, Cloneable, Serializable {
    public static int DEFAULT_INITIAL_CAPACITY = 32;
    public static final float DEFAULT_LOAD_FACTOR = 0.75f;
    public static final int MAXIMUM_CAPACITY = 1073741824;
    public static final int MINIMUM_CAPACITY = 4;
    public final BarrierLock barrierLock;
    public transient int count;
    public transient Set entrySet;
    public transient Set keySet;
    public transient Object lastWrite;
    public float loadFactor;
    public transient Entry[] table;
    public int threshold;
    public transient Collection values;

    public static class BarrierLock implements Serializable {
    }

    public static class Entry implements Map.Entry {
        public final int hash;
        public final Object key;
        public final Entry next;
        public volatile Object value;

        public Entry(int i2, Object obj, Object obj2, Entry entry) {
            this.hash = i2;
            this.key = obj;
            this.next = entry;
            this.value = obj2;
        }

        public boolean equals(Object obj) {
            if (!(obj instanceof Map.Entry)) {
                return false;
            }
            Map.Entry entry = (Map.Entry) obj;
            if (!this.key.equals(entry.getKey()) || !this.value.equals(entry.getValue())) {
                return false;
            }
            return true;
        }

        @Override // java.util.Map.Entry
        public Object getKey() {
            return this.key;
        }

        @Override // java.util.Map.Entry
        public Object getValue() {
            return this.value;
        }

        public int hashCode() {
            return this.key.hashCode() ^ this.value.hashCode();
        }

        @Override // java.util.Map.Entry
        public Object setValue(Object obj) {
            if (obj != null) {
                Object obj2 = this.value;
                this.value = obj;
                return obj2;
            }
            throw null;
        }

        public String toString() {
            StringBuffer stringBuffer = new StringBuffer();
            stringBuffer.append(this.key);
            stringBuffer.append("=");
            stringBuffer.append(this.value);
            return stringBuffer.toString();
        }
    }

    public class EntrySet extends AbstractSet {
        public EntrySet() {
        }

        public void clear() {
            ConcurrentReaderHashMap.this.clear();
        }

        public boolean contains(Object obj) {
            if (!(obj instanceof Map.Entry)) {
                return false;
            }
            Map.Entry entry = (Map.Entry) obj;
            Object obj2 = ConcurrentReaderHashMap.this.get(entry.getKey());
            if (obj2 == null || !obj2.equals(entry.getValue())) {
                return false;
            }
            return true;
        }

        @Override // java.util.AbstractCollection, java.util.Collection, java.util.Set, java.lang.Iterable
        public Iterator iterator() {
            return new HashIterator();
        }

        public boolean remove(Object obj) {
            if (!(obj instanceof Map.Entry)) {
                return false;
            }
            return ConcurrentReaderHashMap.this.findAndRemoveEntry((Map.Entry) obj);
        }

        public int size() {
            return ConcurrentReaderHashMap.this.size();
        }
    }

    public class HashIterator implements Iterator, Enumeration {
        public Object currentKey;
        public Object currentValue;
        public Entry entry = null;
        public int index;
        public Entry lastReturned = null;
        public final Entry[] tab;

        public HashIterator() {
            Entry[] tableForReading = ConcurrentReaderHashMap.this.getTableForReading();
            this.tab = tableForReading;
            this.index = tableForReading.length - 1;
        }

        public boolean hasMoreElements() {
            return hasNext();
        }

        public boolean hasNext() {
            int i2;
            do {
                Entry entry2 = this.entry;
                if (entry2 != null) {
                    Object obj = entry2.value;
                    if (obj != null) {
                        this.currentKey = this.entry.key;
                        this.currentValue = obj;
                        return true;
                    }
                    this.entry = this.entry.next;
                }
                while (this.entry == null && (i2 = this.index) >= 0) {
                    Entry[] entryArr = this.tab;
                    this.index = i2 - 1;
                    this.entry = entryArr[i2];
                }
            } while (this.entry != null);
            this.currentValue = null;
            this.currentKey = null;
            return false;
        }

        @Override // java.util.Iterator
        public Object next() {
            if (this.currentKey != null || hasNext()) {
                Object returnValueOfNext = returnValueOfNext();
                Entry entry2 = this.entry;
                this.lastReturned = entry2;
                this.currentValue = null;
                this.currentKey = null;
                this.entry = entry2.next;
                return returnValueOfNext;
            }
            throw new NoSuchElementException();
        }

        @Override // java.util.Enumeration
        public Object nextElement() {
            return next();
        }

        public void remove() {
            Entry entry2 = this.lastReturned;
            if (entry2 != null) {
                ConcurrentReaderHashMap.this.remove(entry2.key);
                this.lastReturned = null;
                return;
            }
            throw new IllegalStateException();
        }

        public Object returnValueOfNext() {
            return this.entry;
        }
    }

    public class KeyIterator extends HashIterator {
        public KeyIterator() {
            super();
        }

        @Override // org.apache.xmlbeans.impl.common.ConcurrentReaderHashMap.HashIterator
        public Object returnValueOfNext() {
            return this.currentKey;
        }
    }

    public class KeySet extends AbstractSet {
        public KeySet() {
        }

        public void clear() {
            ConcurrentReaderHashMap.this.clear();
        }

        public boolean contains(Object obj) {
            return ConcurrentReaderHashMap.this.containsKey(obj);
        }

        @Override // java.util.AbstractCollection, java.util.Collection, java.util.Set, java.lang.Iterable
        public Iterator iterator() {
            return new KeyIterator();
        }

        public boolean remove(Object obj) {
            return ConcurrentReaderHashMap.this.remove(obj) != null;
        }

        public int size() {
            return ConcurrentReaderHashMap.this.size();
        }
    }

    public class ValueIterator extends HashIterator {
        public ValueIterator() {
            super();
        }

        @Override // org.apache.xmlbeans.impl.common.ConcurrentReaderHashMap.HashIterator
        public Object returnValueOfNext() {
            return this.currentValue;
        }
    }

    public class Values extends AbstractCollection {
        public Values() {
        }

        public void clear() {
            ConcurrentReaderHashMap.this.clear();
        }

        public boolean contains(Object obj) {
            return ConcurrentReaderHashMap.this.containsValue(obj);
        }

        @Override // java.util.AbstractCollection, java.util.Collection, java.lang.Iterable
        public Iterator iterator() {
            return new ValueIterator();
        }

        public int size() {
            return ConcurrentReaderHashMap.this.size();
        }
    }

    public ConcurrentReaderHashMap(int i2, float f2) {
        this.barrierLock = new BarrierLock();
        this.keySet = null;
        this.entrySet = null;
        this.values = null;
        if (f2 > 0.0f) {
            this.loadFactor = f2;
            int p2capacity = p2capacity(i2);
            this.table = new Entry[p2capacity];
            this.threshold = (int) (((float) p2capacity) * f2);
            return;
        }
        StringBuffer stringBuffer = new StringBuffer();
        stringBuffer.append("Illegal Load factor: ");
        stringBuffer.append(f2);
        throw new IllegalArgumentException(stringBuffer.toString());
    }

    public static int hash(Object obj) {
        int hashCode = obj.hashCode();
        return ((hashCode << 7) - hashCode) + (hashCode >>> 9) + (hashCode >>> 17);
    }

    private int p2capacity(int i2) {
        int i3 = MAXIMUM_CAPACITY;
        if (i2 <= 1073741824 && i2 >= 0) {
            i3 = 4;
            while (i3 < i2) {
                i3 <<= 1;
            }
        }
        return i3;
    }

    private synchronized void readObject(ObjectInputStream objectInputStream) {
        objectInputStream.defaultReadObject();
        this.table = new Entry[objectInputStream.readInt()];
        int readInt = objectInputStream.readInt();
        for (int i2 = 0; i2 < readInt; i2++) {
            put(objectInputStream.readObject(), objectInputStream.readObject());
        }
    }

    private synchronized void writeObject(ObjectOutputStream objectOutputStream) {
        objectOutputStream.defaultWriteObject();
        objectOutputStream.writeInt(this.table.length);
        objectOutputStream.writeInt(this.count);
        for (int length = this.table.length - 1; length >= 0; length--) {
            for (Entry entry = this.table[length]; entry != null; entry = entry.next) {
                objectOutputStream.writeObject(entry.key);
                objectOutputStream.writeObject(entry.value);
            }
        }
    }

    public synchronized int capacity() {
        return this.table.length;
    }

    public synchronized void clear() {
        Entry[] entryArr = this.table;
        for (int i2 = 0; i2 < entryArr.length; i2++) {
            for (Entry entry = entryArr[i2]; entry != null; entry = entry.next) {
                entry.value = null;
            }
            entryArr[i2] = null;
        }
        this.count = 0;
        recordModification(entryArr);
    }

    /* JADX WARNING: Code restructure failed: missing block: B:15:0x003b, code lost:
        throw new java.lang.InternalError();
     */
    /* JADX WARNING: Exception block dominator not found, dom blocks: [] */
    /* JADX WARNING: Missing exception handler attribute for start block: B:13:0x0036 */
    @Override // java.util.AbstractMap, java.lang.Object
    public synchronized Object clone() {
        ConcurrentReaderHashMap concurrentReaderHashMap;
        concurrentReaderHashMap = (ConcurrentReaderHashMap) super.clone();
        concurrentReaderHashMap.keySet = null;
        concurrentReaderHashMap.entrySet = null;
        concurrentReaderHashMap.values = null;
        Entry[] entryArr = this.table;
        Entry[] entryArr2 = new Entry[entryArr.length];
        concurrentReaderHashMap.table = entryArr2;
        for (int i2 = 0; i2 < entryArr.length; i2++) {
            Entry entry = entryArr[i2];
            Entry entry2 = null;
            while (entry != null) {
                Entry entry3 = new Entry(entry.hash, entry.key, entry.value, entry2);
                entry = entry.next;
                entry2 = entry3;
            }
            entryArr2[i2] = entry2;
        }
        return concurrentReaderHashMap;
    }

    public boolean contains(Object obj) {
        return containsValue(obj);
    }

    public boolean containsKey(Object obj) {
        return get(obj) != null;
    }

    public boolean containsValue(Object obj) {
        if (obj != null) {
            Entry[] tableForReading = getTableForReading();
            for (Entry entry : tableForReading) {
                for (; entry != null; entry = entry.next) {
                    if (obj.equals(entry.value)) {
                        return true;
                    }
                }
            }
            return false;
        }
        throw null;
    }

    public Enumeration elements() {
        return new ValueIterator();
    }

    @Override // java.util.AbstractMap, java.util.Map
    public Set entrySet() {
        Set set = this.entrySet;
        if (set != null) {
            return set;
        }
        EntrySet entrySet2 = new EntrySet();
        this.entrySet = entrySet2;
        return entrySet2;
    }

    public boolean eq(Object obj, Object obj2) {
        return obj == obj2 || obj.equals(obj2);
    }

    public synchronized boolean findAndRemoveEntry(Map.Entry entry) {
        Object key = entry.getKey();
        Object obj = get(key);
        if (obj == null || !obj.equals(entry.getValue())) {
            return false;
        }
        remove(key);
        return true;
    }

    @Override // java.util.AbstractMap, java.util.Map
    public Object get(Object obj) {
        int hash = hash(obj);
        Entry[] entryArr = this.table;
        int length = (entryArr.length - 1) & hash;
        Entry entry = entryArr[length];
        Entry entry2 = entry;
        while (true) {
            if (entry == null) {
                Entry[] tableForReading = getTableForReading();
                if (entryArr == tableForReading && entry2 == entryArr[length]) {
                    return null;
                }
                length = hash & (tableForReading.length - 1);
                entry2 = tableForReading[length];
                entryArr = tableForReading;
            } else if (entry.hash != hash || !eq(obj, entry.key)) {
                entry = entry.next;
            } else {
                Object obj2 = entry.value;
                if (obj2 != null) {
                    return obj2;
                }
                synchronized (this) {
                    entryArr = this.table;
                }
                length = (entryArr.length - 1) & hash;
                entry2 = entryArr[length];
            }
            entry = entry2;
        }
    }

    public final Entry[] getTableForReading() {
        Entry[] entryArr;
        synchronized (this.barrierLock) {
            entryArr = this.table;
        }
        return entryArr;
    }

    public synchronized boolean isEmpty() {
        return this.count == 0;
    }

    @Override // java.util.AbstractMap, java.util.Map
    public Set keySet() {
        Set set = this.keySet;
        if (set != null) {
            return set;
        }
        KeySet keySet2 = new KeySet();
        this.keySet = keySet2;
        return keySet2;
    }

    public Enumeration keys() {
        return new KeyIterator();
    }

    public float loadFactor() {
        return this.loadFactor;
    }

    @Override // java.util.AbstractMap, java.util.Map
    public Object put(Object obj, Object obj2) {
        if (obj2 != null) {
            int hash = hash(obj);
            Entry[] entryArr = this.table;
            int length = (entryArr.length - 1) & hash;
            Entry entry = entryArr[length];
            Entry entry2 = entry;
            while (entry2 != null && (entry2.hash != hash || !eq(obj, entry2.key))) {
                entry2 = entry2.next;
            }
            synchronized (this) {
                if (entryArr == this.table) {
                    if (entry2 != null) {
                        Object obj3 = entry2.value;
                        if (entry == entryArr[length] && obj3 != null) {
                            entry2.value = obj2;
                            return obj3;
                        }
                    } else if (entry == entryArr[length]) {
                        Entry entry3 = new Entry(hash, obj, obj2, entry);
                        entryArr[length] = entry3;
                        int i2 = this.count + 1;
                        this.count = i2;
                        if (i2 >= this.threshold) {
                            rehash();
                        } else {
                            recordModification(entry3);
                        }
                        return null;
                    }
                }
                return sput(obj, obj2, hash);
            }
        }
        throw null;
    }

    @Override // java.util.AbstractMap, java.util.Map
    public synchronized void putAll(Map map) {
        int size = map.size();
        if (size != 0) {
            while (size >= this.threshold) {
                rehash();
            }
            for (Map.Entry entry : map.entrySet()) {
                put(entry.getKey(), entry.getValue());
            }
        }
    }

    public final void recordModification(Object obj) {
        synchronized (this.barrierLock) {
            this.lastWrite = obj;
        }
    }

    public void rehash() {
        Entry[] entryArr = this.table;
        int length = entryArr.length;
        if (length >= 1073741824) {
            this.threshold = Integer.MAX_VALUE;
            return;
        }
        int i2 = length << 1;
        int i3 = i2 - 1;
        this.threshold = (int) (((float) i2) * this.loadFactor);
        Entry[] entryArr2 = new Entry[i2];
        for (Entry entry : entryArr) {
            if (entry != null) {
                int i4 = entry.hash & i3;
                Entry entry2 = entry.next;
                if (entry2 == null) {
                    entryArr2[i4] = entry;
                } else {
                    Entry entry3 = entry;
                    while (entry2 != null) {
                        int i5 = entry2.hash & i3;
                        if (i5 != i4) {
                            entry3 = entry2;
                            i4 = i5;
                        }
                        entry2 = entry2.next;
                    }
                    entryArr2[i4] = entry3;
                    while (entry != entry3) {
                        int i6 = entry.hash;
                        int i7 = i6 & i3;
                        entryArr2[i7] = new Entry(i6, entry.key, entry.value, entryArr2[i7]);
                        entry = entry.next;
                    }
                }
            }
        }
        this.table = entryArr2;
        recordModification(entryArr2);
    }

    @Override // java.util.AbstractMap, java.util.Map
    public Object remove(Object obj) {
        int hash = hash(obj);
        Entry[] entryArr = this.table;
        int length = (entryArr.length - 1) & hash;
        Entry entry = entryArr[length];
        Entry entry2 = entry;
        while (entry2 != null && (entry2.hash != hash || !eq(obj, entry2.key))) {
            entry2 = entry2.next;
        }
        synchronized (this) {
            if (entryArr == this.table) {
                if (entry2 != null) {
                    Object obj2 = entry2.value;
                    if (entry == entryArr[length] && obj2 != null) {
                        entry2.value = null;
                        this.count--;
                        Entry entry3 = entry2.next;
                        while (entry != entry2) {
                            Entry entry4 = new Entry(entry.hash, entry.key, entry.value, entry3);
                            entry = entry.next;
                            entry3 = entry4;
                        }
                        entryArr[length] = entry3;
                        recordModification(entry3);
                        return obj2;
                    }
                } else if (entry == entryArr[length]) {
                    return null;
                }
            }
            return sremove(obj, hash);
        }
    }

    public synchronized int size() {
        return this.count;
    }

    public Object sput(Object obj, Object obj2, int i2) {
        Entry[] entryArr = this.table;
        int length = (entryArr.length - 1) & i2;
        Entry entry = entryArr[length];
        for (Entry entry2 = entry; entry2 != null; entry2 = entry2.next) {
            if (entry2.hash == i2 && eq(obj, entry2.key)) {
                Object obj3 = entry2.value;
                entry2.value = obj2;
                return obj3;
            }
        }
        Entry entry3 = new Entry(i2, obj, obj2, entry);
        entryArr[length] = entry3;
        int i3 = this.count + 1;
        this.count = i3;
        if (i3 >= this.threshold) {
            rehash();
            return null;
        }
        recordModification(entry3);
        return null;
    }

    public Object sremove(Object obj, int i2) {
        Entry[] entryArr = this.table;
        int length = (entryArr.length - 1) & i2;
        Entry entry = entryArr[length];
        for (Entry entry2 = entry; entry2 != null; entry2 = entry2.next) {
            if (entry2.hash == i2 && eq(obj, entry2.key)) {
                Object obj2 = entry2.value;
                entry2.value = null;
                this.count--;
                Entry entry3 = entry2.next;
                while (entry != entry2) {
                    Entry entry4 = new Entry(entry.hash, entry.key, entry.value, entry3);
                    entry = entry.next;
                    entry3 = entry4;
                }
                entryArr[length] = entry3;
                recordModification(entry3);
                return obj2;
            }
        }
        return null;
    }

    @Override // java.util.AbstractMap, java.util.Map
    public Collection values() {
        Collection collection = this.values;
        if (collection != null) {
            return collection;
        }
        Values values2 = new Values();
        this.values = values2;
        return values2;
    }

    public ConcurrentReaderHashMap(int i2) {
        this(i2, 0.75f);
    }

    public ConcurrentReaderHashMap() {
        this(DEFAULT_INITIAL_CAPACITY, 0.75f);
    }

    public ConcurrentReaderHashMap(Map map) {
        this(Math.max(((int) (((float) map.size()) / 0.75f)) + 1, 16), 0.75f);
        putAll(map);
    }
}
