package org.apache.xmlbeans.impl.common;

import b.b.a.a.a;
import java.util.ArrayList;
import java.util.Collection;
import java.util.HashMap;
import java.util.LinkedHashSet;
import java.util.List;
import java.util.Map;
import java.util.Set;
import org.apache.poi.javax.xml.namespace.QName;
import org.apache.poi.javax.xml.stream.Location;
import org.apache.xmlbeans.SchemaIdentityConstraint;
import org.apache.xmlbeans.SchemaType;
import org.apache.xmlbeans.XmlCursor;
import org.apache.xmlbeans.XmlError;
import org.apache.xmlbeans.XmlErrorCodes;
import org.apache.xmlbeans.XmlID;
import org.apache.xmlbeans.XmlIDREF;
import org.apache.xmlbeans.XmlIDREFS;
import org.apache.xmlbeans.XmlObject;
import org.apache.xmlbeans.impl.common.ValidatorListener;
import org.apache.xmlbeans.impl.common.XPath;

public class IdentityConstraint {
    public static final /* synthetic */ boolean $assertionsDisabled;
    public static /* synthetic */ Class class$org$apache$xmlbeans$impl$common$IdentityConstraint;
    public ConstraintState _constraintStack;
    public ElementState _elementStack;
    public Collection _errorListener;
    public boolean _invalid;
    public boolean _trackIdrefs;

    public abstract class ConstraintState {
        public ConstraintState _next;

        public ConstraintState() {
            IdentityConstraint.this.setSavePoint(IdentityConstraint.this._constraintStack);
            this._next = IdentityConstraint.this._constraintStack;
            IdentityConstraint.this._constraintStack = this;
        }

        public abstract void attr(ValidatorListener.Event event, QName qName, SchemaType schemaType, String str);

        public abstract void element(ValidatorListener.Event event, SchemaType schemaType);

        public abstract void endElement(ValidatorListener.Event event);

        public abstract void remove(ValidatorListener.Event event);

        public abstract void text(ValidatorListener.Event event, SchemaType schemaType, String str, boolean z);
    }

    public static class ElementState {
        public boolean _hasConstraints;
        public ElementState _next;
        public ConstraintState _savePoint;

        public ElementState() {
        }
    }

    public class FieldState extends ConstraintState {
        public XPath.ExecutionContext[] _contexts;
        public boolean[] _needsValue;
        public SelectorState _selector;
        public XmlObjectList _value;

        public FieldState(SelectorState selectorState, ValidatorListener.Event event, SchemaType schemaType) {
            super();
            this._selector = selectorState;
            SchemaIdentityConstraint schemaIdentityConstraint = selectorState._constraint;
            int length = schemaIdentityConstraint.getFields().length;
            this._contexts = new XPath.ExecutionContext[length];
            this._needsValue = new boolean[length];
            this._value = new XmlObjectList(length);
            for (int i2 = 0; i2 < length; i2++) {
                this._contexts[i2] = new XPath.ExecutionContext();
                this._contexts[i2].init((XPath) schemaIdentityConstraint.getFieldPath(i2));
                if ((this._contexts[i2].start() & 1) != 0) {
                    if (!IdentityConstraint.hasSimpleContent(schemaType)) {
                        IdentityConstraint.this.emitError(event, "Identity constraint field must have simple content");
                    } else {
                        this._needsValue[i2] = true;
                    }
                }
            }
        }

        @Override // org.apache.xmlbeans.impl.common.IdentityConstraint.ConstraintState
        public void attr(ValidatorListener.Event event, QName qName, SchemaType schemaType, String str) {
            if (str != null) {
                int i2 = 0;
                while (true) {
                    XPath.ExecutionContext[] executionContextArr = this._contexts;
                    if (i2 < executionContextArr.length) {
                        if (executionContextArr[i2].attr(qName)) {
                            XmlObject newValue = IdentityConstraint.newValue(schemaType, str);
                            if (newValue != null) {
                                if (!this._value.set(newValue, i2)) {
                                    IdentityConstraint identityConstraint = IdentityConstraint.this;
                                    StringBuffer a = a.a("Multiple instances of field with xpath: '");
                                    a.append(this._selector._constraint.getFields()[i2]);
                                    a.append("' for a selector");
                                    identityConstraint.emitError(event, a.toString());
                                }
                            } else {
                                return;
                            }
                        }
                        i2++;
                    } else {
                        return;
                    }
                }
            }
        }

        @Override // org.apache.xmlbeans.impl.common.IdentityConstraint.ConstraintState
        public void element(ValidatorListener.Event event, SchemaType schemaType) {
            int i2 = 0;
            for (int i3 = 0; i3 < this._contexts.length; i3++) {
                if (this._needsValue[i3]) {
                    IdentityConstraint.this.emitError(event, "Identity constraint field must have simple content");
                    this._needsValue[i3] = false;
                }
            }
            while (true) {
                XPath.ExecutionContext[] executionContextArr = this._contexts;
                if (i2 < executionContextArr.length) {
                    if ((executionContextArr[i2].element(event.getName()) & 1) != 0) {
                        if (!IdentityConstraint.hasSimpleContent(schemaType)) {
                            IdentityConstraint.this.emitError(event, "Identity constraint field must have simple content");
                        } else {
                            this._needsValue[i2] = true;
                        }
                    }
                    i2++;
                } else {
                    return;
                }
            }
        }

        @Override // org.apache.xmlbeans.impl.common.IdentityConstraint.ConstraintState
        public void endElement(ValidatorListener.Event event) {
            for (int i2 = 0; i2 < this._needsValue.length; i2++) {
                this._contexts[i2].end();
                this._needsValue[i2] = false;
            }
        }

        @Override // org.apache.xmlbeans.impl.common.IdentityConstraint.ConstraintState
        public void remove(ValidatorListener.Event event) {
            if (this._selector._constraint.getConstraintCategory() != 1 || this._value.unfilled() < 0) {
                this._selector.addFields(this._value, event);
                return;
            }
            IdentityConstraint identityConstraint = IdentityConstraint.this;
            StringBuffer a = a.a("Key ");
            a.append(QNameHelper.pretty(this._selector._constraint.getName()));
            a.append(" is missing field with xpath: '");
            a.append(this._selector._constraint.getFields()[this._value.unfilled()]);
            a.append("'");
            identityConstraint.emitError(event, a.toString());
        }

        @Override // org.apache.xmlbeans.impl.common.IdentityConstraint.ConstraintState
        public void text(ValidatorListener.Event event, SchemaType schemaType, String str, boolean z) {
            if (str != null || z) {
                for (int i2 = 0; i2 < this._contexts.length; i2++) {
                    if (this._needsValue[i2]) {
                        if (z || !IdentityConstraint.hasSimpleContent(schemaType)) {
                            IdentityConstraint.this.emitError(event, "Identity constraint field must have simple content");
                            return;
                        }
                        XmlObject newValue = IdentityConstraint.newValue(IdentityConstraint.getSimpleType(schemaType), str);
                        if (newValue == null) {
                            return;
                        }
                        if (!this._value.set(newValue, i2)) {
                            IdentityConstraint identityConstraint = IdentityConstraint.this;
                            StringBuffer a = a.a("Multiple instances of field with xpath: '");
                            a.append(this._selector._constraint.getFields()[i2]);
                            a.append("' for a selector");
                            identityConstraint.emitError(event, a.toString());
                        }
                    }
                }
            }
        }
    }

    public class IdRefState extends ConstraintState {
        public IdState _ids;
        public List _values = new ArrayList();

        public IdRefState(IdState idState) {
            super();
            this._ids = idState;
        }

        private void handleValue(ValidatorListener.Event event, SchemaType schemaType, String str) {
            if (str != null && schemaType != null && !schemaType.isNoType()) {
                if (XmlIDREFS.type.isAssignableFrom(schemaType)) {
                    XmlIDREFS xmlIDREFS = (XmlIDREFS) IdentityConstraint.newValue(XmlIDREFS.type, str);
                    if (xmlIDREFS != null) {
                        List xgetListValue = xmlIDREFS.xgetListValue();
                        for (int i2 = 0; i2 < xgetListValue.size(); i2++) {
                            XmlObjectList xmlObjectList = new XmlObjectList(1);
                            xmlObjectList.set((XmlIDREF) xgetListValue.get(i2), 0);
                            this._values.add(xmlObjectList);
                        }
                    }
                } else if (XmlIDREF.type.isAssignableFrom(schemaType)) {
                    XmlObjectList xmlObjectList2 = new XmlObjectList(1);
                    XmlIDREF xmlIDREF = (XmlIDREF) schemaType.newValue(str);
                    if (xmlIDREF != null) {
                        xmlObjectList2.set(xmlIDREF, 0);
                        this._values.add(xmlObjectList2);
                    }
                }
            }
        }

        @Override // org.apache.xmlbeans.impl.common.IdentityConstraint.ConstraintState
        public void attr(ValidatorListener.Event event, QName qName, SchemaType schemaType, String str) {
            handleValue(event, schemaType, str);
        }

        @Override // org.apache.xmlbeans.impl.common.IdentityConstraint.ConstraintState
        public void element(ValidatorListener.Event event, SchemaType schemaType) {
        }

        @Override // org.apache.xmlbeans.impl.common.IdentityConstraint.ConstraintState
        public void endElement(ValidatorListener.Event event) {
        }

        @Override // org.apache.xmlbeans.impl.common.IdentityConstraint.ConstraintState
        public void remove(ValidatorListener.Event event) {
            for (Object obj : this._values) {
                if (!this._ids._values.contains(obj)) {
                    IdentityConstraint identityConstraint = IdentityConstraint.this;
                    StringBuffer stringBuffer = new StringBuffer();
                    stringBuffer.append("ID not found for IDRef value '");
                    stringBuffer.append(obj);
                    stringBuffer.append("'");
                    identityConstraint.emitError(event, stringBuffer.toString());
                }
            }
        }

        @Override // org.apache.xmlbeans.impl.common.IdentityConstraint.ConstraintState
        public void text(ValidatorListener.Event event, SchemaType schemaType, String str, boolean z) {
            if (!z) {
                handleValue(event, schemaType, str);
            }
        }
    }

    public class IdState extends ConstraintState {
        public Set _values = new LinkedHashSet();

        public IdState() {
            super();
        }

        private void handleValue(ValidatorListener.Event event, SchemaType schemaType, String str) {
            if (str != null && schemaType != null && !schemaType.isNoType() && XmlID.type.isAssignableFrom(schemaType)) {
                XmlObjectList xmlObjectList = new XmlObjectList(1);
                XmlObject newValue = IdentityConstraint.newValue(XmlID.type, str);
                if (newValue != null) {
                    xmlObjectList.set(newValue, 0);
                    if (this._values.contains(xmlObjectList)) {
                        IdentityConstraint.this.emitError(event, XmlErrorCodes.ID_VALID$DUPLICATE, new Object[]{str});
                        return;
                    }
                    this._values.add(xmlObjectList);
                }
            }
        }

        @Override // org.apache.xmlbeans.impl.common.IdentityConstraint.ConstraintState
        public void attr(ValidatorListener.Event event, QName qName, SchemaType schemaType, String str) {
            handleValue(event, schemaType, str);
        }

        @Override // org.apache.xmlbeans.impl.common.IdentityConstraint.ConstraintState
        public void element(ValidatorListener.Event event, SchemaType schemaType) {
        }

        @Override // org.apache.xmlbeans.impl.common.IdentityConstraint.ConstraintState
        public void endElement(ValidatorListener.Event event) {
        }

        @Override // org.apache.xmlbeans.impl.common.IdentityConstraint.ConstraintState
        public void remove(ValidatorListener.Event event) {
        }

        @Override // org.apache.xmlbeans.impl.common.IdentityConstraint.ConstraintState
        public void text(ValidatorListener.Event event, SchemaType schemaType, String str, boolean z) {
            if (!z) {
                handleValue(event, schemaType, str);
            }
        }
    }

    public class KeyrefState extends SelectorState {
        public Object CHILD_ADDED = new Object();
        public Object CHILD_REMOVED = new Object();
        public Object SELF_ADDED = new Object();
        public Map _keyValues = new HashMap();

        public KeyrefState(SchemaIdentityConstraint schemaIdentityConstraint, ValidatorListener.Event event, SchemaType schemaType) {
            super(schemaIdentityConstraint, event, schemaType);
        }

        private boolean hasKeyValue(Object obj) {
            Object obj2 = this._keyValues.get(obj);
            return (obj2 == null || obj2 == this.CHILD_REMOVED) ? false : true;
        }

        public void addKeyValues(Set set, boolean z) {
            for (Object obj : set) {
                Object obj2 = this._keyValues.get(obj);
                if (obj2 == null) {
                    this._keyValues.put(obj, z ? this.CHILD_ADDED : this.SELF_ADDED);
                } else if (obj2 == this.CHILD_ADDED) {
                    if (z) {
                        this._keyValues.put(obj, this.CHILD_REMOVED);
                    } else {
                        this._keyValues.put(obj, this.SELF_ADDED);
                    }
                } else if (obj2 == this.CHILD_REMOVED && !z) {
                    this._keyValues.put(obj, this.SELF_ADDED);
                }
            }
        }

        @Override // org.apache.xmlbeans.impl.common.IdentityConstraint.SelectorState, org.apache.xmlbeans.impl.common.IdentityConstraint.ConstraintState
        public void remove(ValidatorListener.Event event) {
            ConstraintState constraintState = this._next;
            while (constraintState != null && constraintState != IdentityConstraint.this._elementStack._savePoint) {
                if (constraintState instanceof SelectorState) {
                    SelectorState selectorState = (SelectorState) constraintState;
                    if (selectorState._constraint == this._constraint.getReferencedKey()) {
                        addKeyValues(selectorState._values, false);
                    }
                }
                constraintState = constraintState._next;
            }
            for (XmlObjectList xmlObjectList : this._values) {
                if (xmlObjectList.unfilled() < 0 && !hasKeyValue(xmlObjectList)) {
                    IdentityConstraint.this.emitError(event, XmlErrorCodes.IDENTITY_CONSTRAINT_VALID$KEYREF_KEY_NOT_FOUND, new Object[]{xmlObjectList, QNameHelper.pretty(this._constraint.getName())});
                    return;
                }
            }
        }
    }

    public class SelectorState extends ConstraintState {
        public SchemaIdentityConstraint _constraint;
        public XPath.ExecutionContext _context;
        public Set _values = new LinkedHashSet();

        public SelectorState(SchemaIdentityConstraint schemaIdentityConstraint, ValidatorListener.Event event, SchemaType schemaType) {
            super();
            this._constraint = schemaIdentityConstraint;
            XPath.ExecutionContext executionContext = new XPath.ExecutionContext();
            this._context = executionContext;
            executionContext.init((XPath) this._constraint.getSelectorPath());
            if ((this._context.start() & 1) != 0) {
                createFieldState(event, schemaType);
            }
        }

        public void addFields(XmlObjectList xmlObjectList, ValidatorListener.Event event) {
            if (this._constraint.getConstraintCategory() == 2) {
                this._values.add(xmlObjectList);
            } else if (!this._values.contains(xmlObjectList)) {
                this._values.add(xmlObjectList);
            } else if (this._constraint.getConstraintCategory() == 3) {
                IdentityConstraint.this.emitError(event, XmlErrorCodes.IDENTITY_CONSTRAINT_VALID$DUPLICATE_UNIQUE, new Object[]{xmlObjectList, QNameHelper.pretty(this._constraint.getName())});
            } else {
                IdentityConstraint.this.emitError(event, XmlErrorCodes.IDENTITY_CONSTRAINT_VALID$DUPLICATE_KEY, new Object[]{xmlObjectList, QNameHelper.pretty(this._constraint.getName())});
            }
        }

        @Override // org.apache.xmlbeans.impl.common.IdentityConstraint.ConstraintState
        public void attr(ValidatorListener.Event event, QName qName, SchemaType schemaType, String str) {
        }

        public void createFieldState(ValidatorListener.Event event, SchemaType schemaType) {
            new FieldState(this, event, schemaType);
        }

        @Override // org.apache.xmlbeans.impl.common.IdentityConstraint.ConstraintState
        public void element(ValidatorListener.Event event, SchemaType schemaType) {
            if ((this._context.element(event.getName()) & 1) != 0) {
                createFieldState(event, schemaType);
            }
        }

        @Override // org.apache.xmlbeans.impl.common.IdentityConstraint.ConstraintState
        public void endElement(ValidatorListener.Event event) {
            this._context.end();
        }

        @Override // org.apache.xmlbeans.impl.common.IdentityConstraint.ConstraintState
        public void remove(ValidatorListener.Event event) {
            for (ConstraintState constraintState = this._next; constraintState != null; constraintState = constraintState._next) {
                if (constraintState instanceof KeyrefState) {
                    KeyrefState keyrefState = (KeyrefState) constraintState;
                    if (keyrefState._constraint.getReferencedKey() == this._constraint) {
                        keyrefState.addKeyValues(this._values, true);
                    }
                }
            }
        }

        @Override // org.apache.xmlbeans.impl.common.IdentityConstraint.ConstraintState
        public void text(ValidatorListener.Event event, SchemaType schemaType, String str, boolean z) {
        }
    }

    static {
        Class cls = class$org$apache$xmlbeans$impl$common$IdentityConstraint;
        if (cls == null) {
            cls = class$("org.apache.xmlbeans.impl.common.IdentityConstraint");
            class$org$apache$xmlbeans$impl$common$IdentityConstraint = cls;
        }
        $assertionsDisabled = !cls.desiredAssertionStatus();
    }

    public IdentityConstraint(Collection collection, boolean z) {
        this._errorListener = collection;
        this._trackIdrefs = z;
    }

    private void buildIdStates() {
        IdState idState = new IdState();
        if (this._trackIdrefs) {
            new IdRefState(idState);
        }
    }

    public static /* synthetic */ Class class$(String str) {
        try {
            return Class.forName(str);
        } catch (ClassNotFoundException e2) {
            throw a.a(e2);
        }
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private void emitError(ValidatorListener.Event event, String str, Object[] objArr) {
        this._invalid = true;
        if (this._errorListener == null) {
            return;
        }
        if ($assertionsDisabled || event != null) {
            this._errorListener.add(errorForEvent(str, objArr, 0, event));
            return;
        }
        throw new AssertionError();
    }

    public static XmlError errorForEvent(String str, Object[] objArr, int i2, ValidatorListener.Event event) {
        XmlCursor locationAsCursor = event.getLocationAsCursor();
        if (locationAsCursor != null) {
            return XmlError.forCursor(str, objArr, i2, locationAsCursor);
        }
        Location location = event.getLocation();
        if (location != null) {
            return XmlError.forLocation(str, objArr, i2, location.getSystemId(), location.getLineNumber(), location.getColumnNumber(), location.getCharacterOffset());
        }
        return XmlError.forMessage(str, objArr, i2);
    }

    public static SchemaType getSimpleType(SchemaType schemaType) {
        if ($assertionsDisabled || schemaType.isSimpleType() || schemaType.getContentType() == 2) {
            while (!schemaType.isSimpleType()) {
                schemaType = schemaType.getBaseType();
            }
            return schemaType;
        }
        StringBuffer stringBuffer = new StringBuffer();
        stringBuffer.append(schemaType);
        stringBuffer.append(" does not have simple content.");
        throw new AssertionError(stringBuffer.toString());
    }

    public static boolean hasSimpleContent(SchemaType schemaType) {
        return schemaType.isSimpleType() || schemaType.getContentType() == 2;
    }

    private void newConstraintState(SchemaIdentityConstraint schemaIdentityConstraint, ValidatorListener.Event event, SchemaType schemaType) {
        if (schemaIdentityConstraint.getConstraintCategory() == 2) {
            new KeyrefState(schemaIdentityConstraint, event, schemaType);
        } else {
            new SelectorState(schemaIdentityConstraint, event, schemaType);
        }
    }

    private void newState() {
        boolean z = this._elementStack == null;
        ElementState elementState = new ElementState();
        elementState._next = this._elementStack;
        this._elementStack = elementState;
        if (z) {
            buildIdStates();
        }
    }

    public static XmlObject newValue(SchemaType schemaType, String str) {
        try {
            return schemaType.newValue(str);
        } catch (IllegalArgumentException unused) {
            return null;
        }
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private void setSavePoint(ConstraintState constraintState) {
        ElementState elementState = this._elementStack;
        if (!elementState._hasConstraints) {
            elementState._savePoint = constraintState;
        }
        this._elementStack._hasConstraints = true;
    }

    public void attr(ValidatorListener.Event event, QName qName, SchemaType schemaType, String str) {
        for (ConstraintState constraintState = this._constraintStack; constraintState != null; constraintState = constraintState._next) {
            constraintState.attr(event, qName, schemaType, str);
        }
    }

    public void element(ValidatorListener.Event event, SchemaType schemaType, SchemaIdentityConstraint[] schemaIdentityConstraintArr) {
        newState();
        for (ConstraintState constraintState = this._constraintStack; constraintState != null; constraintState = constraintState._next) {
            constraintState.element(event, schemaType);
        }
        int i2 = 0;
        while (schemaIdentityConstraintArr != null && i2 < schemaIdentityConstraintArr.length) {
            newConstraintState(schemaIdentityConstraintArr[i2], event, schemaType);
            i2++;
        }
    }

    public void endElement(ValidatorListener.Event event) {
        if (this._elementStack._hasConstraints) {
            ConstraintState constraintState = this._constraintStack;
            while (constraintState != null && constraintState != this._elementStack._savePoint) {
                constraintState.remove(event);
                constraintState = constraintState._next;
            }
            this._constraintStack = this._elementStack._savePoint;
        }
        this._elementStack = this._elementStack._next;
        for (ConstraintState constraintState2 = this._constraintStack; constraintState2 != null; constraintState2 = constraintState2._next) {
            constraintState2.endElement(event);
        }
    }

    public boolean isValid() {
        return !this._invalid;
    }

    public void text(ValidatorListener.Event event, SchemaType schemaType, String str, boolean z) {
        for (ConstraintState constraintState = this._constraintStack; constraintState != null; constraintState = constraintState._next) {
            constraintState.text(event, schemaType, str, z);
        }
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private void emitError(ValidatorListener.Event event, String str) {
        this._invalid = true;
        if (this._errorListener == null) {
            return;
        }
        if ($assertionsDisabled || event != null) {
            this._errorListener.add(errorForEvent(str, 0, event));
            return;
        }
        throw new AssertionError();
    }

    public static XmlError errorForEvent(String str, int i2, ValidatorListener.Event event) {
        XmlCursor locationAsCursor = event.getLocationAsCursor();
        if (locationAsCursor != null) {
            return XmlError.forCursor(str, i2, locationAsCursor);
        }
        Location location = event.getLocation();
        if (location != null) {
            return XmlError.forLocation(str, i2, location.getSystemId(), location.getLineNumber(), location.getColumnNumber(), location.getCharacterOffset());
        }
        return XmlError.forMessage(str, i2);
    }
}
