package org.apache.xmlbeans.impl.common;

import b.b.a.a.a;
import java.io.BufferedOutputStream;
import java.io.File;
import java.io.FileInputStream;
import java.io.FileOutputStream;
import java.io.IOException;
import java.io.InputStream;
import java.io.PrintStream;
import java.util.jar.JarEntry;
import java.util.jar.JarInputStream;
import java.util.jar.JarOutputStream;

public class JarHelper {
    public static final int BUFFER_SIZE = 2156;
    public static final char SEP = '/';
    public byte[] mBuffer = new byte[BUFFER_SIZE];
    public int mByteCount = 0;
    public String mDestJarName = "";
    public boolean mVerbose = false;

    public static void main(String[] strArr) {
        if (strArr.length < 2) {
            System.err.println("Usage: JarHelper jarname.jar directory");
            return;
        }
        JarHelper jarHelper = new JarHelper();
        jarHelper.mVerbose = true;
        jarHelper.jarDir(new File(strArr[1]), new File(strArr[0]));
    }

    public void jarDir(File file, File file2) {
        if (file == null || file2 == null) {
            throw new IllegalArgumentException();
        }
        this.mDestJarName = file2.getCanonicalPath();
        FileOutputStream fileOutputStream = new FileOutputStream(file2);
        JarOutputStream jarOutputStream = new JarOutputStream(fileOutputStream);
        try {
            jarDir(file, jarOutputStream, null);
            jarOutputStream.close();
            fileOutputStream.close();
        } catch (IOException e2) {
            throw e2;
        } catch (Throwable th) {
            jarOutputStream.close();
            fileOutputStream.close();
            throw th;
        }
    }

    public void setVerbose(boolean z) {
        this.mVerbose = z;
    }

    public void unjar(InputStream inputStream, File file) {
        JarInputStream jarInputStream = new JarInputStream(inputStream);
        while (true) {
            JarEntry nextJarEntry = jarInputStream.getNextJarEntry();
            if (nextJarEntry == null) {
                jarInputStream.close();
                return;
            } else if (nextJarEntry.isDirectory()) {
                File file2 = new File(file, nextJarEntry.getName());
                file2.mkdir();
                if (nextJarEntry.getTime() != -1) {
                    file2.setLastModified(nextJarEntry.getTime());
                }
            } else {
                byte[] bArr = new byte[BUFFER_SIZE];
                File file3 = new File(file, nextJarEntry.getName());
                if (this.mVerbose) {
                    PrintStream printStream = System.out;
                    StringBuffer stringBuffer = new StringBuffer();
                    stringBuffer.append("unjarring ");
                    stringBuffer.append(file3);
                    stringBuffer.append(" from ");
                    stringBuffer.append(nextJarEntry.getName());
                    printStream.println(stringBuffer.toString());
                }
                BufferedOutputStream bufferedOutputStream = new BufferedOutputStream(new FileOutputStream(file3), BUFFER_SIZE);
                while (true) {
                    int read = jarInputStream.read(bArr, 0, BUFFER_SIZE);
                    if (read == -1) {
                        break;
                    }
                    bufferedOutputStream.write(bArr, 0, read);
                }
                bufferedOutputStream.flush();
                bufferedOutputStream.close();
                if (nextJarEntry.getTime() != -1) {
                    file3.setLastModified(nextJarEntry.getTime());
                }
            }
        }
    }

    public void unjarDir(File file, File file2) {
        unjar(new FileInputStream(file), file2);
    }

    private void jarDir(File file, JarOutputStream jarOutputStream, String str) {
        String str2;
        if (this.mVerbose) {
            PrintStream printStream = System.out;
            StringBuffer stringBuffer = new StringBuffer();
            stringBuffer.append("checking ");
            stringBuffer.append(file);
            printStream.println(stringBuffer.toString());
        }
        if (file.isDirectory()) {
            String[] list = file.list();
            if (str == null) {
                str2 = "";
            } else {
                StringBuffer a = a.a(str);
                a.append(file.getName());
                a.append(SEP);
                str2 = a.toString();
            }
            if (str != null) {
                JarEntry jarEntry = new JarEntry(str2);
                jarEntry.setTime(file.lastModified());
                jarOutputStream.putNextEntry(jarEntry);
                jarOutputStream.flush();
                jarOutputStream.closeEntry();
            }
            for (String str3 : list) {
                jarDir(new File(file, str3), jarOutputStream, str2);
            }
        } else if (!file.getCanonicalPath().equals(this.mDestJarName)) {
            if (this.mVerbose) {
                PrintStream printStream2 = System.out;
                StringBuffer a2 = a.a("adding ");
                a2.append(file.getPath());
                printStream2.println(a2.toString());
            }
            FileInputStream fileInputStream = new FileInputStream(file);
            try {
                StringBuffer stringBuffer2 = new StringBuffer();
                stringBuffer2.append(str);
                stringBuffer2.append(file.getName());
                JarEntry jarEntry2 = new JarEntry(stringBuffer2.toString());
                jarEntry2.setTime(file.lastModified());
                jarOutputStream.putNextEntry(jarEntry2);
                while (true) {
                    int read = fileInputStream.read(this.mBuffer);
                    this.mByteCount = read;
                    if (read != -1) {
                        jarOutputStream.write(this.mBuffer, 0, read);
                        if (this.mVerbose) {
                            PrintStream printStream3 = System.out;
                            StringBuffer stringBuffer3 = new StringBuffer();
                            stringBuffer3.append("wrote ");
                            stringBuffer3.append(this.mByteCount);
                            stringBuffer3.append(" bytes");
                            printStream3.println(stringBuffer3.toString());
                        }
                    } else {
                        jarOutputStream.flush();
                        jarOutputStream.closeEntry();
                        fileInputStream.close();
                        return;
                    }
                }
            } catch (IOException e2) {
                throw e2;
            } catch (Throwable th) {
                fileInputStream.close();
                throw th;
            }
        } else if (this.mVerbose) {
            PrintStream printStream4 = System.out;
            StringBuffer a3 = a.a("skipping ");
            a3.append(file.getPath());
            printStream4.println(a3.toString());
        }
    }
}
