package org.apache.xmlbeans.impl.common;

import b.b.a.a.a;
import java.util.ArrayList;
import java.util.Arrays;
import java.util.HashSet;
import java.util.Iterator;
import java.util.List;
import java.util.Set;
import org.apache.poi.javax.xml.namespace.QName;
import org.apache.poi.ss.formula.functions.Complex;
import org.apache.xerces.impl.xs.SchemaSymbols;
import org.apache.xmlbeans.impl.jam.internal.elements.VoidClassImpl;
import org.apache.xmlbeans.impl.jam.xml.JamXmlElements;

public class NameUtil {
    public static final char AYAH = 1757;
    public static final char COLON = ':';
    public static final boolean DEBUG = false;
    public static final int DIGIT = 2;
    public static final char DOT = 183;
    public static final char ELHIZB = 1758;
    public static final char HYPHEN = '-';
    public static final String JAVA_NS_PREFIX = "java:";
    public static final String LANG_PREFIX = "java.";
    public static final int LOWER = 5;
    public static final int MARK = 3;
    public static final int NOCASE = 6;
    public static final char PERIOD = '.';
    public static final int PUNCT = 1;
    public static final int START = 0;
    public static final char TELEIA = 903;
    public static final int UPPER = 4;
    public static final char USCORE = '_';
    public static final Set extraWords = new HashSet(Arrays.asList(Complex.DEFAULT_SUFFIX, "target", "org", "com"));
    public static final Set javaNames = new HashSet(Arrays.asList("CharSequence", "Cloneable", "Comparable", "Runnable", "Boolean", "Byte", "Character", "Class", "ClassLoader", "Compiler", "Double", "Float", "InheritableThreadLocal", "Integer", "Long", "Math", "Number", "Object", "Package", "Process", "Runtime", "RuntimePermission", "SecurityManager", "Short", "StackTraceElement", "StrictMath", "String", "StringBuffer", "System", "Thread", "ThreadGroup", "ThreadLocal", "Throwable", "Void", "ArithmeticException", "ArrayIndexOutOfBoundsException", "ArrayStoreException", "ClassCastException", "ClassNotFoundException", "CloneNotSupportedException", "Exception", "IllegalAccessException", "IllegalArgumentException", "IllegalMonitorStateException", "IllegalStateException", "IllegalThreadStateException", "IndexOutOfBoundsException", "InstantiationException", "InterruptedException", "NegativeArraySizeException", "NoSuchFieldException", "NoSuchMethodException", "NullPointerException", "NumberFormatException", "RuntimeException", "SecurityException", "StringIndexOutOfBoundsException", "UnsupportedOperationException", "AbstractMethodError", "AssertionError", "ClassCircularityError", "ClassFormatError", "Error", "ExceptionInInitializerError", "IllegalAccessError", "IncompatibleClassChangeError", "InstantiationError", "InternalError", "LinkageError", "NoClassDefFoundError", "NoSuchFieldError", "NoSuchMethodError", "OutOfMemoryError", "StackOverflowError", "ThreadDeath", "UnknownError", "UnsatisfiedLinkError", "UnsupportedClassVersionError", "VerifyError", "VirtualMachineError", "BigInteger", "BigDecimal", "Enum", "Date", "GDate", "GDuration", "QName", "List", "XmlObject", "XmlCursor", "XmlBeans", "SchemaType"));
    public static final Set javaWords = new HashSet(Arrays.asList("assert", "abstract", "boolean", "break", SchemaSymbols.ATTVAL_BYTE, "case", "catch", "char", JamXmlElements.CLASS, "const", "continue", "default", "do", "double", "else", "enum", "extends", SchemaSymbols.ATTVAL_FALSE, "final", "finally", "float", "for", "goto", "if", "implements", "import", "instanceof", "int", JamXmlElements.INTERFACE, "long", "native", "new", "null", "package", "private", "protected", "public", "return", SchemaSymbols.ATTVAL_SHORT, "static", "strictfp", "super", "switch", "synchronized", "this", "threadsafe", "throw", "throws", "transient", SchemaSymbols.ATTVAL_TRUE, "try", VoidClassImpl.SIMPLE_NAME, "volatile", "while"));

    public static void addCapped(List list, String str) {
        if (str.length() > 0) {
            list.add(upperCaseFirstLetter(str));
        }
    }

    public static int findSchemeColon(String str) {
        int length = str.length();
        if (length == 0 || !isUriAlphaChar(str.charAt(0))) {
            return -1;
        }
        int i2 = 1;
        while (i2 < length && isUriSchemeChar(str.charAt(i2))) {
            i2++;
        }
        if (i2 == length || str.charAt(i2) != ':') {
            return -1;
        }
        while (i2 < length && str.charAt(i2) == ':') {
            i2++;
        }
        return i2 - 1;
    }

    public static int getCharClass(char c, boolean z) {
        if (isPunctuation(c, z)) {
            return 1;
        }
        if (Character.isDigit(c)) {
            return 2;
        }
        if (Character.isUpperCase(c)) {
            return 4;
        }
        if (Character.isLowerCase(c)) {
            return 5;
        }
        if (Character.isLetter(c)) {
            return 6;
        }
        if (Character.isJavaIdentifierPart(c)) {
            return 3;
        }
        return 1;
    }

    public static String getClassNameFromQName(QName qName) {
        return getClassNameFromQName(qName, false);
    }

    public static String getNamespaceFromPackage(Class cls) {
        String str;
        for (Class cls2 = cls; cls2.isArray(); cls2 = cls2.getComponentType()) {
        }
        String name = cls.getName();
        int lastIndexOf = name.lastIndexOf(46);
        if (lastIndexOf < 0) {
            str = "";
        } else {
            str = name.substring(0, lastIndexOf);
        }
        return a.a(JAVA_NS_PREFIX, str);
    }

    public static String getPackageFromNamespace(String str) {
        return getPackageFromNamespace(str, false);
    }

    public static boolean isExtraReservedWord(String str, boolean z) {
        if (z) {
            str = str.toLowerCase();
        }
        return extraWords.contains(str);
    }

    public static boolean isJavaCommonClassName(String str) {
        return javaNames.contains(str);
    }

    public static boolean isJavaReservedWord(String str) {
        return isJavaReservedWord(str, true);
    }

    public static boolean isLetter(int i2) {
        return i2 == 4 || i2 == 5 || i2 == 6;
    }

    public static boolean isPunctuation(char c, boolean z) {
        return c == '-' || c == '.' || c == ':' || c == 183 || (c == '_' && !z) || c == 903 || c == 1757 || c == 1758;
    }

    public static boolean isUriAlphaChar(char c) {
        return (c >= 'a' && c <= 'z') || (c >= 'A' && c <= 'Z');
    }

    public static boolean isUriSchemeChar(char c) {
        return (c >= 'a' && c <= 'z') || (c >= 'A' && c <= 'Z') || ((c >= '0' && c <= '9') || c == '-' || c == '.' || c == '+');
    }

    public static boolean isValidJavaIdentifier(String str) {
        if (str != null) {
            int length = str.length();
            if (length == 0 || javaWords.contains(str) || !Character.isJavaIdentifierStart(str.charAt(0))) {
                return false;
            }
            for (int i2 = 1; i2 < length; i2++) {
                if (!Character.isJavaIdentifierPart(str.charAt(i2))) {
                    return false;
                }
            }
            return true;
        }
        throw new IllegalArgumentException("id cannot be null");
    }

    public static String jls77String(String str) {
        StringBuffer stringBuffer = new StringBuffer(str);
        for (int i2 = 0; i2 < str.length(); i2++) {
            if (!Character.isJavaIdentifierPart(stringBuffer.charAt(i2)) || '$' == stringBuffer.charAt(i2)) {
                stringBuffer.setCharAt(i2, USCORE);
            }
        }
        if (stringBuffer.length() == 0 || !Character.isJavaIdentifierStart(stringBuffer.charAt(0))) {
            stringBuffer.insert(0, USCORE);
        }
        if (isJavaReservedWord(str)) {
            stringBuffer.append(USCORE);
        }
        return stringBuffer.toString();
    }

    public static String lowerCamelCase(String str) {
        return lowerCamelCase(str, false, true);
    }

    public static void main(String[] strArr) {
        for (String str : strArr) {
            System.out.println(upperCaseUnderbar(str));
        }
    }

    public static String nonExtraKeyword(String str) {
        return isExtraReservedWord(str, true) ? a.a(str, "Value") : str;
    }

    public static String nonJavaCommonClassName(String str) {
        return isJavaCommonClassName(str) ? a.a("X", str) : str;
    }

    public static String nonJavaKeyword(String str) {
        if (!isJavaReservedWord(str)) {
            return str;
        }
        StringBuffer stringBuffer = new StringBuffer();
        stringBuffer.append('x');
        stringBuffer.append(str);
        return stringBuffer.toString();
    }

    public static String processFilename(String str) {
        int lastIndexOf = str.lastIndexOf(46);
        if (lastIndexOf <= 0) {
            return str;
        }
        int i2 = lastIndexOf + 1;
        return (i2 + 2 == str.length() || i2 + 3 == str.length() || str.substring(i2).toLowerCase() == "html") ? str.substring(0, lastIndexOf) : str;
    }

    public static List splitDNS(String str) {
        ArrayList arrayList = new ArrayList();
        int length = str.length();
        for (int lastIndexOf = str.lastIndexOf(46); lastIndexOf != -1; lastIndexOf--) {
            if (str.charAt(lastIndexOf) == '.') {
                arrayList.add(jls77String(str.substring(lastIndexOf + 1, length)));
                length = lastIndexOf;
            }
        }
        arrayList.add(jls77String(str.substring(0, length)));
        if (arrayList.size() >= 3 && ((String) arrayList.get(arrayList.size() - 1)).toLowerCase().equals("www")) {
            arrayList.remove(arrayList.size() - 1);
        }
        return arrayList;
    }

    public static List splitWords(String str, boolean z) {
        ArrayList arrayList = new ArrayList();
        int length = str.length();
        int i2 = 0;
        int i3 = 0;
        int i4 = 0;
        while (i2 < length) {
            int charClass = getCharClass(str.charAt(i2), z);
            if (i4 != 1 && charClass == 1) {
                addCapped(arrayList, str.substring(i3, i2));
                while (true) {
                    int charClass2 = getCharClass(str.charAt(i2), z);
                    if (charClass2 != 1) {
                        i4 = charClass2;
                        i3 = i2;
                        break;
                    }
                    i2++;
                    if (i2 >= length) {
                        return arrayList;
                    }
                }
            } else {
                if ((i4 == 2) != (charClass == 2) || ((i4 == 5 && charClass != 5) || isLetter(i4) != isLetter(charClass))) {
                    addCapped(arrayList, str.substring(i3, i2));
                    i3 = i2;
                } else if (i4 == 4 && charClass == 5 && i2 > i3 + 1) {
                    int i5 = i2 - 1;
                    addCapped(arrayList, str.substring(i3, i5));
                    i3 = i5;
                }
                i4 = charClass;
            }
            i2++;
        }
        addCapped(arrayList, str.substring(i3));
        return arrayList;
    }

    public static String upperCamelCase(String str) {
        return upperCamelCase(str, false);
    }

    public static String upperCaseFirstLetter(String str) {
        if (str.length() == 0 || Character.isUpperCase(str.charAt(0))) {
            return str;
        }
        StringBuffer stringBuffer = new StringBuffer(str);
        stringBuffer.setCharAt(0, Character.toUpperCase(stringBuffer.charAt(0)));
        return stringBuffer.toString();
    }

    public static String upperCaseUnderbar(String str) {
        StringBuffer stringBuffer = new StringBuffer();
        List splitWords = splitWords(str, false);
        int size = splitWords.size() - 1;
        if (size >= 0 && !Character.isJavaIdentifierStart(((String) splitWords.get(0)).charAt(0))) {
            stringBuffer.append("X_");
        }
        for (int i2 = 0; i2 < size; i2++) {
            stringBuffer.append((String) splitWords.get(i2));
            stringBuffer.append(USCORE);
        }
        if (size >= 0) {
            stringBuffer.append((String) splitWords.get(size));
        }
        int length = stringBuffer.length();
        for (int i3 = 0; i3 < length; i3++) {
            stringBuffer.setCharAt(i3, Character.toUpperCase(stringBuffer.charAt(i3)));
        }
        return stringBuffer.toString();
    }

    public static String getClassNameFromQName(QName qName, boolean z) {
        String upperCamelCase = upperCamelCase(qName.getLocalPart(), z);
        String packageFromNamespace = getPackageFromNamespace(qName.getNamespaceURI(), z);
        return packageFromNamespace != null ? a.a(packageFromNamespace, ".", upperCamelCase) : upperCamelCase;
    }

    /* JADX WARNING: Removed duplicated region for block: B:20:0x0064  */
    public static String getPackageFromNamespace(String str, boolean z) {
        List<String> list;
        if (str == null || str.length() == 0) {
            return "noNamespace";
        }
        int length = str.length();
        int findSchemeColon = findSchemeColon(str);
        if (findSchemeColon == length - 1) {
            ArrayList arrayList = new ArrayList();
            arrayList.add(str.substring(0, findSchemeColon));
            list = arrayList;
        } else if (findSchemeColon < 0 || !str.substring(0, findSchemeColon).equals("java")) {
            ArrayList arrayList2 = new ArrayList();
            int i2 = findSchemeColon + 1;
            loop0:
            while (i2 < length) {
                while (str.charAt(i2) == '/') {
                    i2++;
                    if (i2 >= length) {
                        break loop0;
                    }
                }
                int i3 = i2;
                while (str.charAt(i3) != '/' && (i3 = i3 + 1) < length) {
                    while (str.charAt(i3) != '/') {
                        while (str.charAt(i3) != '/') {
                        }
                    }
                }
                arrayList2.add(str.substring(i2, i3));
                i2 = i3;
            }
            if (arrayList2.size() > 1) {
                arrayList2.set(arrayList2.size() - 1, processFilename((String) arrayList2.get(arrayList2.size() - 1)));
            }
            if (arrayList2.size() > 0) {
                List splitDNS = splitDNS((String) arrayList2.get(0));
                arrayList2.remove(0);
                arrayList2.addAll(0, splitDNS);
            }
            list = arrayList2;
        } else {
            list = Arrays.asList(str.substring(findSchemeColon + 1).split("\\."));
        }
        StringBuffer stringBuffer = new StringBuffer();
        for (String str2 : list) {
            String nonJavaKeyword = nonJavaKeyword(lowerCamelCase(str2, z, true));
            if (nonJavaKeyword.length() > 0) {
                stringBuffer.append(nonJavaKeyword);
                stringBuffer.append(PERIOD);
            }
        }
        if (stringBuffer.length() == 0) {
            return "noNamespace";
        }
        if (z) {
            return stringBuffer.substring(0, stringBuffer.length() - 1).toLowerCase();
        }
        return stringBuffer.substring(0, stringBuffer.length() - 1);
    }

    public static boolean isJavaReservedWord(String str, boolean z) {
        if (z) {
            str = str.toLowerCase();
        }
        return javaWords.contains(str);
    }

    public static String lowerCamelCase(String str, boolean z, boolean z2) {
        StringBuffer stringBuffer = new StringBuffer();
        List splitWords = splitWords(str, z);
        if (splitWords.size() > 0) {
            String lowerCase = ((String) splitWords.get(0)).toLowerCase();
            if (!Character.isJavaIdentifierStart(lowerCase.charAt(0)) && z2) {
                stringBuffer.append("x");
            }
            stringBuffer.append(lowerCase);
            Iterator it = splitWords.iterator();
            it.next();
            while (it.hasNext()) {
                stringBuffer.append((String) it.next());
            }
        }
        return stringBuffer.toString();
    }

    public static String upperCamelCase(String str, boolean z) {
        StringBuffer stringBuffer = new StringBuffer();
        List<String> splitWords = splitWords(str, z);
        if (splitWords.size() > 0) {
            if (!Character.isJavaIdentifierStart(((String) splitWords.get(0)).charAt(0))) {
                stringBuffer.append("X");
            }
            for (String str2 : splitWords) {
                stringBuffer.append(str2);
            }
        }
        return stringBuffer.toString();
    }
}
