package org.apache.xmlbeans.impl.common;

import b.b.a.a.a;
import java.io.UnsupportedEncodingException;
import java.security.MessageDigest;
import java.security.NoSuchAlgorithmException;
import java.util.Collections;
import java.util.HashMap;
import java.util.Map;
import org.apache.poi.javax.xml.namespace.QName;
import org.apache.poi.openxml4j.opc.internal.ZipHelper;
import org.apache.poi.ss.util.SheetUtil;
import org.apache.xmlbeans.SchemaField;
import org.apache.xmlbeans.SchemaType;
import org.apache.xmlbeans.impl.soap.SOAPConstants;
import org.apache.xmlbeans.xml.stream.XMLName;

public class QNameHelper {
    public static final /* synthetic */ boolean $assertionsDisabled;
    public static final int MAX_NAME_LENGTH = 64;
    public static final String URI_SHA1_PREFIX = "URI_SHA_1_";
    public static final Map WELL_KNOWN_PREFIXES = buildWKP();
    public static /* synthetic */ Class class$org$apache$xmlbeans$impl$common$QNameHelper;
    public static final char[] hexdigits = {SheetUtil.defaultChar, '1', '2', '3', '4', '5', '6', '7', '8', '9', 'A', 'B', 'C', 'D', 'E', 'F'};

    static {
        Class cls = class$org$apache$xmlbeans$impl$common$QNameHelper;
        if (cls == null) {
            cls = class$("org.apache.xmlbeans.impl.common.QNameHelper");
            class$org$apache$xmlbeans$impl$common$QNameHelper = cls;
        }
        $assertionsDisabled = !cls.desiredAssertionStatus();
    }

    public static Map buildWKP() {
        HashMap hashMap = new HashMap();
        hashMap.put("http://www.w3.org/XML/1998/namespace", "xml");
        hashMap.put("http://www.w3.org/2001/XMLSchema", "xs");
        hashMap.put("http://www.w3.org/2001/XMLSchema-instance", "xsi");
        hashMap.put("http://schemas.xmlsoap.org/wsdl/", "wsdl");
        hashMap.put("http://schemas.xmlsoap.org/soap/encoding/", "soapenc");
        hashMap.put(SOAPConstants.URI_NS_SOAP_ENVELOPE, "soapenv");
        return Collections.unmodifiableMap(hashMap);
    }

    public static /* synthetic */ Class class$(String str) {
        try {
            return Class.forName(str);
        } catch (ClassNotFoundException e2) {
            throw a.a(e2);
        }
    }

    public static QName forLN(String str) {
        return new QName("", str);
    }

    public static QName forLNS(String str, String str2) {
        if (str2 == null) {
            str2 = "";
        }
        return new QName(str2, str);
    }

    public static QName forPretty(String str, int i2) {
        int indexOf = str.indexOf(64, i2);
        if (indexOf < 0) {
            return new QName("", str.substring(i2));
        }
        return new QName(str.substring(indexOf + 1), str.substring(i2, indexOf));
    }

    public static String getLocalPart(String str) {
        int indexOf = str.indexOf(58);
        return indexOf < 0 ? str : str.substring(indexOf + 1);
    }

    public static String getPrefixPart(String str) {
        int indexOf = str.indexOf(58);
        return indexOf >= 0 ? str.substring(0, indexOf) : "";
    }

    public static XMLName getXMLName(QName qName) {
        if (qName == null) {
            return null;
        }
        return XMLNameHelper.forLNS(qName.getLocalPart(), qName.getNamespaceURI());
    }

    public static String hexsafe(String str) {
        byte[] bArr;
        StringBuffer stringBuffer = new StringBuffer();
        for (int i2 = 0; i2 < str.length(); i2++) {
            char charAt = str.charAt(i2);
            if (isSafe(charAt)) {
                stringBuffer.append(charAt);
            } else {
                try {
                    byte[] bytes = str.substring(i2, i2 + 1).getBytes("UTF-8");
                    for (int i3 = 0; i3 < bytes.length; i3++) {
                        stringBuffer.append(NameUtil.USCORE);
                        stringBuffer.append(hexdigits[(bytes[i3] >> 4) & 15]);
                        stringBuffer.append(hexdigits[bytes[i3] & 15]);
                    }
                } catch (UnsupportedEncodingException unused) {
                    stringBuffer.append("_BAD_UTF8_CHAR");
                }
            }
        }
        if (stringBuffer.length() <= 64) {
            return stringBuffer.toString();
        }
        try {
            MessageDigest instance = MessageDigest.getInstance("SHA");
            try {
                bArr = str.getBytes("UTF-8");
            } catch (UnsupportedEncodingException unused2) {
                bArr = new byte[0];
            }
            byte[] digest = instance.digest(bArr);
            if ($assertionsDisabled || digest.length == 20) {
                StringBuffer stringBuffer2 = new StringBuffer(URI_SHA1_PREFIX);
                for (int i4 = 0; i4 < digest.length; i4++) {
                    stringBuffer2.append(hexdigits[(digest[i4] >> 4) & 15]);
                    stringBuffer2.append(hexdigits[digest[i4] & 15]);
                }
                return stringBuffer2.toString();
            }
            throw new AssertionError();
        } catch (NoSuchAlgorithmException unused3) {
            throw new IllegalStateException("Using in a JDK without an SHA implementation");
        }
    }

    public static String hexsafedir(QName qName) {
        if (qName.getNamespaceURI() == null || qName.getNamespaceURI().length() == 0) {
            StringBuffer a = a.a("_nons/");
            a.append(hexsafe(qName.getLocalPart()));
            return a.toString();
        }
        StringBuffer stringBuffer = new StringBuffer();
        stringBuffer.append(hexsafe(qName.getNamespaceURI()));
        stringBuffer.append(ZipHelper.FORWARD_SLASH);
        stringBuffer.append(hexsafe(qName.getLocalPart()));
        return stringBuffer.toString();
    }

    public static boolean isSafe(int i2) {
        if (i2 >= 97 && i2 <= 122) {
            return true;
        }
        if (i2 < 65 || i2 > 90) {
            return i2 >= 48 && i2 <= 57;
        }
        return true;
    }

    public static boolean isVowel(char c) {
        return c == 'A' || c == 'E' || c == 'I' || c == 'O' || c == 'U' || c == 'a' || c == 'e' || c == 'i' || c == 'o' || c == 'u';
    }

    public static String namespace(SchemaType schemaType) {
        while (schemaType != null) {
            if (schemaType.getName() != null) {
                return schemaType.getName().getNamespaceURI();
            }
            if (schemaType.getContainerField() != null && schemaType.getContainerField().getName().getNamespaceURI().length() > 0) {
                return schemaType.getContainerField().getName().getNamespaceURI();
            }
            schemaType = schemaType.getOuterType();
        }
        return "";
    }

    public static String pretty(QName qName) {
        if (qName == null) {
            return "null";
        }
        if (qName.getNamespaceURI() == null || qName.getNamespaceURI().length() == 0) {
            return qName.getLocalPart();
        }
        StringBuffer stringBuffer = new StringBuffer();
        stringBuffer.append(qName.getLocalPart());
        stringBuffer.append("@");
        stringBuffer.append(qName.getNamespaceURI());
        return stringBuffer.toString();
    }

    public static String readable(SchemaType schemaType) {
        return readable(schemaType, WELL_KNOWN_PREFIXES);
    }

    public static boolean startsWithXml(String str, int i2) {
        if (str.length() < i2 + 3) {
            return false;
        }
        if (str.charAt(i2) != 'X' && str.charAt(i2) != 'x') {
            return false;
        }
        int i3 = i2 + 1;
        if (str.charAt(i3) != 'M' && str.charAt(i3) != 'm') {
            return false;
        }
        int i4 = i2 + 2;
        if (str.charAt(i4) == 'L' || str.charAt(i4) == 'l') {
            return true;
        }
        return false;
    }

    public static String suggestPrefix(String str) {
        String str2 = (String) WELL_KNOWN_PREFIXES.get(str);
        if (str2 != null) {
            return str2;
        }
        int length = str.length();
        int lastIndexOf = str.lastIndexOf(47);
        if (lastIndexOf > 0 && lastIndexOf == str.length() - 1) {
            lastIndexOf = str.lastIndexOf(47, lastIndexOf - 1);
            length = lastIndexOf;
        }
        int i2 = lastIndexOf + 1;
        if (str.startsWith("www.", i2)) {
            i2 += 4;
        }
        while (i2 < length && !XMLChar.isNCNameStart(str.charAt(i2))) {
            i2++;
        }
        int i3 = i2 + 1;
        while (true) {
            if (i3 >= length) {
                break;
            } else if (!XMLChar.isNCName(str.charAt(i3)) || !Character.isLetterOrDigit(str.charAt(i3))) {
                length = i3;
            } else {
                i3++;
            }
        }
        length = i3;
        int i4 = i2 + 3;
        if (str.length() < i4 || !startsWithXml(str, i2)) {
            if (length - i2 > 4) {
                length = (!isVowel(str.charAt(i2 + 2)) || isVowel(str.charAt(i4))) ? i4 : i2 + 4;
            }
            if (length - i2 == 0) {
                return "ns";
            }
            return str.substring(i2, length).toLowerCase();
        } else if (str.length() < i2 + 4) {
            return "ns";
        } else {
            StringBuffer a = a.a("x");
            a.append(Character.toLowerCase(str.charAt(i4)));
            return a.toString();
        }
    }

    public static String readable(SchemaType schemaType, Map map) {
        if (schemaType.getName() != null) {
            return readable(schemaType.getName(), map);
        }
        if (schemaType.isAttributeType()) {
            StringBuffer a = a.a("attribute type ");
            a.append(readable(schemaType.getAttributeTypeAttributeName(), map));
            return a.toString();
        } else if (schemaType.isDocumentType()) {
            StringBuffer a2 = a.a("document type ");
            a2.append(readable(schemaType.getDocumentElementName(), map));
            return a2.toString();
        } else if (schemaType.isNoType() || schemaType.getOuterType() == null) {
            return "invalid type";
        } else {
            SchemaType outerType = schemaType.getOuterType();
            SchemaField containerField = schemaType.getContainerField();
            if (outerType.isAttributeType()) {
                StringBuffer a3 = a.a("type of attribute ");
                a3.append(readable(containerField.getName(), map));
                return a3.toString();
            } else if (outerType.isDocumentType()) {
                StringBuffer a4 = a.a("type of element ");
                a4.append(readable(containerField.getName(), map));
                return a4.toString();
            } else if (containerField != null) {
                if (containerField.isAttribute()) {
                    StringBuffer a5 = a.a("type of ");
                    a5.append(containerField.getName().getLocalPart());
                    a5.append(" attribute in ");
                    a5.append(readable(outerType, map));
                    return a5.toString();
                }
                StringBuffer a6 = a.a("type of ");
                a6.append(containerField.getName().getLocalPart());
                a6.append(" element in ");
                a6.append(readable(outerType, map));
                return a6.toString();
            } else if (outerType.getBaseType() == schemaType) {
                StringBuffer a7 = a.a("base type of ");
                a7.append(readable(outerType, map));
                return a7.toString();
            } else if (outerType.getSimpleVariety() == 3) {
                StringBuffer a8 = a.a("item type of ");
                a8.append(readable(outerType, map));
                return a8.toString();
            } else if (outerType.getSimpleVariety() == 2) {
                StringBuffer a9 = a.a("member type ");
                a9.append(schemaType.getAnonymousUnionMemberOrdinal());
                a9.append(" of ");
                a9.append(readable(outerType, map));
                return a9.toString();
            } else {
                StringBuffer a10 = a.a("inner type in ");
                a10.append(readable(outerType, map));
                return a10.toString();
            }
        }
    }

    public static String readable(QName qName) {
        return readable(qName, WELL_KNOWN_PREFIXES);
    }

    public static String readable(QName qName, Map map) {
        if (qName.getNamespaceURI().length() == 0) {
            return qName.getLocalPart();
        }
        String str = (String) map.get(qName.getNamespaceURI());
        if (str != null) {
            StringBuffer c = a.c(str, ":");
            c.append(qName.getLocalPart());
            return c.toString();
        }
        StringBuffer stringBuffer = new StringBuffer();
        stringBuffer.append(qName.getLocalPart());
        stringBuffer.append(" in namespace ");
        stringBuffer.append(qName.getNamespaceURI());
        return stringBuffer.toString();
    }
}
