package org.apache.xmlbeans.impl.common;

import org.apache.poi.javax.xml.stream.XMLStreamReader;
import org.apache.poi.javax.xml.stream.XMLStreamWriter;

public final class XmlReaderToWriter {
    public static void write(XMLStreamReader xMLStreamReader, XMLStreamWriter xMLStreamWriter) {
        switch (xMLStreamReader.getEventType()) {
            case 1:
                String localName = xMLStreamReader.getLocalName();
                String namespaceURI = xMLStreamReader.getNamespaceURI();
                if (namespaceURI == null || namespaceURI.length() <= 0) {
                    xMLStreamWriter.writeStartElement(localName);
                } else {
                    String prefix = xMLStreamReader.getPrefix();
                    if (prefix != null) {
                        xMLStreamWriter.writeStartElement(prefix, localName, namespaceURI);
                    } else {
                        xMLStreamWriter.writeStartElement(namespaceURI, localName);
                    }
                }
                int namespaceCount = xMLStreamReader.getNamespaceCount();
                for (int i2 = 0; i2 < namespaceCount; i2++) {
                    xMLStreamWriter.writeNamespace(xMLStreamReader.getNamespacePrefix(i2), xMLStreamReader.getNamespaceURI(i2));
                }
                int attributeCount = xMLStreamReader.getAttributeCount();
                for (int i3 = 0; i3 < attributeCount; i3++) {
                    String attributeNamespace = xMLStreamReader.getAttributeNamespace(i3);
                    if (attributeNamespace != null) {
                        xMLStreamWriter.writeAttribute(attributeNamespace, xMLStreamReader.getAttributeLocalName(i3), xMLStreamReader.getAttributeValue(i3));
                    } else {
                        xMLStreamWriter.writeAttribute(xMLStreamReader.getAttributeLocalName(i3), xMLStreamReader.getAttributeValue(i3));
                    }
                }
                return;
            case 2:
                xMLStreamWriter.writeEndElement();
                return;
            case 3:
                xMLStreamWriter.writeProcessingInstruction(xMLStreamReader.getPITarget(), xMLStreamReader.getPIData());
                return;
            case 4:
            case 6:
                xMLStreamWriter.writeCharacters(xMLStreamReader.getTextCharacters(), xMLStreamReader.getTextStart(), xMLStreamReader.getTextLength());
                return;
            case 5:
                xMLStreamWriter.writeComment(xMLStreamReader.getText());
                return;
            case 7:
                String characterEncodingScheme = xMLStreamReader.getCharacterEncodingScheme();
                String version = xMLStreamReader.getVersion();
                if (characterEncodingScheme != null && version != null) {
                    xMLStreamWriter.writeStartDocument(characterEncodingScheme, version);
                    return;
                } else if (version != null) {
                    xMLStreamWriter.writeStartDocument(xMLStreamReader.getVersion());
                    return;
                } else {
                    return;
                }
            case 8:
                xMLStreamWriter.writeEndDocument();
                return;
            case 9:
                xMLStreamWriter.writeEntityRef(xMLStreamReader.getLocalName());
                return;
            case 10:
            default:
                return;
            case 11:
                xMLStreamWriter.writeDTD(xMLStreamReader.getText());
                return;
            case 12:
                xMLStreamWriter.writeCData(xMLStreamReader.getText());
                return;
        }
    }

    public static void writeAll(XMLStreamReader xMLStreamReader, XMLStreamWriter xMLStreamWriter) {
        while (xMLStreamReader.hasNext()) {
            write(xMLStreamReader, xMLStreamWriter);
            xMLStreamReader.next();
        }
        write(xMLStreamReader, xMLStreamWriter);
        xMLStreamWriter.flush();
    }
}
