package org.apache.xmlbeans.impl.config;

import b.b.a.a.a;
import org.apache.xmlbeans.InterfaceExtension;
import org.apache.xmlbeans.XmlObject;
import org.apache.xmlbeans.impl.common.NameUtil;
import org.apache.xmlbeans.impl.jam.JClass;
import org.apache.xmlbeans.impl.jam.JMethod;
import org.apache.xmlbeans.impl.jam.JParameter;
import org.apache.xmlbeans.impl.jam.JamClassLoader;
import org.apache.xmlbeans.impl.xb.xmlconfig.Extensionconfig;

public class InterfaceExtensionImpl implements InterfaceExtension {
    public String _delegateToClassName;
    public String _interfaceClassName;
    public MethodSignatureImpl[] _methods;
    public NameSet _xbeanSet;

    public static class MethodSignatureImpl implements InterfaceExtension.MethodSignature {
        public final int NOTINITIALIZED = -1;
        public String[] _exceptions;
        public int _hashCode = -1;
        public String _intfName;
        public String _name;
        public String[] _params;
        public String _return;
        public String _signature;

        public MethodSignatureImpl(String str, JMethod jMethod) {
            if (str == null || jMethod == null) {
                StringBuffer stringBuffer = new StringBuffer();
                stringBuffer.append("Interface: ");
                stringBuffer.append(str);
                stringBuffer.append(" method: ");
                stringBuffer.append(jMethod);
                throw new IllegalArgumentException(stringBuffer.toString());
            }
            this._intfName = str;
            this._hashCode = -1;
            this._signature = null;
            this._name = jMethod.getSimpleName();
            this._return = jMethod.getReturnType().getQualifiedName().replace('$', NameUtil.PERIOD);
            JParameter[] parameters = jMethod.getParameters();
            this._params = new String[parameters.length];
            for (int i2 = 0; i2 < parameters.length; i2++) {
                this._params[i2] = parameters[i2].getType().getQualifiedName().replace('$', NameUtil.PERIOD);
            }
            JClass[] exceptionTypes = jMethod.getExceptionTypes();
            this._exceptions = new String[exceptionTypes.length];
            for (int i3 = 0; i3 < exceptionTypes.length; i3++) {
                this._exceptions[i3] = exceptionTypes[i3].getQualifiedName().replace('$', NameUtil.PERIOD);
            }
        }

        public boolean equals(Object obj) {
            if (!(obj instanceof MethodSignatureImpl)) {
                return false;
            }
            MethodSignatureImpl methodSignatureImpl = (MethodSignatureImpl) obj;
            if (!methodSignatureImpl.getName().equals(getName())) {
                return false;
            }
            String[] parameterTypes = getParameterTypes();
            String[] parameterTypes2 = methodSignatureImpl.getParameterTypes();
            if (parameterTypes2.length != parameterTypes.length) {
                return false;
            }
            for (int i2 = 0; i2 < parameterTypes.length; i2++) {
                if (!parameterTypes2[i2].equals(parameterTypes[i2])) {
                    return false;
                }
            }
            if (!this._intfName.equals(methodSignatureImpl._intfName)) {
                return false;
            }
            return true;
        }

        @Override // org.apache.xmlbeans.InterfaceExtension.MethodSignature
        public String[] getExceptionTypes() {
            return this._exceptions;
        }

        public String getInterfaceName() {
            return this._intfName;
        }

        @Override // org.apache.xmlbeans.InterfaceExtension.MethodSignature
        public String getName() {
            return this._name;
        }

        @Override // org.apache.xmlbeans.InterfaceExtension.MethodSignature
        public String[] getParameterTypes() {
            return this._params;
        }

        @Override // org.apache.xmlbeans.InterfaceExtension.MethodSignature
        public String getReturnType() {
            return this._return;
        }

        public String getSignature() {
            String str = this._signature;
            if (str != null) {
                return str;
            }
            StringBuffer stringBuffer = new StringBuffer(60);
            stringBuffer.append(this._name);
            stringBuffer.append("(");
            int i2 = 0;
            while (i2 < this._params.length) {
                stringBuffer.append(i2 == 0 ? "" : " ,");
                stringBuffer.append(this._params[i2]);
                i2++;
            }
            stringBuffer.append(")");
            String stringBuffer2 = stringBuffer.toString();
            this._signature = stringBuffer2;
            return stringBuffer2;
        }

        public int hashCode() {
            String[] parameterTypes;
            int i2 = this._hashCode;
            if (i2 != -1) {
                return i2;
            }
            int hashCode = getName().hashCode();
            for (String str : getParameterTypes()) {
                hashCode = (hashCode * 19) + str.hashCode();
            }
            int hashCode2 = (this._intfName.hashCode() * 21) + hashCode;
            this._hashCode = hashCode2;
            return hashCode2;
        }

        public String toString() {
            StringBuffer stringBuffer = new StringBuffer();
            stringBuffer.append(getReturnType());
            stringBuffer.append(" ");
            stringBuffer.append(getSignature());
            return stringBuffer.toString();
        }
    }

    public static String emitType(JClass jClass) {
        if (!jClass.isArrayType()) {
            return jClass.getQualifiedName().replace('$', NameUtil.PERIOD);
        }
        StringBuffer stringBuffer = new StringBuffer();
        stringBuffer.append(emitType(jClass.getArrayComponentType()));
        stringBuffer.append("[]");
        return stringBuffer.toString();
    }

    public static JMethod getMethod(JClass jClass, String str, JClass[] jClassArr) {
        JMethod[] methods = jClass.getMethods();
        for (JMethod jMethod : methods) {
            if (str.equals(jMethod.getSimpleName())) {
                JParameter[] parameters = jMethod.getParameters();
                if (parameters.length == jClassArr.length) {
                    for (int i2 = 0; i2 < parameters.length; i2++) {
                        parameters[i2].getType().equals(jClassArr[i2]);
                    }
                    return jMethod;
                }
            }
        }
        return null;
    }

    public static String listTypes(JClass[] jClassArr) {
        StringBuffer stringBuffer = new StringBuffer();
        for (int i2 = 0; i2 < jClassArr.length; i2++) {
            JClass jClass = jClassArr[i2];
            if (i2 > 0) {
                stringBuffer.append(", ");
            }
            stringBuffer.append(emitType(jClass));
        }
        return stringBuffer.toString();
    }

    public static InterfaceExtensionImpl newInstance(JamClassLoader jamClassLoader, NameSet nameSet, Extensionconfig.Interface r5) {
        InterfaceExtensionImpl interfaceExtensionImpl = new InterfaceExtensionImpl();
        interfaceExtensionImpl._xbeanSet = nameSet;
        JClass validateInterface = validateInterface(jamClassLoader, r5.getName(), r5);
        if (validateInterface == null) {
            StringBuffer a = a.a("Interface '");
            a.append(r5.getStaticHandler());
            a.append("' not found.");
            BindingConfigImpl.error(a.toString(), r5);
            return null;
        }
        interfaceExtensionImpl._interfaceClassName = validateInterface.getQualifiedName();
        String staticHandler = r5.getStaticHandler();
        interfaceExtensionImpl._delegateToClassName = staticHandler;
        JClass validateClass = validateClass(jamClassLoader, staticHandler, r5);
        if (validateClass == null) {
            StringBuffer a2 = a.a("Handler class '");
            a2.append(r5.getStaticHandler());
            a2.append("' not found on classpath, skip validation.");
            BindingConfigImpl.warning(a2.toString(), r5);
            return interfaceExtensionImpl;
        } else if (!interfaceExtensionImpl.validateMethods(validateInterface, validateClass, r5)) {
            return null;
        } else {
            return interfaceExtensionImpl;
        }
    }

    public static JClass validateClass(JamClassLoader jamClassLoader, String str, XmlObject xmlObject) {
        return validateJava(jamClassLoader, str, false, xmlObject);
    }

    public static JClass validateInterface(JamClassLoader jamClassLoader, String str, XmlObject xmlObject) {
        return validateJava(jamClassLoader, str, true, xmlObject);
    }

    public static JClass validateJava(JamClassLoader jamClassLoader, String str, boolean z, XmlObject xmlObject) {
        if (jamClassLoader == null) {
            return null;
        }
        String str2 = z ? "Interface" : "Class";
        JClass loadClass = jamClassLoader.loadClass(str);
        if (loadClass == null || loadClass.isUnresolvedType()) {
            StringBuffer stringBuffer = new StringBuffer();
            stringBuffer.append(str2);
            stringBuffer.append(" '");
            stringBuffer.append(str);
            stringBuffer.append("' not found.");
            BindingConfigImpl.error(stringBuffer.toString(), xmlObject);
            return null;
        }
        if ((z && !loadClass.isInterface()) || (!z && loadClass.isInterface())) {
            StringBuffer c = a.c("'", str, "' must be ");
            c.append(z ? "an interface" : "a class");
            c.append(".");
            BindingConfigImpl.error(c.toString(), xmlObject);
        }
        if (!loadClass.isPublic()) {
            StringBuffer stringBuffer2 = new StringBuffer();
            stringBuffer2.append(str2);
            stringBuffer2.append(" '");
            stringBuffer2.append(str);
            stringBuffer2.append("' is not public.");
            BindingConfigImpl.error(stringBuffer2.toString(), xmlObject);
        }
        return loadClass;
    }

    private JMethod validateMethod(JClass jClass, JClass jClass2, JMethod jMethod, XmlObject xmlObject) {
        String simpleName = jMethod.getSimpleName();
        JParameter[] parameters = jMethod.getParameters();
        JClass returnType = jMethod.getReturnType();
        int length = parameters.length + 1;
        JClass[] jClassArr = new JClass[length];
        jClassArr[0] = returnType.forName("org.apache.xmlbeans.XmlObject");
        for (int i2 = 1; i2 < length; i2++) {
            jClassArr[i2] = parameters[i2 - 1].getType();
        }
        JMethod method = getMethod(jClass2, simpleName, jClassArr);
        if (method == null) {
            StringBuffer a = a.a("Handler class '");
            a.append(jClass2.getQualifiedName());
            a.append("' does not contain method ");
            a.append(simpleName);
            a.append("(");
            a.append(listTypes(jClassArr));
            a.append(")");
            BindingConfigImpl.error(a.toString(), xmlObject);
            return null;
        }
        JClass[] exceptionTypes = jMethod.getExceptionTypes();
        JClass[] exceptionTypes2 = method.getExceptionTypes();
        if (exceptionTypes2.length != exceptionTypes.length) {
            StringBuffer a2 = a.a("Handler method '");
            a2.append(jClass2.getQualifiedName());
            a2.append(".");
            a2.append(simpleName);
            a2.append("(");
            a2.append(listTypes(jClassArr));
            a2.append(")' must declare the same exceptions as the interface method '");
            a2.append(jClass.getQualifiedName());
            a2.append(".");
            a2.append(simpleName);
            a2.append("(");
            a2.append(listTypes(parameters));
            BindingConfigImpl.error(a2.toString(), xmlObject);
            return null;
        }
        for (int i3 = 0; i3 < exceptionTypes2.length; i3++) {
            if (exceptionTypes2[i3] != exceptionTypes[i3]) {
                StringBuffer a3 = a.a("Handler method '");
                a3.append(jClass2.getQualifiedName());
                a3.append(".");
                a3.append(simpleName);
                a3.append("(");
                a3.append(listTypes(jClassArr));
                a3.append(")' must declare the same exceptions as the interface method '");
                a3.append(jClass.getQualifiedName());
                a3.append(".");
                a3.append(simpleName);
                a3.append("(");
                a3.append(listTypes(parameters));
                BindingConfigImpl.error(a3.toString(), xmlObject);
                return null;
            }
        }
        if (!method.isPublic() || !method.isStatic()) {
            StringBuffer a4 = a.a("Method '");
            a4.append(jClass2.getQualifiedName());
            a4.append(".");
            a4.append(simpleName);
            a4.append("(");
            a4.append(listTypes(jClassArr));
            a4.append(")' must be declared public and static.");
            BindingConfigImpl.error(a4.toString(), xmlObject);
            return null;
        } else if (returnType.equals(method.getReturnType())) {
            return jMethod;
        } else {
            StringBuffer a5 = a.a("Return type for method '");
            a5.append(method.getReturnType());
            a5.append(" ");
            a5.append(jClass2.getQualifiedName());
            a5.append(".");
            a5.append(simpleName);
            a5.append("(");
            a5.append(listTypes(jClassArr));
            a5.append(")' does not match the return type of the interface method :'");
            a5.append(returnType);
            a5.append("'.");
            BindingConfigImpl.error(a5.toString(), xmlObject);
            return null;
        }
    }

    private boolean validateMethods(JClass jClass, JClass jClass2, XmlObject xmlObject) {
        JMethod[] methods = jClass.getMethods();
        this._methods = new MethodSignatureImpl[methods.length];
        boolean z = true;
        for (int i2 = 0; i2 < methods.length; i2++) {
            JMethod validateMethod = validateMethod(jClass, jClass2, methods[i2], xmlObject);
            if (validateMethod != null) {
                this._methods[i2] = new MethodSignatureImpl(getStaticHandler(), validateMethod);
            } else {
                z = false;
            }
        }
        return z;
    }

    public boolean contains(String str) {
        return this._xbeanSet.contains(str);
    }

    @Override // org.apache.xmlbeans.InterfaceExtension
    public String getInterface() {
        return this._interfaceClassName;
    }

    @Override // org.apache.xmlbeans.InterfaceExtension
    public InterfaceExtension.MethodSignature[] getMethods() {
        return this._methods;
    }

    @Override // org.apache.xmlbeans.InterfaceExtension
    public String getStaticHandler() {
        return this._delegateToClassName;
    }

    public String toString() {
        StringBuffer a = a.a("  static handler: ");
        a.append(this._delegateToClassName);
        a.append("\n");
        a.append("  interface: ");
        a.append(this._interfaceClassName);
        a.append("\n");
        a.append("  name set: ");
        a.append(this._xbeanSet);
        a.append("\n");
        for (int i2 = 0; i2 < this._methods.length; i2++) {
            a.append("  method[");
            a.append(i2);
            a.append("]=");
            a.append(this._methods[i2]);
            a.append("\n");
        }
        return a.toString();
    }

    public static String listTypes(JParameter[] jParameterArr) {
        StringBuffer stringBuffer = new StringBuffer();
        for (int i2 = 0; i2 < jParameterArr.length; i2++) {
            JClass type = jParameterArr[i2].getType();
            if (i2 > 0) {
                stringBuffer.append(", ");
            }
            stringBuffer.append(emitType(type));
        }
        return stringBuffer.toString();
    }
}
