package org.apache.xmlbeans.impl.jam;

import java.lang.reflect.Constructor;
import java.lang.reflect.Field;
import java.lang.reflect.Method;
import java.util.Arrays;
import java.util.Comparator;

public class JamUtils {
    public static final JamUtils INSTANCE = new JamUtils();
    public static Comparator SOURCE_POSITION_COMPARATOR = new Comparator() {
        /* class org.apache.xmlbeans.impl.jam.JamUtils.AnonymousClass1 */

        @Override // java.util.Comparator
        public int compare(Object obj, Object obj2) {
            JSourcePosition sourcePosition = ((JElement) obj).getSourcePosition();
            JSourcePosition sourcePosition2 = ((JElement) obj2).getSourcePosition();
            if (sourcePosition == null) {
                return sourcePosition2 == null ? 0 : -1;
            }
            if (sourcePosition2 == null) {
                return 1;
            }
            if (sourcePosition.getLine() < sourcePosition2.getLine()) {
                return -1;
            }
            if (sourcePosition.getLine() > sourcePosition2.getLine()) {
                return 1;
            }
            return 0;
        }
    };

    public static final JamUtils getInstance() {
        return INSTANCE;
    }

    public Constructor getConstructorOn(JConstructor jConstructor, Class cls) {
        if (cls == null) {
            throw new IllegalArgumentException("null class");
        } else if (jConstructor != null) {
            Class<?>[] clsArr = null;
            JParameter[] parameters = jConstructor.getParameters();
            if (parameters != null && parameters.length > 0) {
                int length = parameters.length;
                Class<?>[] clsArr2 = new Class[length];
                for (int i2 = 0; i2 < length; i2++) {
                    clsArr2[i2] = loadClass(parameters[i2].getType(), cls.getClassLoader());
                }
                clsArr = clsArr2;
            }
            return cls.getConstructor(clsArr);
        } else {
            throw new IllegalArgumentException("null ctor");
        }
    }

    public Field getFieldOn(JField jField, Class cls) {
        if (cls == null) {
            throw new IllegalArgumentException("null class");
        } else if (jField != null) {
            return cls.getField(jField.getSimpleName());
        } else {
            throw new IllegalArgumentException("null field");
        }
    }

    public Method getMethodOn(JMethod jMethod, Class cls) {
        if (cls == null) {
            throw new IllegalArgumentException("null class");
        } else if (jMethod != null) {
            Class<?>[] clsArr = null;
            JParameter[] parameters = jMethod.getParameters();
            if (parameters != null && parameters.length > 0) {
                int length = parameters.length;
                Class<?>[] clsArr2 = new Class[length];
                for (int i2 = 0; i2 < length; i2++) {
                    clsArr2[i2] = loadClass(parameters[i2].getType(), cls.getClassLoader());
                }
                clsArr = clsArr2;
            }
            return cls.getMethod(jMethod.getSimpleName(), clsArr);
        } else {
            throw new IllegalArgumentException("null method");
        }
    }

    public Class loadClass(JClass jClass, ClassLoader classLoader) {
        return classLoader.loadClass(jClass.getQualifiedName());
    }

    public void placeInSourceOrder(JElement[] jElementArr) {
        if (jElementArr != null) {
            Arrays.sort(jElementArr, SOURCE_POSITION_COMPARATOR);
            return;
        }
        throw new IllegalArgumentException("null elements");
    }
}
