package org.apache.xmlbeans.impl.jam.annotation;

import com.sun.javadoc.SourcePosition;
import com.sun.javadoc.Tag;
import org.apache.xmlbeans.impl.jam.JClass;
import org.apache.xmlbeans.impl.jam.internal.elements.ElementContext;
import org.apache.xmlbeans.impl.jam.mutable.MAnnotatedElement;
import org.apache.xmlbeans.impl.jam.mutable.MAnnotation;
import org.apache.xmlbeans.impl.jam.mutable.MSourcePosition;
import org.apache.xmlbeans.impl.jam.provider.JamLogger;
import org.apache.xmlbeans.impl.jam.provider.JamServiceContext;

public abstract class JavadocTagParser {
    public boolean mAddSingleValueMembers = false;
    public JamServiceContext mContext = null;

    private void setPosition(MAnnotation mAnnotation, Tag tag) {
        SourcePosition position = tag.position();
        if (position != null) {
            MSourcePosition createSourcePosition = mAnnotation.createSourcePosition();
            createSourcePosition.setLine(position.line());
            createSourcePosition.setColumn(position.column());
            if (position.file() != null) {
                createSourcePosition.setSourceURI(position.file().toURI());
            }
        }
    }

    public MAnnotation[] createAnnotations(MAnnotatedElement mAnnotatedElement, Tag tag) {
        String substring = tag.name().trim().substring(1);
        MAnnotation mutableAnnotation = mAnnotatedElement.getMutableAnnotation(substring);
        if (mutableAnnotation == null) {
            mutableAnnotation = mAnnotatedElement.findOrCreateAnnotation(substring);
            setPosition(mutableAnnotation, tag);
        }
        MAnnotation addLiteralAnnotation = mAnnotatedElement.addLiteralAnnotation(substring);
        setPosition(addLiteralAnnotation, tag);
        MAnnotation[] mAnnotationArr = {addLiteralAnnotation, mutableAnnotation};
        if (this.mAddSingleValueMembers) {
            setSingleValueText(mAnnotationArr, tag);
        }
        return mAnnotationArr;
    }

    public JamLogger getLogger() {
        return this.mContext.getLogger();
    }

    public JClass getStringType() {
        return ((ElementContext) this.mContext).getClassLoader().loadClass("java.lang.String");
    }

    public void init(JamServiceContext jamServiceContext) {
        if (jamServiceContext == null) {
            throw new IllegalArgumentException("null logger");
        } else if (this.mContext == null) {
            this.mContext = jamServiceContext;
        } else {
            throw new IllegalStateException("JavadocTagParser.init() called twice");
        }
    }

    public abstract void parse(MAnnotatedElement mAnnotatedElement, Tag tag);

    public void setAddSingleValueMembers(boolean z) {
        this.mAddSingleValueMembers = z;
    }

    public void setSingleValueText(MAnnotation[] mAnnotationArr, Tag tag) {
        String text = tag.text();
        for (MAnnotation mAnnotation : mAnnotationArr) {
            mAnnotation.setSimpleValue("value", text, getStringType());
        }
    }

    public void setValue(MAnnotation[] mAnnotationArr, String str, String str2) {
        String trim = str2.trim();
        String trim2 = str.trim();
        for (int i2 = 0; i2 < mAnnotationArr.length; i2++) {
            if (mAnnotationArr[i2].getValue(trim2) == null) {
                mAnnotationArr[i2].setSimpleValue(trim2, trim, getStringType());
            }
        }
    }
}
