package org.apache.xmlbeans.impl.jam.internal;

import java.io.PrintWriter;
import java.util.ArrayList;
import java.util.Arrays;
import org.apache.poi.ss.formula.ptg.LessThanPtg;
import org.apache.xmlbeans.impl.jam.JAnnotation;
import org.apache.xmlbeans.impl.jam.JClass;
import org.apache.xmlbeans.impl.jam.JConstructor;
import org.apache.xmlbeans.impl.jam.JElement;
import org.apache.xmlbeans.impl.jam.JMethod;
import org.apache.xmlbeans.impl.jam.JamClassIterator;

public class JamPrinter {
    public static final String INDENT = "  ";

    public static JElement[] getChildrenFor(JElement jElement) {
        ArrayList arrayList = new ArrayList();
        if (jElement instanceof JClass) {
            JClass jClass = (JClass) jElement;
            arrayList.addAll(Arrays.asList(jClass.getDeclaredFields()));
            arrayList.addAll(Arrays.asList(jClass.getDeclaredMethods()));
            arrayList.addAll(Arrays.asList(jClass.getConstructors()));
            arrayList.addAll(Arrays.asList(jClass.getClasses()));
        } else if (jElement instanceof JConstructor) {
            arrayList.addAll(Arrays.asList(((JConstructor) jElement).getParameters()));
        } else if (jElement instanceof JMethod) {
            arrayList.addAll(Arrays.asList(((JMethod) jElement).getParameters()));
        }
        JElement[] jElementArr = new JElement[arrayList.size()];
        arrayList.toArray(jElementArr);
        return jElementArr;
    }

    private String getTypeKey(Object obj) {
        int i2;
        if (obj == null) {
            return "[?UNKNOWN!]";
        }
        String name = obj.getClass().getName();
        int lastIndexOf = name.lastIndexOf(".");
        return (lastIndexOf == -1 || (i2 = lastIndexOf + 1) >= name.length()) ? name : name.substring(i2);
    }

    private void indent(int i2, PrintWriter printWriter) {
        for (int i3 = 0; i3 < i2; i3++) {
            printWriter.print(INDENT);
        }
    }

    public static JamPrinter newInstance() {
        return new JamPrinter();
    }

    public void print(JElement jElement, PrintWriter printWriter) {
        print(jElement, 0, printWriter);
    }

    public void print(JamClassIterator jamClassIterator, PrintWriter printWriter) {
        while (jamClassIterator.hasNext()) {
            JClass nextClass = jamClassIterator.nextClass();
            printWriter.println("------------------------------");
            printWriter.println(nextClass.getQualifiedName());
            printWriter.println("------------------------------");
            print(nextClass, printWriter);
            printWriter.println();
        }
    }

    private void print(JElement jElement, int i2, PrintWriter printWriter) {
        indent(i2, printWriter);
        printWriter.print("[");
        printWriter.print(getTypeKey(jElement));
        printWriter.print("] ");
        if (jElement instanceof JMethod) {
            printWriter.print(((JMethod) jElement).getReturnType().getFieldDescriptor());
            printWriter.print(" ");
            printWriter.println(jElement.getSimpleName());
            return;
        }
        printWriter.println(jElement.getSimpleName());
    }

    private void print(JAnnotation[] jAnnotationArr, int i2, PrintWriter printWriter) {
        for (int i3 = 0; i3 < jAnnotationArr.length; i3++) {
            indent(i2, printWriter);
            printWriter.print(LessThanPtg.LESSTHAN);
            printWriter.print(getTypeKey(jAnnotationArr[i3]));
            printWriter.print("> ");
            printWriter.print(jAnnotationArr[i3].getSimpleName());
        }
    }
}
