package org.apache.xmlbeans.impl.jam.internal;

import b.b.a.a.a;
import java.io.File;
import java.io.PrintWriter;
import java.util.ArrayList;
import java.util.Collection;
import java.util.HashMap;
import java.util.HashSet;
import java.util.Iterator;
import java.util.List;
import java.util.Map;
import java.util.Properties;
import org.apache.poi.ss.formula.function.FunctionMetadataReader;
import org.apache.xmlbeans.impl.common.JarHelper;
import org.apache.xmlbeans.impl.common.NameUtil;
import org.apache.xmlbeans.impl.jam.JamClassLoader;
import org.apache.xmlbeans.impl.jam.JamServiceParams;
import org.apache.xmlbeans.impl.jam.annotation.AnnotationProxy;
import org.apache.xmlbeans.impl.jam.annotation.DefaultAnnotationProxy;
import org.apache.xmlbeans.impl.jam.annotation.JavadocTagParser;
import org.apache.xmlbeans.impl.jam.annotation.WhitespaceDelimitedTagParser;
import org.apache.xmlbeans.impl.jam.internal.elements.ElementContext;
import org.apache.xmlbeans.impl.jam.provider.CompositeJamClassBuilder;
import org.apache.xmlbeans.impl.jam.provider.JamClassBuilder;
import org.apache.xmlbeans.impl.jam.provider.JamLogger;
import org.apache.xmlbeans.impl.jam.provider.JamServiceContext;
import org.apache.xmlbeans.impl.jam.provider.ResourcePath;
import org.apache.xmlbeans.impl.jam.visitor.CompositeMVisitor;
import org.apache.xmlbeans.impl.jam.visitor.MVisitor;
import org.apache.xmlbeans.impl.jam.visitor.PropertyInitializer;

public class JamServiceContextImpl extends JamLoggerImpl implements JamServiceContext, JamServiceParams, ElementContext {
    public static final char INNER_CLASS_SEPARATOR = '$';
    public static final String PREFIX = "[JamServiceContextImpl] ";
    public boolean m14WarningsEnabled = false;
    public List mBaseBuilders = null;
    public List mClassLoaders = null;
    public Map mClassRoot2Scanner = null;
    public List mClasspath = null;
    public MVisitor mCommentInitializer = null;
    public List mExcludeClasses = null;
    public List mIncludeClasses = null;
    public JamClassLoader mLoader = null;
    public List mOtherInitializers = null;
    public Properties mProperties = null;
    public MVisitor mPropertyInitializer = new PropertyInitializer();
    public Map mSourceRoot2Scanner = null;
    public List mSourcepath = null;
    public JavadocTagParser mTagParser = null;
    public List mToolClasspath = null;
    public List mUnstructuredSourceFiles = null;
    public boolean mUseSystemClasspath = true;

    public static ResourcePath createJPath(Collection collection) {
        if (collection == null || collection.size() == 0) {
            return null;
        }
        File[] fileArr = new File[collection.size()];
        collection.toArray(fileArr);
        return ResourcePath.forFiles(fileArr);
    }

    public static String filename2classname(String str) {
        int lastIndexOf = str.lastIndexOf(46);
        if (lastIndexOf != -1) {
            str = str.substring(0, lastIndexOf);
        }
        return str.replace(JarHelper.SEP, NameUtil.PERIOD).replace('\\', NameUtil.PERIOD);
    }

    private Iterator getAllDirectoryScanners() {
        ArrayList arrayList = new ArrayList();
        Map map = this.mSourceRoot2Scanner;
        if (map != null) {
            arrayList.addAll(map.values());
        }
        Map map2 = this.mClassRoot2Scanner;
        if (map2 != null) {
            arrayList.addAll(map2.values());
        }
        return arrayList.iterator();
    }

    private DirectoryScanner getClassScanner(File file) {
        if (this.mClassRoot2Scanner == null) {
            this.mClassRoot2Scanner = new HashMap();
        }
        DirectoryScanner directoryScanner = (DirectoryScanner) this.mClassRoot2Scanner.get(file);
        if (directoryScanner != null) {
            return directoryScanner;
        }
        Map map = this.mClassRoot2Scanner;
        DirectoryScanner directoryScanner2 = new DirectoryScanner(file, this);
        map.put(file, directoryScanner2);
        return directoryScanner2;
    }

    private File getPathRootForFile(File[] fileArr, File file) {
        if (fileArr == null) {
            throw new IllegalArgumentException("null sourcepath");
        } else if (fileArr.length == 0) {
            throw new IllegalArgumentException("empty sourcepath");
        } else if (file != null) {
            File absoluteFile = file.getAbsoluteFile();
            if (isVerbose(this)) {
                StringBuffer stringBuffer = new StringBuffer();
                stringBuffer.append("[JamServiceContextImpl] Getting root for ");
                stringBuffer.append(absoluteFile);
                stringBuffer.append(FunctionMetadataReader.ELLIPSIS);
                verbose(stringBuffer.toString());
            }
            for (int i2 = 0; i2 < fileArr.length; i2++) {
                if (isVerbose(this)) {
                    StringBuffer a = a.a("[JamServiceContextImpl] ...looking in ");
                    a.append(fileArr[i2]);
                    verbose(a.toString());
                }
                if (isContainingDir(fileArr[i2].getAbsoluteFile(), absoluteFile)) {
                    if (isVerbose(this)) {
                        verbose("[JamServiceContextImpl] ...found it!");
                    }
                    return fileArr[i2].getAbsoluteFile();
                }
            }
            StringBuffer stringBuffer2 = new StringBuffer();
            stringBuffer2.append(absoluteFile);
            stringBuffer2.append(" is not in the given path.");
            throw new IllegalArgumentException(stringBuffer2.toString());
        } else {
            throw new IllegalArgumentException("null sourceFile");
        }
    }

    private DirectoryScanner getSourceScanner(File file) {
        if (this.mSourceRoot2Scanner == null) {
            this.mSourceRoot2Scanner = new HashMap();
        }
        DirectoryScanner directoryScanner = (DirectoryScanner) this.mSourceRoot2Scanner.get(file);
        if (directoryScanner != null) {
            return directoryScanner;
        }
        Map map = this.mSourceRoot2Scanner;
        DirectoryScanner directoryScanner2 = new DirectoryScanner(file, this);
        map.put(file, directoryScanner2);
        return directoryScanner2;
    }

    private boolean isContainingDir(File file, File file2) {
        if (isVerbose(this)) {
            StringBuffer stringBuffer = new StringBuffer();
            stringBuffer.append("[JamServiceContextImpl] ... ...isContainingDir ");
            stringBuffer.append(file);
            stringBuffer.append(JamPrinter.INDENT);
            stringBuffer.append(file2);
            verbose(stringBuffer.toString());
        }
        if (file2 == null) {
            return false;
        }
        if (!file.equals(file2)) {
            return isContainingDir(file, file2.getParentFile());
        }
        if (!isVerbose(this)) {
            return true;
        }
        verbose("[JamServiceContextImpl] ... ...yes!");
        return true;
    }

    private String source2pattern(File file, File file2) {
        if (isVerbose(this)) {
            StringBuffer stringBuffer = new StringBuffer();
            stringBuffer.append("[JamServiceContextImpl] source2pattern ");
            stringBuffer.append(file);
            stringBuffer.append(JamPrinter.INDENT);
            stringBuffer.append(file2);
            verbose(stringBuffer.toString());
        }
        String absolutePath = file.getAbsolutePath();
        String absolutePath2 = file2.getAbsolutePath();
        if (isVerbose(this)) {
            StringBuffer a = a.a("[JamServiceContextImpl] source2pattern returning ");
            a.append(absolutePath2.substring(absolutePath.length() + 1));
            verbose(a.toString());
        }
        return absolutePath2.substring(absolutePath.length() + 1);
    }

    @Override // org.apache.xmlbeans.impl.jam.JamServiceParams
    public void addClassBuilder(JamClassBuilder jamClassBuilder) {
        if (this.mBaseBuilders == null) {
            this.mBaseBuilders = new ArrayList();
        }
        this.mBaseBuilders.add(jamClassBuilder);
    }

    @Override // org.apache.xmlbeans.impl.jam.JamServiceParams
    public void addClassLoader(ClassLoader classLoader) {
        if (this.mClassLoaders == null) {
            this.mClassLoaders = new ArrayList();
        }
        this.mClassLoaders.add(classLoader);
    }

    @Override // org.apache.xmlbeans.impl.jam.JamServiceParams
    public void addClasspath(File file) {
        List list = this.mClasspath;
        if (list == null) {
            this.mClasspath = new ArrayList();
        } else if (list.contains(file)) {
            return;
        }
        this.mClasspath.add(file);
    }

    @Override // org.apache.xmlbeans.impl.jam.JamServiceParams
    public void addInitializer(MVisitor mVisitor) {
        if (this.mOtherInitializers == null) {
            this.mOtherInitializers = new ArrayList();
        }
        this.mOtherInitializers.add(mVisitor);
    }

    @Override // org.apache.xmlbeans.impl.jam.JamServiceParams
    public void addSourcepath(File file) {
        List list = this.mSourcepath;
        if (list == null) {
            this.mSourcepath = new ArrayList();
        } else if (list.contains(file)) {
            return;
        }
        this.mSourcepath.add(file);
    }

    @Override // org.apache.xmlbeans.impl.jam.JamServiceParams
    public void addToolClasspath(File file) {
        List list = this.mToolClasspath;
        if (list == null) {
            this.mToolClasspath = new ArrayList();
        } else if (list.contains(file)) {
            return;
        }
        this.mToolClasspath.add(file);
    }

    @Override // org.apache.xmlbeans.impl.jam.internal.elements.ElementContext
    public AnnotationProxy createAnnotationProxy(String str) {
        DefaultAnnotationProxy defaultAnnotationProxy = new DefaultAnnotationProxy();
        defaultAnnotationProxy.init(this);
        return defaultAnnotationProxy;
    }

    @Override // org.apache.xmlbeans.impl.jam.JamServiceParams
    public void excludeClass(String str) {
        if (this.mExcludeClasses == null) {
            this.mExcludeClasses = new ArrayList();
        }
        this.mExcludeClasses.add(str);
    }

    @Override // org.apache.xmlbeans.impl.jam.JamServiceParams
    public void excludeClassFile(File[] fileArr, File file) {
        File pathRootForFile = getPathRootForFile(fileArr, file);
        excludeClassPattern(new File[]{pathRootForFile}, source2pattern(pathRootForFile, file));
    }

    @Override // org.apache.xmlbeans.impl.jam.JamServiceParams
    public void excludeClassPattern(File[] fileArr, String str) {
        if (fileArr == null) {
            throw new IllegalArgumentException("null classpath");
        } else if (fileArr.length == 0) {
            throw new IllegalArgumentException("empty classpath");
        } else if (str != null) {
            String trim = str.trim();
            if (trim.length() != 0) {
                for (int i2 = 0; i2 < fileArr.length; i2++) {
                    if (isVerbose(this)) {
                        StringBuffer c = a.c("[JamServiceContextImpl] EXCLUDING '", trim, "' under ");
                        c.append(fileArr[i2]);
                        verbose(c.toString());
                    }
                    addClasspath(fileArr[i2]);
                    getClassScanner(fileArr[i2]).exclude(trim);
                }
                return;
            }
            throw new IllegalArgumentException("empty pattern");
        } else {
            throw new IllegalArgumentException("null pattern");
        }
    }

    @Override // org.apache.xmlbeans.impl.jam.JamServiceParams
    public void excludeSourceFile(File[] fileArr, File file) {
        File pathRootForFile = getPathRootForFile(fileArr, file);
        excludeSourcePattern(new File[]{pathRootForFile}, source2pattern(pathRootForFile, file));
    }

    @Override // org.apache.xmlbeans.impl.jam.JamServiceParams
    public void excludeSourcePattern(File[] fileArr, String str) {
        if (fileArr == null) {
            throw new IllegalArgumentException("null sourcepath");
        } else if (fileArr.length == 0) {
            throw new IllegalArgumentException("empty sourcepath");
        } else if (str != null) {
            String trim = str.trim();
            if (trim.length() != 0) {
                for (int i2 = 0; i2 < fileArr.length; i2++) {
                    if (isVerbose(this)) {
                        StringBuffer c = a.c("[JamServiceContextImpl] EXCLUDING '", trim, "' under ");
                        c.append(fileArr[i2]);
                        verbose(c.toString());
                    }
                    addSourcepath(fileArr[i2]);
                    getSourceScanner(fileArr[i2]).exclude(trim);
                }
                return;
            }
            throw new IllegalArgumentException("empty pattern");
        } else {
            throw new IllegalArgumentException("null pattern");
        }
    }

    @Override // org.apache.xmlbeans.impl.jam.provider.JamServiceContext
    public String[] getAllClassnames() {
        HashSet hashSet = new HashSet();
        List list = this.mIncludeClasses;
        if (list != null) {
            hashSet.addAll(list);
        }
        Iterator allDirectoryScanners = getAllDirectoryScanners();
        while (allDirectoryScanners.hasNext()) {
            String[] includedFiles = ((DirectoryScanner) allDirectoryScanners.next()).getIncludedFiles();
            for (int i2 = 0; i2 < includedFiles.length; i2++) {
                if (includedFiles[i2].indexOf(36) == -1) {
                    hashSet.add(filename2classname(includedFiles[i2]));
                }
            }
        }
        List list2 = this.mExcludeClasses;
        if (list2 != null) {
            hashSet.removeAll(list2);
        }
        String[] strArr = new String[hashSet.size()];
        hashSet.toArray(strArr);
        return strArr;
    }

    @Override // org.apache.xmlbeans.impl.jam.provider.JamServiceContext
    public JamClassBuilder getBaseBuilder() {
        List list = this.mBaseBuilders;
        if (list == null || list.size() == 0) {
            return null;
        }
        if (this.mBaseBuilders.size() == 1) {
            return (JamClassBuilder) this.mBaseBuilders.get(0);
        }
        JamClassBuilder[] jamClassBuilderArr = new JamClassBuilder[this.mBaseBuilders.size()];
        this.mBaseBuilders.toArray(jamClassBuilderArr);
        return new CompositeJamClassBuilder(jamClassBuilderArr);
    }

    @Override // org.apache.xmlbeans.impl.jam.internal.elements.ElementContext
    public JamClassLoader getClassLoader() {
        return this.mLoader;
    }

    @Override // org.apache.xmlbeans.impl.jam.provider.JamServiceContext
    public MVisitor getInitializer() {
        ArrayList arrayList = new ArrayList();
        MVisitor mVisitor = this.mCommentInitializer;
        if (mVisitor != null) {
            arrayList.add(mVisitor);
        }
        MVisitor mVisitor2 = this.mPropertyInitializer;
        if (mVisitor2 != null) {
            arrayList.add(mVisitor2);
        }
        List list = this.mOtherInitializers;
        if (list != null) {
            arrayList.addAll(list);
        }
        MVisitor[] mVisitorArr = new MVisitor[arrayList.size()];
        arrayList.toArray(mVisitorArr);
        return new CompositeMVisitor(mVisitorArr);
    }

    @Override // org.apache.xmlbeans.impl.jam.provider.JamServiceContext
    public ResourcePath getInputClasspath() {
        return createJPath(this.mClasspath);
    }

    @Override // org.apache.xmlbeans.impl.jam.provider.JamServiceContext
    public ResourcePath getInputSourcepath() {
        return createJPath(this.mSourcepath);
    }

    @Override // org.apache.xmlbeans.impl.jam.provider.JamServiceContext, org.apache.xmlbeans.impl.jam.internal.elements.ElementContext
    public JamLogger getLogger() {
        return this;
    }

    @Override // org.apache.xmlbeans.impl.jam.provider.JamServiceContext
    public String getProperty(String str) {
        Properties properties = this.mProperties;
        if (properties == null) {
            return null;
        }
        return properties.getProperty(str);
    }

    @Override // org.apache.xmlbeans.impl.jam.provider.JamServiceContext
    public ClassLoader[] getReflectionClassLoaders() {
        List list = this.mClassLoaders;
        if (list != null) {
            int size = list.size() + (this.mUseSystemClasspath ? 1 : 0);
            ClassLoader[] classLoaderArr = new ClassLoader[size];
            for (int i2 = 0; i2 < this.mClassLoaders.size(); i2++) {
                classLoaderArr[i2] = (ClassLoader) this.mClassLoaders.get(i2);
            }
            if (this.mUseSystemClasspath) {
                classLoaderArr[size - 1] = ClassLoader.getSystemClassLoader();
            }
            return classLoaderArr;
        } else if (!this.mUseSystemClasspath) {
            return new ClassLoader[0];
        } else {
            return new ClassLoader[]{ClassLoader.getSystemClassLoader()};
        }
    }

    @Override // org.apache.xmlbeans.impl.jam.provider.JamServiceContext
    public File[] getSourceFiles() {
        HashSet hashSet = new HashSet();
        Map map = this.mSourceRoot2Scanner;
        if (map != null) {
            for (DirectoryScanner directoryScanner : map.values()) {
                if (isVerbose(this)) {
                    StringBuffer a = a.a("[JamServiceContextImpl]  checking scanner for dir");
                    a.append(directoryScanner.getRoot());
                    verbose(a.toString());
                }
                String[] includedFiles = directoryScanner.getIncludedFiles();
                for (int i2 = 0; i2 < includedFiles.length; i2++) {
                    if (isVerbose(this)) {
                        StringBuffer a2 = a.a("[JamServiceContextImpl]  ...including a source file ");
                        a2.append(includedFiles[i2]);
                        verbose(a2.toString());
                    }
                    hashSet.add(new File(directoryScanner.getRoot(), includedFiles[i2]));
                }
            }
        }
        if (this.mUnstructuredSourceFiles != null) {
            if (isVerbose(this)) {
                StringBuffer a3 = a.a("[JamServiceContextImpl] adding ");
                a3.append(this.mUnstructuredSourceFiles.size());
                a3.append(" other source files");
                verbose(a3.toString());
            }
            hashSet.addAll(this.mUnstructuredSourceFiles);
        }
        File[] fileArr = new File[hashSet.size()];
        hashSet.toArray(fileArr);
        return fileArr;
    }

    @Override // org.apache.xmlbeans.impl.jam.provider.JamServiceContext
    public JavadocTagParser getTagParser() {
        if (this.mTagParser == null) {
            WhitespaceDelimitedTagParser whitespaceDelimitedTagParser = new WhitespaceDelimitedTagParser();
            this.mTagParser = whitespaceDelimitedTagParser;
            whitespaceDelimitedTagParser.init(this);
        }
        return this.mTagParser;
    }

    @Override // org.apache.xmlbeans.impl.jam.provider.JamServiceContext
    public ResourcePath getToolClasspath() {
        return createJPath(this.mToolClasspath);
    }

    public File[] getUnstructuredSourceFiles() {
        List list = this.mUnstructuredSourceFiles;
        if (list == null) {
            return null;
        }
        File[] fileArr = new File[list.size()];
        this.mUnstructuredSourceFiles.toArray(fileArr);
        return fileArr;
    }

    @Override // org.apache.xmlbeans.impl.jam.JamServiceParams
    public void includeClass(String str) {
        if (this.mIncludeClasses == null) {
            this.mIncludeClasses = new ArrayList();
        }
        this.mIncludeClasses.add(str);
    }

    @Override // org.apache.xmlbeans.impl.jam.JamServiceParams
    public void includeClassFile(File[] fileArr, File file) {
        File pathRootForFile = getPathRootForFile(fileArr, file);
        includeClassPattern(new File[]{pathRootForFile}, source2pattern(pathRootForFile, file));
    }

    @Override // org.apache.xmlbeans.impl.jam.JamServiceParams
    public void includeClassPattern(File[] fileArr, String str) {
        if (fileArr == null) {
            throw new IllegalArgumentException("null classpath");
        } else if (fileArr.length == 0) {
            throw new IllegalArgumentException("empty classpath");
        } else if (str != null) {
            String trim = str.trim();
            if (trim.length() != 0) {
                for (int i2 = 0; i2 < fileArr.length; i2++) {
                    if (isVerbose(this)) {
                        StringBuffer c = a.c("[JamServiceContextImpl] including '", trim, "' under ");
                        c.append(fileArr[i2]);
                        verbose(c.toString());
                    }
                    addClasspath(fileArr[i2]);
                    getClassScanner(fileArr[i2]).include(trim);
                }
                return;
            }
            throw new IllegalArgumentException("empty pattern");
        } else {
            throw new IllegalArgumentException("null pattern");
        }
    }

    @Override // org.apache.xmlbeans.impl.jam.JamServiceParams
    public void includeSourceFile(File file) {
        if (file != null) {
            File absoluteFile = file.getAbsoluteFile();
            if (isVerbose(this)) {
                verbose("[JamServiceContextImpl] adding source ");
            }
            if (!absoluteFile.exists()) {
                StringBuffer stringBuffer = new StringBuffer();
                stringBuffer.append(absoluteFile);
                stringBuffer.append(" does not exist");
                throw new IllegalArgumentException(stringBuffer.toString());
            } else if (!absoluteFile.isDirectory()) {
                if (this.mUnstructuredSourceFiles == null) {
                    this.mUnstructuredSourceFiles = new ArrayList();
                }
                this.mUnstructuredSourceFiles.add(absoluteFile.getAbsoluteFile());
            } else {
                StringBuffer stringBuffer2 = new StringBuffer();
                stringBuffer2.append(absoluteFile);
                stringBuffer2.append(" cannot be included as a source file because it is a directory.");
                throw new IllegalArgumentException(stringBuffer2.toString());
            }
        } else {
            throw new IllegalArgumentException("null file");
        }
    }

    @Override // org.apache.xmlbeans.impl.jam.JamServiceParams
    public void includeSourcePattern(File[] fileArr, String str) {
        if (fileArr == null) {
            throw new IllegalArgumentException("null sourcepath");
        } else if (fileArr.length == 0) {
            throw new IllegalArgumentException("empty sourcepath");
        } else if (str != null) {
            String trim = str.trim();
            if (trim.length() != 0) {
                for (int i2 = 0; i2 < fileArr.length; i2++) {
                    if (isVerbose(this)) {
                        StringBuffer c = a.c("[JamServiceContextImpl] including '", trim, "' under ");
                        c.append(fileArr[i2]);
                        verbose(c.toString());
                    }
                    addSourcepath(fileArr[i2]);
                    getSourceScanner(fileArr[i2]).include(trim);
                }
                return;
            }
            throw new IllegalArgumentException("empty pattern");
        } else {
            throw new IllegalArgumentException("null pattern");
        }
    }

    @Override // org.apache.xmlbeans.impl.jam.provider.JamServiceContext
    public boolean is14WarningsEnabled() {
        return this.m14WarningsEnabled;
    }

    @Override // org.apache.xmlbeans.impl.jam.JamServiceParams
    public void set14WarningsEnabled(boolean z) {
        this.m14WarningsEnabled = z;
    }

    public void setClassLoader(JamClassLoader jamClassLoader) {
        this.mLoader = jamClassLoader;
    }

    public void setCommentInitializer(MVisitor mVisitor) {
        this.mCommentInitializer = mVisitor;
    }

    @Override // org.apache.xmlbeans.impl.jam.JamServiceParams
    public void setJamLogger(JamLogger jamLogger) {
        throw new IllegalStateException("NYI");
    }

    @Override // org.apache.xmlbeans.impl.jam.JamServiceParams
    public void setJavadocTagParser(JavadocTagParser javadocTagParser) {
        this.mTagParser = javadocTagParser;
        javadocTagParser.init(this);
    }

    @Override // org.apache.xmlbeans.impl.jam.JamServiceParams
    public void setLoggerWriter(PrintWriter printWriter) {
        super.setOut(printWriter);
    }

    @Override // org.apache.xmlbeans.impl.jam.JamServiceParams
    public void setParentClassLoader(JamClassLoader jamClassLoader) {
        throw new IllegalStateException("NYI");
    }

    @Override // org.apache.xmlbeans.impl.jam.JamServiceParams
    public void setProperty(String str, String str2) {
        if (this.mProperties == null) {
            this.mProperties = new Properties();
        }
        this.mProperties.setProperty(str, str2);
    }

    @Override // org.apache.xmlbeans.impl.jam.JamServiceParams
    public void setPropertyInitializer(MVisitor mVisitor) {
        this.mPropertyInitializer = mVisitor;
    }

    @Override // org.apache.xmlbeans.impl.jam.JamServiceParams
    public void setUseSystemClasspath(boolean z) {
        this.mUseSystemClasspath = z;
    }

    @Override // org.apache.xmlbeans.impl.jam.JamServiceParams
    public void includeSourceFile(File[] fileArr, File file) {
        File pathRootForFile = getPathRootForFile(fileArr, file);
        includeSourcePattern(new File[]{pathRootForFile}, source2pattern(pathRootForFile, file));
    }
}
