package org.apache.xmlbeans.impl.jam.internal.classrefs;

import b.b.a.a.a;
import java.io.StringWriter;
import org.apache.xmlbeans.impl.jam.JClass;

public class UnqualifiedJClassRef implements JClassRef {
    public static final String PREFIX = "[UnqualifiedJClassRef]";
    public static final boolean VERBOSE = false;
    public JClassRefContext mContext;
    public String mQualifiedClassname = null;
    public String mUnqualifiedClassname;

    public UnqualifiedJClassRef(String str, JClassRefContext jClassRefContext) {
        if (jClassRefContext == null) {
            throw new IllegalArgumentException("null ctx");
        } else if (str != null) {
            this.mContext = jClassRefContext;
            this.mUnqualifiedClassname = str;
        } else {
            throw new IllegalArgumentException("null ucname");
        }
    }

    private String checkAlreadyQualified(String str) {
        JClass loadClass = this.mContext.getClassLoader().loadClass(str);
        if (loadClass.isUnresolvedType()) {
            return null;
        }
        return loadClass.getQualifiedName();
    }

    private String checkExplicitImport(String str) {
        String[] importSpecs = this.mContext.getImportSpecs();
        for (int i2 = 0; i2 < importSpecs.length; i2++) {
            if (lastSegment(importSpecs[i2]).equals(str)) {
                return importSpecs[i2];
            }
        }
        return null;
    }

    private String checkJavaLang(String str) {
        JClass loadClass = this.mContext.getClassLoader().loadClass(a.a("java.lang.", str));
        if (loadClass.isUnresolvedType()) {
            return null;
        }
        return loadClass.getQualifiedName();
    }

    private String checkSamePackage(String str) {
        StringBuffer stringBuffer = new StringBuffer();
        stringBuffer.append(this.mContext.getPackageName());
        stringBuffer.append(".");
        stringBuffer.append(str);
        JClass loadClass = this.mContext.getClassLoader().loadClass(stringBuffer.toString());
        if (loadClass.isUnresolvedType()) {
            return null;
        }
        return loadClass.getQualifiedName();
    }

    public static JClassRef create(String str, JClassRefContext jClassRefContext) {
        throw new IllegalStateException("Unqualified names currently disabled.");
    }

    public static String firstSegment(String str) {
        int indexOf = str.indexOf(".");
        if (indexOf == -1) {
            return str;
        }
        return str.substring(0, indexOf);
    }

    public static String lastSegment(String str) {
        int lastIndexOf = str.lastIndexOf(".");
        if (lastIndexOf == -1) {
            return str;
        }
        return str.substring(lastIndexOf + 1);
    }

    private String qualifyName(String str) {
        String checkExplicitImport = checkExplicitImport(str);
        if (checkExplicitImport != null) {
            return checkExplicitImport;
        }
        String checkJavaLang = checkJavaLang(str);
        if (checkJavaLang != null) {
            return checkJavaLang;
        }
        String checkSamePackage = checkSamePackage(str);
        if (checkSamePackage != null) {
            return checkSamePackage;
        }
        String checkAlreadyQualified = checkAlreadyQualified(str);
        if (checkAlreadyQualified != null) {
            return checkAlreadyQualified;
        }
        return null;
    }

    @Override // org.apache.xmlbeans.impl.jam.internal.classrefs.JClassRef
    public String getQualifiedName() {
        int i2;
        String str;
        String str2 = this.mQualifiedClassname;
        if (str2 != null) {
            return str2;
        }
        int indexOf = this.mUnqualifiedClassname.indexOf(91);
        if (indexOf != -1) {
            str = this.mUnqualifiedClassname.substring(0, indexOf);
            i2 = 0;
            do {
                i2++;
                indexOf = this.mUnqualifiedClassname.indexOf(91, indexOf + 1);
            } while (indexOf != -1);
        } else {
            str = this.mUnqualifiedClassname;
            i2 = 0;
        }
        String qualifyName = qualifyName(str);
        if (qualifyName != null) {
            if (i2 > 0) {
                StringWriter stringWriter = new StringWriter();
                for (int i3 = 0; i3 < i2; i3++) {
                    stringWriter.write(91);
                }
                stringWriter.write(76);
                stringWriter.write(qualifyName);
                stringWriter.write(59);
                this.mQualifiedClassname = stringWriter.toString();
            } else {
                this.mQualifiedClassname = qualifyName;
            }
            return this.mQualifiedClassname;
        }
        StringBuffer c = a.c("unable to handle unqualified java type reference '", str, " [");
        c.append(this.mUnqualifiedClassname);
        c.append("]'. ");
        c.append("This is still partially NYI.");
        throw new IllegalStateException(c.toString());
    }

    @Override // org.apache.xmlbeans.impl.jam.internal.classrefs.JClassRef
    public JClass getRefClass() {
        return this.mContext.getClassLoader().loadClass(getQualifiedName());
    }
}
