package org.apache.xmlbeans.impl.jam.internal.elements;

import b.b.a.a.a;
import org.apache.poi.ss.formula.functions.NumericFunction;
import org.apache.xmlbeans.impl.jam.JAnnotation;
import org.apache.xmlbeans.impl.jam.JAnnotationValue;
import org.apache.xmlbeans.impl.jam.JClass;
import org.apache.xmlbeans.impl.jam.internal.classrefs.JClassRef;
import org.apache.xmlbeans.impl.jam.internal.classrefs.QualifiedJClassRef;
import org.apache.xmlbeans.impl.jam.provider.JamLogger;

public class AnnotationValueImpl implements JAnnotationValue {
    public ElementContext mContext;
    public String mName;
    public JClassRef mType = null;
    public Object mValue = null;

    public AnnotationValueImpl(ElementContext elementContext, String str, Object obj, JClass jClass) {
        if (elementContext == null) {
            throw new IllegalArgumentException("null ctx");
        } else if (str == null) {
            throw new IllegalArgumentException("null name");
        } else if (obj == null) {
            throw new IllegalArgumentException("null value");
        } else if (jClass != null) {
            if (obj.getClass().isArray()) {
                this.mValue = ensureArrayWrapped(obj);
            } else {
                this.mValue = obj;
            }
            this.mContext = elementContext;
            this.mName = str;
            this.mType = QualifiedJClassRef.create(jClass);
        } else {
            throw new IllegalArgumentException("null type");
        }
    }

    public static final Object[] ensureArrayWrapped(Object obj) {
        if (obj instanceof Object[]) {
            return (Object[]) obj;
        }
        int i2 = 0;
        if (obj instanceof int[]) {
            int[] iArr = (int[]) obj;
            int length = iArr.length;
            Integer[] numArr = new Integer[length];
            while (i2 < length) {
                numArr[i2] = new Integer(iArr[i2]);
                i2++;
            }
            return numArr;
        } else if (obj instanceof boolean[]) {
            boolean[] zArr = (boolean[]) obj;
            int length2 = zArr.length;
            Boolean[] boolArr = new Boolean[length2];
            while (i2 < length2) {
                boolArr[i2] = Boolean.valueOf(zArr[i2]);
                i2++;
            }
            return boolArr;
        } else if (obj instanceof byte[]) {
            byte[] bArr = (byte[]) obj;
            int length3 = bArr.length;
            Byte[] bArr2 = new Byte[length3];
            while (i2 < length3) {
                bArr2[i2] = new Byte(bArr[i2]);
                i2++;
            }
            return bArr2;
        } else if (obj instanceof char[]) {
            char[] cArr = (char[]) obj;
            int length4 = cArr.length;
            Character[] chArr = new Character[length4];
            while (i2 < length4) {
                chArr[i2] = new Character(cArr[i2]);
                i2++;
            }
            return chArr;
        } else if (obj instanceof float[]) {
            float[] fArr = (float[]) obj;
            int length5 = fArr.length;
            Float[] fArr2 = new Float[length5];
            while (i2 < length5) {
                fArr2[i2] = new Float(fArr[i2]);
                i2++;
            }
            return fArr2;
        } else if (obj instanceof double[]) {
            double[] dArr = (double[]) obj;
            int length6 = dArr.length;
            Double[] dArr2 = new Double[length6];
            while (i2 < length6) {
                dArr2[i2] = new Double(dArr[i2]);
                i2++;
            }
            return dArr2;
        } else if (obj instanceof long[]) {
            long[] jArr = (long[]) obj;
            int length7 = jArr.length;
            Long[] lArr = new Long[length7];
            while (i2 < length7) {
                lArr[i2] = new Long(jArr[i2]);
                i2++;
            }
            return lArr;
        } else if (obj instanceof short[]) {
            short[] sArr = (short[]) obj;
            int length8 = sArr.length;
            Short[] shArr = new Short[length8];
            while (i2 < length8) {
                shArr[i2] = new Short(sArr[i2]);
                i2++;
            }
            return shArr;
        } else {
            StringBuffer a = a.a("Unknown array type ");
            a.append(obj.getClass());
            throw new IllegalStateException(a.toString());
        }
    }

    @Override // org.apache.xmlbeans.impl.jam.JAnnotationValue
    public JAnnotation asAnnotation() {
        Object obj = this.mValue;
        if (obj instanceof JAnnotation) {
            return (JAnnotation) obj;
        }
        return null;
    }

    @Override // org.apache.xmlbeans.impl.jam.JAnnotationValue
    public JAnnotation[] asAnnotationArray() {
        Object obj = this.mValue;
        if (obj instanceof JAnnotation[]) {
            return (JAnnotation[]) obj;
        }
        return null;
    }

    @Override // org.apache.xmlbeans.impl.jam.JAnnotationValue
    public boolean asBoolean() {
        Object obj = this.mValue;
        if (obj == null) {
            return false;
        }
        return Boolean.valueOf(obj.toString().trim()).booleanValue();
    }

    @Override // org.apache.xmlbeans.impl.jam.JAnnotationValue
    public boolean[] asBooleanArray() {
        if (!this.mValue.getClass().isArray()) {
            return null;
        }
        int length = ((Object[]) this.mValue).length;
        boolean[] zArr = new boolean[length];
        for (int i2 = 0; i2 < length; i2++) {
            Object obj = this.mValue;
            if (((Object[]) obj)[i2] == null) {
                JamLogger logger = this.mContext.getLogger();
                StringBuffer stringBuffer = new StringBuffer();
                stringBuffer.append("Null annotation value array element ");
                stringBuffer.append(i2);
                stringBuffer.append(" on ");
                stringBuffer.append(getName());
                logger.error(stringBuffer.toString());
                zArr[i2] = false;
            } else {
                zArr[i2] = Boolean.valueOf(((Object[]) obj)[i2].toString()).booleanValue();
            }
        }
        return zArr;
    }

    @Override // org.apache.xmlbeans.impl.jam.JAnnotationValue
    public byte asByte() {
        Object obj = this.mValue;
        if (obj == null) {
            return 0;
        }
        if (obj instanceof Number) {
            return ((Number) obj).byteValue();
        }
        try {
            return Byte.parseByte(obj.toString().trim());
        } catch (NumberFormatException unused) {
            return 0;
        }
    }

    @Override // org.apache.xmlbeans.impl.jam.JAnnotationValue
    public byte[] asByteArray() {
        if (!this.mValue.getClass().isArray()) {
            return null;
        }
        int length = ((Object[]) this.mValue).length;
        byte[] bArr = new byte[length];
        for (int i2 = 0; i2 < length; i2++) {
            Object obj = this.mValue;
            if (((Object[]) obj)[i2] == null) {
                JamLogger logger = this.mContext.getLogger();
                StringBuffer stringBuffer = new StringBuffer();
                stringBuffer.append("Null annotation value array element ");
                stringBuffer.append(i2);
                stringBuffer.append(" on ");
                stringBuffer.append(getName());
                logger.error(stringBuffer.toString());
                bArr[i2] = 0;
            } else {
                bArr[i2] = Byte.parseByte(((Object[]) obj)[i2].toString());
            }
        }
        return bArr;
    }

    @Override // org.apache.xmlbeans.impl.jam.JAnnotationValue
    public char asChar() {
        Object obj = this.mValue;
        if (obj == null) {
            return 0;
        }
        if (obj instanceof Character) {
            return ((Character) obj).charValue();
        }
        String obj2 = obj.toString();
        this.mValue = obj2;
        if (obj2.length() == 0) {
            return 0;
        }
        return ((String) this.mValue).charAt(0);
    }

    @Override // org.apache.xmlbeans.impl.jam.JAnnotationValue
    public char[] asCharArray() {
        if (!this.mValue.getClass().isArray()) {
            return null;
        }
        int length = ((Object[]) this.mValue).length;
        char[] cArr = new char[length];
        for (int i2 = 0; i2 < length; i2++) {
            Object obj = this.mValue;
            if (((Object[]) obj)[i2] == null) {
                JamLogger logger = this.mContext.getLogger();
                StringBuffer stringBuffer = new StringBuffer();
                stringBuffer.append("Null annotation value array element ");
                stringBuffer.append(i2);
                stringBuffer.append(" on ");
                stringBuffer.append(getName());
                logger.error(stringBuffer.toString());
                cArr[i2] = 0;
            } else {
                cArr[i2] = ((Object[]) obj)[i2].toString().charAt(0);
            }
        }
        return cArr;
    }

    @Override // org.apache.xmlbeans.impl.jam.JAnnotationValue
    public JClass asClass() {
        Object obj = this.mValue;
        if (obj instanceof JClass) {
            return (JClass) obj;
        }
        return null;
    }

    @Override // org.apache.xmlbeans.impl.jam.JAnnotationValue
    public JClass[] asClassArray() {
        Object obj = this.mValue;
        if (obj instanceof JClass[]) {
            return (JClass[]) obj;
        }
        return null;
    }

    @Override // org.apache.xmlbeans.impl.jam.JAnnotationValue
    public double asDouble() {
        Object obj = this.mValue;
        if (obj == null) {
            return NumericFunction.LOG_10_TO_BASE_e;
        }
        if (obj instanceof Number) {
            return ((Number) obj).doubleValue();
        }
        try {
            return Double.parseDouble(obj.toString().trim());
        } catch (NumberFormatException unused) {
            return NumericFunction.LOG_10_TO_BASE_e;
        }
    }

    @Override // org.apache.xmlbeans.impl.jam.JAnnotationValue
    public double[] asDoubleArray() {
        if (!this.mValue.getClass().isArray()) {
            return null;
        }
        int length = ((Object[]) this.mValue).length;
        double[] dArr = new double[length];
        for (int i2 = 0; i2 < length; i2++) {
            Object obj = this.mValue;
            if (((Object[]) obj)[i2] == null) {
                JamLogger logger = this.mContext.getLogger();
                StringBuffer stringBuffer = new StringBuffer();
                stringBuffer.append("Null annotation value array element ");
                stringBuffer.append(i2);
                stringBuffer.append(" on ");
                stringBuffer.append(getName());
                logger.error(stringBuffer.toString());
                dArr[i2] = 0.0d;
            } else {
                dArr[i2] = Double.parseDouble(((Object[]) obj)[i2].toString());
            }
        }
        return dArr;
    }

    @Override // org.apache.xmlbeans.impl.jam.JAnnotationValue
    public float asFloat() {
        Object obj = this.mValue;
        if (obj == null) {
            return 0.0f;
        }
        if (obj instanceof Number) {
            return ((Number) obj).floatValue();
        }
        try {
            return Float.parseFloat(obj.toString().trim());
        } catch (NumberFormatException unused) {
            return 0.0f;
        }
    }

    @Override // org.apache.xmlbeans.impl.jam.JAnnotationValue
    public float[] asFloatArray() {
        if (!this.mValue.getClass().isArray()) {
            return null;
        }
        int length = ((Object[]) this.mValue).length;
        float[] fArr = new float[length];
        for (int i2 = 0; i2 < length; i2++) {
            Object obj = this.mValue;
            if (((Object[]) obj)[i2] == null) {
                JamLogger logger = this.mContext.getLogger();
                StringBuffer stringBuffer = new StringBuffer();
                stringBuffer.append("Null annotation value array element ");
                stringBuffer.append(i2);
                stringBuffer.append(" on ");
                stringBuffer.append(getName());
                logger.error(stringBuffer.toString());
                fArr[i2] = 0.0f;
            } else {
                fArr[i2] = Float.parseFloat(((Object[]) obj)[i2].toString());
            }
        }
        return fArr;
    }

    @Override // org.apache.xmlbeans.impl.jam.JAnnotationValue
    public int asInt() {
        Object obj = this.mValue;
        if (obj == null) {
            return 0;
        }
        if (obj instanceof Number) {
            return ((Number) obj).intValue();
        }
        try {
            return Integer.parseInt(obj.toString().trim());
        } catch (NumberFormatException unused) {
            return 0;
        }
    }

    @Override // org.apache.xmlbeans.impl.jam.JAnnotationValue
    public int[] asIntArray() {
        if (!this.mValue.getClass().isArray()) {
            return null;
        }
        int length = ((Object[]) this.mValue).length;
        int[] iArr = new int[length];
        for (int i2 = 0; i2 < length; i2++) {
            Object obj = this.mValue;
            if (((Object[]) obj)[i2] == null) {
                JamLogger logger = this.mContext.getLogger();
                StringBuffer stringBuffer = new StringBuffer();
                stringBuffer.append("Null annotation value array element ");
                stringBuffer.append(i2);
                stringBuffer.append(" on ");
                stringBuffer.append(getName());
                logger.error(stringBuffer.toString());
                iArr[i2] = 0;
            } else {
                iArr[i2] = Integer.parseInt(((Object[]) obj)[i2].toString());
            }
        }
        return iArr;
    }

    @Override // org.apache.xmlbeans.impl.jam.JAnnotationValue
    public long asLong() {
        Object obj = this.mValue;
        if (obj == null) {
            return 0;
        }
        if (obj instanceof Number) {
            return ((Number) obj).longValue();
        }
        try {
            return Long.parseLong(obj.toString().trim());
        } catch (NumberFormatException unused) {
            return 0;
        }
    }

    @Override // org.apache.xmlbeans.impl.jam.JAnnotationValue
    public long[] asLongArray() {
        if (!this.mValue.getClass().isArray()) {
            return null;
        }
        int length = ((Object[]) this.mValue).length;
        long[] jArr = new long[length];
        for (int i2 = 0; i2 < length; i2++) {
            Object obj = this.mValue;
            if (((Object[]) obj)[i2] == null) {
                JamLogger logger = this.mContext.getLogger();
                StringBuffer stringBuffer = new StringBuffer();
                stringBuffer.append("Null annotation value array element ");
                stringBuffer.append(i2);
                stringBuffer.append(" on ");
                stringBuffer.append(getName());
                logger.error(stringBuffer.toString());
                jArr[i2] = 0;
            } else {
                jArr[i2] = Long.parseLong(((Object[]) obj)[i2].toString());
            }
        }
        return jArr;
    }

    @Override // org.apache.xmlbeans.impl.jam.JAnnotationValue
    public short asShort() {
        Object obj = this.mValue;
        if (obj == null) {
            return 0;
        }
        if (obj instanceof Number) {
            return ((Number) obj).shortValue();
        }
        try {
            return Short.parseShort(obj.toString().trim());
        } catch (NumberFormatException unused) {
            return 0;
        }
    }

    @Override // org.apache.xmlbeans.impl.jam.JAnnotationValue
    public short[] asShortArray() {
        if (!this.mValue.getClass().isArray()) {
            return null;
        }
        int length = ((Object[]) this.mValue).length;
        short[] sArr = new short[length];
        for (int i2 = 0; i2 < length; i2++) {
            Object obj = this.mValue;
            if (((Object[]) obj)[i2] == null) {
                JamLogger logger = this.mContext.getLogger();
                StringBuffer stringBuffer = new StringBuffer();
                stringBuffer.append("Null annotation value array element ");
                stringBuffer.append(i2);
                stringBuffer.append(" on ");
                stringBuffer.append(getName());
                logger.error(stringBuffer.toString());
                sArr[i2] = 0;
            } else {
                sArr[i2] = Short.parseShort(((Object[]) obj)[i2].toString());
            }
        }
        return sArr;
    }

    @Override // org.apache.xmlbeans.impl.jam.JAnnotationValue
    public String asString() {
        Object obj = this.mValue;
        if (obj == null) {
            return null;
        }
        return obj.toString();
    }

    @Override // org.apache.xmlbeans.impl.jam.JAnnotationValue
    public String[] asStringArray() {
        if (!this.mValue.getClass().isArray()) {
            return null;
        }
        int length = ((Object[]) this.mValue).length;
        String[] strArr = new String[length];
        for (int i2 = 0; i2 < length; i2++) {
            Object obj = this.mValue;
            if (((Object[]) obj)[i2] == null) {
                JamLogger logger = this.mContext.getLogger();
                StringBuffer a = a.a("Null annotation value array element on ");
                a.append(getName());
                logger.error(a.toString());
                strArr[i2] = "";
            } else {
                strArr[i2] = ((Object[]) obj)[i2].toString();
            }
        }
        return strArr;
    }

    @Override // org.apache.xmlbeans.impl.jam.JAnnotationValue
    public String getName() {
        return this.mName;
    }

    @Override // org.apache.xmlbeans.impl.jam.JAnnotationValue
    public JClass getType() {
        return this.mType.getRefClass();
    }

    @Override // org.apache.xmlbeans.impl.jam.JAnnotationValue
    public Object getValue() {
        return this.mValue;
    }

    @Override // org.apache.xmlbeans.impl.jam.JAnnotationValue
    public boolean isDefaultValueUsed() {
        throw new IllegalStateException("NYI");
    }
}
