package org.apache.xmlbeans.impl.jam.internal.elements;

import b.b.a.a.a;
import java.io.StringWriter;
import org.apache.xmlbeans.impl.jam.JClass;
import org.apache.xmlbeans.impl.jam.JamClassLoader;

public final class ArrayClassImpl extends BuiltinClassImpl {
    public JClass mComponentType;
    public int mDimensions;

    public ArrayClassImpl(JClass jClass, int i2) {
        super(((ElementImpl) jClass).getContext());
        if (i2 < 1) {
            throw new IllegalArgumentException(a.b("dimensions=", i2));
        } else if (jClass != null) {
            this.mComponentType = jClass;
            this.mDimensions = i2;
        } else {
            throw new IllegalArgumentException("null componentType");
        }
    }

    public static JClass createClassForFD(String str, JamClassLoader jamClassLoader) {
        if (!str.startsWith("[")) {
            throw new IllegalArgumentException(a.a("must be an array type fd: ", str));
        } else if (str.endsWith(";")) {
            int indexOf = str.indexOf("L");
            if (indexOf != -1 && indexOf < str.length() - 2) {
                return new ArrayClassImpl(jamClassLoader.loadClass(str.substring(indexOf + 1, str.length() - 1)), indexOf);
            }
            throw new IllegalArgumentException(a.a("array type field descriptor '", str, "' is malformed"));
        } else {
            int lastIndexOf = str.lastIndexOf("[") + 1;
            JClass loadClass = jamClassLoader.loadClass(str.substring(lastIndexOf, lastIndexOf + 1));
            if (loadClass != null) {
                return new ArrayClassImpl(loadClass, lastIndexOf);
            }
            throw new IllegalArgumentException(a.a("array type field descriptor '", str, "' is malformed"));
        }
    }

    public static String normalizeArrayName(String str) {
        int indexOf;
        if (str.startsWith("[")) {
            return str;
        }
        if (!str.endsWith("]") || (indexOf = str.indexOf(91)) == -1) {
            throw new IllegalArgumentException(a.a("'", str, "' does not name an array"));
        }
        String substring = str.substring(0, indexOf);
        String primitiveClassForName = PrimitiveClassImpl.getPrimitiveClassForName(substring);
        if (primitiveClassForName == null) {
            StringBuffer stringBuffer = new StringBuffer();
            stringBuffer.append('L');
            stringBuffer.append(substring);
            stringBuffer.append(';');
            primitiveClassForName = stringBuffer.toString();
        }
        StringWriter stringWriter = new StringWriter();
        do {
            stringWriter.write(91);
            indexOf = str.indexOf(91, indexOf + 1);
        } while (indexOf != -1);
        stringWriter.write(primitiveClassForName);
        return stringWriter.toString();
    }

    @Override // org.apache.xmlbeans.impl.jam.internal.elements.BuiltinClassImpl, org.apache.xmlbeans.impl.jam.JClass
    public JClass getArrayComponentType() {
        return this.mComponentType;
    }

    @Override // org.apache.xmlbeans.impl.jam.internal.elements.BuiltinClassImpl, org.apache.xmlbeans.impl.jam.JClass
    public int getArrayDimensions() {
        return this.mDimensions;
    }

    @Override // org.apache.xmlbeans.impl.jam.internal.elements.BuiltinClassImpl, org.apache.xmlbeans.impl.jam.JClass
    public String getFieldDescriptor() {
        StringWriter stringWriter = new StringWriter();
        for (int i2 = 0; i2 < this.mDimensions; i2++) {
            stringWriter.write("[");
        }
        if (this.mComponentType.isPrimitiveType()) {
            stringWriter.write(this.mComponentType.getFieldDescriptor());
        } else {
            stringWriter.write("L");
            stringWriter.write(this.mComponentType.getQualifiedName());
            stringWriter.write(";");
        }
        return stringWriter.toString();
    }

    @Override // org.apache.xmlbeans.impl.jam.internal.elements.BuiltinClassImpl, org.apache.xmlbeans.impl.jam.JElement
    public String getQualifiedName() {
        StringWriter stringWriter = new StringWriter();
        stringWriter.write(this.mComponentType.getQualifiedName());
        for (int i2 = 0; i2 < this.mDimensions; i2++) {
            stringWriter.write("[]");
        }
        return stringWriter.toString();
    }

    @Override // org.apache.xmlbeans.impl.jam.JElement, org.apache.xmlbeans.impl.jam.internal.elements.ElementImpl
    public String getSimpleName() {
        String qualifiedName = getQualifiedName();
        int lastIndexOf = qualifiedName.lastIndexOf(46);
        return lastIndexOf == -1 ? qualifiedName : qualifiedName.substring(lastIndexOf + 1);
    }

    @Override // org.apache.xmlbeans.impl.jam.internal.elements.BuiltinClassImpl, org.apache.xmlbeans.impl.jam.JClass
    public JClass getSuperclass() {
        return getClassLoader().loadClass("java.lang.Object");
    }

    @Override // org.apache.xmlbeans.impl.jam.internal.elements.BuiltinClassImpl, org.apache.xmlbeans.impl.jam.JClass
    public boolean isArrayType() {
        return true;
    }

    @Override // org.apache.xmlbeans.impl.jam.JClass
    public boolean isAssignableFrom(JClass jClass) {
        return jClass.isArrayType() && jClass.getArrayDimensions() == this.mDimensions && this.mComponentType.isAssignableFrom(jClass.getArrayComponentType());
    }
}
