package org.apache.xmlbeans.impl.jam.internal.elements;

import b.b.a.a.a;
import java.lang.reflect.Modifier;
import java.util.ArrayList;
import java.util.Collection;
import java.util.TreeSet;
import org.apache.xmlbeans.impl.common.NameUtil;
import org.apache.xmlbeans.impl.jam.JAnnotation;
import org.apache.xmlbeans.impl.jam.JAnnotationValue;
import org.apache.xmlbeans.impl.jam.JClass;
import org.apache.xmlbeans.impl.jam.JComment;
import org.apache.xmlbeans.impl.jam.JConstructor;
import org.apache.xmlbeans.impl.jam.JField;
import org.apache.xmlbeans.impl.jam.JMethod;
import org.apache.xmlbeans.impl.jam.JPackage;
import org.apache.xmlbeans.impl.jam.JProperty;
import org.apache.xmlbeans.impl.jam.JSourcePosition;
import org.apache.xmlbeans.impl.jam.internal.JamClassLoaderImpl;
import org.apache.xmlbeans.impl.jam.internal.classrefs.JClassRef;
import org.apache.xmlbeans.impl.jam.internal.classrefs.JClassRefContext;
import org.apache.xmlbeans.impl.jam.internal.classrefs.QualifiedJClassRef;
import org.apache.xmlbeans.impl.jam.internal.classrefs.UnqualifiedJClassRef;
import org.apache.xmlbeans.impl.jam.mutable.MClass;
import org.apache.xmlbeans.impl.jam.mutable.MConstructor;
import org.apache.xmlbeans.impl.jam.mutable.MField;
import org.apache.xmlbeans.impl.jam.mutable.MMethod;
import org.apache.xmlbeans.impl.jam.provider.JamClassPopulator;
import org.apache.xmlbeans.impl.jam.visitor.JVisitor;
import org.apache.xmlbeans.impl.jam.visitor.MVisitor;

public class ClassImpl extends MemberImpl implements MClass, JClassRef, JClassRefContext {
    public static final int INITIALIZING = 5;
    public static final int LOADED = 6;
    public static final int NEW = 1;
    public static final int POPULATING = 3;
    public static final int UNINITIALIZED = 4;
    public static final int UNPOPULATED = 2;
    public ArrayList mConstructors = null;
    public ArrayList mDeclaredProperties = null;
    public ArrayList mFields = null;
    public String[] mImports = null;
    public ArrayList mInnerClasses = null;
    public ArrayList mInterfaceRefs = null;
    public boolean mIsAnnotationType = false;
    public boolean mIsEnum = false;
    public boolean mIsInterface = false;
    public ArrayList mMethods = null;
    public String mPackageName = null;
    public JamClassPopulator mPopulator;
    public ArrayList mProperties = null;
    public int mState = 1;
    public JClassRef mSuperClassRef = null;

    public ClassImpl(String str, String str2, ElementContext elementContext, String[] strArr, JamClassPopulator jamClassPopulator) {
        super(elementContext);
        super.setSimpleName(str2);
        this.mPackageName = str.trim();
        this.mImports = strArr;
        this.mPopulator = jamClassPopulator;
        setState(2);
    }

    private void addFieldsRecursively(JClass jClass, Collection collection) {
        JField[] declaredFields;
        JClass[] interfaces;
        for (JField jField : jClass.getDeclaredFields()) {
            collection.add(jField);
        }
        for (JClass jClass2 : jClass.getInterfaces()) {
            addFieldsRecursively(jClass2, collection);
        }
        JClass superclass = jClass.getSuperclass();
        if (superclass != null) {
            addFieldsRecursively(superclass, collection);
        }
    }

    private void addMethodsRecursively(JClass jClass, Collection collection) {
        JMethod[] declaredMethods;
        JClass[] interfaces;
        for (JMethod jMethod : jClass.getDeclaredMethods()) {
            collection.add(jMethod);
        }
        for (JClass jClass2 : jClass.getInterfaces()) {
            addMethodsRecursively(jClass2, collection);
        }
        JClass superclass = jClass.getSuperclass();
        if (superclass != null) {
            addMethodsRecursively(superclass, collection);
        }
    }

    private boolean isAssignableFromRecursively(JClass jClass) {
        if (getQualifiedName().equals(jClass.getQualifiedName())) {
            return true;
        }
        JClass[] interfaces = jClass.getInterfaces();
        if (interfaces != null) {
            for (JClass jClass2 : interfaces) {
                if (isAssignableFromRecursively(jClass2)) {
                    return true;
                }
            }
        }
        JClass superclass = jClass.getSuperclass();
        if (superclass == null || !isAssignableFromRecursively(superclass)) {
            return false;
        }
        return true;
    }

    public static void validateClassName(String str) {
        if (str == null) {
            throw new IllegalArgumentException("null class name specified");
        } else if (Character.isJavaIdentifierStart(str.charAt(0))) {
            for (int i2 = 1; i2 < str.length(); i2++) {
                char charAt = str.charAt(i2);
                if (charAt == '.') {
                    if (str.charAt(i2 - 1) == '.') {
                        throw new IllegalArgumentException(a.a("'..' not allowed in class name: ", str));
                    } else if (i2 == str.length() - 1) {
                        throw new IllegalArgumentException(a.a("'.' not allowed at end of class name: ", str));
                    }
                } else if (!Character.isJavaIdentifierPart(charAt)) {
                    StringBuffer stringBuffer = new StringBuffer();
                    stringBuffer.append("Illegal character '");
                    stringBuffer.append(charAt);
                    stringBuffer.append("' in class name: ");
                    stringBuffer.append(str);
                    throw new IllegalArgumentException(stringBuffer.toString());
                }
            }
        } else {
            throw new IllegalArgumentException(a.a("Invalid first character in class name: ", str));
        }
    }

    @Override // org.apache.xmlbeans.impl.jam.mutable.MElement
    public void accept(MVisitor mVisitor) {
        mVisitor.visit(this);
    }

    @Override // org.apache.xmlbeans.impl.jam.mutable.MClass
    public void addInterface(JClass jClass) {
        if (jClass != null) {
            addInterface(jClass.getQualifiedName());
            return;
        }
        throw new IllegalArgumentException("null interf");
    }

    @Override // org.apache.xmlbeans.impl.jam.mutable.MClass
    public void addInterfaceUnqualified(String str) {
        if (this.mInterfaceRefs == null) {
            this.mInterfaceRefs = new ArrayList();
        }
        this.mInterfaceRefs.add(UnqualifiedJClassRef.create(str, this));
    }

    @Override // org.apache.xmlbeans.impl.jam.mutable.MClass
    public MConstructor addNewConstructor() {
        if (this.mConstructors == null) {
            this.mConstructors = new ArrayList();
        }
        ConstructorImpl constructorImpl = new ConstructorImpl(this);
        this.mConstructors.add(constructorImpl);
        return constructorImpl;
    }

    @Override // org.apache.xmlbeans.impl.jam.mutable.MClass
    public JProperty addNewDeclaredProperty(String str, JMethod jMethod, JMethod jMethod2) {
        if (this.mDeclaredProperties == null) {
            this.mDeclaredProperties = new ArrayList();
        }
        PropertyImpl propertyImpl = new PropertyImpl(str, jMethod, jMethod2, (jMethod != null ? jMethod.getReturnType() : jMethod2.getParameters()[0].getType()).getFieldDescriptor());
        this.mDeclaredProperties.add(propertyImpl);
        return propertyImpl;
    }

    @Override // org.apache.xmlbeans.impl.jam.mutable.MClass
    public MField addNewField() {
        if (this.mFields == null) {
            this.mFields = new ArrayList();
        }
        FieldImpl fieldImpl = new FieldImpl(ElementImpl.defaultName(this.mFields.size()), this, "java.lang.Object");
        this.mFields.add(fieldImpl);
        return fieldImpl;
    }

    @Override // org.apache.xmlbeans.impl.jam.mutable.MClass
    public MClass addNewInnerClass(String str) {
        int lastIndexOf = str.lastIndexOf(46);
        if (lastIndexOf == -1) {
            lastIndexOf = str.lastIndexOf(36);
        }
        if (lastIndexOf != -1) {
            str = str.substring(lastIndexOf + 1);
        }
        String str2 = this.mPackageName;
        StringBuffer stringBuffer = new StringBuffer();
        stringBuffer.append(getSimpleName());
        stringBuffer.append("$");
        stringBuffer.append(str);
        ClassImpl classImpl = new ClassImpl(str2, stringBuffer.toString(), getImportSpecs(), this);
        if (this.mInnerClasses == null) {
            this.mInnerClasses = new ArrayList();
        }
        this.mInnerClasses.add(classImpl);
        classImpl.setState(6);
        ((JamClassLoaderImpl) getClassLoader()).addToCache(classImpl);
        return classImpl;
    }

    @Override // org.apache.xmlbeans.impl.jam.mutable.MClass
    public MMethod addNewMethod() {
        if (this.mMethods == null) {
            this.mMethods = new ArrayList();
        }
        MethodImpl methodImpl = new MethodImpl(ElementImpl.defaultName(this.mMethods.size()), this);
        this.mMethods.add(methodImpl);
        return methodImpl;
    }

    @Override // org.apache.xmlbeans.impl.jam.mutable.MClass
    public JProperty addNewProperty(String str, JMethod jMethod, JMethod jMethod2) {
        if (this.mProperties == null) {
            this.mProperties = new ArrayList();
        }
        PropertyImpl propertyImpl = new PropertyImpl(str, jMethod, jMethod2, (jMethod != null ? jMethod.getReturnType() : jMethod2.getParameters()[0].getType()).getFieldDescriptor());
        this.mProperties.add(propertyImpl);
        return propertyImpl;
    }

    public void ensureLoaded() {
        int i2 = this.mState;
        if (i2 != 6) {
            if (i2 == 2) {
                if (this.mPopulator != null) {
                    setState(3);
                    this.mPopulator.populate(this);
                    setState(4);
                } else {
                    throw new IllegalStateException("null populator");
                }
            }
            if (this.mState == 4) {
                setState(5);
                ((JamClassLoaderImpl) getClassLoader()).initialize(this);
            }
            setState(6);
        }
    }

    @Override // org.apache.xmlbeans.impl.jam.JClass
    public JClass forName(String str) {
        return getClassLoader().loadClass(str);
    }

    @Override // org.apache.xmlbeans.impl.jam.JAnnotatedElement, org.apache.xmlbeans.impl.jam.internal.elements.AnnotatedElementImpl
    public JAnnotation[] getAllJavadocTags() {
        ensureLoaded();
        return super.getAllJavadocTags();
    }

    @Override // org.apache.xmlbeans.impl.jam.JAnnotatedElement, org.apache.xmlbeans.impl.jam.internal.elements.AnnotatedElementImpl
    public JAnnotation getAnnotation(Class cls) {
        ensureLoaded();
        return super.getAnnotation(cls);
    }

    @Override // org.apache.xmlbeans.impl.jam.JAnnotatedElement, org.apache.xmlbeans.impl.jam.internal.elements.AnnotatedElementImpl
    public Object getAnnotationProxy(Class cls) {
        ensureLoaded();
        return super.getAnnotationProxy(cls);
    }

    @Override // org.apache.xmlbeans.impl.jam.JAnnotatedElement, org.apache.xmlbeans.impl.jam.internal.elements.AnnotatedElementImpl
    public JAnnotationValue getAnnotationValue(String str) {
        ensureLoaded();
        return super.getAnnotationValue(str);
    }

    @Override // org.apache.xmlbeans.impl.jam.JAnnotatedElement, org.apache.xmlbeans.impl.jam.internal.elements.AnnotatedElementImpl
    public JAnnotation[] getAnnotations() {
        ensureLoaded();
        return super.getAnnotations();
    }

    @Override // org.apache.xmlbeans.impl.jam.JClass
    public JClass getArrayComponentType() {
        return null;
    }

    @Override // org.apache.xmlbeans.impl.jam.JClass
    public int getArrayDimensions() {
        return 0;
    }

    @Override // org.apache.xmlbeans.impl.jam.JClass
    public JClass[] getClasses() {
        ensureLoaded();
        ArrayList arrayList = this.mInnerClasses;
        if (arrayList == null) {
            return new JClass[0];
        }
        JClass[] jClassArr = new JClass[arrayList.size()];
        this.mInnerClasses.toArray(jClassArr);
        return jClassArr;
    }

    @Override // org.apache.xmlbeans.impl.jam.JAnnotatedElement, org.apache.xmlbeans.impl.jam.internal.elements.AnnotatedElementImpl
    public JComment getComment() {
        ensureLoaded();
        return super.getComment();
    }

    @Override // org.apache.xmlbeans.impl.jam.JClass
    public JConstructor[] getConstructors() {
        ensureLoaded();
        return getMutableConstructors();
    }

    @Override // org.apache.xmlbeans.impl.jam.JClass
    public JPackage getContainingPackage() {
        return getClassLoader().getPackage(this.mPackageName);
    }

    @Override // org.apache.xmlbeans.impl.jam.JClass
    public JField[] getDeclaredFields() {
        ensureLoaded();
        return getMutableFields();
    }

    @Override // org.apache.xmlbeans.impl.jam.JClass
    public JMethod[] getDeclaredMethods() {
        ensureLoaded();
        return getMutableMethods();
    }

    @Override // org.apache.xmlbeans.impl.jam.JClass
    public JProperty[] getDeclaredProperties() {
        ensureLoaded();
        ArrayList arrayList = this.mDeclaredProperties;
        if (arrayList == null) {
            return new JProperty[0];
        }
        JProperty[] jPropertyArr = new JProperty[arrayList.size()];
        this.mDeclaredProperties.toArray(jPropertyArr);
        return jPropertyArr;
    }

    @Override // org.apache.xmlbeans.impl.jam.JClass
    public String getFieldDescriptor() {
        return getQualifiedName();
    }

    @Override // org.apache.xmlbeans.impl.jam.JClass
    public JField[] getFields() {
        ensureLoaded();
        ArrayList arrayList = new ArrayList();
        addFieldsRecursively(this, arrayList);
        JField[] jFieldArr = new JField[arrayList.size()];
        arrayList.toArray(jFieldArr);
        return jFieldArr;
    }

    @Override // org.apache.xmlbeans.impl.jam.internal.classrefs.JClassRefContext
    public String[] getImportSpecs() {
        ensureLoaded();
        String[] strArr = this.mImports;
        return strArr == null ? new String[0] : strArr;
    }

    @Override // org.apache.xmlbeans.impl.jam.JClass
    public JClass[] getImportedClasses() {
        ensureLoaded();
        String[] importSpecs = getImportSpecs();
        if (importSpecs == null) {
            return new JClass[0];
        }
        ArrayList arrayList = new ArrayList();
        for (int i2 = 0; i2 < importSpecs.length; i2++) {
            if (!importSpecs[i2].endsWith("*")) {
                arrayList.add(getClassLoader().loadClass(importSpecs[i2]));
            }
        }
        JClass[] jClassArr = new JClass[arrayList.size()];
        arrayList.toArray(jClassArr);
        return jClassArr;
    }

    @Override // org.apache.xmlbeans.impl.jam.JClass
    public JPackage[] getImportedPackages() {
        JClass[] importedClasses;
        ensureLoaded();
        TreeSet treeSet = new TreeSet();
        for (JClass jClass : getImportedClasses()) {
            JPackage containingPackage = jClass.getContainingPackage();
            if (containingPackage != null) {
                treeSet.add(containingPackage);
            }
        }
        String[] importSpecs = getImportSpecs();
        if (importSpecs != null) {
            for (int i2 = 0; i2 < importSpecs.length; i2++) {
                if (importSpecs[i2].endsWith(".*")) {
                    treeSet.add(getClassLoader().getPackage(importSpecs[i2].substring(0, importSpecs[i2].length() - 2)));
                }
            }
        }
        JPackage[] jPackageArr = new JPackage[treeSet.size()];
        treeSet.toArray(jPackageArr);
        return jPackageArr;
    }

    @Override // org.apache.xmlbeans.impl.jam.JClass
    public JClass[] getInterfaces() {
        ensureLoaded();
        ArrayList arrayList = this.mInterfaceRefs;
        if (arrayList == null || arrayList.size() == 0) {
            return new JClass[0];
        }
        int size = this.mInterfaceRefs.size();
        JClass[] jClassArr = new JClass[size];
        for (int i2 = 0; i2 < size; i2++) {
            jClassArr[i2] = ((JClassRef) this.mInterfaceRefs.get(i2)).getRefClass();
        }
        return jClassArr;
    }

    @Override // org.apache.xmlbeans.impl.jam.JClass
    public JMethod[] getMethods() {
        ensureLoaded();
        ArrayList arrayList = new ArrayList();
        addMethodsRecursively(this, arrayList);
        JMethod[] jMethodArr = new JMethod[arrayList.size()];
        arrayList.toArray(jMethodArr);
        return jMethodArr;
    }

    @Override // org.apache.xmlbeans.impl.jam.JMember, org.apache.xmlbeans.impl.jam.internal.elements.MemberImpl
    public int getModifiers() {
        ensureLoaded();
        return super.getModifiers();
    }

    @Override // org.apache.xmlbeans.impl.jam.mutable.MClass
    public MConstructor[] getMutableConstructors() {
        ArrayList arrayList = this.mConstructors;
        if (arrayList == null || arrayList.size() == 0) {
            return new MConstructor[0];
        }
        MConstructor[] mConstructorArr = new MConstructor[this.mConstructors.size()];
        this.mConstructors.toArray(mConstructorArr);
        return mConstructorArr;
    }

    @Override // org.apache.xmlbeans.impl.jam.mutable.MClass
    public MField[] getMutableFields() {
        ArrayList arrayList = this.mFields;
        if (arrayList == null || arrayList.size() == 0) {
            return new MField[0];
        }
        MField[] mFieldArr = new MField[this.mFields.size()];
        this.mFields.toArray(mFieldArr);
        return mFieldArr;
    }

    @Override // org.apache.xmlbeans.impl.jam.mutable.MClass
    public MMethod[] getMutableMethods() {
        ArrayList arrayList = this.mMethods;
        if (arrayList == null || arrayList.size() == 0) {
            return new MMethod[0];
        }
        MMethod[] mMethodArr = new MMethod[this.mMethods.size()];
        this.mMethods.toArray(mMethodArr);
        return mMethodArr;
    }

    @Override // org.apache.xmlbeans.impl.jam.internal.classrefs.JClassRefContext
    public String getPackageName() {
        return this.mPackageName;
    }

    @Override // org.apache.xmlbeans.impl.jam.JClass
    public Class getPrimitiveClass() {
        return null;
    }

    @Override // org.apache.xmlbeans.impl.jam.JClass
    public JProperty[] getProperties() {
        ensureLoaded();
        ArrayList arrayList = this.mProperties;
        if (arrayList == null) {
            return new JProperty[0];
        }
        JProperty[] jPropertyArr = new JProperty[arrayList.size()];
        this.mProperties.toArray(jPropertyArr);
        return jPropertyArr;
    }

    @Override // org.apache.xmlbeans.impl.jam.internal.classrefs.JClassRef, org.apache.xmlbeans.impl.jam.JElement
    public String getQualifiedName() {
        String str;
        StringBuffer stringBuffer = new StringBuffer();
        if (this.mPackageName.length() > 0) {
            StringBuffer stringBuffer2 = new StringBuffer();
            stringBuffer2.append(this.mPackageName);
            stringBuffer2.append(NameUtil.PERIOD);
            str = stringBuffer2.toString();
        } else {
            str = "";
        }
        stringBuffer.append(str);
        stringBuffer.append(this.mSimpleName);
        return stringBuffer.toString();
    }

    @Override // org.apache.xmlbeans.impl.jam.internal.classrefs.JClassRef
    public JClass getRefClass() {
        return this;
    }

    @Override // org.apache.xmlbeans.impl.jam.JElement, org.apache.xmlbeans.impl.jam.internal.elements.ElementImpl
    public JSourcePosition getSourcePosition() {
        ensureLoaded();
        return super.getSourcePosition();
    }

    @Override // org.apache.xmlbeans.impl.jam.JClass
    public JClass getSuperclass() {
        ensureLoaded();
        JClassRef jClassRef = this.mSuperClassRef;
        if (jClassRef == null) {
            return null;
        }
        return jClassRef.getRefClass();
    }

    @Override // org.apache.xmlbeans.impl.jam.JClass
    public boolean isAbstract() {
        return Modifier.isAbstract(getModifiers());
    }

    @Override // org.apache.xmlbeans.impl.jam.JClass
    public boolean isAnnotationType() {
        ensureLoaded();
        return this.mIsAnnotationType;
    }

    @Override // org.apache.xmlbeans.impl.jam.JClass
    public boolean isArrayType() {
        return false;
    }

    @Override // org.apache.xmlbeans.impl.jam.JClass
    public boolean isAssignableFrom(JClass jClass) {
        ensureLoaded();
        if (isPrimitiveType() || jClass.isPrimitiveType()) {
            return getQualifiedName().equals(jClass.getQualifiedName());
        }
        return isAssignableFromRecursively(jClass);
    }

    @Override // org.apache.xmlbeans.impl.jam.JClass
    public boolean isBuiltinType() {
        return false;
    }

    @Override // org.apache.xmlbeans.impl.jam.JClass
    public boolean isEnumType() {
        ensureLoaded();
        return this.mIsEnum;
    }

    @Override // org.apache.xmlbeans.impl.jam.JClass
    public boolean isFinal() {
        return Modifier.isFinal(getModifiers());
    }

    @Override // org.apache.xmlbeans.impl.jam.JClass
    public boolean isInterface() {
        ensureLoaded();
        return this.mIsInterface;
    }

    @Override // org.apache.xmlbeans.impl.jam.JClass
    public boolean isObjectType() {
        return getQualifiedName().equals("java.lang.Object");
    }

    @Override // org.apache.xmlbeans.impl.jam.JClass
    public boolean isPrimitiveType() {
        return false;
    }

    @Override // org.apache.xmlbeans.impl.jam.JClass
    public boolean isStatic() {
        return Modifier.isStatic(getModifiers());
    }

    @Override // org.apache.xmlbeans.impl.jam.JClass
    public boolean isUnresolvedType() {
        return false;
    }

    @Override // org.apache.xmlbeans.impl.jam.JClass
    public boolean isVoidType() {
        return false;
    }

    @Override // org.apache.xmlbeans.impl.jam.mutable.MClass
    public void removeConstructor(MConstructor mConstructor) {
        ArrayList arrayList = this.mConstructors;
        if (arrayList != null) {
            arrayList.remove(mConstructor);
        }
    }

    @Override // org.apache.xmlbeans.impl.jam.mutable.MClass
    public void removeDeclaredProperty(JProperty jProperty) {
        ArrayList arrayList = this.mDeclaredProperties;
        if (arrayList != null) {
            arrayList.remove(jProperty);
        }
    }

    @Override // org.apache.xmlbeans.impl.jam.mutable.MClass
    public void removeField(MField mField) {
        ArrayList arrayList = this.mFields;
        if (arrayList != null) {
            arrayList.remove(mField);
        }
    }

    @Override // org.apache.xmlbeans.impl.jam.mutable.MClass
    public void removeInnerClass(MClass mClass) {
        ArrayList arrayList = this.mInnerClasses;
        if (arrayList != null) {
            arrayList.remove(mClass);
        }
    }

    @Override // org.apache.xmlbeans.impl.jam.mutable.MClass
    public void removeInterface(JClass jClass) {
        if (jClass != null) {
            removeInterface(jClass.getQualifiedName());
            return;
        }
        throw new IllegalArgumentException("null interf");
    }

    @Override // org.apache.xmlbeans.impl.jam.mutable.MClass
    public void removeMethod(MMethod mMethod) {
        ArrayList arrayList = this.mMethods;
        if (arrayList != null) {
            arrayList.remove(mMethod);
        }
    }

    @Override // org.apache.xmlbeans.impl.jam.mutable.MClass
    public void removeProperty(JProperty jProperty) {
        ArrayList arrayList = this.mProperties;
        if (arrayList != null) {
            arrayList.remove(jProperty);
        }
    }

    @Override // org.apache.xmlbeans.impl.jam.mutable.MClass
    public void setIsAnnotationType(boolean z) {
        this.mIsAnnotationType = z;
    }

    @Override // org.apache.xmlbeans.impl.jam.mutable.MClass
    public void setIsEnumType(boolean z) {
        this.mIsEnum = z;
    }

    @Override // org.apache.xmlbeans.impl.jam.mutable.MClass
    public void setIsInterface(boolean z) {
        this.mIsInterface = z;
    }

    @Override // org.apache.xmlbeans.impl.jam.mutable.MElement, org.apache.xmlbeans.impl.jam.internal.elements.ElementImpl
    public void setSimpleName(String str) {
        throw new UnsupportedOperationException("Class names cannot be changed");
    }

    public void setState(int i2) {
        this.mState = i2;
    }

    @Override // org.apache.xmlbeans.impl.jam.mutable.MClass
    public void setSuperclass(String str) {
        if (str == null) {
            this.mSuperClassRef = null;
        } else if (!str.equals(getQualifiedName())) {
            this.mSuperClassRef = QualifiedJClassRef.create(str, this);
        } else {
            throw new IllegalArgumentException(a.a("A class cannot be it's own superclass: '", str, "'"));
        }
    }

    @Override // org.apache.xmlbeans.impl.jam.mutable.MClass
    public void setSuperclassUnqualified(String str) {
        this.mSuperClassRef = UnqualifiedJClassRef.create(str, this);
    }

    @Override // org.apache.xmlbeans.impl.jam.JElement
    public void accept(JVisitor jVisitor) {
        jVisitor.visit(this);
    }

    @Override // org.apache.xmlbeans.impl.jam.mutable.MClass
    public void addInterface(String str) {
        if (this.mInterfaceRefs == null) {
            this.mInterfaceRefs = new ArrayList();
        }
        if (!str.equals(getQualifiedName())) {
            this.mInterfaceRefs.add(QualifiedJClassRef.create(str, this));
            return;
        }
        throw new IllegalArgumentException(a.a("A class cannot implement itself: '", str, "'"));
    }

    @Override // org.apache.xmlbeans.impl.jam.JAnnotatedElement, org.apache.xmlbeans.impl.jam.internal.elements.AnnotatedElementImpl
    public JAnnotation getAnnotation(String str) {
        ensureLoaded();
        return super.getAnnotation(str);
    }

    @Override // org.apache.xmlbeans.impl.jam.mutable.MClass
    public void removeInterface(String str) {
        if (str == null) {
            throw new IllegalArgumentException("null classname");
        } else if (this.mInterfaceRefs != null) {
            for (int i2 = 0; i2 < this.mInterfaceRefs.size(); i2++) {
                if (str.equals(((JClassRef) this.mInterfaceRefs.get(i2)).getQualifiedName())) {
                    this.mInterfaceRefs.remove(i2);
                }
            }
        }
    }

    @Override // org.apache.xmlbeans.impl.jam.mutable.MClass
    public void setSuperclass(JClass jClass) {
        if (jClass == null) {
            this.mSuperClassRef = null;
        } else {
            setSuperclass(jClass.getQualifiedName());
        }
    }

    public ClassImpl(String str, String str2, ElementContext elementContext, String[] strArr) {
        super(elementContext);
        super.setSimpleName(str2);
        this.mPackageName = str.trim();
        this.mImports = strArr;
        this.mPopulator = null;
        setState(4);
    }

    public ClassImpl(String str, String str2, String[] strArr, ClassImpl classImpl) {
        super(classImpl);
        super.setSimpleName(str2);
        this.mPackageName = str.trim();
        this.mImports = strArr;
        this.mPopulator = null;
        setState(4);
    }
}
