package org.apache.xmlbeans.impl.jam.internal.elements;

import java.io.StringWriter;
import java.util.ArrayList;
import java.util.List;
import org.apache.xmlbeans.impl.jam.JClass;
import org.apache.xmlbeans.impl.jam.JParameter;
import org.apache.xmlbeans.impl.jam.internal.classrefs.DirectJClassRef;
import org.apache.xmlbeans.impl.jam.internal.classrefs.JClassRef;
import org.apache.xmlbeans.impl.jam.internal.classrefs.QualifiedJClassRef;
import org.apache.xmlbeans.impl.jam.internal.classrefs.UnqualifiedJClassRef;
import org.apache.xmlbeans.impl.jam.mutable.MInvokable;
import org.apache.xmlbeans.impl.jam.mutable.MParameter;

public abstract class InvokableImpl extends MemberImpl implements MInvokable {
    public List mExceptionClassRefs = null;
    public List mParameters = null;

    public InvokableImpl(ClassImpl classImpl) {
        super(classImpl);
    }

    @Override // org.apache.xmlbeans.impl.jam.mutable.MInvokable
    public void addException(JClass jClass) {
        if (jClass != null) {
            if (this.mExceptionClassRefs == null) {
                this.mExceptionClassRefs = new ArrayList();
            }
            this.mExceptionClassRefs.add(DirectJClassRef.create(jClass));
            return;
        }
        throw new IllegalArgumentException("null exception class");
    }

    @Override // org.apache.xmlbeans.impl.jam.mutable.MInvokable
    public MParameter addNewParameter() {
        if (this.mParameters == null) {
            this.mParameters = new ArrayList();
        }
        ParameterImpl parameterImpl = new ParameterImpl(ElementImpl.defaultName(this.mParameters.size()), this, "java.lang.Object");
        this.mParameters.add(parameterImpl);
        return parameterImpl;
    }

    public void addUnqualifiedException(String str) {
        if (str != null) {
            if (this.mExceptionClassRefs == null) {
                this.mExceptionClassRefs = new ArrayList();
            }
            this.mExceptionClassRefs.add(UnqualifiedJClassRef.create(str, (ClassImpl) getContainingClass()));
            return;
        }
        throw new IllegalArgumentException("null qcname");
    }

    @Override // org.apache.xmlbeans.impl.jam.JInvokable
    public JClass[] getExceptionTypes() {
        List list = this.mExceptionClassRefs;
        if (list == null || list.size() == 0) {
            return new JClass[0];
        }
        int size = this.mExceptionClassRefs.size();
        JClass[] jClassArr = new JClass[size];
        for (int i2 = 0; i2 < size; i2++) {
            jClassArr[i2] = ((JClassRef) this.mExceptionClassRefs.get(i2)).getRefClass();
        }
        return jClassArr;
    }

    @Override // org.apache.xmlbeans.impl.jam.mutable.MInvokable
    public MParameter[] getMutableParameters() {
        List list = this.mParameters;
        if (list == null || list.size() == 0) {
            return new MParameter[0];
        }
        MParameter[] mParameterArr = new MParameter[this.mParameters.size()];
        this.mParameters.toArray(mParameterArr);
        return mParameterArr;
    }

    @Override // org.apache.xmlbeans.impl.jam.JInvokable
    public JParameter[] getParameters() {
        return getMutableParameters();
    }

    @Override // org.apache.xmlbeans.impl.jam.JElement
    public String getQualifiedName() {
        StringWriter stringWriter = new StringWriter();
        stringWriter.write(getContainingClass().getQualifiedName());
        stringWriter.write(46);
        stringWriter.write(getSimpleName());
        stringWriter.write(40);
        JParameter[] parameters = getParameters();
        for (int i2 = 0; i2 < parameters.length; i2++) {
            stringWriter.write(parameters[i2].getType().getQualifiedName());
            if (i2 < parameters.length - 1) {
                stringWriter.write(", ");
            }
        }
        stringWriter.write(41);
        return stringWriter.toString();
    }

    @Override // org.apache.xmlbeans.impl.jam.mutable.MInvokable
    public void removeException(String str) {
        if (str != null) {
            List list = this.mExceptionClassRefs;
            if (list != null) {
                list.remove(str);
                return;
            }
            return;
        }
        throw new IllegalArgumentException("null classname");
    }

    @Override // org.apache.xmlbeans.impl.jam.mutable.MInvokable
    public void removeParameter(MParameter mParameter) {
        List list = this.mParameters;
        if (list != null) {
            list.remove(mParameter);
        }
    }

    public void setUnqualifiedThrows(List list) {
        if (list == null || list.size() == 0) {
            this.mExceptionClassRefs = null;
            return;
        }
        this.mExceptionClassRefs = new ArrayList(list.size());
        for (int i2 = 0; i2 < list.size(); i2++) {
            this.mExceptionClassRefs.add(UnqualifiedJClassRef.create((String) list.get(i2), (ClassImpl) getContainingClass()));
        }
    }

    @Override // org.apache.xmlbeans.impl.jam.mutable.MInvokable
    public void addException(String str) {
        if (str != null) {
            if (this.mExceptionClassRefs == null) {
                this.mExceptionClassRefs = new ArrayList();
            }
            this.mExceptionClassRefs.add(QualifiedJClassRef.create(str, (ClassImpl) getContainingClass()));
            return;
        }
        throw new IllegalArgumentException("null qcname");
    }

    @Override // org.apache.xmlbeans.impl.jam.mutable.MInvokable
    public void removeException(JClass jClass) {
        removeException(jClass.getQualifiedName());
    }
}
