package org.apache.xmlbeans.impl.jam.internal.javadoc;

import b.b.a.a.a;
import com.sun.javadoc.ClassDoc;
import com.sun.javadoc.Doc;
import com.sun.javadoc.ExecutableMemberDoc;
import com.sun.javadoc.FieldDoc;
import com.sun.javadoc.MethodDoc;
import com.sun.javadoc.PackageDoc;
import com.sun.javadoc.Parameter;
import com.sun.javadoc.ProgramElementDoc;
import com.sun.javadoc.RootDoc;
import com.sun.javadoc.SourcePosition;
import com.sun.javadoc.Tag;
import com.sun.javadoc.Type;
import java.io.File;
import java.io.FileNotFoundException;
import java.io.IOException;
import java.io.PrintWriter;
import java.io.StringWriter;
import java.util.ArrayList;
import java.util.StringTokenizer;
import org.apache.poi.ss.formula.function.FunctionMetadataReader;
import org.apache.xmlbeans.impl.common.NameUtil;
import org.apache.xmlbeans.impl.jam.annotation.JavadocTagParser;
import org.apache.xmlbeans.impl.jam.internal.JamServiceContextImpl;
import org.apache.xmlbeans.impl.jam.internal.elements.ElementContext;
import org.apache.xmlbeans.impl.jam.internal.elements.PrimitiveClassImpl;
import org.apache.xmlbeans.impl.jam.mutable.MAnnotatedElement;
import org.apache.xmlbeans.impl.jam.mutable.MClass;
import org.apache.xmlbeans.impl.jam.mutable.MElement;
import org.apache.xmlbeans.impl.jam.mutable.MField;
import org.apache.xmlbeans.impl.jam.mutable.MInvokable;
import org.apache.xmlbeans.impl.jam.mutable.MMethod;
import org.apache.xmlbeans.impl.jam.mutable.MParameter;
import org.apache.xmlbeans.impl.jam.mutable.MSourcePosition;
import org.apache.xmlbeans.impl.jam.provider.JamClassBuilder;
import org.apache.xmlbeans.impl.jam.provider.JamClassPopulator;
import org.apache.xmlbeans.impl.jam.provider.JamLogger;
import org.apache.xmlbeans.impl.jam.provider.JamServiceContext;

public class JavadocClassBuilder extends JamClassBuilder implements JamClassPopulator {
    public static final String ARGS_PROPERTY = "javadoc.args";
    public static final String PARSETAGS_PROPERTY = "javadoc.parsetags";
    public boolean mParseTags = true;
    public RootDoc mRootDoc = null;
    public JavadocTagParser mTagParser = null;
    public JavadocTigerDelegate mTigerDelegate = null;

    private void addAnnotations(MAnnotatedElement mAnnotatedElement, ProgramElementDoc programElementDoc) {
        String commentText = programElementDoc.commentText();
        if (commentText != null) {
            mAnnotatedElement.createComment().setText(commentText);
        }
        Tag[] tags = programElementDoc.tags();
        for (int i2 = 0; i2 < tags.length; i2++) {
            if (getLogger().isVerbose(this)) {
                JamLogger logger = getLogger();
                StringBuffer a = a.a("...'");
                a.append(tags[i2].name());
                a.append("' ' ");
                a.append(tags[i2].text());
                logger.verbose(a.toString());
            }
            this.mTagParser.parse(mAnnotatedElement, tags[i2]);
        }
        JavadocTigerDelegate javadocTigerDelegate = this.mTigerDelegate;
        if (javadocTigerDelegate != null) {
            javadocTigerDelegate.extractAnnotations(mAnnotatedElement, programElementDoc);
        }
    }

    public static void addSourcePosition(MElement mElement, Doc doc) {
        SourcePosition position = doc.position();
        if (position != null) {
            addSourcePosition(mElement, position);
        }
    }

    public static String getFdFor(Type type) {
        if (type != null) {
            String dimension = type.dimension();
            if (dimension == null || dimension.length() == 0) {
                ClassDoc asClassDoc = type.asClassDoc();
                if (asClassDoc == null) {
                    return type.qualifiedTypeName();
                }
                ClassDoc containingClass = asClassDoc.containingClass();
                if (containingClass == null) {
                    return asClassDoc.qualifiedName();
                }
                String name = asClassDoc.name();
                String substring = name.substring(name.lastIndexOf(46) + 1);
                StringBuffer stringBuffer = new StringBuffer();
                stringBuffer.append(containingClass.qualifiedName());
                stringBuffer.append('$');
                stringBuffer.append(substring);
                return stringBuffer.toString();
            }
            StringWriter stringWriter = new StringWriter();
            int length = dimension.length() / 2;
            for (int i2 = 0; i2 < length; i2++) {
                stringWriter.write("[");
            }
            String primitiveClassForName = PrimitiveClassImpl.getPrimitiveClassForName(type.qualifiedTypeName());
            if (primitiveClassForName != null) {
                stringWriter.write(primitiveClassForName);
            } else {
                stringWriter.write("L");
                if (type.asClassDoc() != null) {
                    stringWriter.write(type.asClassDoc().qualifiedName());
                } else {
                    stringWriter.write(type.qualifiedTypeName());
                }
                stringWriter.write(";");
            }
            return stringWriter.toString();
        }
        throw new IllegalArgumentException("null type");
    }

    private String[] getJavadocArgs(JamServiceContext jamServiceContext) {
        String property = jamServiceContext.getProperty(ARGS_PROPERTY);
        if (property == null) {
            return null;
        }
        StringTokenizer stringTokenizer = new StringTokenizer(property);
        String[] strArr = new String[stringTokenizer.countTokens()];
        int i2 = 0;
        while (stringTokenizer.hasMoreTokens()) {
            strArr[i2] = stringTokenizer.nextToken();
            i2++;
        }
        return strArr;
    }

    private void initDelegate(ElementContext elementContext) {
        this.mTigerDelegate = JavadocTigerDelegate.create(elementContext);
    }

    private void initJavadoc(JamServiceContext jamServiceContext) {
        this.mTagParser = jamServiceContext.getTagParser();
        String property = jamServiceContext.getProperty(PARSETAGS_PROPERTY);
        if (property != null) {
            this.mParseTags = Boolean.valueOf(property).booleanValue();
            JamLogger logger = getLogger();
            StringBuffer a = a.a("mParseTags=");
            a.append(this.mParseTags);
            logger.verbose(a.toString(), this);
        }
        try {
            File[] sourceFiles = jamServiceContext.getSourceFiles();
            if (sourceFiles == null || sourceFiles.length == 0) {
                throw new IllegalArgumentException("No source files in context.");
            }
            String resourcePath = jamServiceContext.getInputSourcepath() == null ? null : jamServiceContext.getInputSourcepath().toString();
            String resourcePath2 = jamServiceContext.getInputClasspath() == null ? null : jamServiceContext.getInputClasspath().toString();
            if (getLogger().isVerbose(this)) {
                JamLogger logger2 = getLogger();
                StringBuffer stringBuffer = new StringBuffer();
                stringBuffer.append("sourcePath =");
                stringBuffer.append(resourcePath);
                logger2.verbose(stringBuffer.toString());
                JamLogger logger3 = getLogger();
                StringBuffer stringBuffer2 = new StringBuffer();
                stringBuffer2.append("classPath =");
                stringBuffer2.append(resourcePath2);
                logger3.verbose(stringBuffer2.toString());
                for (File file : sourceFiles) {
                    JamLogger logger4 = getLogger();
                    StringBuffer a2 = a.a("including '");
                    a2.append(file);
                    a2.append("'");
                    logger4.verbose(a2.toString());
                }
            }
            try {
                RootDoc run = JavadocRunner.newInstance().run(sourceFiles, getLogger().isVerbose(this) ? new PrintWriter(System.out) : null, resourcePath, resourcePath2, getJavadocArgs(jamServiceContext), getLogger());
                this.mRootDoc = run;
                if (run == null) {
                    getLogger().error("Javadoc returned a null root");
                    return;
                }
                if (getLogger().isVerbose(this)) {
                    JamLogger logger5 = getLogger();
                    StringBuffer stringBuffer3 = new StringBuffer();
                    stringBuffer3.append(" received ");
                    stringBuffer3.append(this.mRootDoc.classes().length);
                    stringBuffer3.append(" ClassDocs from javadoc: ");
                    logger5.verbose(stringBuffer3.toString());
                }
                ClassDoc[] classes = this.mRootDoc.classes();
                for (int i2 = 0; i2 < classes.length; i2++) {
                    if (classes[i2].containingClass() == null) {
                        if (getLogger().isVerbose(this)) {
                            JamLogger logger6 = getLogger();
                            StringBuffer stringBuffer4 = new StringBuffer();
                            stringBuffer4.append(FunctionMetadataReader.ELLIPSIS);
                            stringBuffer4.append(classes[i2].qualifiedName());
                            logger6.verbose(stringBuffer4.toString());
                        }
                        ((JamServiceContextImpl) jamServiceContext).includeClass(getFdFor(classes[i2]));
                    }
                }
            } catch (FileNotFoundException e2) {
                getLogger().error(e2);
            } catch (IOException e3) {
                getLogger().error(e3);
            }
        } catch (IOException e4) {
            getLogger().error(e4);
        }
    }

    public MMethod addMethod(MClass mClass, MethodDoc methodDoc) {
        MMethod addNewMethod = mClass.addNewMethod();
        populate(addNewMethod, methodDoc);
        return addNewMethod;
    }

    @Override // org.apache.xmlbeans.impl.jam.provider.JamClassBuilder
    public MClass build(String str, String str2) {
        String str3;
        ArrayList arrayList;
        assertInitialized();
        if (getLogger().isVerbose(this)) {
            getLogger().verbose(a.a("trying to build '", str, "' '", str2, "'"));
        }
        if (str.trim().length() > 0) {
            StringBuffer stringBuffer = new StringBuffer();
            stringBuffer.append(str);
            stringBuffer.append(NameUtil.PERIOD);
            stringBuffer.append(str2);
            str3 = stringBuffer.toString();
        } else {
            str3 = str2;
        }
        ClassDoc classNamed = this.mRootDoc.classNamed(str3);
        String[] strArr = null;
        if (classNamed == null) {
            if (getLogger().isVerbose(this)) {
                JamLogger logger = getLogger();
                StringBuffer stringBuffer2 = new StringBuffer();
                stringBuffer2.append("no ClassDoc for ");
                stringBuffer2.append(str3);
                logger.verbose(stringBuffer2.toString());
            }
            return null;
        }
        Type[] importedClasses = classNamed.importedClasses();
        if (importedClasses != null) {
            arrayList = new ArrayList();
            for (Type type : importedClasses) {
                arrayList.add(getFdFor(type));
            }
        } else {
            arrayList = null;
        }
        PackageDoc[] importedPackages = classNamed.importedPackages();
        if (importedPackages != null) {
            if (arrayList == null) {
                arrayList = new ArrayList();
            }
            for (PackageDoc packageDoc : importedPackages) {
                StringBuffer stringBuffer3 = new StringBuffer();
                stringBuffer3.append(packageDoc.name());
                stringBuffer3.append(".*");
                arrayList.add(stringBuffer3.toString());
            }
        }
        if (arrayList != null) {
            strArr = new String[arrayList.size()];
            arrayList.toArray(strArr);
        }
        MClass createClassToBuild = createClassToBuild(str, str2, strArr, this);
        createClassToBuild.setArtifact(classNamed);
        return createClassToBuild;
    }

    @Override // org.apache.xmlbeans.impl.jam.provider.JamClassBuilder
    public void init(ElementContext elementContext) {
        if (elementContext != null) {
            super.init(elementContext);
            getLogger().verbose("init()", this);
            initDelegate(elementContext);
            initJavadoc((JamServiceContext) elementContext);
            return;
        }
        throw new IllegalArgumentException("null context");
    }

    @Override // org.apache.xmlbeans.impl.jam.provider.JamClassPopulator
    public void populate(MClass mClass) {
        Type[] interfaces;
        FieldDoc[] fields;
        ExecutableMemberDoc[] constructors;
        MethodDoc[] methods;
        if (mClass != null) {
            assertInitialized();
            ClassDoc classDoc = (ClassDoc) mClass.getArtifact();
            if (classDoc != null) {
                mClass.setModifiers(classDoc.modifierSpecifier());
                mClass.setIsInterface(classDoc.isInterface());
                JavadocTigerDelegate javadocTigerDelegate = this.mTigerDelegate;
                if (javadocTigerDelegate != null) {
                    mClass.setIsEnumType(javadocTigerDelegate.isEnum(classDoc));
                }
                ClassDoc superclass = classDoc.superclass();
                if (superclass != null) {
                    mClass.setSuperclass(getFdFor(superclass));
                }
                for (Type type : classDoc.interfaces()) {
                    mClass.addInterface(getFdFor(type));
                }
                for (FieldDoc fieldDoc : classDoc.fields()) {
                    populate(mClass.addNewField(), fieldDoc);
                }
                for (ExecutableMemberDoc executableMemberDoc : classDoc.constructors()) {
                    populate(mClass.addNewConstructor(), executableMemberDoc);
                }
                for (MethodDoc methodDoc : classDoc.methods()) {
                    populate(mClass.addNewMethod(), methodDoc);
                }
                JavadocTigerDelegate javadocTigerDelegate2 = this.mTigerDelegate;
                if (javadocTigerDelegate2 != null) {
                    javadocTigerDelegate2.populateAnnotationTypeIfNecessary(classDoc, mClass, this);
                }
                addAnnotations(mClass, classDoc);
                addSourcePosition((MElement) mClass, (Doc) classDoc);
                ClassDoc[] innerClasses = classDoc.innerClasses();
                if (innerClasses != null) {
                    for (int i2 = 0; i2 < innerClasses.length; i2++) {
                        MClass addNewInnerClass = mClass.addNewInnerClass(innerClasses[i2].typeName());
                        addNewInnerClass.setArtifact(innerClasses[i2]);
                        populate(addNewInnerClass);
                    }
                    return;
                }
                return;
            }
            throw new IllegalStateException("null artifact");
        }
        throw new IllegalArgumentException("null dest");
    }

    public static void addSourcePosition(MElement mElement, SourcePosition sourcePosition) {
        MSourcePosition createSourcePosition = mElement.createSourcePosition();
        createSourcePosition.setColumn(sourcePosition.column());
        createSourcePosition.setLine(sourcePosition.line());
        File file = sourcePosition.file();
        if (file != null) {
            createSourcePosition.setSourceURI(file.toURI());
        }
    }

    private void populate(MField mField, FieldDoc fieldDoc) {
        mField.setArtifact(fieldDoc);
        mField.setSimpleName(fieldDoc.name());
        mField.setType(getFdFor(fieldDoc.type()));
        mField.setModifiers(fieldDoc.modifierSpecifier());
        addAnnotations(mField, fieldDoc);
        addSourcePosition((MElement) mField, (Doc) fieldDoc);
    }

    private void populate(MMethod mMethod, MethodDoc methodDoc) {
        if (mMethod == null) {
            throw new IllegalArgumentException("null dest");
        } else if (methodDoc != null) {
            populate((MInvokable) mMethod, (ExecutableMemberDoc) methodDoc);
            mMethod.setReturnType(getFdFor(methodDoc.returnType()));
        } else {
            throw new IllegalArgumentException("null src");
        }
    }

    private void populate(MInvokable mInvokable, ExecutableMemberDoc executableMemberDoc) {
        Type[] thrownExceptions;
        Parameter[] parameters;
        if (mInvokable == null) {
            throw new IllegalArgumentException("null dest");
        } else if (executableMemberDoc != null) {
            mInvokable.setArtifact(executableMemberDoc);
            mInvokable.setSimpleName(executableMemberDoc.name());
            mInvokable.setModifiers(executableMemberDoc.modifierSpecifier());
            for (Type type : executableMemberDoc.thrownExceptions()) {
                mInvokable.addException(getFdFor(type));
            }
            for (Parameter parameter : executableMemberDoc.parameters()) {
                populate(mInvokable.addNewParameter(), executableMemberDoc, parameter);
            }
            addAnnotations(mInvokable, executableMemberDoc);
            addSourcePosition((MElement) mInvokable, (Doc) executableMemberDoc);
        } else {
            throw new IllegalArgumentException("null src");
        }
    }

    private void populate(MParameter mParameter, ExecutableMemberDoc executableMemberDoc, Parameter parameter) {
        mParameter.setArtifact(parameter);
        mParameter.setSimpleName(parameter.name());
        mParameter.setType(getFdFor(parameter.type()));
        JavadocTigerDelegate javadocTigerDelegate = this.mTigerDelegate;
        if (javadocTigerDelegate != null) {
            javadocTigerDelegate.extractAnnotations(mParameter, executableMemberDoc, parameter);
        }
    }
}
