package org.apache.xmlbeans.impl.jam.internal.parser;

import b.b.a.a.a;
import java.io.File;
import java.io.FileReader;
import java.io.IOException;
import java.io.InputStream;
import java.io.InputStreamReader;
import java.io.PrintWriter;
import java.io.Reader;
import java.util.ArrayList;
import java.util.List;
import org.apache.poi.openxml4j.opc.internal.ZipHelper;
import org.apache.xmlbeans.impl.common.NameUtil;
import org.apache.xmlbeans.impl.jam.JamClassLoader;
import org.apache.xmlbeans.impl.jam.internal.JamPrinter;
import org.apache.xmlbeans.impl.jam.mutable.MClass;
import org.apache.xmlbeans.impl.jam.provider.JamClassBuilder;
import org.apache.xmlbeans.impl.jam.provider.JamClassPopulator;
import org.apache.xmlbeans.impl.jam.provider.JamServiceContext;
import org.apache.xmlbeans.impl.jam.provider.ResourcePath;
import org.apache.xmlbeans.impl.tool.XMLBean;

public class ParserClassBuilder extends JamClassBuilder implements JamClassPopulator {
    public static final boolean VERBOSE = false;
    public PrintWriter mOut;
    public ResourcePath mSourcePath;
    public boolean mVerbose;

    public static class MainTool {
        public int mCount = 0;
        public List mFailures = new ArrayList();
        public PrintWriter mOut = new PrintWriter(System.out);
        public long mStartTime = System.currentTimeMillis();

        private void addFailure(File file) {
            this.mFailures.add(file);
        }

        private void parse(ParserClassBuilder parserClassBuilder, File file) {
            File[] listFiles;
            System.gc();
            if (file.isDirectory()) {
                for (File file2 : file.listFiles()) {
                    parse(parserClassBuilder, file2);
                }
            } else if (file.getName().endsWith(XMLBean.JAVA)) {
                this.mCount++;
                try {
                    if (ParserClassBuilder.parse(new FileReader(file), null) == null) {
                        this.mOut.println("[error, parser result is null]");
                        addFailure(file);
                    }
                } catch (Throwable th) {
                    th.printStackTrace(this.mOut);
                    addFailure(file);
                }
            }
        }

        public void process(String[] strArr) {
            for (String str : strArr) {
                try {
                    parse(new ParserClassBuilder(), new File(str));
                } catch (Exception e2) {
                    e2.printStackTrace();
                }
            }
            this.mOut.println("\n\n\n");
            int size = this.mFailures.size();
            if (size != 0) {
                this.mOut.println("The following files failed to parse:");
                for (int i2 = 0; i2 < size; i2++) {
                    this.mOut.println(((File) this.mFailures.get(i2)).getAbsolutePath());
                }
            }
            PrintWriter printWriter = this.mOut;
            StringBuffer stringBuffer = new StringBuffer();
            int i3 = this.mCount;
            stringBuffer.append(((i3 - size) * 100) / i3);
            stringBuffer.append("% (");
            stringBuffer.append(this.mCount - size);
            stringBuffer.append(ZipHelper.FORWARD_SLASH);
            stringBuffer.append(this.mCount);
            stringBuffer.append(") ");
            stringBuffer.append("of input java files successfully parsed.");
            printWriter.println(stringBuffer.toString());
            PrintWriter printWriter2 = this.mOut;
            StringBuffer a = a.a("Total time: ");
            a.append((System.currentTimeMillis() - this.mStartTime) / 1000);
            a.append(" seconds.");
            printWriter2.println(a.toString());
            this.mOut.flush();
            System.out.flush();
            System.err.flush();
        }
    }

    public static void main(String[] strArr) {
        new MainTool().process(strArr);
    }

    public static MClass[] parse(Reader reader, JamClassLoader jamClassLoader) {
        if (reader == null) {
            throw new IllegalArgumentException("null in");
        } else if (jamClassLoader == null) {
            throw new IllegalArgumentException("null loader");
        } else {
            throw new IllegalStateException("temporarily NI");
        }
    }

    @Override // org.apache.xmlbeans.impl.jam.provider.JamClassBuilder
    public MClass build(String str, String str2) {
        if (str == null) {
            throw new IllegalArgumentException("null pkg");
        } else if (str2 != null) {
            StringBuffer stringBuffer = new StringBuffer();
            stringBuffer.append(str.replace(NameUtil.PERIOD, File.separatorChar));
            stringBuffer.append(File.separatorChar);
            stringBuffer.append(str2);
            stringBuffer.append(XMLBean.JAVA);
            String stringBuffer2 = stringBuffer.toString();
            if (str2.indexOf(".") == -1) {
                InputStream findInPath = this.mSourcePath.findInPath(stringBuffer2);
                if (findInPath == null) {
                    if (this.mVerbose) {
                        PrintWriter printWriter = this.mOut;
                        StringBuffer stringBuffer3 = new StringBuffer();
                        stringBuffer3.append("[ParserClassBuilder] could not find ");
                        stringBuffer3.append(stringBuffer2);
                        printWriter.println(stringBuffer3.toString());
                    }
                    return null;
                }
                if (this.mVerbose) {
                    PrintWriter printWriter2 = this.mOut;
                    StringBuffer stringBuffer4 = new StringBuffer();
                    stringBuffer4.append("[ParserClassBuilder] loading class ");
                    stringBuffer4.append(str);
                    stringBuffer4.append(JamPrinter.INDENT);
                    stringBuffer4.append(str2);
                    printWriter2.println(stringBuffer4.toString());
                    PrintWriter printWriter3 = this.mOut;
                    StringBuffer stringBuffer5 = new StringBuffer();
                    stringBuffer5.append("[ParserClassBuilder] from file ");
                    stringBuffer5.append(stringBuffer2);
                    printWriter3.println(stringBuffer5.toString());
                }
                try {
                    new InputStreamReader(findInPath).close();
                } catch (IOException e2) {
                    e2.printStackTrace();
                }
                return null;
            }
            throw new IllegalArgumentException("inner classes are NYI at the moment");
        } else {
            throw new IllegalArgumentException("null name");
        }
    }

    @Override // org.apache.xmlbeans.impl.jam.provider.JamClassPopulator
    public void populate(MClass mClass) {
        throw new IllegalStateException("NYI");
    }

    public ParserClassBuilder() {
        this.mVerbose = false;
        this.mOut = new PrintWriter(System.out);
    }

    public ParserClassBuilder(JamServiceContext jamServiceContext) {
        this.mVerbose = false;
        this.mOut = new PrintWriter(System.out);
        this.mSourcePath = jamServiceContext.getInputSourcepath();
    }
}
