package org.apache.xmlbeans.impl.jam.internal.reflect;

import java.lang.reflect.Constructor;
import java.lang.reflect.Field;
import java.lang.reflect.Method;
import org.apache.xmlbeans.impl.jam.internal.TigerDelegate;
import org.apache.xmlbeans.impl.jam.internal.elements.ElementContext;
import org.apache.xmlbeans.impl.jam.mutable.MClass;
import org.apache.xmlbeans.impl.jam.mutable.MConstructor;
import org.apache.xmlbeans.impl.jam.mutable.MField;
import org.apache.xmlbeans.impl.jam.mutable.MMember;
import org.apache.xmlbeans.impl.jam.mutable.MParameter;
import org.apache.xmlbeans.impl.jam.provider.JamLogger;

public abstract class ReflectTigerDelegate extends TigerDelegate {
    public static final String IMPL_NAME = "org.apache.xmlbeans.impl.jam.internal.reflect.ReflectTigerDelegateImpl_150";

    public static ReflectTigerDelegate create(JamLogger jamLogger) {
        if (!TigerDelegate.isTigerReflectionAvailable(jamLogger)) {
            return null;
        }
        try {
            ReflectTigerDelegate reflectTigerDelegate = (ReflectTigerDelegate) Class.forName(IMPL_NAME).newInstance();
            reflectTigerDelegate.init(jamLogger);
            return reflectTigerDelegate;
        } catch (ClassNotFoundException e2) {
            TigerDelegate.issue14BuildWarning(e2, jamLogger);
            return null;
        } catch (IllegalAccessException e3) {
            jamLogger.error(e3);
            return null;
        } catch (InstantiationException e4) {
            jamLogger.error(e4);
            return null;
        }
    }

    public abstract void extractAnnotations(MClass mClass, Class cls);

    public abstract void extractAnnotations(MConstructor mConstructor, Constructor constructor);

    public abstract void extractAnnotations(MField mField, Field field);

    public abstract void extractAnnotations(MMember mMember, Method method);

    public abstract void extractAnnotations(MParameter mParameter, Constructor constructor, int i2);

    public abstract void extractAnnotations(MParameter mParameter, Method method, int i2);

    public abstract Constructor getEnclosingConstructor(Class cls);

    public abstract Method getEnclosingMethod(Class cls);

    public abstract boolean isEnum(Class cls);

    public abstract void populateAnnotationTypeIfNecessary(Class cls, MClass mClass, ReflectClassBuilder reflectClassBuilder);

    public static ReflectTigerDelegate create(ElementContext elementContext) {
        if (!TigerDelegate.isTigerReflectionAvailable(elementContext.getLogger())) {
            return null;
        }
        try {
            ReflectTigerDelegate reflectTigerDelegate = (ReflectTigerDelegate) Class.forName(IMPL_NAME).newInstance();
            reflectTigerDelegate.init(elementContext);
            return reflectTigerDelegate;
        } catch (ClassNotFoundException e2) {
            TigerDelegate.issue14BuildWarning(e2, elementContext.getLogger());
            return null;
        } catch (IllegalAccessException e3) {
            elementContext.getLogger().error(e3);
            return null;
        } catch (InstantiationException e4) {
            elementContext.getLogger().error(e4);
            return null;
        }
    }
}
