package org.apache.xmlbeans.impl.jam.provider;

import b.b.a.a.a;
import java.io.File;
import java.io.IOException;
import java.net.URLClassLoader;
import java.util.ArrayList;
import org.apache.xmlbeans.impl.jam.JamClassLoader;
import org.apache.xmlbeans.impl.jam.JamService;
import org.apache.xmlbeans.impl.jam.JamServiceFactory;
import org.apache.xmlbeans.impl.jam.JamServiceParams;
import org.apache.xmlbeans.impl.jam.internal.JamClassLoaderImpl;
import org.apache.xmlbeans.impl.jam.internal.JamServiceContextImpl;
import org.apache.xmlbeans.impl.jam.internal.JamServiceImpl;
import org.apache.xmlbeans.impl.jam.internal.elements.ElementContext;
import org.apache.xmlbeans.impl.jam.internal.javadoc.JavadocClassBuilder;
import org.apache.xmlbeans.impl.jam.internal.parser.ParserClassBuilder;
import org.apache.xmlbeans.impl.jam.internal.reflect.ReflectClassBuilder;

public class JamServiceFactoryImpl extends JamServiceFactory {
    public static final String PREFIX = "[JamServiceFactoryImpl]";
    public static final String USE_NEW_PARSER = "JamServiceFactoryImpl.use-new-parser";

    public JamClassBuilder createBuilder(JamServiceContext jamServiceContext) {
        JamLogger logger = jamServiceContext.getLogger();
        ArrayList arrayList = new ArrayList();
        JamClassBuilder baseBuilder = jamServiceContext.getBaseBuilder();
        if (baseBuilder != null) {
            arrayList.add(baseBuilder);
        }
        JamClassBuilder createSourceBuilder = createSourceBuilder(jamServiceContext);
        if (logger.isVerbose(this)) {
            logger.verbose("added classbuilder for sources");
        }
        if (createSourceBuilder != null) {
            arrayList.add(createSourceBuilder);
        }
        JamClassBuilder createClassfileBuilder = createClassfileBuilder(jamServiceContext);
        if (logger.isVerbose(this)) {
            logger.verbose("added classbuilder for custom classpath");
        }
        if (createClassfileBuilder != null) {
            arrayList.add(createClassfileBuilder);
        }
        ClassLoader[] reflectionClassLoaders = jamServiceContext.getReflectionClassLoaders();
        for (int i2 = 0; i2 < reflectionClassLoaders.length; i2++) {
            if (logger.isVerbose(this)) {
                StringBuffer a = a.a("added classbuilder for classloader ");
                a.append(reflectionClassLoaders[i2].getClass());
                logger.verbose(a.toString());
            }
            arrayList.add(new ReflectClassBuilder(reflectionClassLoaders[i2]));
        }
        int size = arrayList.size();
        JamClassBuilder[] jamClassBuilderArr = new JamClassBuilder[size];
        arrayList.toArray(jamClassBuilderArr);
        CompositeJamClassBuilder compositeJamClassBuilder = new CompositeJamClassBuilder(jamClassBuilderArr);
        compositeJamClassBuilder.init((ElementContext) jamServiceContext);
        if (logger.isVerbose(this)) {
            StringBuffer stringBuffer = new StringBuffer();
            stringBuffer.append("returning a composite of ");
            stringBuffer.append(size);
            stringBuffer.append(" class builders.");
            logger.verbose(stringBuffer.toString());
            compositeJamClassBuilder.build("java.lang", "Object");
            compositeJamClassBuilder.build("javax.ejb", "SessionBean");
        }
        return compositeJamClassBuilder;
    }

    public JamClassLoader createClassLoader(JamServiceContext jamServiceContext) {
        return new JamClassLoaderImpl((ElementContext) jamServiceContext, createBuilder(jamServiceContext), jamServiceContext.getInitializer());
    }

    public JamClassBuilder createClassfileBuilder(JamServiceContext jamServiceContext) {
        ResourcePath inputClasspath = jamServiceContext.getInputClasspath();
        if (inputClasspath == null) {
            return null;
        }
        return new ReflectClassBuilder(new URLClassLoader(inputClasspath.toUrlPath()));
    }

    @Override // org.apache.xmlbeans.impl.jam.JamServiceFactory
    public JamClassLoader createJamClassLoader(ClassLoader classLoader) {
        JamServiceParams createServiceParams = createServiceParams();
        createServiceParams.setUseSystemClasspath(false);
        createServiceParams.setPropertyInitializer(null);
        createServiceParams.addClassLoader(classLoader);
        try {
            return createService(createServiceParams).getClassLoader();
        } catch (IOException e2) {
            e2.printStackTrace();
            throw new IllegalStateException(e2.getMessage());
        }
    }

    @Override // org.apache.xmlbeans.impl.jam.JamServiceFactory
    public JamService createService(JamServiceParams jamServiceParams) {
        if (jamServiceParams instanceof JamServiceContextImpl) {
            JamServiceContextImpl jamServiceContextImpl = (JamServiceContextImpl) jamServiceParams;
            jamServiceContextImpl.setClassLoader(createClassLoader(jamServiceContextImpl));
            return new JamServiceImpl((ElementContext) jamServiceParams, getSpecifiedClasses(jamServiceContextImpl));
        }
        throw new IllegalArgumentException("JamServiceParams must be instantiated by this JamServiceFactory.");
    }

    @Override // org.apache.xmlbeans.impl.jam.JamServiceFactory
    public JamServiceParams createServiceParams() {
        return new JamServiceContextImpl();
    }

    public JamClassBuilder createSourceBuilder(JamServiceContext jamServiceContext) {
        File[] sourceFiles = jamServiceContext.getSourceFiles();
        if (sourceFiles == null || sourceFiles.length == 0) {
            if (!jamServiceContext.isVerbose(this)) {
                return null;
            }
            jamServiceContext.verbose("[JamServiceFactoryImpl]no source files present, skipping source ClassBuilder");
            return null;
        } else if (jamServiceContext.getProperty(USE_NEW_PARSER) == null) {
            return new JavadocClassBuilder();
        } else {
            return new ParserClassBuilder(jamServiceContext);
        }
    }

    @Override // org.apache.xmlbeans.impl.jam.JamServiceFactory
    public JamClassLoader createSystemJamClassLoader() {
        JamServiceParams createServiceParams = createServiceParams();
        createServiceParams.setUseSystemClasspath(true);
        try {
            return createService(createServiceParams).getClassLoader();
        } catch (IOException e2) {
            e2.printStackTrace();
            throw new IllegalStateException(e2.getMessage());
        }
    }

    public String[] getSpecifiedClasses(JamServiceContext jamServiceContext) {
        return jamServiceContext.getAllClassnames();
    }
}
