package org.apache.xmlbeans.impl.piccolo.xml;

import b.b.a.a.a;
import java.io.CharArrayReader;
import java.io.InputStream;
import java.io.Reader;
import java.net.URL;
import java.util.HashMap;
import java.util.Map;
import org.apache.xmlbeans.impl.piccolo.util.RecursionException;
import org.xml.sax.EntityResolver;
import org.xml.sax.InputSource;

public class EntityManager {
    public static final int GENERAL = 0;
    public static final int PARAMETER = 1;
    public Map entitiesByURI;
    public Map[] entityMaps;
    public EntityResolver resolver;

    public EntityManager() {
        this(null);
    }

    public static String resolveSystemID(String str, String str2) {
        URL url;
        if (str != null) {
            url = new URL(new URL(str), str2);
        } else {
            url = new URL(str2);
        }
        return url.toString();
    }

    public void clear() {
        this.entityMaps[0].clear();
        this.entityMaps[1].clear();
        this.entitiesByURI.clear();
    }

    public Entity getByID(Entity entity, String str, String str2) {
        Entity entity2;
        String resolveSystemID = resolveSystemID(entity.getSystemID(), str2);
        Entity entity3 = (Entity) this.entitiesByURI.get(resolveSystemID);
        if (entity3 != null) {
            return entity3;
        }
        if (str != null && str.length() > 0 && (entity2 = (Entity) this.entitiesByURI.get(str)) != null) {
            return entity2;
        }
        Entry entry = new Entry(this, str, resolveSystemID);
        if (str != null && str.length() > 0) {
            this.entitiesByURI.put(str, entry);
        }
        this.entitiesByURI.put(resolveSystemID, entry);
        return entry;
    }

    public Entity getByName(String str, int i2) {
        return (Entry) this.entityMaps[i2].get(str);
    }

    public EntityResolver getResolver() {
        return this.resolver;
    }

    public boolean putExternal(Entity entity, String str, String str2, String str3, int i2) {
        if (this.entityMaps[i2].get(str) != null) {
            return false;
        }
        String resolveSystemID = resolveSystemID(entity.getSystemID(), str3);
        Entry entry = new Entry(this, str2, resolveSystemID);
        this.entityMaps[i2].put(str, entry);
        if (str2 != null && str2.length() > 0) {
            this.entitiesByURI.put(str2, entry);
        }
        this.entitiesByURI.put(resolveSystemID, entry);
        return true;
    }

    public boolean putInternal(String str, String str2, int i2) {
        if (this.entityMaps[i2].get(str) != null) {
            return false;
        }
        this.entityMaps[i2].put(str, new Entry(str2));
        return true;
    }

    public boolean putUnparsed(Entity entity, String str, String str2, String str3, String str4, int i2) {
        if (this.entityMaps[i2].get(str) != null) {
            return false;
        }
        this.entityMaps[i2].put(str, new Entry(str2, str3, str4));
        return true;
    }

    public void setResolver(EntityResolver entityResolver) {
        this.resolver = entityResolver;
    }

    public EntityManager(EntityResolver entityResolver) {
        this.entityMaps = new HashMap[]{new HashMap(), new HashMap()};
        this.entitiesByURI = new HashMap();
        setResolver(entityResolver);
    }

    public final class Entry implements Entity {
        public boolean isOpen;
        public boolean isStandalone;
        public String ndata;
        public String pubID;
        public XMLInputReader reader;
        public String sysID;
        public char[] value;

        public Entry(String str) {
            this.isOpen = false;
            this.reader = null;
            this.isStandalone = false;
            this.ndata = null;
            this.sysID = null;
            this.pubID = null;
            this.value = str.toCharArray();
        }

        @Override // org.apache.xmlbeans.impl.piccolo.xml.Entity
        public char[] charArrayValue() {
            return this.value;
        }

        @Override // org.apache.xmlbeans.impl.piccolo.xml.Entity
        public void close() {
            this.isOpen = false;
            this.reader = null;
        }

        @Override // org.apache.xmlbeans.impl.piccolo.xml.Entity
        public String getDeclaredEncoding() {
            XMLInputReader xMLInputReader = this.reader;
            if (xMLInputReader != null) {
                return xMLInputReader.getXMLDeclaredEncoding();
            }
            return null;
        }

        @Override // org.apache.xmlbeans.impl.piccolo.xml.Entity
        public String getPublicID() {
            return this.pubID;
        }

        @Override // org.apache.xmlbeans.impl.piccolo.xml.Entity
        public Reader getReader() {
            if (isInternal()) {
                return new CharArrayReader(this.value);
            }
            return this.reader;
        }

        @Override // org.apache.xmlbeans.impl.piccolo.xml.Entity
        public String getSystemID() {
            return this.sysID;
        }

        @Override // org.apache.xmlbeans.impl.piccolo.xml.Entity
        public String getXMLVersion() {
            XMLInputReader xMLInputReader = this.reader;
            if (xMLInputReader != null) {
                return xMLInputReader.getXMLVersion();
            }
            return null;
        }

        @Override // org.apache.xmlbeans.impl.piccolo.xml.Entity
        public boolean isInternal() {
            return this.sysID == null;
        }

        @Override // org.apache.xmlbeans.impl.piccolo.xml.Entity
        public boolean isOpen() {
            return this.isOpen;
        }

        @Override // org.apache.xmlbeans.impl.piccolo.xml.Entity
        public boolean isParsed() {
            return this.ndata == null;
        }

        @Override // org.apache.xmlbeans.impl.piccolo.xml.Entity
        public boolean isStandalone() {
            return this.isStandalone;
        }

        @Override // org.apache.xmlbeans.impl.piccolo.xml.Entity
        public boolean isStandaloneDeclared() {
            XMLInputReader xMLInputReader = this.reader;
            if (xMLInputReader != null) {
                return xMLInputReader.isXMLStandaloneDeclared();
            }
            return false;
        }

        @Override // org.apache.xmlbeans.impl.piccolo.xml.Entity
        public void open() {
            if (this.ndata != null) {
                throw new FatalParsingException(a.a(a.a("Cannot reference entity; unknown NDATA type '"), this.ndata, "'"));
            } else if (!this.isOpen) {
                if (!isInternal()) {
                    if (EntityManager.this.resolver == null) {
                        this.reader = new XMLStreamReader(new URL(this.sysID).openStream(), true);
                    } else {
                        InputSource resolveEntity = EntityManager.this.resolver.resolveEntity(this.pubID, this.sysID);
                        if (resolveEntity == null) {
                            this.reader = new XMLStreamReader(new URL(this.sysID).openStream(), true);
                        } else {
                            Reader characterStream = resolveEntity.getCharacterStream();
                            if (characterStream != null) {
                                this.reader = new XMLReaderReader(characterStream, true);
                            } else {
                                InputStream byteStream = resolveEntity.getByteStream();
                                if (byteStream != null) {
                                    this.reader = new XMLStreamReader(byteStream, resolveEntity.getEncoding(), true);
                                } else {
                                    this.reader = new XMLStreamReader(new URL(resolveEntity.getSystemId()).openStream(), resolveEntity.getEncoding(), true);
                                }
                            }
                        }
                    }
                    this.isStandalone = this.reader.isXMLStandalone();
                }
                this.isOpen = true;
            } else {
                throw new RecursionException();
            }
        }

        @Override // org.apache.xmlbeans.impl.piccolo.xml.Entity
        public void setStandalone(boolean z) {
            this.isStandalone = z;
        }

        @Override // org.apache.xmlbeans.impl.piccolo.xml.Entity
        public String stringValue() {
            return new String(this.value);
        }

        public Entry(EntityManager entityManager, String str, String str2) {
            this(str, str2, null);
        }

        public Entry(String str, String str2, String str3) {
            this.isOpen = false;
            this.reader = null;
            this.isStandalone = false;
            this.pubID = str;
            this.sysID = str2;
            this.ndata = str3;
        }
    }
}
