package org.apache.xmlbeans.impl.piccolo.xml;

import org.apache.xmlbeans.impl.piccolo.util.IntStack;
import org.apache.xmlbeans.impl.piccolo.util.StringStack;

public class FastNamespaceSupport {
    public static final String XMLNS = "http://www.w3.org/XML/1998/namespace";
    public IntStack contextPrefixCounts = new IntStack(20);
    public String defaultURI;
    public IntStack defaultURIContextCounts = new IntStack(20);
    public int defaultURIContexts;
    public StringStack defaultURIs = new StringStack(20);
    public int prefixCount;
    public int prefixPos;
    public String[] prefixes = new String[20];
    public String[] uris = new String[20];

    public FastNamespaceSupport() {
        reset();
    }

    public void declarePrefix(String str, String str2) {
        if (str.length() == 0) {
            int i2 = this.defaultURIContexts - 1;
            this.defaultURIContexts = i2;
            this.defaultURIContextCounts.push(i2);
            this.defaultURIs.push(this.defaultURI);
            this.defaultURIContexts = 0;
            this.defaultURI = str2;
            return;
        }
        int i3 = 0;
        while (true) {
            int i4 = this.prefixCount;
            if (i3 < i4) {
                String[] strArr = this.prefixes;
                int i5 = this.prefixPos;
                if (str == strArr[i5 - i3]) {
                    this.uris[i5 - i3] = str2;
                    return;
                }
                i3++;
            } else {
                int i6 = this.prefixPos + 1;
                this.prefixPos = i6;
                this.prefixCount = i4 + 1;
                String[] strArr2 = this.prefixes;
                if (i6 >= strArr2.length) {
                    int length = strArr2.length;
                    int i7 = length * 2;
                    String[] strArr3 = new String[i7];
                    String[] strArr4 = new String[i7];
                    System.arraycopy(strArr2, 0, strArr3, 0, length);
                    System.arraycopy(this.uris, 0, strArr4, 0, length);
                    this.prefixes = strArr3;
                    this.uris = strArr4;
                }
                String[] strArr5 = this.prefixes;
                int i8 = this.prefixPos;
                strArr5[i8] = str;
                this.uris[i8] = str2;
                return;
            }
        }
    }

    public String getContextPrefix(int i2) {
        if (i2 == this.prefixCount && this.defaultURIContexts == 0 && this.defaultURI != "") {
            return "";
        }
        return this.prefixes[this.prefixPos - i2];
    }

    public int getContextSize() {
        return this.prefixCount + ((this.defaultURIContexts != 0 || this.defaultURI == "") ? 0 : 1);
    }

    public String getContextURI(int i2) {
        String str;
        if (i2 == this.prefixCount && this.defaultURIContexts == 0 && (str = this.defaultURI) != "") {
            return str;
        }
        return this.uris[this.prefixPos - i2];
    }

    public String getDefaultURI() {
        return this.defaultURI;
    }

    public String getURI(String str) {
        if (str == null || str.length() == 0) {
            return this.defaultURI;
        }
        if (str == "xml") {
            return "http://www.w3.org/XML/1998/namespace";
        }
        for (int i2 = this.prefixPos; i2 >= 0; i2--) {
            if (str == this.prefixes[i2]) {
                return this.uris[i2];
            }
        }
        return "";
    }

    public void popContext() {
        int i2 = this.defaultURIContexts;
        if (i2 <= 0) {
            this.defaultURIContexts = this.defaultURIContextCounts.pop();
            this.defaultURI = this.defaultURIs.pop();
        } else {
            this.defaultURIContexts = i2 - 1;
        }
        this.prefixPos -= this.prefixCount;
        this.prefixCount = this.contextPrefixCounts.pop();
    }

    public String[] processName(String str, String[] strArr, boolean z) {
        int indexOf = str.indexOf(58);
        strArr[2] = str;
        if (indexOf < 0) {
            strArr[1] = str;
            if (z) {
                strArr[0] = "";
            } else {
                strArr[0] = this.defaultURI;
            }
            return strArr;
        }
        String substring = str.substring(0, indexOf);
        strArr[1] = str.substring(indexOf + 1);
        String uri = getURI(substring);
        strArr[0] = uri;
        if (uri == "") {
            return null;
        }
        return strArr;
    }

    public void pushContext() {
        this.defaultURIContexts++;
        this.contextPrefixCounts.push(this.prefixCount);
        this.prefixCount = 0;
    }

    public void reset() {
        this.defaultURIs.clear();
        this.contextPrefixCounts.clear();
        this.defaultURIContextCounts.clear();
        this.prefixPos = -1;
        this.defaultURI = "";
        this.prefixCount = 0;
        this.defaultURIContexts = 0;
    }
}
