package org.apache.xmlbeans.impl.piccolo.xml;

import b.b.a.a.a;
import java.io.File;
import java.io.FileInputStream;
import java.util.Enumeration;
import java.util.HashMap;
import java.util.Map;
import java.util.Properties;
import javax.xml.parsers.ParserConfigurationException;
import javax.xml.parsers.SAXParser;
import javax.xml.parsers.SAXParserFactory;
import org.apache.xmlbeans.impl.piccolo.util.FactoryServiceFinder;
import org.xml.sax.Parser;
import org.xml.sax.SAXNotRecognizedException;
import org.xml.sax.SAXNotSupportedException;
import org.xml.sax.XMLReader;

public class JAXPSAXParserFactory extends SAXParserFactory {
    public static Boolean FALSE = new Boolean(false);
    public static Boolean TRUE = new Boolean(true);
    public static final String VALIDATING_PROPERTY = "org.apache.xmlbeans.impl.piccolo.xml.ValidatingSAXParserFactory";
    public static Class validatingFactoryClass = findValidatingFactory();
    public Map featureMap = new HashMap();
    public boolean namespaceAware = false;
    public Piccolo nvParser = new Piccolo();
    public ParserConfigurationException pendingNonvalidatingException = null;
    public ParserConfigurationException pendingValidatingException = null;
    public boolean validating = false;
    public SAXParserFactory validatingFactory;

    public static class JAXPSAXParser extends SAXParser {
        public Piccolo parser;

        public JAXPSAXParser(Piccolo piccolo) {
            this.parser = piccolo;
        }

        @Override // javax.xml.parsers.SAXParser
        public Parser getParser() {
            return this.parser;
        }

        @Override // javax.xml.parsers.SAXParser
        public Object getProperty(String str) {
            return this.parser.getProperty(str);
        }

        @Override // javax.xml.parsers.SAXParser
        public XMLReader getXMLReader() {
            return this.parser;
        }

        @Override // javax.xml.parsers.SAXParser
        public boolean isNamespaceAware() {
            return this.parser.fNamespaces;
        }

        @Override // javax.xml.parsers.SAXParser
        public boolean isValidating() {
            return false;
        }

        @Override // javax.xml.parsers.SAXParser
        public void setProperty(String str, Object obj) {
            this.parser.setProperty(str, obj);
        }
    }

    public JAXPSAXParserFactory() {
        try {
            if (validatingFactoryClass != null) {
                SAXParserFactory sAXParserFactory = (SAXParserFactory) validatingFactoryClass.newInstance();
                this.validatingFactory = sAXParserFactory;
                sAXParserFactory.setNamespaceAware(false);
                this.validatingFactory.setValidating(true);
            }
        } catch (Exception unused) {
            this.validatingFactory = null;
        }
        setNamespaceAware(false);
    }

    public static Class findValidatingFactory() {
        try {
            String property = System.getProperty(VALIDATING_PROPERTY);
            if (property != null) {
                return Class.forName(property);
            }
        } catch (Exception unused) {
        }
        try {
            String property2 = System.getProperty("java.home");
            StringBuffer stringBuffer = new StringBuffer();
            stringBuffer.append(property2);
            stringBuffer.append(File.separator);
            stringBuffer.append("lib");
            stringBuffer.append(File.separator);
            stringBuffer.append("jaxp.properties");
            File file = new File(stringBuffer.toString());
            if (file.exists()) {
                Properties properties = new Properties();
                properties.load(new FileInputStream(file));
                String property3 = properties.getProperty(VALIDATING_PROPERTY);
                if (property3 != null) {
                    return Class.forName(property3);
                }
            }
        } catch (Exception unused2) {
        }
        try {
            Enumeration findServices = FactoryServiceFinder.findServices("javax.xml.parsers.SAXParserFactory");
            while (findServices.hasMoreElements()) {
                try {
                    String str = (String) findServices.nextElement();
                    if (!str.equals("org.apache.xmlbeans.impl.piccolo.xml.Piccolo")) {
                        return Class.forName(str);
                    }
                } catch (ClassNotFoundException unused3) {
                }
            }
        } catch (Exception unused4) {
        }
        try {
            return Class.forName("org.apache.crimson.jaxp.SAXParserFactoryImpl");
        } catch (ClassNotFoundException unused5) {
            return null;
        }
    }

    public static SAXParserFactory newInstance() {
        return new JAXPSAXParserFactory();
    }

    private void reconfigureNonvalidating() {
        try {
            for (Map.Entry entry : this.featureMap.entrySet()) {
                this.nvParser.setFeature((String) entry.getKey(), ((Boolean) entry.getValue()).booleanValue());
            }
        } catch (SAXNotRecognizedException e2) {
            this.pendingNonvalidatingException = new ParserConfigurationException(e2.toString());
        } catch (SAXNotSupportedException e3) {
            this.pendingNonvalidatingException = new ParserConfigurationException(e3.toString());
        }
    }

    private void reconfigureValidating() {
        if (this.validatingFactory != null) {
            try {
                for (Map.Entry entry : this.featureMap.entrySet()) {
                    this.validatingFactory.setFeature((String) entry.getKey(), ((Boolean) entry.getValue()).booleanValue());
                }
            } catch (ParserConfigurationException e2) {
                this.pendingValidatingException = e2;
            } catch (SAXNotRecognizedException e3) {
                this.pendingValidatingException = new ParserConfigurationException(e3.toString());
            } catch (SAXNotSupportedException e4) {
                this.pendingValidatingException = new ParserConfigurationException(e4.toString());
            }
        }
    }

    @Override // javax.xml.parsers.SAXParserFactory
    public boolean getFeature(String str) {
        SAXParserFactory sAXParserFactory;
        if (!this.validating || (sAXParserFactory = this.validatingFactory) == null) {
            return this.nvParser.getFeature(str);
        }
        return sAXParserFactory.getFeature(str);
    }

    @Override // javax.xml.parsers.SAXParserFactory
    public SAXParser newSAXParser() {
        if (this.validating) {
            SAXParserFactory sAXParserFactory = this.validatingFactory;
            if (sAXParserFactory != null) {
                ParserConfigurationException parserConfigurationException = this.pendingValidatingException;
                if (parserConfigurationException == null) {
                    return sAXParserFactory.newSAXParser();
                }
                throw parserConfigurationException;
            }
            throw new ParserConfigurationException("XML document validation is not supported");
        }
        ParserConfigurationException parserConfigurationException2 = this.pendingNonvalidatingException;
        if (parserConfigurationException2 == null) {
            return new JAXPSAXParser(new Piccolo(this.nvParser));
        }
        throw parserConfigurationException2;
    }

    @Override // javax.xml.parsers.SAXParserFactory
    public void setFeature(String str, boolean z) {
        ParserConfigurationException parserConfigurationException;
        ParserConfigurationException parserConfigurationException2;
        this.featureMap.put(str, z ? TRUE : FALSE);
        SAXParserFactory sAXParserFactory = this.validatingFactory;
        if (sAXParserFactory != null) {
            if (this.pendingValidatingException != null) {
                reconfigureValidating();
            } else {
                try {
                    sAXParserFactory.setFeature(str, z);
                } catch (ParserConfigurationException e2) {
                    this.pendingValidatingException = e2;
                }
            }
        }
        if (this.pendingNonvalidatingException != null) {
            reconfigureNonvalidating();
        }
        if (this.validating && (parserConfigurationException2 = this.pendingValidatingException) != null) {
            throw parserConfigurationException2;
        } else if (!this.validating && (parserConfigurationException = this.pendingNonvalidatingException) != null) {
            throw parserConfigurationException;
        }
    }

    @Override // javax.xml.parsers.SAXParserFactory
    public void setNamespaceAware(boolean z) {
        super.setNamespaceAware(z);
        this.namespaceAware = z;
        try {
            this.nvParser.setFeature("http://xml.org/sax/features/namespaces", z);
            this.nvParser.setFeature("http://xml.org/sax/features/namespace-prefixes", !z);
        } catch (SAXNotSupportedException e2) {
            StringBuffer a = a.a("Error setting namespace feature: ");
            a.append(e2.toString());
            this.pendingNonvalidatingException = new ParserConfigurationException(a.toString());
        } catch (SAXNotRecognizedException e3) {
            StringBuffer a2 = a.a("Error setting namespace feature: ");
            a2.append(e3.toString());
            this.pendingNonvalidatingException = new ParserConfigurationException(a2.toString());
        }
        SAXParserFactory sAXParserFactory = this.validatingFactory;
        if (sAXParserFactory != null) {
            sAXParserFactory.setNamespaceAware(z);
        }
    }

    @Override // javax.xml.parsers.SAXParserFactory
    public void setValidating(boolean z) {
        super.setValidating(z);
        this.validating = z;
    }
}
