package org.apache.xmlbeans.impl.piccolo.xml;

import b.b.a.a.a;
import java.io.Reader;
import org.apache.xmlbeans.impl.piccolo.io.IllegalCharException;

public final class XMLReaderReader extends XMLInputReader {
    public static final int BUFFER_SIZE = 8192;
    public char[] cbuf;
    public int cbufEnd;
    public int cbufPos;
    public boolean eofReached;
    public Reader in;
    public char[] oneCharBuf;
    public boolean rewindDeclaration;
    public boolean sawCR;

    public XMLReaderReader() {
        this.cbuf = new char[8192];
        this.cbufPos = 0;
        this.cbufEnd = 0;
        this.eofReached = false;
        this.sawCR = false;
        this.oneCharBuf = new char[1];
    }

    private void fillCharBuffer() {
        this.cbufPos = 0;
        int read = this.in.read(this.cbuf, 0, 8192);
        this.cbufEnd = read;
        if (read <= 0) {
            this.eofReached = true;
        }
    }

    private void processXMLDecl() {
        int parseXMLDeclaration = parseXMLDeclaration(this.cbuf, 0, this.cbufEnd);
        if (parseXMLDeclaration > 0 && !this.rewindDeclaration) {
            this.cbufPos += parseXMLDeclaration;
        }
    }

    @Override // java.io.Closeable, java.io.Reader, java.lang.AutoCloseable
    public void close() {
        this.eofReached = true;
        this.cbufEnd = 0;
        this.cbufPos = 0;
        Reader reader = this.in;
        if (reader != null) {
            reader.close();
        }
    }

    @Override // java.io.Reader
    public void mark(int i2) {
        throw new UnsupportedOperationException("mark() not supported");
    }

    public boolean markSupported() {
        return false;
    }

    @Override // java.io.Reader
    public int read() {
        int read = read(this.oneCharBuf, 0, 1);
        if (read <= 0) {
            return read;
        }
        return this.oneCharBuf[0];
    }

    @Override // java.io.Reader
    public boolean ready() {
        return this.cbufEnd - this.cbufPos > 0 || this.in.ready();
    }

    public void reset(Reader reader, boolean z) {
        super.resetInput();
        this.in = reader;
        this.rewindDeclaration = z;
        this.cbufEnd = 0;
        this.cbufPos = 0;
        this.sawCR = false;
        this.eofReached = false;
        fillCharBuffer();
        processXMLDecl();
    }

    @Override // java.io.Reader
    public long skip(long j) {
        int i2 = 0;
        while (((long) i2) < j) {
            int i3 = this.cbufPos;
            if (i3 < this.cbufEnd) {
                char[] cArr = this.cbuf;
                this.cbufPos = i3 + 1;
                char c = cArr[i3];
                if (c >= ' ') {
                    if (c <= 55295 || ((c >= 57344 && c <= 65533) || (c >= 0 && c <= 65535))) {
                        this.sawCR = false;
                    } else {
                        throw new IllegalCharException(a.a(c, a.a("Illegal XML Character: 0x")));
                    }
                } else if (c != '\t') {
                    if (c != '\n') {
                        if (c == '\r') {
                            this.sawCR = true;
                        } else {
                            throw new IllegalCharException(a.a(c, a.a("Illegal XML character: 0x")));
                        }
                    } else if (this.sawCR) {
                        this.sawCR = false;
                    }
                }
                i2++;
            } else if (this.eofReached) {
                break;
            } else {
                fillCharBuffer();
            }
        }
        if (i2 == 0 && this.eofReached) {
            i2 = -1;
        }
        return (long) i2;
    }

    @Override // java.io.Reader
    public int read(char[] cArr) {
        return read(cArr, 0, cArr.length);
    }

    @Override // java.io.Reader
    public int read(char[] cArr, int i2, int i3) {
        int i4;
        int i5 = 0;
        while (i5 < i3) {
            int i6 = this.cbufPos;
            if (i6 >= this.cbufEnd) {
                if (this.eofReached || (i5 != 0 && !this.in.ready())) {
                    break;
                }
                fillCharBuffer();
            } else {
                char[] cArr2 = this.cbuf;
                this.cbufPos = i6 + 1;
                char c = cArr2[i6];
                if (c < ' ') {
                    if (c == '\t') {
                        i4 = i5 + 1;
                        cArr[i5 + i2] = '\t';
                    } else if (c != '\n') {
                        if (c == '\r') {
                            this.sawCR = true;
                            i4 = i5 + 1;
                            cArr[i5 + i2] = '\n';
                        } else {
                            throw new IllegalCharException(a.a(c, a.a("Illegal XML character: 0x")));
                        }
                    } else if (this.sawCR) {
                        this.sawCR = false;
                    } else {
                        i4 = i5 + 1;
                        cArr[i5 + i2] = '\n';
                    }
                    i5 = i4;
                } else if (c <= 55295 || ((c >= 57344 && c <= 65533) || (c >= 0 && c <= 65535))) {
                    this.sawCR = false;
                    cArr[i5 + i2] = c;
                    i5++;
                } else {
                    throw new IllegalCharException(a.a(c, a.a("Illegal XML Character: 0x")));
                }
            }
        }
        if (i5 != 0 || !this.eofReached) {
            return i5;
        }
        return -1;
    }

    public XMLReaderReader(Reader reader) {
        this(reader, true);
    }

    public XMLReaderReader(Reader reader, boolean z) {
        this.cbuf = new char[8192];
        this.cbufPos = 0;
        this.cbufEnd = 0;
        this.eofReached = false;
        this.sawCR = false;
        this.oneCharBuf = new char[1];
        reset(reader, z);
    }

    @Override // java.io.Reader
    public void reset() {
        super.resetInput();
        this.in.reset();
        this.cbufEnd = 0;
        this.cbufPos = 0;
        this.sawCR = false;
        this.eofReached = false;
    }
}
