package org.apache.xmlbeans.impl.regex;

import b.b.a.a.a;
import java.io.Serializable;
import java.text.CharacterIterator;
import org.apache.poi.openxml4j.opc.internal.ZipHelper;
import org.apache.xmlbeans.impl.regex.Op;
import org.apache.xmlbeans.impl.regex.Token;

public class RegularExpression implements Serializable {
    public static final int CARRIAGE_RETURN = 13;
    public static final boolean DEBUG = false;
    public static final int EXTENDED_COMMENT = 16;
    public static final int IGNORE_CASE = 2;
    public static final int LINE_FEED = 10;
    public static final int LINE_SEPARATOR = 8232;
    public static final int MULTIPLE_LINES = 8;
    public static final int PARAGRAPH_SEPARATOR = 8233;
    public static final int PROHIBIT_FIXED_STRING_OPTIMIZATION = 256;
    public static final int PROHIBIT_HEAD_CHARACTER_OPTIMIZATION = 128;
    public static final int SINGLE_LINE = 4;
    public static final int SPECIAL_COMMA = 1024;
    public static final int UNICODE_WORD_BOUNDARY = 64;
    public static final int USE_UNICODE_CATEGORY = 32;
    public static final int WT_IGNORE = 0;
    public static final int WT_LETTER = 1;
    public static final int WT_OTHER = 2;
    public static final int XMLSCHEMA_MODE = 512;
    public transient Context context = null;
    public transient RangeToken firstChar = null;
    public transient String fixedString = null;
    public transient boolean fixedStringOnly = false;
    public transient int fixedStringOptions;
    public transient BMPattern fixedStringTable = null;
    public boolean hasBackReferences = false;
    public transient int minlength;
    public int nofparen;
    public transient int numberOfClosures;
    public transient Op operations = null;
    public int options;
    public String regex;
    public Token tokentree;

    public RegularExpression(String str) {
        setPattern(str, (String) null);
    }

    private synchronized void compile(Token token) {
        if (this.operations == null) {
            this.numberOfClosures = 0;
            this.operations = compile(token, null, false);
        }
    }

    public static final int getPreviousWordType(char[] cArr, int i2, int i3, int i4, int i5) {
        int i6 = i4 - 1;
        int wordType = getWordType(cArr, i2, i3, i6, i5);
        while (wordType == 0) {
            i6--;
            wordType = getWordType(cArr, i2, i3, i6, i5);
        }
        return wordType;
    }

    public static final int getWordType(char[] cArr, int i2, int i3, int i4, int i5) {
        if (i4 < i2 || i4 >= i3) {
            return 2;
        }
        return getWordType0(cArr[i4], i5);
    }

    public static final int getWordType0(char c, int i2) {
        if (isSet(i2, 64)) {
            int type = Character.getType(c);
            if (type != 15) {
                if (type != 16) {
                    switch (type) {
                        case 1:
                        case 2:
                        case 3:
                        case 4:
                        case 5:
                        case 8:
                        case 9:
                        case 10:
                        case 11:
                            return 1;
                        case 6:
                        case 7:
                            break;
                        default:
                            return 2;
                    }
                }
                return 0;
            }
            switch (c) {
                case '\t':
                case '\n':
                case 11:
                case '\f':
                case '\r':
                    return 2;
                default:
                    return 0;
            }
        } else if (isSet(i2, 32)) {
            if (Token.getRange("IsWord", true).match(c)) {
                return 1;
            }
            return 2;
        } else if (isWordChar(c)) {
            return 1;
        } else {
            return 2;
        }
    }

    public static final boolean isEOLChar(int i2) {
        return i2 == 10 || i2 == 13 || i2 == 8232 || i2 == 8233;
    }

    public static final boolean isSet(int i2, int i3) {
        return (i2 & i3) == i3;
    }

    public static final boolean isWordChar(int i2) {
        if (i2 == 95) {
            return true;
        }
        if (i2 < 48 || i2 > 122) {
            return false;
        }
        if (i2 <= 57) {
            return true;
        }
        if (i2 < 65) {
            return false;
        }
        return i2 <= 90 || i2 >= 97;
    }

    /* JADX WARNING: Code restructure failed: missing block: B:236:0x02e8, code lost:
        if (r10.match.getEnd(r11.refNumber) >= 0) goto L_0x030d;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:240:0x0309, code lost:
        if (matchCharArray(r10, r11.condition, r12, r13, r14) >= 0) goto L_0x030d;
     */
    private int matchCharArray(Context context2, Op op, int i2, int i3, int i4) {
        int i5;
        int i6;
        int i7;
        int i8;
        int i9;
        int wordType;
        int wordType2;
        char[] cArr = context2.charTarget;
        while (op != null) {
            int i10 = context2.limit;
            if (i2 <= i10 && i2 >= context2.start) {
                int i11 = op.type;
                boolean z = true;
                if (i11 == 0) {
                    if (i3 <= 0) {
                        i2--;
                        if (i2 < i10 && i2 >= 0) {
                            char c = cArr[i2];
                            if (!isSet(i4, 4)) {
                                boolean isLowSurrogate = REUtil.isLowSurrogate(c);
                                int i12 = c;
                                if (isLowSurrogate) {
                                    i12 = c;
                                    if (i2 - 1 >= 0) {
                                        i2--;
                                        i12 = REUtil.composeFromSurrogates(cArr[i2], c);
                                    }
                                }
                                if (!isEOLChar(i12 == 1 ? 1 : 0)) {
                                    return -1;
                                }
                            } else if (REUtil.isLowSurrogate(c) && i2 - 1 >= 0) {
                                i2--;
                            }
                        }
                    } else if (i2 >= i10) {
                        return -1;
                    } else {
                        char c2 = cArr[i2];
                        if (!isSet(i4, 4)) {
                            boolean isHighSurrogate = REUtil.isHighSurrogate(c2);
                            int i13 = c2;
                            if (isHighSurrogate) {
                                int i14 = i2 + 1;
                                i13 = c2;
                                if (i14 < context2.limit) {
                                    i2 = i14;
                                    i13 = REUtil.composeFromSurrogates(c2, cArr[i14]);
                                }
                            }
                            if (isEOLChar(i13 == 1 ? 1 : 0)) {
                                return -1;
                            }
                        } else if (REUtil.isHighSurrogate(c2) && (i5 = i2 + 1) < context2.limit) {
                            i2 = i5;
                        }
                        i2++;
                    }
                    op = op.next;
                } else if (i11 == 1) {
                    if (isSet(i4, 2)) {
                        int data = op.getData();
                        if (i3 <= 0) {
                            i2--;
                            if (i2 >= context2.limit || i2 < 0 || !matchIgnoreCase(data, cArr[i2])) {
                                return -1;
                            }
                            op = op.next;
                        } else if (i2 >= context2.limit || !matchIgnoreCase(data, cArr[i2])) {
                            return -1;
                        }
                    } else {
                        int data2 = op.getData();
                        if (i3 <= 0) {
                            i2--;
                            if (i2 >= context2.limit || i2 < 0 || data2 != cArr[i2]) {
                                return -1;
                            }
                            op = op.next;
                        } else if (i2 >= context2.limit || data2 != cArr[i2]) {
                            return -1;
                        }
                    }
                    i2++;
                    op = op.next;
                } else if (i11 == 15) {
                    int data3 = op.getData();
                    Match match = context2.match;
                    if (match == null || data3 <= 0) {
                        Match match2 = context2.match;
                        if (match2 == null || data3 >= 0) {
                            op = op.next;
                        } else {
                            int i15 = -data3;
                            int end = match2.getEnd(i15);
                            context2.match.setEnd(i15, i2);
                            int matchCharArray = matchCharArray(context2, op.next, i2, i3, i4);
                            if (matchCharArray < 0) {
                                context2.match.setEnd(i15, end);
                            }
                            return matchCharArray;
                        }
                    } else {
                        int beginning = match.getBeginning(data3);
                        context2.match.setBeginning(data3, i2);
                        int matchCharArray2 = matchCharArray(context2, op.next, i2, i3, i4);
                        if (matchCharArray2 < 0) {
                            context2.match.setBeginning(data3, beginning);
                        }
                        return matchCharArray2;
                    }
                } else if (i11 != 16) {
                    switch (i11) {
                        case 3:
                        case 4:
                            if (i3 <= 0) {
                                i2--;
                                if (i2 >= i10 || i2 < 0) {
                                    return -1;
                                }
                                char c3 = cArr[i2];
                                boolean isLowSurrogate2 = REUtil.isLowSurrogate(c3);
                                char c4 = c3;
                                if (isLowSurrogate2) {
                                    c4 = c3;
                                    if (i2 - 1 >= 0) {
                                        i2--;
                                        c4 = REUtil.composeFromSurrogates(cArr[i2], c3);
                                    }
                                }
                                RangeToken token = op.getToken();
                                if (isSet(i4, 2)) {
                                    RangeToken caseInsensitiveToken = token.getCaseInsensitiveToken();
                                    if (!caseInsensitiveToken.match(c4)) {
                                        if (c4 >= 0) {
                                            return -1;
                                        }
                                        char upperCase = Character.toUpperCase((char) c4);
                                        if (!caseInsensitiveToken.match(upperCase) && !caseInsensitiveToken.match(Character.toLowerCase(upperCase))) {
                                            return -1;
                                        }
                                    }
                                } else if (!token.match(c4 == 1 ? 1 : 0)) {
                                    return -1;
                                }
                            } else if (i2 >= i10) {
                                return -1;
                            } else {
                                char c5 = cArr[i2];
                                boolean isHighSurrogate2 = REUtil.isHighSurrogate(c5);
                                char c6 = c5;
                                if (isHighSurrogate2) {
                                    int i16 = i2 + 1;
                                    c6 = c5;
                                    if (i16 < context2.limit) {
                                        i2 = i16;
                                        c6 = REUtil.composeFromSurrogates(c5, cArr[i16]);
                                    }
                                }
                                RangeToken token2 = op.getToken();
                                if (isSet(i4, 2)) {
                                    RangeToken caseInsensitiveToken2 = token2.getCaseInsensitiveToken();
                                    if (!caseInsensitiveToken2.match(c6)) {
                                        if (c6 >= 0) {
                                            return -1;
                                        }
                                        char upperCase2 = Character.toUpperCase((char) c6);
                                        if (!caseInsensitiveToken2.match(upperCase2) && !caseInsensitiveToken2.match(Character.toLowerCase(upperCase2))) {
                                            return -1;
                                        }
                                    }
                                } else if (!token2.match(c6 == 1 ? 1 : 0)) {
                                    return -1;
                                }
                                i2++;
                            }
                            op = op.next;
                            continue;
                        case 5:
                            int data4 = op.getData();
                            if (data4 != 36) {
                                if (data4 != 60) {
                                    if (data4 != 62) {
                                        if (data4 == 90) {
                                            int i17 = context2.limit;
                                            if (i2 != i17 && (((i9 = i2 + 1) != i17 || !isEOLChar(cArr[i2])) && !(i2 + 2 == context2.limit && cArr[i2] == '\r' && cArr[i9] == '\n'))) {
                                                return -1;
                                            }
                                        } else if (data4 != 94) {
                                            if (data4 != 98) {
                                                if (data4 != 122) {
                                                    switch (data4) {
                                                        case 64:
                                                            int i18 = context2.start;
                                                            if (i2 != i18 && (i2 <= i18 || !isEOLChar(cArr[i2 - 1]))) {
                                                                return -1;
                                                            }
                                                        case 65:
                                                            if (i2 != context2.start) {
                                                                return -1;
                                                            }
                                                            break;
                                                        case 66:
                                                            if (!(context2.length == 0 || (wordType2 = getWordType(cArr, context2.start, context2.limit, i2, i4)) == 0 || wordType2 == getPreviousWordType(cArr, context2.start, context2.limit, i2, i4))) {
                                                                z = false;
                                                            }
                                                            if (!z) {
                                                                return -1;
                                                            }
                                                            break;
                                                    }
                                                } else if (i2 != context2.limit) {
                                                    return -1;
                                                }
                                            } else if (context2.length == 0 || (wordType = getWordType(cArr, context2.start, context2.limit, i2, i4)) == 0 || wordType == getPreviousWordType(cArr, context2.start, context2.limit, i2, i4)) {
                                                return -1;
                                            }
                                        } else if (isSet(i4, 8)) {
                                            int i19 = context2.start;
                                            if (i2 != i19 && (i2 <= i19 || !isEOLChar(cArr[i2 - 1]))) {
                                                return -1;
                                            }
                                        } else if (i2 != context2.start) {
                                            return -1;
                                        }
                                    } else if (context2.length == 0 || i2 == (i8 = context2.start) || getWordType(cArr, i8, context2.limit, i2, i4) != 2 || getPreviousWordType(cArr, context2.start, context2.limit, i2, i4) != 1) {
                                        return -1;
                                    }
                                } else if (context2.length == 0 || i2 == (i7 = context2.limit) || getWordType(cArr, context2.start, i7, i2, i4) != 1 || getPreviousWordType(cArr, context2.start, context2.limit, i2, i4) != 2) {
                                    return -1;
                                }
                            } else if (isSet(i4, 8)) {
                                int i20 = context2.limit;
                                if (i2 != i20 && (i2 >= i20 || !isEOLChar(cArr[i2]))) {
                                    return -1;
                                }
                            } else {
                                int i21 = context2.limit;
                                if (i2 != i21 && (((i6 = i2 + 1) != i21 || !isEOLChar(cArr[i2])) && !(i2 + 2 == context2.limit && cArr[i2] == '\r' && cArr[i6] == '\n'))) {
                                    return -1;
                                }
                            }
                            op = op.next;
                            continue;
                        case 6:
                            String string = op.getString();
                            int length = string.length();
                            if (!isSet(i4, 2)) {
                                if (i3 <= 0) {
                                    i2 -= length;
                                    if (!regionMatches(cArr, i2, context2.limit, string, length)) {
                                        return -1;
                                    }
                                    op = op.next;
                                    continue;
                                } else if (!regionMatches(cArr, i2, context2.limit, string, length)) {
                                    return -1;
                                }
                            } else if (i3 <= 0) {
                                i2 -= length;
                                if (!regionMatchesIgnoreCase(cArr, i2, context2.limit, string, length)) {
                                    return -1;
                                }
                                op = op.next;
                                continue;
                            } else if (!regionMatchesIgnoreCase(cArr, i2, context2.limit, string, length)) {
                                return -1;
                            }
                            i2 += length;
                            op = op.next;
                            continue;
                        case 7:
                            int data5 = op.getData();
                            if (data5 >= 0) {
                                int[] iArr = context2.offsets;
                                int i22 = iArr[data5];
                                if (i22 < 0 || i22 != i2) {
                                    context2.offsets[data5] = i2;
                                } else {
                                    iArr[data5] = -1;
                                    op = op.next;
                                    continue;
                                }
                            }
                            int matchCharArray3 = matchCharArray(context2, op.getChild(), i2, i3, i4);
                            if (data5 >= 0) {
                                context2.offsets[data5] = -1;
                            }
                            if (matchCharArray3 < 0) {
                                op = op.next;
                                break;
                            } else {
                                return matchCharArray3;
                            }
                        case 8:
                        case 10:
                            int matchCharArray4 = matchCharArray(context2, op.next, i2, i3, i4);
                            if (matchCharArray4 >= 0) {
                                return matchCharArray4;
                            }
                            op = op.getChild();
                            continue;
                        case 9:
                            int matchCharArray5 = matchCharArray(context2, op.getChild(), i2, i3, i4);
                            if (matchCharArray5 >= 0) {
                                return matchCharArray5;
                            }
                            op = op.next;
                            continue;
                        case 11:
                            for (int i23 = 0; i23 < op.size(); i23++) {
                                int matchCharArray6 = matchCharArray(context2, op.elementAt(i23), i2, i3, i4);
                                if (matchCharArray6 >= 0) {
                                    return matchCharArray6;
                                }
                            }
                            return -1;
                        default:
                            switch (i11) {
                                case 20:
                                    if (matchCharArray(context2, op.getChild(), i2, 1, i4) < 0) {
                                        return -1;
                                    }
                                    op = op.next;
                                    continue;
                                case 21:
                                    if (matchCharArray(context2, op.getChild(), i2, 1, i4) >= 0) {
                                        return -1;
                                    }
                                    op = op.next;
                                    continue;
                                case 22:
                                    if (matchCharArray(context2, op.getChild(), i2, -1, i4) < 0) {
                                        return -1;
                                    }
                                    op = op.next;
                                    continue;
                                case 23:
                                    if (matchCharArray(context2, op.getChild(), i2, -1, i4) >= 0) {
                                        return -1;
                                    }
                                    op = op.next;
                                    continue;
                                case 24:
                                    i2 = matchCharArray(context2, op.getChild(), i2, i3, i4);
                                    if (i2 < 0) {
                                        return i2;
                                    }
                                    op = op.next;
                                    continue;
                                case 25:
                                    i2 = matchCharArray(context2, op.getChild(), i2, i3, (op.getData() | i4) & (~op.getData2()));
                                    if (i2 < 0) {
                                        return i2;
                                    }
                                    op = op.next;
                                    continue;
                                case 26:
                                    Op.ConditionOp conditionOp = (Op.ConditionOp) op;
                                    int i24 = conditionOp.refNumber;
                                    if (i24 <= 0) {
                                        break;
                                    } else if (i24 < this.nofparen) {
                                        if (context2.match.getBeginning(i24) >= 0) {
                                            break;
                                        }
                                    } else {
                                        StringBuffer a = a.a("Internal Error: Reference number must be more than zero: ");
                                        a.append(conditionOp.refNumber);
                                        throw new RuntimeException(a.toString());
                                    }
                                    z = false;
                                    if (!z) {
                                        Op op2 = conditionOp.no;
                                        if (op2 != null) {
                                            op = op2;
                                            break;
                                        } else {
                                            op = conditionOp.next;
                                            break;
                                        }
                                    } else {
                                        op = conditionOp.yes;
                                        continue;
                                        continue;
                                    }
                                default:
                                    StringBuffer a2 = a.a("Unknown operation type: ");
                                    a2.append(op.type);
                                    throw new RuntimeException(a2.toString());
                            }
                    }
                } else {
                    int data6 = op.getData();
                    if (data6 <= 0 || data6 >= this.nofparen) {
                        throw new RuntimeException(a.b("Internal Error: Reference number must be more than zero: ", data6));
                    } else if (context2.match.getBeginning(data6) < 0 || context2.match.getEnd(data6) < 0) {
                        return -1;
                    } else {
                        int beginning2 = context2.match.getBeginning(data6);
                        int end2 = context2.match.getEnd(data6) - beginning2;
                        if (!isSet(i4, 2)) {
                            if (i3 <= 0) {
                                i2 -= end2;
                                if (!regionMatches(cArr, i2, context2.limit, beginning2, end2)) {
                                    return -1;
                                }
                                op = op.next;
                            } else if (!regionMatches(cArr, i2, context2.limit, beginning2, end2)) {
                                return -1;
                            }
                        } else if (i3 <= 0) {
                            i2 -= end2;
                            if (!regionMatchesIgnoreCase(cArr, i2, context2.limit, beginning2, end2)) {
                                return -1;
                            }
                            op = op.next;
                        } else if (!regionMatchesIgnoreCase(cArr, i2, context2.limit, beginning2, end2)) {
                            return -1;
                        }
                        i2 += end2;
                        op = op.next;
                    }
                }
            }
            return -1;
        }
        if (!isSet(i4, 512) || i2 == context2.limit) {
            return i2;
        }
        return -1;
    }

    /* JADX WARNING: Code restructure failed: missing block: B:236:0x0302, code lost:
        if (r10.match.getEnd(r11.refNumber) >= 0) goto L_0x0327;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:240:0x0323, code lost:
        if (matchCharacterIterator(r10, r11.condition, r12, r13, r14) >= 0) goto L_0x0327;
     */
    private int matchCharacterIterator(Context context2, Op op, int i2, int i3, int i4) {
        int i5;
        int i6;
        int i7;
        int i8;
        int i9;
        int i10;
        int i11;
        int wordType;
        int wordType2;
        CharacterIterator characterIterator = context2.ciTarget;
        while (op != null) {
            int i12 = context2.limit;
            if (i2 <= i12 && i2 >= context2.start) {
                int i13 = op.type;
                boolean z = true;
                if (i13 == 0) {
                    if (i3 <= 0) {
                        i2--;
                        if (i2 < i12 && i2 >= 0) {
                            int index = characterIterator.setIndex(i2);
                            if (!isSet(i4, 4)) {
                                if (REUtil.isLowSurrogate(index) && i2 - 1 >= 0) {
                                    i2--;
                                    index = REUtil.composeFromSurrogates(characterIterator.setIndex(i2), index);
                                }
                                if (!isEOLChar(index)) {
                                    return -1;
                                }
                            } else if (REUtil.isLowSurrogate(index) && i2 - 1 >= 0) {
                                i2--;
                            }
                        }
                    } else if (i2 >= i12) {
                        return -1;
                    } else {
                        int index2 = characterIterator.setIndex(i2);
                        if (!isSet(i4, 4)) {
                            if (REUtil.isHighSurrogate(index2) && (i5 = i2 + 1) < context2.limit) {
                                index2 = REUtil.composeFromSurrogates(index2, characterIterator.setIndex(i5));
                                i2 = i5;
                            }
                            if (isEOLChar(index2)) {
                                return -1;
                            }
                        } else if (REUtil.isHighSurrogate(index2) && (i6 = i2 + 1) < context2.limit) {
                            i2 = i6;
                        }
                        i2++;
                    }
                    op = op.next;
                } else if (i13 == 1) {
                    if (isSet(i4, 2)) {
                        int data = op.getData();
                        if (i3 <= 0) {
                            i2--;
                            if (i2 >= context2.limit || i2 < 0 || !matchIgnoreCase(data, characterIterator.setIndex(i2))) {
                                return -1;
                            }
                            op = op.next;
                        } else if (i2 >= context2.limit || !matchIgnoreCase(data, characterIterator.setIndex(i2))) {
                            return -1;
                        }
                    } else {
                        int data2 = op.getData();
                        if (i3 <= 0) {
                            i2--;
                            if (i2 >= context2.limit || i2 < 0 || data2 != characterIterator.setIndex(i2)) {
                                return -1;
                            }
                            op = op.next;
                        } else if (i2 >= context2.limit || data2 != characterIterator.setIndex(i2)) {
                            return -1;
                        }
                    }
                    i2++;
                    op = op.next;
                } else if (i13 == 15) {
                    int data3 = op.getData();
                    Match match = context2.match;
                    if (match == null || data3 <= 0) {
                        Match match2 = context2.match;
                        if (match2 == null || data3 >= 0) {
                            op = op.next;
                        } else {
                            int i14 = -data3;
                            int end = match2.getEnd(i14);
                            context2.match.setEnd(i14, i2);
                            int matchCharacterIterator = matchCharacterIterator(context2, op.next, i2, i3, i4);
                            if (matchCharacterIterator < 0) {
                                context2.match.setEnd(i14, end);
                            }
                            return matchCharacterIterator;
                        }
                    } else {
                        int beginning = match.getBeginning(data3);
                        context2.match.setBeginning(data3, i2);
                        int matchCharacterIterator2 = matchCharacterIterator(context2, op.next, i2, i3, i4);
                        if (matchCharacterIterator2 < 0) {
                            context2.match.setBeginning(data3, beginning);
                        }
                        return matchCharacterIterator2;
                    }
                } else if (i13 != 16) {
                    switch (i13) {
                        case 3:
                        case 4:
                            if (i3 <= 0) {
                                i2--;
                                if (i2 >= i12 || i2 < 0) {
                                    return -1;
                                }
                                int index3 = characterIterator.setIndex(i2);
                                if (REUtil.isLowSurrogate(index3) && i2 - 1 >= 0) {
                                    i2--;
                                    index3 = REUtil.composeFromSurrogates(characterIterator.setIndex(i2), index3);
                                }
                                RangeToken token = op.getToken();
                                if (isSet(i4, 2)) {
                                    RangeToken caseInsensitiveToken = token.getCaseInsensitiveToken();
                                    if (!caseInsensitiveToken.match(index3)) {
                                        if (index3 >= 65536) {
                                            return -1;
                                        }
                                        char upperCase = Character.toUpperCase((char) index3);
                                        if (!caseInsensitiveToken.match(upperCase) && !caseInsensitiveToken.match(Character.toLowerCase(upperCase))) {
                                            return -1;
                                        }
                                    }
                                } else if (!token.match(index3)) {
                                    return -1;
                                }
                            } else if (i2 >= i12) {
                                return -1;
                            } else {
                                int index4 = characterIterator.setIndex(i2);
                                if (REUtil.isHighSurrogate(index4) && (i7 = i2 + 1) < context2.limit) {
                                    index4 = REUtil.composeFromSurrogates(index4, characterIterator.setIndex(i7));
                                    i2 = i7;
                                }
                                RangeToken token2 = op.getToken();
                                if (isSet(i4, 2)) {
                                    RangeToken caseInsensitiveToken2 = token2.getCaseInsensitiveToken();
                                    if (!caseInsensitiveToken2.match(index4)) {
                                        if (index4 >= 65536) {
                                            return -1;
                                        }
                                        char upperCase2 = Character.toUpperCase((char) index4);
                                        if (!caseInsensitiveToken2.match(upperCase2) && !caseInsensitiveToken2.match(Character.toLowerCase(upperCase2))) {
                                            return -1;
                                        }
                                    }
                                } else if (!token2.match(index4)) {
                                    return -1;
                                }
                                i2++;
                            }
                            op = op.next;
                            continue;
                        case 5:
                            int data4 = op.getData();
                            if (data4 != 36) {
                                if (data4 != 60) {
                                    if (data4 != 62) {
                                        if (data4 == 90) {
                                            int i15 = context2.limit;
                                            if (i2 != i15 && (((i11 = i2 + 1) != i15 || !isEOLChar(characterIterator.setIndex(i2))) && !(i2 + 2 == context2.limit && characterIterator.setIndex(i2) == '\r' && characterIterator.setIndex(i11) == '\n'))) {
                                                return -1;
                                            }
                                        } else if (data4 != 94) {
                                            if (data4 != 98) {
                                                if (data4 != 122) {
                                                    switch (data4) {
                                                        case 64:
                                                            int i16 = context2.start;
                                                            if (i2 != i16 && (i2 <= i16 || !isEOLChar(characterIterator.setIndex(i2 - 1)))) {
                                                                return -1;
                                                            }
                                                        case 65:
                                                            if (i2 != context2.start) {
                                                                return -1;
                                                            }
                                                            break;
                                                        case 66:
                                                            if (!(context2.length == 0 || (wordType2 = getWordType(characterIterator, context2.start, context2.limit, i2, i4)) == 0 || wordType2 == getPreviousWordType(characterIterator, context2.start, context2.limit, i2, i4))) {
                                                                z = false;
                                                            }
                                                            if (!z) {
                                                                return -1;
                                                            }
                                                            break;
                                                    }
                                                } else if (i2 != context2.limit) {
                                                    return -1;
                                                }
                                            } else if (context2.length == 0 || (wordType = getWordType(characterIterator, context2.start, context2.limit, i2, i4)) == 0 || wordType == getPreviousWordType(characterIterator, context2.start, context2.limit, i2, i4)) {
                                                return -1;
                                            }
                                        } else if (isSet(i4, 8)) {
                                            int i17 = context2.start;
                                            if (i2 != i17 && (i2 <= i17 || !isEOLChar(characterIterator.setIndex(i2 - 1)))) {
                                                return -1;
                                            }
                                        } else if (i2 != context2.start) {
                                            return -1;
                                        }
                                    } else if (context2.length == 0 || i2 == (i10 = context2.start) || getWordType(characterIterator, i10, context2.limit, i2, i4) != 2 || getPreviousWordType(characterIterator, context2.start, context2.limit, i2, i4) != 1) {
                                        return -1;
                                    }
                                } else if (context2.length == 0 || i2 == (i9 = context2.limit) || getWordType(characterIterator, context2.start, i9, i2, i4) != 1 || getPreviousWordType(characterIterator, context2.start, context2.limit, i2, i4) != 2) {
                                    return -1;
                                }
                            } else if (isSet(i4, 8)) {
                                int i18 = context2.limit;
                                if (i2 != i18 && (i2 >= i18 || !isEOLChar(characterIterator.setIndex(i2)))) {
                                    return -1;
                                }
                            } else {
                                int i19 = context2.limit;
                                if (i2 != i19 && (((i8 = i2 + 1) != i19 || !isEOLChar(characterIterator.setIndex(i2))) && !(i2 + 2 == context2.limit && characterIterator.setIndex(i2) == '\r' && characterIterator.setIndex(i8) == '\n'))) {
                                    return -1;
                                }
                            }
                            op = op.next;
                            continue;
                        case 6:
                            String string = op.getString();
                            int length = string.length();
                            if (!isSet(i4, 2)) {
                                if (i3 <= 0) {
                                    i2 -= length;
                                    if (!regionMatches(characterIterator, i2, context2.limit, string, length)) {
                                        return -1;
                                    }
                                    op = op.next;
                                    continue;
                                } else if (!regionMatches(characterIterator, i2, context2.limit, string, length)) {
                                    return -1;
                                }
                            } else if (i3 <= 0) {
                                i2 -= length;
                                if (!regionMatchesIgnoreCase(characterIterator, i2, context2.limit, string, length)) {
                                    return -1;
                                }
                                op = op.next;
                                continue;
                            } else if (!regionMatchesIgnoreCase(characterIterator, i2, context2.limit, string, length)) {
                                return -1;
                            }
                            i2 += length;
                            op = op.next;
                            continue;
                        case 7:
                            int data5 = op.getData();
                            if (data5 >= 0) {
                                int[] iArr = context2.offsets;
                                int i20 = iArr[data5];
                                if (i20 < 0 || i20 != i2) {
                                    context2.offsets[data5] = i2;
                                } else {
                                    iArr[data5] = -1;
                                    op = op.next;
                                    continue;
                                }
                            }
                            int matchCharacterIterator3 = matchCharacterIterator(context2, op.getChild(), i2, i3, i4);
                            if (data5 >= 0) {
                                context2.offsets[data5] = -1;
                            }
                            if (matchCharacterIterator3 < 0) {
                                op = op.next;
                                break;
                            } else {
                                return matchCharacterIterator3;
                            }
                        case 8:
                        case 10:
                            int matchCharacterIterator4 = matchCharacterIterator(context2, op.next, i2, i3, i4);
                            if (matchCharacterIterator4 >= 0) {
                                return matchCharacterIterator4;
                            }
                            op = op.getChild();
                            continue;
                        case 9:
                            int matchCharacterIterator5 = matchCharacterIterator(context2, op.getChild(), i2, i3, i4);
                            if (matchCharacterIterator5 >= 0) {
                                return matchCharacterIterator5;
                            }
                            op = op.next;
                            continue;
                        case 11:
                            for (int i21 = 0; i21 < op.size(); i21++) {
                                int matchCharacterIterator6 = matchCharacterIterator(context2, op.elementAt(i21), i2, i3, i4);
                                if (matchCharacterIterator6 >= 0) {
                                    return matchCharacterIterator6;
                                }
                            }
                            return -1;
                        default:
                            switch (i13) {
                                case 20:
                                    if (matchCharacterIterator(context2, op.getChild(), i2, 1, i4) < 0) {
                                        return -1;
                                    }
                                    op = op.next;
                                    continue;
                                case 21:
                                    if (matchCharacterIterator(context2, op.getChild(), i2, 1, i4) >= 0) {
                                        return -1;
                                    }
                                    op = op.next;
                                    continue;
                                case 22:
                                    if (matchCharacterIterator(context2, op.getChild(), i2, -1, i4) < 0) {
                                        return -1;
                                    }
                                    op = op.next;
                                    continue;
                                case 23:
                                    if (matchCharacterIterator(context2, op.getChild(), i2, -1, i4) >= 0) {
                                        return -1;
                                    }
                                    op = op.next;
                                    continue;
                                case 24:
                                    i2 = matchCharacterIterator(context2, op.getChild(), i2, i3, i4);
                                    if (i2 < 0) {
                                        return i2;
                                    }
                                    op = op.next;
                                    continue;
                                case 25:
                                    i2 = matchCharacterIterator(context2, op.getChild(), i2, i3, (op.getData() | i4) & (~op.getData2()));
                                    if (i2 < 0) {
                                        return i2;
                                    }
                                    op = op.next;
                                    continue;
                                case 26:
                                    Op.ConditionOp conditionOp = (Op.ConditionOp) op;
                                    int i22 = conditionOp.refNumber;
                                    if (i22 <= 0) {
                                        break;
                                    } else if (i22 < this.nofparen) {
                                        if (context2.match.getBeginning(i22) >= 0) {
                                            break;
                                        }
                                    } else {
                                        StringBuffer a = a.a("Internal Error: Reference number must be more than zero: ");
                                        a.append(conditionOp.refNumber);
                                        throw new RuntimeException(a.toString());
                                    }
                                    z = false;
                                    if (!z) {
                                        Op op2 = conditionOp.no;
                                        if (op2 != null) {
                                            op = op2;
                                            break;
                                        } else {
                                            op = conditionOp.next;
                                            break;
                                        }
                                    } else {
                                        op = conditionOp.yes;
                                        continue;
                                        continue;
                                    }
                                default:
                                    StringBuffer a2 = a.a("Unknown operation type: ");
                                    a2.append(op.type);
                                    throw new RuntimeException(a2.toString());
                            }
                    }
                } else {
                    int data6 = op.getData();
                    if (data6 <= 0 || data6 >= this.nofparen) {
                        throw new RuntimeException(a.b("Internal Error: Reference number must be more than zero: ", data6));
                    } else if (context2.match.getBeginning(data6) < 0 || context2.match.getEnd(data6) < 0) {
                        return -1;
                    } else {
                        int beginning2 = context2.match.getBeginning(data6);
                        int end2 = context2.match.getEnd(data6) - beginning2;
                        if (!isSet(i4, 2)) {
                            if (i3 <= 0) {
                                i2 -= end2;
                                if (!regionMatches(characterIterator, i2, context2.limit, beginning2, end2)) {
                                    return -1;
                                }
                                op = op.next;
                            } else if (!regionMatches(characterIterator, i2, context2.limit, beginning2, end2)) {
                                return -1;
                            }
                        } else if (i3 <= 0) {
                            i2 -= end2;
                            if (!regionMatchesIgnoreCase(characterIterator, i2, context2.limit, beginning2, end2)) {
                                return -1;
                            }
                            op = op.next;
                        } else if (!regionMatchesIgnoreCase(characterIterator, i2, context2.limit, beginning2, end2)) {
                            return -1;
                        }
                        i2 += end2;
                        op = op.next;
                    }
                }
            }
            return -1;
        }
        if (!isSet(i4, 512) || i2 == context2.limit) {
            return i2;
        }
        return -1;
    }

    public static final boolean matchIgnoreCase(int i2, int i3) {
        if (i2 == i3) {
            return true;
        }
        if (i2 > 65535 || i3 > 65535) {
            return false;
        }
        char upperCase = Character.toUpperCase((char) i2);
        char upperCase2 = Character.toUpperCase((char) i3);
        if (upperCase == upperCase2 || Character.toLowerCase(upperCase) == Character.toLowerCase(upperCase2)) {
            return true;
        }
        return false;
    }

    /* JADX WARNING: Code restructure failed: missing block: B:236:0x0302, code lost:
        if (r10.match.getEnd(r11.refNumber) >= 0) goto L_0x0327;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:240:0x0323, code lost:
        if (matchString(r10, r11.condition, r12, r13, r14) >= 0) goto L_0x0327;
     */
    private int matchString(Context context2, Op op, int i2, int i3, int i4) {
        int i5;
        int i6;
        int i7;
        int i8;
        int i9;
        int i10;
        int i11;
        int wordType;
        int wordType2;
        String str = context2.strTarget;
        while (op != null) {
            int i12 = context2.limit;
            if (i2 <= i12 && i2 >= context2.start) {
                int i13 = op.type;
                boolean z = true;
                if (i13 == 0) {
                    if (i3 <= 0) {
                        i2--;
                        if (i2 < i12 && i2 >= 0) {
                            int charAt = str.charAt(i2);
                            if (!isSet(i4, 4)) {
                                if (REUtil.isLowSurrogate(charAt) && i2 - 1 >= 0) {
                                    i2--;
                                    charAt = REUtil.composeFromSurrogates(str.charAt(i2), charAt);
                                }
                                if (!isEOLChar(charAt)) {
                                    return -1;
                                }
                            } else if (REUtil.isLowSurrogate(charAt) && i2 - 1 >= 0) {
                                i2--;
                            }
                        }
                    } else if (i2 >= i12) {
                        return -1;
                    } else {
                        int charAt2 = str.charAt(i2);
                        if (!isSet(i4, 4)) {
                            if (REUtil.isHighSurrogate(charAt2) && (i5 = i2 + 1) < context2.limit) {
                                charAt2 = REUtil.composeFromSurrogates(charAt2, str.charAt(i5));
                                i2 = i5;
                            }
                            if (isEOLChar(charAt2)) {
                                return -1;
                            }
                        } else if (REUtil.isHighSurrogate(charAt2) && (i6 = i2 + 1) < context2.limit) {
                            i2 = i6;
                        }
                        i2++;
                    }
                    op = op.next;
                } else if (i13 == 1) {
                    if (isSet(i4, 2)) {
                        int data = op.getData();
                        if (i3 <= 0) {
                            i2--;
                            if (i2 >= context2.limit || i2 < 0 || !matchIgnoreCase(data, str.charAt(i2))) {
                                return -1;
                            }
                            op = op.next;
                        } else if (i2 >= context2.limit || !matchIgnoreCase(data, str.charAt(i2))) {
                            return -1;
                        }
                    } else {
                        int data2 = op.getData();
                        if (i3 <= 0) {
                            i2--;
                            if (i2 >= context2.limit || i2 < 0 || data2 != str.charAt(i2)) {
                                return -1;
                            }
                            op = op.next;
                        } else if (i2 >= context2.limit || data2 != str.charAt(i2)) {
                            return -1;
                        }
                    }
                    i2++;
                    op = op.next;
                } else if (i13 == 15) {
                    int data3 = op.getData();
                    Match match = context2.match;
                    if (match == null || data3 <= 0) {
                        Match match2 = context2.match;
                        if (match2 == null || data3 >= 0) {
                            op = op.next;
                        } else {
                            int i14 = -data3;
                            int end = match2.getEnd(i14);
                            context2.match.setEnd(i14, i2);
                            int matchString = matchString(context2, op.next, i2, i3, i4);
                            if (matchString < 0) {
                                context2.match.setEnd(i14, end);
                            }
                            return matchString;
                        }
                    } else {
                        int beginning = match.getBeginning(data3);
                        context2.match.setBeginning(data3, i2);
                        int matchString2 = matchString(context2, op.next, i2, i3, i4);
                        if (matchString2 < 0) {
                            context2.match.setBeginning(data3, beginning);
                        }
                        return matchString2;
                    }
                } else if (i13 != 16) {
                    switch (i13) {
                        case 3:
                        case 4:
                            if (i3 <= 0) {
                                i2--;
                                if (i2 >= i12 || i2 < 0) {
                                    return -1;
                                }
                                int charAt3 = str.charAt(i2);
                                if (REUtil.isLowSurrogate(charAt3) && i2 - 1 >= 0) {
                                    i2--;
                                    charAt3 = REUtil.composeFromSurrogates(str.charAt(i2), charAt3);
                                }
                                RangeToken token = op.getToken();
                                if (isSet(i4, 2)) {
                                    RangeToken caseInsensitiveToken = token.getCaseInsensitiveToken();
                                    if (!caseInsensitiveToken.match(charAt3)) {
                                        if (charAt3 >= 65536) {
                                            return -1;
                                        }
                                        char upperCase = Character.toUpperCase((char) charAt3);
                                        if (!caseInsensitiveToken.match(upperCase) && !caseInsensitiveToken.match(Character.toLowerCase(upperCase))) {
                                            return -1;
                                        }
                                    }
                                } else if (!token.match(charAt3)) {
                                    return -1;
                                }
                            } else if (i2 >= i12) {
                                return -1;
                            } else {
                                int charAt4 = str.charAt(i2);
                                if (REUtil.isHighSurrogate(charAt4) && (i7 = i2 + 1) < context2.limit) {
                                    charAt4 = REUtil.composeFromSurrogates(charAt4, str.charAt(i7));
                                    i2 = i7;
                                }
                                RangeToken token2 = op.getToken();
                                if (isSet(i4, 2)) {
                                    RangeToken caseInsensitiveToken2 = token2.getCaseInsensitiveToken();
                                    if (!caseInsensitiveToken2.match(charAt4)) {
                                        if (charAt4 >= 65536) {
                                            return -1;
                                        }
                                        char upperCase2 = Character.toUpperCase((char) charAt4);
                                        if (!caseInsensitiveToken2.match(upperCase2) && !caseInsensitiveToken2.match(Character.toLowerCase(upperCase2))) {
                                            return -1;
                                        }
                                    }
                                } else if (!token2.match(charAt4)) {
                                    return -1;
                                }
                                i2++;
                            }
                            op = op.next;
                            continue;
                        case 5:
                            int data4 = op.getData();
                            if (data4 != 36) {
                                if (data4 != 60) {
                                    if (data4 != 62) {
                                        if (data4 == 90) {
                                            int i15 = context2.limit;
                                            if (i2 != i15 && (((i11 = i2 + 1) != i15 || !isEOLChar(str.charAt(i2))) && !(i2 + 2 == context2.limit && str.charAt(i2) == '\r' && str.charAt(i11) == '\n'))) {
                                                return -1;
                                            }
                                        } else if (data4 != 94) {
                                            if (data4 != 98) {
                                                if (data4 != 122) {
                                                    switch (data4) {
                                                        case 64:
                                                            int i16 = context2.start;
                                                            if (i2 != i16 && (i2 <= i16 || !isEOLChar(str.charAt(i2 - 1)))) {
                                                                return -1;
                                                            }
                                                        case 65:
                                                            if (i2 != context2.start) {
                                                                return -1;
                                                            }
                                                            break;
                                                        case 66:
                                                            if (!(context2.length == 0 || (wordType2 = getWordType(str, context2.start, context2.limit, i2, i4)) == 0 || wordType2 == getPreviousWordType(str, context2.start, context2.limit, i2, i4))) {
                                                                z = false;
                                                            }
                                                            if (!z) {
                                                                return -1;
                                                            }
                                                            break;
                                                    }
                                                } else if (i2 != context2.limit) {
                                                    return -1;
                                                }
                                            } else if (context2.length == 0 || (wordType = getWordType(str, context2.start, context2.limit, i2, i4)) == 0 || wordType == getPreviousWordType(str, context2.start, context2.limit, i2, i4)) {
                                                return -1;
                                            }
                                        } else if (isSet(i4, 8)) {
                                            int i17 = context2.start;
                                            if (i2 != i17 && (i2 <= i17 || !isEOLChar(str.charAt(i2 - 1)))) {
                                                return -1;
                                            }
                                        } else if (i2 != context2.start) {
                                            return -1;
                                        }
                                    } else if (context2.length == 0 || i2 == (i10 = context2.start) || getWordType(str, i10, context2.limit, i2, i4) != 2 || getPreviousWordType(str, context2.start, context2.limit, i2, i4) != 1) {
                                        return -1;
                                    }
                                } else if (context2.length == 0 || i2 == (i9 = context2.limit) || getWordType(str, context2.start, i9, i2, i4) != 1 || getPreviousWordType(str, context2.start, context2.limit, i2, i4) != 2) {
                                    return -1;
                                }
                            } else if (isSet(i4, 8)) {
                                int i18 = context2.limit;
                                if (i2 != i18 && (i2 >= i18 || !isEOLChar(str.charAt(i2)))) {
                                    return -1;
                                }
                            } else {
                                int i19 = context2.limit;
                                if (i2 != i19 && (((i8 = i2 + 1) != i19 || !isEOLChar(str.charAt(i2))) && !(i2 + 2 == context2.limit && str.charAt(i2) == '\r' && str.charAt(i8) == '\n'))) {
                                    return -1;
                                }
                            }
                            op = op.next;
                            continue;
                        case 6:
                            String string = op.getString();
                            int length = string.length();
                            if (!isSet(i4, 2)) {
                                if (i3 <= 0) {
                                    i2 -= length;
                                    if (!regionMatches(str, i2, context2.limit, string, length)) {
                                        return -1;
                                    }
                                    op = op.next;
                                    continue;
                                } else if (!regionMatches(str, i2, context2.limit, string, length)) {
                                    return -1;
                                }
                            } else if (i3 <= 0) {
                                i2 -= length;
                                if (!regionMatchesIgnoreCase(str, i2, context2.limit, string, length)) {
                                    return -1;
                                }
                                op = op.next;
                                continue;
                            } else if (!regionMatchesIgnoreCase(str, i2, context2.limit, string, length)) {
                                return -1;
                            }
                            i2 += length;
                            op = op.next;
                            continue;
                        case 7:
                            int data5 = op.getData();
                            if (data5 >= 0) {
                                int[] iArr = context2.offsets;
                                int i20 = iArr[data5];
                                if (i20 < 0 || i20 != i2) {
                                    context2.offsets[data5] = i2;
                                } else {
                                    iArr[data5] = -1;
                                    op = op.next;
                                    continue;
                                }
                            }
                            int matchString3 = matchString(context2, op.getChild(), i2, i3, i4);
                            if (data5 >= 0) {
                                context2.offsets[data5] = -1;
                            }
                            if (matchString3 < 0) {
                                op = op.next;
                                break;
                            } else {
                                return matchString3;
                            }
                        case 8:
                        case 10:
                            int matchString4 = matchString(context2, op.next, i2, i3, i4);
                            if (matchString4 >= 0) {
                                return matchString4;
                            }
                            op = op.getChild();
                            continue;
                        case 9:
                            int matchString5 = matchString(context2, op.getChild(), i2, i3, i4);
                            if (matchString5 >= 0) {
                                return matchString5;
                            }
                            op = op.next;
                            continue;
                        case 11:
                            for (int i21 = 0; i21 < op.size(); i21++) {
                                int matchString6 = matchString(context2, op.elementAt(i21), i2, i3, i4);
                                if (matchString6 >= 0) {
                                    return matchString6;
                                }
                            }
                            return -1;
                        default:
                            switch (i13) {
                                case 20:
                                    if (matchString(context2, op.getChild(), i2, 1, i4) < 0) {
                                        return -1;
                                    }
                                    op = op.next;
                                    continue;
                                case 21:
                                    if (matchString(context2, op.getChild(), i2, 1, i4) >= 0) {
                                        return -1;
                                    }
                                    op = op.next;
                                    continue;
                                case 22:
                                    if (matchString(context2, op.getChild(), i2, -1, i4) < 0) {
                                        return -1;
                                    }
                                    op = op.next;
                                    continue;
                                case 23:
                                    if (matchString(context2, op.getChild(), i2, -1, i4) >= 0) {
                                        return -1;
                                    }
                                    op = op.next;
                                    continue;
                                case 24:
                                    i2 = matchString(context2, op.getChild(), i2, i3, i4);
                                    if (i2 < 0) {
                                        return i2;
                                    }
                                    op = op.next;
                                    continue;
                                case 25:
                                    i2 = matchString(context2, op.getChild(), i2, i3, (op.getData() | i4) & (~op.getData2()));
                                    if (i2 < 0) {
                                        return i2;
                                    }
                                    op = op.next;
                                    continue;
                                case 26:
                                    Op.ConditionOp conditionOp = (Op.ConditionOp) op;
                                    int i22 = conditionOp.refNumber;
                                    if (i22 <= 0) {
                                        break;
                                    } else if (i22 < this.nofparen) {
                                        if (context2.match.getBeginning(i22) >= 0) {
                                            break;
                                        }
                                    } else {
                                        StringBuffer a = a.a("Internal Error: Reference number must be more than zero: ");
                                        a.append(conditionOp.refNumber);
                                        throw new RuntimeException(a.toString());
                                    }
                                    z = false;
                                    if (!z) {
                                        Op op2 = conditionOp.no;
                                        if (op2 != null) {
                                            op = op2;
                                            break;
                                        } else {
                                            op = conditionOp.next;
                                            break;
                                        }
                                    } else {
                                        op = conditionOp.yes;
                                        continue;
                                        continue;
                                    }
                                default:
                                    StringBuffer a2 = a.a("Unknown operation type: ");
                                    a2.append(op.type);
                                    throw new RuntimeException(a2.toString());
                            }
                    }
                } else {
                    int data6 = op.getData();
                    if (data6 <= 0 || data6 >= this.nofparen) {
                        throw new RuntimeException(a.b("Internal Error: Reference number must be more than zero: ", data6));
                    } else if (context2.match.getBeginning(data6) < 0 || context2.match.getEnd(data6) < 0) {
                        return -1;
                    } else {
                        int beginning2 = context2.match.getBeginning(data6);
                        int end2 = context2.match.getEnd(data6) - beginning2;
                        if (!isSet(i4, 2)) {
                            if (i3 <= 0) {
                                i2 -= end2;
                                if (!regionMatches(str, i2, context2.limit, beginning2, end2)) {
                                    return -1;
                                }
                                op = op.next;
                            } else if (!regionMatches(str, i2, context2.limit, beginning2, end2)) {
                                return -1;
                            }
                        } else if (i3 <= 0) {
                            i2 -= end2;
                            if (!regionMatchesIgnoreCase(str, i2, context2.limit, beginning2, end2)) {
                                return -1;
                            }
                            op = op.next;
                        } else if (!regionMatchesIgnoreCase(str, i2, context2.limit, beginning2, end2)) {
                            return -1;
                        }
                        i2 += end2;
                        op = op.next;
                    }
                }
            }
            return -1;
        }
        if (!isSet(i4, 512) || i2 == context2.limit) {
            return i2;
        }
        return -1;
    }

    public static final boolean regionMatches(char[] cArr, int i2, int i3, String str, int i4) {
        if (i2 < 0 || i3 - i2 < i4) {
            return false;
        }
        int i5 = 0;
        while (true) {
            int i6 = i4 - 1;
            if (i4 <= 0) {
                return true;
            }
            int i7 = i2 + 1;
            int i8 = i5 + 1;
            if (cArr[i2] != str.charAt(i5)) {
                return false;
            }
            i2 = i7;
            i4 = i6;
            i5 = i8;
        }
    }

    public static final boolean regionMatchesIgnoreCase(char[] cArr, int i2, int i3, String str, int i4) {
        char upperCase;
        char upperCase2;
        if (i2 < 0 || i3 - i2 < i4) {
            return false;
        }
        int i5 = 0;
        while (true) {
            int i6 = i4 - 1;
            if (i4 <= 0) {
                return true;
            }
            int i7 = i2 + 1;
            char c = cArr[i2];
            int i8 = i5 + 1;
            char charAt = str.charAt(i5);
            if (c != charAt && (upperCase = Character.toUpperCase(c)) != (upperCase2 = Character.toUpperCase(charAt)) && Character.toLowerCase(upperCase) != Character.toLowerCase(upperCase2)) {
                return false;
            }
            i2 = i7;
            i4 = i6;
            i5 = i8;
        }
    }

    public boolean equals(Object obj) {
        if (obj == null || !(obj instanceof RegularExpression)) {
            return false;
        }
        RegularExpression regularExpression = (RegularExpression) obj;
        if (!this.regex.equals(regularExpression.regex) || this.options != regularExpression.options) {
            return false;
        }
        return true;
    }

    public int getNumberOfGroups() {
        return this.nofparen;
    }

    public String getOptions() {
        return REUtil.createOptionString(this.options);
    }

    public String getPattern() {
        return this.regex;
    }

    public int hashCode() {
        StringBuffer stringBuffer = new StringBuffer();
        stringBuffer.append(this.regex);
        stringBuffer.append(ZipHelper.FORWARD_SLASH);
        stringBuffer.append(getOptions());
        return stringBuffer.toString().hashCode();
    }

    public boolean matches(char[] cArr) {
        return matches(cArr, 0, cArr.length, (Match) null);
    }

    public void prepare() {
        int i2;
        compile(this.tokentree);
        this.minlength = this.tokentree.getMinLength();
        this.firstChar = null;
        if (!isSet(this.options, 128) && !isSet(this.options, 512)) {
            RangeToken createRange = Token.createRange();
            if (this.tokentree.analyzeFirstCharacter(createRange, this.options) == 1) {
                createRange.compactRanges();
                this.firstChar = createRange;
            }
        }
        Op op = this.operations;
        if (op != null && ((i2 = op.type) == 6 || i2 == 1)) {
            Op op2 = this.operations;
            if (op2.next == null) {
                this.fixedStringOnly = true;
                if (op2.type == 6) {
                    this.fixedString = op2.getString();
                } else if (op2.getData() >= 65536) {
                    this.fixedString = REUtil.decomposeToSurrogates(this.operations.getData());
                } else {
                    this.fixedString = new String(new char[]{(char) this.operations.getData()});
                }
                int i3 = this.options;
                this.fixedStringOptions = i3;
                this.fixedStringTable = new BMPattern(this.fixedString, 256, isSet(i3, 2));
                return;
            }
        }
        if (!isSet(this.options, 256) && !isSet(this.options, 512)) {
            Token.FixedStringContainer fixedStringContainer = new Token.FixedStringContainer();
            this.tokentree.findFixedString(fixedStringContainer, this.options);
            Token token = fixedStringContainer.token;
            String string = token == null ? null : token.getString();
            this.fixedString = string;
            this.fixedStringOptions = fixedStringContainer.options;
            if (string != null && string.length() < 2) {
                this.fixedString = null;
            }
            String str = this.fixedString;
            if (str != null) {
                this.fixedStringTable = new BMPattern(str, 256, isSet(this.fixedStringOptions, 2));
            }
        }
    }

    public void setPattern(String str) {
        setPattern(str, this.options);
    }

    public String toString() {
        return this.tokentree.toString(this.options);
    }

    public static final int getWordType(String str, int i2, int i3, int i4, int i5) {
        if (i4 < i2 || i4 >= i3) {
            return 2;
        }
        return getWordType0(str.charAt(i4), i5);
    }

    public static final boolean regionMatches(char[] cArr, int i2, int i3, int i4, int i5) {
        if (i2 < 0 || i3 - i2 < i5) {
            return false;
        }
        while (true) {
            int i6 = i5 - 1;
            if (i5 <= 0) {
                return true;
            }
            int i7 = i2 + 1;
            int i8 = i4 + 1;
            if (cArr[i2] != cArr[i4]) {
                return false;
            }
            i2 = i7;
            i4 = i8;
            i5 = i6;
        }
    }

    private void setPattern(String str, int i2) {
        this.regex = str;
        this.options = i2;
        RegexParser parserForXMLSchema = isSet(i2, 512) ? new ParserForXMLSchema() : new RegexParser();
        this.tokentree = parserForXMLSchema.parse(this.regex, this.options);
        this.nofparen = parserForXMLSchema.parennumber;
        this.hasBackReferences = parserForXMLSchema.hasBackReferences;
        this.operations = null;
        this.context = null;
    }

    public boolean matches(char[] cArr, int i2, int i3) {
        return matches(cArr, i2, i3, (Match) null);
    }

    public static final int getPreviousWordType(String str, int i2, int i3, int i4, int i5) {
        int i6 = i4 - 1;
        int wordType = getWordType(str, i2, i3, i6, i5);
        while (wordType == 0) {
            i6--;
            wordType = getWordType(str, i2, i3, i6, i5);
        }
        return wordType;
    }

    public static final int getWordType(CharacterIterator characterIterator, int i2, int i3, int i4, int i5) {
        if (i4 < i2 || i4 >= i3) {
            return 2;
        }
        return getWordType0(characterIterator.setIndex(i4), i5);
    }

    public static final boolean regionMatches(String str, int i2, int i3, String str2, int i4) {
        if (i3 - i2 < i4) {
            return false;
        }
        return str.regionMatches(i2, str2, 0, i4);
    }

    public boolean matches(char[] cArr, Match match) {
        return matches(cArr, 0, cArr.length, match);
    }

    public static final class Context {
        public char[] charTarget;
        public CharacterIterator ciTarget;
        public boolean inuse = false;
        public int length;
        public int limit;
        public Match match;
        public int[] offsets;
        public int start;
        public String strTarget;

        private void resetCommon(int i2) {
            this.length = this.limit - this.start;
            this.inuse = true;
            this.match = null;
            int[] iArr = this.offsets;
            if (iArr == null || iArr.length != i2) {
                this.offsets = new int[i2];
            }
            for (int i3 = 0; i3 < i2; i3++) {
                this.offsets[i3] = -1;
            }
        }

        public void reset(CharacterIterator characterIterator, int i2, int i3, int i4) {
            this.ciTarget = characterIterator;
            this.start = i2;
            this.limit = i3;
            resetCommon(i4);
        }

        public void reset(String str, int i2, int i3, int i4) {
            this.strTarget = str;
            this.start = i2;
            this.limit = i3;
            resetCommon(i4);
        }

        public void reset(char[] cArr, int i2, int i3, int i4) {
            this.charTarget = cArr;
            this.start = i2;
            this.limit = i3;
            resetCommon(i4);
        }
    }

    public static final boolean regionMatches(String str, int i2, int i3, int i4, int i5) {
        if (i3 - i2 < i5) {
            return false;
        }
        return str.regionMatches(i2, str, i4, i5);
    }

    public boolean equals(String str, int i2) {
        return this.regex.equals(str) && this.options == i2;
    }

    public boolean matches(char[] cArr, int i2, int i3, Match match) {
        Context context2;
        int i4;
        int i5;
        int i6;
        int i7;
        synchronized (this) {
            if (this.operations == null) {
                prepare();
            }
            if (this.context == null) {
                this.context = new Context();
            }
        }
        synchronized (this.context) {
            context2 = this.context.inuse ? new Context() : this.context;
            context2.reset(cArr, i2, i3, this.numberOfClosures);
        }
        if (match != null) {
            match.setNumberOfGroups(this.nofparen);
            match.setSource(cArr);
        } else if (this.hasBackReferences) {
            match = new Match();
            match.setNumberOfGroups(this.nofparen);
        }
        context2.match = match;
        if (isSet(this.options, 512)) {
            int matchCharArray = matchCharArray(context2, this.operations, context2.start, 1, this.options);
            if (matchCharArray != context2.limit) {
                return false;
            }
            Match match2 = context2.match;
            if (match2 != null) {
                match2.setBeginning(0, context2.start);
                context2.match.setEnd(0, matchCharArray);
            }
            context2.inuse = false;
            return true;
        } else if (this.fixedStringOnly) {
            int matches = this.fixedStringTable.matches(cArr, context2.start, context2.limit);
            if (matches >= 0) {
                Match match3 = context2.match;
                if (match3 != null) {
                    match3.setBeginning(0, matches);
                    context2.match.setEnd(0, this.fixedString.length() + matches);
                }
                context2.inuse = false;
                return true;
            }
            context2.inuse = false;
            return false;
        } else if (this.fixedString == null || this.fixedStringTable.matches(cArr, context2.start, context2.limit) >= 0) {
            int i8 = context2.limit - this.minlength;
            int i9 = -1;
            Op op = this.operations;
            if (op == null || op.type != 7 || op.getChild().type != 0) {
                RangeToken rangeToken = this.firstChar;
                if (rangeToken != null) {
                    if (isSet(this.options, 2)) {
                        RangeToken caseInsensitiveToken = this.firstChar.getCaseInsensitiveToken();
                        i6 = context2.start;
                        while (i6 <= i8) {
                            char c = cArr[i6];
                            if (!REUtil.isHighSurrogate(c) || (i7 = i6 + 1) >= context2.limit) {
                                if (!caseInsensitiveToken.match(c)) {
                                    char upperCase = Character.toUpperCase((char) c);
                                    if (!caseInsensitiveToken.match(upperCase) && !caseInsensitiveToken.match(Character.toLowerCase(upperCase))) {
                                        i6++;
                                    }
                                }
                            } else if (!caseInsensitiveToken.match(REUtil.composeFromSurrogates(c, cArr[i7]))) {
                                continue;
                                i6++;
                            }
                            i9 = matchCharArray(context2, this.operations, i6, 1, this.options);
                            if (i9 >= 0) {
                                break;
                            }
                            i6++;
                        }
                    } else {
                        i6 = context2.start;
                        while (i6 <= i8) {
                            char c2 = cArr[i6];
                            boolean isHighSurrogate = REUtil.isHighSurrogate(c2);
                            int i10 = c2;
                            if (isHighSurrogate) {
                                int i11 = i6 + 1;
                                i10 = c2;
                                if (i11 < context2.limit) {
                                    i10 = REUtil.composeFromSurrogates(c2, cArr[i11]);
                                }
                            }
                            if (rangeToken.match(i10 == 1 ? 1 : 0) && (i9 = matchCharArray(context2, this.operations, i6, 1, this.options)) >= 0) {
                                break;
                            }
                            i6++;
                        }
                    }
                    i4 = i9;
                    i5 = i6;
                } else {
                    i5 = context2.start;
                    while (i5 <= i8) {
                        i9 = matchCharArray(context2, this.operations, i5, 1, this.options);
                        if (i9 >= 0) {
                            break;
                        }
                        i5++;
                    }
                    i4 = i9;
                }
            } else if (isSet(this.options, 4)) {
                i5 = context2.start;
                i4 = matchCharArray(context2, this.operations, i5, 1, this.options);
            } else {
                int i12 = context2.start;
                int i13 = -1;
                boolean z = true;
                while (i12 <= i8) {
                    if (!isEOLChar(cArr[i12])) {
                        if (z && (i13 = matchCharArray(context2, this.operations, i12, 1, this.options)) >= 0) {
                            break;
                        }
                        z = false;
                    } else {
                        z = true;
                    }
                    i12++;
                }
                i4 = i13;
                i5 = i12;
            }
            if (i4 >= 0) {
                Match match4 = context2.match;
                if (match4 != null) {
                    match4.setBeginning(0, i5);
                    context2.match.setEnd(0, i4);
                }
                context2.inuse = false;
                return true;
            }
            context2.inuse = false;
            return false;
        } else {
            context2.inuse = false;
            return false;
        }
    }

    public static final int getPreviousWordType(CharacterIterator characterIterator, int i2, int i3, int i4, int i5) {
        int i6 = i4 - 1;
        int wordType = getWordType(characterIterator, i2, i3, i6, i5);
        while (wordType == 0) {
            i6--;
            wordType = getWordType(characterIterator, i2, i3, i6, i5);
        }
        return wordType;
    }

    public static final boolean regionMatches(CharacterIterator characterIterator, int i2, int i3, String str, int i4) {
        if (i2 < 0 || i3 - i2 < i4) {
            return false;
        }
        int i5 = 0;
        while (true) {
            int i6 = i4 - 1;
            if (i4 <= 0) {
                return true;
            }
            int i7 = i2 + 1;
            int i8 = i5 + 1;
            if (characterIterator.setIndex(i2) != str.charAt(i5)) {
                return false;
            }
            i2 = i7;
            i4 = i6;
            i5 = i8;
        }
    }

    private Op compile(Token token, Op op, boolean z) {
        Op op2;
        Op op3;
        Op.ChildOp childOp;
        int i2 = token.type;
        int i3 = 0;
        switch (i2) {
            case 0:
                op2 = Op.createChar(token.getChar());
                op2.next = op;
                break;
            case 1:
                if (!z) {
                    for (int size = token.size() - 1; size >= 0; size--) {
                        op = compile(token.getChild(size), op, false);
                    }
                    return op;
                }
                while (i3 < token.size()) {
                    op = compile(token.getChild(i3), op, true);
                    i3++;
                }
                return op;
            case 2:
                Op.UnionOp createUnion = Op.createUnion(token.size());
                while (i3 < token.size()) {
                    createUnion.addElement(compile(token.getChild(i3), op, z));
                    i3++;
                }
                return createUnion;
            case 3:
            case 9:
                Token child = token.getChild(0);
                int min = token.getMin();
                int max = token.getMax();
                if (min < 0 || min != max) {
                    if (min > 0 && max > 0) {
                        max -= min;
                    }
                    if (max > 0) {
                        int i4 = 0;
                        Op op4 = op;
                        while (i4 < max) {
                            Op.ChildOp createQuestion = Op.createQuestion(token.type == 9);
                            createQuestion.next = op;
                            createQuestion.setChild(compile(child, op4, z));
                            i4++;
                            op4 = createQuestion;
                        }
                        op3 = op4;
                    } else {
                        if (token.type == 9) {
                            childOp = Op.createNonGreedyClosure();
                        } else if (child.getMinLength() == 0) {
                            int i5 = this.numberOfClosures;
                            this.numberOfClosures = i5 + 1;
                            childOp = Op.createClosure(i5);
                        } else {
                            childOp = Op.createClosure(-1);
                        }
                        childOp.next = op;
                        childOp.setChild(compile(child, childOp, z));
                        op3 = childOp;
                    }
                    if (min <= 0) {
                        return op3;
                    }
                    while (i3 < min) {
                        op3 = compile(child, op3, z);
                        i3++;
                    }
                    return op3;
                }
                while (i3 < min) {
                    op = compile(child, op, z);
                    i3++;
                }
                return op;
            case 4:
            case 5:
                op2 = Op.createRange(token);
                op2.next = op;
                break;
            case 6:
                if (token.getParenNumber() == 0) {
                    return compile(token.getChild(0), op, z);
                }
                if (z) {
                    return Op.createCapture(-token.getParenNumber(), compile(token.getChild(0), Op.createCapture(token.getParenNumber(), op), z));
                }
                return Op.createCapture(token.getParenNumber(), compile(token.getChild(0), Op.createCapture(-token.getParenNumber(), op), z));
            case 7:
                return op;
            case 8:
                op2 = Op.createAnchor(token.getChar());
                op2.next = op;
                break;
            case 10:
                op2 = Op.createString(token.getString());
                op2.next = op;
                break;
            case 11:
                op2 = Op.createDot();
                op2.next = op;
                break;
            case 12:
                op2 = Op.createBackReference(token.getReferenceNumber());
                op2.next = op;
                break;
            default:
                Op op5 = null;
                switch (i2) {
                    case 20:
                        return Op.createLook(20, op, compile(token.getChild(0), null, false));
                    case 21:
                        return Op.createLook(21, op, compile(token.getChild(0), null, false));
                    case 22:
                        return Op.createLook(22, op, compile(token.getChild(0), null, true));
                    case 23:
                        return Op.createLook(23, op, compile(token.getChild(0), null, true));
                    case 24:
                        return Op.createIndependent(op, compile(token.getChild(0), null, z));
                    case 25:
                        Token.ModifierToken modifierToken = (Token.ModifierToken) token;
                        return Op.createModifier(op, compile(token.getChild(0), null, z), modifierToken.getOptions(), modifierToken.getOptionsMask());
                    case 26:
                        Token.ConditionToken conditionToken = (Token.ConditionToken) token;
                        int i6 = conditionToken.refNumber;
                        Token token2 = conditionToken.condition;
                        Op compile = token2 == null ? null : compile(token2, null, z);
                        Op compile2 = compile(conditionToken.yes, op, z);
                        Token token3 = conditionToken.no;
                        if (token3 != null) {
                            op5 = compile(token3, op, z);
                        }
                        return Op.createCondition(op, i6, compile, compile2, op5);
                    default:
                        StringBuffer a = a.a("Unknown token type: ");
                        a.append(token.type);
                        throw new RuntimeException(a.toString());
                }
        }
        return op2;
    }

    public static final boolean regionMatches(CharacterIterator characterIterator, int i2, int i3, int i4, int i5) {
        if (i2 < 0 || i3 - i2 < i5) {
            return false;
        }
        while (true) {
            int i6 = i5 - 1;
            if (i5 <= 0) {
                return true;
            }
            int i7 = i2 + 1;
            int i8 = i4 + 1;
            if (characterIterator.setIndex(i2) != characterIterator.setIndex(i4)) {
                return false;
            }
            i2 = i7;
            i4 = i8;
            i5 = i6;
        }
    }

    public static final boolean regionMatchesIgnoreCase(char[] cArr, int i2, int i3, int i4, int i5) {
        char upperCase;
        char upperCase2;
        if (i2 < 0 || i3 - i2 < i5) {
            return false;
        }
        while (true) {
            int i6 = i5 - 1;
            if (i5 <= 0) {
                return true;
            }
            int i7 = i2 + 1;
            char c = cArr[i2];
            int i8 = i4 + 1;
            char c2 = cArr[i4];
            if (c != c2 && (upperCase = Character.toUpperCase(c)) != (upperCase2 = Character.toUpperCase(c2)) && Character.toLowerCase(upperCase) != Character.toLowerCase(upperCase2)) {
                return false;
            }
            i2 = i7;
            i4 = i8;
            i5 = i6;
        }
    }

    public RegularExpression(String str, String str2) {
        setPattern(str, str2);
    }

    public void setPattern(String str, String str2) {
        setPattern(str, REUtil.parseOptions(str2));
    }

    public static final boolean regionMatchesIgnoreCase(String str, int i2, int i3, String str2, int i4) {
        return str.regionMatches(true, i2, str2, 0, i4);
    }

    public static final boolean regionMatchesIgnoreCase(String str, int i2, int i3, int i4, int i5) {
        if (i3 - i2 < i5) {
            return false;
        }
        return str.regionMatches(true, i2, str, i4, i5);
    }

    public static final boolean regionMatchesIgnoreCase(CharacterIterator characterIterator, int i2, int i3, String str, int i4) {
        char upperCase;
        char upperCase2;
        if (i2 < 0 || i3 - i2 < i4) {
            return false;
        }
        int i5 = 0;
        while (true) {
            int i6 = i4 - 1;
            if (i4 <= 0) {
                return true;
            }
            int i7 = i2 + 1;
            char index = characterIterator.setIndex(i2);
            int i8 = i5 + 1;
            char charAt = str.charAt(i5);
            if (index != charAt && (upperCase = Character.toUpperCase(index)) != (upperCase2 = Character.toUpperCase(charAt)) && Character.toLowerCase(upperCase) != Character.toLowerCase(upperCase2)) {
                return false;
            }
            i2 = i7;
            i4 = i6;
            i5 = i8;
        }
    }

    public static final boolean regionMatchesIgnoreCase(CharacterIterator characterIterator, int i2, int i3, int i4, int i5) {
        char upperCase;
        char upperCase2;
        if (i2 < 0 || i3 - i2 < i5) {
            return false;
        }
        while (true) {
            int i6 = i5 - 1;
            if (i5 <= 0) {
                return true;
            }
            int i7 = i2 + 1;
            char index = characterIterator.setIndex(i2);
            int i8 = i4 + 1;
            char index2 = characterIterator.setIndex(i4);
            if (index != index2 && (upperCase = Character.toUpperCase(index)) != (upperCase2 = Character.toUpperCase(index2)) && Character.toLowerCase(upperCase) != Character.toLowerCase(upperCase2)) {
                return false;
            }
            i2 = i7;
            i4 = i8;
            i5 = i6;
        }
    }

    public RegularExpression(String str, Token token, int i2, boolean z, int i3) {
        this.regex = str;
        this.tokentree = token;
        this.nofparen = i2;
        this.options = i3;
        this.hasBackReferences = z;
    }

    public boolean matches(String str) {
        return matches(str, 0, str.length(), (Match) null);
    }

    public boolean matches(String str, int i2, int i3) {
        return matches(str, i2, i3, (Match) null);
    }

    public boolean matches(String str, Match match) {
        return matches(str, 0, str.length(), match);
    }

    public boolean matches(String str, int i2, int i3, Match match) {
        Context context2;
        int i4;
        int i5;
        int i6;
        int i7;
        int i8;
        synchronized (this) {
            if (this.operations == null) {
                prepare();
            }
            if (this.context == null) {
                this.context = new Context();
            }
        }
        synchronized (this.context) {
            context2 = this.context.inuse ? new Context() : this.context;
            context2.reset(str, i2, i3, this.numberOfClosures);
        }
        if (match != null) {
            match.setNumberOfGroups(this.nofparen);
            match.setSource(str);
        } else if (this.hasBackReferences) {
            match = new Match();
            match.setNumberOfGroups(this.nofparen);
        }
        context2.match = match;
        if (isSet(this.options, 512)) {
            int matchString = matchString(context2, this.operations, context2.start, 1, this.options);
            if (matchString != context2.limit) {
                return false;
            }
            Match match2 = context2.match;
            if (match2 != null) {
                match2.setBeginning(0, context2.start);
                context2.match.setEnd(0, matchString);
            }
            context2.inuse = false;
            return true;
        } else if (this.fixedStringOnly) {
            int matches = this.fixedStringTable.matches(str, context2.start, context2.limit);
            if (matches >= 0) {
                Match match3 = context2.match;
                if (match3 != null) {
                    match3.setBeginning(0, matches);
                    context2.match.setEnd(0, this.fixedString.length() + matches);
                }
                context2.inuse = false;
                return true;
            }
            context2.inuse = false;
            return false;
        } else if (this.fixedString == null || this.fixedStringTable.matches(str, context2.start, context2.limit) >= 0) {
            int i9 = context2.limit - this.minlength;
            int i10 = -1;
            Op op = this.operations;
            if (op == null || op.type != 7 || op.getChild().type != 0) {
                RangeToken rangeToken = this.firstChar;
                if (rangeToken != null) {
                    if (isSet(this.options, 2)) {
                        RangeToken caseInsensitiveToken = this.firstChar.getCaseInsensitiveToken();
                        i6 = context2.start;
                        while (i6 <= i9) {
                            char charAt = str.charAt(i6);
                            if (!REUtil.isHighSurrogate(charAt) || (i8 = i6 + 1) >= context2.limit) {
                                if (!caseInsensitiveToken.match(charAt)) {
                                    char upperCase = Character.toUpperCase((char) charAt);
                                    if (!caseInsensitiveToken.match(upperCase) && !caseInsensitiveToken.match(Character.toLowerCase(upperCase))) {
                                        i6++;
                                    }
                                }
                            } else if (!caseInsensitiveToken.match(REUtil.composeFromSurrogates(charAt, str.charAt(i8)))) {
                                continue;
                                i6++;
                            }
                            i10 = matchString(context2, this.operations, i6, 1, this.options);
                            if (i10 >= 0) {
                                break;
                            }
                            i6++;
                        }
                    } else {
                        i6 = context2.start;
                        while (i6 <= i9) {
                            int charAt2 = str.charAt(i6);
                            if (REUtil.isHighSurrogate(charAt2) && (i7 = i6 + 1) < context2.limit) {
                                charAt2 = REUtil.composeFromSurrogates(charAt2, str.charAt(i7));
                            }
                            if (rangeToken.match(charAt2) && (i10 = matchString(context2, this.operations, i6, 1, this.options)) >= 0) {
                                break;
                            }
                            i6++;
                        }
                    }
                    i4 = i10;
                    i5 = i6;
                } else {
                    i5 = context2.start;
                    while (i5 <= i9) {
                        i10 = matchString(context2, this.operations, i5, 1, this.options);
                        if (i10 >= 0) {
                            break;
                        }
                        i5++;
                    }
                    i4 = i10;
                }
            } else if (isSet(this.options, 4)) {
                i5 = context2.start;
                i4 = matchString(context2, this.operations, i5, 1, this.options);
            } else {
                int i11 = context2.start;
                int i12 = -1;
                boolean z = true;
                while (i11 <= i9) {
                    if (!isEOLChar(str.charAt(i11))) {
                        if (z && (i12 = matchString(context2, this.operations, i11, 1, this.options)) >= 0) {
                            break;
                        }
                        z = false;
                    } else {
                        z = true;
                    }
                    i11++;
                }
                i4 = i12;
                i5 = i11;
            }
            if (i4 >= 0) {
                Match match4 = context2.match;
                if (match4 != null) {
                    match4.setBeginning(0, i5);
                    context2.match.setEnd(0, i4);
                }
                context2.inuse = false;
                return true;
            }
            context2.inuse = false;
            return false;
        } else {
            context2.inuse = false;
            return false;
        }
    }

    public boolean matches(CharacterIterator characterIterator) {
        return matches(characterIterator, (Match) null);
    }

    public boolean matches(CharacterIterator characterIterator, Match match) {
        Context context2;
        int i2;
        int i3;
        int i4;
        int i5;
        int i6;
        int beginIndex = characterIterator.getBeginIndex();
        int endIndex = characterIterator.getEndIndex();
        synchronized (this) {
            if (this.operations == null) {
                prepare();
            }
            if (this.context == null) {
                this.context = new Context();
            }
        }
        synchronized (this.context) {
            context2 = this.context.inuse ? new Context() : this.context;
            context2.reset(characterIterator, beginIndex, endIndex, this.numberOfClosures);
        }
        if (match != null) {
            match.setNumberOfGroups(this.nofparen);
            match.setSource(characterIterator);
        } else if (this.hasBackReferences) {
            match = new Match();
            match.setNumberOfGroups(this.nofparen);
        }
        context2.match = match;
        if (isSet(this.options, 512)) {
            int matchCharacterIterator = matchCharacterIterator(context2, this.operations, context2.start, 1, this.options);
            if (matchCharacterIterator != context2.limit) {
                return false;
            }
            Match match2 = context2.match;
            if (match2 != null) {
                match2.setBeginning(0, context2.start);
                context2.match.setEnd(0, matchCharacterIterator);
            }
            context2.inuse = false;
            return true;
        } else if (this.fixedStringOnly) {
            int matches = this.fixedStringTable.matches(characterIterator, context2.start, context2.limit);
            if (matches >= 0) {
                Match match3 = context2.match;
                if (match3 != null) {
                    match3.setBeginning(0, matches);
                    context2.match.setEnd(0, this.fixedString.length() + matches);
                }
                context2.inuse = false;
                return true;
            }
            context2.inuse = false;
            return false;
        } else if (this.fixedString == null || this.fixedStringTable.matches(characterIterator, context2.start, context2.limit) >= 0) {
            int i7 = context2.limit - this.minlength;
            int i8 = -1;
            Op op = this.operations;
            if (op == null || op.type != 7 || op.getChild().type != 0) {
                RangeToken rangeToken = this.firstChar;
                if (rangeToken != null) {
                    if (isSet(this.options, 2)) {
                        RangeToken caseInsensitiveToken = this.firstChar.getCaseInsensitiveToken();
                        i4 = context2.start;
                        while (i4 <= i7) {
                            char index = characterIterator.setIndex(i4);
                            if (!REUtil.isHighSurrogate(index) || (i6 = i4 + 1) >= context2.limit) {
                                if (!caseInsensitiveToken.match(index)) {
                                    char upperCase = Character.toUpperCase((char) index);
                                    if (!caseInsensitiveToken.match(upperCase) && !caseInsensitiveToken.match(Character.toLowerCase(upperCase))) {
                                        i4++;
                                    }
                                }
                            } else if (!caseInsensitiveToken.match(REUtil.composeFromSurrogates(index, characterIterator.setIndex(i6)))) {
                                continue;
                                i4++;
                            }
                            i8 = matchCharacterIterator(context2, this.operations, i4, 1, this.options);
                            if (i8 >= 0) {
                                break;
                            }
                            i4++;
                        }
                    } else {
                        i4 = context2.start;
                        while (i4 <= i7) {
                            int index2 = characterIterator.setIndex(i4);
                            if (REUtil.isHighSurrogate(index2) && (i5 = i4 + 1) < context2.limit) {
                                index2 = REUtil.composeFromSurrogates(index2, characterIterator.setIndex(i5));
                            }
                            if (rangeToken.match(index2) && (i8 = matchCharacterIterator(context2, this.operations, i4, 1, this.options)) >= 0) {
                                break;
                            }
                            i4++;
                        }
                    }
                    i2 = i8;
                    i3 = i4;
                } else {
                    i3 = context2.start;
                    while (i3 <= i7) {
                        i8 = matchCharacterIterator(context2, this.operations, i3, 1, this.options);
                        if (i8 >= 0) {
                            break;
                        }
                        i3++;
                    }
                    i2 = i8;
                }
            } else if (isSet(this.options, 4)) {
                i3 = context2.start;
                i2 = matchCharacterIterator(context2, this.operations, i3, 1, this.options);
            } else {
                int i9 = context2.start;
                int i10 = -1;
                boolean z = true;
                while (i9 <= i7) {
                    if (!isEOLChar(characterIterator.setIndex(i9))) {
                        if (z && (i10 = matchCharacterIterator(context2, this.operations, i9, 1, this.options)) >= 0) {
                            break;
                        }
                        z = false;
                    } else {
                        z = true;
                    }
                    i9++;
                }
                i2 = i10;
                i3 = i9;
            }
            if (i2 >= 0) {
                Match match4 = context2.match;
                if (match4 != null) {
                    match4.setBeginning(0, i3);
                    context2.match.setEnd(0, i2);
                }
                context2.inuse = false;
                return true;
            }
            context2.inuse = false;
            return false;
        } else {
            context2.inuse = false;
            return false;
        }
    }
}
