package org.apache.xmlbeans.impl.regex;

import java.util.HashMap;
import java.util.Map;
import org.apache.xmlbeans.impl.common.XMLChar;

public class SchemaRegularExpression extends RegularExpression {
    public static final Map knownPatterns = buildKnownPatternMap();

    public static Map buildKnownPatternMap() {
        HashMap hashMap = new HashMap();
        hashMap.put("\\c+", new SchemaRegularExpression("\\c+") {
            /* class org.apache.xmlbeans.impl.regex.SchemaRegularExpression.AnonymousClass1 */

            @Override // org.apache.xmlbeans.impl.regex.RegularExpression
            public boolean matches(String str) {
                return XMLChar.isValidNmtoken(str);
            }
        });
        hashMap.put("\\i\\c*", new SchemaRegularExpression("\\i\\c*") {
            /* class org.apache.xmlbeans.impl.regex.SchemaRegularExpression.AnonymousClass2 */

            @Override // org.apache.xmlbeans.impl.regex.RegularExpression
            public boolean matches(String str) {
                return XMLChar.isValidName(str);
            }
        });
        hashMap.put("[\\i-[:]][\\c-[:]]*", new SchemaRegularExpression("[\\i-[:]][\\c-[:]]*") {
            /* class org.apache.xmlbeans.impl.regex.SchemaRegularExpression.AnonymousClass3 */

            @Override // org.apache.xmlbeans.impl.regex.RegularExpression
            public boolean matches(String str) {
                return XMLChar.isValidNCName(str);
            }
        });
        return hashMap;
    }

    public static RegularExpression forPattern(String str) {
        SchemaRegularExpression schemaRegularExpression = (SchemaRegularExpression) knownPatterns.get(str);
        if (schemaRegularExpression != null) {
            return schemaRegularExpression;
        }
        return new RegularExpression(str, "X");
    }

    public SchemaRegularExpression(String str) {
        super(str, "X");
    }
}
