package org.apache.xmlbeans.impl.schema;

import b.b.a.a.a;
import java.io.File;
import java.io.InputStream;
import java.math.BigInteger;
import java.util.Collections;
import java.util.HashMap;
import java.util.Map;
import org.apache.poi.hpsf.Filetime;
import org.apache.poi.javax.xml.namespace.QName;
import org.apache.xerces.impl.xs.SchemaSymbols;
import org.apache.xmlbeans.Filer;
import org.apache.xmlbeans.QNameSet;
import org.apache.xmlbeans.SchemaAnnotation;
import org.apache.xmlbeans.SchemaAttributeGroup;
import org.apache.xmlbeans.SchemaComponent;
import org.apache.xmlbeans.SchemaGlobalAttribute;
import org.apache.xmlbeans.SchemaGlobalElement;
import org.apache.xmlbeans.SchemaIdentityConstraint;
import org.apache.xmlbeans.SchemaModelGroup;
import org.apache.xmlbeans.SchemaType;
import org.apache.xmlbeans.SchemaTypeSystem;
import org.apache.xmlbeans.impl.common.QNameHelper;
import org.apache.xmlbeans.impl.regex.ParseException;
import org.apache.xmlbeans.impl.regex.RegularExpression;
import org.apache.xmlbeans.impl.regex.SchemaRegularExpression;
import org.apache.xmlbeans.impl.values.XmlIntegerImpl;
import org.apache.xmlbeans.impl.values.XmlStringImpl;
import org.apache.xmlbeans.impl.values.XmlValueOutOfRangeException;

public class BuiltinSchemaTypeSystem extends SchemaTypeLoaderBase implements SchemaTypeSystem {
    public static final /* synthetic */ boolean $assertionsDisabled;
    public static final SchemaAnnotation[] EMPTY_SCHEMAANNOTATION_ARRAY = new SchemaAnnotation[0];
    public static final SchemaAttributeGroup[] EMPTY_SCHEMAATTRIBUTEGROUP_ARRAY = new SchemaAttributeGroup[0];
    public static final SchemaGlobalAttribute[] EMPTY_SCHEMAATTRIBUTE_ARRAY = new SchemaGlobalAttribute[0];
    public static final SchemaGlobalElement[] EMPTY_SCHEMAELEMENT_ARRAY = new SchemaGlobalElement[0];
    public static final SchemaModelGroup[] EMPTY_SCHEMAMODELGROUP_ARRAY = new SchemaModelGroup[0];
    public static final SchemaType.Ref[] EMPTY_SCHEMATYPEREF_ARRAY = new SchemaType.Ref[0];
    public static final SchemaType[] EMPTY_SCHEMATYPE_ARRAY = new SchemaType[0];
    public static final XmlValueRef[] FACETS_BUILTIN_LIST = {null, buildNnInteger(BigInteger.ONE), null, null, null, null, null, null, null, build_wsstring(3), null, null};
    public static final XmlValueRef[] FACETS_BYTE = {null, null, null, null, buildInteger(BigInteger.valueOf(-128)), buildInteger(BigInteger.valueOf(127)), null, null, buildNnInteger(BigInteger.ZERO), build_wsstring(3), null, null};
    public static final XmlValueRef[] FACETS_INT = {null, null, null, null, buildInteger(BigInteger.valueOf(-2147483648L)), buildInteger(BigInteger.valueOf(2147483647L)), null, null, buildNnInteger(BigInteger.ZERO), build_wsstring(3), null, null};
    public static final XmlValueRef[] FACETS_INTEGER = {null, null, null, null, null, null, null, null, buildNnInteger(BigInteger.ZERO), build_wsstring(3), null, null};
    public static final XmlValueRef[] FACETS_LIST = FACETS_WS_COLLAPSE;
    public static final XmlValueRef[] FACETS_LONG = {null, null, null, null, buildInteger(BigInteger.valueOf(Long.MIN_VALUE)), buildInteger(BigInteger.valueOf(Long.MAX_VALUE)), null, null, buildNnInteger(BigInteger.ZERO), build_wsstring(3), null, null};
    public static final XmlValueRef[] FACETS_NEGATIVE = {null, null, null, null, null, buildInteger(BigInteger.ONE.negate()), null, null, buildNnInteger(BigInteger.ZERO), build_wsstring(3), null, null};
    public static final XmlValueRef[] FACETS_NONE = {null, null, null, null, null, null, null, null, null, null, null, null};
    public static final XmlValueRef[] FACETS_NONNEGATIVE = {null, null, null, null, buildInteger(BigInteger.ZERO), null, null, null, buildNnInteger(BigInteger.ZERO), build_wsstring(3), null, null};
    public static final XmlValueRef[] FACETS_NONPOSITIVE = {null, null, null, null, null, buildInteger(BigInteger.ZERO), null, null, buildNnInteger(BigInteger.ZERO), build_wsstring(3), null, null};
    public static final XmlValueRef[] FACETS_POSITIVE = {null, null, null, null, buildInteger(BigInteger.ONE), null, null, null, buildNnInteger(BigInteger.ZERO), build_wsstring(3), null, null};
    public static final XmlValueRef[] FACETS_SHORT = {null, null, null, null, buildInteger(BigInteger.valueOf(-32768)), buildInteger(BigInteger.valueOf(32767)), null, null, buildNnInteger(BigInteger.ZERO), build_wsstring(3), null, null};
    public static final XmlValueRef[] FACETS_UNION = FACETS_NONE;
    public static final XmlValueRef[] FACETS_UNSIGNED_BYTE = {null, null, null, null, buildInteger(BigInteger.ZERO), buildInteger(BigInteger.valueOf(255)), null, null, buildNnInteger(BigInteger.ZERO), build_wsstring(3), null, null};
    public static final XmlValueRef[] FACETS_UNSIGNED_INT = {null, null, null, null, buildInteger(BigInteger.ZERO), buildInteger(BigInteger.valueOf(Filetime.UINT_MASK)), null, null, buildNnInteger(BigInteger.ZERO), build_wsstring(3), null, null};
    public static final XmlValueRef[] FACETS_UNSIGNED_LONG = {null, null, null, null, buildInteger(BigInteger.ZERO), buildInteger(new BigInteger("18446744073709551615")), null, null, buildNnInteger(BigInteger.ZERO), build_wsstring(3), null, null};
    public static final XmlValueRef[] FACETS_UNSIGNED_SHORT = {null, null, null, null, buildInteger(BigInteger.ZERO), buildInteger(BigInteger.valueOf(65535)), null, null, buildNnInteger(BigInteger.ZERO), build_wsstring(3), null, null};
    public static final XmlValueRef[] FACETS_WS_COLLAPSE = {null, null, null, null, null, null, null, null, null, build_wsstring(3), null, null};
    public static final XmlValueRef[] FACETS_WS_PRESERVE = {null, null, null, null, null, null, null, null, null, build_wsstring(1), null, null};
    public static final XmlValueRef[] FACETS_WS_REPLACE = {null, null, null, null, null, null, null, null, null, build_wsstring(2), null, null};
    public static final boolean[] FIXED_FACETS_INTEGER = {false, false, false, false, false, false, false, false, true, true, false, false};
    public static final boolean[] FIXED_FACETS_LIST;
    public static final boolean[] FIXED_FACETS_NONE = {false, false, false, false, false, false, false, false, false, false, false, false};
    public static final boolean[] FIXED_FACETS_UNION = FIXED_FACETS_NONE;
    public static final boolean[] FIXED_FACETS_WS;
    public static final SchemaTypeImpl ST_ANY_SIMPLE = _global.getBuiltinType(2);
    public static final SchemaTypeImpl ST_ANY_TYPE;
    public static final SchemaTypeImpl ST_ANY_URI = _global.getBuiltinType(6);
    public static final SchemaTypeImpl ST_BASE_64_BINARY = _global.getBuiltinType(4);
    public static final SchemaTypeImpl ST_BOOLEAN = _global.getBuiltinType(3);
    public static final SchemaTypeImpl ST_BYTE = _global.getBuiltinType(26);
    public static final SchemaTypeImpl ST_DATE = _global.getBuiltinType(16);
    public static final SchemaTypeImpl ST_DATE_TIME = _global.getBuiltinType(14);
    public static final SchemaTypeImpl ST_DECIMAL = _global.getBuiltinType(11);
    public static final SchemaTypeImpl ST_DOUBLE = _global.getBuiltinType(10);
    public static final SchemaTypeImpl ST_DURATION = _global.getBuiltinType(13);
    public static final SchemaTypeImpl ST_ENTITIES = _global.getBuiltinType(44);
    public static final SchemaTypeImpl ST_ENTITY = _global.getBuiltinType(43);
    public static final SchemaTypeImpl ST_FLOAT = _global.getBuiltinType(9);
    public static final SchemaTypeImpl ST_G_DAY = _global.getBuiltinType(20);
    public static final SchemaTypeImpl ST_G_MONTH = _global.getBuiltinType(21);
    public static final SchemaTypeImpl ST_G_MONTH_DAY = _global.getBuiltinType(19);
    public static final SchemaTypeImpl ST_G_YEAR = _global.getBuiltinType(18);
    public static final SchemaTypeImpl ST_G_YEAR_MONTH = _global.getBuiltinType(17);
    public static final SchemaTypeImpl ST_HEX_BINARY = _global.getBuiltinType(5);
    public static final SchemaTypeImpl ST_ID = _global.getBuiltinType(40);
    public static final SchemaTypeImpl ST_IDREF = _global.getBuiltinType(41);
    public static final SchemaTypeImpl ST_IDREFS = _global.getBuiltinType(42);
    public static final SchemaTypeImpl ST_INT = _global.getBuiltinType(24);
    public static final SchemaTypeImpl ST_INTEGER = _global.getBuiltinType(22);
    public static final SchemaTypeImpl ST_LANGUAGE = _global.getBuiltinType(39);
    public static final SchemaTypeImpl ST_LONG = _global.getBuiltinType(23);
    public static final SchemaTypeImpl ST_NAME = _global.getBuiltinType(37);
    public static final SchemaTypeImpl ST_NCNAME = _global.getBuiltinType(38);
    public static final SchemaTypeImpl ST_NEGATIVE_INTEGER = _global.getBuiltinType(28);
    public static final SchemaTypeImpl ST_NMTOKEN = _global.getBuiltinType(45);
    public static final SchemaTypeImpl ST_NMTOKENS = _global.getBuiltinType(46);
    public static final SchemaTypeImpl ST_NON_NEGATIVE_INTEGER = _global.getBuiltinType(29);
    public static final SchemaTypeImpl ST_NON_POSITIVE_INTEGER = _global.getBuiltinType(27);
    public static final SchemaTypeImpl ST_NORMALIZED_STRING = _global.getBuiltinType(35);
    public static final SchemaTypeImpl ST_NOTATION = _global.getBuiltinType(8);
    public static final SchemaTypeImpl ST_NO_TYPE = _global.getBuiltinType(0);
    public static final SchemaTypeImpl ST_POSITIVE_INTEGER = _global.getBuiltinType(30);
    public static final SchemaTypeImpl ST_QNAME = _global.getBuiltinType(7);
    public static final SchemaTypeImpl ST_SHORT = _global.getBuiltinType(25);
    public static final SchemaTypeImpl ST_STRING = _global.getBuiltinType(12);
    public static final SchemaTypeImpl ST_TIME = _global.getBuiltinType(15);
    public static final SchemaTypeImpl ST_TOKEN = _global.getBuiltinType(36);
    public static final SchemaTypeImpl ST_UNSIGNED_BYTE = _global.getBuiltinType(34);
    public static final SchemaTypeImpl ST_UNSIGNED_INT = _global.getBuiltinType(32);
    public static final SchemaTypeImpl ST_UNSIGNED_LONG = _global.getBuiltinType(31);
    public static final SchemaTypeImpl ST_UNSIGNED_SHORT = _global.getBuiltinType(33);
    public static final XmlValueRef XMLSTR_COLLAPSE = buildString(SchemaSymbols.ATTVAL_PRESERVE);
    public static final XmlValueRef XMLSTR_PRESERVE = buildString(SchemaSymbols.ATTVAL_PRESERVE);
    public static final XmlValueRef XMLSTR_REPLACE = buildString(SchemaSymbols.ATTVAL_PRESERVE);
    public static BuiltinSchemaTypeSystem _global;
    public static /* synthetic */ Class class$org$apache$xmlbeans$impl$schema$BuiltinSchemaTypeSystem;
    public SchemaContainer _container;
    public Map _handlesToObjects = new HashMap();
    public Map _objectsToHandles = new HashMap();
    public SchemaTypeImpl[] _typeArray = new SchemaTypeImpl[47];
    public Map _typeMap = new HashMap();
    public Map _typesByClassname = new HashMap();

    static {
        Class cls = class$org$apache$xmlbeans$impl$schema$BuiltinSchemaTypeSystem;
        if (cls == null) {
            cls = class$("org.apache.xmlbeans.impl.schema.BuiltinSchemaTypeSystem");
            class$org$apache$xmlbeans$impl$schema$BuiltinSchemaTypeSystem = cls;
        }
        $assertionsDisabled = !cls.desiredAssertionStatus();
        BuiltinSchemaTypeSystem builtinSchemaTypeSystem = new BuiltinSchemaTypeSystem();
        _global = builtinSchemaTypeSystem;
        ST_ANY_TYPE = builtinSchemaTypeSystem.getBuiltinType(1);
        boolean[] zArr = {false, false, false, false, false, false, false, false, false, true, false, false};
        FIXED_FACETS_WS = zArr;
        FIXED_FACETS_LIST = zArr;
        for (int i2 = 0; i2 <= 46; i2++) {
            _global.fillInType(i2);
        }
    }

    public BuiltinSchemaTypeSystem() {
        SchemaContainer schemaContainer = new SchemaContainer("http://www.w3.org/2001/XMLSchema");
        this._container = schemaContainer;
        schemaContainer.setTypeSystem(this);
        setupBuiltin(1, "anyType", "org.apache.xmlbeans.XmlObject");
        setupBuiltin(2, SchemaSymbols.ATTVAL_ANYSIMPLETYPE, "org.apache.xmlbeans.XmlAnySimpleType");
        setupBuiltin(3, "boolean", "org.apache.xmlbeans.XmlBoolean");
        setupBuiltin(4, "base64Binary", "org.apache.xmlbeans.XmlBase64Binary");
        setupBuiltin(5, "hexBinary", "org.apache.xmlbeans.XmlHexBinary");
        setupBuiltin(6, "anyURI", "org.apache.xmlbeans.XmlAnyURI");
        setupBuiltin(7, "QName", "org.apache.xmlbeans.XmlQName");
        setupBuiltin(8, SchemaSymbols.ATTVAL_NOTATION, "org.apache.xmlbeans.XmlNOTATION");
        setupBuiltin(9, "float", "org.apache.xmlbeans.XmlFloat");
        setupBuiltin(10, "double", "org.apache.xmlbeans.XmlDouble");
        setupBuiltin(11, "decimal", "org.apache.xmlbeans.XmlDecimal");
        setupBuiltin(12, SchemaSymbols.ATTVAL_STRING, "org.apache.xmlbeans.XmlString");
        setupBuiltin(13, "duration", "org.apache.xmlbeans.XmlDuration");
        setupBuiltin(14, SchemaSymbols.ATTVAL_DATETIME, "org.apache.xmlbeans.XmlDateTime");
        setupBuiltin(15, SchemaSymbols.ATTVAL_TIME, "org.apache.xmlbeans.XmlTime");
        setupBuiltin(16, "date", "org.apache.xmlbeans.XmlDate");
        setupBuiltin(17, SchemaSymbols.ATTVAL_YEARMONTH, "org.apache.xmlbeans.XmlGYearMonth");
        setupBuiltin(18, SchemaSymbols.ATTVAL_YEAR, "org.apache.xmlbeans.XmlGYear");
        setupBuiltin(19, SchemaSymbols.ATTVAL_MONTHDAY, "org.apache.xmlbeans.XmlGMonthDay");
        setupBuiltin(20, SchemaSymbols.ATTVAL_DAY, "org.apache.xmlbeans.XmlGDay");
        setupBuiltin(21, SchemaSymbols.ATTVAL_MONTH, "org.apache.xmlbeans.XmlGMonth");
        setupBuiltin(22, "integer", "org.apache.xmlbeans.XmlInteger");
        setupBuiltin(23, "long", "org.apache.xmlbeans.XmlLong");
        setupBuiltin(24, "int", "org.apache.xmlbeans.XmlInt");
        setupBuiltin(25, SchemaSymbols.ATTVAL_SHORT, "org.apache.xmlbeans.XmlShort");
        setupBuiltin(26, SchemaSymbols.ATTVAL_BYTE, "org.apache.xmlbeans.XmlByte");
        setupBuiltin(27, SchemaSymbols.ATTVAL_NONPOSITIVEINTEGER, "org.apache.xmlbeans.XmlNonPositiveInteger");
        setupBuiltin(28, SchemaSymbols.ATTVAL_NEGATIVEINTEGER, "org.apache.xmlbeans.XmlNegativeInteger");
        setupBuiltin(29, SchemaSymbols.ATTVAL_NONNEGATIVEINTEGER, "org.apache.xmlbeans.XmlNonNegativeInteger");
        setupBuiltin(30, SchemaSymbols.ATTVAL_POSITIVEINTEGER, "org.apache.xmlbeans.XmlPositiveInteger");
        setupBuiltin(31, SchemaSymbols.ATTVAL_UNSIGNEDLONG, "org.apache.xmlbeans.XmlUnsignedLong");
        setupBuiltin(32, SchemaSymbols.ATTVAL_UNSIGNEDINT, "org.apache.xmlbeans.XmlUnsignedInt");
        setupBuiltin(33, SchemaSymbols.ATTVAL_UNSIGNEDSHORT, "org.apache.xmlbeans.XmlUnsignedShort");
        setupBuiltin(34, SchemaSymbols.ATTVAL_UNSIGNEDBYTE, "org.apache.xmlbeans.XmlUnsignedByte");
        setupBuiltin(35, SchemaSymbols.ATTVAL_NORMALIZEDSTRING, "org.apache.xmlbeans.XmlNormalizedString");
        setupBuiltin(36, SchemaSymbols.ATTVAL_TOKEN, "org.apache.xmlbeans.XmlToken");
        setupBuiltin(37, SchemaSymbols.ATTVAL_NAME, "org.apache.xmlbeans.XmlName");
        setupBuiltin(38, "NCName", "org.apache.xmlbeans.XmlNCName");
        setupBuiltin(39, "language", "org.apache.xmlbeans.XmlLanguage");
        setupBuiltin(40, SchemaSymbols.ATTVAL_ID, "org.apache.xmlbeans.XmlID");
        setupBuiltin(41, SchemaSymbols.ATTVAL_IDREF, "org.apache.xmlbeans.XmlIDREF");
        setupBuiltin(42, SchemaSymbols.ATTVAL_IDREFS, "org.apache.xmlbeans.XmlIDREFS");
        setupBuiltin(43, SchemaSymbols.ATTVAL_ENTITY, "org.apache.xmlbeans.XmlENTITY");
        setupBuiltin(44, SchemaSymbols.ATTVAL_ENTITIES, "org.apache.xmlbeans.XmlENTITIES");
        setupBuiltin(45, "NMTOKEN", "org.apache.xmlbeans.XmlNMTOKEN");
        setupBuiltin(46, SchemaSymbols.ATTVAL_NMTOKENS, "org.apache.xmlbeans.XmlNMTOKENS");
        setupBuiltin(0, null, null);
        this._container.setImmutable();
    }

    public static XmlValueRef buildInteger(BigInteger bigInteger) {
        if (bigInteger == null) {
            return null;
        }
        try {
            XmlIntegerImpl xmlIntegerImpl = new XmlIntegerImpl();
            xmlIntegerImpl.set(bigInteger);
            xmlIntegerImpl.setImmutable();
            return new XmlValueRef(xmlIntegerImpl);
        } catch (XmlValueOutOfRangeException unused) {
            return null;
        }
    }

    public static XmlValueRef buildNnInteger(BigInteger bigInteger) {
        if (bigInteger == null || bigInteger.signum() < 0) {
            return null;
        }
        try {
            XmlIntegerImpl xmlIntegerImpl = new XmlIntegerImpl();
            xmlIntegerImpl.set(bigInteger);
            xmlIntegerImpl.setImmutable();
            return new XmlValueRef(xmlIntegerImpl);
        } catch (XmlValueOutOfRangeException unused) {
            return null;
        }
    }

    public static XmlValueRef buildString(String str) {
        if (str == null) {
            return null;
        }
        try {
            XmlStringImpl xmlStringImpl = new XmlStringImpl();
            xmlStringImpl.set(str);
            xmlStringImpl.setImmutable();
            return new XmlValueRef(xmlStringImpl);
        } catch (XmlValueOutOfRangeException unused) {
            return null;
        }
    }

    public static XmlValueRef build_wsstring(int i2) {
        if (i2 == 1) {
            return XMLSTR_PRESERVE;
        }
        if (i2 == 2) {
            return XMLSTR_REPLACE;
        }
        if (i2 != 3) {
            return null;
        }
        return XMLSTR_COLLAPSE;
    }

    public static /* synthetic */ Class class$(String str) {
        try {
            return Class.forName(str);
        } catch (ClassNotFoundException e2) {
            throw a.a(e2);
        }
    }

    public static SchemaTypeSystem get() {
        return _global;
    }

    private SchemaTypeImpl getBuiltinType(int i2) {
        return this._typeArray[i2];
    }

    public static SchemaType getNoType() {
        return ST_NO_TYPE;
    }

    private void setupBuiltin(int i2, String str, String str2) {
        QName qName;
        SchemaTypeImpl schemaTypeImpl = new SchemaTypeImpl(this._container, true);
        this._container.addGlobalType(schemaTypeImpl.getRef());
        if (str == null) {
            qName = null;
        } else {
            qName = QNameHelper.forLNS(str, "http://www.w3.org/2001/XMLSchema");
        }
        StringBuffer a = a.a("_BI_");
        if (str == null) {
            str = "NO_TYPE";
        }
        a.append(str);
        String stringBuffer = a.toString();
        schemaTypeImpl.setName(qName);
        schemaTypeImpl.setBuiltinTypeCode(i2);
        if (str2 != null) {
            schemaTypeImpl.setFullJavaName(str2);
        }
        this._typeArray[i2] = schemaTypeImpl;
        this._typeMap.put(qName, schemaTypeImpl);
        this._handlesToObjects.put(stringBuffer, schemaTypeImpl);
        this._objectsToHandles.put(schemaTypeImpl, stringBuffer);
        if (str2 != null) {
            this._typesByClassname.put(str2, schemaTypeImpl);
        }
    }

    @Override // org.apache.xmlbeans.SchemaTypeSystem
    public SchemaAnnotation[] annotations() {
        return EMPTY_SCHEMAANNOTATION_ARRAY;
    }

    @Override // org.apache.xmlbeans.SchemaTypeSystem
    public SchemaAttributeGroup[] attributeGroups() {
        return EMPTY_SCHEMAATTRIBUTEGROUP_ARRAY;
    }

    @Override // org.apache.xmlbeans.SchemaTypeSystem
    public SchemaType[] attributeTypes() {
        return EMPTY_SCHEMATYPE_ARRAY;
    }

    @Override // org.apache.xmlbeans.SchemaTypeSystem
    public SchemaType[] documentTypes() {
        return EMPTY_SCHEMATYPE_ARRAY;
    }

    /* JADX INFO: Can't fix incorrect switch cases order, some code will duplicate */
    /* JADX WARNING: Removed duplicated region for block: B:116:0x01aa  */
    /* JADX WARNING: Removed duplicated region for block: B:117:0x01ad  */
    /* JADX WARNING: Removed duplicated region for block: B:118:0x01b0  */
    /* JADX WARNING: Removed duplicated region for block: B:119:0x01b2  */
    /* JADX WARNING: Removed duplicated region for block: B:120:0x01b5  */
    /* JADX WARNING: Removed duplicated region for block: B:121:0x01b8  */
    /* JADX WARNING: Removed duplicated region for block: B:124:0x01bd A[SYNTHETIC, Splitter:B:124:0x01bd] */
    /* JADX WARNING: Removed duplicated region for block: B:135:0x01da  */
    /* JADX WARNING: Removed duplicated region for block: B:136:0x0222  */
    public void fillInType(int i2) {
        int i3;
        SchemaTypeImpl schemaTypeImpl;
        SchemaTypeImpl schemaTypeImpl2;
        SchemaType.Ref ref;
        int i4;
        SchemaType.Ref ref2;
        int i5;
        int i6;
        boolean[] zArr;
        XmlValueRef[] xmlValueRefArr;
        boolean z;
        boolean z2;
        boolean z3;
        int i7;
        boolean z4;
        String str;
        RegularExpression regularExpression;
        boolean[] zArr2;
        XmlValueRef[] xmlValueRefArr2;
        SchemaTypeImpl builtinType = getBuiltinType(i2);
        switch (i2) {
            case 0:
                schemaTypeImpl2 = ST_ANY_TYPE;
                i3 = 0;
                schemaTypeImpl = null;
                break;
            case 1:
                schemaTypeImpl2 = null;
                i3 = 0;
                schemaTypeImpl = null;
                break;
            case 2:
                schemaTypeImpl2 = ST_ANY_TYPE;
                i3 = 1;
                schemaTypeImpl = null;
                break;
            case 3:
            case 4:
            case 5:
            case 6:
            case 7:
            case 8:
            case 9:
            case 10:
            case 11:
            case 12:
            case 13:
            case 14:
            case 15:
            case 16:
            case 17:
            case 18:
            case 19:
            case 20:
            case 21:
                schemaTypeImpl2 = ST_ANY_SIMPLE;
                i3 = 1;
                schemaTypeImpl = null;
                break;
            case 22:
                schemaTypeImpl2 = ST_DECIMAL;
                i3 = 1;
                schemaTypeImpl = null;
                break;
            case 23:
                schemaTypeImpl2 = ST_INTEGER;
                i3 = 1;
                schemaTypeImpl = null;
                break;
            case 24:
                schemaTypeImpl2 = ST_LONG;
                i3 = 1;
                schemaTypeImpl = null;
                break;
            case 25:
                schemaTypeImpl2 = ST_INT;
                i3 = 1;
                schemaTypeImpl = null;
                break;
            case 26:
                schemaTypeImpl2 = ST_SHORT;
                i3 = 1;
                schemaTypeImpl = null;
                break;
            case 27:
                schemaTypeImpl2 = ST_INTEGER;
                i3 = 1;
                schemaTypeImpl = null;
                break;
            case 28:
                schemaTypeImpl2 = ST_NON_POSITIVE_INTEGER;
                i3 = 1;
                schemaTypeImpl = null;
                break;
            case 29:
                schemaTypeImpl2 = ST_INTEGER;
                i3 = 1;
                schemaTypeImpl = null;
                break;
            case 30:
                schemaTypeImpl2 = ST_NON_NEGATIVE_INTEGER;
                i3 = 1;
                schemaTypeImpl = null;
                break;
            case 31:
                schemaTypeImpl2 = ST_NON_NEGATIVE_INTEGER;
                i3 = 1;
                schemaTypeImpl = null;
                break;
            case 32:
                schemaTypeImpl2 = ST_UNSIGNED_LONG;
                i3 = 1;
                schemaTypeImpl = null;
                break;
            case 33:
                schemaTypeImpl2 = ST_UNSIGNED_INT;
                i3 = 1;
                schemaTypeImpl = null;
                break;
            case 34:
                schemaTypeImpl2 = ST_UNSIGNED_SHORT;
                i3 = 1;
                schemaTypeImpl = null;
                break;
            case 35:
                schemaTypeImpl2 = ST_STRING;
                i3 = 1;
                schemaTypeImpl = null;
                break;
            case 36:
                schemaTypeImpl2 = ST_NORMALIZED_STRING;
                i3 = 1;
                schemaTypeImpl = null;
                break;
            case 37:
                schemaTypeImpl2 = ST_TOKEN;
                i3 = 1;
                schemaTypeImpl = null;
                break;
            case 38:
                schemaTypeImpl2 = ST_NAME;
                i3 = 1;
                schemaTypeImpl = null;
                break;
            case 39:
            case 45:
                schemaTypeImpl2 = ST_TOKEN;
                i3 = 1;
                schemaTypeImpl = null;
                break;
            case 40:
            case 41:
            case 43:
                schemaTypeImpl2 = ST_NCNAME;
                i3 = 1;
                schemaTypeImpl = null;
                break;
            case 42:
            case 44:
            case 46:
                schemaTypeImpl2 = ST_ANY_SIMPLE;
                if (i2 == 42) {
                    schemaTypeImpl = ST_IDREF;
                } else if (i2 == 44) {
                    schemaTypeImpl = ST_ENTITY;
                } else {
                    schemaTypeImpl = ST_NMTOKEN;
                }
                i3 = 3;
                break;
            default:
                if (!$assertionsDisabled) {
                    throw new AssertionError();
                }
                schemaTypeImpl2 = ST_ANY_TYPE;
                i3 = 1;
                schemaTypeImpl = null;
                break;
        }
        builtinType.setDerivationType(1);
        builtinType.setSimpleTypeVariety(i3);
        if (i3 != 0) {
            builtinType.setSimpleType(true);
        } else if (!($assertionsDisabled || i2 == 1 || i2 == 0)) {
            throw new AssertionError();
        }
        if (schemaTypeImpl2 == null) {
            ref = null;
        } else {
            ref = schemaTypeImpl2.getRef();
        }
        builtinType.setBaseTypeRef(ref);
        if (schemaTypeImpl2 == null) {
            i4 = 0;
        } else {
            i4 = schemaTypeImpl2.getBaseDepth() + 1;
        }
        builtinType.setBaseDepth(i4);
        if (schemaTypeImpl == null) {
            ref2 = null;
        } else {
            ref2 = schemaTypeImpl.getRef();
        }
        builtinType.setListItemTypeRef(ref2);
        if (i2 >= 2 && i2 <= 21) {
            builtinType.setPrimitiveTypeRef(builtinType.getRef());
        } else if (i3 == 1) {
            if (schemaTypeImpl2 == null) {
                throw new IllegalStateException(a.b("Base was null for ", i2));
            } else if (schemaTypeImpl2.getPrimitiveType() != null) {
                builtinType.setPrimitiveTypeRef(schemaTypeImpl2.getPrimitiveType().getRef());
            } else {
                throw new IllegalStateException(a.b("Base.gpt was null for ", i2));
            }
        }
        switch (i2) {
            case 0:
            case 1:
            case 2:
                xmlValueRefArr = FACETS_NONE;
                zArr = FIXED_FACETS_NONE;
                i6 = 0;
                i5 = 0;
                break;
            case 3:
            case 4:
            case 5:
            case 6:
            case 7:
            case 8:
            case 9:
            case 10:
            case 13:
            case 14:
            case 15:
            case 16:
            case 17:
            case 18:
            case 19:
            case 20:
            case 21:
                xmlValueRefArr = FACETS_WS_COLLAPSE;
                zArr = FIXED_FACETS_WS;
                i6 = 3;
                i5 = 0;
                break;
            case 11:
                xmlValueRefArr = FACETS_WS_COLLAPSE;
                zArr = FIXED_FACETS_WS;
                i6 = 3;
                i5 = SchemaType.SIZE_BIG_DECIMAL;
                break;
            case 12:
                xmlValueRefArr = FACETS_WS_PRESERVE;
                zArr = FIXED_FACETS_NONE;
                i6 = 1;
                i5 = 0;
                break;
            case 22:
                xmlValueRefArr2 = FACETS_INTEGER;
                zArr2 = FIXED_FACETS_INTEGER;
                xmlValueRefArr = xmlValueRefArr2;
                zArr = zArr2;
                i6 = 3;
                i5 = 1000000;
                break;
            case 23:
                xmlValueRefArr = FACETS_LONG;
                zArr = FIXED_FACETS_INTEGER;
                i6 = 3;
                i5 = 64;
                break;
            case 24:
                xmlValueRefArr = FACETS_INT;
                zArr = FIXED_FACETS_INTEGER;
                i6 = 3;
                i5 = 32;
                break;
            case 25:
                xmlValueRefArr = FACETS_SHORT;
                zArr = FIXED_FACETS_INTEGER;
                i6 = 3;
                i5 = 16;
                break;
            case 26:
                xmlValueRefArr = FACETS_BYTE;
                zArr = FIXED_FACETS_INTEGER;
                i6 = 3;
                i5 = 8;
                break;
            case 27:
                xmlValueRefArr2 = FACETS_NONPOSITIVE;
                zArr2 = FIXED_FACETS_INTEGER;
                xmlValueRefArr = xmlValueRefArr2;
                zArr = zArr2;
                i6 = 3;
                i5 = 1000000;
                break;
            case 28:
                xmlValueRefArr2 = FACETS_NEGATIVE;
                zArr2 = FIXED_FACETS_INTEGER;
                xmlValueRefArr = xmlValueRefArr2;
                zArr = zArr2;
                i6 = 3;
                i5 = 1000000;
                break;
            case 29:
                xmlValueRefArr2 = FACETS_NONNEGATIVE;
                zArr2 = FIXED_FACETS_INTEGER;
                xmlValueRefArr = xmlValueRefArr2;
                zArr = zArr2;
                i6 = 3;
                i5 = 1000000;
                break;
            case 30:
                xmlValueRefArr2 = FACETS_POSITIVE;
                zArr2 = FIXED_FACETS_INTEGER;
                xmlValueRefArr = xmlValueRefArr2;
                zArr = zArr2;
                i6 = 3;
                i5 = 1000000;
                break;
            case 31:
                xmlValueRefArr2 = FACETS_UNSIGNED_LONG;
                zArr2 = FIXED_FACETS_INTEGER;
                xmlValueRefArr = xmlValueRefArr2;
                zArr = zArr2;
                i6 = 3;
                i5 = 1000000;
                break;
            case 32:
                xmlValueRefArr = FACETS_UNSIGNED_INT;
                zArr = FIXED_FACETS_INTEGER;
                i6 = 3;
                i5 = 64;
                break;
            case 33:
                xmlValueRefArr = FACETS_UNSIGNED_SHORT;
                zArr = FIXED_FACETS_INTEGER;
                i6 = 3;
                i5 = 32;
                break;
            case 34:
                xmlValueRefArr = FACETS_UNSIGNED_BYTE;
                zArr = FIXED_FACETS_INTEGER;
                i6 = 3;
                i5 = 16;
                break;
            case 35:
                xmlValueRefArr = FACETS_WS_REPLACE;
                zArr = FIXED_FACETS_NONE;
                i6 = 2;
                i5 = 0;
                break;
            case 36:
            case 37:
            case 38:
            case 39:
            case 40:
            case 41:
            case 42:
            case 43:
            case 45:
                xmlValueRefArr = FACETS_WS_COLLAPSE;
                zArr = FIXED_FACETS_NONE;
                i6 = 3;
                i5 = 0;
                break;
            case 44:
            case 46:
                xmlValueRefArr = FACETS_BUILTIN_LIST;
                zArr = FIXED_FACETS_NONE;
                i6 = 0;
                i5 = 0;
                break;
            default:
                if (!$assertionsDisabled) {
                    throw new AssertionError();
                }
                xmlValueRefArr = FACETS_NONE;
                zArr = FIXED_FACETS_NONE;
                i6 = 0;
                i5 = 0;
                break;
        }
        switch (i2) {
            case 0:
            case 1:
            case 2:
            case 4:
            case 5:
            case 6:
            case 7:
            case 8:
            case 12:
            case 35:
            case 36:
            case 37:
            case 38:
            case 39:
            case 40:
            case 41:
            case 42:
            case 43:
            case 44:
            case 45:
            case 46:
                i7 = 0;
                z3 = false;
                z2 = false;
                z = false;
                builtinType.setBasicFacets(xmlValueRefArr, zArr);
                builtinType.setWhiteSpaceRule(i6);
                builtinType.setOrdered(i7);
                builtinType.setBounded(z3);
                builtinType.setNumeric(z2);
                builtinType.setFinite(z);
                builtinType.setDecimalSize(i5);
                builtinType.setAnonymousTypeRefs(EMPTY_SCHEMATYPEREF_ARRAY);
                switch (i2) {
                    case 37:
                        str = "\\i\\c*";
                        z4 = true;
                        break;
                    case 38:
                        str = "[\\i-[:]][\\c-[:]]*";
                        z4 = true;
                        break;
                    case 39:
                        str = "[a-zA-Z]{1,8}(-[a-zA-Z0-9]{1,8})*";
                        z4 = true;
                        break;
                    case 40:
                    case 41:
                    case 43:
                        str = null;
                        z4 = true;
                        break;
                    case 42:
                    case 44:
                    default:
                        z4 = false;
                        str = null;
                        break;
                    case 45:
                        str = "\\c+";
                        z4 = true;
                        break;
                }
                if (str != null) {
                    try {
                        regularExpression = SchemaRegularExpression.forPattern(str);
                    } catch (ParseException unused) {
                        if ($assertionsDisabled) {
                            regularExpression = null;
                        } else {
                            throw new AssertionError();
                        }
                    }
                    builtinType.setPatterns(new RegularExpression[]{regularExpression});
                }
                builtinType.setPatternFacet(z4);
                if (i2 != 1) {
                    SchemaParticleImpl schemaParticleImpl = new SchemaParticleImpl();
                    schemaParticleImpl.setParticleType(5);
                    schemaParticleImpl.setWildcardSet(QNameSet.ALL);
                    schemaParticleImpl.setWildcardProcess(2);
                    schemaParticleImpl.setMinOccurs(BigInteger.ZERO);
                    schemaParticleImpl.setMaxOccurs(null);
                    schemaParticleImpl.setTransitionRules(QNameSet.ALL, true);
                    schemaParticleImpl.setTransitionNotes(QNameSet.ALL, true);
                    SchemaAttributeModelImpl schemaAttributeModelImpl = new SchemaAttributeModelImpl();
                    schemaAttributeModelImpl.setWildcardProcess(2);
                    schemaAttributeModelImpl.setWildcardSet(QNameSet.ALL);
                    builtinType.setComplexTypeVariety(4);
                    Map map = Collections.EMPTY_MAP;
                    builtinType.setContentModel(schemaParticleImpl, schemaAttributeModelImpl, map, map, false);
                    builtinType.setAnonymousTypeRefs(EMPTY_SCHEMATYPEREF_ARRAY);
                    QNameSet qNameSet = QNameSet.ALL;
                    builtinType.setWildcardSummary(qNameSet, true, qNameSet, true);
                } else if (i2 == 0) {
                    SchemaAttributeModelImpl schemaAttributeModelImpl2 = new SchemaAttributeModelImpl();
                    builtinType.setComplexTypeVariety(1);
                    Map map2 = Collections.EMPTY_MAP;
                    builtinType.setContentModel(null, schemaAttributeModelImpl2, map2, map2, false);
                    builtinType.setAnonymousTypeRefs(EMPTY_SCHEMATYPEREF_ARRAY);
                    QNameSet qNameSet2 = QNameSet.EMPTY;
                    builtinType.setWildcardSummary(qNameSet2, false, qNameSet2, false);
                }
                builtinType.setOrderSensitive(false);
                return;
            case 3:
                i7 = 0;
                z3 = false;
                z2 = false;
                z = true;
                builtinType.setBasicFacets(xmlValueRefArr, zArr);
                builtinType.setWhiteSpaceRule(i6);
                builtinType.setOrdered(i7);
                builtinType.setBounded(z3);
                builtinType.setNumeric(z2);
                builtinType.setFinite(z);
                builtinType.setDecimalSize(i5);
                builtinType.setAnonymousTypeRefs(EMPTY_SCHEMATYPEREF_ARRAY);
                switch (i2) {
                }
                if (str != null) {
                }
                builtinType.setPatternFacet(z4);
                if (i2 != 1) {
                }
                builtinType.setOrderSensitive(false);
                return;
            case 9:
            case 10:
            case 11:
            case 22:
                i7 = 2;
                z3 = false;
                z2 = true;
                z = false;
                builtinType.setBasicFacets(xmlValueRefArr, zArr);
                builtinType.setWhiteSpaceRule(i6);
                builtinType.setOrdered(i7);
                builtinType.setBounded(z3);
                builtinType.setNumeric(z2);
                builtinType.setFinite(z);
                builtinType.setDecimalSize(i5);
                builtinType.setAnonymousTypeRefs(EMPTY_SCHEMATYPEREF_ARRAY);
                switch (i2) {
                }
                if (str != null) {
                }
                builtinType.setPatternFacet(z4);
                if (i2 != 1) {
                }
                builtinType.setOrderSensitive(false);
                return;
            case 13:
            case 14:
            case 15:
            case 16:
            case 17:
            case 18:
            case 19:
            case 20:
            case 21:
                i7 = 1;
                z3 = false;
                z2 = false;
                z = false;
                builtinType.setBasicFacets(xmlValueRefArr, zArr);
                builtinType.setWhiteSpaceRule(i6);
                builtinType.setOrdered(i7);
                builtinType.setBounded(z3);
                builtinType.setNumeric(z2);
                builtinType.setFinite(z);
                builtinType.setDecimalSize(i5);
                builtinType.setAnonymousTypeRefs(EMPTY_SCHEMATYPEREF_ARRAY);
                switch (i2) {
                }
                if (str != null) {
                }
                builtinType.setPatternFacet(z4);
                if (i2 != 1) {
                }
                builtinType.setOrderSensitive(false);
                return;
            case 23:
            case 24:
            case 25:
            case 26:
            case 27:
            case 28:
            case 29:
            case 30:
            case 31:
            case 32:
            case 33:
            case 34:
                i7 = 2;
                z3 = true;
                z2 = true;
                z = true;
                builtinType.setBasicFacets(xmlValueRefArr, zArr);
                builtinType.setWhiteSpaceRule(i6);
                builtinType.setOrdered(i7);
                builtinType.setBounded(z3);
                builtinType.setNumeric(z2);
                builtinType.setFinite(z);
                builtinType.setDecimalSize(i5);
                builtinType.setAnonymousTypeRefs(EMPTY_SCHEMATYPEREF_ARRAY);
                switch (i2) {
                }
                if (str != null) {
                }
                builtinType.setPatternFacet(z4);
                if (i2 != 1) {
                }
                builtinType.setOrderSensitive(false);
                return;
            default:
                if (!$assertionsDisabled) {
                    throw new AssertionError();
                }
                i7 = 0;
                z3 = false;
                z2 = false;
                z = false;
                builtinType.setBasicFacets(xmlValueRefArr, zArr);
                builtinType.setWhiteSpaceRule(i6);
                builtinType.setOrdered(i7);
                builtinType.setBounded(z3);
                builtinType.setNumeric(z2);
                builtinType.setFinite(z);
                builtinType.setDecimalSize(i5);
                builtinType.setAnonymousTypeRefs(EMPTY_SCHEMATYPEREF_ARRAY);
                switch (i2) {
                }
                if (str != null) {
                }
                builtinType.setPatternFacet(z4);
                if (i2 != 1) {
                }
                builtinType.setOrderSensitive(false);
                return;
        }
    }

    @Override // org.apache.xmlbeans.impl.schema.SchemaTypeLoaderBase, org.apache.xmlbeans.SchemaTypeLoader
    public SchemaGlobalAttribute findAttribute(QName qName) {
        return null;
    }

    @Override // org.apache.xmlbeans.SchemaTypeLoader
    public SchemaAttributeGroup.Ref findAttributeGroupRef(QName qName) {
        return null;
    }

    @Override // org.apache.xmlbeans.SchemaTypeLoader
    public SchemaGlobalAttribute.Ref findAttributeRef(QName qName) {
        return null;
    }

    @Override // org.apache.xmlbeans.impl.schema.SchemaTypeLoaderBase, org.apache.xmlbeans.SchemaTypeLoader
    public SchemaType findAttributeType(QName qName) {
        return null;
    }

    @Override // org.apache.xmlbeans.SchemaTypeLoader
    public SchemaType.Ref findAttributeTypeRef(QName qName) {
        return null;
    }

    @Override // org.apache.xmlbeans.impl.schema.SchemaTypeLoaderBase, org.apache.xmlbeans.SchemaTypeLoader
    public SchemaType findDocumentType(QName qName) {
        return null;
    }

    @Override // org.apache.xmlbeans.SchemaTypeLoader
    public SchemaType.Ref findDocumentTypeRef(QName qName) {
        return null;
    }

    @Override // org.apache.xmlbeans.impl.schema.SchemaTypeLoaderBase, org.apache.xmlbeans.SchemaTypeLoader
    public SchemaGlobalElement findElement(QName qName) {
        return null;
    }

    @Override // org.apache.xmlbeans.SchemaTypeLoader
    public SchemaGlobalElement.Ref findElementRef(QName qName) {
        return null;
    }

    @Override // org.apache.xmlbeans.SchemaTypeLoader
    public SchemaIdentityConstraint.Ref findIdentityConstraintRef(QName qName) {
        return null;
    }

    @Override // org.apache.xmlbeans.SchemaTypeLoader
    public SchemaModelGroup.Ref findModelGroupRef(QName qName) {
        return null;
    }

    @Override // org.apache.xmlbeans.impl.schema.SchemaTypeLoaderBase, org.apache.xmlbeans.SchemaTypeLoader
    public SchemaType findType(QName qName) {
        return (SchemaType) this._typeMap.get(qName);
    }

    @Override // org.apache.xmlbeans.SchemaTypeLoader
    public SchemaType.Ref findTypeRef(QName qName) {
        SchemaType findType = findType(qName);
        if (findType == null) {
            return null;
        }
        return findType.getRef();
    }

    @Override // org.apache.xmlbeans.SchemaTypeSystem
    public ClassLoader getClassLoader() {
        Class cls = class$org$apache$xmlbeans$impl$schema$BuiltinSchemaTypeSystem;
        if (cls == null) {
            cls = class$("org.apache.xmlbeans.impl.schema.BuiltinSchemaTypeSystem");
            class$org$apache$xmlbeans$impl$schema$BuiltinSchemaTypeSystem = cls;
        }
        return cls.getClassLoader();
    }

    @Override // org.apache.xmlbeans.SchemaTypeSystem
    public String getName() {
        return "schema.typesystem.builtin";
    }

    @Override // org.apache.xmlbeans.SchemaTypeLoader
    public InputStream getSourceAsStream(String str) {
        return null;
    }

    @Override // org.apache.xmlbeans.SchemaTypeSystem
    public SchemaGlobalAttribute[] globalAttributes() {
        return EMPTY_SCHEMAATTRIBUTE_ARRAY;
    }

    @Override // org.apache.xmlbeans.SchemaTypeSystem
    public SchemaGlobalElement[] globalElements() {
        return EMPTY_SCHEMAELEMENT_ARRAY;
    }

    @Override // org.apache.xmlbeans.SchemaTypeSystem
    public SchemaType[] globalTypes() {
        SchemaTypeImpl[] schemaTypeImplArr = this._typeArray;
        int length = schemaTypeImplArr.length - 1;
        SchemaType[] schemaTypeArr = new SchemaType[length];
        System.arraycopy(schemaTypeImplArr, 1, schemaTypeArr, 0, length);
        return schemaTypeArr;
    }

    public String handleForType(SchemaType schemaType) {
        return (String) this._objectsToHandles.get(schemaType);
    }

    @Override // org.apache.xmlbeans.SchemaTypeLoader
    public boolean isNamespaceDefined(String str) {
        return str.equals("http://www.w3.org/2001/XMLSchema");
    }

    @Override // org.apache.xmlbeans.SchemaTypeSystem
    public SchemaModelGroup[] modelGroups() {
        return EMPTY_SCHEMAMODELGROUP_ARRAY;
    }

    @Override // org.apache.xmlbeans.SchemaTypeSystem
    public void resolve() {
    }

    @Override // org.apache.xmlbeans.SchemaTypeSystem
    public SchemaComponent resolveHandle(String str) {
        return (SchemaComponent) this._handlesToObjects.get(str);
    }

    @Override // org.apache.xmlbeans.SchemaTypeSystem
    public void save(Filer filer) {
        throw new UnsupportedOperationException("The builtin schema type system cannot be saved.");
    }

    @Override // org.apache.xmlbeans.SchemaTypeSystem
    public void saveToDirectory(File file) {
        throw new UnsupportedOperationException("The builtin schema type system cannot be saved.");
    }

    @Override // org.apache.xmlbeans.SchemaTypeLoader
    public SchemaType typeForClassname(String str) {
        return (SchemaType) this._typesByClassname.get(str);
    }

    @Override // org.apache.xmlbeans.SchemaTypeSystem
    public SchemaType typeForHandle(String str) {
        return (SchemaType) this._handlesToObjects.get(str);
    }
}
