package org.apache.xmlbeans.impl.schema;

import b.b.a.a.a;
import java.io.Writer;
import java.nio.charset.CharacterCodingException;
import java.nio.charset.Charset;
import java.nio.charset.CharsetEncoder;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.HashSet;
import java.util.LinkedHashMap;
import java.util.Map;
import org.apache.lucene.codecs.lucene3x.Lucene3xNormsProducer;
import org.apache.poi.javax.xml.namespace.QName;
import org.apache.poi.ss.formula.functions.Complex;
import org.apache.poi.ss.formula.ptg.GreaterThanPtg;
import org.apache.poi.ss.formula.ptg.StringPtg;
import org.apache.xerces.impl.xs.SchemaSymbols;
import org.apache.xmlbeans.InterfaceExtension;
import org.apache.xmlbeans.PrePostExtension;
import org.apache.xmlbeans.SchemaCodePrinter;
import org.apache.xmlbeans.SchemaProperty;
import org.apache.xmlbeans.SchemaStringEnumEntry;
import org.apache.xmlbeans.SchemaType;
import org.apache.xmlbeans.SchemaTypeSystem;
import org.apache.xmlbeans.SystemProperties;
import org.apache.xmlbeans.XmlObject;
import org.apache.xmlbeans.XmlOptions;
import org.apache.xmlbeans.impl.common.NameUtil;
import org.apache.xmlbeans.impl.jam.internal.elements.VoidClassImpl;

public final class SchemaTypeCodePrinter implements SchemaCodePrinter {
    public static final /* synthetic */ boolean $assertionsDisabled;
    public static final int ADD_NEW_VALUE = 3;
    public static final int INDENT_INCREMENT = 4;
    public static final String INDEX_CLASSNAME = "TypeSystemHolder";
    public static final String LINE_SEPARATOR = (SystemProperties.getProperty("line.separator") == null ? "\n" : SystemProperties.getProperty("line.separator"));
    public static final String MAX_SPACES = "                                        ";
    public static final int NOTHING = 1;
    public static final int THROW_EXCEPTION = 4;
    public static /* synthetic */ Class class$org$apache$xmlbeans$impl$schema$SchemaTypeCodePrinter;
    public int _indent = 0;
    public boolean _useJava15;
    public Writer _writer;

    static {
        Class cls = class$org$apache$xmlbeans$impl$schema$SchemaTypeCodePrinter;
        if (cls == null) {
            cls = class$("org.apache.xmlbeans.impl.schema.SchemaTypeCodePrinter");
            class$org$apache$xmlbeans$impl$schema$SchemaTypeCodePrinter = cls;
        }
        $assertionsDisabled = !cls.desiredAssertionStatus();
    }

    public SchemaTypeCodePrinter(XmlOptions xmlOptions) {
        String str = (xmlOptions == null || !XmlOptions.hasOption(xmlOptions, XmlOptions.GENERATE_JAVA_VERSION)) ? null : (String) xmlOptions.get(XmlOptions.GENERATE_JAVA_VERSION);
        this._useJava15 = XmlOptions.GENERATE_JAVA_15.equals(str == null ? XmlOptions.GENERATE_JAVA_14 : str);
    }

    public static /* synthetic */ Class class$(String str) {
        try {
            return Class.forName(str);
        } catch (ClassNotFoundException e2) {
            throw a.a(e2);
        }
    }

    private void emitSpecializedAccessors(SchemaType schemaType) {
        int decimalSize;
        if (schemaType.getSimpleVariety() == 1 && schemaType.getPrimitiveType().getBuiltinTypeCode() == 11 && ((decimalSize = schemaType.getDecimalSize()) != schemaType.getBaseType().getDecimalSize() || schemaType.getBaseType().getFullJavaName() == null)) {
            if (decimalSize == 1000000) {
                a.a(this, "java.math.BigInteger getBigIntegerValue();", "void setBigIntegerValue(java.math.BigInteger bi);", "/** @deprecated */");
                if (this._useJava15) {
                    emit("@Deprecated");
                }
                emit("java.math.BigInteger bigIntegerValue();");
                emit("/** @deprecated */");
                if (this._useJava15) {
                    emit("@Deprecated");
                }
                emit("void set(java.math.BigInteger bi);");
            } else if (decimalSize == 64) {
                a.a(this, "long getLongValue();", "void setLongValue(long l);", "/** @deprecated */");
                if (this._useJava15) {
                    emit("@Deprecated");
                }
                emit("long longValue();");
                emit("/** @deprecated */");
                if (this._useJava15) {
                    emit("@Deprecated");
                }
                emit("void set(long l);");
            } else if (decimalSize == 32) {
                a.a(this, "int getIntValue();", "void setIntValue(int i);", "/** @deprecated */");
                if (this._useJava15) {
                    emit("@Deprecated");
                }
                emit("int intValue();");
                emit("/** @deprecated */");
                if (this._useJava15) {
                    emit("@Deprecated");
                }
                emit("void set(int i);");
            } else if (decimalSize == 16) {
                a.a(this, "short getShortValue();", "void setShortValue(short s);", "/** @deprecated */");
                if (this._useJava15) {
                    emit("@Deprecated");
                }
                emit("short shortValue();");
                emit("/** @deprecated */");
                if (this._useJava15) {
                    emit("@Deprecated");
                }
                emit("void set(short s);");
            } else if (decimalSize == 8) {
                a.a(this, "byte getByteValue();", "void setByteValue(byte b);", "/** @deprecated */");
                if (this._useJava15) {
                    emit("@Deprecated");
                }
                emit("byte byteValue();");
                emit("/** @deprecated */");
                if (this._useJava15) {
                    emit("@Deprecated");
                }
                emit("void set(byte b);");
            }
        }
        if (schemaType.getSimpleVariety() == 2) {
            a.a(this, "java.lang.Object getObjectValue();", "void setObjectValue(java.lang.Object val);", "/** @deprecated */");
            if (this._useJava15) {
                emit("@Deprecated");
            }
            emit("java.lang.Object objectValue();");
            emit("/** @deprecated */");
            if (this._useJava15) {
                emit("@Deprecated");
            }
            emit("void objectSet(java.lang.Object val);");
            emit("org.apache.xmlbeans.SchemaType instanceType();");
            SchemaType unionCommonBaseType = schemaType.getUnionCommonBaseType();
            if (unionCommonBaseType != null) {
                unionCommonBaseType.getSimpleVariety();
            }
            emitSpecializedAccessors(unionCommonBaseType);
        }
        if (schemaType.getSimpleVariety() == 3) {
            emit("java.util.List getListValue();");
            emit("java.util.List xgetListValue();");
            emit("void setListValue(java.util.List list);");
            emit("/** @deprecated */");
            if (this._useJava15) {
                emit("@Deprecated");
            }
            emit("java.util.List listValue();");
            emit("/** @deprecated */");
            if (this._useJava15) {
                emit("@Deprecated");
            }
            emit("java.util.List xlistValue();");
            emit("/** @deprecated */");
            if (this._useJava15) {
                emit("@Deprecated");
            }
            emit("void set(java.util.List list);");
        }
    }

    public static SchemaType findBaseType(SchemaType schemaType) {
        while (schemaType.getFullJavaName() == null) {
            schemaType = schemaType.getBaseType();
        }
        return schemaType;
    }

    private SchemaProperty[] getDerivedProperties(SchemaType schemaType) {
        QName name = schemaType.getName();
        if (name == null || !name.equals(schemaType.getBaseType().getName())) {
            return schemaType.getDerivedProperties();
        }
        SchemaType baseType = schemaType.getBaseType();
        SchemaProperty[] derivedProperties = schemaType.getDerivedProperties();
        LinkedHashMap linkedHashMap = new LinkedHashMap();
        for (int i2 = 0; i2 < derivedProperties.length; i2++) {
            linkedHashMap.put(derivedProperties[i2].getName(), derivedProperties[i2]);
        }
        while (baseType != null && name.equals(baseType.getName())) {
            SchemaProperty[] derivedProperties2 = baseType.getDerivedProperties();
            for (int i3 = 0; i3 < derivedProperties2.length; i3++) {
                if (!linkedHashMap.containsKey(derivedProperties2[i3].getName())) {
                    linkedHashMap.put(derivedProperties2[i3].getName(), derivedProperties2[i3]);
                }
            }
            baseType = baseType.getBaseType();
        }
        return (SchemaProperty[]) linkedHashMap.values().toArray(new SchemaProperty[0]);
    }

    public static String getExtensionInterfaces(SchemaType schemaType) {
        SchemaTypeImpl impl = getImpl(schemaType);
        if (impl == null) {
            return "";
        }
        StringBuffer stringBuffer = new StringBuffer();
        InterfaceExtension[] interfaceExtensions = impl.getInterfaceExtensions();
        if (interfaceExtensions != null) {
            for (InterfaceExtension interfaceExtension : interfaceExtensions) {
                StringBuffer a = a.a(", ");
                a.append(interfaceExtension.getInterface());
                stringBuffer.append(a.toString());
            }
        }
        return stringBuffer.toString();
    }

    private String getFullJavaName(SchemaType schemaType) {
        SchemaTypeImpl schemaTypeImpl = (SchemaTypeImpl) schemaType;
        String fullJavaName = schemaTypeImpl.getFullJavaName();
        while (schemaTypeImpl.isRedefinition()) {
            fullJavaName = schemaTypeImpl.getFullJavaName();
            schemaTypeImpl = (SchemaTypeImpl) schemaTypeImpl.getBaseType();
        }
        return fullJavaName;
    }

    public static SchemaTypeImpl getImpl(SchemaType schemaType) {
        if (schemaType instanceof SchemaTypeImpl) {
            return (SchemaTypeImpl) schemaType;
        }
        return null;
    }

    public static SchemaCodePrinter getPrinter(XmlOptions xmlOptions) {
        Object safeGet = XmlOptions.safeGet(xmlOptions, XmlOptions.SCHEMA_CODE_PRINTER);
        if (safeGet == null || !(safeGet instanceof SchemaCodePrinter)) {
            safeGet = new SchemaTypeCodePrinter(xmlOptions);
        }
        return (SchemaCodePrinter) safeGet;
    }

    public static void getTypeName(Class cls, StringBuffer stringBuffer) {
        int i2 = 0;
        while (cls.isArray()) {
            cls = cls.getComponentType();
            i2++;
        }
        stringBuffer.append(cls.getName());
        for (int i3 = 0; i3 < i2; i3++) {
            stringBuffer.append("[]");
        }
    }

    private String getUserTypeStaticHandlerMethod(boolean z, SchemaTypeImpl schemaTypeImpl) {
        String str;
        String localPart = schemaTypeImpl.getName().getLocalPart();
        if (localPart.length() < 2) {
            str = localPart.toUpperCase();
        } else {
            StringBuffer stringBuffer = new StringBuffer();
            stringBuffer.append(localPart.substring(0, 1).toUpperCase());
            stringBuffer.append(localPart.substring(1));
            str = stringBuffer.toString();
        }
        if (z) {
            StringBuffer stringBuffer2 = new StringBuffer();
            stringBuffer2.append(schemaTypeImpl.getUserTypeHandlerName());
            stringBuffer2.append(".encode");
            stringBuffer2.append(str);
            return stringBuffer2.toString();
        }
        StringBuffer stringBuffer3 = new StringBuffer();
        stringBuffer3.append(schemaTypeImpl.getUserTypeHandlerName());
        stringBuffer3.append(".decode");
        stringBuffer3.append(str);
        return stringBuffer3.toString();
    }

    private boolean hasBase(SchemaType schemaType) {
        SchemaType baseEnumType = schemaType.getBaseEnumType();
        if (!baseEnumType.isAnonymousType() || !baseEnumType.isSkippedAnonymousType()) {
            if (baseEnumType != schemaType) {
                return true;
            }
        } else if (schemaType.getContentBasedOnType() != null) {
            if (schemaType.getContentBasedOnType().getBaseType() != baseEnumType) {
                return true;
            }
        } else if (schemaType.getBaseType() != baseEnumType) {
            return true;
        }
        return false;
    }

    public static String indexClassForSystem(SchemaTypeSystem schemaTypeSystem) {
        return a.a(schemaTypeSystem.getName(), ".", "TypeSystemHolder");
    }

    public static boolean isJavaPrimitive(int i2) {
        return i2 >= 1 && i2 <= 7;
    }

    public static String javaStringEscape(String str) {
        for (int i2 = 0; i2 < str.length(); i2++) {
            char charAt = str.charAt(i2);
            if (charAt == '\n' || charAt == '\r' || charAt == '\"' || charAt == '\\') {
                StringBuffer stringBuffer = new StringBuffer();
                for (int i3 = 0; i3 < str.length(); i3++) {
                    char charAt2 = str.charAt(i3);
                    if (charAt2 == '\n') {
                        stringBuffer.append("\\n");
                    } else if (charAt2 == '\r') {
                        stringBuffer.append("\\r");
                    } else if (charAt2 == '\"') {
                        stringBuffer.append("\\\"");
                    } else if (charAt2 != '\\') {
                        stringBuffer.append(charAt2);
                    } else {
                        stringBuffer.append("\\\\");
                    }
                }
                return stringBuffer.toString();
            }
        }
        return str;
    }

    public static String javaWrappedType(int i2) {
        switch (i2) {
            case 1:
                return "java.lang.Boolean";
            case 2:
                return "java.lang.Float";
            case 3:
                return "java.lang.Double";
            case 4:
                return "java.lang.Byte";
            case 5:
                return "java.lang.Short";
            case 6:
                return "java.lang.Integer";
            case 7:
                return "java.lang.Long";
            default:
                if (!$assertionsDisabled) {
                    throw new AssertionError();
                }
                throw new IllegalStateException();
        }
    }

    public static String makeSafe(String str) {
        Charset forName = Charset.forName(System.getProperty("file.encoding"));
        if (forName != null) {
            CharsetEncoder newEncoder = forName.newEncoder();
            StringBuffer stringBuffer = new StringBuffer();
            int i2 = 0;
            while (i2 < str.length() && newEncoder.canEncode(str.charAt(i2))) {
                i2++;
            }
            while (i2 < str.length()) {
                char charAt = str.charAt(i2);
                if (newEncoder.canEncode(charAt)) {
                    stringBuffer.append(charAt);
                } else {
                    String hexString = Integer.toHexString(charAt);
                    int length = hexString.length();
                    if (length == 1) {
                        stringBuffer.append("\\u000");
                        stringBuffer.append(hexString);
                    } else if (length == 2) {
                        stringBuffer.append("\\u00");
                        stringBuffer.append(hexString);
                    } else if (length == 3) {
                        stringBuffer.append("\\u0");
                        stringBuffer.append(hexString);
                    } else if (length == 4) {
                        stringBuffer.append("\\u");
                        stringBuffer.append(hexString);
                    } else {
                        throw new IllegalStateException();
                    }
                }
                i2++;
            }
            return stringBuffer.toString();
        }
        throw new IllegalStateException("Default character set is null!");
    }

    public static String prettyQName(QName qName) {
        String localPart = qName.getLocalPart();
        if (qName.getNamespaceURI() == null) {
            return localPart;
        }
        StringBuffer c = a.c(localPart, "(@");
        c.append(qName.getNamespaceURI());
        c.append(")");
        return c.toString();
    }

    private void printExtensionImplMethods(SchemaType schemaType) {
        InterfaceExtension[] interfaceExtensions;
        SchemaTypeImpl impl = getImpl(schemaType);
        if (!(impl == null || (interfaceExtensions = impl.getInterfaceExtensions()) == null)) {
            for (int i2 = 0; i2 < interfaceExtensions.length; i2++) {
                InterfaceExtension.MethodSignature[] methods = interfaceExtensions[i2].getMethods();
                if (methods != null) {
                    for (int i3 = 0; i3 < methods.length; i3++) {
                        StringBuffer a = a.a("Implementation method for interface ");
                        a.append(interfaceExtensions[i2].getStaticHandler());
                        printJavaDoc(a.toString());
                        printInterfaceMethodDecl(methods[i3]);
                        startBlock();
                        printInterfaceMethodImpl(interfaceExtensions[i2].getStaticHandler(), methods[i3]);
                        endBlock();
                    }
                }
            }
        }
    }

    public static void printLoader(Writer writer, SchemaTypeSystem schemaTypeSystem, XmlOptions xmlOptions) {
        getPrinter(xmlOptions).printLoader(writer, schemaTypeSystem);
    }

    public static void printType(Writer writer, SchemaType schemaType, XmlOptions xmlOptions) {
        getPrinter(xmlOptions).printType(writer, schemaType);
    }

    public static void printTypeImpl(Writer writer, SchemaType schemaType, XmlOptions xmlOptions) {
        getPrinter(xmlOptions).printTypeImpl(writer, schemaType);
    }

    public static String shortIndexClassForSystem(SchemaTypeSystem schemaTypeSystem) {
        return "TypeSystemHolder";
    }

    public static boolean xmlTypeForPropertyIsUnion(SchemaProperty schemaProperty) {
        SchemaType javaBasedOnType = schemaProperty.javaBasedOnType();
        return javaBasedOnType.isSimpleType() && javaBasedOnType.getSimpleVariety() == 2;
    }

    public void emit(String str) {
        int i2 = this._indent;
        if (i2 > 20) {
            i2 = (i2 / 2) + 10;
        }
        if (i2 > 40) {
            i2 = 40;
        }
        this._writer.write(MAX_SPACES.substring(0, i2));
        try {
            this._writer.write(str);
        } catch (CharacterCodingException unused) {
            this._writer.write(makeSafe(str));
        }
        this._writer.write(LINE_SEPARATOR);
    }

    public void emitAddTarget(String str, boolean z, boolean z2, String str2) {
        if (z) {
            emit(a.a("target = (", str2, ")get_store().add_attribute_user(", str, ");"));
        } else {
            emit(a.a("target = (", str2, ")get_store().add_element_user(", str, ");"));
        }
    }

    public void emitDeclareTarget(boolean z, String str) {
        if (z) {
            StringBuffer stringBuffer = new StringBuffer();
            stringBuffer.append(str);
            stringBuffer.append(" target = null;");
            emit(stringBuffer.toString());
        }
    }

    public void emitGetTarget(String str, String str2, boolean z, String str3, int i2, String str4) {
        if ($assertionsDisabled || !(str == null || str2 == null)) {
            StringBuffer stringBuffer = new StringBuffer();
            stringBuffer.append(str4);
            stringBuffer.append(" target = null;");
            emit(stringBuffer.toString());
            if (z) {
                emit(a.a("target = (", str4, ")get_store().find_attribute_user(", str2, ");"));
            } else {
                StringBuffer c = a.c("target = (", str4, ")get_store().find_element_user(", str, ", ");
                c.append(str3);
                c.append(");");
                emit(c.toString());
            }
            if (i2 != 1) {
                emit("if (target == null)");
                startBlock();
                if (i2 != 1) {
                    if (i2 == 3) {
                        emitAddTarget(str2, z, false, str4);
                    } else if (i2 == 4) {
                        emit("throw new IndexOutOfBoundsException();");
                    } else if (!$assertionsDisabled) {
                        throw new AssertionError(a.b("Bad behaviour type: ", i2));
                    }
                }
                endBlock();
                return;
            }
            return;
        }
        throw new AssertionError();
    }

    public void emitImplementationPostamble() {
        outdent();
        emit("}");
    }

    public void emitImplementationPreamble() {
        emit("synchronized (monitor())");
        emit("{");
        indent();
        emit("check_orphaned();");
    }

    public void emitPost(SchemaType schemaType, int i2, String str, boolean z) {
        emitPost(schemaType, i2, str, z, "-1");
    }

    public void emitPre(SchemaType schemaType, int i2, String str, boolean z) {
        emitPre(schemaType, i2, str, z, "-1");
    }

    public String encodeString(String str) {
        StringBuffer stringBuffer = new StringBuffer();
        stringBuffer.append(StringPtg.FORMULA_DELIMITER);
        for (int i2 = 0; i2 < str.length(); i2++) {
            char charAt = str.charAt(i2);
            if (charAt == '\"') {
                stringBuffer.append('\\');
                stringBuffer.append(StringPtg.FORMULA_DELIMITER);
            } else if (charAt == '\\') {
                stringBuffer.append('\\');
                stringBuffer.append('\\');
            } else if (charAt == '\r') {
                stringBuffer.append('\\');
                stringBuffer.append('r');
            } else if (charAt == '\n') {
                stringBuffer.append('\\');
                stringBuffer.append('n');
            } else if (charAt == '\t') {
                stringBuffer.append('\\');
                stringBuffer.append('t');
            } else {
                stringBuffer.append(charAt);
            }
        }
        stringBuffer.append(StringPtg.FORMULA_DELIMITER);
        return stringBuffer.toString();
    }

    public void endBlock() {
        outdent();
        emit("}");
    }

    public String findJavaType(SchemaType schemaType) {
        while (schemaType.getFullJavaName() == null) {
            schemaType = schemaType.getBaseType();
        }
        return schemaType.getFullJavaName();
    }

    public String getAtomicRestrictionType(SchemaType schemaType) {
        switch (schemaType.getPrimitiveType().getBuiltinTypeCode()) {
            case 2:
                return "org.apache.xmlbeans.impl.values.XmlAnySimpleTypeImpl";
            case 3:
                return "org.apache.xmlbeans.impl.values.JavaBooleanHolderEx";
            case 4:
                return "org.apache.xmlbeans.impl.values.JavaBase64HolderEx";
            case 5:
                return "org.apache.xmlbeans.impl.values.JavaHexBinaryHolderEx";
            case 6:
                return "org.apache.xmlbeans.impl.values.JavaUriHolderEx";
            case 7:
                return "org.apache.xmlbeans.impl.values.JavaQNameHolderEx";
            case 8:
                return "org.apache.xmlbeans.impl.values.JavaNotationHolderEx";
            case 9:
                return "org.apache.xmlbeans.impl.values.JavaFloatHolderEx";
            case 10:
                return "org.apache.xmlbeans.impl.values.JavaDoubleHolderEx";
            case 11:
                int decimalSize = schemaType.getDecimalSize();
                if (decimalSize == 8 || decimalSize == 16 || decimalSize == 32) {
                    return "org.apache.xmlbeans.impl.values.JavaIntHolderEx";
                }
                if (decimalSize == 64) {
                    return "org.apache.xmlbeans.impl.values.JavaLongHolderEx";
                }
                switch (decimalSize) {
                    case 1000000:
                        return "org.apache.xmlbeans.impl.values.JavaIntegerHolderEx";
                    case SchemaType.SIZE_BIG_DECIMAL:
                        return "org.apache.xmlbeans.impl.values.JavaDecimalHolderEx";
                    default:
                        if ($assertionsDisabled) {
                            return "org.apache.xmlbeans.impl.values.JavaDecimalHolderEx";
                        }
                        throw new AssertionError();
                }
            case 12:
                return schemaType.hasStringEnumValues() ? "org.apache.xmlbeans.impl.values.JavaStringEnumerationHolderEx" : "org.apache.xmlbeans.impl.values.JavaStringHolderEx";
            case 13:
                return "org.apache.xmlbeans.impl.values.JavaGDurationHolderEx";
            case 14:
            case 15:
            case 16:
            case 17:
            case 18:
            case 19:
            case 20:
            case 21:
                return "org.apache.xmlbeans.impl.values.JavaGDateHolderEx";
            default:
                if ($assertionsDisabled) {
                    return null;
                }
                throw new AssertionError("unrecognized primitive type");
        }
    }

    public String getBaseClass(SchemaType schemaType) {
        SchemaType findBaseType = findBaseType(schemaType.getBaseType());
        int simpleVariety = schemaType.getSimpleVariety();
        if (simpleVariety == 0) {
            return !XmlObject.type.equals(findBaseType) ? findBaseType.getFullJavaImplName() : "org.apache.xmlbeans.impl.values.XmlComplexContentImpl";
        }
        if (simpleVariety != 1) {
            if (simpleVariety == 2) {
                return "org.apache.xmlbeans.impl.values.XmlUnionImpl";
            }
            if (simpleVariety == 3) {
                return "org.apache.xmlbeans.impl.values.XmlListImpl";
            }
            throw new IllegalStateException();
        } else if ($assertionsDisabled || !schemaType.isBuiltinType()) {
            return getAtomicRestrictionType(schemaType);
        } else {
            throw new AssertionError();
        }
    }

    public String getIdentifier(Map map, QName qName) {
        return ((String[]) map.get(qName))[0];
    }

    public String getSetIdentifier(Map map, QName qName) {
        String[] strArr = (String[]) map.get(qName);
        return strArr[1] == null ? strArr[0] : strArr[1];
    }

    public void indent() {
        this._indent += 4;
    }

    public String javaTypeForProperty(SchemaProperty schemaProperty) {
        if (schemaProperty.getJavaTypeCode() == 0) {
            return findJavaType(schemaProperty.javaBasedOnType()).replace('$', NameUtil.PERIOD);
        }
        if (schemaProperty.getJavaTypeCode() == 20) {
            return ((SchemaTypeImpl) schemaProperty.getType()).getUserTypeName();
        }
        switch (schemaProperty.getJavaTypeCode()) {
            case 1:
                return "boolean";
            case 2:
                return "float";
            case 3:
                return "double";
            case 4:
                return SchemaSymbols.ATTVAL_BYTE;
            case 5:
                return SchemaSymbols.ATTVAL_SHORT;
            case 6:
                return "int";
            case 7:
                return "long";
            case 8:
                return "java.math.BigDecimal";
            case 9:
                return "java.math.BigInteger";
            case 10:
                return "java.lang.String";
            case 11:
                return "byte[]";
            case 12:
                return "org.apache.xmlbeans.GDate";
            case 13:
                return "org.apache.xmlbeans.GDuration";
            case 14:
                return "java.util.Date";
            case 15:
                return "org.apache.poi.javax.xml.namespace.QName";
            case 16:
                return "java.util.List";
            case 17:
                return "java.util.Calendar";
            case 18:
                SchemaType javaBasedOnType = schemaProperty.javaBasedOnType();
                if (javaBasedOnType.getSimpleVariety() == 2) {
                    javaBasedOnType = javaBasedOnType.getUnionCommonBaseType();
                }
                if (!$assertionsDisabled && javaBasedOnType.getBaseEnumType() == null) {
                    throw new AssertionError();
                } else if (hasBase(javaBasedOnType)) {
                    StringBuffer stringBuffer = new StringBuffer();
                    stringBuffer.append(findJavaType(javaBasedOnType.getBaseEnumType()).replace('$', NameUtil.PERIOD));
                    stringBuffer.append(".Enum");
                    return stringBuffer.toString();
                } else {
                    StringBuffer stringBuffer2 = new StringBuffer();
                    stringBuffer2.append(findJavaType(javaBasedOnType).replace('$', NameUtil.PERIOD));
                    stringBuffer2.append(".Enum");
                    return stringBuffer2.toString();
                }
            case 19:
                return "java.lang.Object";
            default:
                if (!$assertionsDisabled) {
                    throw new AssertionError();
                }
                throw new IllegalStateException();
        }
    }

    public void makeAttributeDefaultValue(String str, SchemaProperty schemaProperty, String str2) {
        if (str == null) {
            str = schemaProperty.javaBasedOnType().getFullJavaName().replace('$', NameUtil.PERIOD);
        }
        emit(a.a("target = (", str, ")get_default_attribute_value(", str2, ");"));
    }

    public void makeMissingValue(int i2) {
        switch (i2) {
            case 1:
                emit("return false;");
                return;
            case 2:
                emit("return 0.0f;");
                return;
            case 3:
                emit("return 0.0;");
                return;
            case 4:
            case 5:
            case 6:
                emit("return 0;");
                return;
            case 7:
                emit("return 0L;");
                return;
            default:
                emit("return null;");
                return;
        }
    }

    public void outdent() {
        this._indent -= 4;
    }

    public String prePostOpString(int i2) {
        if (i2 == 1) {
            return "org.apache.xmlbeans.PrePostExtension.OPERATION_SET";
        }
        if (i2 == 2) {
            return "org.apache.xmlbeans.PrePostExtension.OPERATION_INSERT";
        }
        if (i2 == 3) {
            return "org.apache.xmlbeans.PrePostExtension.OPERATION_REMOVE";
        }
        if ($assertionsDisabled) {
            return "org.apache.xmlbeans.PrePostExtension.OPERATION_SET";
        }
        throw new AssertionError();
    }

    public void printConstructor(SchemaType schemaType, String str) {
        String str2;
        emit("");
        StringBuffer stringBuffer = new StringBuffer();
        stringBuffer.append("public ");
        stringBuffer.append(str);
        stringBuffer.append("(org.apache.xmlbeans.SchemaType sType)");
        emit(stringBuffer.toString());
        startBlock();
        StringBuffer stringBuffer2 = new StringBuffer();
        stringBuffer2.append("super(sType");
        if (schemaType.getSimpleVariety() == 0) {
            str2 = "";
        } else {
            StringBuffer a = a.a(", ");
            a.append(!schemaType.isSimpleType());
            str2 = a.toString();
        }
        stringBuffer2.append(str2);
        stringBuffer2.append(");");
        emit(stringBuffer2.toString());
        endBlock();
        if (schemaType.getSimpleVariety() != 0) {
            emit("");
            StringBuffer stringBuffer3 = new StringBuffer();
            stringBuffer3.append("protected ");
            stringBuffer3.append(str);
            stringBuffer3.append("(org.apache.xmlbeans.SchemaType sType, boolean b)");
            emit(stringBuffer3.toString());
            startBlock();
            emit("super(sType, b);");
            endBlock();
        }
    }

    public void printFactory(SchemaType schemaType) {
        boolean z = !schemaType.isAnonymousType() || schemaType.isDocumentType() || schemaType.isAttributeType();
        String replace = schemaType.getFullJavaName().replace('$', NameUtil.PERIOD);
        emit("");
        emit("/**");
        emit(" * A factory class with static methods for creating instances");
        emit(" * of this type.");
        emit(" */");
        emit("");
        emit("public static final class Factory");
        emit("{");
        indent();
        if (schemaType.isSimpleType()) {
            StringBuffer stringBuffer = new StringBuffer();
            stringBuffer.append("public static ");
            stringBuffer.append(replace);
            stringBuffer.append(" newValue(java.lang.Object obj) {");
            emit(stringBuffer.toString());
            StringBuffer stringBuffer2 = new StringBuffer();
            stringBuffer2.append("  return (");
            stringBuffer2.append(replace);
            stringBuffer2.append(") type.newValue( obj ); }");
            emit(stringBuffer2.toString());
            emit("");
        }
        if (schemaType.isAbstract()) {
            emit("/** @deprecated No need to be able to create instances of abstract types */");
            if (this._useJava15) {
                emit("@Deprecated");
            }
        }
        StringBuffer stringBuffer3 = new StringBuffer();
        stringBuffer3.append("public static ");
        stringBuffer3.append(replace);
        stringBuffer3.append(" newInstance() {");
        emit(stringBuffer3.toString());
        StringBuffer stringBuffer4 = new StringBuffer();
        stringBuffer4.append("  return (");
        stringBuffer4.append(replace);
        stringBuffer4.append(") org.apache.xmlbeans.XmlBeans.getContextTypeLoader().newInstance( type, null ); }");
        emit(stringBuffer4.toString());
        emit("");
        if (schemaType.isAbstract()) {
            emit("/** @deprecated No need to be able to create instances of abstract types */");
            if (this._useJava15) {
                emit("@Deprecated");
            }
        }
        StringBuffer stringBuffer5 = new StringBuffer();
        stringBuffer5.append("public static ");
        stringBuffer5.append(replace);
        stringBuffer5.append(" newInstance(org.apache.xmlbeans.XmlOptions options) {");
        emit(stringBuffer5.toString());
        StringBuffer stringBuffer6 = new StringBuffer();
        stringBuffer6.append("  return (");
        stringBuffer6.append(replace);
        stringBuffer6.append(") org.apache.xmlbeans.XmlBeans.getContextTypeLoader().newInstance( type, options ); }");
        emit(stringBuffer6.toString());
        emit("");
        if (z) {
            emit("/** @param xmlAsString the string value to parse */");
            StringBuffer stringBuffer7 = new StringBuffer();
            stringBuffer7.append("public static ");
            stringBuffer7.append(replace);
            stringBuffer7.append(" parse(java.lang.String xmlAsString) throws org.apache.xmlbeans.XmlException {");
            emit(stringBuffer7.toString());
            a.a(new StringBuffer(), "  return (", replace, ") org.apache.xmlbeans.XmlBeans.getContextTypeLoader().parse( xmlAsString, type, null ); }", this);
            emit("");
            StringBuffer stringBuffer8 = new StringBuffer();
            stringBuffer8.append("public static ");
            stringBuffer8.append(replace);
            stringBuffer8.append(" parse(java.lang.String xmlAsString, org.apache.xmlbeans.XmlOptions options) throws org.apache.xmlbeans.XmlException {");
            emit(stringBuffer8.toString());
            a.a(new StringBuffer(), "  return (", replace, ") org.apache.xmlbeans.XmlBeans.getContextTypeLoader().parse( xmlAsString, type, options ); }", this);
            emit("");
            emit("/** @param file the file from which to load an xml document */");
            StringBuffer stringBuffer9 = new StringBuffer();
            stringBuffer9.append("public static ");
            stringBuffer9.append(replace);
            stringBuffer9.append(" parse(java.io.File file) throws org.apache.xmlbeans.XmlException, java.io.IOException {");
            emit(stringBuffer9.toString());
            StringBuffer stringBuffer10 = new StringBuffer();
            stringBuffer10.append("  return (");
            stringBuffer10.append(replace);
            stringBuffer10.append(") org.apache.xmlbeans.XmlBeans.getContextTypeLoader().parse( file, type, null ); }");
            emit(stringBuffer10.toString());
            emit("");
            StringBuffer stringBuffer11 = new StringBuffer();
            stringBuffer11.append("public static ");
            stringBuffer11.append(replace);
            stringBuffer11.append(" parse(java.io.File file, org.apache.xmlbeans.XmlOptions options) throws org.apache.xmlbeans.XmlException, java.io.IOException {");
            emit(stringBuffer11.toString());
            StringBuffer stringBuffer12 = new StringBuffer();
            stringBuffer12.append("  return (");
            stringBuffer12.append(replace);
            stringBuffer12.append(") org.apache.xmlbeans.XmlBeans.getContextTypeLoader().parse( file, type, options ); }");
            emit(stringBuffer12.toString());
            emit("");
            StringBuffer stringBuffer13 = new StringBuffer();
            stringBuffer13.append("public static ");
            stringBuffer13.append(replace);
            stringBuffer13.append(" parse(java.net.URL u) throws org.apache.xmlbeans.XmlException, java.io.IOException {");
            emit(stringBuffer13.toString());
            a.a(new StringBuffer(), "  return (", replace, ") org.apache.xmlbeans.XmlBeans.getContextTypeLoader().parse( u, type, null ); }", this);
            emit("");
            StringBuffer stringBuffer14 = new StringBuffer();
            stringBuffer14.append("public static ");
            stringBuffer14.append(replace);
            stringBuffer14.append(" parse(java.net.URL u, org.apache.xmlbeans.XmlOptions options) throws org.apache.xmlbeans.XmlException, java.io.IOException {");
            emit(stringBuffer14.toString());
            a.a(new StringBuffer(), "  return (", replace, ") org.apache.xmlbeans.XmlBeans.getContextTypeLoader().parse( u, type, options ); }", this);
            emit("");
            StringBuffer stringBuffer15 = new StringBuffer();
            stringBuffer15.append("public static ");
            stringBuffer15.append(replace);
            stringBuffer15.append(" parse(java.io.InputStream is) throws org.apache.xmlbeans.XmlException, java.io.IOException {");
            emit(stringBuffer15.toString());
            a.a(new StringBuffer(), "  return (", replace, ") org.apache.xmlbeans.XmlBeans.getContextTypeLoader().parse( is, type, null ); }", this);
            emit("");
            StringBuffer stringBuffer16 = new StringBuffer();
            stringBuffer16.append("public static ");
            stringBuffer16.append(replace);
            stringBuffer16.append(" parse(java.io.InputStream is, org.apache.xmlbeans.XmlOptions options) throws org.apache.xmlbeans.XmlException, java.io.IOException {");
            emit(stringBuffer16.toString());
            a.a(new StringBuffer(), "  return (", replace, ") org.apache.xmlbeans.XmlBeans.getContextTypeLoader().parse( is, type, options ); }", this);
            emit("");
            StringBuffer stringBuffer17 = new StringBuffer();
            stringBuffer17.append("public static ");
            stringBuffer17.append(replace);
            stringBuffer17.append(" parse(java.io.Reader r) throws org.apache.xmlbeans.XmlException, java.io.IOException {");
            emit(stringBuffer17.toString());
            a.a(new StringBuffer(), "  return (", replace, ") org.apache.xmlbeans.XmlBeans.getContextTypeLoader().parse( r, type, null ); }", this);
            emit("");
            StringBuffer stringBuffer18 = new StringBuffer();
            stringBuffer18.append("public static ");
            stringBuffer18.append(replace);
            stringBuffer18.append(" parse(java.io.Reader r, org.apache.xmlbeans.XmlOptions options) throws org.apache.xmlbeans.XmlException, java.io.IOException {");
            emit(stringBuffer18.toString());
            a.a(new StringBuffer(), "  return (", replace, ") org.apache.xmlbeans.XmlBeans.getContextTypeLoader().parse( r, type, options ); }", this);
            emit("");
            StringBuffer stringBuffer19 = new StringBuffer();
            stringBuffer19.append("public static ");
            stringBuffer19.append(replace);
            stringBuffer19.append(" parse(javax.xml.stream.XMLStreamReader sr) throws org.apache.xmlbeans.XmlException {");
            emit(stringBuffer19.toString());
            a.a(new StringBuffer(), "  return (", replace, ") org.apache.xmlbeans.XmlBeans.getContextTypeLoader().parse( sr, type, null ); }", this);
            emit("");
            StringBuffer stringBuffer20 = new StringBuffer();
            stringBuffer20.append("public static ");
            stringBuffer20.append(replace);
            stringBuffer20.append(" parse(javax.xml.stream.XMLStreamReader sr, org.apache.xmlbeans.XmlOptions options) throws org.apache.xmlbeans.XmlException {");
            emit(stringBuffer20.toString());
            a.a(new StringBuffer(), "  return (", replace, ") org.apache.xmlbeans.XmlBeans.getContextTypeLoader().parse( sr, type, options ); }", this);
            emit("");
            StringBuffer stringBuffer21 = new StringBuffer();
            stringBuffer21.append("public static ");
            stringBuffer21.append(replace);
            stringBuffer21.append(" parse(org.w3c.dom.Node node) throws org.apache.xmlbeans.XmlException {");
            emit(stringBuffer21.toString());
            a.a(new StringBuffer(), "  return (", replace, ") org.apache.xmlbeans.XmlBeans.getContextTypeLoader().parse( node, type, null ); }", this);
            emit("");
            StringBuffer stringBuffer22 = new StringBuffer();
            stringBuffer22.append("public static ");
            stringBuffer22.append(replace);
            stringBuffer22.append(" parse(org.w3c.dom.Node node, org.apache.xmlbeans.XmlOptions options) throws org.apache.xmlbeans.XmlException {");
            emit(stringBuffer22.toString());
            a.a(new StringBuffer(), "  return (", replace, ") org.apache.xmlbeans.XmlBeans.getContextTypeLoader().parse( node, type, options ); }", this);
            emit("");
            emit("/** @deprecated {@link org.apache.xmlbeans.xml.stream.XMLInputStream} */");
            if (this._useJava15) {
                emit("@Deprecated");
            }
            StringBuffer stringBuffer23 = new StringBuffer();
            stringBuffer23.append("public static ");
            stringBuffer23.append(replace);
            stringBuffer23.append(" parse(org.apache.xmlbeans.xml.stream.XMLInputStream xis) throws org.apache.xmlbeans.XmlException, org.apache.xmlbeans.xml.stream.XMLStreamException {");
            emit(stringBuffer23.toString());
            StringBuffer stringBuffer24 = new StringBuffer();
            stringBuffer24.append("  return (");
            stringBuffer24.append(replace);
            stringBuffer24.append(") org.apache.xmlbeans.XmlBeans.getContextTypeLoader().parse( xis, type, null ); }");
            emit(stringBuffer24.toString());
            emit("");
            emit("/** @deprecated {@link org.apache.xmlbeans.xml.stream.XMLInputStream} */");
            if (this._useJava15) {
                emit("@Deprecated");
            }
            StringBuffer stringBuffer25 = new StringBuffer();
            stringBuffer25.append("public static ");
            stringBuffer25.append(replace);
            stringBuffer25.append(" parse(org.apache.xmlbeans.xml.stream.XMLInputStream xis, org.apache.xmlbeans.XmlOptions options) throws org.apache.xmlbeans.XmlException, org.apache.xmlbeans.xml.stream.XMLStreamException {");
            emit(stringBuffer25.toString());
            StringBuffer stringBuffer26 = new StringBuffer();
            stringBuffer26.append("  return (");
            stringBuffer26.append(replace);
            stringBuffer26.append(") org.apache.xmlbeans.XmlBeans.getContextTypeLoader().parse( xis, type, options ); }");
            emit(stringBuffer26.toString());
            emit("");
            emit("/** @deprecated {@link org.apache.xmlbeans.xml.stream.XMLInputStream} */");
            if (this._useJava15) {
                emit("@Deprecated");
            }
            emit("public static org.apache.xmlbeans.xml.stream.XMLInputStream newValidatingXMLInputStream(org.apache.xmlbeans.xml.stream.XMLInputStream xis) throws org.apache.xmlbeans.XmlException, org.apache.xmlbeans.xml.stream.XMLStreamException {");
            emit("  return org.apache.xmlbeans.XmlBeans.getContextTypeLoader().newValidatingXMLInputStream( xis, type, null ); }");
            emit("");
            emit("/** @deprecated {@link org.apache.xmlbeans.xml.stream.XMLInputStream} */");
            if (this._useJava15) {
                emit("@Deprecated");
            }
            a.a(this, "public static org.apache.xmlbeans.xml.stream.XMLInputStream newValidatingXMLInputStream(org.apache.xmlbeans.xml.stream.XMLInputStream xis, org.apache.xmlbeans.XmlOptions options) throws org.apache.xmlbeans.XmlException, org.apache.xmlbeans.xml.stream.XMLStreamException {", "  return org.apache.xmlbeans.XmlBeans.getContextTypeLoader().newValidatingXMLInputStream( xis, type, options ); }", "");
        }
        emit("private Factory() { } // No instance of this class allowed");
        outdent();
        emit("}");
    }

    public void printGetterImpls(String str, SchemaProperty schemaProperty, QName qName, boolean z, String str2, int i2, String str3, String str4, boolean z2, boolean z3, boolean z4, boolean z5, boolean z6, String str5, String str6) {
        String str7;
        String str8;
        String str9;
        String str10;
        String str11;
        String str12;
        String str13;
        String str14;
        String str15;
        String str16;
        String str17;
        String str18;
        String str19;
        String str20;
        String str21;
        String str22;
        String str23;
        String str24;
        String str25;
        String str26;
        StringBuffer a = a.a("\"");
        a.append(qName.getLocalPart());
        a.append("\"");
        a.append(z ? " attribute" : " element");
        String stringBuffer = a.toString();
        boolean z7 = i2 == 0;
        String str27 = (z6 || !z7) ? "org.apache.xmlbeans.SimpleValue" : str4;
        if (z5) {
            StringBuffer stringBuffer2 = new StringBuffer();
            stringBuffer2.append(z4 ? "Gets first " : "Gets the ");
            stringBuffer2.append(stringBuffer);
            printJavaDoc(stringBuffer2.toString());
            StringBuffer stringBuffer3 = new StringBuffer();
            stringBuffer3.append("public ");
            stringBuffer3.append(str3);
            stringBuffer3.append(" get");
            stringBuffer3.append(str2);
            stringBuffer3.append("()");
            emit(stringBuffer3.toString());
            startBlock();
            emitImplementationPreamble();
            str7 = " get";
            emitGetTarget(str6, str5, z, "0", 1, str27);
            if (!z || !(schemaProperty.hasDefault() == 2 || schemaProperty.hasFixed() == 2)) {
                str25 = str27;
            } else {
                emit("if (target == null)");
                startBlock();
                str25 = str27;
                makeAttributeDefaultValue(str25, schemaProperty, str5);
                endBlock();
            }
            emit("if (target == null)");
            startBlock();
            makeMissingValue(i2);
            endBlock();
            printJGetValue(i2, str3, (SchemaTypeImpl) schemaProperty.getType());
            emitImplementationPostamble();
            endBlock();
            if (!z7) {
                StringBuffer stringBuffer4 = new StringBuffer();
                stringBuffer4.append(z4 ? "Gets (as xml) first " : "Gets (as xml) the ");
                stringBuffer4.append(stringBuffer);
                printJavaDoc(stringBuffer4.toString());
                StringBuffer stringBuffer5 = new StringBuffer();
                stringBuffer5.append("public ");
                stringBuffer5.append(str4);
                stringBuffer5.append(" xget");
                stringBuffer5.append(str2);
                stringBuffer5.append("()");
                emit(stringBuffer5.toString());
                startBlock();
                emitImplementationPreamble();
                str26 = "()";
                str8 = " xget";
                str10 = "public ";
                str9 = str25;
                emitGetTarget(str6, str5, z, "0", 1, str4);
                if (z && (schemaProperty.hasDefault() == 2 || schemaProperty.hasFixed() == 2)) {
                    emit("if (target == null)");
                    startBlock();
                    makeAttributeDefaultValue(str4, schemaProperty, str5);
                    endBlock();
                }
                emit("return target;");
                emitImplementationPostamble();
                endBlock();
            } else {
                str9 = str25;
                str26 = "()";
                str8 = " xget";
                str10 = "public ";
            }
            if (z2) {
                StringBuffer stringBuffer6 = new StringBuffer();
                stringBuffer6.append(z4 ? "Tests for nil first " : "Tests for nil ");
                stringBuffer6.append(stringBuffer);
                printJavaDoc(stringBuffer6.toString());
                StringBuffer stringBuffer7 = new StringBuffer();
                stringBuffer7.append("public boolean isNil");
                stringBuffer7.append(str2);
                str11 = str26;
                stringBuffer7.append(str11);
                emit(stringBuffer7.toString());
                startBlock();
                emitImplementationPreamble();
                emitGetTarget(str6, str5, z, "0", 1, str4);
                emit("if (target == null) return false;");
                emit("return target.isNil();");
                emitImplementationPostamble();
                endBlock();
            } else {
                str11 = str26;
            }
        } else {
            str11 = "()";
            str10 = "public ";
            str7 = " get";
            str8 = " xget";
            str9 = str27;
        }
        if (z3) {
            StringBuffer stringBuffer8 = new StringBuffer();
            stringBuffer8.append(z4 ? "True if has at least one " : "True if has ");
            stringBuffer8.append(stringBuffer);
            printJavaDoc(stringBuffer8.toString());
            StringBuffer stringBuffer9 = new StringBuffer();
            stringBuffer9.append("public boolean isSet");
            stringBuffer9.append(str2);
            stringBuffer9.append(str11);
            emit(stringBuffer9.toString());
            startBlock();
            emitImplementationPreamble();
            if (z) {
                a.a("return get_store().find_attribute_user(", str5, ") != null;", this);
                str12 = str8;
            } else {
                str12 = str8;
                a.a("return get_store().count_elements(", str6, ") != 0;", this);
            }
            emitImplementationPostamble();
            endBlock();
        } else {
            str12 = str8;
        }
        if (z4) {
            String a2 = a.a(str2, SoapEncSchemaTypeSystem.SOAP_ARRAY);
            if (this._useJava15) {
                str14 = a2;
                str13 = str12;
                str16 = "return get_store().count_elements(";
                str15 = stringBuffer;
                printListGetter15Impl(str, stringBuffer, str2, isJavaPrimitive(i2) ? javaWrappedType(i2) : str3, str4, z7, false);
            } else {
                str14 = a2;
                str13 = str12;
                str16 = "return get_store().count_elements(";
                str15 = stringBuffer;
            }
            if (this._useJava15) {
                emit("");
                emit("/**");
                StringBuffer stringBuffer10 = new StringBuffer();
                stringBuffer10.append(" * Gets array of all ");
                stringBuffer10.append(str15);
                stringBuffer10.append(Lucene3xNormsProducer.SEPARATE_NORMS_EXTENSION);
                emit(stringBuffer10.toString());
                emit(" * @deprecated");
                emit(" */");
                emit("@Deprecated");
                str17 = "";
            } else {
                StringBuffer stringBuffer11 = new StringBuffer();
                str17 = "";
                stringBuffer11.append("Gets array of all ");
                stringBuffer11.append(str15);
                stringBuffer11.append(Lucene3xNormsProducer.SEPARATE_NORMS_EXTENSION);
                printJavaDoc(stringBuffer11.toString());
            }
            emit(a.a(str10, str3, "[] get", str14, str11));
            startBlock();
            emitImplementationPreamble();
            if (this._useJava15) {
                emit(a.a("java.util.List<", str4, "> targetList = new java.util.ArrayList<", str4, ">();"));
            } else {
                emit("java.util.List targetList = new java.util.ArrayList();");
            }
            StringBuffer stringBuffer12 = new StringBuffer();
            stringBuffer12.append("get_store().find_all_element_users(");
            stringBuffer12.append(str6);
            stringBuffer12.append(", targetList);");
            emit(stringBuffer12.toString());
            printJGetArrayValue(i2, str3, (SchemaTypeImpl) schemaProperty.getType());
            emitImplementationPostamble();
            endBlock();
            StringBuffer stringBuffer13 = new StringBuffer();
            stringBuffer13.append("Gets ith ");
            stringBuffer13.append(str15);
            printJavaDoc(stringBuffer13.toString());
            StringBuffer stringBuffer14 = new StringBuffer();
            stringBuffer14.append(str10);
            stringBuffer14.append(str3);
            stringBuffer14.append(str7);
            stringBuffer14.append(str14);
            stringBuffer14.append("(int i)");
            emit(stringBuffer14.toString());
            startBlock();
            emitImplementationPreamble();
            emitGetTarget(str6, str5, z, Complex.DEFAULT_SUFFIX, 4, str9);
            printJGetValue(i2, str3, (SchemaTypeImpl) schemaProperty.getType());
            emitImplementationPostamble();
            endBlock();
            if (!z7) {
                if (this._useJava15) {
                    str21 = ", targetList);";
                    str24 = "@Deprecated";
                    str23 = ">();";
                    str22 = "get_store().find_all_element_users(";
                    printListGetter15Impl(str, str15, str2, str4, str4, z7, true);
                } else {
                    str21 = ", targetList);";
                    str24 = "@Deprecated";
                    str23 = ">();";
                    str22 = "get_store().find_all_element_users(";
                }
                if (this._useJava15) {
                    emit(str17);
                    emit("/**");
                    StringBuffer stringBuffer15 = new StringBuffer();
                    stringBuffer15.append(" * Gets array of all ");
                    stringBuffer15.append(str15);
                    stringBuffer15.append(Lucene3xNormsProducer.SEPARATE_NORMS_EXTENSION);
                    emit(stringBuffer15.toString());
                    emit(" * @deprecated");
                    emit(" */");
                    emit(str24);
                } else {
                    StringBuffer stringBuffer16 = new StringBuffer();
                    stringBuffer16.append("Gets (as xml) array of all ");
                    stringBuffer16.append(str15);
                    stringBuffer16.append(Lucene3xNormsProducer.SEPARATE_NORMS_EXTENSION);
                    printJavaDoc(stringBuffer16.toString());
                }
                str20 = str14;
                emit(a.a(str10, str4, "[] xget", str20, str11));
                startBlock();
                emitImplementationPreamble();
                if (this._useJava15) {
                    emit(a.a("java.util.List<", str4, "> targetList = new java.util.ArrayList<", str4, str23));
                } else {
                    emit("java.util.List targetList = new java.util.ArrayList();");
                }
                StringBuffer stringBuffer17 = new StringBuffer();
                stringBuffer17.append(str22);
                str19 = str6;
                stringBuffer17.append(str19);
                stringBuffer17.append(str21);
                emit(stringBuffer17.toString());
                StringBuffer stringBuffer18 = new StringBuffer();
                stringBuffer18.append(str4);
                a.a(stringBuffer18, "[] result = new ", str4, "[targetList.size()];", this);
                emit("targetList.toArray(result);");
                emit("return result;");
                emitImplementationPostamble();
                endBlock();
                StringBuffer stringBuffer19 = new StringBuffer();
                stringBuffer19.append("Gets (as xml) ith ");
                stringBuffer19.append(str15);
                printJavaDoc(stringBuffer19.toString());
                StringBuffer stringBuffer20 = new StringBuffer();
                a.a(stringBuffer20, str10, str4, str13, str20);
                str18 = "(int i)";
                stringBuffer20.append(str18);
                emit(stringBuffer20.toString());
                startBlock();
                emitImplementationPreamble();
                emitGetTarget(str6, str5, z, Complex.DEFAULT_SUFFIX, 4, str4);
                emit("return target;");
                emitImplementationPostamble();
                endBlock();
            } else {
                str19 = str6;
                str18 = "(int i)";
                str20 = str14;
            }
            if (z2) {
                StringBuffer stringBuffer21 = new StringBuffer();
                stringBuffer21.append("Tests for nil ith ");
                stringBuffer21.append(str15);
                printJavaDoc(stringBuffer21.toString());
                StringBuffer stringBuffer22 = new StringBuffer();
                stringBuffer22.append("public boolean isNil");
                stringBuffer22.append(str20);
                stringBuffer22.append(str18);
                emit(stringBuffer22.toString());
                startBlock();
                emitImplementationPreamble();
                emitGetTarget(str6, str5, z, Complex.DEFAULT_SUFFIX, 4, str4);
                emit("return target.isNil();");
                emitImplementationPostamble();
                endBlock();
            }
            StringBuffer stringBuffer23 = new StringBuffer();
            stringBuffer23.append("Returns number of ");
            stringBuffer23.append(str15);
            printJavaDoc(stringBuffer23.toString());
            StringBuffer stringBuffer24 = new StringBuffer();
            stringBuffer24.append("public int sizeOf");
            stringBuffer24.append(str20);
            stringBuffer24.append(str11);
            emit(stringBuffer24.toString());
            startBlock();
            emitImplementationPreamble();
            StringBuffer stringBuffer25 = new StringBuffer();
            stringBuffer25.append(str16);
            stringBuffer25.append(str19);
            stringBuffer25.append(");");
            emit(stringBuffer25.toString());
            emitImplementationPostamble();
            endBlock();
        }
    }

    public void printInnerType(SchemaType schemaType, SchemaTypeSystem schemaTypeSystem) {
        emit("");
        printInnerTypeJavaDoc(schemaType);
        startInterface(schemaType);
        printStaticTypeDeclaration(schemaType, schemaTypeSystem);
        if (!schemaType.isSimpleType()) {
            if (schemaType.getContentType() == 2 && schemaType.hasStringEnumValues()) {
                printStringEnumeration(schemaType);
            }
            SchemaProperty[] derivedProperties = getDerivedProperties(schemaType);
            for (SchemaProperty schemaProperty : derivedProperties) {
                printPropertyGetters(schemaProperty.getName(), schemaProperty.isAttribute(), schemaProperty.getJavaPropertyName(), schemaProperty.getJavaTypeCode(), javaTypeForProperty(schemaProperty), xmlTypeForProperty(schemaProperty), schemaProperty.hasNillable() != 0, schemaProperty.extendsJavaOption(), schemaProperty.extendsJavaArray(), schemaProperty.extendsJavaSingleton());
                if (!schemaProperty.isReadOnly()) {
                    printPropertySetters(schemaProperty.getName(), schemaProperty.isAttribute(), schemaProperty.getJavaPropertyName(), schemaProperty.getJavaTypeCode(), javaTypeForProperty(schemaProperty), xmlTypeForProperty(schemaProperty), schemaProperty.hasNillable() != 0, schemaProperty.extendsJavaOption(), schemaProperty.extendsJavaArray(), schemaProperty.extendsJavaSingleton());
                }
            }
        } else if (schemaType.hasStringEnumValues()) {
            printStringEnumeration(schemaType);
        }
        printNestedInnerTypes(schemaType, schemaTypeSystem);
        printFactory(schemaType);
        endBlock();
    }

    public void printInnerTypeImpl(SchemaType schemaType, SchemaTypeSystem schemaTypeSystem, boolean z) {
        SchemaProperty[] schemaPropertyArr;
        Map map;
        SchemaTypeCodePrinter schemaTypeCodePrinter = this;
        String shortJavaImplName = schemaType.getShortJavaImplName();
        printInnerTypeJavaDoc(schemaType);
        schemaTypeCodePrinter.startClass(schemaType, z);
        schemaTypeCodePrinter.printConstructor(schemaType, shortJavaImplName);
        printExtensionImplMethods(schemaType);
        if (!schemaType.isSimpleType()) {
            if (schemaType.getContentType() == 2) {
                SchemaType baseType = schemaType.getBaseType();
                ArrayList arrayList = null;
                while (!baseType.isSimpleType() && !baseType.isBuiltinType()) {
                    SchemaProperty[] derivedProperties = baseType.getDerivedProperties();
                    for (int i2 = 0; i2 < derivedProperties.length; i2++) {
                        if (!derivedProperties[i2].isAttribute() || schemaType.getAttributeProperty(derivedProperties[i2].getName()) == null) {
                            if (arrayList == null) {
                                arrayList = new ArrayList();
                            }
                            arrayList.add(derivedProperties[i2]);
                        }
                    }
                    baseType = baseType.getBaseType();
                }
                schemaPropertyArr = schemaType.getProperties();
                if (arrayList != null) {
                    for (SchemaProperty schemaProperty : schemaPropertyArr) {
                        arrayList.add(schemaProperty);
                    }
                    schemaPropertyArr = (SchemaProperty[]) arrayList.toArray(new SchemaProperty[arrayList.size()]);
                }
            } else {
                schemaPropertyArr = getDerivedProperties(schemaType);
            }
            SchemaProperty[] schemaPropertyArr2 = schemaPropertyArr;
            Map printStaticFields = schemaTypeCodePrinter.printStaticFields(schemaPropertyArr2);
            int i3 = 0;
            while (i3 < schemaPropertyArr2.length) {
                SchemaProperty schemaProperty2 = schemaPropertyArr2[i3];
                QName name = schemaProperty2.getName();
                String xmlTypeForProperty = schemaTypeCodePrinter.xmlTypeForProperty(schemaProperty2);
                printGetterImpls(shortJavaImplName, schemaProperty2, name, schemaProperty2.isAttribute(), schemaProperty2.getJavaPropertyName(), schemaProperty2.getJavaTypeCode(), schemaTypeCodePrinter.javaTypeForProperty(schemaProperty2), xmlTypeForProperty, schemaProperty2.hasNillable() != 0, schemaProperty2.extendsJavaOption(), schemaProperty2.extendsJavaArray(), schemaProperty2.extendsJavaSingleton(), xmlTypeForPropertyIsUnion(schemaProperty2), schemaTypeCodePrinter.getIdentifier(printStaticFields, name), schemaTypeCodePrinter.getSetIdentifier(printStaticFields, name));
                if (!schemaProperty2.isReadOnly()) {
                    map = printStaticFields;
                    printSetterImpls(name, schemaProperty2, schemaProperty2.isAttribute(), schemaProperty2.getJavaPropertyName(), schemaProperty2.getJavaTypeCode(), javaTypeForProperty(schemaProperty2), xmlTypeForProperty, schemaProperty2.hasNillable() != 0, schemaProperty2.extendsJavaOption(), schemaProperty2.extendsJavaArray(), schemaProperty2.extendsJavaSingleton(), xmlTypeForPropertyIsUnion(schemaProperty2), getIdentifier(printStaticFields, name), getSetIdentifier(printStaticFields, name), schemaType);
                } else {
                    map = printStaticFields;
                }
                i3++;
                schemaTypeCodePrinter = this;
                printStaticFields = map;
                schemaPropertyArr2 = schemaPropertyArr2;
                shortJavaImplName = shortJavaImplName;
            }
        }
        printNestedTypeImpls(schemaType, schemaTypeSystem);
        endBlock();
    }

    public void printInnerTypeJavaDoc(SchemaType schemaType) {
        SchemaType[] unionConstituentTypes;
        QName name = schemaType.getName();
        if (name == null) {
            if (schemaType.isDocumentType()) {
                name = schemaType.getDocumentElementName();
            } else if (schemaType.isAttributeType()) {
                name = schemaType.getAttributeTypeAttributeName();
            } else if (schemaType.getContainerField() != null) {
                name = schemaType.getContainerField().getName();
            }
        }
        emit("/**");
        if (schemaType.isDocumentType()) {
            StringBuffer a = a.a(" * A document containing one ");
            a.append(prettyQName(name));
            a.append(" element.");
            emit(a.toString());
        } else if (schemaType.isAttributeType()) {
            StringBuffer a2 = a.a(" * A document containing one ");
            a2.append(prettyQName(name));
            a2.append(" attribute.");
            emit(a2.toString());
        } else if (name != null) {
            StringBuffer a3 = a.a(" * An XML ");
            a3.append(prettyQName(name));
            a3.append(".");
            emit(a3.toString());
        } else {
            emit(" * An anonymous inner XML type.");
        }
        emit(" *");
        int simpleVariety = schemaType.getSimpleVariety();
        if (simpleVariety == 0) {
            emit(" * This is a complex type.");
        } else if (simpleVariety == 1) {
            StringBuffer a4 = a.a(" * This is an atomic type that is a restriction of ");
            a4.append(getFullJavaName(schemaType));
            a4.append(".");
            emit(a4.toString());
        } else if (simpleVariety == 2) {
            emit(" * This is a union type. Instances are of one of the following types:");
            for (SchemaType schemaType2 : schemaType.getUnionConstituentTypes()) {
                StringBuffer a5 = a.a(" *     ");
                a5.append(schemaType2.getFullJavaName());
                emit(a5.toString());
            }
        } else if (simpleVariety == 3) {
            StringBuffer a6 = a.a(" * This is a list type whose items are ");
            a6.append(schemaType.getListItemType().getFullJavaName());
            a6.append(".");
            emit(a6.toString());
        }
        emit(" */");
    }

    public void printInterfaceMethodDecl(InterfaceExtension.MethodSignature methodSignature) {
        String str;
        StringBuffer stringBuffer = new StringBuffer(60);
        stringBuffer.append("public ");
        stringBuffer.append(methodSignature.getReturnType());
        stringBuffer.append(" ");
        stringBuffer.append(methodSignature.getName());
        stringBuffer.append("(");
        String[] parameterTypes = methodSignature.getParameterTypes();
        for (int i2 = 0; i2 < parameterTypes.length; i2++) {
            if (i2 != 0) {
                stringBuffer.append(", ");
            }
            stringBuffer.append(parameterTypes[i2]);
            stringBuffer.append(" p");
            stringBuffer.append(i2);
        }
        stringBuffer.append(")");
        String[] exceptionTypes = methodSignature.getExceptionTypes();
        for (int i3 = 0; i3 < exceptionTypes.length; i3++) {
            StringBuffer stringBuffer2 = new StringBuffer();
            if (i3 == 0) {
                str = " throws ";
            } else {
                str = ", ";
            }
            stringBuffer2.append(str);
            stringBuffer2.append(exceptionTypes[i3]);
            stringBuffer.append(stringBuffer2.toString());
        }
        emit(stringBuffer.toString());
    }

    public void printInterfaceMethodImpl(String str, InterfaceExtension.MethodSignature methodSignature) {
        StringBuffer stringBuffer = new StringBuffer(60);
        if (!methodSignature.getReturnType().equals(VoidClassImpl.SIMPLE_NAME)) {
            stringBuffer.append("return ");
        }
        stringBuffer.append(str);
        stringBuffer.append(".");
        stringBuffer.append(methodSignature.getName());
        stringBuffer.append("(this");
        String[] parameterTypes = methodSignature.getParameterTypes();
        for (int i2 = 0; i2 < parameterTypes.length; i2++) {
            StringBuffer stringBuffer2 = new StringBuffer();
            stringBuffer2.append(", p");
            stringBuffer2.append(i2);
            stringBuffer.append(stringBuffer2.toString());
        }
        stringBuffer.append(");");
        emit(stringBuffer.toString());
    }

    public void printJGetArrayValue(int i2, String str, SchemaTypeImpl schemaTypeImpl) {
        switch (i2) {
            case 0:
                StringBuffer stringBuffer = new StringBuffer();
                stringBuffer.append(str);
                stringBuffer.append("[] result = new ");
                stringBuffer.append(str);
                stringBuffer.append("[targetList.size()];");
                emit(stringBuffer.toString());
                emit("targetList.toArray(result);");
                break;
            case 1:
                a.a(this, "boolean[] result = new boolean[targetList.size()];", "for (int i = 0, len = targetList.size() ; i < len ; i++)", "    result[i] = ((org.apache.xmlbeans.SimpleValue)targetList.get(i)).getBooleanValue();");
                break;
            case 2:
                a.a(this, "float[] result = new float[targetList.size()];", "for (int i = 0, len = targetList.size() ; i < len ; i++)", "    result[i] = ((org.apache.xmlbeans.SimpleValue)targetList.get(i)).getFloatValue();");
                break;
            case 3:
                a.a(this, "double[] result = new double[targetList.size()];", "for (int i = 0, len = targetList.size() ; i < len ; i++)", "    result[i] = ((org.apache.xmlbeans.SimpleValue)targetList.get(i)).getDoubleValue();");
                break;
            case 4:
                a.a(this, "byte[] result = new byte[targetList.size()];", "for (int i = 0, len = targetList.size() ; i < len ; i++)", "    result[i] = ((org.apache.xmlbeans.SimpleValue)targetList.get(i)).getByteValue();");
                break;
            case 5:
                a.a(this, "short[] result = new short[targetList.size()];", "for (int i = 0, len = targetList.size() ; i < len ; i++)", "    result[i] = ((org.apache.xmlbeans.SimpleValue)targetList.get(i)).getShortValue();");
                break;
            case 6:
                a.a(this, "int[] result = new int[targetList.size()];", "for (int i = 0, len = targetList.size() ; i < len ; i++)", "    result[i] = ((org.apache.xmlbeans.SimpleValue)targetList.get(i)).getIntValue();");
                break;
            case 7:
                a.a(this, "long[] result = new long[targetList.size()];", "for (int i = 0, len = targetList.size() ; i < len ; i++)", "    result[i] = ((org.apache.xmlbeans.SimpleValue)targetList.get(i)).getLongValue();");
                break;
            case 8:
                a.a(this, "java.math.BigDecimal[] result = new java.math.BigDecimal[targetList.size()];", "for (int i = 0, len = targetList.size() ; i < len ; i++)", "    result[i] = ((org.apache.xmlbeans.SimpleValue)targetList.get(i)).getBigDecimalValue();");
                break;
            case 9:
                a.a(this, "java.math.BigInteger[] result = new java.math.BigInteger[targetList.size()];", "for (int i = 0, len = targetList.size() ; i < len ; i++)", "    result[i] = ((org.apache.xmlbeans.SimpleValue)targetList.get(i)).getBigIntegerValue();");
                break;
            case 10:
                a.a(this, "java.lang.String[] result = new java.lang.String[targetList.size()];", "for (int i = 0, len = targetList.size() ; i < len ; i++)", "    result[i] = ((org.apache.xmlbeans.SimpleValue)targetList.get(i)).getStringValue();");
                break;
            case 11:
                a.a(this, "byte[][] result = new byte[targetList.size()][];", "for (int i = 0, len = targetList.size() ; i < len ; i++)", "    result[i] = ((org.apache.xmlbeans.SimpleValue)targetList.get(i)).getByteArrayValue();");
                break;
            case 12:
                a.a(this, "org.apache.xmlbeans.GDate[] result = new org.apache.xmlbeans.GDate[targetList.size()];", "for (int i = 0, len = targetList.size() ; i < len ; i++)", "    result[i] = ((org.apache.xmlbeans.SimpleValue)targetList.get(i)).getGDateValue();");
                break;
            case 13:
                a.a(this, "org.apache.xmlbeans.GDuration[] result = new org.apache.xmlbeans.GDuration[targetList.size()];", "for (int i = 0, len = targetList.size() ; i < len ; i++)", "    result[i] = ((org.apache.xmlbeans.SimpleValue)targetList.get(i)).getGDurationValue();");
                break;
            case 14:
                a.a(this, "java.util.Date[] result = new java.util.Date[targetList.size()];", "for (int i = 0, len = targetList.size() ; i < len ; i++)", "    result[i] = ((org.apache.xmlbeans.SimpleValue)targetList.get(i)).getDateValue();");
                break;
            case 15:
                a.a(this, "org.apache.poi.javax.xml.namespace.QName[] result = new javax.xml.namespace.QName[targetList.size()];", "for (int i = 0, len = targetList.size() ; i < len ; i++)", "    result[i] = ((org.apache.xmlbeans.SimpleValue)targetList.get(i)).getQNameValue();");
                break;
            case 16:
                a.a(this, "java.util.List[] result = new java.util.List[targetList.size()];", "for (int i = 0, len = targetList.size() ; i < len ; i++)", "    result[i] = ((org.apache.xmlbeans.SimpleValue)targetList.get(i)).getListValue();");
                break;
            case 17:
                a.a(this, "java.util.Calendar[] result = new java.util.Calendar[targetList.size()];", "for (int i = 0, len = targetList.size() ; i < len ; i++)", "    result[i] = ((org.apache.xmlbeans.SimpleValue)targetList.get(i)).getCalendarValue();");
                break;
            case 18:
                StringBuffer stringBuffer2 = new StringBuffer();
                stringBuffer2.append(str);
                stringBuffer2.append("[] result = new ");
                stringBuffer2.append(str);
                stringBuffer2.append("[targetList.size()];");
                emit(stringBuffer2.toString());
                emit("for (int i = 0, len = targetList.size() ; i < len ; i++)");
                StringBuffer stringBuffer3 = new StringBuffer();
                stringBuffer3.append("    result[i] = (");
                stringBuffer3.append(str);
                stringBuffer3.append(")((org.apache.xmlbeans.SimpleValue)targetList.get(i)).getEnumValue();");
                emit(stringBuffer3.toString());
                break;
            case 19:
                a.a(this, "java.lang.Object[] result = new java.lang.Object[targetList.size()];", "for (int i = 0, len = targetList.size() ; i < len ; i++)", "    result[i] = ((org.apache.xmlbeans.SimpleValue)targetList.get(i)).getObjectValue();");
                break;
            case 20:
                StringBuffer stringBuffer4 = new StringBuffer();
                stringBuffer4.append(schemaTypeImpl.getUserTypeName());
                stringBuffer4.append("[] result = new ");
                stringBuffer4.append(schemaTypeImpl.getUserTypeName());
                stringBuffer4.append("[targetList.size()];");
                emit(stringBuffer4.toString());
                emit("for (int i = 0, len = targetList.size() ; i < len ; i++)");
                StringBuffer stringBuffer5 = new StringBuffer();
                stringBuffer5.append("    result[i] = ");
                stringBuffer5.append(getUserTypeStaticHandlerMethod(false, schemaTypeImpl));
                stringBuffer5.append("((org.apache.xmlbeans.SimpleValue)targetList.get(i));");
                emit(stringBuffer5.toString());
                break;
            default:
                throw new IllegalStateException();
        }
        emit("return result;");
    }

    public void printJGetValue(int i2, String str, SchemaTypeImpl schemaTypeImpl) {
        switch (i2) {
            case 0:
                emit("return target;");
                return;
            case 1:
                emit("return target.getBooleanValue();");
                return;
            case 2:
                emit("return target.getFloatValue();");
                return;
            case 3:
                emit("return target.getDoubleValue();");
                return;
            case 4:
                emit("return target.getByteValue();");
                return;
            case 5:
                emit("return target.getShortValue();");
                return;
            case 6:
                emit("return target.getIntValue();");
                return;
            case 7:
                emit("return target.getLongValue();");
                return;
            case 8:
                emit("return target.getBigDecimalValue();");
                return;
            case 9:
                emit("return target.getBigIntegerValue();");
                return;
            case 10:
                emit("return target.getStringValue();");
                return;
            case 11:
                emit("return target.getByteArrayValue();");
                return;
            case 12:
                emit("return target.getGDateValue();");
                return;
            case 13:
                emit("return target.getGDurationValue();");
                return;
            case 14:
                emit("return target.getDateValue();");
                return;
            case 15:
                emit("return target.getQNameValue();");
                return;
            case 16:
                emit("return target.getListValue();");
                return;
            case 17:
                emit("return target.getCalendarValue();");
                return;
            case 18:
                a.a("return (", str, ")target.getEnumValue();", this);
                return;
            case 19:
                emit("return target.getObjectValue();");
                return;
            case 20:
                StringBuffer a = a.a("return ");
                a.append(getUserTypeStaticHandlerMethod(false, schemaTypeImpl));
                a.append("(target);");
                emit(a.toString());
                return;
            default:
                throw new IllegalStateException();
        }
    }

    public void printJSetValue(int i2, String str, SchemaTypeImpl schemaTypeImpl) {
        switch (i2) {
            case 0:
                a.a("target.set(", str, ");", this);
                return;
            case 1:
                a.a("target.setBooleanValue(", str, ");", this);
                return;
            case 2:
                a.a("target.setFloatValue(", str, ");", this);
                return;
            case 3:
                a.a("target.setDoubleValue(", str, ");", this);
                return;
            case 4:
                a.a("target.setByteValue(", str, ");", this);
                return;
            case 5:
                a.a("target.setShortValue(", str, ");", this);
                return;
            case 6:
                a.a("target.setIntValue(", str, ");", this);
                return;
            case 7:
                a.a("target.setLongValue(", str, ");", this);
                return;
            case 8:
                a.a("target.setBigDecimalValue(", str, ");", this);
                return;
            case 9:
                a.a("target.setBigIntegerValue(", str, ");", this);
                return;
            case 10:
                a.a("target.setStringValue(", str, ");", this);
                return;
            case 11:
                a.a("target.setByteArrayValue(", str, ");", this);
                return;
            case 12:
                a.a("target.setGDateValue(", str, ");", this);
                return;
            case 13:
                a.a("target.setGDurationValue(", str, ");", this);
                return;
            case 14:
                a.a("target.setDateValue(", str, ");", this);
                return;
            case 15:
                a.a("target.setQNameValue(", str, ");", this);
                return;
            case 16:
                a.a("target.setListValue(", str, ");", this);
                return;
            case 17:
                a.a("target.setCalendarValue(", str, ");", this);
                return;
            case 18:
                a.a("target.setEnumValue(", str, ");", this);
                return;
            case 19:
                a.a("target.setObjectValue(", str, ");", this);
                return;
            case 20:
                StringBuffer stringBuffer = new StringBuffer();
                stringBuffer.append(getUserTypeStaticHandlerMethod(true, schemaTypeImpl));
                stringBuffer.append("(");
                stringBuffer.append(str);
                stringBuffer.append(", target);");
                emit(stringBuffer.toString());
                return;
            default:
                throw new IllegalStateException();
        }
    }

    public void printJavaDoc(String str) {
        emit("");
        emit("/**");
        StringBuffer stringBuffer = new StringBuffer();
        stringBuffer.append(" * ");
        stringBuffer.append(str);
        emit(stringBuffer.toString());
        emit(" */");
    }

    public void printListGetter15Impl(String str, String str2, String str3, String str4, String str5, boolean z, boolean z2) {
        String str6;
        String str7;
        String a = a.a(str3, SoapEncSchemaTypeSystem.SOAP_ARRAY);
        String a2 = a.a(str3, "List");
        String a3 = a.a(str, ".this.");
        String str8 = "x";
        String a4 = a.a(new StringBuffer(), z2 ? str8 : "", "get");
        StringBuffer stringBuffer = new StringBuffer();
        if (!z2) {
            str8 = "";
        }
        String a5 = a.a(stringBuffer, str8, "set");
        StringBuffer a6 = a.a("Gets ");
        if (z2) {
            str6 = "(as xml) ";
        } else {
            str6 = "";
        }
        a6.append(str6);
        a6.append("a List of ");
        a6.append(str2);
        a6.append(Lucene3xNormsProducer.SEPARATE_NORMS_EXTENSION);
        printJavaDoc(a6.toString());
        StringBuffer stringBuffer2 = new StringBuffer();
        stringBuffer2.append("public java.util.List<");
        stringBuffer2.append(str4);
        stringBuffer2.append("> ");
        stringBuffer2.append(a4);
        stringBuffer2.append(a2);
        stringBuffer2.append("()");
        emit(stringBuffer2.toString());
        startBlock();
        StringBuffer stringBuffer3 = new StringBuffer();
        a.a(stringBuffer3, "final class ", a2, " extends java.util.AbstractList<", str4);
        stringBuffer3.append(GreaterThanPtg.GREATERTHAN);
        emit(stringBuffer3.toString());
        startBlock();
        if (this._useJava15) {
            emit("@Override");
        }
        StringBuffer stringBuffer4 = new StringBuffer();
        stringBuffer4.append("public ");
        stringBuffer4.append(str4);
        stringBuffer4.append(" get(int i)");
        emit(stringBuffer4.toString());
        StringBuffer stringBuffer5 = new StringBuffer();
        stringBuffer5.append("    { return ");
        stringBuffer5.append(a3);
        stringBuffer5.append(a4);
        stringBuffer5.append(a);
        stringBuffer5.append("(i); }");
        emit(stringBuffer5.toString());
        emit("");
        if (this._useJava15) {
            emit("@Override");
        }
        emit(a.a("public ", str4, " set(int i, ", str4, " o)"));
        startBlock();
        StringBuffer stringBuffer6 = new StringBuffer();
        stringBuffer6.append(str4);
        stringBuffer6.append(" old = ");
        stringBuffer6.append(a3);
        stringBuffer6.append(a4);
        stringBuffer6.append(a);
        stringBuffer6.append("(i);");
        emit(stringBuffer6.toString());
        StringBuffer stringBuffer7 = new StringBuffer();
        stringBuffer7.append(a3);
        stringBuffer7.append(a5);
        stringBuffer7.append(a);
        stringBuffer7.append("(i, o);");
        emit(stringBuffer7.toString());
        emit("return old;");
        endBlock();
        emit("");
        if (this._useJava15) {
            emit("@Override");
        }
        a.a("public void add(int i, ", str4, " o)", this);
        if (z || z2) {
            str7 = a2;
            emit(a.a("    { ", a3, "insertNew", str3, "(i).set(o); }"));
        } else {
            str7 = a2;
            emit(a.a("    { ", a3, "insert", str3, "(i, o); }"));
        }
        emit("");
        if (this._useJava15) {
            emit("@Override");
        }
        StringBuffer stringBuffer8 = new StringBuffer();
        stringBuffer8.append("public ");
        stringBuffer8.append(str4);
        stringBuffer8.append(" remove(int i)");
        emit(stringBuffer8.toString());
        startBlock();
        StringBuffer stringBuffer9 = new StringBuffer();
        stringBuffer9.append(str4);
        a.a(stringBuffer9, " old = ", a3, a4, a);
        stringBuffer9.append("(i);");
        emit(stringBuffer9.toString());
        StringBuffer stringBuffer10 = new StringBuffer();
        stringBuffer10.append(a3);
        stringBuffer10.append("remove");
        stringBuffer10.append(str3);
        stringBuffer10.append("(i);");
        emit(stringBuffer10.toString());
        emit("return old;");
        endBlock();
        emit("");
        if (this._useJava15) {
            emit("@Override");
        }
        emit("public int size()");
        StringBuffer stringBuffer11 = new StringBuffer();
        stringBuffer11.append("    { return ");
        stringBuffer11.append(a3);
        stringBuffer11.append("sizeOf");
        stringBuffer11.append(a);
        stringBuffer11.append("(); }");
        emit(stringBuffer11.toString());
        emit("");
        endBlock();
        emit("");
        emitImplementationPreamble();
        StringBuffer stringBuffer12 = new StringBuffer();
        stringBuffer12.append("return new ");
        stringBuffer12.append(str7);
        stringBuffer12.append("();");
        emit(stringBuffer12.toString());
        emitImplementationPostamble();
        endBlock();
    }

    @Override // org.apache.xmlbeans.SchemaCodePrinter
    public void printLoader(Writer writer, SchemaTypeSystem schemaTypeSystem) {
    }

    public void printNestedInnerTypes(SchemaType schemaType, SchemaTypeSystem schemaTypeSystem) {
        boolean z = schemaType.getName() != null && schemaType.getName().equals(schemaType.getBaseType().getName());
        while (schemaType != null) {
            SchemaType[] anonymousTypes = schemaType.getAnonymousTypes();
            for (int i2 = 0; i2 < anonymousTypes.length; i2++) {
                if (anonymousTypes[i2].isSkippedAnonymousType()) {
                    printNestedInnerTypes(anonymousTypes[i2], schemaTypeSystem);
                } else {
                    printInnerType(anonymousTypes[i2], schemaTypeSystem);
                }
            }
            if (!z) {
                return;
            }
            if (schemaType.getDerivationType() == 2 || schemaType.isSimpleType()) {
                schemaType = schemaType.getBaseType();
            } else {
                return;
            }
        }
    }

    public void printNestedTypeImpls(SchemaType schemaType, SchemaTypeSystem schemaTypeSystem) {
        boolean z = schemaType.getName() != null && schemaType.getName().equals(schemaType.getBaseType().getName());
        while (schemaType != null) {
            SchemaType[] anonymousTypes = schemaType.getAnonymousTypes();
            for (int i2 = 0; i2 < anonymousTypes.length; i2++) {
                if (anonymousTypes[i2].isSkippedAnonymousType()) {
                    printNestedTypeImpls(anonymousTypes[i2], schemaTypeSystem);
                } else {
                    printInnerTypeImpl(anonymousTypes[i2], schemaTypeSystem, true);
                }
            }
            if (!z) {
                return;
            }
            if (schemaType.getDerivationType() == 2 || schemaType.isSimpleType()) {
                schemaType = schemaType.getBaseType();
            } else {
                return;
            }
        }
    }

    public void printPackage(SchemaType schemaType, boolean z) {
        String str;
        if (z) {
            str = schemaType.getFullJavaName();
        } else {
            str = schemaType.getFullJavaImplName();
        }
        int lastIndexOf = str.lastIndexOf(46);
        if (lastIndexOf >= 0) {
            a.a("package ", str.substring(0, lastIndexOf), ";", this);
        }
    }

    public void printPropertyGetters(QName qName, boolean z, String str, int i2, String str2, String str3, boolean z2, boolean z3, boolean z4, boolean z5) {
        String str4;
        String str5;
        String str6;
        StringBuffer a = a.a("\"");
        a.append(qName.getLocalPart());
        a.append("\"");
        a.append(z ? " attribute" : " element");
        String stringBuffer = a.toString();
        boolean z6 = i2 == 0;
        if (z5) {
            StringBuffer stringBuffer2 = new StringBuffer();
            stringBuffer2.append(z4 ? "Gets first " : "Gets the ");
            stringBuffer2.append(stringBuffer);
            printJavaDoc(stringBuffer2.toString());
            StringBuffer stringBuffer3 = new StringBuffer();
            stringBuffer3.append(str2);
            a.a(stringBuffer3, " get", str, "();", this);
            if (!z6) {
                StringBuffer stringBuffer4 = new StringBuffer();
                stringBuffer4.append(z4 ? "Gets (as xml) first " : "Gets (as xml) the ");
                stringBuffer4.append(stringBuffer);
                printJavaDoc(stringBuffer4.toString());
                StringBuffer stringBuffer5 = new StringBuffer();
                stringBuffer5.append(str3);
                a.a(stringBuffer5, " xget", str, "();", this);
            }
            if (z2) {
                StringBuffer stringBuffer6 = new StringBuffer();
                stringBuffer6.append(z4 ? "Tests for nil first " : "Tests for nil ");
                stringBuffer6.append(stringBuffer);
                printJavaDoc(stringBuffer6.toString());
                StringBuffer stringBuffer7 = new StringBuffer();
                stringBuffer7.append("boolean isNil");
                stringBuffer7.append(str);
                stringBuffer7.append("();");
                emit(stringBuffer7.toString());
            }
        }
        if (z3) {
            StringBuffer stringBuffer8 = new StringBuffer();
            stringBuffer8.append(z4 ? "True if has at least one " : "True if has ");
            stringBuffer8.append(stringBuffer);
            printJavaDoc(stringBuffer8.toString());
            StringBuffer stringBuffer9 = new StringBuffer();
            stringBuffer9.append("boolean isSet");
            stringBuffer9.append(str);
            stringBuffer9.append("();");
            emit(stringBuffer9.toString());
        }
        if (z4) {
            String a2 = a.a(str, SoapEncSchemaTypeSystem.SOAP_ARRAY);
            if (this._useJava15) {
                String javaWrappedType = isJavaPrimitive(i2) ? javaWrappedType(i2) : str2;
                StringBuffer stringBuffer10 = new StringBuffer();
                str4 = "boolean isNil";
                stringBuffer10.append("Gets a List of ");
                stringBuffer10.append(stringBuffer);
                stringBuffer10.append(Lucene3xNormsProducer.SEPARATE_NORMS_EXTENSION);
                printJavaDoc(stringBuffer10.toString());
                StringBuffer stringBuffer11 = new StringBuffer();
                stringBuffer11.append("java.util.List<");
                stringBuffer11.append(javaWrappedType);
                stringBuffer11.append("> get");
                stringBuffer11.append(str);
                stringBuffer11.append("List();");
                emit(stringBuffer11.toString());
            } else {
                str4 = "boolean isNil";
            }
            if (this._useJava15) {
                emit("");
                emit("/**");
                StringBuffer stringBuffer12 = new StringBuffer();
                str5 = "";
                stringBuffer12.append(" * Gets array of all ");
                stringBuffer12.append(stringBuffer);
                stringBuffer12.append(Lucene3xNormsProducer.SEPARATE_NORMS_EXTENSION);
                emit(stringBuffer12.toString());
                emit(" * @deprecated");
                emit(" */");
                emit("@Deprecated");
            } else {
                str5 = "";
                StringBuffer stringBuffer13 = new StringBuffer();
                stringBuffer13.append("Gets array of all ");
                stringBuffer13.append(stringBuffer);
                stringBuffer13.append(Lucene3xNormsProducer.SEPARATE_NORMS_EXTENSION);
                printJavaDoc(stringBuffer13.toString());
            }
            StringBuffer stringBuffer14 = new StringBuffer();
            stringBuffer14.append(str2);
            stringBuffer14.append("[] get");
            stringBuffer14.append(a2);
            stringBuffer14.append("();");
            emit(stringBuffer14.toString());
            StringBuffer stringBuffer15 = new StringBuffer();
            stringBuffer15.append("Gets ith ");
            stringBuffer15.append(stringBuffer);
            printJavaDoc(stringBuffer15.toString());
            StringBuffer stringBuffer16 = new StringBuffer();
            stringBuffer16.append(str2);
            a.a(stringBuffer16, " get", a2, "(int i);", this);
            if (!z6) {
                if (this._useJava15) {
                    StringBuffer stringBuffer17 = new StringBuffer();
                    stringBuffer17.append("Gets (as xml) a List of ");
                    stringBuffer17.append(stringBuffer);
                    stringBuffer17.append(Lucene3xNormsProducer.SEPARATE_NORMS_EXTENSION);
                    printJavaDoc(stringBuffer17.toString());
                    StringBuffer stringBuffer18 = new StringBuffer();
                    stringBuffer18.append("java.util.List<");
                    stringBuffer18.append(str3);
                    stringBuffer18.append("> xget");
                    str6 = str5;
                    stringBuffer18.append(str);
                    stringBuffer18.append("List();");
                    emit(stringBuffer18.toString());
                } else {
                    str6 = str5;
                }
                if (this._useJava15) {
                    emit(str6);
                    emit("/**");
                    StringBuffer stringBuffer19 = new StringBuffer();
                    stringBuffer19.append(" * Gets (as xml) array of all ");
                    stringBuffer19.append(stringBuffer);
                    stringBuffer19.append(Lucene3xNormsProducer.SEPARATE_NORMS_EXTENSION);
                    emit(stringBuffer19.toString());
                    emit(" * @deprecated");
                    emit(" */");
                    emit("@Deprecated");
                } else {
                    StringBuffer stringBuffer20 = new StringBuffer();
                    stringBuffer20.append("Gets (as xml) array of all ");
                    stringBuffer20.append(stringBuffer);
                    stringBuffer20.append(Lucene3xNormsProducer.SEPARATE_NORMS_EXTENSION);
                    printJavaDoc(stringBuffer20.toString());
                }
                StringBuffer stringBuffer21 = new StringBuffer();
                stringBuffer21.append(str3);
                stringBuffer21.append("[] xget");
                stringBuffer21.append(a2);
                stringBuffer21.append("();");
                emit(stringBuffer21.toString());
                StringBuffer stringBuffer22 = new StringBuffer();
                stringBuffer22.append("Gets (as xml) ith ");
                stringBuffer22.append(stringBuffer);
                printJavaDoc(stringBuffer22.toString());
                StringBuffer stringBuffer23 = new StringBuffer();
                stringBuffer23.append(str3);
                a.a(stringBuffer23, " xget", a2, "(int i);", this);
            }
            if (z2) {
                StringBuffer stringBuffer24 = new StringBuffer();
                stringBuffer24.append("Tests for nil ith ");
                stringBuffer24.append(stringBuffer);
                printJavaDoc(stringBuffer24.toString());
                StringBuffer stringBuffer25 = new StringBuffer();
                stringBuffer25.append(str4);
                stringBuffer25.append(a2);
                stringBuffer25.append("(int i);");
                emit(stringBuffer25.toString());
            }
            StringBuffer stringBuffer26 = new StringBuffer();
            stringBuffer26.append("Returns number of ");
            stringBuffer26.append(stringBuffer);
            printJavaDoc(stringBuffer26.toString());
            StringBuffer stringBuffer27 = new StringBuffer();
            stringBuffer27.append("int sizeOf");
            stringBuffer27.append(a2);
            stringBuffer27.append("();");
            emit(stringBuffer27.toString());
        }
    }

    public void printPropertySetters(QName qName, boolean z, String str, int i2, String str2, String str3, boolean z2, boolean z3, boolean z4, boolean z5) {
        String str4;
        String str5;
        String str6;
        String nonJavaKeyword = NameUtil.nonJavaKeyword(NameUtil.lowerCamelCase(str));
        if (nonJavaKeyword.equals(Complex.DEFAULT_SUFFIX)) {
            nonJavaKeyword = "iValue";
        }
        boolean z6 = i2 == 0;
        StringBuffer a = a.a("\"");
        a.append(qName.getLocalPart());
        a.append("\"");
        a.append(z ? " attribute" : " element");
        String stringBuffer = a.toString();
        if (z5) {
            StringBuffer stringBuffer2 = new StringBuffer();
            stringBuffer2.append(z4 ? "Sets first " : "Sets the ");
            stringBuffer2.append(stringBuffer);
            printJavaDoc(stringBuffer2.toString());
            StringBuffer stringBuffer3 = new StringBuffer();
            stringBuffer3.append("void set");
            a.a(stringBuffer3, str, "(", str2, " ");
            stringBuffer3.append(nonJavaKeyword);
            stringBuffer3.append(");");
            emit(stringBuffer3.toString());
            if (!z6) {
                StringBuffer stringBuffer4 = new StringBuffer();
                stringBuffer4.append(z4 ? "Sets (as xml) first " : "Sets (as xml) the ");
                stringBuffer4.append(stringBuffer);
                printJavaDoc(stringBuffer4.toString());
                StringBuffer stringBuffer5 = new StringBuffer();
                stringBuffer5.append("void xset");
                a.a(stringBuffer5, str, "(", str3, " ");
                stringBuffer5.append(nonJavaKeyword);
                stringBuffer5.append(");");
                emit(stringBuffer5.toString());
            }
            if (z6 && !z4) {
                StringBuffer stringBuffer6 = new StringBuffer();
                stringBuffer6.append("Appends and returns a new empty ");
                stringBuffer6.append(stringBuffer);
                printJavaDoc(stringBuffer6.toString());
                StringBuffer stringBuffer7 = new StringBuffer();
                stringBuffer7.append(str3);
                stringBuffer7.append(" addNew");
                stringBuffer7.append(str);
                stringBuffer7.append("();");
                emit(stringBuffer7.toString());
            }
            if (z2) {
                StringBuffer stringBuffer8 = new StringBuffer();
                stringBuffer8.append(z4 ? "Nils the first " : "Nils the ");
                stringBuffer8.append(stringBuffer);
                printJavaDoc(stringBuffer8.toString());
                StringBuffer stringBuffer9 = new StringBuffer();
                str4 = "void setNil";
                stringBuffer9.append(str4);
                stringBuffer9.append(str);
                stringBuffer9.append("();");
                emit(stringBuffer9.toString());
            } else {
                str4 = "void setNil";
            }
        } else {
            str4 = "void setNil";
        }
        if (z3) {
            StringBuffer stringBuffer10 = new StringBuffer();
            str5 = " addNew";
            stringBuffer10.append(z4 ? "Removes first " : "Unsets the ");
            stringBuffer10.append(stringBuffer);
            printJavaDoc(stringBuffer10.toString());
            StringBuffer stringBuffer11 = new StringBuffer();
            stringBuffer11.append("void unset");
            stringBuffer11.append(str);
            stringBuffer11.append("();");
            emit(stringBuffer11.toString());
        } else {
            str5 = " addNew";
        }
        if (z4) {
            String a2 = a.a(str, SoapEncSchemaTypeSystem.SOAP_ARRAY);
            StringBuffer stringBuffer12 = new StringBuffer();
            stringBuffer12.append("Sets array of all ");
            stringBuffer12.append(stringBuffer);
            printJavaDoc(stringBuffer12.toString());
            StringBuffer stringBuffer13 = new StringBuffer();
            stringBuffer13.append("void set");
            stringBuffer13.append(a2);
            a.a(stringBuffer13, "(", str2, "[] ", nonJavaKeyword);
            stringBuffer13.append("Array);");
            emit(stringBuffer13.toString());
            StringBuffer stringBuffer14 = new StringBuffer();
            stringBuffer14.append("Sets ith ");
            stringBuffer14.append(stringBuffer);
            printJavaDoc(stringBuffer14.toString());
            StringBuffer stringBuffer15 = new StringBuffer();
            a.a(stringBuffer15, "void set", a2, "(int i, ", str2);
            a.a(stringBuffer15, " ", nonJavaKeyword, ");", this);
            if (!z6) {
                StringBuffer stringBuffer16 = new StringBuffer();
                stringBuffer16.append("Sets (as xml) array of all ");
                stringBuffer16.append(stringBuffer);
                printJavaDoc(stringBuffer16.toString());
                StringBuffer stringBuffer17 = new StringBuffer();
                stringBuffer17.append("void xset");
                stringBuffer17.append(a2);
                a.a(stringBuffer17, "(", str3, "[] ", nonJavaKeyword);
                stringBuffer17.append("Array);");
                emit(stringBuffer17.toString());
                StringBuffer stringBuffer18 = new StringBuffer();
                stringBuffer18.append("Sets (as xml) ith ");
                stringBuffer18.append(stringBuffer);
                printJavaDoc(stringBuffer18.toString());
                StringBuffer stringBuffer19 = new StringBuffer();
                a.a(stringBuffer19, "void xset", a2, "(int i, ", str3);
                a.a(stringBuffer19, " ", nonJavaKeyword, ");", this);
            }
            if (z2) {
                StringBuffer stringBuffer20 = new StringBuffer();
                stringBuffer20.append("Nils the ith ");
                stringBuffer20.append(stringBuffer);
                printJavaDoc(stringBuffer20.toString());
                StringBuffer stringBuffer21 = new StringBuffer();
                stringBuffer21.append(str4);
                stringBuffer21.append(a2);
                stringBuffer21.append("(int i);");
                emit(stringBuffer21.toString());
            }
            if (!z6) {
                StringBuffer stringBuffer22 = new StringBuffer();
                stringBuffer22.append("Inserts the value as the ith ");
                stringBuffer22.append(stringBuffer);
                printJavaDoc(stringBuffer22.toString());
                StringBuffer stringBuffer23 = new StringBuffer();
                stringBuffer23.append("void insert");
                str6 = str;
                stringBuffer23.append(str6);
                a.a(stringBuffer23, "(int i, ", str2, " ", nonJavaKeyword);
                stringBuffer23.append(");");
                emit(stringBuffer23.toString());
                StringBuffer stringBuffer24 = new StringBuffer();
                stringBuffer24.append("Appends the value as the last ");
                stringBuffer24.append(stringBuffer);
                printJavaDoc(stringBuffer24.toString());
                StringBuffer stringBuffer25 = new StringBuffer();
                a.a(stringBuffer25, "void add", str6, "(", str2);
                a.a(stringBuffer25, " ", nonJavaKeyword, ");", this);
            } else {
                str6 = str;
            }
            StringBuffer stringBuffer26 = new StringBuffer();
            stringBuffer26.append("Inserts and returns a new empty value (as xml) as the ith ");
            stringBuffer26.append(stringBuffer);
            printJavaDoc(stringBuffer26.toString());
            StringBuffer stringBuffer27 = new StringBuffer();
            stringBuffer27.append(str3);
            stringBuffer27.append(" insertNew");
            stringBuffer27.append(str6);
            stringBuffer27.append("(int i);");
            emit(stringBuffer27.toString());
            StringBuffer stringBuffer28 = new StringBuffer();
            stringBuffer28.append("Appends and returns a new empty value (as xml) as the last ");
            stringBuffer28.append(stringBuffer);
            printJavaDoc(stringBuffer28.toString());
            StringBuffer stringBuffer29 = new StringBuffer();
            stringBuffer29.append(str3);
            stringBuffer29.append(str5);
            stringBuffer29.append(str6);
            stringBuffer29.append("();");
            emit(stringBuffer29.toString());
            StringBuffer stringBuffer30 = new StringBuffer();
            stringBuffer30.append("Removes the ith ");
            stringBuffer30.append(stringBuffer);
            printJavaDoc(stringBuffer30.toString());
            StringBuffer stringBuffer31 = new StringBuffer();
            stringBuffer31.append("void remove");
            stringBuffer31.append(str6);
            stringBuffer31.append("(int i);");
            emit(stringBuffer31.toString());
        }
    }

    public void printSetterImpls(QName qName, SchemaProperty schemaProperty, boolean z, String str, int i2, String str2, String str3, boolean z2, boolean z3, boolean z4, boolean z5, boolean z6, String str4, String str5, SchemaType schemaType) {
        String str6;
        String str7;
        String str8;
        String str9;
        String str10;
        String str11;
        String str12;
        String str13;
        String str14;
        String str15;
        SchemaType schemaType2;
        boolean z7;
        String str16;
        String str17;
        String str18;
        String str19;
        String str20;
        String str21;
        String str22;
        String str23;
        String str24;
        String str25;
        String str26;
        String str27;
        String str28;
        String str29;
        String str30;
        String str31;
        String str32;
        String str33;
        String str34;
        String str35;
        String str36;
        String str37;
        String str38;
        String str39;
        String str40;
        String str41;
        String str42;
        String str43;
        SchemaType schemaType3;
        String str44;
        String str45;
        String str46;
        String str47;
        String str48;
        String str49;
        String str50;
        String str51;
        String str52;
        String str53;
        String str54;
        String str55;
        String str56;
        String str57;
        String str58;
        boolean z8;
        String str59;
        String str60;
        SchemaType schemaType4;
        String str61;
        String str62;
        String str63;
        String str64;
        String str65;
        String str66;
        String str67;
        String str68;
        String nonExtraKeyword = NameUtil.nonExtraKeyword(NameUtil.nonJavaKeyword(NameUtil.lowerCamelCase(str)));
        boolean z9 = i2 == 0;
        boolean z10 = i2 == 19;
        boolean z11 = str4 != str5;
        String str69 = (z6 || !z9) ? "org.apache.xmlbeans.SimpleValue" : str3;
        StringBuffer a = a.a("\"");
        a.append(qName.getLocalPart());
        a.append("\"");
        a.append(z ? " attribute" : " element");
        String stringBuffer = a.toString();
        String str70 = "0";
        if (z5) {
            StringBuffer stringBuffer2 = new StringBuffer();
            stringBuffer2.append(z4 ? "Sets first " : "Sets the ");
            stringBuffer2.append(stringBuffer);
            printJavaDoc(stringBuffer2.toString());
            StringBuffer stringBuffer3 = new StringBuffer();
            stringBuffer3.append("public void set");
            a.a(stringBuffer3, str, "(", str2, " ");
            stringBuffer3.append(nonExtraKeyword);
            stringBuffer3.append(")");
            emit(stringBuffer3.toString());
            startBlock();
            if (!z9 || z11) {
                str53 = "public void xset";
                str10 = "public void set";
                str52 = ")";
                str50 = stringBuffer;
                str6 = str69;
                str51 = "public ";
                emitImplementationPreamble();
                if (z4) {
                    str65 = str70;
                } else {
                    str65 = "-1";
                }
                emitPre(schemaType, 1, str4, z, str65);
                str12 = ", ";
                str14 = nonExtraKeyword;
                emitGetTarget(str5, str4, z, "0", 3, str6);
                printJSetValue(i2, str14, (SchemaTypeImpl) schemaProperty.getType());
                if (z4) {
                    str66 = str70;
                } else {
                    str66 = "-1";
                }
                emitPost(schemaType, 1, str4, z, str66);
                emitImplementationPostamble();
            } else {
                if (z4) {
                    str67 = str70;
                } else {
                    str67 = "-1";
                }
                str10 = "public void set";
                str52 = ")";
                str53 = "public void xset";
                str51 = "public ";
                str50 = stringBuffer;
                str6 = str69;
                emitPre(schemaType, 1, str4, z, str67);
                StringBuffer c = a.c("generatedSetterHelperImpl(", nonExtraKeyword, ", ", str5, ", 0, ");
                c.append("org.apache.xmlbeans.impl.values.XmlObjectBase.KIND_SETTERHELPER_SINGLETON);");
                emit(c.toString());
                if (z4) {
                    str68 = str70;
                } else {
                    str68 = "-1";
                }
                emitPost(schemaType, 1, str4, z, str68);
                str12 = ", ";
                str14 = nonExtraKeyword;
            }
            endBlock();
            if (!z9) {
                StringBuffer stringBuffer4 = new StringBuffer();
                stringBuffer4.append(z4 ? "Sets (as xml) first " : "Sets (as xml) the ");
                stringBuffer4.append(str50);
                printJavaDoc(stringBuffer4.toString());
                StringBuffer stringBuffer5 = new StringBuffer();
                stringBuffer5.append(str53);
                a.a(stringBuffer5, str, "(", str3, " ");
                stringBuffer5.append(str14);
                stringBuffer5.append(str52);
                emit(stringBuffer5.toString());
                startBlock();
                emitImplementationPreamble();
                if (z4) {
                    str63 = str70;
                } else {
                    str63 = "-1";
                }
                str54 = " ";
                str56 = str52;
                emitPre(schemaType, 1, str4, z, str63);
                str55 = "(";
                str15 = str50;
                emitGetTarget(str5, str4, z, "0", 3, str3);
                str57 = ");";
                a.a("target.set(", str14, str57, this);
                if (z4) {
                    str64 = str70;
                } else {
                    str64 = "-1";
                }
                emitPost(schemaType, 1, str4, z, str64);
                emitImplementationPostamble();
                endBlock();
            } else {
                str57 = ");";
                str55 = "(";
                str15 = str50;
                str54 = " ";
                str56 = str52;
            }
            if (!z9 || z4) {
                schemaType4 = schemaType;
                str60 = "()";
                str16 = str55;
                str59 = str51;
                str13 = str53;
                str58 = str54;
                str9 = str56;
                str17 = str57;
                z8 = z;
            } else {
                StringBuffer stringBuffer6 = new StringBuffer();
                stringBuffer6.append("Appends and returns a new empty ");
                stringBuffer6.append(str15);
                printJavaDoc(stringBuffer6.toString());
                StringBuffer stringBuffer7 = new StringBuffer();
                str59 = str51;
                stringBuffer7.append(str59);
                stringBuffer7.append(str3);
                stringBuffer7.append(" addNew");
                stringBuffer7.append(str);
                str60 = "()";
                stringBuffer7.append(str60);
                emit(stringBuffer7.toString());
                startBlock();
                emitImplementationPreamble();
                emitDeclareTarget(true, str3);
                schemaType4 = schemaType;
                str13 = str53;
                str16 = str55;
                str58 = str54;
                str9 = str56;
                str17 = str57;
                z8 = z;
                emitPre(schemaType4, 2, str4, z8);
                emitAddTarget(str4, z8, true, str3);
                emitPost(schemaType4, 2, str4, z8);
                emit("return target;");
                emitImplementationPostamble();
                endBlock();
            }
            if (z2) {
                StringBuffer stringBuffer8 = new StringBuffer();
                stringBuffer8.append(z4 ? "Nils the first " : "Nils the ");
                stringBuffer8.append(str15);
                printJavaDoc(stringBuffer8.toString());
                StringBuffer stringBuffer9 = new StringBuffer();
                stringBuffer9.append("public void setNil");
                stringBuffer9.append(str);
                stringBuffer9.append(str60);
                emit(stringBuffer9.toString());
                startBlock();
                emitImplementationPreamble();
                if (z4) {
                    str61 = str70;
                } else {
                    str61 = "-1";
                }
                schemaType2 = schemaType4;
                str8 = str60;
                str7 = str59;
                emitPre(schemaType, 1, str4, z, str61);
                str11 = str58;
                z7 = z8;
                emitGetTarget(str5, str4, z, "0", 3, str3);
                emit("target.setNil();");
                if (z4) {
                    str62 = str70;
                } else {
                    str62 = "-1";
                }
                emitPost(schemaType, 1, str4, z, str62);
                emitImplementationPostamble();
                endBlock();
            } else {
                schemaType2 = schemaType4;
                str8 = str60;
                str7 = str59;
                str11 = str58;
                z7 = z8;
            }
        } else {
            str13 = "public void xset";
            z7 = z;
            schemaType2 = schemaType;
            str10 = "public void set";
            str8 = "()";
            str9 = ")";
            str7 = "public ";
            str6 = str69;
            str11 = " ";
            str16 = "(";
            str12 = ", ";
            str17 = ");";
            str15 = stringBuffer;
            str14 = nonExtraKeyword;
        }
        if (z3) {
            StringBuffer stringBuffer10 = new StringBuffer();
            stringBuffer10.append(z4 ? "Removes first " : "Unsets the ");
            stringBuffer10.append(str15);
            printJavaDoc(stringBuffer10.toString());
            StringBuffer stringBuffer11 = new StringBuffer();
            stringBuffer11.append("public void unset");
            stringBuffer11.append(str);
            stringBuffer11.append(str8);
            emit(stringBuffer11.toString());
            startBlock();
            emitImplementationPreamble();
            if (z4) {
                str48 = str70;
            } else {
                str48 = "-1";
            }
            emitPre(schemaType, 3, str4, z, str48);
            if (z7) {
                str49 = str4;
                a.a("get_store().remove_attribute(", str49, str17, this);
            } else {
                str49 = str4;
                a.a("get_store().remove_element(", str5, ", 0);", this);
            }
            if (!z4) {
                str70 = "-1";
            }
            str8 = str8;
            str18 = str49;
            emitPost(schemaType, 3, str4, z, str70);
            emitImplementationPostamble();
            endBlock();
        } else {
            str18 = str4;
        }
        if (z4) {
            String a2 = a.a(str, SoapEncSchemaTypeSystem.SOAP_ARRAY);
            if (z9) {
                StringBuffer stringBuffer12 = new StringBuffer();
                stringBuffer12.append("Sets array of all ");
                stringBuffer12.append(str15);
                stringBuffer12.append("  WARNING: This method is not atomicaly synchronized.");
                printJavaDoc(stringBuffer12.toString());
                StringBuffer stringBuffer13 = new StringBuffer();
                stringBuffer13.append(str10);
                str21 = str15;
                str20 = str8;
                str22 = str2;
                a.a(stringBuffer13, a2, str16, str22, "[] ");
                stringBuffer13.append(str14);
                stringBuffer13.append("Array)");
                emit(stringBuffer13.toString());
                startBlock();
                emit("check_orphaned();");
                emitPre(schemaType2, 1, str18, z7);
                if (!z10) {
                    str23 = str12;
                    if (!z11) {
                        StringBuffer c2 = a.c("arraySetterHelper(", str14, SoapEncSchemaTypeSystem.SOAP_ARRAY, str23, str18);
                        c2.append(str17);
                        emit(c2.toString());
                    } else {
                        a.a(a.c("arraySetterHelper(", str14, SoapEncSchemaTypeSystem.SOAP_ARRAY, str23, str18), str23, str5, str17, this);
                    }
                } else if (!z11) {
                    str23 = str12;
                    StringBuffer c3 = a.c("unionArraySetterHelper(", str14, SoapEncSchemaTypeSystem.SOAP_ARRAY, str23, str18);
                    c3.append(str17);
                    emit(c3.toString());
                } else {
                    str23 = str12;
                    a.a(a.c("unionArraySetterHelper(", str14, SoapEncSchemaTypeSystem.SOAP_ARRAY, str23, str18), str23, str5, str17, this);
                }
                emitPost(schemaType2, 1, str18, z7);
                endBlock();
                str19 = a2;
                str24 = "arraySetterHelper(";
                str25 = str10;
            } else {
                str21 = str15;
                str23 = str12;
                str20 = str8;
                str22 = str2;
                StringBuffer stringBuffer14 = new StringBuffer();
                stringBuffer14.append("Sets array of all ");
                stringBuffer14.append(str21);
                printJavaDoc(stringBuffer14.toString());
                StringBuffer stringBuffer15 = new StringBuffer();
                str25 = str10;
                stringBuffer15.append(str25);
                stringBuffer15.append(a2);
                str19 = a2;
                a.a(stringBuffer15, str16, str22, "[] ", str14);
                stringBuffer15.append("Array)");
                emit(stringBuffer15.toString());
                startBlock();
                emitImplementationPreamble();
                emitPre(schemaType2, 1, str18, z7);
                if (z10) {
                    if (!z11) {
                        StringBuffer c4 = a.c("unionArraySetterHelper(", str14, SoapEncSchemaTypeSystem.SOAP_ARRAY, str23, str18);
                        c4.append(str17);
                        emit(c4.toString());
                    } else {
                        a.a(a.c("unionArraySetterHelper(", str14, SoapEncSchemaTypeSystem.SOAP_ARRAY, str23, str18), str23, str5, str17, this);
                    }
                } else if (schemaProperty.getJavaTypeCode() != 20) {
                    if (!z11) {
                        str24 = "arraySetterHelper(";
                        StringBuffer c5 = a.c(str24, str14, SoapEncSchemaTypeSystem.SOAP_ARRAY, str23, str18);
                        c5.append(str17);
                        emit(c5.toString());
                    } else {
                        str24 = "arraySetterHelper(";
                        a.a(a.c(str24, str14, SoapEncSchemaTypeSystem.SOAP_ARRAY, str23, str18), str23, str5, str17, this);
                    }
                    emitPost(schemaType2, 1, str18, z7);
                    emitImplementationPostamble();
                    endBlock();
                } else if (!z11) {
                    StringBuffer c6 = a.c("org.apache.xmlbeans.SimpleValue[] dests = arraySetterHelper(", str14, "Array.length", str23, str18);
                    c6.append(str17);
                    emit(c6.toString());
                    emit("for ( int i = 0 ; i < dests.length ; i++ ) {");
                    StringBuffer stringBuffer16 = new StringBuffer();
                    stringBuffer16.append("    ");
                    stringBuffer16.append(getUserTypeStaticHandlerMethod(true, (SchemaTypeImpl) schemaProperty.getType()));
                    stringBuffer16.append(str16);
                    stringBuffer16.append(str14);
                    stringBuffer16.append("Array[i], dests[i]);");
                    emit(stringBuffer16.toString());
                    emit("}");
                } else {
                    a.a(a.c("org.apache.xmlbeans.SimpleValue[] dests = arraySetterHelper(", str14, "Array.length", str23, str18), str23, str5, str17, this);
                    emit("for ( int i = 0 ; i < dests.length ; i++ ) {");
                    StringBuffer stringBuffer17 = new StringBuffer();
                    stringBuffer17.append("    ");
                    stringBuffer17.append(getUserTypeStaticHandlerMethod(true, (SchemaTypeImpl) schemaProperty.getType()));
                    stringBuffer17.append(str16);
                    stringBuffer17.append(str14);
                    stringBuffer17.append("Array[i], dests[i]);");
                    emit(stringBuffer17.toString());
                    emit("}");
                }
                str24 = "arraySetterHelper(";
                emitPost(schemaType2, 1, str18, z7);
                emitImplementationPostamble();
                endBlock();
            }
            StringBuffer stringBuffer18 = new StringBuffer();
            stringBuffer18.append("Sets ith ");
            stringBuffer18.append(str21);
            printJavaDoc(stringBuffer18.toString());
            StringBuffer stringBuffer19 = new StringBuffer();
            stringBuffer19.append(str25);
            stringBuffer19.append(str19);
            a.a(stringBuffer19, "(int i, ", str22, str11, str14);
            stringBuffer19.append(str9);
            emit(stringBuffer19.toString());
            startBlock();
            if (!z9 || z11) {
                str33 = "(int i, ";
                str26 = str19;
                str27 = str21;
                str29 = str9;
                str28 = "Array)";
                str32 = str24;
                str30 = str11;
                str34 = SoapEncSchemaTypeSystem.SOAP_ARRAY;
                emitImplementationPreamble();
                emitPre(schemaType, 1, str4, z, Complex.DEFAULT_SUFFIX);
                str31 = str18;
                emitGetTarget(str5, str4, z, Complex.DEFAULT_SUFFIX, 4, str6);
                printJSetValue(i2, str14, (SchemaTypeImpl) schemaProperty.getType());
                str35 = str16;
                emitPost(schemaType, 1, str4, z, Complex.DEFAULT_SUFFIX);
                emitImplementationPostamble();
            } else {
                str33 = "(int i, ";
                str29 = str9;
                str32 = str24;
                str28 = "Array)";
                str27 = str21;
                str26 = str19;
                str30 = str11;
                str34 = SoapEncSchemaTypeSystem.SOAP_ARRAY;
                emitPre(schemaType, 1, str4, z, Complex.DEFAULT_SUFFIX);
                StringBuffer c7 = a.c("generatedSetterHelperImpl(", str14, str23, str5, ", i, ");
                c7.append("org.apache.xmlbeans.impl.values.XmlObjectBase.KIND_SETTERHELPER_ARRAYITEM);");
                emit(c7.toString());
                emitPost(schemaType, 1, str4, z, Complex.DEFAULT_SUFFIX);
                str31 = str18;
                str35 = str16;
            }
            endBlock();
            if (!z9) {
                StringBuffer stringBuffer20 = new StringBuffer();
                stringBuffer20.append("Sets (as xml) array of all ");
                stringBuffer20.append(str27);
                printJavaDoc(stringBuffer20.toString());
                StringBuffer stringBuffer21 = new StringBuffer();
                stringBuffer21.append(str13);
                stringBuffer21.append(str26);
                a.a(stringBuffer21, str35, str3, "[]", str14);
                stringBuffer21.append(str28);
                emit(stringBuffer21.toString());
                startBlock();
                emitImplementationPreamble();
                emitPre(schemaType, 1, str31, z7);
                StringBuffer stringBuffer22 = new StringBuffer();
                a.a(stringBuffer22, str32, str14, str34, str23);
                stringBuffer22.append(str31);
                stringBuffer22.append(str17);
                emit(stringBuffer22.toString());
                emitPost(schemaType, 1, str31, z7);
                emitImplementationPostamble();
                endBlock();
                StringBuffer stringBuffer23 = new StringBuffer();
                stringBuffer23.append("Sets (as xml) ith ");
                stringBuffer23.append(str27);
                printJavaDoc(stringBuffer23.toString());
                StringBuffer stringBuffer24 = new StringBuffer();
                stringBuffer24.append(str13);
                str40 = str30;
                a.a(stringBuffer24, str26, str33, str3, str40);
                stringBuffer24.append(str14);
                stringBuffer24.append(str29);
                emit(stringBuffer24.toString());
                startBlock();
                emitImplementationPreamble();
                str38 = str29;
                str36 = str26;
                str39 = str27;
                emitPre(schemaType, 1, str4, z, Complex.DEFAULT_SUFFIX);
                str37 = str23;
                str41 = str35;
                emitGetTarget(str5, str4, z, Complex.DEFAULT_SUFFIX, 4, str3);
                a.a("target.set(", str14, str17, this);
                emitPost(schemaType, 1, str4, z, Complex.DEFAULT_SUFFIX);
                emitImplementationPostamble();
                endBlock();
            } else {
                str37 = str23;
                str40 = str30;
                str38 = str29;
                str39 = str27;
                str36 = str26;
                str41 = str35;
            }
            if (z2) {
                StringBuffer stringBuffer25 = new StringBuffer();
                stringBuffer25.append("Nils the ith ");
                stringBuffer25.append(str39);
                printJavaDoc(stringBuffer25.toString());
                StringBuffer stringBuffer26 = new StringBuffer();
                stringBuffer26.append("public void setNil");
                stringBuffer26.append(str36);
                stringBuffer26.append("(int i)");
                emit(stringBuffer26.toString());
                startBlock();
                emitImplementationPreamble();
                emitPre(schemaType, 1, str4, z, Complex.DEFAULT_SUFFIX);
                emitGetTarget(str5, str4, z, Complex.DEFAULT_SUFFIX, 4, str3);
                emit("target.setNil();");
                emitPost(schemaType, 1, str4, z, Complex.DEFAULT_SUFFIX);
                emitImplementationPostamble();
                endBlock();
            }
            if (!z9) {
                StringBuffer stringBuffer27 = new StringBuffer();
                stringBuffer27.append("Inserts the value as the ith ");
                stringBuffer27.append(str39);
                printJavaDoc(stringBuffer27.toString());
                StringBuffer stringBuffer28 = new StringBuffer();
                stringBuffer28.append("public void insert");
                stringBuffer28.append(str);
                a.a(stringBuffer28, str33, str2, str40, str14);
                stringBuffer28.append(str38);
                emit(stringBuffer28.toString());
                startBlock();
                emitImplementationPreamble();
                str42 = "(int i)";
                str44 = ", i);";
                emitPre(schemaType, 2, str4, z, Complex.DEFAULT_SUFFIX);
                StringBuffer stringBuffer29 = new StringBuffer();
                stringBuffer29.append(str6);
                stringBuffer29.append(" target = ");
                emit(stringBuffer29.toString());
                indent();
                if (!z11) {
                    emit(a.a(str41, str6, ")get_store().insert_element_user(", str31, str44));
                    str47 = str37;
                } else {
                    str47 = str37;
                    StringBuffer c8 = a.c(str41, str6, ")get_store().insert_element_user(", str5, str47);
                    c8.append(str31);
                    c8.append(str44);
                    emit(c8.toString());
                }
                outdent();
                printJSetValue(i2, str14, (SchemaTypeImpl) schemaProperty.getType());
                str43 = str47;
                emitPost(schemaType, 2, str4, z, Complex.DEFAULT_SUFFIX);
                emitImplementationPostamble();
                endBlock();
                StringBuffer stringBuffer30 = new StringBuffer();
                stringBuffer30.append("Appends the value as the last ");
                stringBuffer30.append(str39);
                printJavaDoc(stringBuffer30.toString());
                StringBuffer stringBuffer31 = new StringBuffer();
                stringBuffer31.append("public void add");
                str45 = str;
                stringBuffer31.append(str45);
                a.a(stringBuffer31, str41, str2, str40, str14);
                stringBuffer31.append(str38);
                emit(stringBuffer31.toString());
                startBlock();
                emitImplementationPreamble();
                emitDeclareTarget(true, str6);
                schemaType3 = schemaType;
                emitPre(schemaType3, 2, str31, z);
                emitAddTarget(str31, z, true, str6);
                printJSetValue(i2, str14, (SchemaTypeImpl) schemaProperty.getType());
                emitPost(schemaType3, 2, str31, z);
                emitImplementationPostamble();
                endBlock();
            } else {
                schemaType3 = schemaType;
                str42 = "(int i)";
                str43 = str37;
                str44 = ", i);";
                str45 = str;
            }
            StringBuffer stringBuffer32 = new StringBuffer();
            stringBuffer32.append("Inserts and returns a new empty value (as xml) as the ith ");
            stringBuffer32.append(str39);
            printJavaDoc(stringBuffer32.toString());
            StringBuffer stringBuffer33 = new StringBuffer();
            stringBuffer33.append(str7);
            stringBuffer33.append(str3);
            stringBuffer33.append(" insertNew");
            stringBuffer33.append(str45);
            stringBuffer33.append(str42);
            emit(stringBuffer33.toString());
            startBlock();
            emitImplementationPreamble();
            emitDeclareTarget(true, str3);
            emitPre(schemaType, 2, str4, z, Complex.DEFAULT_SUFFIX);
            if (!z11) {
                emit(a.a("target = (", str3, ")get_store().insert_element_user(", str31, str44));
                str46 = str5;
            } else {
                str46 = str5;
                StringBuffer c9 = a.c("target = (", str3, ")get_store().insert_element_user(", str46, str43);
                c9.append(str31);
                c9.append(str44);
                emit(c9.toString());
            }
            emitPost(schemaType, 2, str4, z, Complex.DEFAULT_SUFFIX);
            emit("return target;");
            emitImplementationPostamble();
            endBlock();
            StringBuffer stringBuffer34 = new StringBuffer();
            stringBuffer34.append("Appends and returns a new empty value (as xml) as the last ");
            stringBuffer34.append(str39);
            printJavaDoc(stringBuffer34.toString());
            StringBuffer stringBuffer35 = new StringBuffer();
            stringBuffer35.append(str7);
            stringBuffer35.append(str3);
            stringBuffer35.append(" addNew");
            stringBuffer35.append(str45);
            stringBuffer35.append(str20);
            emit(stringBuffer35.toString());
            startBlock();
            emitImplementationPreamble();
            emitDeclareTarget(true, str3);
            emitPre(schemaType3, 2, str31, z);
            emitAddTarget(str31, z, true, str3);
            emitPost(schemaType3, 2, str31, z);
            emit("return target;");
            emitImplementationPostamble();
            endBlock();
            StringBuffer stringBuffer36 = new StringBuffer();
            stringBuffer36.append("Removes the ith ");
            stringBuffer36.append(str39);
            printJavaDoc(stringBuffer36.toString());
            StringBuffer stringBuffer37 = new StringBuffer();
            stringBuffer37.append("public void remove");
            stringBuffer37.append(str45);
            stringBuffer37.append(str42);
            emit(stringBuffer37.toString());
            startBlock();
            emitImplementationPreamble();
            emitPre(schemaType, 3, str4, z, Complex.DEFAULT_SUFFIX);
            a.a("get_store().remove_element(", str46, str44, this);
            emitPost(schemaType, 3, str4, z, Complex.DEFAULT_SUFFIX);
            emitImplementationPostamble();
            endBlock();
        }
    }

    public void printShortJavaDoc(String str) {
        a.a("/** ", str, " */", this);
    }

    public Map printStaticFields(SchemaProperty[] schemaPropertyArr) {
        HashMap hashMap = new HashMap();
        emit("");
        for (int i2 = 0; i2 < schemaPropertyArr.length; i2++) {
            String[] strArr = new String[2];
            SchemaProperty schemaProperty = schemaPropertyArr[i2];
            QName name = schemaProperty.getName();
            hashMap.put(name, strArr);
            String javaPropertyName = schemaProperty.getJavaPropertyName();
            StringBuffer c = a.c(javaPropertyName, "$");
            int i3 = i2 * 2;
            c.append(i3);
            strArr[0] = c.toString().toUpperCase();
            StringBuffer a = a.a("\"");
            a.append(name.getNamespaceURI());
            a.append("\"");
            String stringBuffer = a.toString();
            StringBuffer a2 = a.a("private static final javax.xml.namespace.QName ");
            a2.append(strArr[0]);
            a2.append(" = ");
            emit(a2.toString());
            indent();
            StringBuffer stringBuffer2 = new StringBuffer();
            stringBuffer2.append("new javax.xml.namespace.QName(");
            stringBuffer2.append(stringBuffer);
            stringBuffer2.append(", \"");
            stringBuffer2.append(name.getLocalPart());
            stringBuffer2.append("\");");
            emit(stringBuffer2.toString());
            outdent();
            if (schemaPropertyArr[i2].acceptedNames() != null) {
                QName[] acceptedNames = schemaPropertyArr[i2].acceptedNames();
                if (acceptedNames.length > 1) {
                    StringBuffer c2 = a.c(javaPropertyName, "$");
                    c2.append(i3 + 1);
                    strArr[1] = c2.toString().toUpperCase();
                    StringBuffer a3 = a.a("private static final org.apache.xmlbeans.QNameSet ");
                    a3.append(strArr[1]);
                    a3.append(" = org.apache.xmlbeans.QNameSet.forArray( new javax.xml.namespace.QName[] { ");
                    emit(a3.toString());
                    indent();
                    for (int i4 = 0; i4 < acceptedNames.length; i4++) {
                        StringBuffer a4 = a.a("new javax.xml.namespace.QName(\"");
                        a4.append(acceptedNames[i4].getNamespaceURI());
                        a4.append("\", \"");
                        a4.append(acceptedNames[i4].getLocalPart());
                        a4.append("\"),");
                        emit(a4.toString());
                    }
                    outdent();
                    emit("});");
                }
            }
        }
        emit("");
        return hashMap;
    }

    public void printStaticTypeDeclaration(SchemaType schemaType, SchemaTypeSystem schemaTypeSystem) {
        String shortJavaName = schemaType.getShortJavaName();
        emit("public static final org.apache.xmlbeans.SchemaType type = (org.apache.xmlbeans.SchemaType)");
        indent();
        StringBuffer c = a.c("org.apache.xmlbeans.XmlBeans.typeSystemForClassLoader(", shortJavaName, ".class.getClassLoader(), \"");
        c.append(schemaTypeSystem.getName());
        c.append("\")");
        c.append(".resolveHandle(\"");
        c.append(((SchemaTypeSystemImpl) schemaTypeSystem).handleForType(schemaType));
        c.append("\");");
        emit(c.toString());
        outdent();
    }

    public void printStringEnumeration(SchemaType schemaType) {
        String fullJavaName = schemaType.getBaseEnumType().getFullJavaName();
        boolean hasBase = hasBase(schemaType);
        if (!hasBase) {
            a.a(this, "", "org.apache.xmlbeans.StringEnumAbstractBase enumValue();", "void set(org.apache.xmlbeans.StringEnumAbstractBase e);");
        }
        emit("");
        SchemaStringEnumEntry[] stringEnumEntries = schemaType.getStringEnumEntries();
        HashSet hashSet = new HashSet();
        HashSet hashSet2 = new HashSet();
        for (int i2 = 0; i2 < stringEnumEntries.length; i2++) {
            String string = stringEnumEntries[i2].getString();
            if (hashSet.contains(string)) {
                hashSet2.add(string);
            } else {
                hashSet.add(string);
                String enumName = stringEnumEntries[i2].getEnumName();
                if (hasBase) {
                    StringBuffer c = a.c("static final ", fullJavaName, ".Enum ", enumName, " = ");
                    c.append(fullJavaName);
                    c.append(".");
                    c.append(enumName);
                    c.append(";");
                    emit(c.toString());
                } else {
                    StringBuffer c2 = a.c("static final Enum ", enumName, " = Enum.forString(\"");
                    c2.append(javaStringEscape(string));
                    c2.append("\");");
                    emit(c2.toString());
                }
            }
        }
        emit("");
        for (int i3 = 0; i3 < stringEnumEntries.length; i3++) {
            if (!hashSet2.contains(stringEnumEntries[i3].getString())) {
                StringBuffer a = a.a("INT_");
                a.append(stringEnumEntries[i3].getEnumName());
                String stringBuffer = a.toString();
                if (hasBase) {
                    StringBuffer c3 = a.c("static final int ", stringBuffer, " = ", fullJavaName, ".");
                    c3.append(stringBuffer);
                    c3.append(";");
                    emit(c3.toString());
                } else {
                    emit(a.a("static final int ", stringBuffer, " = Enum.", stringBuffer, ";"));
                }
            }
        }
        if (!hasBase) {
            emit("");
            emit("/**");
            StringBuffer stringBuffer2 = new StringBuffer();
            stringBuffer2.append(" * Enumeration value class for ");
            stringBuffer2.append(fullJavaName);
            stringBuffer2.append(".");
            emit(stringBuffer2.toString());
            emit(" * These enum values can be used as follows:");
            emit(" * <pre>");
            emit(" * enum.toString(); // returns the string value of the enum");
            emit(" * enum.intValue(); // returns an int value, useful for switches");
            if (stringEnumEntries.length > 0) {
                StringBuffer a2 = a.a(" * // e.g., case Enum.INT_");
                a2.append(stringEnumEntries[0].getEnumName());
                emit(a2.toString());
            }
            emit(" * Enum.forString(s); // returns the enum value for a string");
            emit(" * Enum.forInt(i); // returns the enum value for an int");
            emit(" * </pre>");
            emit(" * Enumeration objects are immutable singleton objects that");
            emit(" * can be compared using == object equality. They have no");
            emit(" * public constructor. See the constants defined within this");
            emit(" * class for all the valid values.");
            emit(" */");
            emit("static final class Enum extends org.apache.xmlbeans.StringEnumAbstractBase");
            emit("{");
            indent();
            emit("/**");
            emit(" * Returns the enum value for a string, or null if none.");
            emit(" */");
            emit("public static Enum forString(java.lang.String s)");
            emit("    { return (Enum)table.forString(s); }");
            emit("/**");
            emit(" * Returns the enum value corresponding to an int, or null if none.");
            emit(" */");
            emit("public static Enum forInt(int i)");
            emit("    { return (Enum)table.forInt(i); }");
            emit("");
            emit("private Enum(java.lang.String s, int i)");
            emit("    { super(s, i); }");
            emit("");
            for (int i4 = 0; i4 < stringEnumEntries.length; i4++) {
                StringBuffer a3 = a.a("INT_");
                a3.append(stringEnumEntries[i4].getEnumName());
                String stringBuffer3 = a3.toString();
                int intValue = stringEnumEntries[i4].getIntValue();
                StringBuffer stringBuffer4 = new StringBuffer();
                stringBuffer4.append("static final int ");
                stringBuffer4.append(stringBuffer3);
                stringBuffer4.append(" = ");
                stringBuffer4.append(intValue);
                stringBuffer4.append(";");
                emit(stringBuffer4.toString());
            }
            emit("");
            emit("public static final org.apache.xmlbeans.StringEnumAbstractBase.Table table =");
            emit("    new org.apache.xmlbeans.StringEnumAbstractBase.Table");
            emit("(");
            indent();
            emit("new Enum[]");
            emit("{");
            indent();
            for (int i5 = 0; i5 < stringEnumEntries.length; i5++) {
                String string2 = stringEnumEntries[i5].getString();
                StringBuffer a4 = a.a("INT_");
                a4.append(stringEnumEntries[i5].getEnumName());
                String stringBuffer5 = a4.toString();
                StringBuffer a5 = a.a("new Enum(\"");
                a5.append(javaStringEscape(string2));
                a5.append("\", ");
                a5.append(stringBuffer5);
                a5.append("),");
                emit(a5.toString());
            }
            outdent();
            emit("}");
            outdent();
            emit(");");
            emit("private static final long serialVersionUID = 1L;");
            emit("private java.lang.Object readResolve() { return forInt(intValue()); } ");
            outdent();
            emit("}");
        }
    }

    public void printTopComment(SchemaType schemaType) {
        emit("/*");
        if (schemaType.getName() != null) {
            StringBuffer a = a.a(" * XML Type:  ");
            a.append(schemaType.getName().getLocalPart());
            emit(a.toString());
            StringBuffer stringBuffer = new StringBuffer();
            stringBuffer.append(" * Namespace: ");
            stringBuffer.append(schemaType.getName().getNamespaceURI());
            emit(stringBuffer.toString());
        } else {
            QName qName = null;
            if (schemaType.isDocumentType()) {
                qName = schemaType.getDocumentElementName();
                emit(" * An XML document type.");
            } else if (schemaType.isAttributeType()) {
                qName = schemaType.getAttributeTypeAttributeName();
                emit(" * An XML attribute type.");
            } else if (!$assertionsDisabled) {
                throw new AssertionError();
            }
            if ($assertionsDisabled || qName != null) {
                StringBuffer a2 = a.a(" * Localname: ");
                a2.append(qName.getLocalPart());
                emit(a2.toString());
                StringBuffer stringBuffer2 = new StringBuffer();
                stringBuffer2.append(" * Namespace: ");
                stringBuffer2.append(qName.getNamespaceURI());
                emit(stringBuffer2.toString());
            } else {
                throw new AssertionError();
            }
        }
        StringBuffer a3 = a.a(" * Java type: ");
        a3.append(schemaType.getFullJavaName());
        emit(a3.toString());
        emit(" *");
        emit(" * Automatically generated - do not modify.");
        emit(" */");
    }

    public void startBlock() {
        emit("{");
        indent();
    }

    public void startClass(SchemaType schemaType, boolean z) {
        SchemaType[] unionMemberTypes;
        String shortJavaImplName = schemaType.getShortJavaImplName();
        String baseClass = getBaseClass(schemaType);
        StringBuffer stringBuffer = new StringBuffer();
        stringBuffer.append(schemaType.getFullJavaName().replace('$', NameUtil.PERIOD));
        if (schemaType.getSimpleVariety() == 2) {
            for (SchemaType schemaType2 : schemaType.getUnionMemberTypes()) {
                StringBuffer a = a.a(", ");
                a.append(schemaType2.getFullJavaName().replace('$', NameUtil.PERIOD));
                stringBuffer.append(a.toString());
            }
        }
        StringBuffer a2 = a.a("public ");
        a.a(a2, z ? "static " : "", "class ", shortJavaImplName, " extends ");
        a2.append(baseClass);
        a2.append(" implements ");
        a2.append(stringBuffer.toString());
        emit(a2.toString());
        startBlock();
        emit("private static final long serialVersionUID = 1L;");
    }

    public void startInterface(SchemaType schemaType) {
        String shortJavaName = schemaType.getShortJavaName();
        String findJavaType = findJavaType(schemaType.getBaseType());
        StringBuffer stringBuffer = new StringBuffer();
        stringBuffer.append("public interface ");
        stringBuffer.append(shortJavaName);
        stringBuffer.append(" extends ");
        stringBuffer.append(findJavaType);
        stringBuffer.append(getExtensionInterfaces(schemaType));
        emit(stringBuffer.toString());
        emit("{");
        indent();
        emitSpecializedAccessors(schemaType);
    }

    public String xmlTypeForProperty(SchemaProperty schemaProperty) {
        return findJavaType(schemaProperty.javaBasedOnType()).replace('$', NameUtil.PERIOD);
    }

    public void emitPost(SchemaType schemaType, int i2, String str, boolean z, String str2) {
        PrePostExtension prePostExtension;
        SchemaTypeImpl impl = getImpl(schemaType);
        if (impl != null && (prePostExtension = impl.getPrePostExtension()) != null) {
            if (prePostExtension.hasPreCall()) {
                endBlock();
            }
            if (prePostExtension.hasPostCall()) {
                StringBuffer stringBuffer = new StringBuffer();
                stringBuffer.append(prePostExtension.getStaticHandler());
                stringBuffer.append(".postSet(");
                stringBuffer.append(prePostOpString(i2));
                stringBuffer.append(", this, ");
                stringBuffer.append(str);
                stringBuffer.append(", ");
                stringBuffer.append(z);
                a.a(stringBuffer, ", ", str2, ");", this);
            }
        }
    }

    public void emitPre(SchemaType schemaType, int i2, String str, boolean z, String str2) {
        PrePostExtension prePostExtension;
        SchemaTypeImpl impl = getImpl(schemaType);
        if (impl != null && (prePostExtension = impl.getPrePostExtension()) != null && prePostExtension.hasPreCall()) {
            StringBuffer a = a.a("if ( ");
            a.append(prePostExtension.getStaticHandler());
            a.append(".preSet(");
            a.append(prePostOpString(i2));
            a.append(", this, ");
            a.append(str);
            a.append(", ");
            a.append(z);
            a.append(", ");
            a.append(str2);
            a.append("))");
            emit(a.toString());
            startBlock();
        }
    }

    @Override // org.apache.xmlbeans.SchemaCodePrinter
    public void printType(Writer writer, SchemaType schemaType) {
        this._writer = writer;
        printTopComment(schemaType);
        printPackage(schemaType, true);
        emit("");
        printInnerType(schemaType, schemaType.getTypeSystem());
        this._writer.flush();
    }

    @Override // org.apache.xmlbeans.SchemaCodePrinter
    public void printTypeImpl(Writer writer, SchemaType schemaType) {
        this._writer = writer;
        printTopComment(schemaType);
        printPackage(schemaType, false);
        printInnerTypeImpl(schemaType, schemaType.getTypeSystem(), false);
    }
}
