package org.apache.xmlbeans.impl.schema;

import b.b.a.a.a;
import java.io.File;
import java.io.IOException;
import java.io.PrintStream;
import java.io.Writer;
import java.net.MalformedURLException;
import java.net.URI;
import java.util.ArrayList;
import java.util.Arrays;
import java.util.Collection;
import java.util.HashMap;
import java.util.HashSet;
import java.util.Iterator;
import java.util.List;
import java.util.Map;
import java.util.Set;
import org.apache.xmlbeans.BindingConfig;
import org.apache.xmlbeans.Filer;
import org.apache.xmlbeans.SchemaType;
import org.apache.xmlbeans.SchemaTypeLoader;
import org.apache.xmlbeans.SchemaTypeSystem;
import org.apache.xmlbeans.XmlErrorCodes;
import org.apache.xmlbeans.XmlException;
import org.apache.xmlbeans.XmlObject;
import org.apache.xmlbeans.XmlOptions;
import org.apache.xmlbeans.impl.common.XmlErrorWatcher;
import org.apache.xmlbeans.impl.schema.StscImporter;
import org.apache.xmlbeans.impl.xb.xsdschema.SchemaDocument;

public class SchemaTypeSystemCompiler {

    public static class Parameters {
        public URI baseURI;
        public BindingConfig config;
        public Collection errorListener;
        public SchemaTypeSystem existingSystem;
        public boolean javaize;
        public SchemaTypeLoader linkTo;
        public String name;
        public XmlOptions options;
        public SchemaDocument.Schema[] schemas;
        public File schemasDir;
        public Map sourcesToCopyMap;

        public URI getBaseURI() {
            return this.baseURI;
        }

        public BindingConfig getConfig() {
            return this.config;
        }

        public Collection getErrorListener() {
            return this.errorListener;
        }

        public SchemaTypeSystem getExistingTypeSystem() {
            return this.existingSystem;
        }

        public SchemaTypeLoader getLinkTo() {
            return this.linkTo;
        }

        public String getName() {
            return this.name;
        }

        public XmlOptions getOptions() {
            return this.options;
        }

        public SchemaDocument.Schema[] getSchemas() {
            return this.schemas;
        }

        public File getSchemasDir() {
            return this.schemasDir;
        }

        public Map getSourcesToCopyMap() {
            return this.sourcesToCopyMap;
        }

        public boolean isJavaize() {
            return this.javaize;
        }

        public void setBaseURI(URI uri) {
            this.baseURI = uri;
        }

        public void setConfig(BindingConfig bindingConfig) {
            this.config = bindingConfig;
        }

        public void setErrorListener(Collection collection) {
            this.errorListener = collection;
        }

        public void setExistingTypeSystem(SchemaTypeSystem schemaTypeSystem) {
            this.existingSystem = schemaTypeSystem;
        }

        public void setJavaize(boolean z) {
            this.javaize = z;
        }

        public void setLinkTo(SchemaTypeLoader schemaTypeLoader) {
            this.linkTo = schemaTypeLoader;
        }

        public void setName(String str) {
            this.name = str;
        }

        public void setOptions(XmlOptions xmlOptions) {
            this.options = xmlOptions;
        }

        public void setSchemas(SchemaDocument.Schema[] schemaArr) {
            this.schemas = schemaArr;
        }

        public void setSchemasDir(File file) {
            this.schemasDir = file;
        }

        public void setSourcesToCopyMap(Map map) {
            this.sourcesToCopyMap = map;
        }
    }

    public static SchemaTypeSystem compile(Parameters parameters) {
        return compileImpl(parameters.getExistingTypeSystem(), parameters.getName(), parameters.getSchemas(), parameters.getConfig(), parameters.getLinkTo(), parameters.getOptions(), parameters.getErrorListener(), parameters.isJavaize(), parameters.getBaseURI(), parameters.getSourcesToCopyMap(), parameters.getSchemasDir());
    }

    public static SchemaTypeSystemImpl compileImpl(SchemaTypeSystem schemaTypeSystem, String str, SchemaDocument.Schema[] schemaArr, BindingConfig bindingConfig, SchemaTypeLoader schemaTypeLoader, XmlOptions xmlOptions, Collection collection, boolean z, URI uri, Map map, File file) {
        if (schemaTypeLoader != null) {
            XmlErrorWatcher xmlErrorWatcher = new XmlErrorWatcher(collection);
            boolean z2 = schemaTypeSystem != null;
            StscState start = StscState.start();
            boolean z3 = xmlOptions == null || !xmlOptions.hasOption(XmlOptions.COMPILE_NO_VALIDATION);
            try {
                start.setErrorListener(xmlErrorWatcher);
                start.setBindingConfig(bindingConfig);
                start.setOptions(xmlOptions);
                start.setGivenTypeSystemName(str);
                start.setSchemasDir(file);
                if (uri != null) {
                    start.setBaseUri(uri);
                }
                start.setImportingTypeLoader(SchemaTypeLoaderImpl.build(new SchemaTypeLoader[]{BuiltinSchemaTypeSystem.get(), schemaTypeLoader}, null, null));
                ArrayList arrayList = new ArrayList(schemaArr.length);
                if (z3) {
                    XmlOptions errorListener = new XmlOptions().setErrorListener(xmlErrorWatcher);
                    if (xmlOptions.hasOption(XmlOptions.VALIDATE_TREAT_LAX_AS_SKIP)) {
                        errorListener.setValidateTreatLaxAsSkip();
                    }
                    for (int i2 = 0; i2 < schemaArr.length; i2++) {
                        if (schemaArr[i2].validate(errorListener)) {
                            arrayList.add(schemaArr[i2]);
                        }
                    }
                } else {
                    arrayList.addAll(Arrays.asList(schemaArr));
                }
                SchemaDocument.Schema[] schemaArr2 = (SchemaDocument.Schema[]) arrayList.toArray(new SchemaDocument.Schema[arrayList.size()]);
                if (z2) {
                    HashSet hashSet = new HashSet();
                    schemaArr2 = getSchemasToRecompile((SchemaTypeSystemImpl) schemaTypeSystem, schemaArr2, hashSet);
                    start.initFromTypeSystem((SchemaTypeSystemImpl) schemaTypeSystem, hashSet);
                } else {
                    start.setDependencies(new SchemaDependencies());
                }
                StscTranslator.addAllDefinitions(StscImporter.resolveImportsAndIncludes(schemaArr2, z2));
                StscResolver.resolveAll();
                StscChecker.checkAll();
                StscJavaizer.javaizeAllTypes(z);
                StscState.get().sts().loadFromStscState(start);
                if (map != null) {
                    map.putAll(start.sourceCopyMap());
                }
                if (xmlErrorWatcher.hasError()) {
                    if (!start.allowPartial() || start.getRecovered() != xmlErrorWatcher.size()) {
                        StscState.end();
                        return null;
                    }
                    StscState.get().sts().setIncomplete(true);
                }
                if (schemaTypeSystem != null) {
                    ((SchemaTypeSystemImpl) schemaTypeSystem).setIncomplete(true);
                }
                return StscState.get().sts();
            } finally {
                StscState.end();
            }
        } else {
            throw new IllegalArgumentException("Must supply linkTo");
        }
    }

    /* JADX WARNING: Failed to process nested try/catch */
    /* JADX WARNING: Missing exception handler attribute for start block: B:27:0x0085 */
    /* JADX WARNING: Removed duplicated region for block: B:30:0x0092 A[SYNTHETIC, Splitter:B:30:0x0092] */
    /* JADX WARNING: Removed duplicated region for block: B:57:0x003c A[SYNTHETIC] */
    public static boolean generateTypes(SchemaTypeSystem schemaTypeSystem, Filer filer, XmlOptions xmlOptions) {
        if ((schemaTypeSystem instanceof SchemaTypeSystemImpl) && ((SchemaTypeSystemImpl) schemaTypeSystem).isIncomplete()) {
            return false;
        }
        boolean z = true;
        ArrayList arrayList = new ArrayList();
        arrayList.addAll(Arrays.asList(schemaTypeSystem.globalTypes()));
        arrayList.addAll(Arrays.asList(schemaTypeSystem.documentTypes()));
        arrayList.addAll(Arrays.asList(schemaTypeSystem.attributeTypes()));
        Iterator it = arrayList.iterator();
        while (it.hasNext()) {
            SchemaType schemaType = (SchemaType) it.next();
            if (!schemaType.isBuiltinType() && schemaType.getFullJavaName() != null) {
                Writer writer = null;
                try {
                    writer = filer.createSourceFile(schemaType.getFullJavaName());
                    SchemaTypeCodePrinter.printType(writer, schemaType, xmlOptions);
                    if (writer != null) {
                        writer.close();
                    }
                } catch (IOException e2) {
                    PrintStream printStream = System.err;
                    StringBuffer stringBuffer = new StringBuffer();
                    stringBuffer.append("IO Error ");
                    stringBuffer.append(e2);
                    printStream.println(stringBuffer.toString());
                    if (writer != null) {
                        try {
                            writer.close();
                        } catch (IOException unused) {
                        }
                    }
                    z = false;
                } catch (Throwable th) {
                    if (writer != null) {
                        try {
                            writer.close();
                        } catch (IOException unused2) {
                        }
                    }
                    throw th;
                }
                try {
                    writer = filer.createSourceFile(schemaType.getFullJavaImplName());
                    SchemaTypeCodePrinter.printTypeImpl(writer, schemaType, xmlOptions);
                    if (writer == null) {
                        try {
                            writer.close();
                        } catch (IOException unused3) {
                        }
                    }
                } catch (IOException e3) {
                    PrintStream printStream2 = System.err;
                    StringBuffer stringBuffer2 = new StringBuffer();
                    stringBuffer2.append("IO Error ");
                    stringBuffer2.append(e3);
                    printStream2.println(stringBuffer2.toString());
                    if (writer != null) {
                        try {
                            writer.close();
                        } catch (IOException unused4) {
                        }
                    }
                    z = false;
                } catch (Throwable th2) {
                    if (writer != null) {
                        try {
                            writer.close();
                        } catch (IOException unused5) {
                        }
                    }
                    throw th2;
                }
            }
        }
        return z;
    }

    public static SchemaDocument.Schema[] getSchemasToRecompile(SchemaTypeSystemImpl schemaTypeSystemImpl, SchemaDocument.Schema[] schemaArr, Set set) {
        HashSet hashSet = new HashSet();
        HashMap hashMap = new HashMap();
        ArrayList arrayList = new ArrayList();
        for (int i2 = 0; i2 < schemaArr.length; i2++) {
            String sourceName = schemaArr[i2].documentProperties().getSourceName();
            if (sourceName != null) {
                hashSet.add(sourceName);
                hashMap.put(sourceName, schemaArr[i2]);
                arrayList.add(schemaArr[i2]);
            } else {
                throw new IllegalArgumentException("One of the Schema files passed in doesn't have the source set, which prevents it to be incrementally compiled");
            }
        }
        SchemaDependencies dependencies = schemaTypeSystemImpl.getDependencies();
        set.addAll(dependencies.computeTransitiveClosure(dependencies.getNamespacesTouched(hashSet)));
        List filesTouched = dependencies.getFilesTouched(set);
        StscState.get().setDependencies(new SchemaDependencies(dependencies, set));
        for (int i3 = 0; i3 < filesTouched.size(); i3++) {
            String str = (String) filesTouched.get(i3);
            if (((SchemaDocument.Schema) hashMap.get(str)) == null) {
                try {
                    XmlObject downloadDocument = StscImporter.DownloadTable.downloadDocument(StscState.get().getS4SLoader(), null, str);
                    XmlOptions xmlOptions = new XmlOptions();
                    xmlOptions.setErrorListener(StscState.get().getErrorListener());
                    if (downloadDocument instanceof SchemaDocument) {
                        if (downloadDocument.validate(xmlOptions)) {
                            arrayList.add(((SchemaDocument) downloadDocument).getSchema());
                        }
                    }
                    StscState stscState = StscState.get();
                    StringBuffer stringBuffer = new StringBuffer();
                    stringBuffer.append("Referenced document is not a valid schema, URL = ");
                    stringBuffer.append(str);
                    stscState.error(stringBuffer.toString(), 56, (XmlObject) null);
                } catch (MalformedURLException e2) {
                    StscState.get().error(XmlErrorCodes.EXCEPTION_LOADING_URL, new Object[]{"MalformedURLException", str, e2.getMessage()}, (XmlObject) null);
                } catch (IOException e3) {
                    StscState.get().error(XmlErrorCodes.EXCEPTION_LOADING_URL, new Object[]{"IOException", str, e3.getMessage()}, (XmlObject) null);
                } catch (XmlException e4) {
                    StscState.get().error(XmlErrorCodes.EXCEPTION_LOADING_URL, new Object[]{"XmlException", str, e4.getMessage()}, (XmlObject) null);
                }
            }
        }
        return (SchemaDocument.Schema[]) arrayList.toArray(new SchemaDocument.Schema[arrayList.size()]);
    }

    public static SchemaTypeSystemImpl compile(String str, SchemaTypeSystem schemaTypeSystem, XmlObject[] xmlObjectArr, BindingConfig bindingConfig, SchemaTypeLoader schemaTypeLoader, Filer filer, XmlOptions xmlOptions) {
        XmlOptions maskNull = XmlOptions.maskNull(xmlOptions);
        ArrayList arrayList = new ArrayList();
        if (xmlObjectArr != null) {
            for (int i2 = 0; i2 < xmlObjectArr.length; i2++) {
                if (xmlObjectArr[i2] instanceof SchemaDocument.Schema) {
                    arrayList.add(xmlObjectArr[i2]);
                } else if (!(xmlObjectArr[i2] instanceof SchemaDocument) || ((SchemaDocument) xmlObjectArr[i2]).getSchema() == null) {
                    StringBuffer a = a.a("Thread ");
                    a.append(Thread.currentThread().getName());
                    a.append(": The ");
                    a.append(i2);
                    a.append("th supplied input is not a schema document: its type is ");
                    a.append(xmlObjectArr[i2].schemaType());
                    throw new XmlException(a.toString());
                } else {
                    arrayList.add(((SchemaDocument) xmlObjectArr[i2]).getSchema());
                }
            }
        }
        XmlErrorWatcher xmlErrorWatcher = new XmlErrorWatcher((Collection) maskNull.get(XmlOptions.ERROR_LISTENER));
        SchemaTypeSystemImpl compileImpl = compileImpl(schemaTypeSystem, str, (SchemaDocument.Schema[]) arrayList.toArray(new SchemaDocument.Schema[arrayList.size()]), bindingConfig, schemaTypeLoader, maskNull, xmlErrorWatcher, filer != null, (URI) maskNull.get(XmlOptions.BASE_URI), null, null);
        if (!xmlErrorWatcher.hasError() || compileImpl != null) {
            if (!(compileImpl == null || compileImpl.isIncomplete() || filer == null)) {
                compileImpl.save(filer);
                generateTypes(compileImpl, filer, maskNull);
            }
            return compileImpl;
        }
        throw new XmlException(xmlErrorWatcher.firstError());
    }
}
