package org.apache.xmlbeans.impl.schema;

import b.b.a.a.a;
import java.io.ByteArrayOutputStream;
import java.io.DataInputStream;
import java.io.DataOutputStream;
import java.io.File;
import java.io.IOException;
import java.io.InputStream;
import java.io.OutputStream;
import java.math.BigInteger;
import java.util.ArrayList;
import java.util.Arrays;
import java.util.Collections;
import java.util.HashMap;
import java.util.HashSet;
import java.util.Iterator;
import java.util.LinkedHashMap;
import java.util.LinkedHashSet;
import java.util.List;
import java.util.Map;
import java.util.Random;
import java.util.Set;
import java.util.zip.ZipEntry;
import java.util.zip.ZipFile;
import org.apache.lucene.codecs.lucene3x.Lucene3xNormsProducer;
import org.apache.poi.javax.xml.namespace.QName;
import org.apache.poi.openxml4j.opc.PackageRelationship;
import org.apache.poi.openxml4j.opc.internal.ZipHelper;
import org.apache.xmlbeans.Filer;
import org.apache.xmlbeans.QNameSet;
import org.apache.xmlbeans.ResourceLoader;
import org.apache.xmlbeans.SchemaAnnotation;
import org.apache.xmlbeans.SchemaAttributeGroup;
import org.apache.xmlbeans.SchemaAttributeModel;
import org.apache.xmlbeans.SchemaComponent;
import org.apache.xmlbeans.SchemaGlobalAttribute;
import org.apache.xmlbeans.SchemaGlobalElement;
import org.apache.xmlbeans.SchemaIdentityConstraint;
import org.apache.xmlbeans.SchemaLocalAttribute;
import org.apache.xmlbeans.SchemaLocalElement;
import org.apache.xmlbeans.SchemaModelGroup;
import org.apache.xmlbeans.SchemaParticle;
import org.apache.xmlbeans.SchemaProperty;
import org.apache.xmlbeans.SchemaStringEnumEntry;
import org.apache.xmlbeans.SchemaType;
import org.apache.xmlbeans.SchemaTypeLoader;
import org.apache.xmlbeans.SchemaTypeLoaderException;
import org.apache.xmlbeans.SchemaTypeSystem;
import org.apache.xmlbeans.SimpleValue;
import org.apache.xmlbeans.SystemProperties;
import org.apache.xmlbeans.XmlAnySimpleType;
import org.apache.xmlbeans.XmlBeans;
import org.apache.xmlbeans.XmlObject;
import org.apache.xmlbeans.XmlOptions;
import org.apache.xmlbeans.impl.common.JarHelper;
import org.apache.xmlbeans.impl.common.NameUtil;
import org.apache.xmlbeans.impl.common.QNameHelper;
import org.apache.xmlbeans.impl.common.XBeanDebug;
import org.apache.xmlbeans.impl.regex.RegularExpression;
import org.apache.xmlbeans.impl.schema.SchemaAnnotationImpl;
import org.apache.xmlbeans.impl.schema.StscComplexTypeResolver;
import org.apache.xmlbeans.impl.util.FilerImpl;
import org.apache.xmlbeans.impl.util.HexBin;
import org.apache.xmlbeans.impl.values.XmlObjectBase;
import org.apache.xmlbeans.impl.xb.xsdschema.AttributeGroupDocument;
import org.apache.xmlbeans.impl.xb.xsdschema.GroupDocument;
import org.apache.xmlbeans.soap.SOAPArrayType;
import org.apache.xmlbeans.soap.SchemaWSDLArrayType;
import repackage.Repackager;

public class SchemaTypeSystemImpl extends SchemaTypeLoaderBase implements SchemaTypeSystem {
    public static final /* synthetic */ boolean $assertionsDisabled;
    public static final int CONSTANT_CLASS = 7;
    public static final int CONSTANT_DOUBLE = 6;
    public static final int CONSTANT_FIELD = 9;
    public static final int CONSTANT_FLOAT = 4;
    public static final int CONSTANT_INTEGER = 3;
    public static final int CONSTANT_INTERFACEMETHOD = 11;
    public static final int CONSTANT_LONG = 5;
    public static final int CONSTANT_METHOD = 10;
    public static final int CONSTANT_NAMEANDTYPE = 12;
    public static final int CONSTANT_STRING = 8;
    public static final int CONSTANT_UNICODE = 2;
    public static final int CONSTANT_UTF8 = 1;
    public static final int DATA_BABE = -629491010;
    public static final SchemaAttributeGroup[] EMPTY_AG_ARRAY = new SchemaAttributeGroup[0];
    public static final SchemaAnnotation[] EMPTY_ANN_ARRAY = new SchemaAnnotation[0];
    public static final SchemaGlobalAttribute[] EMPTY_GA_ARRAY = new SchemaGlobalAttribute[0];
    public static final SchemaGlobalElement[] EMPTY_GE_ARRAY = new SchemaGlobalElement[0];
    public static final SchemaIdentityConstraint[] EMPTY_IC_ARRAY = new SchemaIdentityConstraint[0];
    public static final SchemaModelGroup[] EMPTY_MG_ARRAY = new SchemaModelGroup[0];
    public static final SchemaType[] EMPTY_ST_ARRAY = new SchemaType[0];
    public static final int FIELD_GLOBAL = 1;
    public static final int FIELD_LOCALATTR = 2;
    public static final int FIELD_LOCALELT = 3;
    public static final int FIELD_NONE = 0;
    public static final int FILETYPE_SCHEMAATTRIBUTE = 4;
    public static final int FILETYPE_SCHEMAATTRIBUTEGROUP = 7;
    public static final int FILETYPE_SCHEMAELEMENT = 3;
    public static final int FILETYPE_SCHEMAIDENTITYCONSTRAINT = 8;
    public static final int FILETYPE_SCHEMAINDEX = 1;
    public static final int FILETYPE_SCHEMAMODELGROUP = 6;
    public static final int FILETYPE_SCHEMAPOINTER = 5;
    public static final int FILETYPE_SCHEMATYPE = 2;
    public static final int FLAG_ABSTRACT = 262144;
    public static final int FLAG_ATTRIBUTE_TYPE = 524288;
    public static final int FLAG_BLOCK_EXT = 4096;
    public static final int FLAG_BLOCK_REST = 8192;
    public static final int FLAG_BOUNDED = 8;
    public static final int FLAG_COMPILED = 2048;
    public static final int FLAG_DOCUMENT_TYPE = 2;
    public static final int FLAG_FINAL_EXT = 16384;
    public static final int FLAG_FINAL_LIST = 131072;
    public static final int FLAG_FINAL_REST = 32768;
    public static final int FLAG_FINAL_UNION = 65536;
    public static final int FLAG_FINITE = 16;
    public static final int FLAG_HAS_PATTERN = 256;
    public static final int FLAG_NUMERIC = 32;
    public static final int FLAG_ORDERED = 4;
    public static final int FLAG_ORDER_SENSITIVE = 512;
    public static final int FLAG_PART_ABSTRACT = 128;
    public static final int FLAG_PART_BLOCKEXT = 16;
    public static final int FLAG_PART_BLOCKREST = 32;
    public static final int FLAG_PART_BLOCKSUBST = 64;
    public static final int FLAG_PART_FINALEXT = 256;
    public static final int FLAG_PART_FINALREST = 512;
    public static final int FLAG_PART_FIXED = 4;
    public static final int FLAG_PART_NILLABLE = 8;
    public static final int FLAG_PART_SKIPPABLE = 1;
    public static final int FLAG_PROP_ISATTR = 1;
    public static final int FLAG_PROP_JAVAARRAY = 8;
    public static final int FLAG_PROP_JAVAOPTIONAL = 4;
    public static final int FLAG_PROP_JAVASINGLETON = 2;
    public static final int FLAG_SIMPLE_TYPE = 1;
    public static final int FLAG_STRINGENUM = 64;
    public static final int FLAG_TOTAL_ORDER = 1024;
    public static final int FLAG_UNION_OF_LISTS = 128;
    public static final String HOLDER_TEMPLATE_CLASS = "org.apache.xmlbeans.impl.schema.TypeSystemHolder";
    public static final String HOLDER_TEMPLATE_CLASSFILE = "TypeSystemHolder.template";
    public static final String[] HOLDER_TEMPLATE_NAMES = makeClassStrings(HOLDER_TEMPLATE_CLASS);
    public static final int MAJOR_VERSION = 2;
    public static final int MAX_UNSIGNED_SHORT = 65535;
    public static String METADATA_PACKAGE_GEN = null;
    public static final int MINOR_VERSION = 24;
    public static final int RELEASE_NUMBER = 0;
    public static final byte[] SINGLE_ZERO_BYTE = {0};
    public static byte[] _mask = new byte[16];
    public static Random _random;
    public static /* synthetic */ Class class$org$apache$xmlbeans$SchemaTypeSystem;
    public static /* synthetic */ Class class$org$apache$xmlbeans$impl$schema$SchemaTypeSystemImpl;
    public boolean _allNonGroupHandlesResolved = false;
    public List _annotations;
    public Map _attributeGroups;
    public Map _attributeTypes;
    public String _basePackage;
    public ClassLoader _classloader;
    public Map _containers = new HashMap();
    public SchemaDependencies _deps;
    public Map _documentTypes;
    public Filer _filer;
    public Map _globalAttributes;
    public Map _globalElements;
    public Map _globalTypes;
    public Map _identityConstraints = Collections.EMPTY_MAP;
    public boolean _incomplete = false;
    public SchemaTypeLoader _linker;
    public HandlePool _localHandles;
    public Map _modelGroups;
    public String _name;
    public Set _namespaces;
    public List _redefinedAttributeGroups;
    public List _redefinedGlobalTypes;
    public List _redefinedModelGroups;
    public final Map _resolvedHandles = new HashMap();
    public ResourceLoader _resourceLoader;
    public Map _typeRefsByClassname = new HashMap();

    public class HandlePool {
        public Map _componentsToHandles = new LinkedHashMap();
        public Map _handlesToRefs = new LinkedHashMap();
        public boolean _started;

        public HandlePool() {
        }

        private String addUniqueHandle(SchemaComponent schemaComponent, String str) {
            String lowerCase = str.toLowerCase();
            int i2 = 2;
            String str2 = lowerCase;
            while (this._handlesToRefs.containsKey(str2)) {
                str2 = a.b(lowerCase, i2);
                i2++;
            }
            this._handlesToRefs.put(str2, schemaComponent.getComponentRef());
            this._componentsToHandles.put(schemaComponent, str2);
            return str2;
        }

        public Set getAllHandles() {
            return this._handlesToRefs.keySet();
        }

        public String handleForAttribute(SchemaGlobalAttribute schemaGlobalAttribute) {
            if (schemaGlobalAttribute == null) {
                return null;
            }
            if (schemaGlobalAttribute.getTypeSystem() == SchemaTypeSystemImpl.this.getTypeSystem()) {
                String str = (String) this._componentsToHandles.get(schemaGlobalAttribute);
                if (str != null) {
                    return str;
                }
                StringBuffer stringBuffer = new StringBuffer();
                stringBuffer.append(NameUtil.upperCamelCase(schemaGlobalAttribute.getName().getLocalPart()));
                stringBuffer.append("Attribute");
                return addUniqueHandle(schemaGlobalAttribute, stringBuffer.toString());
            }
            throw new IllegalArgumentException("Cannot supply handles for types from another type system");
        }

        public String handleForAttributeGroup(SchemaAttributeGroup schemaAttributeGroup) {
            if (schemaAttributeGroup == null) {
                return null;
            }
            if (schemaAttributeGroup.getTypeSystem() == SchemaTypeSystemImpl.this.getTypeSystem()) {
                String str = (String) this._componentsToHandles.get(schemaAttributeGroup);
                if (str != null) {
                    return str;
                }
                StringBuffer stringBuffer = new StringBuffer();
                stringBuffer.append(NameUtil.upperCamelCase(schemaAttributeGroup.getName().getLocalPart()));
                stringBuffer.append("AttributeGroup");
                return addUniqueHandle(schemaAttributeGroup, stringBuffer.toString());
            }
            throw new IllegalArgumentException("Cannot supply handles for types from another type system");
        }

        public String handleForComponent(SchemaComponent schemaComponent) {
            if (schemaComponent == null) {
                return null;
            }
            if (schemaComponent.getTypeSystem() != SchemaTypeSystemImpl.this.getTypeSystem()) {
                throw new IllegalArgumentException("Cannot supply handles for types from another type system");
            } else if (schemaComponent instanceof SchemaType) {
                return handleForType((SchemaType) schemaComponent);
            } else {
                if (schemaComponent instanceof SchemaGlobalElement) {
                    return handleForElement((SchemaGlobalElement) schemaComponent);
                }
                if (schemaComponent instanceof SchemaGlobalAttribute) {
                    return handleForAttribute((SchemaGlobalAttribute) schemaComponent);
                }
                if (schemaComponent instanceof SchemaModelGroup) {
                    return handleForModelGroup((SchemaModelGroup) schemaComponent);
                }
                if (schemaComponent instanceof SchemaAttributeGroup) {
                    return handleForAttributeGroup((SchemaAttributeGroup) schemaComponent);
                }
                if (schemaComponent instanceof SchemaIdentityConstraint) {
                    return handleForIdentityConstraint((SchemaIdentityConstraint) schemaComponent);
                }
                throw new IllegalStateException("Component type cannot have a handle");
            }
        }

        public String handleForElement(SchemaGlobalElement schemaGlobalElement) {
            if (schemaGlobalElement == null) {
                return null;
            }
            if (schemaGlobalElement.getTypeSystem() == SchemaTypeSystemImpl.this.getTypeSystem()) {
                String str = (String) this._componentsToHandles.get(schemaGlobalElement);
                if (str != null) {
                    return str;
                }
                StringBuffer stringBuffer = new StringBuffer();
                stringBuffer.append(NameUtil.upperCamelCase(schemaGlobalElement.getName().getLocalPart()));
                stringBuffer.append("Element");
                return addUniqueHandle(schemaGlobalElement, stringBuffer.toString());
            }
            throw new IllegalArgumentException("Cannot supply handles for types from another type system");
        }

        public String handleForIdentityConstraint(SchemaIdentityConstraint schemaIdentityConstraint) {
            if (schemaIdentityConstraint == null) {
                return null;
            }
            if (schemaIdentityConstraint.getTypeSystem() == SchemaTypeSystemImpl.this.getTypeSystem()) {
                String str = (String) this._componentsToHandles.get(schemaIdentityConstraint);
                if (str != null) {
                    return str;
                }
                StringBuffer stringBuffer = new StringBuffer();
                stringBuffer.append(NameUtil.upperCamelCase(schemaIdentityConstraint.getName().getLocalPart()));
                stringBuffer.append("IdentityConstraint");
                return addUniqueHandle(schemaIdentityConstraint, stringBuffer.toString());
            }
            throw new IllegalArgumentException("Cannot supply handles for types from another type system");
        }

        public String handleForModelGroup(SchemaModelGroup schemaModelGroup) {
            if (schemaModelGroup == null) {
                return null;
            }
            if (schemaModelGroup.getTypeSystem() == SchemaTypeSystemImpl.this.getTypeSystem()) {
                String str = (String) this._componentsToHandles.get(schemaModelGroup);
                if (str != null) {
                    return str;
                }
                StringBuffer stringBuffer = new StringBuffer();
                stringBuffer.append(NameUtil.upperCamelCase(schemaModelGroup.getName().getLocalPart()));
                stringBuffer.append("ModelGroup");
                return addUniqueHandle(schemaModelGroup, stringBuffer.toString());
            }
            throw new IllegalArgumentException("Cannot supply handles for types from another type system");
        }

        /* JADX WARNING: Removed duplicated region for block: B:23:0x0076  */
        /* JADX WARNING: Removed duplicated region for block: B:24:0x007d  */
        public String handleForType(SchemaType schemaType) {
            String str;
            String str2;
            if (schemaType == null) {
                return null;
            }
            if (schemaType.getTypeSystem() == SchemaTypeSystemImpl.this.getTypeSystem()) {
                String str3 = (String) this._componentsToHandles.get(schemaType);
                if (str3 != null) {
                    return str3;
                }
                QName name = schemaType.getName();
                if (name == null) {
                    if (schemaType.isDocumentType()) {
                        name = schemaType.getDocumentElementName();
                        str = "Doc";
                    } else if (schemaType.isAttributeType()) {
                        name = schemaType.getAttributeTypeAttributeName();
                        str = "AttrType";
                    } else if (schemaType.getContainerField() != null) {
                        name = schemaType.getContainerField().getName();
                        str = schemaType.getContainerField().isAttribute() ? "Attr" : "Elem";
                    }
                    String upperCase = Integer.toHexString(schemaType.toString().hashCode() | Integer.MIN_VALUE).substring(4).toUpperCase();
                    if (name != null) {
                        str2 = a.a("Anon", upperCase, PackageRelationship.TYPE_ATTRIBUTE_NAME);
                    } else {
                        StringBuffer stringBuffer = new StringBuffer();
                        stringBuffer.append(NameUtil.upperCamelCase(name.getLocalPart()));
                        stringBuffer.append(upperCase);
                        stringBuffer.append(str);
                        stringBuffer.append(PackageRelationship.TYPE_ATTRIBUTE_NAME);
                        str2 = stringBuffer.toString();
                    }
                    return addUniqueHandle(schemaType, str2);
                }
                str = "";
                String upperCase2 = Integer.toHexString(schemaType.toString().hashCode() | Integer.MIN_VALUE).substring(4).toUpperCase();
                if (name != null) {
                }
                return addUniqueHandle(schemaType, str2);
            }
            throw new IllegalArgumentException("Cannot supply handles for types from another type system");
        }

        public SchemaComponent.Ref refForHandle(String str) {
            if (str == null) {
                return null;
            }
            return (SchemaComponent.Ref) this._handlesToRefs.get(str);
        }

        public void startWriteMode() {
            this._started = true;
            this._componentsToHandles = new LinkedHashMap();
            for (String str : this._handlesToRefs.keySet()) {
                this._componentsToHandles.put(((SchemaComponent.Ref) this._handlesToRefs.get(str)).getComponent(), str);
            }
        }
    }

    public static class StringPool {
        public String _handle;
        public String _name;
        public List intsToStrings = new ArrayList();
        public Map stringsToInts = new HashMap();

        public StringPool(String str, String str2) {
            this._handle = str;
            this._name = str2;
            this.intsToStrings.add(null);
        }

        public int codeForString(String str) {
            if (str == null) {
                return 0;
            }
            Integer num = (Integer) this.stringsToInts.get(str);
            if (num == null) {
                num = new Integer(this.intsToStrings.size());
                this.intsToStrings.add(str);
                this.stringsToInts.put(str, num);
            }
            return num.intValue();
        }

        public void readFrom(DataInputStream dataInputStream) {
            if (this.intsToStrings.size() == 1 && this.stringsToInts.size() == 0) {
                try {
                    int readUnsignedShort = dataInputStream.readUnsignedShort();
                    for (int i2 = 1; i2 < readUnsignedShort; i2++) {
                        if (codeForString(dataInputStream.readUTF().intern()) != i2) {
                            throw new IllegalStateException();
                        }
                    }
                } catch (IOException e2) {
                    throw new SchemaTypeLoaderException(e2.getMessage() == null ? e2.getMessage() : "IO Exception", this._name, this._handle, 9, e2);
                }
            } else {
                throw new IllegalStateException();
            }
        }

        public String stringForCode(int i2) {
            if (i2 == 0) {
                return null;
            }
            return (String) this.intsToStrings.get(i2);
        }

        public void writeTo(DataOutputStream dataOutputStream) {
            if (this.intsToStrings.size() < 65535) {
                try {
                    dataOutputStream.writeShort(this.intsToStrings.size());
                    Iterator it = this.intsToStrings.iterator();
                    it.next();
                    while (it.hasNext()) {
                        dataOutputStream.writeUTF((String) it.next());
                    }
                } catch (IOException e2) {
                    throw new SchemaTypeLoaderException(e2.getMessage(), this._name, this._handle, 9);
                }
            } else {
                StringBuffer a = a.a("Too many strings (");
                a.append(this.intsToStrings.size());
                a.append(")");
                throw new SchemaTypeLoaderException(a.toString(), this._name, this._handle, 10);
            }
        }
    }

    static {
        String str;
        Class cls = class$org$apache$xmlbeans$impl$schema$SchemaTypeSystemImpl;
        if (cls == null) {
            cls = class$("org.apache.xmlbeans.impl.schema.SchemaTypeSystemImpl");
            class$org$apache$xmlbeans$impl$schema$SchemaTypeSystemImpl = cls;
        }
        $assertionsDisabled = !cls.desiredAssertionStatus();
        Class cls2 = class$org$apache$xmlbeans$SchemaTypeSystem;
        if (cls2 == null) {
            cls2 = class$("org.apache.xmlbeans.SchemaTypeSystem");
            class$org$apache$xmlbeans$SchemaTypeSystem = cls2;
        }
        Package r0 = cls2.getPackage();
        if (r0 == null) {
            Class cls3 = class$org$apache$xmlbeans$SchemaTypeSystem;
            if (cls3 == null) {
                cls3 = class$("org.apache.xmlbeans.SchemaTypeSystem");
                class$org$apache$xmlbeans$SchemaTypeSystem = cls3;
            }
            String name = cls3.getName();
            Class cls4 = class$org$apache$xmlbeans$SchemaTypeSystem;
            if (cls4 == null) {
                cls4 = class$("org.apache.xmlbeans.SchemaTypeSystem");
                class$org$apache$xmlbeans$SchemaTypeSystem = cls4;
            }
            str = name.substring(0, cls4.getName().lastIndexOf("."));
        } else {
            str = r0.getName();
        }
        METADATA_PACKAGE_GEN = str.replaceAll("\\.", "_");
    }

    public SchemaTypeSystemImpl(Class cls) {
        String name = cls.getName();
        this._name = name.substring(0, name.lastIndexOf(46));
        StringBuffer a = a.a("Loading type system ");
        a.append(this._name);
        XBeanDebug.trace(1, a.toString(), 1);
        this._basePackage = nameToPathString(this._name);
        ClassLoader classLoader = cls.getClassLoader();
        this._classloader = classLoader;
        this._linker = SchemaTypeLoaderImpl.build(null, null, classLoader);
        this._resourceLoader = new ClassLoaderResourceLoader(this._classloader);
        try {
            initFromHeader();
            StringBuffer a2 = a.a("Finished loading type system ");
            a2.append(this._name);
            XBeanDebug.trace(1, a2.toString(), -1);
        } catch (RuntimeException e2) {
            XBeanDebug.logException(e2);
            throw e2;
        } catch (Error e3) {
            XBeanDebug.logException(e3);
            throw e3;
        }
    }

    private void addContainer(String str) {
        SchemaContainer schemaContainer = new SchemaContainer(str);
        schemaContainer.setTypeSystem(this);
        this._containers.put(str, schemaContainer);
    }

    private void assertContainersSynchronized() {
        if (!$assertionsDisabled) {
            HashMap hashMap = new HashMap();
            for (SchemaContainer schemaContainer : this._containers.values()) {
                hashMap.putAll(buildComponentRefMap((SchemaComponent[]) schemaContainer.globalElements().toArray(new SchemaComponent[0])));
            }
            if ($assertionsDisabled || this._globalElements.equals(hashMap)) {
                HashMap hashMap2 = new HashMap();
                for (SchemaContainer schemaContainer2 : this._containers.values()) {
                    hashMap2.putAll(buildComponentRefMap((SchemaComponent[]) schemaContainer2.globalAttributes().toArray(new SchemaComponent[0])));
                }
                if ($assertionsDisabled || this._globalAttributes.equals(hashMap2)) {
                    HashMap hashMap3 = new HashMap();
                    for (SchemaContainer schemaContainer3 : this._containers.values()) {
                        hashMap3.putAll(buildComponentRefMap((SchemaComponent[]) schemaContainer3.modelGroups().toArray(new SchemaComponent[0])));
                    }
                    if ($assertionsDisabled || this._modelGroups.equals(hashMap3)) {
                        HashSet hashSet = new HashSet();
                        for (SchemaContainer schemaContainer4 : this._containers.values()) {
                            hashSet.addAll(buildComponentRefList((SchemaComponent[]) schemaContainer4.redefinedModelGroups().toArray(new SchemaComponent[0])));
                        }
                        if ($assertionsDisabled || new HashSet(this._redefinedModelGroups).equals(hashSet)) {
                            HashMap hashMap4 = new HashMap();
                            for (SchemaContainer schemaContainer5 : this._containers.values()) {
                                hashMap4.putAll(buildComponentRefMap((SchemaComponent[]) schemaContainer5.attributeGroups().toArray(new SchemaComponent[0])));
                            }
                            if ($assertionsDisabled || this._attributeGroups.equals(hashMap4)) {
                                HashSet hashSet2 = new HashSet();
                                for (SchemaContainer schemaContainer6 : this._containers.values()) {
                                    hashSet2.addAll(buildComponentRefList((SchemaComponent[]) schemaContainer6.redefinedAttributeGroups().toArray(new SchemaComponent[0])));
                                }
                                if ($assertionsDisabled || new HashSet(this._redefinedAttributeGroups).equals(hashSet2)) {
                                    HashMap hashMap5 = new HashMap();
                                    for (SchemaContainer schemaContainer7 : this._containers.values()) {
                                        hashMap5.putAll(buildComponentRefMap((SchemaComponent[]) schemaContainer7.globalTypes().toArray(new SchemaComponent[0])));
                                    }
                                    if ($assertionsDisabled || this._globalTypes.equals(hashMap5)) {
                                        HashSet hashSet3 = new HashSet();
                                        for (SchemaContainer schemaContainer8 : this._containers.values()) {
                                            hashSet3.addAll(buildComponentRefList((SchemaComponent[]) schemaContainer8.redefinedGlobalTypes().toArray(new SchemaComponent[0])));
                                        }
                                        if ($assertionsDisabled || new HashSet(this._redefinedGlobalTypes).equals(hashSet3)) {
                                            HashMap hashMap6 = new HashMap();
                                            for (SchemaContainer schemaContainer9 : this._containers.values()) {
                                                hashMap6.putAll(buildDocumentMap((SchemaType[]) schemaContainer9.documentTypes().toArray(new SchemaType[0])));
                                            }
                                            if ($assertionsDisabled || this._documentTypes.equals(hashMap6)) {
                                                HashMap hashMap7 = new HashMap();
                                                for (SchemaContainer schemaContainer10 : this._containers.values()) {
                                                    hashMap7.putAll(buildAttributeTypeMap((SchemaType[]) schemaContainer10.attributeTypes().toArray(new SchemaType[0])));
                                                }
                                                if ($assertionsDisabled || this._attributeTypes.equals(hashMap7)) {
                                                    HashMap hashMap8 = new HashMap();
                                                    for (SchemaContainer schemaContainer11 : this._containers.values()) {
                                                        hashMap8.putAll(buildComponentRefMap((SchemaComponent[]) schemaContainer11.identityConstraints().toArray(new SchemaComponent[0])));
                                                    }
                                                    if ($assertionsDisabled || this._identityConstraints.equals(hashMap8)) {
                                                        HashSet hashSet4 = new HashSet();
                                                        for (SchemaContainer schemaContainer12 : this._containers.values()) {
                                                            hashSet4.addAll(schemaContainer12.annotations());
                                                        }
                                                        if ($assertionsDisabled || new HashSet(this._annotations).equals(hashSet4)) {
                                                            HashSet hashSet5 = new HashSet();
                                                            for (SchemaContainer schemaContainer13 : this._containers.values()) {
                                                                hashSet5.add(schemaContainer13.getNamespace());
                                                            }
                                                            if (!($assertionsDisabled || this._namespaces.equals(hashSet5))) {
                                                                throw new AssertionError();
                                                            }
                                                            return;
                                                        }
                                                        throw new AssertionError();
                                                    }
                                                    throw new AssertionError();
                                                }
                                                throw new AssertionError();
                                            }
                                            throw new AssertionError();
                                        }
                                        throw new AssertionError();
                                    }
                                    throw new AssertionError();
                                }
                                throw new AssertionError();
                            }
                            throw new AssertionError();
                        }
                        throw new AssertionError();
                    }
                    throw new AssertionError();
                }
                throw new AssertionError();
            }
            throw new AssertionError();
        }
    }

    public static Map buildAttributeTypeMap(SchemaType[] schemaTypeArr) {
        LinkedHashMap linkedHashMap = new LinkedHashMap();
        for (int i2 = 0; i2 < schemaTypeArr.length; i2++) {
            linkedHashMap.put(schemaTypeArr[i2].getAttributeTypeAttributeName(), schemaTypeArr[i2].getRef());
        }
        return linkedHashMap;
    }

    public static List buildComponentRefList(SchemaComponent[] schemaComponentArr) {
        ArrayList arrayList = new ArrayList();
        for (SchemaComponent schemaComponent : schemaComponentArr) {
            arrayList.add(schemaComponent.getComponentRef());
        }
        return arrayList;
    }

    public static Map buildComponentRefMap(SchemaComponent[] schemaComponentArr) {
        LinkedHashMap linkedHashMap = new LinkedHashMap();
        for (int i2 = 0; i2 < schemaComponentArr.length; i2++) {
            linkedHashMap.put(schemaComponentArr[i2].getName(), schemaComponentArr[i2].getComponentRef());
        }
        return linkedHashMap;
    }

    private void buildContainers(List list, List list2, List list3) {
        for (Map.Entry entry : this._globalElements.entrySet()) {
            getContainerNonNull(((QName) entry.getKey()).getNamespaceURI()).addGlobalElement((SchemaGlobalElement.Ref) entry.getValue());
        }
        for (Map.Entry entry2 : this._globalAttributes.entrySet()) {
            getContainerNonNull(((QName) entry2.getKey()).getNamespaceURI()).addGlobalAttribute((SchemaGlobalAttribute.Ref) entry2.getValue());
        }
        for (Map.Entry entry3 : this._modelGroups.entrySet()) {
            getContainerNonNull(((QName) entry3.getKey()).getNamespaceURI()).addModelGroup((SchemaModelGroup.Ref) entry3.getValue());
        }
        for (Map.Entry entry4 : this._attributeGroups.entrySet()) {
            getContainerNonNull(((QName) entry4.getKey()).getNamespaceURI()).addAttributeGroup((SchemaAttributeGroup.Ref) entry4.getValue());
        }
        for (Map.Entry entry5 : this._identityConstraints.entrySet()) {
            getContainerNonNull(((QName) entry5.getKey()).getNamespaceURI()).addIdentityConstraint((SchemaIdentityConstraint.Ref) entry5.getValue());
        }
        for (Map.Entry entry6 : this._globalTypes.entrySet()) {
            getContainerNonNull(((QName) entry6.getKey()).getNamespaceURI()).addGlobalType((SchemaType.Ref) entry6.getValue());
        }
        for (Map.Entry entry7 : this._documentTypes.entrySet()) {
            getContainerNonNull(((QName) entry7.getKey()).getNamespaceURI()).addDocumentType((SchemaType.Ref) entry7.getValue());
        }
        for (Map.Entry entry8 : this._attributeTypes.entrySet()) {
            getContainerNonNull(((QName) entry8.getKey()).getNamespaceURI()).addAttributeType((SchemaType.Ref) entry8.getValue());
        }
        List list4 = this._redefinedGlobalTypes;
        if (!(list4 == null || this._redefinedModelGroups == null || this._redefinedAttributeGroups == null)) {
            if ($assertionsDisabled || list4.size() == list.size()) {
                Iterator it = list.iterator();
                for (SchemaType.Ref ref : this._redefinedGlobalTypes) {
                    getContainerNonNull(((QName) it.next()).getNamespaceURI()).addRedefinedType(ref);
                }
                Iterator it2 = list2.iterator();
                for (SchemaModelGroup.Ref ref2 : this._redefinedModelGroups) {
                    getContainerNonNull(((QName) it2.next()).getNamespaceURI()).addRedefinedModelGroup(ref2);
                }
                Iterator it3 = list3.iterator();
                for (SchemaAttributeGroup.Ref ref3 : this._redefinedAttributeGroups) {
                    getContainerNonNull(((QName) it3.next()).getNamespaceURI()).addRedefinedAttributeGroup(ref3);
                }
            } else {
                throw new AssertionError();
            }
        }
        List<SchemaAnnotation> list5 = this._annotations;
        if (list5 != null) {
            for (SchemaAnnotation schemaAnnotation : list5) {
                getContainerNonNull("").addAnnotation(schemaAnnotation);
            }
        }
        for (SchemaContainer schemaContainer : this._containers.values()) {
            schemaContainer.setImmutable();
        }
    }

    public static Map buildDocumentMap(SchemaType[] schemaTypeArr) {
        LinkedHashMap linkedHashMap = new LinkedHashMap();
        for (int i2 = 0; i2 < schemaTypeArr.length; i2++) {
            linkedHashMap.put(schemaTypeArr[i2].getDocumentElementName(), schemaTypeArr[i2].getRef());
        }
        return linkedHashMap;
    }

    private Map buildTypeRefsByClassname() {
        ArrayList arrayList = new ArrayList();
        LinkedHashMap linkedHashMap = new LinkedHashMap();
        arrayList.addAll(Arrays.asList(documentTypes()));
        arrayList.addAll(Arrays.asList(attributeTypes()));
        arrayList.addAll(Arrays.asList(globalTypes()));
        for (int i2 = 0; i2 < arrayList.size(); i2++) {
            SchemaType schemaType = (SchemaType) arrayList.get(i2);
            String fullJavaName = schemaType.getFullJavaName();
            if (fullJavaName != null) {
                linkedHashMap.put(fullJavaName.replace('$', NameUtil.PERIOD), schemaType.getRef());
            }
            arrayList.addAll(Arrays.asList(schemaType.getAnonymousTypes()));
        }
        return linkedHashMap;
    }

    public static /* synthetic */ Class class$(String str) {
        try {
            return Class.forName(str);
        } catch (ClassNotFoundException e2) {
            throw a.a(e2);
        }
    }

    /* JADX WARNING: Removed duplicated region for block: B:44:0x0060 A[SYNTHETIC, Splitter:B:44:0x0060] */
    /* JADX WARNING: Removed duplicated region for block: B:51:0x0067 A[SYNTHETIC, Splitter:B:51:0x0067] */
    public static String crackPointer(InputStream inputStream) {
        DataInputStream dataInputStream;
        Throwable th;
        DataInputStream dataInputStream2 = null;
        try {
            dataInputStream = new DataInputStream(inputStream);
            try {
                if (dataInputStream.readInt() != -629491010) {
                    try {
                        dataInputStream.close();
                    } catch (IOException unused) {
                    }
                    return null;
                }
                short readShort = dataInputStream.readShort();
                short readShort2 = dataInputStream.readShort();
                if (readShort != 2) {
                    try {
                        dataInputStream.close();
                    } catch (IOException unused2) {
                    }
                    return null;
                } else if (readShort2 > 24) {
                    try {
                        dataInputStream.close();
                    } catch (IOException unused3) {
                    }
                    return null;
                } else {
                    if (readShort > 2 || (readShort == 2 && readShort2 >= 18)) {
                        dataInputStream.readShort();
                    }
                    if (dataInputStream.readShort() != 5) {
                        try {
                            dataInputStream.close();
                        } catch (IOException unused4) {
                        }
                        return null;
                    }
                    StringPool stringPool = new StringPool("pointer", "unk");
                    stringPool.readFrom(dataInputStream);
                    String stringForCode = stringPool.stringForCode(dataInputStream.readShort());
                    try {
                        dataInputStream.close();
                    } catch (IOException unused5) {
                    }
                    return stringForCode;
                }
            } catch (IOException unused6) {
                if (dataInputStream != null) {
                }
                return null;
            } catch (Throwable th2) {
                th = th2;
                dataInputStream2 = dataInputStream;
                if (dataInputStream2 != null) {
                }
                throw th;
            }
        } catch (IOException unused7) {
            dataInputStream = null;
            if (dataInputStream != null) {
                try {
                    dataInputStream.close();
                } catch (IOException unused8) {
                }
            }
            return null;
        } catch (Throwable th3) {
            th = th3;
            if (dataInputStream2 != null) {
                try {
                    dataInputStream2.close();
                } catch (IOException unused9) {
                }
            }
            throw th;
        }
    }

    /* JADX WARNING: Removed duplicated region for block: B:28:0x006e A[SYNTHETIC, Splitter:B:28:0x006e] */
    public static boolean fileContainsTypeSystem(File file, String str) {
        Throwable th;
        IOException e2;
        StringBuffer stringBuffer = new StringBuffer();
        stringBuffer.append(nameToPathString(str));
        stringBuffer.append("index.xsb");
        String stringBuffer2 = stringBuffer.toString();
        if (file.isDirectory()) {
            return new File(file, stringBuffer2).isFile();
        }
        ZipFile zipFile = null;
        try {
            ZipFile zipFile2 = new ZipFile(file);
            try {
                ZipEntry entry = zipFile2.getEntry(stringBuffer2);
                boolean z = entry != null && !entry.isDirectory();
                try {
                    zipFile2.close();
                } catch (IOException unused) {
                }
                return z;
            } catch (IOException e3) {
                e2 = e3;
                zipFile = zipFile2;
                try {
                    StringBuffer stringBuffer3 = new StringBuffer();
                    stringBuffer3.append("Problem loading SchemaTypeSystem, zipfilename ");
                    stringBuffer3.append(file);
                    XBeanDebug.log(stringBuffer3.toString());
                    XBeanDebug.logException(e2);
                    throw new SchemaTypeLoaderException(e2.getMessage(), str, "index", 9);
                } catch (Throwable th2) {
                    th = th2;
                    if (zipFile != null) {
                        try {
                            zipFile.close();
                        } catch (IOException unused2) {
                        }
                    }
                    throw th;
                }
            } catch (Throwable th3) {
                th = th3;
                zipFile = zipFile2;
                if (zipFile != null) {
                }
                throw th;
            }
        } catch (IOException e4) {
            e2 = e4;
            StringBuffer stringBuffer32 = new StringBuffer();
            stringBuffer32.append("Problem loading SchemaTypeSystem, zipfilename ");
            stringBuffer32.append(file);
            XBeanDebug.log(stringBuffer32.toString());
            XBeanDebug.logException(e2);
            throw new SchemaTypeLoaderException(e2.getMessage(), str, "index", 9);
        }
    }

    private void fixupContainers() {
        for (SchemaContainer schemaContainer : this._containers.values()) {
            schemaContainer.setTypeSystem(this);
            schemaContainer.setImmutable();
        }
    }

    public static SchemaTypeSystemImpl forName(String str, ClassLoader classLoader) {
        try {
            StringBuffer stringBuffer = new StringBuffer();
            stringBuffer.append(str);
            stringBuffer.append(".");
            stringBuffer.append("TypeSystemHolder");
            return (SchemaTypeSystemImpl) Class.forName(stringBuffer.toString(), true, classLoader).getField(XmlBeans.TYPE_SYSTEM_FIELD).get(null);
        } catch (Exception unused) {
            return null;
        }
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private SchemaContainer getContainer(String str) {
        return (SchemaContainer) this._containers.get(str);
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private SchemaContainer getContainerNonNull(String str) {
        SchemaContainer container = getContainer(str);
        if (container != null) {
            return container;
        }
        addContainer(str);
        return getContainer(str);
    }

    /* JADX WARNING: Removed duplicated region for block: B:17:0x00a8  */
    private void initFromHeader() {
        Throwable th;
        StringBuffer a = a.a("Reading unresolved handles for type system ");
        a.append(this._name);
        XBeanDebug.trace(1, a.toString(), 0);
        XsbReader xsbReader = null;
        try {
            XsbReader xsbReader2 = new XsbReader("index", 1);
            try {
                HandlePool handlePool = new HandlePool();
                this._localHandles = handlePool;
                xsbReader2.readHandlePool(handlePool);
                this._globalElements = xsbReader2.readQNameRefMap();
                this._globalAttributes = xsbReader2.readQNameRefMap();
                this._modelGroups = xsbReader2.readQNameRefMap();
                this._attributeGroups = xsbReader2.readQNameRefMap();
                this._identityConstraints = xsbReader2.readQNameRefMap();
                this._globalTypes = xsbReader2.readQNameRefMap();
                this._documentTypes = xsbReader2.readQNameRefMap();
                this._attributeTypes = xsbReader2.readQNameRefMap();
                this._typeRefsByClassname = xsbReader2.readClassnameRefMap();
                this._namespaces = xsbReader2.readNamespaces();
                ArrayList arrayList = new ArrayList();
                ArrayList arrayList2 = new ArrayList();
                ArrayList arrayList3 = new ArrayList();
                if (xsbReader2.atLeast(2, 15, 0)) {
                    this._redefinedGlobalTypes = xsbReader2.readQNameRefMapAsList(arrayList);
                    this._redefinedModelGroups = xsbReader2.readQNameRefMapAsList(arrayList2);
                    this._redefinedAttributeGroups = xsbReader2.readQNameRefMapAsList(arrayList3);
                }
                if (xsbReader2.atLeast(2, 19, 0)) {
                    this._annotations = xsbReader2.readAnnotations();
                }
                buildContainers(arrayList, arrayList2, arrayList3);
                xsbReader2.readEnd();
            } catch (Throwable th2) {
                th = th2;
                xsbReader = xsbReader2;
                if (xsbReader != null) {
                    xsbReader.readEnd();
                }
                throw th;
            }
        } catch (Throwable th3) {
            th = th3;
            if (xsbReader != null) {
            }
            throw th;
        }
    }

    public static String[] makeClassStrings(String str) {
        String[] strArr = new String[4];
        strArr[0] = str;
        strArr[1] = str.replace(NameUtil.PERIOD, JarHelper.SEP);
        strArr[2] = a.a(a.a("L"), strArr[1], ";");
        StringBuffer a = a.a("class$");
        a.append(str.replace(NameUtil.PERIOD, '$'));
        strArr[3] = a.toString();
        return strArr;
    }

    public static String nameToPathString(String str) {
        String replace = str.replace(NameUtil.PERIOD, JarHelper.SEP);
        return (replace.endsWith(ZipHelper.FORWARD_SLASH) || replace.length() <= 0) ? replace : a.a(replace, ZipHelper.FORWARD_SLASH);
    }

    public static synchronized void nextBytes(byte[] bArr) {
        Class cls;
        synchronized (SchemaTypeSystemImpl.class) {
            if (_random == null) {
                try {
                    ByteArrayOutputStream byteArrayOutputStream = new ByteArrayOutputStream();
                    DataOutputStream dataOutputStream = new DataOutputStream(byteArrayOutputStream);
                    if (class$org$apache$xmlbeans$impl$schema$SchemaTypeSystemImpl == null) {
                        cls = class$("org.apache.xmlbeans.impl.schema.SchemaTypeSystemImpl");
                        class$org$apache$xmlbeans$impl$schema$SchemaTypeSystemImpl = cls;
                    } else {
                        cls = class$org$apache$xmlbeans$impl$schema$SchemaTypeSystemImpl;
                    }
                    dataOutputStream.writeInt(System.identityHashCode(cls));
                    String[] strArr = {"user.name", "user.dir", "user.timezone", "user.country", "java.class.path", "java.home", "java.vendor", "java.version", "os.version"};
                    for (int i2 = 0; i2 < 9; i2++) {
                        String property = SystemProperties.getProperty(strArr[i2]);
                        if (property != null) {
                            dataOutputStream.writeUTF(property);
                            dataOutputStream.writeInt(System.identityHashCode(property));
                        }
                    }
                    dataOutputStream.writeLong(Runtime.getRuntime().freeMemory());
                    dataOutputStream.close();
                    byte[] byteArray = byteArrayOutputStream.toByteArray();
                    for (int i3 = 0; i3 < byteArray.length; i3++) {
                        int length = i3 % _mask.length;
                        byte[] bArr2 = _mask;
                        bArr2[length] = (byte) (bArr2[length] * 21);
                        byte[] bArr3 = _mask;
                        bArr3[length] = (byte) (bArr3[length] + i3);
                    }
                } catch (IOException e2) {
                    XBeanDebug.logException(e2);
                }
                _random = new Random(System.currentTimeMillis());
            }
            _random.nextBytes(bArr);
            for (int i4 = 0; i4 < bArr.length; i4++) {
                bArr[i4] = (byte) (_mask[_mask.length & i4] ^ bArr[i4]);
            }
        }
    }

    public static String repackageConstant(String str, String[] strArr, Repackager repackager) {
        int i2 = 0;
        while (true) {
            String[] strArr2 = HOLDER_TEMPLATE_NAMES;
            if (i2 >= strArr2.length) {
                return repackager != null ? repackager.repackage(new StringBuffer(str)).toString() : str;
            }
            if (strArr2[i2].equals(str)) {
                return strArr[i2];
            }
            i2++;
        }
    }

    @Override // org.apache.xmlbeans.SchemaTypeSystem
    public SchemaAnnotation[] annotations() {
        List list = this._annotations;
        if (list == null || list.isEmpty()) {
            return EMPTY_ANN_ARRAY;
        }
        return (SchemaAnnotation[]) this._annotations.toArray(new SchemaAnnotation[this._annotations.size()]);
    }

    @Override // org.apache.xmlbeans.SchemaTypeSystem
    public SchemaAttributeGroup[] attributeGroups() {
        if (this._attributeGroups.isEmpty()) {
            return EMPTY_AG_ARRAY;
        }
        SchemaAttributeGroup[] schemaAttributeGroupArr = new SchemaAttributeGroup[this._attributeGroups.size()];
        int i2 = 0;
        for (SchemaAttributeGroup.Ref ref : this._attributeGroups.values()) {
            schemaAttributeGroupArr[i2] = ref.get();
            i2++;
        }
        return schemaAttributeGroupArr;
    }

    @Override // org.apache.xmlbeans.SchemaTypeSystem
    public SchemaType[] attributeTypes() {
        if (this._attributeTypes.isEmpty()) {
            return EMPTY_ST_ARRAY;
        }
        SchemaType[] schemaTypeArr = new SchemaType[this._attributeTypes.size()];
        int i2 = 0;
        for (SchemaType.Ref ref : this._attributeTypes.values()) {
            schemaTypeArr[i2] = ref.get();
            i2++;
        }
        return schemaTypeArr;
    }

    public SchemaContainer[] containers() {
        SchemaContainer[] schemaContainerArr = new SchemaContainer[this._containers.size()];
        int i2 = 0;
        for (SchemaContainer schemaContainer : this._containers.values()) {
            schemaContainerArr[i2] = schemaContainer;
            i2++;
        }
        return schemaContainerArr;
    }

    @Override // org.apache.xmlbeans.SchemaTypeSystem
    public SchemaType[] documentTypes() {
        if (this._documentTypes.isEmpty()) {
            return EMPTY_ST_ARRAY;
        }
        SchemaType[] schemaTypeArr = new SchemaType[this._documentTypes.size()];
        int i2 = 0;
        for (SchemaType.Ref ref : this._documentTypes.values()) {
            schemaTypeArr[i2] = ref.get();
            i2++;
        }
        return schemaTypeArr;
    }

    @Override // org.apache.xmlbeans.SchemaTypeLoader
    public SchemaAttributeGroup.Ref findAttributeGroupRef(QName qName) {
        return (SchemaAttributeGroup.Ref) this._attributeGroups.get(qName);
    }

    @Override // org.apache.xmlbeans.SchemaTypeLoader
    public SchemaGlobalAttribute.Ref findAttributeRef(QName qName) {
        return (SchemaGlobalAttribute.Ref) this._globalAttributes.get(qName);
    }

    @Override // org.apache.xmlbeans.SchemaTypeLoader
    public SchemaType.Ref findAttributeTypeRef(QName qName) {
        return (SchemaType.Ref) this._attributeTypes.get(qName);
    }

    @Override // org.apache.xmlbeans.SchemaTypeLoader
    public SchemaType.Ref findDocumentTypeRef(QName qName) {
        return (SchemaType.Ref) this._documentTypes.get(qName);
    }

    @Override // org.apache.xmlbeans.SchemaTypeLoader
    public SchemaGlobalElement.Ref findElementRef(QName qName) {
        return (SchemaGlobalElement.Ref) this._globalElements.get(qName);
    }

    @Override // org.apache.xmlbeans.SchemaTypeLoader
    public SchemaIdentityConstraint.Ref findIdentityConstraintRef(QName qName) {
        return (SchemaIdentityConstraint.Ref) this._identityConstraints.get(qName);
    }

    @Override // org.apache.xmlbeans.SchemaTypeLoader
    public SchemaModelGroup.Ref findModelGroupRef(QName qName) {
        return (SchemaModelGroup.Ref) this._modelGroups.get(qName);
    }

    @Override // org.apache.xmlbeans.SchemaTypeLoader
    public SchemaType.Ref findTypeRef(QName qName) {
        return (SchemaType.Ref) this._globalTypes.get(qName);
    }

    @Override // org.apache.xmlbeans.SchemaTypeSystem
    public ClassLoader getClassLoader() {
        return this._classloader;
    }

    public SchemaDependencies getDependencies() {
        return this._deps;
    }

    @Override // org.apache.xmlbeans.SchemaTypeSystem
    public String getName() {
        return this._name;
    }

    @Override // org.apache.xmlbeans.SchemaTypeLoader
    public InputStream getSourceAsStream(String str) {
        if (!str.startsWith(ZipHelper.FORWARD_SLASH)) {
            str = a.a(ZipHelper.FORWARD_SLASH, str);
        }
        ResourceLoader resourceLoader = this._resourceLoader;
        StringBuffer a = a.a("schema");
        a.append(METADATA_PACKAGE_GEN);
        a.append("/src");
        a.append(str);
        return resourceLoader.getResourceAsStream(a.toString());
    }

    public final SchemaTypeSystemImpl getTypeSystem() {
        return this;
    }

    @Override // org.apache.xmlbeans.SchemaTypeSystem
    public SchemaGlobalAttribute[] globalAttributes() {
        if (this._globalAttributes.isEmpty()) {
            return EMPTY_GA_ARRAY;
        }
        SchemaGlobalAttribute[] schemaGlobalAttributeArr = new SchemaGlobalAttribute[this._globalAttributes.size()];
        int i2 = 0;
        for (SchemaGlobalAttribute.Ref ref : this._globalAttributes.values()) {
            schemaGlobalAttributeArr[i2] = ref.get();
            i2++;
        }
        return schemaGlobalAttributeArr;
    }

    @Override // org.apache.xmlbeans.SchemaTypeSystem
    public SchemaGlobalElement[] globalElements() {
        if (this._globalElements.isEmpty()) {
            return EMPTY_GE_ARRAY;
        }
        SchemaGlobalElement[] schemaGlobalElementArr = new SchemaGlobalElement[this._globalElements.size()];
        int i2 = 0;
        for (SchemaGlobalElement.Ref ref : this._globalElements.values()) {
            schemaGlobalElementArr[i2] = ref.get();
            i2++;
        }
        return schemaGlobalElementArr;
    }

    @Override // org.apache.xmlbeans.SchemaTypeSystem
    public SchemaType[] globalTypes() {
        if (this._globalTypes.isEmpty()) {
            return EMPTY_ST_ARRAY;
        }
        SchemaType[] schemaTypeArr = new SchemaType[this._globalTypes.size()];
        int i2 = 0;
        for (SchemaType.Ref ref : this._globalTypes.values()) {
            schemaTypeArr[i2] = ref.get();
            i2++;
        }
        return schemaTypeArr;
    }

    public String handleForType(SchemaType schemaType) {
        return this._localHandles.handleForType(schemaType);
    }

    public SchemaIdentityConstraint[] identityConstraints() {
        if (this._identityConstraints.isEmpty()) {
            return EMPTY_IC_ARRAY;
        }
        SchemaIdentityConstraint[] schemaIdentityConstraintArr = new SchemaIdentityConstraint[this._identityConstraints.size()];
        int i2 = 0;
        for (SchemaIdentityConstraint.Ref ref : this._identityConstraints.values()) {
            schemaIdentityConstraintArr[i2] = ref.get();
            i2++;
        }
        return schemaIdentityConstraintArr;
    }

    public boolean isIncomplete() {
        return this._incomplete;
    }

    @Override // org.apache.xmlbeans.SchemaTypeLoader
    public boolean isNamespaceDefined(String str) {
        return this._namespaces.contains(str);
    }

    public void loadFromBuilder(SchemaGlobalElement[] schemaGlobalElementArr, SchemaGlobalAttribute[] schemaGlobalAttributeArr, SchemaType[] schemaTypeArr, SchemaType[] schemaTypeArr2, SchemaType[] schemaTypeArr3) {
        if ($assertionsDisabled || this._classloader == null) {
            this._localHandles = new HandlePool();
            this._globalElements = buildComponentRefMap(schemaGlobalElementArr);
            this._globalAttributes = buildComponentRefMap(schemaGlobalAttributeArr);
            this._globalTypes = buildComponentRefMap(schemaTypeArr);
            this._documentTypes = buildDocumentMap(schemaTypeArr2);
            this._attributeTypes = buildAttributeTypeMap(schemaTypeArr3);
            this._typeRefsByClassname = buildTypeRefsByClassname();
            List list = Collections.EMPTY_LIST;
            buildContainers(list, list, list);
            this._namespaces = new HashSet();
            return;
        }
        throw new AssertionError();
    }

    public void loadFromStscState(StscState stscState) {
        if ($assertionsDisabled || this._classloader == null) {
            this._localHandles = new HandlePool();
            this._globalElements = buildComponentRefMap(stscState.globalElements());
            this._globalAttributes = buildComponentRefMap(stscState.globalAttributes());
            this._modelGroups = buildComponentRefMap(stscState.modelGroups());
            this._redefinedModelGroups = buildComponentRefList(stscState.redefinedModelGroups());
            this._attributeGroups = buildComponentRefMap(stscState.attributeGroups());
            this._redefinedAttributeGroups = buildComponentRefList(stscState.redefinedAttributeGroups());
            this._globalTypes = buildComponentRefMap(stscState.globalTypes());
            this._redefinedGlobalTypes = buildComponentRefList(stscState.redefinedGlobalTypes());
            this._documentTypes = buildDocumentMap(stscState.documentTypes());
            this._attributeTypes = buildAttributeTypeMap(stscState.attributeTypes());
            this._typeRefsByClassname = buildTypeRefsByClassname(stscState.typesByClassname());
            this._identityConstraints = buildComponentRefMap(stscState.idConstraints());
            this._annotations = stscState.annotations();
            this._namespaces = new HashSet(Arrays.asList(stscState.getNamespaces()));
            this._containers = stscState.getContainerMap();
            fixupContainers();
            assertContainersSynchronized();
            setDependencies(stscState.getDependencies());
            return;
        }
        throw new AssertionError();
    }

    @Override // org.apache.xmlbeans.SchemaTypeSystem
    public SchemaModelGroup[] modelGroups() {
        if (this._modelGroups.isEmpty()) {
            return EMPTY_MG_ARRAY;
        }
        SchemaModelGroup[] schemaModelGroupArr = new SchemaModelGroup[this._modelGroups.size()];
        int i2 = 0;
        for (SchemaModelGroup.Ref ref : this._modelGroups.values()) {
            schemaModelGroupArr[i2] = ref.get();
            i2++;
        }
        return schemaModelGroupArr;
    }

    public SchemaAttributeGroup[] redefinedAttributeGroups() {
        List list = this._redefinedAttributeGroups;
        if (list == null || list.isEmpty()) {
            return EMPTY_AG_ARRAY;
        }
        SchemaAttributeGroup[] schemaAttributeGroupArr = new SchemaAttributeGroup[this._redefinedAttributeGroups.size()];
        int i2 = 0;
        for (SchemaAttributeGroup.Ref ref : this._redefinedAttributeGroups) {
            schemaAttributeGroupArr[i2] = ref.get();
            i2++;
        }
        return schemaAttributeGroupArr;
    }

    public SchemaType[] redefinedGlobalTypes() {
        List list = this._redefinedGlobalTypes;
        if (list == null || list.isEmpty()) {
            return EMPTY_ST_ARRAY;
        }
        SchemaType[] schemaTypeArr = new SchemaType[this._redefinedGlobalTypes.size()];
        int i2 = 0;
        for (SchemaType.Ref ref : this._redefinedGlobalTypes) {
            schemaTypeArr[i2] = ref.get();
            i2++;
        }
        return schemaTypeArr;
    }

    public SchemaModelGroup[] redefinedModelGroups() {
        List list = this._redefinedModelGroups;
        if (list == null || list.isEmpty()) {
            return EMPTY_MG_ARRAY;
        }
        SchemaModelGroup[] schemaModelGroupArr = new SchemaModelGroup[this._redefinedModelGroups.size()];
        int i2 = 0;
        for (SchemaModelGroup.Ref ref : this._redefinedModelGroups) {
            schemaModelGroupArr[i2] = ref.get();
            i2++;
        }
        return schemaModelGroupArr;
    }

    @Override // org.apache.xmlbeans.SchemaTypeSystem
    public void resolve() {
        StringBuffer a = a.a("Resolve called type system ");
        a.append(this._name);
        XBeanDebug.trace(1, a.toString(), 0);
        if (!this._allNonGroupHandlesResolved) {
            StringBuffer a2 = a.a("Resolving all handles for type system ");
            a2.append(this._name);
            XBeanDebug.trace(1, a2.toString(), 1);
            ArrayList arrayList = new ArrayList();
            arrayList.addAll(this._globalElements.values());
            arrayList.addAll(this._globalAttributes.values());
            arrayList.addAll(this._globalTypes.values());
            arrayList.addAll(this._documentTypes.values());
            arrayList.addAll(this._attributeTypes.values());
            arrayList.addAll(this._identityConstraints.values());
            Iterator it = arrayList.iterator();
            while (it.hasNext()) {
                ((SchemaComponent.Ref) it.next()).getComponent();
            }
            StringBuffer a3 = a.a("Finished resolving type system ");
            a3.append(this._name);
            XBeanDebug.trace(1, a3.toString(), -1);
            this._allNonGroupHandlesResolved = true;
        }
    }

    @Override // org.apache.xmlbeans.SchemaTypeSystem
    public SchemaComponent resolveHandle(String str) {
        SchemaComponent schemaComponent;
        SchemaComponent schemaComponent2;
        synchronized (this._resolvedHandles) {
            schemaComponent = (SchemaComponent) this._resolvedHandles.get(str);
        }
        if (schemaComponent == null) {
            XsbReader xsbReader = new XsbReader(str, 65535);
            int actualFiletype = xsbReader.getActualFiletype();
            if (actualFiletype == 2) {
                StringBuffer stringBuffer = new StringBuffer();
                stringBuffer.append("Resolving type for handle ");
                stringBuffer.append(str);
                XBeanDebug.trace(1, stringBuffer.toString(), 0);
                schemaComponent2 = xsbReader.finishLoadingType();
            } else if (actualFiletype == 3) {
                StringBuffer stringBuffer2 = new StringBuffer();
                stringBuffer2.append("Resolving element for handle ");
                stringBuffer2.append(str);
                XBeanDebug.trace(1, stringBuffer2.toString(), 0);
                schemaComponent2 = xsbReader.finishLoadingElement();
            } else if (actualFiletype == 4) {
                StringBuffer stringBuffer3 = new StringBuffer();
                stringBuffer3.append("Resolving attribute for handle ");
                stringBuffer3.append(str);
                XBeanDebug.trace(1, stringBuffer3.toString(), 0);
                schemaComponent2 = xsbReader.finishLoadingAttribute();
            } else if (actualFiletype == 6) {
                StringBuffer stringBuffer4 = new StringBuffer();
                stringBuffer4.append("Resolving model group for handle ");
                stringBuffer4.append(str);
                XBeanDebug.trace(1, stringBuffer4.toString(), 0);
                schemaComponent2 = xsbReader.finishLoadingModelGroup();
            } else if (actualFiletype == 7) {
                StringBuffer stringBuffer5 = new StringBuffer();
                stringBuffer5.append("Resolving attribute group for handle ");
                stringBuffer5.append(str);
                XBeanDebug.trace(1, stringBuffer5.toString(), 0);
                schemaComponent2 = xsbReader.finishLoadingAttributeGroup();
            } else if (actualFiletype == 8) {
                StringBuffer stringBuffer6 = new StringBuffer();
                stringBuffer6.append("Resolving id constraint for handle ");
                stringBuffer6.append(str);
                XBeanDebug.trace(1, stringBuffer6.toString(), 0);
                schemaComponent2 = xsbReader.finishLoadingIdentityConstraint();
            } else {
                throw new IllegalStateException("Illegal handle type");
            }
            synchronized (this._resolvedHandles) {
                if (!this._resolvedHandles.containsKey(str)) {
                    this._resolvedHandles.put(str, schemaComponent2);
                    schemaComponent = schemaComponent2;
                } else {
                    schemaComponent = (SchemaComponent) this._resolvedHandles.get(str);
                }
            }
        }
        return schemaComponent;
    }

    @Override // org.apache.xmlbeans.SchemaTypeSystem
    public void save(Filer filer) {
        if (this._incomplete) {
            throw new IllegalStateException("Incomplete SchemaTypeSystems cannot be saved.");
        } else if (filer != null) {
            this._filer = filer;
            this._localHandles.startWriteMode();
            saveTypesRecursively(globalTypes());
            saveTypesRecursively(documentTypes());
            saveTypesRecursively(attributeTypes());
            saveGlobalElements(globalElements());
            saveGlobalAttributes(globalAttributes());
            saveModelGroups(modelGroups());
            saveAttributeGroups(attributeGroups());
            saveIdentityConstraints(identityConstraints());
            saveTypesRecursively(redefinedGlobalTypes());
            saveModelGroups(redefinedModelGroups());
            saveAttributeGroups(redefinedAttributeGroups());
            saveIndex();
            savePointers();
            saveLoader();
        } else {
            throw new IllegalArgumentException("filer must not be null");
        }
    }

    public void saveAttributeGroup(SchemaAttributeGroup schemaAttributeGroup) {
        if (!this._incomplete) {
            String handleForAttributeGroup = this._localHandles.handleForAttributeGroup(schemaAttributeGroup);
            XsbReader xsbReader = new XsbReader(handleForAttributeGroup);
            xsbReader.writeAttributeGroupData(schemaAttributeGroup);
            xsbReader.writeRealHeader(handleForAttributeGroup, 7);
            xsbReader.writeAttributeGroupData(schemaAttributeGroup);
            xsbReader.writeEnd();
            return;
        }
        throw new IllegalStateException("This SchemaTypeSystem cannot be saved.");
    }

    public void saveAttributeGroups(SchemaAttributeGroup[] schemaAttributeGroupArr) {
        if (!this._incomplete) {
            for (SchemaAttributeGroup schemaAttributeGroup : schemaAttributeGroupArr) {
                saveAttributeGroup(schemaAttributeGroup);
            }
            return;
        }
        throw new IllegalStateException("This SchemaTypeSystem cannot be saved.");
    }

    public void saveGlobalAttribute(SchemaGlobalAttribute schemaGlobalAttribute) {
        if (!this._incomplete) {
            String handleForAttribute = this._localHandles.handleForAttribute(schemaGlobalAttribute);
            XsbReader xsbReader = new XsbReader(handleForAttribute);
            xsbReader.writeAttributeData(schemaGlobalAttribute);
            xsbReader.writeString(schemaGlobalAttribute.getSourceName());
            xsbReader.writeRealHeader(handleForAttribute, 4);
            xsbReader.writeAttributeData(schemaGlobalAttribute);
            xsbReader.writeString(schemaGlobalAttribute.getSourceName());
            xsbReader.writeEnd();
            return;
        }
        throw new IllegalStateException("This SchemaTypeSystem cannot be saved.");
    }

    public void saveGlobalAttributes(SchemaGlobalAttribute[] schemaGlobalAttributeArr) {
        if (!this._incomplete) {
            for (SchemaGlobalAttribute schemaGlobalAttribute : schemaGlobalAttributeArr) {
                saveGlobalAttribute(schemaGlobalAttribute);
            }
            return;
        }
        throw new IllegalStateException("This SchemaTypeSystem cannot be saved.");
    }

    public void saveGlobalElement(SchemaGlobalElement schemaGlobalElement) {
        if (!this._incomplete) {
            String handleForElement = this._localHandles.handleForElement(schemaGlobalElement);
            XsbReader xsbReader = new XsbReader(handleForElement);
            xsbReader.writeParticleData((SchemaParticle) schemaGlobalElement);
            xsbReader.writeString(schemaGlobalElement.getSourceName());
            xsbReader.writeRealHeader(handleForElement, 3);
            xsbReader.writeParticleData((SchemaParticle) schemaGlobalElement);
            xsbReader.writeString(schemaGlobalElement.getSourceName());
            xsbReader.writeEnd();
            return;
        }
        throw new IllegalStateException("This SchemaTypeSystem cannot be saved.");
    }

    public void saveGlobalElements(SchemaGlobalElement[] schemaGlobalElementArr) {
        if (!this._incomplete) {
            for (SchemaGlobalElement schemaGlobalElement : schemaGlobalElementArr) {
                saveGlobalElement(schemaGlobalElement);
            }
            return;
        }
        throw new IllegalStateException("This SchemaTypeSystem cannot be saved.");
    }

    public void saveIdentityConstraint(SchemaIdentityConstraint schemaIdentityConstraint) {
        if (!this._incomplete) {
            String handleForIdentityConstraint = this._localHandles.handleForIdentityConstraint(schemaIdentityConstraint);
            XsbReader xsbReader = new XsbReader(handleForIdentityConstraint);
            xsbReader.writeIdConstraintData(schemaIdentityConstraint);
            xsbReader.writeRealHeader(handleForIdentityConstraint, 8);
            xsbReader.writeIdConstraintData(schemaIdentityConstraint);
            xsbReader.writeEnd();
            return;
        }
        throw new IllegalStateException("This SchemaTypeSystem cannot be saved.");
    }

    public void saveIdentityConstraints(SchemaIdentityConstraint[] schemaIdentityConstraintArr) {
        if (!this._incomplete) {
            for (SchemaIdentityConstraint schemaIdentityConstraint : schemaIdentityConstraintArr) {
                saveIdentityConstraint(schemaIdentityConstraint);
            }
            return;
        }
        throw new IllegalStateException("This SchemaTypeSystem cannot be saved.");
    }

    public void saveIndex() {
        XsbReader xsbReader = new XsbReader("index");
        xsbReader.writeIndexData();
        xsbReader.writeRealHeader("index", 1);
        xsbReader.writeIndexData();
        xsbReader.writeEnd();
    }

    /* JADX WARNING: Can't wrap try/catch for region: R(5:31|32|33|34|(3:37|38|75)(1:73)) */
    /* JADX WARNING: Failed to process nested try/catch */
    /* JADX WARNING: Missing exception handler attribute for start block: B:33:0x00ed */
    /* JADX WARNING: Removed duplicated region for block: B:37:0x00f4 A[SYNTHETIC, Splitter:B:37:0x00f4] */
    /* JADX WARNING: Removed duplicated region for block: B:48:0x010f A[SYNTHETIC, Splitter:B:48:0x010f] */
    /* JADX WARNING: Removed duplicated region for block: B:52:0x0116 A[SYNTHETIC, Splitter:B:52:0x0116] */
    /* JADX WARNING: Removed duplicated region for block: B:59:0x011d A[SYNTHETIC, Splitter:B:59:0x011d] */
    /* JADX WARNING: Removed duplicated region for block: B:63:0x0124  */
    /* JADX WARNING: Removed duplicated region for block: B:73:? A[RETURN, SYNTHETIC] */
    /* JADX WARNING: Removed duplicated region for block: B:74:? A[RETURN, SYNTHETIC] */
    public void saveLoader() {
        OutputStream outputStream;
        OutputStream outputStream2;
        Throwable th;
        Class cls;
        String indexClassForSystem = SchemaTypeCodePrinter.indexClassForSystem(this);
        String[] makeClassStrings = makeClassStrings(indexClassForSystem);
        if ($assertionsDisabled || makeClassStrings.length == HOLDER_TEMPLATE_NAMES.length) {
            Filer filer = this._filer;
            InputStream inputStream = null;
            Repackager repackager = filer instanceof FilerImpl ? ((FilerImpl) filer).getRepackager() : null;
            try {
                if (class$org$apache$xmlbeans$impl$schema$SchemaTypeSystemImpl == null) {
                    cls = class$("org.apache.xmlbeans.impl.schema.SchemaTypeSystemImpl");
                    class$org$apache$xmlbeans$impl$schema$SchemaTypeSystemImpl = cls;
                } else {
                    cls = class$org$apache$xmlbeans$impl$schema$SchemaTypeSystemImpl;
                }
                InputStream resourceAsStream = cls.getResourceAsStream(HOLDER_TEMPLATE_CLASSFILE);
                if (resourceAsStream != null) {
                    try {
                        DataInputStream dataInputStream = new DataInputStream(resourceAsStream);
                        Filer filer2 = this._filer;
                        StringBuffer stringBuffer = new StringBuffer();
                        stringBuffer.append(indexClassForSystem.replace(NameUtil.PERIOD, JarHelper.SEP));
                        stringBuffer.append(".class");
                        OutputStream createBinaryFile = filer2.createBinaryFile(stringBuffer.toString());
                        DataOutputStream dataOutputStream = new DataOutputStream(createBinaryFile);
                        dataOutputStream.writeInt(dataInputStream.readInt());
                        dataOutputStream.writeShort(dataInputStream.readUnsignedShort());
                        dataOutputStream.writeShort(dataInputStream.readUnsignedShort());
                        int readUnsignedShort = dataInputStream.readUnsignedShort();
                        dataOutputStream.writeShort(readUnsignedShort);
                        for (int i2 = 1; i2 < readUnsignedShort; i2++) {
                            int readUnsignedByte = dataInputStream.readUnsignedByte();
                            dataOutputStream.writeByte(readUnsignedByte);
                            switch (readUnsignedByte) {
                                case 1:
                                    dataOutputStream.writeUTF(repackageConstant(dataInputStream.readUTF(), makeClassStrings, repackager));
                                    break;
                                case 2:
                                default:
                                    StringBuffer stringBuffer2 = new StringBuffer();
                                    stringBuffer2.append("Unexpected constant type: ");
                                    stringBuffer2.append(readUnsignedByte);
                                    throw new RuntimeException(stringBuffer2.toString());
                                case 3:
                                case 4:
                                    dataOutputStream.writeInt(dataInputStream.readInt());
                                    break;
                                case 5:
                                case 6:
                                    dataOutputStream.writeInt(dataInputStream.readInt());
                                    dataOutputStream.writeInt(dataInputStream.readInt());
                                    break;
                                case 7:
                                case 8:
                                    dataOutputStream.writeShort(dataInputStream.readUnsignedShort());
                                    break;
                                case 9:
                                case 10:
                                case 11:
                                case 12:
                                    dataOutputStream.writeShort(dataInputStream.readUnsignedShort());
                                    dataOutputStream.writeShort(dataInputStream.readUnsignedShort());
                                    break;
                            }
                        }
                        while (true) {
                            dataOutputStream.writeByte(dataInputStream.readByte());
                            resourceAsStream.close();
                            if (createBinaryFile == null) {
                                try {
                                    createBinaryFile.close();
                                    return;
                                } catch (Exception unused) {
                                    return;
                                }
                            } else {
                                return;
                            }
                        }
                    } catch (IOException unused2) {
                        outputStream = null;
                        inputStream = resourceAsStream;
                        if (inputStream != null) {
                        }
                        if (outputStream == null) {
                        }
                    } catch (Throwable th2) {
                        th = th2;
                        outputStream2 = null;
                        inputStream = resourceAsStream;
                        if (inputStream != null) {
                        }
                        if (outputStream2 != null) {
                        }
                        throw th;
                    }
                } else {
                    throw new SchemaTypeLoaderException("couldn't find resource: TypeSystemHolder.template", this._name, null, 9);
                }
            } catch (IOException unused3) {
                outputStream = null;
                if (inputStream != null) {
                    try {
                        inputStream.close();
                    } catch (Exception unused4) {
                    }
                }
                if (outputStream == null) {
                    outputStream.close();
                }
            } catch (Throwable th3) {
                th = th3;
                outputStream2 = null;
                if (inputStream != null) {
                    try {
                        inputStream.close();
                    } catch (Exception unused5) {
                    }
                }
                if (outputStream2 != null) {
                    try {
                        outputStream2.close();
                    } catch (Exception unused6) {
                    }
                }
                throw th;
            }
        } else {
            throw new AssertionError();
        }
    }

    public void saveModelGroup(SchemaModelGroup schemaModelGroup) {
        if (!this._incomplete) {
            String handleForModelGroup = this._localHandles.handleForModelGroup(schemaModelGroup);
            XsbReader xsbReader = new XsbReader(handleForModelGroup);
            xsbReader.writeModelGroupData(schemaModelGroup);
            xsbReader.writeRealHeader(handleForModelGroup, 6);
            xsbReader.writeModelGroupData(schemaModelGroup);
            xsbReader.writeEnd();
            return;
        }
        throw new IllegalStateException("This SchemaTypeSystem cannot be saved.");
    }

    public void saveModelGroups(SchemaModelGroup[] schemaModelGroupArr) {
        if (!this._incomplete) {
            for (SchemaModelGroup schemaModelGroup : schemaModelGroupArr) {
                saveModelGroup(schemaModelGroup);
            }
            return;
        }
        throw new IllegalStateException("This SchemaTypeSystem cannot be saved.");
    }

    public void savePointerFile(String str, String str2) {
        XsbReader xsbReader = new XsbReader(str);
        xsbReader.writeString(str2);
        xsbReader.writeRealHeader(str, 5);
        xsbReader.writeString(str2);
        xsbReader.writeEnd();
    }

    public void savePointers() {
        savePointersForComponents(globalElements(), a.a(a.a("schema"), METADATA_PACKAGE_GEN, "/element/"));
        savePointersForComponents(globalAttributes(), a.a(a.a("schema"), METADATA_PACKAGE_GEN, "/attribute/"));
        savePointersForComponents(modelGroups(), a.a(a.a("schema"), METADATA_PACKAGE_GEN, "/modelgroup/"));
        savePointersForComponents(attributeGroups(), a.a(a.a("schema"), METADATA_PACKAGE_GEN, "/attributegroup/"));
        savePointersForComponents(globalTypes(), a.a(a.a("schema"), METADATA_PACKAGE_GEN, "/type/"));
        savePointersForComponents(identityConstraints(), a.a(a.a("schema"), METADATA_PACKAGE_GEN, "/identityconstraint/"));
        Set set = this._namespaces;
        StringBuffer a = a.a("schema");
        a.append(METADATA_PACKAGE_GEN);
        a.append("/namespace/");
        savePointersForNamespaces(set, a.toString());
        Set keySet = this._typeRefsByClassname.keySet();
        StringBuffer a2 = a.a("schema");
        a2.append(METADATA_PACKAGE_GEN);
        a2.append("/javaname/");
        savePointersForClassnames(keySet, a2.toString());
        savePointersForComponents(redefinedModelGroups(), a.a(a.a("schema"), METADATA_PACKAGE_GEN, "/redefinedmodelgroup/"));
        savePointersForComponents(redefinedAttributeGroups(), a.a(a.a("schema"), METADATA_PACKAGE_GEN, "/redefinedattributegroup/"));
        savePointersForComponents(redefinedGlobalTypes(), a.a(a.a("schema"), METADATA_PACKAGE_GEN, "/redefinedtype/"));
    }

    public void savePointersForClassnames(Set set, String str) {
        Iterator it = set.iterator();
        while (it.hasNext()) {
            StringBuffer a = a.a(str);
            a.append(((String) it.next()).replace(NameUtil.PERIOD, JarHelper.SEP));
            savePointerFile(a.toString(), this._name);
        }
    }

    public void savePointersForComponents(SchemaComponent[] schemaComponentArr, String str) {
        for (SchemaComponent schemaComponent : schemaComponentArr) {
            StringBuffer a = a.a(str);
            a.append(QNameHelper.hexsafedir(schemaComponent.getName()));
            savePointerFile(a.toString(), this._name);
        }
    }

    public void savePointersForNamespaces(Set set, String str) {
        Iterator it = set.iterator();
        while (it.hasNext()) {
            StringBuffer a = a.a(str);
            a.append(QNameHelper.hexsafedir(new QName((String) it.next(), "xmlns")));
            savePointerFile(a.toString(), this._name);
        }
    }

    @Override // org.apache.xmlbeans.SchemaTypeSystem
    public void saveToDirectory(File file) {
        save(new FilerImpl(file, null, null, false, false));
    }

    public void saveType(SchemaType schemaType) {
        String handleForType = this._localHandles.handleForType(schemaType);
        XsbReader xsbReader = new XsbReader(handleForType);
        xsbReader.writeTypeData(schemaType);
        xsbReader.writeRealHeader(handleForType, 2);
        xsbReader.writeTypeData(schemaType);
        xsbReader.writeEnd();
    }

    public void saveTypesRecursively(SchemaType[] schemaTypeArr) {
        for (int i2 = 0; i2 < schemaTypeArr.length; i2++) {
            if (schemaTypeArr[i2].getTypeSystem() == getTypeSystem()) {
                saveType(schemaTypeArr[i2]);
                saveTypesRecursively(schemaTypeArr[i2].getAnonymousTypes());
            }
        }
    }

    public void setDependencies(SchemaDependencies schemaDependencies) {
        this._deps = schemaDependencies;
    }

    public void setIncomplete(boolean z) {
        this._incomplete = z;
    }

    @Override // org.apache.xmlbeans.SchemaTypeLoader
    public SchemaType typeForClassname(String str) {
        SchemaType.Ref ref = (SchemaType.Ref) this._typeRefsByClassname.get(str);
        if (ref != null) {
            return ref.get();
        }
        return null;
    }

    @Override // org.apache.xmlbeans.SchemaTypeSystem
    public SchemaType typeForHandle(String str) {
        SchemaType schemaType;
        synchronized (this._resolvedHandles) {
            schemaType = (SchemaType) this._resolvedHandles.get(str);
        }
        return schemaType;
    }

    public SchemaTypeSystem typeSystemForName(String str) {
        String str2 = this._name;
        if (str2 == null || !str.equals(str2)) {
            return null;
        }
        return this;
    }

    private Map buildTypeRefsByClassname(Map map) {
        LinkedHashMap linkedHashMap = new LinkedHashMap();
        for (String str : map.keySet()) {
            linkedHashMap.put(str, ((SchemaType) map.get(str)).getRef());
        }
        return linkedHashMap;
    }

    public class XsbReader {
        public static final /* synthetic */ boolean $assertionsDisabled;
        public int _actualfiletype;
        public String _handle;
        public DataInputStream _input;
        public int _majorver;
        public int _minorver;
        public DataOutputStream _output;
        public int _releaseno;
        public StringPool _stringPool;

        static {
            Class cls = SchemaTypeSystemImpl.class$org$apache$xmlbeans$impl$schema$SchemaTypeSystemImpl;
            if (cls == null) {
                cls = SchemaTypeSystemImpl.class$("org.apache.xmlbeans.impl.schema.SchemaTypeSystemImpl");
                SchemaTypeSystemImpl.class$org$apache$xmlbeans$impl$schema$SchemaTypeSystemImpl = cls;
            }
            $assertionsDisabled = !cls.desiredAssertionStatus();
        }

        public XsbReader(String str, int i2) {
            StringBuffer stringBuffer = new StringBuffer();
            stringBuffer.append(SchemaTypeSystemImpl.this._basePackage);
            stringBuffer.append(str);
            stringBuffer.append(".xsb");
            String stringBuffer2 = stringBuffer.toString();
            InputStream loaderStream = getLoaderStream(stringBuffer2);
            if (loaderStream != null) {
                this._input = new DataInputStream(loaderStream);
                this._handle = str;
                if (readInt() == -629491010) {
                    this._majorver = readShort();
                    int readShort = readShort();
                    this._minorver = readShort;
                    if (this._majorver != 2) {
                        StringBuffer a = a.a("XML-BEANS compiled schema: Wrong major version - expecting 2, got ");
                        a.append(this._majorver);
                        throw new SchemaTypeLoaderException(a.toString(), SchemaTypeSystemImpl.this._name, str, 2);
                    } else if (readShort > 24) {
                        StringBuffer a2 = a.a("XML-BEANS compiled schema: Incompatible minor version - expecting up to 24, got ");
                        a2.append(this._minorver);
                        throw new SchemaTypeLoaderException(a2.toString(), SchemaTypeSystemImpl.this._name, str, 3);
                    } else if (readShort >= 14) {
                        if (atLeast(2, 18, 0)) {
                            this._releaseno = readShort();
                        }
                        int readShort2 = readShort();
                        if (readShort2 == i2 || i2 == 65535) {
                            StringPool stringPool = new StringPool(this._handle, SchemaTypeSystemImpl.this._name);
                            this._stringPool = stringPool;
                            stringPool.readFrom(this._input);
                            this._actualfiletype = readShort2;
                            return;
                        }
                        StringBuffer stringBuffer3 = new StringBuffer();
                        stringBuffer3.append("XML-BEANS compiled schema: File has the wrong type - expecting type ");
                        stringBuffer3.append(i2);
                        stringBuffer3.append(", got type ");
                        stringBuffer3.append(readShort2);
                        throw new SchemaTypeLoaderException(stringBuffer3.toString(), SchemaTypeSystemImpl.this._name, str, 4);
                    } else {
                        StringBuffer a3 = a.a("XML-BEANS compiled schema: Incompatible minor version - expecting at least 14, got ");
                        a3.append(this._minorver);
                        throw new SchemaTypeLoaderException(a3.toString(), SchemaTypeSystemImpl.this._name, str, 3);
                    }
                } else {
                    throw new SchemaTypeLoaderException("XML-BEANS compiled schema: Wrong magic cookie", SchemaTypeSystemImpl.this._name, str, 1);
                }
            } else {
                throw new SchemaTypeLoaderException(a.a("XML-BEANS compiled schema: Could not locate compiled schema resource ", stringBuffer2), SchemaTypeSystemImpl.this._name, str, 0);
            }
        }

        public boolean atLeast(int i2, int i3, int i4) {
            int i5 = this._majorver;
            if (i5 > i2) {
                return true;
            }
            if (i5 < i2) {
                return false;
            }
            int i6 = this._minorver;
            if (i6 > i3) {
                return true;
            }
            if (i6 >= i3 && this._releaseno >= i4) {
                return true;
            }
            return false;
        }

        public boolean atMost(int i2, int i3, int i4) {
            int i5 = this._majorver;
            if (i5 > i2) {
                return false;
            }
            if (i5 < i2) {
                return true;
            }
            int i6 = this._minorver;
            if (i6 > i3) {
                return false;
            }
            if (i6 >= i3 && this._releaseno > i4) {
                return false;
            }
            return true;
        }

        public void checkContainerNotNull(SchemaContainer schemaContainer, QName qName) {
            if (schemaContainer == null) {
                StringBuffer a = a.a("Loading of resource ");
                a.append(SchemaTypeSystemImpl.this._name);
                a.append(NameUtil.PERIOD);
                a.append(this._handle);
                a.append("failed, information from ");
                a.append(SchemaTypeSystemImpl.this._name);
                a.append(".index.xsb is ");
                a.append(" out of sync (or conflicting index files found)");
                throw new LinkageError(a.toString());
            }
        }

        public int fileTypeFromComponentType(int i2) {
            if (i2 == 0) {
                return 2;
            }
            if (i2 == 1) {
                return 3;
            }
            if (i2 == 3) {
                return 4;
            }
            if (i2 == 4) {
                return 7;
            }
            if (i2 == 5) {
                return 8;
            }
            if (i2 == 6) {
                return 6;
            }
            throw new IllegalStateException("Unexpected component type");
        }

        public SchemaGlobalAttribute finishLoadingAttribute() {
            try {
                QName readQName = readQName();
                SchemaContainer container = SchemaTypeSystemImpl.this.getContainer(readQName.getNamespaceURI());
                checkContainerNotNull(container, readQName);
                SchemaGlobalAttributeImpl schemaGlobalAttributeImpl = new SchemaGlobalAttributeImpl(container);
                loadAttribute(schemaGlobalAttributeImpl, readQName, container);
                schemaGlobalAttributeImpl.setFilename(readString());
                readEnd();
                return schemaGlobalAttributeImpl;
            } catch (SchemaTypeLoaderException e2) {
                throw e2;
            } catch (Exception e3) {
                throw new SchemaTypeLoaderException("Cannot load type from typesystem", SchemaTypeSystemImpl.this._name, this._handle, 14, e3);
            } catch (Throwable th) {
                readEnd();
                throw th;
            }
        }

        public SchemaAttributeGroup finishLoadingAttributeGroup() {
            QName readQName = readQName();
            SchemaContainer container = SchemaTypeSystemImpl.this.getContainer(readQName.getNamespaceURI());
            checkContainerNotNull(container, readQName);
            SchemaAttributeGroupImpl schemaAttributeGroupImpl = new SchemaAttributeGroupImpl(container);
            try {
                schemaAttributeGroupImpl.init(readQName, readString(), readShort() == 1, atLeast(2, 22, 0) ? readString() : null, atLeast(2, 15, 0) && readShort() == 1, AttributeGroupDocument.Factory.parse(readString()).getAttributeGroup(), readAnnotation(container), null);
                if (atLeast(2, 21, 0)) {
                    schemaAttributeGroupImpl.setFilename(readString());
                }
                readEnd();
                return schemaAttributeGroupImpl;
            } catch (SchemaTypeLoaderException e2) {
                throw e2;
            } catch (Exception e3) {
                throw new SchemaTypeLoaderException("Cannot load type from typesystem", SchemaTypeSystemImpl.this._name, this._handle, 14, e3);
            } catch (Throwable th) {
                readEnd();
                throw th;
            }
        }

        public SchemaGlobalElement finishLoadingElement() {
            try {
                int readShort = readShort();
                if (readShort == 4) {
                    int readShort2 = readShort();
                    BigInteger readBigInteger = readBigInteger();
                    BigInteger readBigInteger2 = readBigInteger();
                    QNameSet readQNameSet = readQNameSet();
                    QName readQName = readQName();
                    SchemaContainer container = SchemaTypeSystemImpl.this.getContainer(readQName.getNamespaceURI());
                    checkContainerNotNull(container, readQName);
                    SchemaGlobalElementImpl schemaGlobalElementImpl = new SchemaGlobalElementImpl(container);
                    schemaGlobalElementImpl.setParticleType(readShort);
                    schemaGlobalElementImpl.setMinOccurs(readBigInteger);
                    schemaGlobalElementImpl.setMaxOccurs(readBigInteger2);
                    boolean z = true;
                    schemaGlobalElementImpl.setTransitionRules(readQNameSet, (readShort2 & 1) != 0);
                    schemaGlobalElementImpl.setNameAndTypeRef(readQName, readTypeRef());
                    schemaGlobalElementImpl.setDefault(readString(), (readShort2 & 4) != 0, null);
                    if (atLeast(2, 16, 0)) {
                        schemaGlobalElementImpl.setDefaultValue(readXmlValueObject());
                    }
                    schemaGlobalElementImpl.setNillable((readShort2 & 8) != 0);
                    schemaGlobalElementImpl.setBlock((readShort2 & 16) != 0, (readShort2 & 32) != 0, (readShort2 & 64) != 0);
                    schemaGlobalElementImpl.setWsdlArrayType(readSOAPArrayType());
                    schemaGlobalElementImpl.setAbstract((readShort2 & 128) != 0);
                    schemaGlobalElementImpl.setAnnotation(readAnnotation(container));
                    boolean z2 = (readShort2 & 256) != 0;
                    if ((readShort2 & 512) == 0) {
                        z = false;
                    }
                    schemaGlobalElementImpl.setFinal(z2, z);
                    if (atLeast(2, 17, 0)) {
                        schemaGlobalElementImpl.setSubstitutionGroup((SchemaGlobalElement.Ref) readHandle());
                    }
                    int readShort3 = readShort();
                    for (int i2 = 0; i2 < readShort3; i2++) {
                        schemaGlobalElementImpl.addSubstitutionGroupMember(readQName());
                    }
                    int readShort4 = readShort();
                    SchemaIdentityConstraint.Ref[] refArr = new SchemaIdentityConstraint.Ref[readShort4];
                    for (int i3 = 0; i3 < readShort4; i3++) {
                        refArr[i3] = (SchemaIdentityConstraint.Ref) readHandle();
                    }
                    schemaGlobalElementImpl.setIdentityConstraints(refArr);
                    schemaGlobalElementImpl.setFilename(readString());
                    readEnd();
                    return schemaGlobalElementImpl;
                }
                throw new SchemaTypeLoaderException("Wrong particle type ", SchemaTypeSystemImpl.this._name, this._handle, 11);
            } catch (SchemaTypeLoaderException e2) {
                throw e2;
            } catch (Exception e3) {
                throw new SchemaTypeLoaderException("Cannot load type from typesystem", SchemaTypeSystemImpl.this._name, null, 14, e3);
            } catch (Throwable th) {
                readEnd();
                throw th;
            }
        }

        public SchemaIdentityConstraint finishLoadingIdentityConstraint() {
            try {
                QName readQName = readQName();
                SchemaContainer container = SchemaTypeSystemImpl.this.getContainer(readQName.getNamespaceURI());
                checkContainerNotNull(container, readQName);
                SchemaIdentityConstraintImpl schemaIdentityConstraintImpl = new SchemaIdentityConstraintImpl(container);
                schemaIdentityConstraintImpl.setName(readQName);
                schemaIdentityConstraintImpl.setConstraintCategory(readShort());
                schemaIdentityConstraintImpl.setSelector(readString());
                schemaIdentityConstraintImpl.setAnnotation(readAnnotation(container));
                int readShort = readShort();
                String[] strArr = new String[readShort];
                for (int i2 = 0; i2 < readShort; i2++) {
                    strArr[i2] = readString();
                }
                schemaIdentityConstraintImpl.setFields(strArr);
                if (schemaIdentityConstraintImpl.getConstraintCategory() == 2) {
                    schemaIdentityConstraintImpl.setReferencedKey((SchemaIdentityConstraint.Ref) readHandle());
                }
                int readShort2 = readShort();
                HashMap hashMap = new HashMap();
                for (int i3 = 0; i3 < readShort2; i3++) {
                    hashMap.put(readString(), readString());
                }
                schemaIdentityConstraintImpl.setNSMap(hashMap);
                if (atLeast(2, 21, 0)) {
                    schemaIdentityConstraintImpl.setFilename(readString());
                }
                readEnd();
                return schemaIdentityConstraintImpl;
            } catch (SchemaTypeLoaderException e2) {
                throw e2;
            } catch (Exception e3) {
                throw new SchemaTypeLoaderException("Cannot load type from typesystem", SchemaTypeSystemImpl.this._name, this._handle, 14, e3);
            } catch (Throwable th) {
                readEnd();
                throw th;
            }
        }

        public SchemaModelGroup finishLoadingModelGroup() {
            QName readQName = readQName();
            SchemaContainer container = SchemaTypeSystemImpl.this.getContainer(readQName.getNamespaceURI());
            checkContainerNotNull(container, readQName);
            SchemaModelGroupImpl schemaModelGroupImpl = new SchemaModelGroupImpl(container);
            try {
                schemaModelGroupImpl.init(readQName, readString(), readShort() == 1, atLeast(2, 22, 0) ? readString() : null, atLeast(2, 22, 0) ? readString() : null, atLeast(2, 15, 0) && readShort() == 1, GroupDocument.Factory.parse(readString()).getGroup(), readAnnotation(container), null);
                if (atLeast(2, 21, 0)) {
                    schemaModelGroupImpl.setFilename(readString());
                }
                readEnd();
                return schemaModelGroupImpl;
            } catch (SchemaTypeLoaderException e2) {
                throw e2;
            } catch (Exception e3) {
                throw new SchemaTypeLoaderException("Cannot load type from typesystem", SchemaTypeSystemImpl.this._name, this._handle, 14, e3);
            } catch (Throwable th) {
                readEnd();
                throw th;
            }
        }

        /* JADX WARNING: Removed duplicated region for block: B:105:0x01e9 A[Catch:{ SchemaTypeLoaderException -> 0x03e1, Exception -> 0x03cc, all -> 0x03c9 }] */
        /* JADX WARNING: Removed duplicated region for block: B:106:0x01eb A[Catch:{ SchemaTypeLoaderException -> 0x03e1, Exception -> 0x03cc, all -> 0x03c9 }] */
        public SchemaType finishLoadingType() {
            int i2;
            QName attributeTypeAttributeName;
            LinkedHashMap linkedHashMap;
            SchemaParticle schemaParticle;
            int i3;
            int i4;
            SchemaParticle schemaParticle2;
            String str = "";
            try {
                SchemaTypeImpl schemaTypeImpl = new SchemaTypeImpl(SchemaTypeSystemImpl.this.getContainerNonNull(str), true);
                schemaTypeImpl.setName(readQName());
                schemaTypeImpl.setOuterSchemaTypeRef(readTypeRef());
                schemaTypeImpl.setBaseDepth(readShort());
                schemaTypeImpl.setBaseTypeRef(readTypeRef());
                schemaTypeImpl.setDerivationType(readShort());
                schemaTypeImpl.setAnnotation(readAnnotation(null));
                int readShort = readShort();
                if (readShort == 1) {
                    schemaTypeImpl.setContainerFieldRef(readHandle());
                } else if (readShort == 2) {
                    schemaTypeImpl.setContainerFieldIndex(1, readShort());
                } else if (readShort == 3) {
                    schemaTypeImpl.setContainerFieldIndex(2, readShort());
                }
                String readString = readString();
                if (readString == null) {
                    readString = str;
                }
                schemaTypeImpl.setFullJavaName(readString);
                String readString2 = readString();
                if (readString2 != null) {
                    str = readString2;
                }
                schemaTypeImpl.setFullJavaImplName(str);
                schemaTypeImpl.setAnonymousTypeRefs(readTypeRefArray());
                schemaTypeImpl.setAnonymousUnionMemberOrdinal(readShort());
                int readInt = readInt();
                boolean z = (readInt & 1) == 0;
                schemaTypeImpl.setCompiled((readInt & 2048) != 0);
                schemaTypeImpl.setDocumentType((readInt & 2) != 0);
                schemaTypeImpl.setAttributeType((524288 & readInt) != 0);
                schemaTypeImpl.setSimpleType(!z);
                if (z) {
                    schemaTypeImpl.setAbstractFinal((262144 & readInt) != 0, (readInt & 16384) != 0, (readInt & 32768) != 0, (readInt & 131072) != 0, (readInt & 65536) != 0);
                    schemaTypeImpl.setBlock((readInt & 4096) != 0, (readInt & 8192) != 0);
                    schemaTypeImpl.setOrderSensitive((readInt & 512) != 0);
                    int readShort2 = readShort();
                    schemaTypeImpl.setComplexTypeVariety(readShort2);
                    if (atLeast(2, 23, 0)) {
                        schemaTypeImpl.setContentBasedOnTypeRef(readTypeRef());
                    }
                    SchemaAttributeModelImpl schemaAttributeModelImpl = new SchemaAttributeModelImpl();
                    int readShort3 = readShort();
                    for (int i5 = 0; i5 < readShort3; i5++) {
                        schemaAttributeModelImpl.addAttribute(readAttributeData());
                    }
                    schemaAttributeModelImpl.setWildcardSet(readQNameSet());
                    schemaAttributeModelImpl.setWildcardProcess(readShort());
                    LinkedHashMap linkedHashMap2 = new LinkedHashMap();
                    int readShort4 = readShort();
                    for (int i6 = 0; i6 < readShort4; i6++) {
                        SchemaProperty readPropertyData = readPropertyData();
                        if (readPropertyData.isAttribute()) {
                            linkedHashMap2.put(readPropertyData.getName(), readPropertyData);
                        } else {
                            StringBuffer stringBuffer = new StringBuffer();
                            stringBuffer.append("Attribute property ");
                            stringBuffer.append(i6);
                            stringBuffer.append(" is not an attribute");
                            throw new SchemaTypeLoaderException(stringBuffer.toString(), SchemaTypeSystemImpl.this._name, this._handle, 6);
                        }
                    }
                    if (readShort2 != 3) {
                        if (readShort2 != 4) {
                            i4 = 0;
                            i3 = 1;
                            schemaParticle = null;
                            linkedHashMap = null;
                            schemaTypeImpl.setContentModel(schemaParticle, schemaAttributeModelImpl, linkedHashMap, linkedHashMap2, i4 != i3);
                            StscComplexTypeResolver.WildcardResult summarizeEltWildcards = StscComplexTypeResolver.summarizeEltWildcards(schemaParticle);
                            StscComplexTypeResolver.WildcardResult summarizeAttrWildcards = StscComplexTypeResolver.summarizeAttrWildcards(schemaAttributeModelImpl);
                            schemaTypeImpl.setWildcardSummary(summarizeEltWildcards.typedWildcards, summarizeEltWildcards.hasWildcards, summarizeAttrWildcards.typedWildcards, summarizeAttrWildcards.hasWildcards);
                            i2 = readShort2;
                        }
                    }
                    i4 = readShort();
                    SchemaParticle[] readParticleArray = readParticleArray();
                    if (readParticleArray.length == 1) {
                        schemaParticle2 = readParticleArray[0];
                    } else if (readParticleArray.length == 0) {
                        schemaParticle2 = null;
                    } else {
                        throw new SchemaTypeLoaderException("Content model not well-formed", SchemaTypeSystemImpl.this._name, this._handle, 7);
                    }
                    LinkedHashMap linkedHashMap3 = new LinkedHashMap();
                    int readShort5 = readShort();
                    for (int i7 = 0; i7 < readShort5; i7++) {
                        SchemaProperty readPropertyData2 = readPropertyData();
                        if (!readPropertyData2.isAttribute()) {
                            linkedHashMap3.put(readPropertyData2.getName(), readPropertyData2);
                        } else {
                            StringBuffer stringBuffer2 = new StringBuffer();
                            stringBuffer2.append("Element property ");
                            stringBuffer2.append(i7);
                            stringBuffer2.append(" is not an element");
                            throw new SchemaTypeLoaderException(stringBuffer2.toString(), SchemaTypeSystemImpl.this._name, this._handle, 6);
                        }
                    }
                    schemaParticle = schemaParticle2;
                    linkedHashMap = linkedHashMap3;
                    i3 = 1;
                    schemaTypeImpl.setContentModel(schemaParticle, schemaAttributeModelImpl, linkedHashMap, linkedHashMap2, i4 != i3);
                    StscComplexTypeResolver.WildcardResult summarizeEltWildcards2 = StscComplexTypeResolver.summarizeEltWildcards(schemaParticle);
                    StscComplexTypeResolver.WildcardResult summarizeAttrWildcards2 = StscComplexTypeResolver.summarizeAttrWildcards(schemaAttributeModelImpl);
                    schemaTypeImpl.setWildcardSummary(summarizeEltWildcards2.typedWildcards, summarizeEltWildcards2.hasWildcards, summarizeAttrWildcards2.typedWildcards, summarizeAttrWildcards2.hasWildcards);
                    i2 = readShort2;
                } else {
                    i2 = 0;
                }
                if (!z || i2 == 2) {
                    int readShort6 = readShort();
                    schemaTypeImpl.setSimpleTypeVariety(readShort6);
                    boolean z2 = (readInt & 64) != 0;
                    schemaTypeImpl.setOrdered((readInt & 4) != 0 ? 0 : (readInt & 1024) != 0 ? 2 : 1);
                    schemaTypeImpl.setBounded((readInt & 8) != 0);
                    schemaTypeImpl.setFinite((readInt & 16) != 0);
                    schemaTypeImpl.setNumeric((readInt & 32) != 0);
                    schemaTypeImpl.setUnionOfLists((readInt & 128) != 0);
                    schemaTypeImpl.setSimpleFinal((readInt & 32768) != 0, (readInt & 131072) != 0, (readInt & 65536) != 0);
                    XmlValueRef[] xmlValueRefArr = new XmlValueRef[12];
                    boolean[] zArr = new boolean[12];
                    int readShort7 = readShort();
                    for (int i8 = 0; i8 < readShort7; i8++) {
                        int readShort8 = readShort();
                        xmlValueRefArr[readShort8] = readXmlValueObject();
                        zArr[readShort8] = readShort() == 1;
                    }
                    schemaTypeImpl.setBasicFacets(xmlValueRefArr, zArr);
                    schemaTypeImpl.setWhiteSpaceRule(readShort());
                    schemaTypeImpl.setPatternFacet((readInt & 256) != 0);
                    int readShort9 = readShort();
                    RegularExpression[] regularExpressionArr = new RegularExpression[readShort9];
                    for (int i9 = 0; i9 < readShort9; i9++) {
                        regularExpressionArr[i9] = new RegularExpression(readString(), "X");
                    }
                    schemaTypeImpl.setPatterns(regularExpressionArr);
                    int readShort10 = readShort();
                    XmlValueRef[] xmlValueRefArr2 = new XmlValueRef[readShort10];
                    for (int i10 = 0; i10 < readShort10; i10++) {
                        xmlValueRefArr2[i10] = readXmlValueObject();
                    }
                    if (readShort10 == 0) {
                        xmlValueRefArr2 = null;
                    }
                    schemaTypeImpl.setEnumerationValues(xmlValueRefArr2);
                    schemaTypeImpl.setBaseEnumTypeRef(readTypeRef());
                    if (z2) {
                        int readShort11 = readShort();
                        SchemaStringEnumEntry[] schemaStringEnumEntryArr = new SchemaStringEnumEntry[readShort11];
                        for (int i11 = 0; i11 < readShort11; i11++) {
                            schemaStringEnumEntryArr[i11] = new SchemaStringEnumEntryImpl(readString(), readShort(), readString());
                        }
                        schemaTypeImpl.setStringEnumEntries(schemaStringEnumEntryArr);
                    }
                    if (readShort6 == 1) {
                        schemaTypeImpl.setPrimitiveTypeRef(readTypeRef());
                        schemaTypeImpl.setDecimalSize(readInt());
                    } else if (readShort6 == 2) {
                        schemaTypeImpl.setPrimitiveTypeRef(BuiltinSchemaTypeSystem.ST_ANY_SIMPLE.getRef());
                        schemaTypeImpl.setUnionMemberTypeRefs(readTypeRefArray());
                    } else if (readShort6 == 3) {
                        schemaTypeImpl.setPrimitiveTypeRef(BuiltinSchemaTypeSystem.ST_ANY_SIMPLE.getRef());
                        schemaTypeImpl.setListItemTypeRef(readTypeRef());
                    } else {
                        throw new SchemaTypeLoaderException("Simple type does not have a recognized variety", SchemaTypeSystemImpl.this._name, this._handle, 8);
                    }
                }
                schemaTypeImpl.setFilename(readString());
                if (schemaTypeImpl.getName() != null) {
                    SchemaContainer container = SchemaTypeSystemImpl.this.getContainer(schemaTypeImpl.getName().getNamespaceURI());
                    checkContainerNotNull(container, schemaTypeImpl.getName());
                    schemaTypeImpl.setContainer(container);
                } else if (schemaTypeImpl.isDocumentType()) {
                    QName documentElementName = schemaTypeImpl.getDocumentElementName();
                    if (documentElementName != null) {
                        SchemaContainer container2 = SchemaTypeSystemImpl.this.getContainer(documentElementName.getNamespaceURI());
                        checkContainerNotNull(container2, documentElementName);
                        schemaTypeImpl.setContainer(container2);
                    }
                } else if (schemaTypeImpl.isAttributeType() && (attributeTypeAttributeName = schemaTypeImpl.getAttributeTypeAttributeName()) != null) {
                    SchemaContainer container3 = SchemaTypeSystemImpl.this.getContainer(attributeTypeAttributeName.getNamespaceURI());
                    checkContainerNotNull(container3, attributeTypeAttributeName);
                    schemaTypeImpl.setContainer(container3);
                }
                readEnd();
                return schemaTypeImpl;
            } catch (SchemaTypeLoaderException e2) {
                throw e2;
            } catch (Exception e3) {
                throw new SchemaTypeLoaderException("Cannot load type from typesystem", SchemaTypeSystemImpl.this._name, this._handle, 14, e3);
            } catch (Throwable th) {
                readEnd();
                throw th;
            }
        }

        public int getActualFiletype() {
            return this._actualfiletype;
        }

        public InputStream getLoaderStream(String str) {
            return SchemaTypeSystemImpl.this._resourceLoader.getResourceAsStream(str);
        }

        public OutputStream getSaverStream(String str) {
            try {
                return SchemaTypeSystemImpl.this._filer.createBinaryFile(str);
            } catch (IOException e2) {
                throw new SchemaTypeLoaderException(e2.getMessage(), SchemaTypeSystemImpl.this._name, this._handle, 9);
            }
        }

        public void loadAttribute(SchemaLocalAttributeImpl schemaLocalAttributeImpl, QName qName, SchemaContainer schemaContainer) {
            schemaLocalAttributeImpl.init(qName, readTypeRef(), readShort(), readString(), null, atLeast(2, 16, 0) ? readXmlValueObject() : null, readShort() == 1, readSOAPArrayType(), readAnnotation(schemaContainer), null);
        }

        public void loadParticle(SchemaParticleImpl schemaParticleImpl, int i2) {
            int readShort = readShort();
            schemaParticleImpl.setParticleType(i2);
            schemaParticleImpl.setMinOccurs(readBigInteger());
            schemaParticleImpl.setMaxOccurs(readBigInteger());
            boolean z = true;
            schemaParticleImpl.setTransitionRules(readQNameSet(), (readShort & 1) != 0);
            if (i2 == 1 || i2 == 2 || i2 == 3) {
                schemaParticleImpl.setParticleChildren(readParticleArray());
            } else if (i2 == 4) {
                SchemaLocalElementImpl schemaLocalElementImpl = (SchemaLocalElementImpl) schemaParticleImpl;
                schemaLocalElementImpl.setNameAndTypeRef(readQName(), readTypeRef());
                schemaLocalElementImpl.setDefault(readString(), (readShort & 4) != 0, null);
                if (atLeast(2, 16, 0)) {
                    schemaLocalElementImpl.setDefaultValue(readXmlValueObject());
                }
                schemaLocalElementImpl.setNillable((readShort & 8) != 0);
                schemaLocalElementImpl.setBlock((readShort & 16) != 0, (readShort & 32) != 0, (readShort & 64) != 0);
                schemaLocalElementImpl.setWsdlArrayType(readSOAPArrayType());
                if ((readShort & 128) == 0) {
                    z = false;
                }
                schemaLocalElementImpl.setAbstract(z);
                schemaLocalElementImpl.setAnnotation(readAnnotation(null));
                int readShort2 = readShort();
                SchemaIdentityConstraint.Ref[] refArr = new SchemaIdentityConstraint.Ref[readShort2];
                for (int i3 = 0; i3 < readShort2; i3++) {
                    refArr[i3] = (SchemaIdentityConstraint.Ref) readHandle();
                }
                schemaLocalElementImpl.setIdentityConstraints(refArr);
            } else if (i2 == 5) {
                schemaParticleImpl.setWildcardSet(readQNameSet());
                schemaParticleImpl.setWildcardProcess(readShort());
            } else {
                throw new SchemaTypeLoaderException("Unrecognized particle type ", SchemaTypeSystemImpl.this._name, this._handle, 11);
            }
        }

        public SchemaAnnotation readAnnotation(SchemaContainer schemaContainer) {
            int readInt;
            if (!atLeast(2, 19, 0) || (readInt = readInt()) == -1) {
                return null;
            }
            SchemaAnnotation.Attribute[] attributeArr = new SchemaAnnotation.Attribute[readInt];
            for (int i2 = 0; i2 < readInt; i2++) {
                attributeArr[i2] = new SchemaAnnotationImpl.AttributeImpl(readQName(), readString(), atLeast(2, 24, 0) ? readString() : null);
            }
            int readInt2 = readInt();
            String[] strArr = new String[readInt2];
            for (int i3 = 0; i3 < readInt2; i3++) {
                strArr[i3] = readString();
            }
            int readInt3 = readInt();
            String[] strArr2 = new String[readInt3];
            for (int i4 = 0; i4 < readInt3; i4++) {
                strArr2[i4] = readString();
            }
            return new SchemaAnnotationImpl(schemaContainer, strArr2, strArr, attributeArr);
        }

        public List readAnnotations() {
            int readInt = readInt();
            ArrayList arrayList = new ArrayList(readInt);
            SchemaContainer containerNonNull = SchemaTypeSystemImpl.this.getContainerNonNull("");
            for (int i2 = 0; i2 < readInt; i2++) {
                arrayList.add(readAnnotation(containerNonNull));
            }
            return arrayList;
        }

        public SchemaLocalAttribute readAttributeData() {
            SchemaLocalAttributeImpl schemaLocalAttributeImpl = new SchemaLocalAttributeImpl();
            loadAttribute(schemaLocalAttributeImpl, readQName(), null);
            return schemaLocalAttributeImpl;
        }

        public BigInteger readBigInteger() {
            byte[] readByteArray = readByteArray();
            if (readByteArray.length == 0) {
                return null;
            }
            if (readByteArray.length == 1 && readByteArray[0] == 0) {
                return BigInteger.ZERO;
            }
            if (readByteArray.length == 1 && readByteArray[0] == 1) {
                return BigInteger.ONE;
            }
            return new BigInteger(readByteArray);
        }

        public byte[] readByteArray() {
            try {
                byte[] bArr = new byte[this._input.readShort()];
                this._input.readFully(bArr);
                return bArr;
            } catch (IOException e2) {
                throw new SchemaTypeLoaderException(e2.getMessage(), SchemaTypeSystemImpl.this._name, this._handle, 9);
            }
        }

        public Map readClassnameRefMap() {
            HashMap hashMap = new HashMap();
            int readShort = readShort();
            for (int i2 = 0; i2 < readShort; i2++) {
                hashMap.put(readString(), readHandle());
            }
            return hashMap;
        }

        public double readDouble() {
            try {
                return this._input.readDouble();
            } catch (IOException e2) {
                throw new SchemaTypeLoaderException(e2.getMessage(), SchemaTypeSystemImpl.this._name, this._handle, 9);
            }
        }

        public void readEnd() {
            try {
                if (this._input != null) {
                    this._input.close();
                }
            } catch (IOException unused) {
            }
            this._input = null;
            this._stringPool = null;
            this._handle = null;
        }

        public void readExtensionsList() {
            int readShort = readShort();
            if ($assertionsDisabled || readShort == 0) {
                for (int i2 = 0; i2 < readShort; i2++) {
                    readString();
                    readString();
                    readString();
                }
                return;
            }
            throw new AssertionError();
        }

        public SchemaComponent.Ref readHandle() {
            String readString = readString();
            if (readString == null) {
                return null;
            }
            if (readString.charAt(0) != '_') {
                return SchemaTypeSystemImpl.this._localHandles.refForHandle(readString);
            }
            char charAt = readString.charAt(2);
            if (charAt == 'A') {
                return SchemaTypeSystemImpl.this._linker.findAttributeRef(QNameHelper.forPretty(readString, 4));
            }
            if (charAt == 'I') {
                SchemaType schemaType = (SchemaType) BuiltinSchemaTypeSystem.get().resolveHandle(readString);
                if (schemaType != null) {
                    return schemaType.getRef();
                }
                return ((SchemaType) XQuerySchemaTypeSystem.get().resolveHandle(readString)).getRef();
            } else if (charAt == 'Y') {
                SchemaType typeForSignature = SchemaTypeSystemImpl.this._linker.typeForSignature(readString.substring(4));
                if (typeForSignature != null) {
                    return typeForSignature.getRef();
                }
                throw new SchemaTypeLoaderException(a.a("Cannot resolve type for handle ", readString), SchemaTypeSystemImpl.this._name, this._handle, 13);
            } else if (charAt == 'D') {
                return SchemaTypeSystemImpl.this._linker.findIdentityConstraintRef(QNameHelper.forPretty(readString, 4));
            } else {
                if (charAt == 'E') {
                    return SchemaTypeSystemImpl.this._linker.findElementRef(QNameHelper.forPretty(readString, 4));
                }
                switch (charAt) {
                    case 'M':
                        return SchemaTypeSystemImpl.this._linker.findModelGroupRef(QNameHelper.forPretty(readString, 4));
                    case 'N':
                        return SchemaTypeSystemImpl.this._linker.findAttributeGroupRef(QNameHelper.forPretty(readString, 4));
                    case 'O':
                        return SchemaTypeSystemImpl.this._linker.findDocumentTypeRef(QNameHelper.forPretty(readString, 4));
                    default:
                        switch (charAt) {
                            case 'R':
                                SchemaGlobalAttribute findAttribute = SchemaTypeSystemImpl.this._linker.findAttribute(QNameHelper.forPretty(readString, 4));
                                if (findAttribute != null) {
                                    return findAttribute.getType().getRef();
                                }
                                throw new SchemaTypeLoaderException(a.a("Cannot resolve attribute for handle ", readString), SchemaTypeSystemImpl.this._name, this._handle, 13);
                            case 'S':
                                SchemaGlobalElement findElement = SchemaTypeSystemImpl.this._linker.findElement(QNameHelper.forPretty(readString, 4));
                                if (findElement != null) {
                                    return findElement.getType().getRef();
                                }
                                throw new SchemaTypeLoaderException(a.a("Cannot resolve element for handle ", readString), SchemaTypeSystemImpl.this._name, this._handle, 13);
                            case 'T':
                                return SchemaTypeSystemImpl.this._linker.findTypeRef(QNameHelper.forPretty(readString, 4));
                            default:
                                throw new SchemaTypeLoaderException(a.a("Cannot resolve handle ", readString), SchemaTypeSystemImpl.this._name, this._handle, 13);
                        }
                }
            }
        }

        public void readHandlePool(HandlePool handlePool) {
            Object obj;
            if (handlePool._handlesToRefs.size() != 0 || handlePool._started) {
                throw new IllegalStateException("Nonempty handle set before read");
            }
            int readShort = readShort();
            for (int i2 = 0; i2 < readShort; i2++) {
                String readString = readString();
                int readShort2 = readShort();
                if (readShort2 == 2) {
                    obj = new SchemaType.Ref(SchemaTypeSystemImpl.this.getTypeSystem(), readString);
                } else if (readShort2 == 3) {
                    obj = new SchemaGlobalElement.Ref(SchemaTypeSystemImpl.this.getTypeSystem(), readString);
                } else if (readShort2 == 4) {
                    obj = new SchemaGlobalAttribute.Ref(SchemaTypeSystemImpl.this.getTypeSystem(), readString);
                } else if (readShort2 == 6) {
                    obj = new SchemaModelGroup.Ref(SchemaTypeSystemImpl.this.getTypeSystem(), readString);
                } else if (readShort2 == 7) {
                    obj = new SchemaAttributeGroup.Ref(SchemaTypeSystemImpl.this.getTypeSystem(), readString);
                } else if (readShort2 == 8) {
                    obj = new SchemaIdentityConstraint.Ref(SchemaTypeSystemImpl.this.getTypeSystem(), readString);
                } else {
                    throw new SchemaTypeLoaderException(a.b("Schema index has an unrecognized entry of type ", readShort2), SchemaTypeSystemImpl.this._name, readString, 5);
                }
                handlePool._handlesToRefs.put(readString, obj);
            }
        }

        public int readInt() {
            try {
                return this._input.readInt();
            } catch (IOException e2) {
                throw new SchemaTypeLoaderException(e2.getMessage(), SchemaTypeSystemImpl.this._name, this._handle, 9);
            }
        }

        public Set readNamespaces() {
            HashSet hashSet = new HashSet();
            int readShort = readShort();
            for (int i2 = 0; i2 < readShort; i2++) {
                hashSet.add(readString());
            }
            return hashSet;
        }

        public SchemaParticle[] readParticleArray() {
            int readShort = readShort();
            SchemaParticle[] schemaParticleArr = new SchemaParticle[readShort];
            for (int i2 = 0; i2 < readShort; i2++) {
                schemaParticleArr[i2] = readParticleData();
            }
            return schemaParticleArr;
        }

        public SchemaParticle readParticleData() {
            SchemaParticleImpl schemaParticleImpl;
            int readShort = readShort();
            if (readShort != 4) {
                schemaParticleImpl = new SchemaParticleImpl();
            } else {
                schemaParticleImpl = new SchemaLocalElementImpl();
            }
            loadParticle(schemaParticleImpl, readShort);
            return schemaParticleImpl;
        }

        public SchemaProperty readPropertyData() {
            SchemaPropertyImpl schemaPropertyImpl = new SchemaPropertyImpl();
            schemaPropertyImpl.setName(readQName());
            schemaPropertyImpl.setTypeRef(readTypeRef());
            int readShort = readShort();
            boolean z = true;
            schemaPropertyImpl.setAttribute((readShort & 1) != 0);
            schemaPropertyImpl.setContainerTypeRef(readTypeRef());
            schemaPropertyImpl.setMinOccurs(readBigInteger());
            schemaPropertyImpl.setMaxOccurs(readBigInteger());
            schemaPropertyImpl.setNillable(readShort());
            schemaPropertyImpl.setDefault(readShort());
            schemaPropertyImpl.setFixed(readShort());
            schemaPropertyImpl.setDefaultText(readString());
            schemaPropertyImpl.setJavaPropertyName(readString());
            schemaPropertyImpl.setJavaTypeCode(readShort());
            SchemaType.Ref readTypeRef = readTypeRef();
            boolean z2 = (readShort & 2) != 0;
            boolean z3 = (readShort & 4) != 0;
            if ((readShort & 8) == 0) {
                z = false;
            }
            schemaPropertyImpl.setExtendsJava(readTypeRef, z2, z3, z);
            if (atMost(2, 19, 0)) {
                schemaPropertyImpl.setJavaSetterDelimiter(readQNameSet());
            }
            if (atLeast(2, 16, 0)) {
                schemaPropertyImpl.setDefaultValue(readXmlValueObject());
            }
            if (!schemaPropertyImpl.isAttribute() && atLeast(2, 17, 0)) {
                int readShort2 = readShort();
                LinkedHashSet linkedHashSet = new LinkedHashSet(readShort2);
                for (int i2 = 0; i2 < readShort2; i2++) {
                    linkedHashSet.add(readQName());
                }
                schemaPropertyImpl.setAcceptedNames(linkedHashSet);
            }
            schemaPropertyImpl.setImmutable();
            return schemaPropertyImpl;
        }

        public QName readQName() {
            String readString = readString();
            String readString2 = readString();
            if (readString2 == null) {
                return null;
            }
            return new QName(readString, readString2);
        }

        public Map readQNameRefMap() {
            HashMap hashMap = new HashMap();
            int readShort = readShort();
            for (int i2 = 0; i2 < readShort; i2++) {
                hashMap.put(readQName(), readHandle());
            }
            return hashMap;
        }

        public List readQNameRefMapAsList(List list) {
            int readShort = readShort();
            ArrayList arrayList = new ArrayList(readShort);
            for (int i2 = 0; i2 < readShort; i2++) {
                QName readQName = readQName();
                arrayList.add(readHandle());
                list.add(readQName);
            }
            return arrayList;
        }

        public QNameSet readQNameSet() {
            int readShort = readShort();
            HashSet hashSet = new HashSet();
            int readShort2 = readShort();
            for (int i2 = 0; i2 < readShort2; i2++) {
                hashSet.add(readString());
            }
            HashSet hashSet2 = new HashSet();
            int readShort3 = readShort();
            for (int i3 = 0; i3 < readShort3; i3++) {
                hashSet2.add(readQName());
            }
            HashSet hashSet3 = new HashSet();
            int readShort4 = readShort();
            for (int i4 = 0; i4 < readShort4; i4++) {
                hashSet3.add(readQName());
            }
            if (readShort == 1) {
                return QNameSet.forSets(hashSet, null, hashSet2, hashSet3);
            }
            return QNameSet.forSets(null, hashSet, hashSet3, hashSet2);
        }

        public SOAPArrayType readSOAPArrayType() {
            QName readQName = readQName();
            String readString = readString();
            if (readQName == null) {
                return null;
            }
            return new SOAPArrayType(readQName, readString);
        }

        public int readShort() {
            try {
                return this._input.readUnsignedShort();
            } catch (IOException e2) {
                throw new SchemaTypeLoaderException(e2.getMessage(), SchemaTypeSystemImpl.this._name, this._handle, 9);
            }
        }

        public String readString() {
            return this._stringPool.stringForCode(readShort());
        }

        public SchemaType.Ref readTypeRef() {
            return (SchemaType.Ref) readHandle();
        }

        public SchemaType.Ref[] readTypeRefArray() {
            int readShort = readShort();
            SchemaType.Ref[] refArr = new SchemaType.Ref[readShort];
            for (int i2 = 0; i2 < readShort; i2++) {
                refArr[i2] = readTypeRef();
            }
            return refArr;
        }

        /* JADX INFO: Can't fix incorrect switch cases order, some code will duplicate */
        public XmlValueRef readXmlValueObject() {
            SchemaType.Ref readTypeRef = readTypeRef();
            if (readTypeRef == null) {
                return null;
            }
            int readShort = readShort();
            if (readShort != 0) {
                if (readShort != 65535) {
                    switch (readShort) {
                        case 2:
                        case 3:
                        case 6:
                        case 11:
                        case 12:
                        case 13:
                        case 14:
                        case 15:
                        case 16:
                        case 17:
                        case 18:
                        case 19:
                        case 20:
                        case 21:
                            return new XmlValueRef(readTypeRef, readString());
                        case 4:
                        case 5:
                            return new XmlValueRef(readTypeRef, readByteArray());
                        case 7:
                        case 8:
                            return new XmlValueRef(readTypeRef, readQName());
                        case 9:
                        case 10:
                            return new XmlValueRef(readTypeRef, new Double(readDouble()));
                        default:
                            if (!$assertionsDisabled) {
                                throw new AssertionError();
                            }
                            break;
                    }
                } else {
                    int readShort2 = readShort();
                    ArrayList arrayList = new ArrayList();
                    writeShort(arrayList.size());
                    for (int i2 = 0; i2 < readShort2; i2++) {
                        arrayList.add(readXmlValueObject());
                    }
                    return new XmlValueRef(readTypeRef, arrayList);
                }
            }
            return new XmlValueRef(readTypeRef, null);
        }

        public void writeAnnotation(SchemaAnnotation schemaAnnotation) {
            if (schemaAnnotation == null) {
                writeInt(-1);
                return;
            }
            SchemaAnnotation.Attribute[] attributes = schemaAnnotation.getAttributes();
            writeInt(attributes.length);
            for (int i2 = 0; i2 < attributes.length; i2++) {
                QName name = attributes[i2].getName();
                String value = attributes[i2].getValue();
                String valueUri = attributes[i2].getValueUri();
                writeQName(name);
                writeString(value);
                writeString(valueUri);
            }
            XmlObject[] userInformation = schemaAnnotation.getUserInformation();
            writeInt(userInformation.length);
            XmlOptions saveAggressiveNamespaces = new XmlOptions().setSaveOuter().setSaveAggressiveNamespaces();
            for (XmlObject xmlObject : userInformation) {
                writeString(xmlObject.xmlText(saveAggressiveNamespaces));
            }
            XmlObject[] applicationInformation = schemaAnnotation.getApplicationInformation();
            writeInt(applicationInformation.length);
            for (XmlObject xmlObject2 : applicationInformation) {
                writeString(xmlObject2.xmlText(saveAggressiveNamespaces));
            }
        }

        public void writeAnnotations(SchemaAnnotation[] schemaAnnotationArr) {
            writeInt(schemaAnnotationArr.length);
            for (SchemaAnnotation schemaAnnotation : schemaAnnotationArr) {
                writeAnnotation(schemaAnnotation);
            }
        }

        public void writeAttributeData(SchemaLocalAttribute schemaLocalAttribute) {
            writeQName(schemaLocalAttribute.getName());
            writeType(schemaLocalAttribute.getType());
            writeShort(schemaLocalAttribute.getUse());
            writeString(schemaLocalAttribute.getDefaultText());
            writeXmlValueObject(schemaLocalAttribute.getDefaultValue());
            writeShort(schemaLocalAttribute.isFixed() ? 1 : 0);
            writeSOAPArrayType(((SchemaWSDLArrayType) schemaLocalAttribute).getWSDLArrayType());
            writeAnnotation(schemaLocalAttribute.getAnnotation());
        }

        public void writeAttributeGroupData(SchemaAttributeGroup schemaAttributeGroup) {
            SchemaAttributeGroupImpl schemaAttributeGroupImpl = (SchemaAttributeGroupImpl) schemaAttributeGroup;
            writeQName(schemaAttributeGroupImpl.getName());
            writeString(schemaAttributeGroupImpl.getTargetNamespace());
            writeShort(schemaAttributeGroupImpl.getChameleonNamespace() != null ? 1 : 0);
            writeString(schemaAttributeGroupImpl.getFormDefault());
            writeShort(schemaAttributeGroupImpl.isRedefinition() ? 1 : 0);
            writeString(schemaAttributeGroupImpl.getParseObject().xmlText(new XmlOptions().setSaveOuter()));
            writeAnnotation(schemaAttributeGroupImpl.getAnnotation());
            writeString(schemaAttributeGroupImpl.getSourceName());
        }

        public void writeAttributeTypeMap(SchemaType[] schemaTypeArr) {
            writeShort(schemaTypeArr.length);
            for (int i2 = 0; i2 < schemaTypeArr.length; i2++) {
                writeQName(schemaTypeArr[i2].getAttributeTypeAttributeName());
                writeHandle(schemaTypeArr[i2]);
            }
        }

        public void writeBigInteger(BigInteger bigInteger) {
            if (bigInteger == null) {
                writeShort(0);
            } else if (bigInteger.signum() == 0) {
                writeByteArray(SchemaTypeSystemImpl.SINGLE_ZERO_BYTE);
            } else {
                writeByteArray(bigInteger.toByteArray());
            }
        }

        public void writeByteArray(byte[] bArr) {
            try {
                writeShort(bArr.length);
                if (this._output != null) {
                    this._output.write(bArr);
                }
            } catch (IOException e2) {
                throw new SchemaTypeLoaderException(e2.getMessage(), SchemaTypeSystemImpl.this._name, this._handle, 9);
            }
        }

        public void writeClassnameMap(Map map) {
            writeShort(map.size());
            for (String str : map.keySet()) {
                writeString(str);
                writeHandle(((SchemaType.Ref) map.get(str)).get());
            }
        }

        public void writeDocumentTypeMap(SchemaType[] schemaTypeArr) {
            writeShort(schemaTypeArr.length);
            for (int i2 = 0; i2 < schemaTypeArr.length; i2++) {
                writeQName(schemaTypeArr[i2].getDocumentElementName());
                writeHandle(schemaTypeArr[i2]);
            }
        }

        public void writeDouble(double d2) {
            DataOutputStream dataOutputStream = this._output;
            if (dataOutputStream != null) {
                try {
                    dataOutputStream.writeDouble(d2);
                } catch (IOException e2) {
                    throw new SchemaTypeLoaderException(e2.getMessage(), SchemaTypeSystemImpl.this._name, this._handle, 9);
                }
            }
        }

        public void writeEnd() {
            try {
                if (this._output != null) {
                    this._output.flush();
                    this._output.close();
                }
                this._output = null;
                this._stringPool = null;
                this._handle = null;
            } catch (IOException e2) {
                throw new SchemaTypeLoaderException(e2.getMessage(), SchemaTypeSystemImpl.this._name, this._handle, 9);
            }
        }

        public void writeHandle(SchemaComponent schemaComponent) {
            if (schemaComponent == null || schemaComponent.getTypeSystem() == SchemaTypeSystemImpl.this.getTypeSystem()) {
                writeString(SchemaTypeSystemImpl.this._localHandles.handleForComponent(schemaComponent));
                return;
            }
            int componentType = schemaComponent.getComponentType();
            if (componentType == 0) {
                SchemaType schemaType = (SchemaType) schemaComponent;
                if (schemaType.isBuiltinType()) {
                    StringBuffer a = a.a("_BI_");
                    a.append(schemaType.getName().getLocalPart());
                    writeString(a.toString());
                } else if (schemaType.getName() != null) {
                    StringBuffer a2 = a.a("_XT_");
                    a2.append(QNameHelper.pretty(schemaType.getName()));
                    writeString(a2.toString());
                } else if (schemaType.isDocumentType()) {
                    StringBuffer a3 = a.a("_XO_");
                    a3.append(QNameHelper.pretty(schemaType.getDocumentElementName()));
                    writeString(a3.toString());
                } else {
                    StringBuffer a4 = a.a("_XY_");
                    a4.append(schemaType.toString());
                    writeString(a4.toString());
                }
            } else if (componentType == 1) {
                StringBuffer a5 = a.a("_XE_");
                a5.append(QNameHelper.pretty(schemaComponent.getName()));
                writeString(a5.toString());
            } else if (componentType == 3) {
                StringBuffer a6 = a.a("_XA_");
                a6.append(QNameHelper.pretty(schemaComponent.getName()));
                writeString(a6.toString());
            } else if (componentType == 4) {
                StringBuffer a7 = a.a("_XN_");
                a7.append(QNameHelper.pretty(schemaComponent.getName()));
                writeString(a7.toString());
            } else if (componentType == 5) {
                StringBuffer a8 = a.a("_XD_");
                a8.append(QNameHelper.pretty(schemaComponent.getName()));
                writeString(a8.toString());
            } else if (componentType == 6) {
                StringBuffer a9 = a.a("_XM_");
                a9.append(QNameHelper.pretty(schemaComponent.getName()));
                writeString(a9.toString());
            } else if (!$assertionsDisabled) {
                throw new AssertionError();
            } else {
                StringBuffer stringBuffer = new StringBuffer();
                stringBuffer.append("Cannot write handle for component ");
                stringBuffer.append(schemaComponent);
                throw new SchemaTypeLoaderException(stringBuffer.toString(), SchemaTypeSystemImpl.this._name, this._handle, 13);
            }
        }

        public void writeHandlePool(HandlePool handlePool) {
            writeShort(handlePool._componentsToHandles.size());
            for (SchemaComponent schemaComponent : handlePool._componentsToHandles.keySet()) {
                int fileTypeFromComponentType = fileTypeFromComponentType(schemaComponent.getComponentType());
                writeString((String) handlePool._componentsToHandles.get(schemaComponent));
                writeShort(fileTypeFromComponentType);
            }
        }

        public void writeIdConstraintData(SchemaIdentityConstraint schemaIdentityConstraint) {
            writeQName(schemaIdentityConstraint.getName());
            writeShort(schemaIdentityConstraint.getConstraintCategory());
            writeString(schemaIdentityConstraint.getSelector());
            writeAnnotation(schemaIdentityConstraint.getAnnotation());
            String[] fields = schemaIdentityConstraint.getFields();
            writeShort(fields.length);
            for (String str : fields) {
                writeString(str);
            }
            if (schemaIdentityConstraint.getConstraintCategory() == 2) {
                writeHandle(schemaIdentityConstraint.getReferencedKey());
            }
            Set<Map.Entry> entrySet = schemaIdentityConstraint.getNSMap().entrySet();
            writeShort(entrySet.size());
            for (Map.Entry entry : entrySet) {
                writeString((String) entry.getKey());
                writeString((String) entry.getValue());
            }
            writeString(schemaIdentityConstraint.getSourceName());
        }

        public void writeIndexData() {
            writeHandlePool(SchemaTypeSystemImpl.this._localHandles);
            writeQNameMap(SchemaTypeSystemImpl.this.globalElements());
            writeQNameMap(SchemaTypeSystemImpl.this.globalAttributes());
            writeQNameMap(SchemaTypeSystemImpl.this.modelGroups());
            writeQNameMap(SchemaTypeSystemImpl.this.attributeGroups());
            writeQNameMap(SchemaTypeSystemImpl.this.identityConstraints());
            writeQNameMap(SchemaTypeSystemImpl.this.globalTypes());
            writeDocumentTypeMap(SchemaTypeSystemImpl.this.documentTypes());
            writeAttributeTypeMap(SchemaTypeSystemImpl.this.attributeTypes());
            writeClassnameMap(SchemaTypeSystemImpl.this._typeRefsByClassname);
            writeNamespaces(SchemaTypeSystemImpl.this._namespaces);
            writeQNameMap(SchemaTypeSystemImpl.this.redefinedGlobalTypes());
            writeQNameMap(SchemaTypeSystemImpl.this.redefinedModelGroups());
            writeQNameMap(SchemaTypeSystemImpl.this.redefinedAttributeGroups());
            writeAnnotations(SchemaTypeSystemImpl.this.annotations());
        }

        public void writeInt(int i2) {
            DataOutputStream dataOutputStream = this._output;
            if (dataOutputStream != null) {
                try {
                    dataOutputStream.writeInt(i2);
                } catch (IOException e2) {
                    throw new SchemaTypeLoaderException(e2.getMessage(), SchemaTypeSystemImpl.this._name, this._handle, 9);
                }
            }
        }

        public void writeModelGroupData(SchemaModelGroup schemaModelGroup) {
            SchemaModelGroupImpl schemaModelGroupImpl = (SchemaModelGroupImpl) schemaModelGroup;
            writeQName(schemaModelGroupImpl.getName());
            writeString(schemaModelGroupImpl.getTargetNamespace());
            writeShort(schemaModelGroupImpl.getChameleonNamespace() != null ? 1 : 0);
            writeString(schemaModelGroupImpl.getElemFormDefault());
            writeString(schemaModelGroupImpl.getAttFormDefault());
            writeShort(schemaModelGroupImpl.isRedefinition() ? 1 : 0);
            writeString(schemaModelGroupImpl.getParseObject().xmlText(new XmlOptions().setSaveOuter()));
            writeAnnotation(schemaModelGroupImpl.getAnnotation());
            writeString(schemaModelGroupImpl.getSourceName());
        }

        public void writeNamespaces(Set set) {
            writeShort(set.size());
            Iterator it = set.iterator();
            while (it.hasNext()) {
                writeString((String) it.next());
            }
        }

        public void writeParticleArray(SchemaParticle[] schemaParticleArr) {
            writeShort(schemaParticleArr.length);
            for (SchemaParticle schemaParticle : schemaParticleArr) {
                writeParticleData(schemaParticle);
            }
        }

        public void writeParticleData(SchemaParticle schemaParticle) {
            writeShort(schemaParticle.getParticleType());
            short s = schemaParticle.isSkippable() ? (short) 1 : 0;
            if (schemaParticle.getParticleType() == 4) {
                SchemaLocalElement schemaLocalElement = (SchemaLocalElement) schemaParticle;
                if (schemaLocalElement.isFixed()) {
                    s = (short) (s | 4);
                }
                if (schemaLocalElement.isNillable()) {
                    s = (short) (s | 8);
                }
                if (schemaLocalElement.blockExtension()) {
                    s = (short) (s | 16);
                }
                if (schemaLocalElement.blockRestriction()) {
                    s = (short) (s | 32);
                }
                if (schemaLocalElement.blockSubstitution()) {
                    s = (short) (s | 64);
                }
                if (schemaLocalElement.isAbstract()) {
                    s = (short) (s | 128);
                }
                if (schemaLocalElement instanceof SchemaGlobalElement) {
                    SchemaGlobalElement schemaGlobalElement = (SchemaGlobalElement) schemaLocalElement;
                    if (schemaGlobalElement.finalExtension()) {
                        s = (short) (s | 256);
                    }
                    if (schemaGlobalElement.finalRestriction()) {
                        s = (short) (s | 512);
                    }
                }
            }
            writeShort(s);
            writeBigInteger(schemaParticle.getMinOccurs());
            writeBigInteger(schemaParticle.getMaxOccurs());
            writeQNameSet(schemaParticle.acceptedStartNames());
            int particleType = schemaParticle.getParticleType();
            if (particleType == 1 || particleType == 2 || particleType == 3) {
                writeParticleArray(schemaParticle.getParticleChildren());
            } else if (particleType == 4) {
                SchemaLocalElement schemaLocalElement2 = (SchemaLocalElement) schemaParticle;
                writeQName(schemaLocalElement2.getName());
                writeType(schemaLocalElement2.getType());
                writeString(schemaLocalElement2.getDefaultText());
                writeXmlValueObject(schemaLocalElement2.getDefaultValue());
                writeSOAPArrayType(((SchemaWSDLArrayType) schemaLocalElement2).getWSDLArrayType());
                writeAnnotation(schemaLocalElement2.getAnnotation());
                if (schemaLocalElement2 instanceof SchemaGlobalElement) {
                    SchemaGlobalElement schemaGlobalElement2 = (SchemaGlobalElement) schemaLocalElement2;
                    writeHandle(schemaGlobalElement2.substitutionGroup());
                    QName[] substitutionGroupMembers = schemaGlobalElement2.substitutionGroupMembers();
                    writeShort(substitutionGroupMembers.length);
                    for (QName qName : substitutionGroupMembers) {
                        writeQName(qName);
                    }
                }
                SchemaIdentityConstraint[] identityConstraints = schemaLocalElement2.getIdentityConstraints();
                writeShort(identityConstraints.length);
                for (SchemaIdentityConstraint schemaIdentityConstraint : identityConstraints) {
                    writeHandle(schemaIdentityConstraint);
                }
            } else if (particleType == 5) {
                writeQNameSet(schemaParticle.getWildcardSet());
                writeShort(schemaParticle.getWildcardProcess());
            } else {
                throw new SchemaTypeLoaderException("Unrecognized particle type ", SchemaTypeSystemImpl.this._name, this._handle, 11);
            }
        }

        public void writePropertyData(SchemaProperty schemaProperty) {
            writeQName(schemaProperty.getName());
            writeType(schemaProperty.getType());
            writeShort(schemaProperty.isAttribute() | (schemaProperty.extendsJavaSingleton() ? 2 : 0) | (schemaProperty.extendsJavaOption() ? 4 : 0) | (schemaProperty.extendsJavaArray() ? 8 : 0));
            writeType(schemaProperty.getContainerType());
            writeBigInteger(schemaProperty.getMinOccurs());
            writeBigInteger(schemaProperty.getMaxOccurs());
            writeShort(schemaProperty.hasNillable());
            writeShort(schemaProperty.hasDefault());
            writeShort(schemaProperty.hasFixed());
            writeString(schemaProperty.getDefaultText());
            writeString(schemaProperty.getJavaPropertyName());
            writeShort(schemaProperty.getJavaTypeCode());
            writeType(schemaProperty.javaBasedOnType());
            writeXmlValueObject(schemaProperty.getDefaultValue());
            if (!schemaProperty.isAttribute()) {
                QName[] acceptedNames = schemaProperty.acceptedNames();
                writeShort(acceptedNames.length);
                for (QName qName : acceptedNames) {
                    writeQName(qName);
                }
            }
        }

        public void writeQName(QName qName) {
            if (qName == null) {
                writeString(null);
                writeString(null);
                return;
            }
            writeString(qName.getNamespaceURI());
            writeString(qName.getLocalPart());
        }

        public void writeQNameMap(SchemaComponent[] schemaComponentArr) {
            writeShort(schemaComponentArr.length);
            for (int i2 = 0; i2 < schemaComponentArr.length; i2++) {
                writeQName(schemaComponentArr[i2].getName());
                writeHandle(schemaComponentArr[i2]);
            }
        }

        public void writeQNameSet(QNameSet qNameSet) {
            int i2 = qNameSet.excludedURIs() != null ? 1 : 0;
            writeShort(i2);
            Set<String> excludedURIs = i2 != 0 ? qNameSet.excludedURIs() : qNameSet.includedURIs();
            writeShort(excludedURIs.size());
            for (String str : excludedURIs) {
                writeString(str);
            }
            Set<QName> excludedQNamesInIncludedURIs = i2 != 0 ? qNameSet.excludedQNamesInIncludedURIs() : qNameSet.includedQNamesInExcludedURIs();
            writeShort(excludedQNamesInIncludedURIs.size());
            for (QName qName : excludedQNamesInIncludedURIs) {
                writeQName(qName);
            }
            Set<QName> includedQNamesInExcludedURIs = i2 != 0 ? qNameSet.includedQNamesInExcludedURIs() : qNameSet.excludedQNamesInIncludedURIs();
            writeShort(includedQNamesInExcludedURIs.size());
            for (QName qName2 : includedQNamesInExcludedURIs) {
                writeQName(qName2);
            }
        }

        public void writeRealHeader(String str, int i2) {
            String str2;
            if (str.indexOf(47) >= 0) {
                str2 = a.a(str, ".xsb");
            } else {
                StringBuffer stringBuffer = new StringBuffer();
                stringBuffer.append(SchemaTypeSystemImpl.this._basePackage);
                stringBuffer.append(str);
                stringBuffer.append(".xsb");
                str2 = stringBuffer.toString();
            }
            OutputStream saverStream = getSaverStream(str2);
            if (saverStream != null) {
                this._output = new DataOutputStream(saverStream);
                this._handle = str;
                writeInt(-629491010);
                writeShort(2);
                writeShort(24);
                writeShort(0);
                writeShort(i2);
                this._stringPool.writeTo(this._output);
                return;
            }
            throw new SchemaTypeLoaderException(a.a("Could not write compiled schema resource ", str2), SchemaTypeSystemImpl.this._name, str, 12);
        }

        public void writeSOAPArrayType(SOAPArrayType sOAPArrayType) {
            if (sOAPArrayType == null) {
                writeQName(null);
                writeString(null);
                return;
            }
            writeQName(sOAPArrayType.getQName());
            writeString(sOAPArrayType.soap11DimensionString());
        }

        public void writeShort(int i2) {
            if (i2 >= 65535 || i2 < -1) {
                StringBuffer stringBuffer = new StringBuffer();
                stringBuffer.append("Value ");
                stringBuffer.append(i2);
                stringBuffer.append(" out of range: must fit in a 16-bit unsigned short.");
                throw new SchemaTypeLoaderException(stringBuffer.toString(), SchemaTypeSystemImpl.this._name, this._handle, 10);
            }
            DataOutputStream dataOutputStream = this._output;
            if (dataOutputStream != null) {
                try {
                    dataOutputStream.writeShort(i2);
                } catch (IOException e2) {
                    throw new SchemaTypeLoaderException(e2.getMessage(), SchemaTypeSystemImpl.this._name, this._handle, 9);
                }
            }
        }

        public void writeString(String str) {
            writeShort(this._stringPool.codeForString(str));
        }

        public void writeType(SchemaType schemaType) {
            writeHandle(schemaType);
        }

        public void writeTypeArray(SchemaType[] schemaTypeArr) {
            writeShort(schemaTypeArr.length);
            for (SchemaType schemaType : schemaTypeArr) {
                writeHandle(schemaType);
            }
        }

        public void writeTypeData(SchemaType schemaType) {
            writeQName(schemaType.getName());
            writeType(schemaType.getOuterType());
            SchemaTypeImpl schemaTypeImpl = (SchemaTypeImpl) schemaType;
            writeShort(schemaTypeImpl.getBaseDepth());
            writeType(schemaType.getBaseType());
            writeShort(schemaType.getDerivationType());
            writeAnnotation(schemaType.getAnnotation());
            if (schemaType.getContainerField() == null) {
                writeShort(0);
            } else if (schemaType.getOuterType().isAttributeType() || schemaType.getOuterType().isDocumentType()) {
                writeShort(1);
                writeHandle((SchemaComponent) schemaType.getContainerField());
            } else if (schemaType.getContainerField().isAttribute()) {
                writeShort(2);
                writeShort(((SchemaTypeImpl) schemaType.getOuterType()).getIndexForLocalAttribute((SchemaLocalAttribute) schemaType.getContainerField()));
            } else {
                writeShort(3);
                writeShort(((SchemaTypeImpl) schemaType.getOuterType()).getIndexForLocalElement((SchemaLocalElement) schemaType.getContainerField()));
            }
            writeString(schemaType.getFullJavaName());
            writeString(schemaType.getFullJavaImplName());
            writeTypeArray(schemaType.getAnonymousTypes());
            writeShort(schemaType.getAnonymousUnionMemberOrdinal());
            int i2 = schemaType.isSimpleType() ? 1 : 0;
            if (schemaType.isDocumentType()) {
                i2 |= 2;
            }
            if (schemaType.isAttributeType()) {
                i2 |= 524288;
            }
            if (schemaType.ordered() != 0) {
                i2 |= 4;
            }
            if (schemaType.ordered() == 2) {
                i2 |= 1024;
            }
            if (schemaType.isBounded()) {
                i2 |= 8;
            }
            if (schemaType.isFinite()) {
                i2 |= 16;
            }
            if (schemaType.isNumeric()) {
                i2 |= 32;
            }
            if (schemaType.hasStringEnumValues()) {
                i2 |= 64;
            }
            if (schemaTypeImpl.isUnionOfLists()) {
                i2 |= 128;
            }
            if (schemaType.hasPatternFacet()) {
                i2 |= 256;
            }
            if (schemaType.isOrderSensitive()) {
                i2 |= 512;
            }
            if (schemaType.blockExtension()) {
                i2 |= 4096;
            }
            if (schemaType.blockRestriction()) {
                i2 |= 8192;
            }
            if (schemaType.finalExtension()) {
                i2 |= 16384;
            }
            if (schemaType.finalRestriction()) {
                i2 |= 16384;
            }
            if (schemaType.finalList()) {
                i2 |= 131072;
            }
            if (schemaType.finalUnion()) {
                i2 |= 65536;
            }
            if (schemaType.isAbstract()) {
                i2 |= 262144;
            }
            writeInt(i2);
            if (!schemaType.isSimpleType()) {
                writeShort(schemaType.getContentType());
                writeType(schemaType.getContentBasedOnType());
                SchemaAttributeModel attributeModel = schemaType.getAttributeModel();
                SchemaLocalAttribute[] attributes = attributeModel.getAttributes();
                writeShort(attributes.length);
                for (SchemaLocalAttribute schemaLocalAttribute : attributes) {
                    writeAttributeData(schemaLocalAttribute);
                }
                writeQNameSet(attributeModel.getWildcardSet());
                writeShort(attributeModel.getWildcardProcess());
                SchemaProperty[] attributeProperties = schemaType.getAttributeProperties();
                writeShort(attributeProperties.length);
                for (SchemaProperty schemaProperty : attributeProperties) {
                    writePropertyData(schemaProperty);
                }
                if (schemaType.getContentType() == 3 || schemaType.getContentType() == 4) {
                    writeShort(schemaType.hasAllContent() ? 1 : 0);
                    writeParticleArray(schemaType.getContentModel() != null ? new SchemaParticle[]{schemaType.getContentModel()} : new SchemaParticle[0]);
                    SchemaProperty[] elementProperties = schemaType.getElementProperties();
                    writeShort(elementProperties.length);
                    for (SchemaProperty schemaProperty2 : elementProperties) {
                        writePropertyData(schemaProperty2);
                    }
                }
            }
            if (schemaType.isSimpleType() || schemaType.getContentType() == 2) {
                writeShort(schemaType.getSimpleVariety());
                int i3 = 0;
                for (int i4 = 0; i4 <= 11; i4++) {
                    if (schemaType.getFacet(i4) != null) {
                        i3++;
                    }
                }
                writeShort(i3);
                for (int i5 = 0; i5 <= 11; i5++) {
                    XmlAnySimpleType facet = schemaType.getFacet(i5);
                    if (facet != null) {
                        writeShort(i5);
                        writeXmlValueObject(facet);
                        writeShort(schemaType.isFacetFixed(i5) ? 1 : 0);
                    }
                }
                writeShort(schemaType.getWhiteSpaceRule());
                RegularExpression[] patternExpressions = schemaTypeImpl.getPatternExpressions();
                writeShort(patternExpressions.length);
                for (RegularExpression regularExpression : patternExpressions) {
                    writeString(regularExpression.getPattern());
                }
                XmlAnySimpleType[] enumerationValues = schemaType.getEnumerationValues();
                if (enumerationValues == null) {
                    writeShort(0);
                } else {
                    writeShort(enumerationValues.length);
                    for (XmlAnySimpleType xmlAnySimpleType : enumerationValues) {
                        writeXmlValueObject(xmlAnySimpleType);
                    }
                }
                writeType(schemaType.getBaseEnumType());
                if (schemaType.hasStringEnumValues()) {
                    SchemaStringEnumEntry[] stringEnumEntries = schemaType.getStringEnumEntries();
                    writeShort(stringEnumEntries.length);
                    for (int i6 = 0; i6 < stringEnumEntries.length; i6++) {
                        writeString(stringEnumEntries[i6].getString());
                        writeShort(stringEnumEntries[i6].getIntValue());
                        writeString(stringEnumEntries[i6].getEnumName());
                    }
                }
                int simpleVariety = schemaType.getSimpleVariety();
                if (simpleVariety == 1) {
                    writeType(schemaType.getPrimitiveType());
                    writeInt(schemaType.getDecimalSize());
                } else if (simpleVariety == 2) {
                    writeTypeArray(schemaType.getUnionMemberTypes());
                } else if (simpleVariety == 3) {
                    writeType(schemaType.getListItemType());
                }
            }
            writeString(schemaType.getSourceName());
        }

        public void writeXmlValueObject(XmlAnySimpleType xmlAnySimpleType) {
            SchemaType schemaType = xmlAnySimpleType == null ? null : xmlAnySimpleType.schemaType();
            writeType(schemaType);
            if (schemaType != null) {
                SimpleValue simpleValue = (SimpleValue) xmlAnySimpleType;
                SchemaType instanceType = simpleValue.instanceType();
                if (instanceType == null) {
                    writeShort(0);
                } else if (instanceType.getSimpleVariety() == 3) {
                    writeShort(-1);
                    List<XmlAnySimpleType> xgetListValue = ((XmlObjectBase) xmlAnySimpleType).xgetListValue();
                    writeShort(xgetListValue.size());
                    for (XmlAnySimpleType xmlAnySimpleType2 : xgetListValue) {
                        writeXmlValueObject(xmlAnySimpleType2);
                    }
                } else {
                    int builtinTypeCode = instanceType.getPrimitiveType().getBuiltinTypeCode();
                    writeShort(builtinTypeCode);
                    switch (builtinTypeCode) {
                        case 2:
                        case 3:
                        case 6:
                        case 11:
                        case 12:
                        case 13:
                        case 14:
                        case 15:
                        case 16:
                        case 17:
                        case 18:
                        case 19:
                        case 20:
                        case 21:
                            writeString(xmlAnySimpleType.getStringValue());
                            return;
                        case 4:
                        case 5:
                            writeByteArray(simpleValue.getByteArrayValue());
                            return;
                        case 7:
                        case 8:
                            writeQName(simpleValue.getQNameValue());
                            return;
                        case 9:
                            writeDouble((double) simpleValue.getFloatValue());
                            return;
                        case 10:
                            writeDouble(simpleValue.getDoubleValue());
                            return;
                        default:
                            return;
                    }
                }
            }
        }

        public XsbReader(String str) {
            this._handle = str;
            this._stringPool = new StringPool(str, SchemaTypeSystemImpl.this._name);
        }
    }

    public SchemaTypeSystemImpl(ResourceLoader resourceLoader, String str, SchemaTypeLoader schemaTypeLoader) {
        this._name = str;
        this._basePackage = nameToPathString(str);
        this._linker = schemaTypeLoader;
        this._resourceLoader = resourceLoader;
        try {
            initFromHeader();
        } catch (RuntimeException e2) {
            XBeanDebug.logException(e2);
            throw e2;
        } catch (Error e3) {
            XBeanDebug.logException(e3);
            throw e3;
        }
    }

    public SchemaTypeSystemImpl(String str) {
        if (str == null) {
            byte[] bArr = new byte[16];
            nextBytes(bArr);
            StringBuffer stringBuffer = new StringBuffer();
            stringBuffer.append(Lucene3xNormsProducer.SEPARATE_NORMS_EXTENSION);
            stringBuffer.append(new String(HexBin.encode(bArr)));
            str = stringBuffer.toString();
        }
        StringBuffer a = a.a("schema");
        a.append(METADATA_PACKAGE_GEN);
        a.append(".system.");
        a.append(str);
        String stringBuffer2 = a.toString();
        this._name = stringBuffer2;
        this._basePackage = nameToPathString(stringBuffer2);
        this._classloader = null;
    }
}
