package org.apache.xmlbeans.impl.schema;

import b.b.a.a.a;
import java.math.BigInteger;
import java.util.ArrayList;
import java.util.Arrays;
import java.util.Collection;
import java.util.HashMap;
import java.util.HashSet;
import java.util.List;
import org.apache.poi.javax.xml.namespace.QName;
import org.apache.xerces.impl.xs.SchemaSymbols;
import org.apache.xmlbeans.SchemaAttributeModel;
import org.apache.xmlbeans.SchemaGlobalElement;
import org.apache.xmlbeans.SchemaIdentityConstraint;
import org.apache.xmlbeans.SchemaLocalAttribute;
import org.apache.xmlbeans.SchemaLocalElement;
import org.apache.xmlbeans.SchemaParticle;
import org.apache.xmlbeans.SchemaType;
import org.apache.xmlbeans.XmlAnySimpleType;
import org.apache.xmlbeans.XmlError;
import org.apache.xmlbeans.XmlErrorCodes;
import org.apache.xmlbeans.XmlID;
import org.apache.xmlbeans.XmlNOTATION;
import org.apache.xmlbeans.XmlObject;
import org.apache.xmlbeans.XmlOptions;
import org.apache.xmlbeans.XmlString;
import org.apache.xmlbeans.impl.common.QNameHelper;
import org.apache.xmlbeans.impl.common.XBeanDebug;
import org.apache.xmlbeans.impl.jam.xml.JamXmlElements;

public class StscChecker {
    public static final /* synthetic */ boolean $assertionsDisabled;
    public static /* synthetic */ Class class$org$apache$xmlbeans$impl$schema$StscChecker;

    static {
        Class cls = class$org$apache$xmlbeans$impl$schema$StscChecker;
        if (cls == null) {
            cls = class$("org.apache.xmlbeans.impl.schema.StscChecker");
            class$org$apache$xmlbeans$impl$schema$StscChecker = cls;
        }
        $assertionsDisabled = !cls.desiredAssertionStatus();
    }

    public static boolean blockSetOK(SchemaLocalElement schemaLocalElement, SchemaLocalElement schemaLocalElement2, Collection collection, XmlObject xmlObject) {
        if (schemaLocalElement.blockRestriction() && !schemaLocalElement2.blockRestriction()) {
            collection.add(XmlError.forObject(XmlErrorCodes.PARTICLE_RESTRICTION_NAME_AND_TYPE$DISALLOWED_SUBSTITUTIONS, new Object[]{printParticle((SchemaParticle) schemaLocalElement2), SchemaSymbols.ATTVAL_RESTRICTION, printParticle((SchemaParticle) schemaLocalElement)}, xmlObject));
            return false;
        } else if (schemaLocalElement.blockExtension() && !schemaLocalElement2.blockExtension()) {
            collection.add(XmlError.forObject(XmlErrorCodes.PARTICLE_RESTRICTION_NAME_AND_TYPE$DISALLOWED_SUBSTITUTIONS, new Object[]{printParticle((SchemaParticle) schemaLocalElement2), SchemaSymbols.ATTVAL_EXTENSION, printParticle((SchemaParticle) schemaLocalElement)}, xmlObject));
            return false;
        } else if (!schemaLocalElement.blockSubstitution() || schemaLocalElement2.blockSubstitution()) {
            return true;
        } else {
            collection.add(XmlError.forObject(XmlErrorCodes.PARTICLE_RESTRICTION_NAME_AND_TYPE$DISALLOWED_SUBSTITUTIONS, new Object[]{printParticle((SchemaParticle) schemaLocalElement2), SchemaSymbols.ATTVAL_SUBSTITUTION, printParticle((SchemaParticle) schemaLocalElement)}, xmlObject));
            return false;
        }
    }

    public static void checkAll() {
        StscState stscState = StscState.get();
        ArrayList arrayList = new ArrayList();
        arrayList.addAll(Arrays.asList(stscState.documentTypes()));
        arrayList.addAll(Arrays.asList(stscState.attributeTypes()));
        arrayList.addAll(Arrays.asList(stscState.redefinedGlobalTypes()));
        arrayList.addAll(Arrays.asList(stscState.globalTypes()));
        for (int i2 = 0; i2 < arrayList.size(); i2++) {
            SchemaType schemaType = (SchemaType) arrayList.get(i2);
            if (!stscState.noPvr() && !schemaType.isDocumentType()) {
                checkRestriction((SchemaTypeImpl) schemaType);
            }
            checkFields((SchemaTypeImpl) schemaType);
            arrayList.addAll(Arrays.asList(schemaType.getAnonymousTypes()));
        }
        checkSubstitutionGroups(stscState.globalElements());
    }

    public static boolean checkAllDerivationsForRestriction(SchemaType schemaType, SchemaType schemaType2, Collection collection, XmlObject xmlObject) {
        HashSet hashSet = schemaType.getSimpleVariety() == 2 ? new HashSet(Arrays.asList(schemaType.getUnionConstituentTypes())) : null;
        SchemaType schemaType3 = schemaType2;
        while (!schemaType.equals(schemaType3) && hashSet != null && !hashSet.contains(schemaType3)) {
            if (schemaType3.getDerivationType() == 1) {
                schemaType3 = schemaType3.getBaseType();
            } else {
                collection.add(XmlError.forObject(XmlErrorCodes.PARTICLE_RESTRICTION_NAME_AND_TYPE$TYPE_RESTRICTED, new Object[]{printType(schemaType2), printType(schemaType), printType(schemaType3)}, xmlObject));
                return false;
            }
        }
        return true;
    }

    public static void checkElementDefaults(SchemaParticle schemaParticle, XmlObject xmlObject, SchemaType schemaType) {
        SchemaParticle[] particleChildren;
        SchemaType[] unionConstituentTypes;
        if (schemaParticle != null) {
            int particleType = schemaParticle.getParticleType();
            if (particleType == 1 || particleType == 2 || particleType == 3) {
                for (SchemaParticle schemaParticle2 : schemaParticle.getParticleChildren()) {
                    checkElementDefaults(schemaParticle2, xmlObject, schemaType);
                }
            } else if (particleType == 4) {
                String defaultText = schemaParticle.getDefaultText();
                if (defaultText != null) {
                    String str = "fixed";
                    if (schemaParticle.getType().isSimpleType() || schemaParticle.getType().getContentType() == 2) {
                        try {
                            XmlAnySimpleType defaultValue = schemaParticle.getDefaultValue();
                            XmlOptions xmlOptions = new XmlOptions();
                            xmlOptions.put(XmlOptions.VALIDATE_TEXT_ONLY);
                            if (defaultValue.validate(xmlOptions)) {
                                SchemaPropertyImpl schemaPropertyImpl = (SchemaPropertyImpl) schemaType.getElementProperty(schemaParticle.getName());
                                if (!(schemaPropertyImpl == null || schemaPropertyImpl.getDefaultText() == null)) {
                                    schemaPropertyImpl.setDefaultValue(new XmlValueRef(defaultValue));
                                }
                            } else {
                                throw new Exception();
                            }
                        } catch (Exception unused) {
                            if (!schemaParticle.isFixed()) {
                                str = "default";
                            }
                            XmlObject selectAttribute = xmlObject.selectAttribute("", str);
                            StscState stscState = StscState.get();
                            Object[] objArr = {QNameHelper.pretty(schemaParticle.getName()), str, defaultText, QNameHelper.pretty(schemaParticle.getType().getName())};
                            if (selectAttribute == null) {
                                selectAttribute = xmlObject;
                            }
                            stscState.error(XmlErrorCodes.ELEM_PROPERTIES$CONSTRAINT_VALID, objArr, selectAttribute);
                        }
                    } else if (schemaParticle.getType().getContentType() == 4) {
                        if (!schemaParticle.getType().getContentModel().isSkippable()) {
                            if (!schemaParticle.isFixed()) {
                                str = "default";
                            }
                            XmlObject selectAttribute2 = xmlObject.selectAttribute("", str);
                            StscState stscState2 = StscState.get();
                            Object[] objArr2 = {QNameHelper.pretty(schemaParticle.getName()), str, defaultText};
                            if (selectAttribute2 == null) {
                                selectAttribute2 = xmlObject;
                            }
                            stscState2.error(XmlErrorCodes.ELEM_DEFAULT_VALID$MIXED_AND_EMPTIABLE, objArr2, selectAttribute2);
                        } else {
                            SchemaPropertyImpl schemaPropertyImpl2 = (SchemaPropertyImpl) schemaType.getElementProperty(schemaParticle.getName());
                            if (!(schemaPropertyImpl2 == null || schemaPropertyImpl2.getDefaultText() == null)) {
                                schemaPropertyImpl2.setDefaultValue(new XmlValueRef(XmlString.type.newValue(defaultText)));
                            }
                        }
                    } else if (schemaParticle.getType().getContentType() == 3) {
                        XmlObject selectAttribute3 = xmlObject.selectAttribute("", "default");
                        StscState stscState3 = StscState.get();
                        Object[] objArr3 = {QNameHelper.pretty(schemaParticle.getName()), defaultText, "element"};
                        if (selectAttribute3 == null) {
                            selectAttribute3 = xmlObject;
                        }
                        stscState3.error(XmlErrorCodes.ELEM_DEFAULT_VALID$SIMPLE_TYPE_OR_MIXED, objArr3, selectAttribute3);
                    } else if (schemaParticle.getType().getContentType() == 1) {
                        XmlObject selectAttribute4 = xmlObject.selectAttribute("", "default");
                        StscState stscState4 = StscState.get();
                        Object[] objArr4 = {QNameHelper.pretty(schemaParticle.getName()), defaultText, "empty"};
                        if (selectAttribute4 == null) {
                            selectAttribute4 = xmlObject;
                        }
                        stscState4.error(XmlErrorCodes.ELEM_DEFAULT_VALID$SIMPLE_TYPE_OR_MIXED, objArr4, selectAttribute4);
                    }
                }
                String str2 = null;
                if (BuiltinSchemaTypeSystem.ST_ID.isAssignableFrom(schemaParticle.getType())) {
                    str2 = BuiltinSchemaTypeSystem.ST_ID.getName().getLocalPart();
                } else if (BuiltinSchemaTypeSystem.ST_IDREF.isAssignableFrom(schemaParticle.getType())) {
                    str2 = BuiltinSchemaTypeSystem.ST_IDREF.getName().getLocalPart();
                } else if (BuiltinSchemaTypeSystem.ST_IDREFS.isAssignableFrom(schemaParticle.getType())) {
                    str2 = BuiltinSchemaTypeSystem.ST_IDREFS.getName().getLocalPart();
                } else if (BuiltinSchemaTypeSystem.ST_ENTITY.isAssignableFrom(schemaParticle.getType())) {
                    str2 = BuiltinSchemaTypeSystem.ST_ENTITY.getName().getLocalPart();
                } else if (BuiltinSchemaTypeSystem.ST_ENTITIES.isAssignableFrom(schemaParticle.getType())) {
                    str2 = BuiltinSchemaTypeSystem.ST_ENTITIES.getName().getLocalPart();
                } else if (BuiltinSchemaTypeSystem.ST_NOTATION.isAssignableFrom(schemaParticle.getType())) {
                    if (schemaParticle.getType().getBuiltinTypeCode() == 8) {
                        StscState stscState5 = StscState.get();
                        Object[] objArr5 = {QNameHelper.pretty(schemaParticle.getName())};
                        XmlObject xmlObject2 = ((SchemaLocalElementImpl) schemaParticle)._parseObject;
                        stscState5.recover(XmlErrorCodes.ELEM_NOTATION_TYPE_FORBIDDEN, objArr5, xmlObject2 == null ? xmlObject : xmlObject2.selectAttribute("", JamXmlElements.TYPE));
                    } else {
                        if (schemaParticle.getType().getSimpleVariety() == 2) {
                            for (SchemaType schemaType2 : schemaParticle.getType().getUnionConstituentTypes()) {
                                if (schemaType2.getBuiltinTypeCode() == 8) {
                                    StscState stscState6 = StscState.get();
                                    Object[] objArr6 = {QNameHelper.pretty(schemaParticle.getName())};
                                    XmlObject xmlObject3 = ((SchemaLocalElementImpl) schemaParticle)._parseObject;
                                    stscState6.recover(XmlErrorCodes.ELEM_NOTATION_TYPE_FORBIDDEN, objArr6, xmlObject3 == null ? xmlObject : xmlObject3.selectAttribute("", JamXmlElements.TYPE));
                                }
                            }
                        }
                        str2 = BuiltinSchemaTypeSystem.ST_NOTATION.getName().getLocalPart();
                    }
                    while (schemaType.getOuterType() != null) {
                        schemaType = schemaType.getOuterType();
                    }
                    if (!schemaType.isDocumentType() ? schemaType.getName().getNamespaceURI().length() > 0 : schemaType.getDocumentElementName().getNamespaceURI().length() > 0) {
                        StscState stscState7 = StscState.get();
                        Object[] objArr7 = {QNameHelper.pretty(schemaParticle.getName())};
                        XmlObject xmlObject4 = ((SchemaLocalElementImpl) schemaParticle)._parseObject;
                        if (xmlObject4 == null) {
                            xmlObject4 = xmlObject;
                        }
                        stscState7.warning(XmlErrorCodes.ELEM_COMPATIBILITY_TARGETNS, objArr7, xmlObject4);
                    }
                }
                if (str2 != null) {
                    StscState stscState8 = StscState.get();
                    Object[] objArr8 = {QNameHelper.pretty(schemaParticle.getName()), str2};
                    XmlObject xmlObject5 = ((SchemaLocalElementImpl) schemaParticle)._parseObject;
                    if (xmlObject5 != null) {
                        xmlObject = xmlObject5.selectAttribute("", JamXmlElements.TYPE);
                    }
                    stscState8.warning(XmlErrorCodes.ELEM_COMPATIBILITY_TYPE, objArr8, xmlObject);
                }
            }
        }
    }

    /* JADX WARNING: Code restructure failed: missing block: B:47:0x00fc, code lost:
        if (r1[r4].getName().getNamespaceURI().length() > 0) goto L_0x00fe;
     */
    /* JADX WARNING: Removed duplicated region for block: B:61:0x0134  */
    /* JADX WARNING: Removed duplicated region for block: B:97:0x01d1 A[SYNTHETIC] */
    public static void checkFields(SchemaTypeImpl schemaTypeImpl) {
        boolean z;
        SchemaType[] unionConstituentTypes;
        if (!schemaTypeImpl.isSimpleType()) {
            XmlObject parseObject = schemaTypeImpl.getParseObject();
            SchemaAttributeModel attributeModel = schemaTypeImpl.getAttributeModel();
            if (attributeModel != null) {
                SchemaLocalAttribute[] attributes = attributeModel.getAttributes();
                QName qName = null;
                int i2 = 0;
                while (i2 < attributes.length) {
                    XmlObject xmlObject = ((SchemaLocalAttributeImpl) attributes[i2])._parseObject;
                    if (XmlID.type.isAssignableFrom(attributes[i2].getType())) {
                        if (qName == null) {
                            qName = attributes[i2].getName();
                        } else {
                            StscState.get().error(XmlErrorCodes.ATTR_GROUP_PROPERTIES$TWO_IDS, new Object[]{QNameHelper.pretty(qName), attributes[i2].getName()}, xmlObject != null ? xmlObject : parseObject);
                        }
                        if (attributes[i2].getDefaultText() != null) {
                            StscState stscState = StscState.get();
                            if (xmlObject == null) {
                                xmlObject = parseObject;
                            }
                            stscState.error(XmlErrorCodes.ATTR_PROPERTIES$ID_FIXED_OR_DEFAULT, (Object[]) null, xmlObject);
                        }
                    } else if (!XmlNOTATION.type.isAssignableFrom(attributes[i2].getType())) {
                        String defaultText = attributes[i2].getDefaultText();
                        if (defaultText != null) {
                            try {
                                XmlAnySimpleType defaultValue = attributes[i2].getDefaultValue();
                                if (defaultValue.validate()) {
                                    SchemaPropertyImpl schemaPropertyImpl = (SchemaPropertyImpl) schemaTypeImpl.getAttributeProperty(attributes[i2].getName());
                                    if (!(schemaPropertyImpl == null || schemaPropertyImpl.getDefaultText() == null)) {
                                        schemaPropertyImpl.setDefaultValue(new XmlValueRef(defaultValue));
                                    }
                                } else {
                                    throw new Exception();
                                }
                            } catch (Exception unused) {
                                String str = attributes[i2].isFixed() ? "fixed" : "default";
                                if (xmlObject != null) {
                                    XmlObject selectAttribute = xmlObject.selectAttribute("", str);
                                    if (selectAttribute != null) {
                                        xmlObject = selectAttribute;
                                    }
                                } else {
                                    xmlObject = parseObject;
                                }
                                StscState.get().error(XmlErrorCodes.ATTR_PROPERTIES$CONSTRAINT_VALID, new Object[]{QNameHelper.pretty(attributes[i2].getName()), str, defaultText, QNameHelper.pretty(attributes[i2].getType().getName())}, xmlObject);
                            }
                        } else {
                            continue;
                        }
                    } else if (attributes[i2].getType().getBuiltinTypeCode() == 8) {
                        StscState stscState2 = StscState.get();
                        Object[] objArr = {QNameHelper.pretty(attributes[i2].getName())};
                        if (xmlObject == null) {
                            xmlObject = parseObject;
                        }
                        stscState2.recover(XmlErrorCodes.ATTR_NOTATION_TYPE_FORBIDDEN, objArr, xmlObject);
                    } else {
                        if (attributes[i2].getType().getSimpleVariety() == 2) {
                            for (SchemaType schemaType : attributes[i2].getType().getUnionConstituentTypes()) {
                                if (schemaType.getBuiltinTypeCode() == 8) {
                                    StscState.get().recover(XmlErrorCodes.ATTR_NOTATION_TYPE_FORBIDDEN, new Object[]{QNameHelper.pretty(attributes[i2].getName())}, xmlObject != null ? xmlObject : parseObject);
                                }
                            }
                        }
                        if (!schemaTypeImpl.isAttributeType()) {
                            SchemaType schemaType2 = schemaTypeImpl;
                            while (schemaType2.getOuterType() != null) {
                                schemaType2 = schemaType2.getOuterType();
                            }
                            if (!schemaType2.isDocumentType()) {
                                z = false;
                                if (z) {
                                    StscState stscState3 = StscState.get();
                                    Object[] objArr2 = {QNameHelper.pretty(attributes[i2].getName())};
                                    if (xmlObject == null) {
                                        xmlObject = parseObject;
                                    }
                                    stscState3.warning(XmlErrorCodes.ATTR_COMPATIBILITY_TARGETNS, objArr2, xmlObject);
                                }
                            } else {
                                z = false;
                                if (z) {
                                }
                            }
                        }
                        z = true;
                        if (z) {
                        }
                    }
                    i2++;
                }
            }
            checkElementDefaults(schemaTypeImpl.getContentModel(), parseObject, schemaTypeImpl);
        }
    }

    public static boolean checkFixed(SchemaLocalElement schemaLocalElement, SchemaLocalElement schemaLocalElement2, Collection collection, XmlObject xmlObject) {
        if (!schemaLocalElement.isFixed() || schemaLocalElement.getDefaultText().equals(schemaLocalElement2.getDefaultText())) {
            return true;
        }
        collection.add(XmlError.forObject(XmlErrorCodes.PARTICLE_RESTRICTION_NAME_AND_TYPE$FIXED, new Object[]{printParticle((SchemaParticle) schemaLocalElement2), schemaLocalElement2.getDefaultText(), printParticle((SchemaParticle) schemaLocalElement), schemaLocalElement.getDefaultText()}, xmlObject));
        return false;
    }

    public static boolean checkForIdentityConstraintExistence(SchemaIdentityConstraint[] schemaIdentityConstraintArr, SchemaIdentityConstraint schemaIdentityConstraint) {
        for (SchemaIdentityConstraint schemaIdentityConstraint2 : schemaIdentityConstraintArr) {
            if (schemaIdentityConstraint2.getName().equals(schemaIdentityConstraint.getName())) {
                return true;
            }
        }
        return false;
    }

    /* JADX WARNING: Removed duplicated region for block: B:10:0x002d  */
    /* JADX WARNING: Removed duplicated region for block: B:11:0x0046  */
    /* JADX WARNING: Removed duplicated region for block: B:14:0x004d  */
    public static boolean checkGroupOccurrenceOK(SchemaParticle schemaParticle, SchemaParticle schemaParticle2, Collection collection, XmlObject xmlObject) {
        BigInteger bigInteger;
        boolean z;
        BigInteger bigInteger2 = BigInteger.ZERO;
        int particleType = schemaParticle2.getParticleType();
        if (particleType != 1) {
            if (particleType == 2) {
                bigInteger2 = getEffectiveMinRangeChoice(schemaParticle2);
                bigInteger = getEffectiveMaxRangeChoice(schemaParticle2);
            } else if (particleType != 3) {
                bigInteger = bigInteger2;
            }
            if (bigInteger2.compareTo(schemaParticle.getMinOccurs()) >= 0) {
                collection.add(XmlError.forObject(XmlErrorCodes.OCCURRENCE_RANGE$MIN_GTE_MIN, new Object[]{printParticle(schemaParticle2), printParticle(schemaParticle)}, xmlObject));
                z = false;
            } else {
                z = true;
            }
            if (schemaParticle.getMaxOccurs() != null) {
                if (bigInteger == null) {
                    collection.add(XmlError.forObject(XmlErrorCodes.OCCURRENCE_RANGE$MAX_LTE_MAX, new Object[]{printParticle(schemaParticle2), printParticle(schemaParticle)}, xmlObject));
                    return false;
                } else if (bigInteger.compareTo(schemaParticle.getMaxOccurs()) > 0) {
                    collection.add(XmlError.forObject(XmlErrorCodes.OCCURRENCE_RANGE$MAX_LTE_MAX, new Object[]{printParticle(schemaParticle2), printParticle(schemaParticle)}, xmlObject));
                    return false;
                }
            }
            return z;
        }
        bigInteger2 = getEffectiveMinRangeAllSeq(schemaParticle2);
        bigInteger = getEffectiveMaxRangeAllSeq(schemaParticle2);
        if (bigInteger2.compareTo(schemaParticle.getMinOccurs()) >= 0) {
        }
        if (schemaParticle.getMaxOccurs() != null) {
        }
        return z;
    }

    public static boolean checkIdentityConstraints(SchemaLocalElement schemaLocalElement, SchemaLocalElement schemaLocalElement2, Collection collection, XmlObject xmlObject) {
        SchemaIdentityConstraint[] identityConstraints;
        SchemaIdentityConstraint[] identityConstraints2 = schemaLocalElement.getIdentityConstraints();
        for (SchemaIdentityConstraint schemaIdentityConstraint : schemaLocalElement2.getIdentityConstraints()) {
            if (checkForIdentityConstraintExistence(identityConstraints2, schemaIdentityConstraint)) {
                collection.add(XmlError.forObject(XmlErrorCodes.PARTICLE_RESTRICTION_NAME_AND_TYPE$IDENTITY_CONSTRAINTS, new Object[]{printParticle((SchemaParticle) schemaLocalElement2), printParticle((SchemaParticle) schemaLocalElement)}, xmlObject));
                return false;
            }
        }
        return true;
    }

    public static boolean checkRestriction(SchemaTypeImpl schemaTypeImpl) {
        if (schemaTypeImpl.getDerivationType() == 1 && !schemaTypeImpl.isSimpleType()) {
            StscState stscState = StscState.get();
            XmlObject parseObject = schemaTypeImpl.getParseObject();
            SchemaType baseType = schemaTypeImpl.getBaseType();
            if (baseType.isSimpleType()) {
                stscState.error(XmlErrorCodes.SCHEMA_COMPLEX_TYPE$COMPLEX_CONTENT, new Object[]{QNameHelper.pretty(baseType.getName())}, parseObject);
                return false;
            }
            int contentType = schemaTypeImpl.getContentType();
            if (contentType == 1) {
                int contentType2 = baseType.getContentType();
                if (contentType2 != 1) {
                    if (contentType2 != 3 && contentType2 != 4) {
                        stscState.error(XmlErrorCodes.COMPLEX_TYPE_RESTRICTION$EMPTY_AND_NOT_SIMPLE, (Object[]) null, parseObject);
                        return false;
                    } else if (baseType.getContentModel() != null && !baseType.getContentModel().isSkippable()) {
                        stscState.error(XmlErrorCodes.COMPLEX_TYPE_RESTRICTION$EMPTY_AND_ELEMENT_OR_MIXED_EMPTIABLE, (Object[]) null, parseObject);
                        return false;
                    }
                }
            } else if (contentType != 2) {
                if (contentType != 3) {
                    if (contentType == 4) {
                        if (baseType.getContentType() != 4) {
                            stscState.error(XmlErrorCodes.COMPLEX_TYPE_RESTRICTION$ELEMENT_OR_MIXED_AND_MIXED, (Object[]) null, parseObject);
                            return false;
                        }
                    }
                }
                if (baseType.getContentType() == 1) {
                    stscState.error(XmlErrorCodes.COMPLEX_TYPE_RESTRICTION$ELEMENT_OR_MIXED_AND_EMPTY, (Object[]) null, parseObject);
                    return false;
                } else if (baseType.getContentType() == 2) {
                    stscState.error(XmlErrorCodes.COMPLEX_TYPE_RESTRICTION$ELEMENT_OR_MIXED_AND_SIMPLE, (Object[]) null, parseObject);
                    return false;
                } else {
                    SchemaParticle contentModel = baseType.getContentModel();
                    SchemaParticle contentModel2 = schemaTypeImpl.getContentModel();
                    if (contentModel2 == null && schemaTypeImpl.getDerivationType() == 1) {
                        return true;
                    }
                    if (contentModel == null || contentModel2 == null) {
                        StringBuffer stringBuffer = new StringBuffer();
                        stringBuffer.append("Null models that weren't caught by EMPTY_CONTENT: ");
                        stringBuffer.append(baseType);
                        stringBuffer.append(" (");
                        stringBuffer.append(contentModel);
                        stringBuffer.append("), ");
                        stringBuffer.append(schemaTypeImpl);
                        stringBuffer.append(" (");
                        stringBuffer.append(contentModel2);
                        stringBuffer.append(")");
                        XBeanDebug.logStackTrace(stringBuffer.toString());
                        stscState.error(XmlErrorCodes.COMPLEX_TYPE_RESTRICTION$ELEMENT_OR_MIXED_AND_VALID, (Object[]) null, parseObject);
                        return false;
                    }
                    ArrayList arrayList = new ArrayList();
                    if (!isParticleValidRestriction(contentModel, contentModel2, arrayList, parseObject)) {
                        if (arrayList.size() == 0) {
                            stscState.error(XmlErrorCodes.COMPLEX_TYPE_RESTRICTION$ELEMENT_OR_MIXED_AND_VALID, (Object[]) null, parseObject);
                        } else {
                            stscState.getErrorListener().add(arrayList.get(arrayList.size() - 1));
                        }
                        return false;
                    }
                }
            } else {
                int contentType3 = baseType.getContentType();
                if (contentType3 == 2) {
                    SchemaType contentBasedOnType = schemaTypeImpl.getContentBasedOnType();
                    if (contentBasedOnType != baseType) {
                        while (baseType != null && !baseType.isSimpleType()) {
                            baseType = baseType.getContentBasedOnType();
                        }
                        if (baseType != null && !baseType.isAssignableFrom(contentBasedOnType)) {
                            stscState.error(XmlErrorCodes.COMPLEX_TYPE_RESTRICTION$SC_NOT_DERIVED, (Object[]) null, parseObject);
                            return false;
                        }
                    }
                } else if (contentType3 != 4) {
                    stscState.error(XmlErrorCodes.COMPLEX_TYPE_RESTRICTION$SC_AND_SIMPLE_TYPE_OR_MIXED, (Object[]) null, parseObject);
                    return false;
                } else if (baseType.getContentModel() != null && !baseType.getContentModel().isSkippable()) {
                    stscState.error(XmlErrorCodes.COMPLEX_TYPE_RESTRICTION$SC_AND_MIXED_EMPTIABLE, (Object[]) null, parseObject);
                    return false;
                }
            }
        }
        return true;
    }

    public static void checkSubstitutionGroups(SchemaGlobalElement[] schemaGlobalElementArr) {
        StscState stscState = StscState.get();
        for (SchemaGlobalElement schemaGlobalElement : schemaGlobalElementArr) {
            SchemaGlobalElement substitutionGroup = schemaGlobalElement.substitutionGroup();
            if (substitutionGroup != null) {
                SchemaType type = substitutionGroup.getType();
                SchemaType type2 = schemaGlobalElement.getType();
                XmlObject xmlObject = ((SchemaGlobalElementImpl) schemaGlobalElement)._parseObject;
                if (!type.isAssignableFrom(type2)) {
                    stscState.error(XmlErrorCodes.ELEM_PROPERTIES$SUBSTITUTION_VALID, new Object[]{QNameHelper.pretty(schemaGlobalElement.getName()), QNameHelper.pretty(substitutionGroup.getName())}, xmlObject);
                } else if (substitutionGroup.finalExtension() && substitutionGroup.finalRestriction()) {
                    stscState.error(XmlErrorCodes.ELEM_PROPERTIES$SUBSTITUTION_FINAL, new Object[]{QNameHelper.pretty(schemaGlobalElement.getName()), QNameHelper.pretty(substitutionGroup.getName()), SchemaSymbols.ATTVAL_POUNDALL}, xmlObject);
                } else if (!type.equals(type2)) {
                    if (substitutionGroup.finalExtension() && type2.getDerivationType() == 2) {
                        stscState.error(XmlErrorCodes.ELEM_PROPERTIES$SUBSTITUTION_FINAL, new Object[]{QNameHelper.pretty(schemaGlobalElement.getName()), QNameHelper.pretty(substitutionGroup.getName()), SchemaSymbols.ATTVAL_EXTENSION}, xmlObject);
                    } else if (substitutionGroup.finalRestriction() && type2.getDerivationType() == 1) {
                        stscState.error(XmlErrorCodes.ELEM_PROPERTIES$SUBSTITUTION_FINAL, new Object[]{QNameHelper.pretty(schemaGlobalElement.getName()), QNameHelper.pretty(substitutionGroup.getName()), SchemaSymbols.ATTVAL_RESTRICTION}, xmlObject);
                    }
                }
            }
        }
    }

    public static /* synthetic */ Class class$(String str) {
        try {
            return Class.forName(str);
        } catch (ClassNotFoundException e2) {
            throw a.a(e2);
        }
    }

    /* JADX WARNING: Code restructure failed: missing block: B:22:0x0047, code lost:
        if (r0.compareTo(r2) > 0) goto L_0x0056;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:26:0x0054, code lost:
        if (r0.compareTo(r2) > 0) goto L_0x0056;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:27:0x0056, code lost:
        r2 = r0;
     */
    /* JADX WARNING: Removed duplicated region for block: B:29:0x005a A[LOOP:0: B:1:0x000b->B:29:0x005a, LOOP_END] */
    /* JADX WARNING: Removed duplicated region for block: B:37:0x005d A[EDGE_INSN: B:37:0x005d->B:30:0x005d ?: BREAK  , SYNTHETIC] */
    public static BigInteger getEffectiveMaxRangeAllSeq(SchemaParticle schemaParticle) {
        BigInteger bigInteger = BigInteger.ZERO;
        SchemaParticle[] particleChildren = schemaParticle.getParticleChildren();
        BigInteger bigInteger2 = bigInteger;
        BigInteger bigInteger3 = bigInteger2;
        boolean z = false;
        for (SchemaParticle schemaParticle2 : particleChildren) {
            int particleType = schemaParticle2.getParticleType();
            if (particleType != 1) {
                if (particleType == 2) {
                    bigInteger = getEffectiveMaxRangeChoice(schemaParticle2);
                    if (bigInteger != null) {
                    }
                } else if (particleType != 3) {
                    if (particleType == 4 || particleType == 5) {
                        if (schemaParticle2.getMaxOccurs() == null) {
                            bigInteger = null;
                        } else if (schemaParticle2.getIntMaxOccurs() > 0) {
                            bigInteger3 = bigInteger3.add(schemaParticle2.getMaxOccurs());
                            z = true;
                        }
                    }
                }
                if (bigInteger != null) {
                    break;
                }
            }
            bigInteger = getEffectiveMaxRangeAllSeq(schemaParticle2);
            if (bigInteger != null) {
            }
            if (bigInteger != null) {
            }
        }
        if (bigInteger == null) {
            return bigInteger;
        }
        if (!z || schemaParticle.getMaxOccurs() != null) {
            return schemaParticle.getMaxOccurs().multiply(bigInteger3.add(bigInteger2));
        }
        return null;
    }

    /* JADX WARNING: Code restructure failed: missing block: B:25:0x004d, code lost:
        if (r0.compareTo(r2) > 0) goto L_0x005c;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:29:0x005a, code lost:
        if (r0.compareTo(r2) > 0) goto L_0x005c;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:30:0x005c, code lost:
        r2 = r0;
     */
    /* JADX WARNING: Removed duplicated region for block: B:32:0x0060 A[LOOP:0: B:1:0x000b->B:32:0x0060, LOOP_END] */
    /* JADX WARNING: Removed duplicated region for block: B:40:0x0063 A[EDGE_INSN: B:40:0x0063->B:33:0x0063 ?: BREAK  , SYNTHETIC] */
    public static BigInteger getEffectiveMaxRangeChoice(SchemaParticle schemaParticle) {
        BigInteger bigInteger = BigInteger.ZERO;
        SchemaParticle[] particleChildren = schemaParticle.getParticleChildren();
        BigInteger bigInteger2 = bigInteger;
        BigInteger bigInteger3 = bigInteger2;
        boolean z = false;
        for (SchemaParticle schemaParticle2 : particleChildren) {
            int particleType = schemaParticle2.getParticleType();
            if (particleType != 1) {
                if (particleType == 2) {
                    bigInteger = getEffectiveMaxRangeChoice(schemaParticle2);
                    if (bigInteger != null) {
                    }
                } else if (particleType != 3) {
                    if (particleType == 4 || particleType == 5) {
                        if (schemaParticle2.getMaxOccurs() == null) {
                            bigInteger = null;
                        } else if (schemaParticle2.getIntMaxOccurs() > 0) {
                            if (schemaParticle2.getMaxOccurs().compareTo(bigInteger3) > 0) {
                                bigInteger3 = schemaParticle2.getMaxOccurs();
                            }
                            z = true;
                        }
                    }
                }
                if (bigInteger != null) {
                    break;
                }
            }
            bigInteger = getEffectiveMaxRangeAllSeq(schemaParticle2);
            if (bigInteger != null) {
            }
            if (bigInteger != null) {
            }
        }
        if (bigInteger == null) {
            return bigInteger;
        }
        if (!z || schemaParticle.getMaxOccurs() != null) {
            return schemaParticle.getMaxOccurs().multiply(bigInteger3.add(bigInteger2));
        }
        return null;
    }

    public static BigInteger getEffectiveMinRangeAllSeq(SchemaParticle schemaParticle) {
        BigInteger bigInteger = BigInteger.ZERO;
        SchemaParticle[] particleChildren = schemaParticle.getParticleChildren();
        BigInteger bigInteger2 = BigInteger.ZERO;
        for (SchemaParticle schemaParticle2 : particleChildren) {
            int particleType = schemaParticle2.getParticleType();
            if (particleType != 1) {
                if (particleType == 2) {
                    bigInteger2 = bigInteger2.add(getEffectiveMinRangeChoice(schemaParticle2));
                } else if (particleType != 3) {
                    if (particleType == 4 || particleType == 5) {
                        bigInteger2 = bigInteger2.add(schemaParticle2.getMinOccurs());
                    }
                }
            }
            bigInteger2 = bigInteger2.add(getEffectiveMinRangeAllSeq(schemaParticle2));
        }
        return schemaParticle.getMinOccurs().multiply(bigInteger2);
    }

    public static BigInteger getEffectiveMinRangeChoice(SchemaParticle schemaParticle) {
        BigInteger bigInteger;
        SchemaParticle[] particleChildren = schemaParticle.getParticleChildren();
        if (particleChildren.length == 0) {
            return BigInteger.ZERO;
        }
        BigInteger bigInteger2 = null;
        for (SchemaParticle schemaParticle2 : particleChildren) {
            int particleType = schemaParticle2.getParticleType();
            if (particleType != 1) {
                if (particleType == 2) {
                    bigInteger = getEffectiveMinRangeChoice(schemaParticle2);
                    if (bigInteger2 != null && bigInteger2.compareTo(bigInteger) <= 0) {
                    }
                    bigInteger2 = bigInteger;
                } else if (particleType != 3) {
                    if ((particleType == 4 || particleType == 5) && (bigInteger2 == null || bigInteger2.compareTo(schemaParticle2.getMinOccurs()) > 0)) {
                        bigInteger2 = schemaParticle2.getMinOccurs();
                    }
                }
            }
            bigInteger = getEffectiveMinRangeAllSeq(schemaParticle2);
            if (bigInteger2 != null && bigInteger2.compareTo(bigInteger) <= 0) {
            }
            bigInteger2 = bigInteger;
        }
        if (bigInteger2 == null) {
            bigInteger2 = BigInteger.ZERO;
        }
        return schemaParticle.getMinOccurs().multiply(bigInteger2);
    }

    public static boolean isParticleValidRestriction(SchemaParticle schemaParticle, SchemaParticle schemaParticle2, Collection collection, XmlObject xmlObject) {
        if (schemaParticle.equals(schemaParticle2)) {
            return true;
        }
        int particleType = schemaParticle.getParticleType();
        if (particleType == 1) {
            int particleType2 = schemaParticle2.getParticleType();
            if (particleType2 == 1) {
                return recurse(schemaParticle, schemaParticle2, collection, xmlObject);
            }
            if (particleType2 != 2) {
                if (particleType2 == 3) {
                    return recurseUnordered(schemaParticle, schemaParticle2, collection, xmlObject);
                }
                if (particleType2 == 4) {
                    return recurseAsIfGroup(schemaParticle, schemaParticle2, collection, xmlObject);
                }
                if (particleType2 != 5) {
                    if ($assertionsDisabled) {
                        return false;
                    }
                    throw new AssertionError(XBeanDebug.logStackTrace("Unknown schema type for Derived Type"));
                }
            }
            collection.add(XmlError.forObject(XmlErrorCodes.PARTICLE_RESTRICTION$INVALID_RESTRICTION, new Object[]{printParticle(schemaParticle2), printParticle(schemaParticle)}, xmlObject));
            return false;
        } else if (particleType == 2) {
            int particleType3 = schemaParticle2.getParticleType();
            if (particleType3 != 1) {
                if (particleType3 == 2) {
                    return recurseLax(schemaParticle, schemaParticle2, collection, xmlObject);
                }
                if (particleType3 == 3) {
                    return mapAndSum(schemaParticle, schemaParticle2, collection, xmlObject);
                }
                if (particleType3 == 4) {
                    return recurseAsIfGroup(schemaParticle, schemaParticle2, collection, xmlObject);
                }
                if (particleType3 != 5) {
                    if ($assertionsDisabled) {
                        return false;
                    }
                    throw new AssertionError(XBeanDebug.logStackTrace("Unknown schema type for Derived Type"));
                }
            }
            collection.add(XmlError.forObject(XmlErrorCodes.PARTICLE_RESTRICTION$INVALID_RESTRICTION, new Object[]{printParticle(schemaParticle2), printParticle(schemaParticle)}, xmlObject));
            return false;
        } else if (particleType == 3) {
            int particleType4 = schemaParticle2.getParticleType();
            if (!(particleType4 == 1 || particleType4 == 2)) {
                if (particleType4 == 3) {
                    return recurse(schemaParticle, schemaParticle2, collection, xmlObject);
                }
                if (particleType4 == 4) {
                    return recurseAsIfGroup(schemaParticle, schemaParticle2, collection, xmlObject);
                }
                if (particleType4 != 5) {
                    if ($assertionsDisabled) {
                        return false;
                    }
                    throw new AssertionError(XBeanDebug.logStackTrace("Unknown schema type for Derived Type"));
                }
            }
            collection.add(XmlError.forObject(XmlErrorCodes.PARTICLE_RESTRICTION$INVALID_RESTRICTION, new Object[]{printParticle(schemaParticle2), printParticle(schemaParticle)}, xmlObject));
            return false;
        } else if (particleType == 4) {
            int particleType5 = schemaParticle2.getParticleType();
            if (!(particleType5 == 1 || particleType5 == 2 || particleType5 == 3)) {
                if (particleType5 == 4) {
                    return nameAndTypeOK((SchemaLocalElement) schemaParticle, (SchemaLocalElement) schemaParticle2, collection, xmlObject);
                }
                if (particleType5 != 5) {
                    if ($assertionsDisabled) {
                        return false;
                    }
                    throw new AssertionError(XBeanDebug.logStackTrace("Unknown schema type for Derived Type"));
                }
            }
            collection.add(XmlError.forObject(XmlErrorCodes.PARTICLE_RESTRICTION$INVALID_RESTRICTION, new Object[]{printParticle(schemaParticle2), printParticle(schemaParticle)}, xmlObject));
            return false;
        } else if (particleType == 5) {
            int particleType6 = schemaParticle2.getParticleType();
            if (particleType6 == 1) {
                return nsRecurseCheckCardinality(schemaParticle, schemaParticle2, collection, xmlObject);
            }
            if (particleType6 == 2) {
                return nsRecurseCheckCardinality(schemaParticle, schemaParticle2, collection, xmlObject);
            }
            if (particleType6 == 3) {
                return nsRecurseCheckCardinality(schemaParticle, schemaParticle2, collection, xmlObject);
            }
            if (particleType6 == 4) {
                return nsCompat(schemaParticle, (SchemaLocalElement) schemaParticle2, collection, xmlObject);
            }
            if (particleType6 == 5) {
                return nsSubset(schemaParticle, schemaParticle2, collection, xmlObject);
            }
            if ($assertionsDisabled) {
                return false;
            }
            throw new AssertionError(XBeanDebug.logStackTrace("Unknown schema type for Derived Type"));
        } else if ($assertionsDisabled) {
            return false;
        } else {
            throw new AssertionError(XBeanDebug.logStackTrace("Unknown schema type for Base Type"));
        }
    }

    public static boolean mapAndSum(SchemaParticle schemaParticle, SchemaParticle schemaParticle2, Collection collection, XmlObject xmlObject) {
        BigInteger bigInteger;
        String str;
        boolean z;
        if (!$assertionsDisabled && schemaParticle.getParticleType() != 2) {
            throw new AssertionError();
        } else if ($assertionsDisabled || schemaParticle2.getParticleType() == 3) {
            SchemaParticle[] particleChildren = schemaParticle2.getParticleChildren();
            SchemaParticle[] particleChildren2 = schemaParticle.getParticleChildren();
            for (SchemaParticle schemaParticle3 : particleChildren) {
                int i2 = 0;
                while (true) {
                    if (i2 >= particleChildren2.length) {
                        z = false;
                        break;
                    } else if (isParticleValidRestriction(particleChildren2[i2], schemaParticle3, collection, xmlObject)) {
                        z = true;
                        break;
                    } else {
                        i2++;
                    }
                }
                if (!z) {
                    collection.add(XmlError.forObject(XmlErrorCodes.PARTICLE_DERIVATION_MAP_AND_SUM$MAP, new Object[]{printParticle(schemaParticle3)}, xmlObject));
                    return false;
                }
            }
            BigInteger multiply = schemaParticle2.getMinOccurs().multiply(BigInteger.valueOf((long) schemaParticle2.getParticleChildren().length));
            if (schemaParticle2.getMaxOccurs() == null) {
                bigInteger = null;
            } else {
                bigInteger = schemaParticle2.getMaxOccurs().multiply(BigInteger.valueOf((long) schemaParticle2.getParticleChildren().length));
            }
            if (multiply.compareTo(schemaParticle.getMinOccurs()) < 0) {
                collection.add(XmlError.forObject(XmlErrorCodes.PARTICLE_DERIVATION_MAP_AND_SUM$SUM_MIN_OCCURS_GTE_MIN_OCCURS, new Object[]{multiply.toString(), schemaParticle.getMinOccurs().toString()}, xmlObject));
                return false;
            } else if (schemaParticle.getMaxOccurs() == null || (bigInteger != null && bigInteger.compareTo(schemaParticle.getMaxOccurs()) <= 0)) {
                return true;
            } else {
                Object[] objArr = new Object[2];
                if (bigInteger == null) {
                    str = SchemaSymbols.ATTVAL_UNBOUNDED;
                } else {
                    str = bigInteger.toString();
                }
                objArr[0] = str;
                objArr[1] = schemaParticle.getMaxOccurs().toString();
                collection.add(XmlError.forObject(XmlErrorCodes.PARTICLE_DERIVATION_MAP_AND_SUM$SUM_MAX_OCCURS_LTE_MAX_OCCURS, objArr, xmlObject));
                return false;
            }
        } else {
            throw new AssertionError();
        }
    }

    public static boolean nameAndTypeOK(SchemaLocalElement schemaLocalElement, SchemaLocalElement schemaLocalElement2, Collection collection, XmlObject xmlObject) {
        SchemaParticle schemaParticle = (SchemaParticle) schemaLocalElement;
        if (!schemaParticle.canStartWithElement(schemaLocalElement2.getName())) {
            collection.add(XmlError.forObject(XmlErrorCodes.PARTICLE_RESTRICTION_NAME_AND_TYPE$NAME, new Object[]{printParticle((SchemaParticle) schemaLocalElement2), printParticle(schemaParticle)}, xmlObject));
            return false;
        } else if (schemaLocalElement.isNillable() || !schemaLocalElement2.isNillable()) {
            return occurrenceRangeOK((SchemaParticle) schemaLocalElement, (SchemaParticle) schemaLocalElement2, collection, xmlObject) && checkFixed(schemaLocalElement, schemaLocalElement2, collection, xmlObject) && checkIdentityConstraints(schemaLocalElement, schemaLocalElement2, collection, xmlObject) && typeDerivationOK(schemaLocalElement.getType(), schemaLocalElement2.getType(), collection, xmlObject) && blockSetOK(schemaLocalElement, schemaLocalElement2, collection, xmlObject);
        } else {
            collection.add(XmlError.forObject(XmlErrorCodes.PARTICLE_RESTRICTION_NAME_AND_TYPE$NILLABLE, new Object[]{printParticle((SchemaParticle) schemaLocalElement2), printParticle((SchemaParticle) schemaLocalElement)}, xmlObject));
            return false;
        }
    }

    public static boolean nsCompat(SchemaParticle schemaParticle, SchemaLocalElement schemaLocalElement, Collection collection, XmlObject xmlObject) {
        if ($assertionsDisabled || schemaParticle.getParticleType() == 5) {
            if (!schemaParticle.getWildcardSet().contains(schemaLocalElement.getName())) {
                collection.add(XmlError.forObject(XmlErrorCodes.PARTICLE_DERIVATION_NS_COMPAT$WILDCARD_VALID, new Object[]{printParticle((SchemaParticle) schemaLocalElement), printParticle(schemaParticle)}, xmlObject));
            } else if (occurrenceRangeOK(schemaParticle, (SchemaParticle) schemaLocalElement, collection, xmlObject)) {
                return true;
            }
            return false;
        }
        throw new AssertionError();
    }

    public static boolean nsRecurseCheckCardinality(SchemaParticle schemaParticle, SchemaParticle schemaParticle2, Collection collection, XmlObject xmlObject) {
        if (!$assertionsDisabled && schemaParticle.getParticleType() != 5) {
            throw new AssertionError();
        } else if ($assertionsDisabled || schemaParticle2.getParticleType() == 1 || schemaParticle2.getParticleType() == 2 || schemaParticle2.getParticleType() == 3) {
            SchemaParticleImpl schemaParticleImpl = new SchemaParticleImpl();
            schemaParticleImpl.setParticleType(schemaParticle.getParticleType());
            schemaParticleImpl.setWildcardProcess(schemaParticle.getWildcardProcess());
            schemaParticleImpl.setWildcardSet(schemaParticle.getWildcardSet());
            schemaParticleImpl.setMinOccurs(BigInteger.ZERO);
            schemaParticleImpl.setMaxOccurs(null);
            schemaParticleImpl.setTransitionRules(schemaParticle.getWildcardSet(), true);
            schemaParticleImpl.setTransitionNotes(schemaParticle.getWildcardSet(), true);
            SchemaParticle[] particleChildren = schemaParticle2.getParticleChildren();
            boolean z = true;
            for (SchemaParticle schemaParticle3 : particleChildren) {
                int particleType = schemaParticle3.getParticleType();
                if (particleType == 1 || particleType == 2 || particleType == 3) {
                    z = nsRecurseCheckCardinality(schemaParticleImpl, schemaParticle3, collection, xmlObject);
                } else if (particleType == 4) {
                    z = nsCompat(schemaParticleImpl, (SchemaLocalElement) schemaParticle3, collection, xmlObject);
                } else if (particleType == 5) {
                    z = nsSubset(schemaParticleImpl, schemaParticle3, collection, xmlObject);
                }
                if (!z) {
                    break;
                }
            }
            return z ? checkGroupOccurrenceOK(schemaParticle, schemaParticle2, collection, xmlObject) : z;
        } else {
            throw new AssertionError();
        }
    }

    public static boolean nsSubset(SchemaParticle schemaParticle, SchemaParticle schemaParticle2, Collection collection, XmlObject xmlObject) {
        if (!$assertionsDisabled && schemaParticle.getParticleType() != 5) {
            throw new AssertionError();
        } else if ($assertionsDisabled || schemaParticle2.getParticleType() == 5) {
            if (occurrenceRangeOK(schemaParticle, schemaParticle2, collection, xmlObject)) {
                if (schemaParticle.getWildcardSet().inverse().isDisjoint(schemaParticle2.getWildcardSet())) {
                    return true;
                }
                collection.add(XmlError.forObject(XmlErrorCodes.PARTICLE_DERIVATION_NS_SUBST$WILDCARD_SUBSET, new Object[]{printParticle(schemaParticle2), printParticle(schemaParticle)}, xmlObject));
            }
            return false;
        } else {
            throw new AssertionError();
        }
    }

    public static boolean occurrenceRangeOK(SchemaParticle schemaParticle, SchemaParticle schemaParticle2, Collection collection, XmlObject xmlObject) {
        if (schemaParticle2.getMinOccurs().compareTo(schemaParticle.getMinOccurs()) < 0) {
            collection.add(XmlError.forObject(XmlErrorCodes.OCCURRENCE_RANGE$MIN_GTE_MIN, new Object[]{printParticle(schemaParticle2), schemaParticle2.getMinOccurs().toString(), printParticle(schemaParticle), schemaParticle.getMinOccurs().toString()}, xmlObject));
        } else if (schemaParticle.getMaxOccurs() == null) {
            return true;
        } else {
            if (schemaParticle2.getMaxOccurs() != null && schemaParticle.getMaxOccurs() != null && schemaParticle2.getMaxOccurs().compareTo(schemaParticle.getMaxOccurs()) <= 0) {
                return true;
            }
            collection.add(XmlError.forObject(XmlErrorCodes.OCCURRENCE_RANGE$MAX_LTE_MAX, new Object[]{printParticle(schemaParticle2), printMaxOccurs(schemaParticle2.getMaxOccurs()), printParticle(schemaParticle), printMaxOccurs(schemaParticle.getMaxOccurs())}, xmlObject));
        }
        return false;
    }

    public static String printMaxOccurs(BigInteger bigInteger) {
        return bigInteger == null ? SchemaSymbols.ATTVAL_UNBOUNDED : bigInteger.toString();
    }

    public static String printParticle(SchemaParticle schemaParticle) {
        int particleType = schemaParticle.getParticleType();
        if (particleType == 1) {
            return "<all>";
        }
        if (particleType == 2) {
            return "<choice>";
        }
        if (particleType == 3) {
            return "<sequence>";
        }
        if (particleType != 4) {
            return particleType != 5 ? "??" : "<any>";
        }
        StringBuffer a = a.a("<element name=\"");
        a.append(QNameHelper.pretty(schemaParticle.getName()));
        a.append("\">");
        return a.toString();
    }

    public static String printParticles(List list) {
        return printParticles((SchemaParticle[]) list.toArray(new SchemaParticle[list.size()]));
    }

    public static String printType(SchemaType schemaType) {
        if (schemaType.getName() != null) {
            return QNameHelper.pretty(schemaType.getName());
        }
        return schemaType.toString();
    }

    public static boolean recurse(SchemaParticle schemaParticle, SchemaParticle schemaParticle2, Collection collection, XmlObject xmlObject) {
        boolean z;
        if (!occurrenceRangeOK(schemaParticle, schemaParticle2, collection, xmlObject)) {
            return false;
        }
        SchemaParticle[] particleChildren = schemaParticle2.getParticleChildren();
        SchemaParticle[] particleChildren2 = schemaParticle.getParticleChildren();
        int i2 = 0;
        int i3 = 0;
        while (true) {
            if (i2 >= particleChildren.length || i3 >= particleChildren2.length) {
                z = true;
            } else {
                SchemaParticle schemaParticle3 = particleChildren[i2];
                SchemaParticle schemaParticle4 = particleChildren2[i3];
                if (!isParticleValidRestriction(schemaParticle4, schemaParticle3, collection, xmlObject)) {
                    if (!schemaParticle4.isSkippable()) {
                        collection.add(XmlError.forObject(XmlErrorCodes.PARTICLE_DERIVATION_RECURSE$MAP_VALID, new Object[]{printParticle(schemaParticle3), printParticle(schemaParticle2), printParticle(schemaParticle4), printParticle(schemaParticle)}, xmlObject));
                        z = false;
                        break;
                    }
                } else {
                    i2++;
                }
                i3++;
            }
        }
        if (i2 < particleChildren.length) {
            collection.add(XmlError.forObject(XmlErrorCodes.PARTICLE_DERIVATION_RECURSE$MAP, new Object[]{printParticle(schemaParticle2), printParticle(schemaParticle), printParticles(particleChildren, i2)}, xmlObject));
            return false;
        }
        if (i3 < particleChildren2.length) {
            ArrayList arrayList = new ArrayList(particleChildren2.length);
            while (i3 < particleChildren2.length) {
                if (!particleChildren2[i3].isSkippable()) {
                    arrayList.add(particleChildren2[i3]);
                }
                i3++;
            }
            if (arrayList.size() > 0) {
                collection.add(XmlError.forObject(XmlErrorCodes.PARTICLE_DERIVATION_RECURSE$UNMAPPED_ARE_EMPTIABLE, new Object[]{printParticle(schemaParticle), printParticle(schemaParticle2), printParticles(arrayList)}, xmlObject));
                return false;
            }
        }
        return z;
    }

    public static boolean recurseAsIfGroup(SchemaParticle schemaParticle, SchemaParticle schemaParticle2, Collection collection, XmlObject xmlObject) {
        if ($assertionsDisabled || ((schemaParticle.getParticleType() == 1 && schemaParticle2.getParticleType() == 4) || ((schemaParticle.getParticleType() == 2 && schemaParticle2.getParticleType() == 4) || (schemaParticle.getParticleType() == 3 && schemaParticle2.getParticleType() == 4)))) {
            SchemaParticleImpl schemaParticleImpl = new SchemaParticleImpl();
            schemaParticleImpl.setParticleType(schemaParticle.getParticleType());
            schemaParticleImpl.setMinOccurs(BigInteger.ONE);
            schemaParticleImpl.setMaxOccurs(BigInteger.ONE);
            schemaParticleImpl.setParticleChildren(new SchemaParticle[]{schemaParticle2});
            return isParticleValidRestriction(schemaParticle, schemaParticleImpl, collection, xmlObject);
        }
        throw new AssertionError();
    }

    public static boolean recurseLax(SchemaParticle schemaParticle, SchemaParticle schemaParticle2, Collection collection, XmlObject xmlObject) {
        if (!$assertionsDisabled && (schemaParticle.getParticleType() != 2 || schemaParticle2.getParticleType() != 2)) {
            throw new AssertionError();
        } else if (!occurrenceRangeOK(schemaParticle, schemaParticle2, collection, xmlObject)) {
            return false;
        } else {
            SchemaParticle[] particleChildren = schemaParticle2.getParticleChildren();
            SchemaParticle[] particleChildren2 = schemaParticle.getParticleChildren();
            int i2 = 0;
            int i3 = 0;
            while (i2 < particleChildren.length && i3 < particleChildren2.length) {
                if (isParticleValidRestriction(particleChildren2[i3], particleChildren[i2], collection, xmlObject)) {
                    i2++;
                }
                i3++;
            }
            if (i2 >= particleChildren.length) {
                return true;
            }
            collection.add(XmlError.forObject(XmlErrorCodes.PARTICLE_DERIVATION_RECURSE_LAX$MAP, new Object[]{printParticles(particleChildren2, i2)}, xmlObject));
            return false;
        }
    }

    public static boolean recurseUnordered(SchemaParticle schemaParticle, SchemaParticle schemaParticle2, Collection collection, XmlObject xmlObject) {
        boolean z;
        if (!$assertionsDisabled && (schemaParticle.getParticleType() != 1 || schemaParticle2.getParticleType() != 3)) {
            throw new AssertionError();
        } else if (!occurrenceRangeOK(schemaParticle, schemaParticle2, collection, xmlObject)) {
            return false;
        } else {
            SchemaParticle[] particleChildren = schemaParticle.getParticleChildren();
            HashMap hashMap = new HashMap(10);
            Object obj = new Object();
            for (int i2 = 0; i2 < particleChildren.length; i2++) {
                hashMap.put(particleChildren[i2].getName(), particleChildren[i2]);
            }
            SchemaParticle[] particleChildren2 = schemaParticle2.getParticleChildren();
            int i3 = 0;
            while (true) {
                if (i3 >= particleChildren2.length) {
                    z = true;
                    break;
                }
                Object obj2 = hashMap.get(particleChildren2[i3].getName());
                if (obj2 == null) {
                    collection.add(XmlError.forObject(XmlErrorCodes.PARTICLE_DERIVATION_RECURSE_UNORDERED$MAP, new Object[]{printParticle(particleChildren2[i3])}, xmlObject));
                    break;
                } else if (obj2 == obj) {
                    collection.add(XmlError.forObject(XmlErrorCodes.PARTICLE_DERIVATION_RECURSE_UNORDERED$MAP_UNIQUE, new Object[]{printParticle(particleChildren2[i3])}, xmlObject));
                    break;
                } else {
                    SchemaParticle schemaParticle3 = (SchemaParticle) obj2;
                    if (particleChildren2[i3].getMaxOccurs() == null || particleChildren2[i3].getMaxOccurs().compareTo(BigInteger.ONE) > 0) {
                        collection.add(XmlError.forObject(XmlErrorCodes.PARTICLE_DERIVATION_RECURSE_UNORDERED$MAP_MAX_OCCURS_1, new Object[]{printParticle(particleChildren2[i3]), printMaxOccurs(particleChildren2[i3].getMinOccurs())}, xmlObject));
                    } else if (!isParticleValidRestriction(schemaParticle3, particleChildren2[i3], collection, xmlObject)) {
                        break;
                    } else {
                        hashMap.put(particleChildren2[i3].getName(), obj);
                        i3++;
                    }
                }
            }
            z = false;
            if (z) {
                for (QName qName : hashMap.keySet()) {
                    if (hashMap.get(qName) != obj && !((SchemaParticle) hashMap.get(qName)).isSkippable()) {
                        collection.add(XmlError.forObject(XmlErrorCodes.PARTICLE_DERIVATION_RECURSE_UNORDERED$UNMAPPED_ARE_EMPTIABLE, new Object[]{printParticle((SchemaParticle) hashMap.get(qName))}, xmlObject));
                        z = false;
                    }
                }
            }
            return z;
        }
    }

    public static boolean typeDerivationOK(SchemaType schemaType, SchemaType schemaType2, Collection collection, XmlObject xmlObject) {
        if (schemaType.isAssignableFrom(schemaType2)) {
            return checkAllDerivationsForRestriction(schemaType, schemaType2, collection, xmlObject);
        }
        collection.add(XmlError.forObject(XmlErrorCodes.PARTICLE_RESTRICTION_NAME_AND_TYPE$TYPE_VALID, new Object[]{printType(schemaType2), printType(schemaType)}, xmlObject));
        return false;
    }

    public static String printParticles(SchemaParticle[] schemaParticleArr) {
        return printParticles(schemaParticleArr, 0, schemaParticleArr.length);
    }

    public static String printParticles(SchemaParticle[] schemaParticleArr, int i2) {
        return printParticles(schemaParticleArr, i2, schemaParticleArr.length);
    }

    public static String printParticles(SchemaParticle[] schemaParticleArr, int i2, int i3) {
        StringBuffer stringBuffer = new StringBuffer(schemaParticleArr.length * 30);
        while (i2 < i3) {
            stringBuffer.append(printParticle(schemaParticleArr[i2]));
            i2++;
            if (i2 != i3) {
                stringBuffer.append(", ");
            }
        }
        return stringBuffer.toString();
    }
}
