package org.apache.xmlbeans.impl.schema;

import b.b.a.a.a;
import java.math.BigInteger;
import java.util.ArrayList;
import java.util.Arrays;
import java.util.Collection;
import java.util.Collections;
import java.util.HashMap;
import java.util.HashSet;
import java.util.Iterator;
import java.util.LinkedHashMap;
import java.util.List;
import java.util.Map;
import java.util.Set;
import org.apache.poi.javax.xml.namespace.QName;
import org.apache.xerces.impl.xs.SchemaSymbols;
import org.apache.xmlbeans.QNameSet;
import org.apache.xmlbeans.QNameSetBuilder;
import org.apache.xmlbeans.QNameSetSpecification;
import org.apache.xmlbeans.SchemaAttributeModel;
import org.apache.xmlbeans.SchemaField;
import org.apache.xmlbeans.SchemaLocalAttribute;
import org.apache.xmlbeans.SchemaLocalElement;
import org.apache.xmlbeans.SchemaParticle;
import org.apache.xmlbeans.SchemaProperty;
import org.apache.xmlbeans.SchemaType;
import org.apache.xmlbeans.XmlCursor;
import org.apache.xmlbeans.XmlErrorCodes;
import org.apache.xmlbeans.XmlInteger;
import org.apache.xmlbeans.XmlNonNegativeInteger;
import org.apache.xmlbeans.XmlObject;
import org.apache.xmlbeans.impl.common.QNameHelper;
import org.apache.xmlbeans.impl.xb.xsdschema.AllNNI;
import org.apache.xmlbeans.impl.xb.xsdschema.AnyDocument;
import org.apache.xmlbeans.impl.xb.xsdschema.Attribute;
import org.apache.xmlbeans.impl.xb.xsdschema.AttributeGroupRef;
import org.apache.xmlbeans.impl.xb.xsdschema.ComplexContentDocument;
import org.apache.xmlbeans.impl.xb.xsdschema.ComplexRestrictionType;
import org.apache.xmlbeans.impl.xb.xsdschema.ComplexType;
import org.apache.xmlbeans.impl.xb.xsdschema.ExtensionType;
import org.apache.xmlbeans.impl.xb.xsdschema.Group;
import org.apache.xmlbeans.impl.xb.xsdschema.LocalElement;
import org.apache.xmlbeans.impl.xb.xsdschema.NamespaceList;
import org.apache.xmlbeans.impl.xb.xsdschema.SchemaDocument;
import org.apache.xmlbeans.impl.xb.xsdschema.SimpleContentDocument;
import org.apache.xmlbeans.impl.xb.xsdschema.SimpleExtensionType;
import org.apache.xmlbeans.impl.xb.xsdschema.SimpleRestrictionType;
import org.apache.xmlbeans.impl.xb.xsdschema.Wildcard;

public class StscComplexTypeResolver {
    public static final /* synthetic */ boolean $assertionsDisabled;
    public static final int ANY_ATTRIBUTE_CODE = 102;
    public static final int ATTRIBUTE_CODE = 100;
    public static final int ATTRIBUTE_GROUP_CODE = 101;
    public static final int MODEL_GROUP_CODE = 100;
    public static Map attributeCodeMap = buildAttributeCodeMap();
    public static CodeForNameEntry[] attributeCodes = {new CodeForNameEntry(QNameHelper.forLNS("attribute", "http://www.w3.org/2001/XMLSchema"), 100), new CodeForNameEntry(QNameHelper.forLNS("attributeGroup", "http://www.w3.org/2001/XMLSchema"), 101), new CodeForNameEntry(QNameHelper.forLNS("anyAttribute", "http://www.w3.org/2001/XMLSchema"), 102)};
    public static /* synthetic */ Class class$org$apache$xmlbeans$impl$schema$StscComplexTypeResolver;
    public static Map particleCodeMap = buildParticleCodeMap();
    public static CodeForNameEntry[] particleCodes = {new CodeForNameEntry(QNameHelper.forLNS("all", "http://www.w3.org/2001/XMLSchema"), 1), new CodeForNameEntry(QNameHelper.forLNS("sequence", "http://www.w3.org/2001/XMLSchema"), 3), new CodeForNameEntry(QNameHelper.forLNS("choice", "http://www.w3.org/2001/XMLSchema"), 2), new CodeForNameEntry(QNameHelper.forLNS("element", "http://www.w3.org/2001/XMLSchema"), 4), new CodeForNameEntry(QNameHelper.forLNS("any", "http://www.w3.org/2001/XMLSchema"), 5), new CodeForNameEntry(QNameHelper.forLNS("group", "http://www.w3.org/2001/XMLSchema"), 100)};

    public static class CodeForNameEntry {
        public int code;
        public QName name;

        public CodeForNameEntry(QName qName, int i2) {
            this.name = qName;
            this.code = i2;
        }
    }

    public static class RedefinitionForGroup {
        public SchemaModelGroupImpl group;
        public boolean seenRedefinition = false;

        public RedefinitionForGroup(SchemaModelGroupImpl schemaModelGroupImpl) {
            this.group = schemaModelGroupImpl;
        }

        public SchemaModelGroupImpl getGroup() {
            return this.group;
        }

        public boolean isSeenRedefinition() {
            return this.seenRedefinition;
        }

        public void setSeenRedefinition(boolean z) {
            this.seenRedefinition = z;
        }
    }

    public static class WildcardResult {
        public boolean hasWildcards;
        public QNameSet typedWildcards;

        public WildcardResult(QNameSet qNameSet, boolean z) {
            this.typedWildcards = qNameSet;
            this.hasWildcards = z;
        }
    }

    static {
        Class cls = class$org$apache$xmlbeans$impl$schema$StscComplexTypeResolver;
        if (cls == null) {
            cls = class$("org.apache.xmlbeans.impl.schema.StscComplexTypeResolver");
            class$org$apache$xmlbeans$impl$schema$StscComplexTypeResolver = cls;
        }
        $assertionsDisabled = !cls.desiredAssertionStatus();
    }

    public static void addMinusPointlessParticles(List list, SchemaParticle schemaParticle, int i2) {
        if (schemaParticle != null) {
            int particleType = schemaParticle.getParticleType();
            if (particleType != 2) {
                if (particleType == 3 && i2 == 3 && schemaParticle.isSingleton()) {
                    list.addAll(Arrays.asList(schemaParticle.getParticleChildren()));
                    return;
                }
            } else if (i2 == 2 && schemaParticle.isSingleton()) {
                list.addAll(Arrays.asList(schemaParticle.getParticleChildren()));
                return;
            }
            list.add(schemaParticle);
        }
    }

    public static boolean afterMapSubsumedByStartMap(Map map, Map map2) {
        if (map2.size() > map.size()) {
            return false;
        }
        if (map2.isEmpty()) {
            return true;
        }
        for (SchemaParticle schemaParticle : map.keySet()) {
            if (schemaParticle.getParticleType() == 5 && map2.containsKey(schemaParticle) && !((QNameSet) map.get(schemaParticle)).containsAll((QNameSet) map2.get(schemaParticle))) {
                return false;
            }
            map2.remove(schemaParticle);
            if (map2.isEmpty()) {
                return true;
            }
        }
        return map2.isEmpty();
    }

    public static Map buildAttributeCodeMap() {
        HashMap hashMap = new HashMap();
        int i2 = 0;
        while (true) {
            CodeForNameEntry[] codeForNameEntryArr = attributeCodes;
            if (i2 >= codeForNameEntryArr.length) {
                return hashMap;
            }
            hashMap.put(codeForNameEntryArr[i2].name, new Integer(attributeCodes[i2].code));
            i2++;
        }
    }

    public static Map buildAttributePropertyModelByQName(SchemaAttributeModel schemaAttributeModel, SchemaType schemaType) {
        LinkedHashMap linkedHashMap = new LinkedHashMap();
        SchemaLocalAttribute[] attributes = schemaAttributeModel.getAttributes();
        for (int i2 = 0; i2 < attributes.length; i2++) {
            linkedHashMap.put(attributes[i2].getName(), buildUseProperty(attributes[i2], schemaType));
        }
        return linkedHashMap;
    }

    /* JADX DEBUG: Failed to insert an additional move for type inference into block B:24:0x0039 */
    /* JADX WARN: Multi-variable type inference failed */
    /* JADX WARN: Type inference failed for: r0v9, types: [java.util.Map] */
    /* JADX WARN: Type inference failed for: r0v10, types: [java.util.Map] */
    /* JADX WARNING: Removed duplicated region for block: B:25:0x003b  */
    /* JADX WARNING: Unknown variable types count: 2 */
    public static Map buildContentPropertyModelByQName(SchemaParticle schemaParticle, SchemaType schemaType) {
        LinkedHashMap linkedHashMap;
        SchemaParticle[] particleChildren;
        LinkedHashMap linkedHashMap2;
        if (schemaParticle == null) {
            return Collections.EMPTY_MAP;
        }
        int particleType = schemaParticle.getParticleType();
        boolean z = true;
        if (particleType != 1) {
            if (particleType == 2) {
                linkedHashMap2 = null;
            } else if (particleType != 3) {
                if (particleType == 4) {
                    linkedHashMap2 = buildElementPropertyModel((SchemaLocalElement) schemaParticle, schemaType);
                } else if (particleType == 5) {
                    linkedHashMap2 = Collections.EMPTY_MAP;
                } else if (!$assertionsDisabled) {
                    throw new AssertionError();
                } else {
                    throw new IllegalStateException();
                }
            }
            z = false;
            linkedHashMap = linkedHashMap2;
            if (linkedHashMap == null) {
                linkedHashMap = new LinkedHashMap();
                for (SchemaParticle schemaParticle2 : schemaParticle.getParticleChildren()) {
                    for (SchemaProperty schemaProperty : buildContentPropertyModelByQName(schemaParticle2, schemaType).values()) {
                        SchemaPropertyImpl schemaPropertyImpl = (SchemaPropertyImpl) linkedHashMap.get(schemaProperty.getName());
                        if (schemaPropertyImpl == null) {
                            if (!z) {
                                ((SchemaPropertyImpl) schemaProperty).setMinOccurs(BigInteger.ZERO);
                            }
                            linkedHashMap.put(schemaProperty.getName(), schemaProperty);
                        } else if ($assertionsDisabled || schemaPropertyImpl.getType().equals(schemaProperty.getType())) {
                            mergeProperties(schemaPropertyImpl, schemaProperty, z);
                        } else {
                            throw new AssertionError();
                        }
                    }
                }
                BigInteger minOccurs = schemaParticle.getMinOccurs();
                BigInteger maxOccurs = schemaParticle.getMaxOccurs();
                for (SchemaProperty schemaProperty2 : linkedHashMap.values()) {
                    BigInteger minOccurs2 = schemaProperty2.getMinOccurs();
                    BigInteger maxOccurs2 = schemaProperty2.getMaxOccurs();
                    BigInteger multiply = minOccurs2.multiply(minOccurs);
                    if (maxOccurs != null && maxOccurs.equals(BigInteger.ZERO)) {
                        maxOccurs2 = BigInteger.ZERO;
                    } else if (maxOccurs2 != null && !maxOccurs2.equals(BigInteger.ZERO)) {
                        maxOccurs2 = maxOccurs == null ? null : maxOccurs2.multiply(maxOccurs);
                    }
                    SchemaPropertyImpl schemaPropertyImpl2 = (SchemaPropertyImpl) schemaProperty2;
                    schemaPropertyImpl2.setMinOccurs(multiply);
                    schemaPropertyImpl2.setMaxOccurs(maxOccurs2);
                }
            }
            return linkedHashMap;
        }
        linkedHashMap = null;
        if (linkedHashMap == null) {
        }
        return linkedHashMap;
    }

    public static Map buildElementPropertyModel(SchemaLocalElement schemaLocalElement, SchemaType schemaType) {
        HashMap hashMap = new HashMap(1);
        SchemaProperty buildUseProperty = buildUseProperty(schemaLocalElement, schemaType);
        hashMap.put(buildUseProperty.getName(), buildUseProperty);
        return hashMap;
    }

    public static Map buildParticleCodeMap() {
        HashMap hashMap = new HashMap();
        int i2 = 0;
        while (true) {
            CodeForNameEntry[] codeForNameEntryArr = particleCodes;
            if (i2 >= codeForNameEntryArr.length) {
                return hashMap;
            }
            hashMap.put(codeForNameEntryArr[i2].name, new Integer(particleCodes[i2].code));
            i2++;
        }
    }

    public static void buildStateMachine(SchemaParticle schemaParticle) {
        boolean z;
        boolean z2;
        if (schemaParticle != null) {
            SchemaParticleImpl schemaParticleImpl = (SchemaParticleImpl) schemaParticle;
            if (!schemaParticleImpl.hasTransitionNotes()) {
                QNameSetBuilder qNameSetBuilder = new QNameSetBuilder();
                QNameSetBuilder qNameSetBuilder2 = new QNameSetBuilder();
                boolean z3 = false;
                boolean z4 = schemaParticleImpl.getMinOccurs().signum() == 0;
                int particleType = schemaParticleImpl.getParticleType();
                if (particleType != 1) {
                    if (particleType == 2) {
                        SchemaParticle[] ensureStateMachine = ensureStateMachine(schemaParticleImpl.getParticleChildren());
                        z2 = false;
                        int i2 = 0;
                        while (!z2 && i2 < ensureStateMachine.length) {
                            if (ensureStateMachine[i2].isSkippable()) {
                                z2 = true;
                            }
                            i2++;
                        }
                        z = true;
                        int i3 = 0;
                        while (z && i3 < ensureStateMachine.length) {
                            if (!((SchemaParticleImpl) ensureStateMachine[i3]).isDeterministic()) {
                                z = false;
                            }
                            i3++;
                        }
                        for (int i4 = 0; i4 < ensureStateMachine.length; i4++) {
                            if (z && !qNameSetBuilder.isDisjoint(ensureStateMachine[i4].acceptedStartNames())) {
                                z = false;
                            }
                            qNameSetBuilder.addAll(ensureStateMachine[i4].acceptedStartNames());
                            qNameSetBuilder2.addAll(((SchemaParticleImpl) ensureStateMachine[i4]).getExcludeNextSet());
                        }
                    } else if (particleType != 3) {
                        if (particleType != 4) {
                            if (particleType == 5) {
                                qNameSetBuilder.addAll(schemaParticleImpl.getWildcardSet());
                            } else {
                                throw new IllegalStateException("Unrecognized schema particle");
                            }
                        } else if (schemaParticleImpl.hasTransitionRules()) {
                            qNameSetBuilder.addAll(schemaParticleImpl.acceptedStartNames());
                        } else {
                            qNameSetBuilder.add(schemaParticleImpl.getName());
                        }
                        z = true;
                    } else {
                        SchemaParticle[] ensureStateMachine2 = ensureStateMachine(schemaParticleImpl.getParticleChildren());
                        z2 = true;
                        int i5 = 0;
                        while (z2 && i5 < ensureStateMachine2.length) {
                            if (!ensureStateMachine2[i5].isSkippable()) {
                                z2 = false;
                            }
                            i5++;
                        }
                        z = true;
                        int i6 = 0;
                        while (z && i6 < ensureStateMachine2.length) {
                            if (!((SchemaParticleImpl) ensureStateMachine2[i6]).isDeterministic()) {
                                z = false;
                            }
                            i6++;
                        }
                        for (int i7 = 1; i7 < ensureStateMachine2.length; i7++) {
                            qNameSetBuilder2.addAll(((SchemaParticleImpl) ensureStateMachine2[i7 - 1]).getExcludeNextSet());
                            if (z && !qNameSetBuilder2.isDisjoint(ensureStateMachine2[i7].acceptedStartNames())) {
                                z = false;
                            }
                            if (ensureStateMachine2[i7].isSkippable()) {
                                qNameSetBuilder2.addAll(ensureStateMachine2[i7].acceptedStartNames());
                            } else {
                                qNameSetBuilder2.clear();
                            }
                        }
                        for (int i8 = 0; i8 < ensureStateMachine2.length; i8++) {
                            qNameSetBuilder.addAll(ensureStateMachine2[i8].acceptedStartNames());
                            if (!ensureStateMachine2[i8].isSkippable()) {
                                break;
                            }
                        }
                    }
                    z4 = z2;
                } else {
                    SchemaParticle[] ensureStateMachine3 = ensureStateMachine(schemaParticleImpl.getParticleChildren());
                    boolean z5 = true;
                    int i9 = 0;
                    while (z5 && i9 < ensureStateMachine3.length) {
                        if (!((SchemaParticleImpl) ensureStateMachine3[i9]).isDeterministic()) {
                            z5 = false;
                        }
                        i9++;
                    }
                    z = z5;
                    for (int i10 = 0; i10 < ensureStateMachine3.length; i10++) {
                        if (z && !qNameSetBuilder.isDisjoint(ensureStateMachine3[i10].acceptedStartNames())) {
                            z = false;
                        }
                        qNameSetBuilder.addAll(ensureStateMachine3[i10].acceptedStartNames());
                        qNameSetBuilder2.addAll(((SchemaParticleImpl) ensureStateMachine3[i10]).getExcludeNextSet());
                    }
                    qNameSetBuilder2.addAll(qNameSetBuilder);
                    z4 = true;
                }
                BigInteger minOccurs = schemaParticleImpl.getMinOccurs();
                BigInteger maxOccurs = schemaParticleImpl.getMaxOccurs();
                boolean z6 = maxOccurs == null || maxOccurs.compareTo(BigInteger.ONE) > 0;
                boolean z7 = maxOccurs == null || minOccurs.compareTo(maxOccurs) < 0;
                if (z6 && z && !qNameSetBuilder2.isDisjoint(qNameSetBuilder)) {
                    QNameSet intersect = qNameSetBuilder2.intersect(qNameSetBuilder);
                    HashMap hashMap = new HashMap();
                    particlesMatchingStart(schemaParticleImpl, intersect, hashMap, new QNameSetBuilder());
                    HashMap hashMap2 = new HashMap();
                    particlesMatchingAfter(schemaParticleImpl, intersect, hashMap2, new QNameSetBuilder(), true);
                    z = afterMapSubsumedByStartMap(hashMap, hashMap2);
                }
                if (z7) {
                    qNameSetBuilder2.addAll(qNameSetBuilder);
                }
                if (z4 || minOccurs.signum() == 0) {
                    z3 = true;
                }
                schemaParticleImpl.setTransitionRules(qNameSetBuilder.toQNameSet(), z3);
                schemaParticleImpl.setTransitionNotes(qNameSetBuilder2.toQNameSet(), z);
            }
        }
    }

    public static SchemaProperty buildUseProperty(SchemaField schemaField, SchemaType schemaType) {
        SchemaPropertyImpl schemaPropertyImpl = new SchemaPropertyImpl();
        schemaPropertyImpl.setName(schemaField.getName());
        schemaPropertyImpl.setContainerTypeRef(schemaType.getRef());
        schemaPropertyImpl.setTypeRef(schemaField.getType().getRef());
        schemaPropertyImpl.setAttribute(schemaField.isAttribute());
        int i2 = 2;
        schemaPropertyImpl.setDefault(schemaField.isDefault() ? 2 : 0);
        schemaPropertyImpl.setFixed(schemaField.isFixed() ? 2 : 0);
        if (!schemaField.isNillable()) {
            i2 = 0;
        }
        schemaPropertyImpl.setNillable(i2);
        schemaPropertyImpl.setDefaultText(schemaField.getDefaultText());
        schemaPropertyImpl.setMinOccurs(schemaField.getMinOccurs());
        schemaPropertyImpl.setMaxOccurs(schemaField.getMaxOccurs());
        if (schemaField instanceof SchemaLocalElementImpl) {
            schemaPropertyImpl.setAcceptedNames(((SchemaLocalElementImpl) schemaField).acceptedStartNames());
        }
        return schemaPropertyImpl;
    }

    public static /* synthetic */ Class class$(String str) {
        try {
            return Class.forName(str);
        } catch (ClassNotFoundException e2) {
            throw a.a(e2);
        }
    }

    public static SchemaParticle[] ensureStateMachine(SchemaParticle[] schemaParticleArr) {
        for (SchemaParticle schemaParticle : schemaParticleArr) {
            buildStateMachine(schemaParticle);
        }
        return schemaParticleArr;
    }

    public static SchemaParticle extendContentModel(SchemaParticle schemaParticle, SchemaParticle schemaParticle2, XmlObject xmlObject) {
        if (schemaParticle2 == null) {
            return schemaParticle;
        }
        if (schemaParticle == null) {
            return schemaParticle2;
        }
        SchemaParticleImpl schemaParticleImpl = new SchemaParticleImpl();
        schemaParticleImpl.setParticleType(3);
        ArrayList arrayList = new ArrayList();
        addMinusPointlessParticles(arrayList, schemaParticle, 3);
        addMinusPointlessParticles(arrayList, schemaParticle2, 3);
        schemaParticleImpl.setMinOccurs(BigInteger.ONE);
        schemaParticleImpl.setMaxOccurs(BigInteger.ONE);
        schemaParticleImpl.setParticleChildren((SchemaParticle[]) arrayList.toArray(new SchemaParticle[arrayList.size()]));
        return filterPointlessParticlesAndVerifyAllParticles(schemaParticleImpl, xmlObject);
    }

    public static Map extractElementModel(SchemaType schemaType) {
        HashMap hashMap = new HashMap();
        if (schemaType != null) {
            SchemaProperty[] properties = schemaType.getProperties();
            for (int i2 = 0; i2 < properties.length; i2++) {
                if (!properties[i2].isAttribute()) {
                    hashMap.put(properties[i2].getName(), properties[i2].getType());
                }
            }
        }
        return hashMap;
    }

    public static BigInteger extractMaxOccurs(AllNNI allNNI) {
        if (allNNI == null) {
            return BigInteger.ONE;
        }
        if (allNNI.instanceType().getPrimitiveType().getBuiltinTypeCode() == 11) {
            return ((XmlInteger) allNNI).getBigIntegerValue();
        }
        return null;
    }

    public static BigInteger extractMinOccurs(XmlNonNegativeInteger xmlNonNegativeInteger) {
        if (xmlNonNegativeInteger == null) {
            return BigInteger.ONE;
        }
        BigInteger bigIntegerValue = xmlNonNegativeInteger.getBigIntegerValue();
        return bigIntegerValue == null ? BigInteger.ONE : bigIntegerValue;
    }

    /* JADX WARNING: Removed duplicated region for block: B:43:0x007b  */
    /* JADX WARNING: Removed duplicated region for block: B:44:0x007d  */
    /* JADX WARNING: Removed duplicated region for block: B:53:0x00a1  */
    public static SchemaParticle filterPointlessParticlesAndVerifyAllParticles(SchemaParticle schemaParticle, XmlObject xmlObject) {
        if (schemaParticle.getMaxOccurs() != null && schemaParticle.getMaxOccurs().signum() == 0) {
            return null;
        }
        int particleType = schemaParticle.getParticleType();
        if (particleType != 1) {
            if (particleType != 2) {
                if (particleType != 3) {
                    if (particleType == 4 || particleType == 5) {
                        return schemaParticle;
                    }
                    if (!$assertionsDisabled) {
                        throw new AssertionError();
                    }
                    throw new IllegalStateException();
                }
            } else if (schemaParticle.getParticleChildren().length == 0 && schemaParticle.getMinOccurs().compareTo(BigInteger.ZERO) == 0) {
                return null;
            } else {
                if (schemaParticle.isSingleton() && schemaParticle.countOfParticleChild() == 1) {
                    return schemaParticle.getParticleChild(0);
                }
                boolean z = schemaParticle.getParticleType() != 1;
                if (z && (schemaParticle.getMaxOccurs() == null || schemaParticle.getMaxOccurs().compareTo(BigInteger.ONE) > 0)) {
                    StscState.get().error(XmlErrorCodes.ALL_GROUP_LIMITED$IN_MIN_MAX_1_PARTICLE, (Object[]) null, xmlObject);
                }
                for (int i2 = 0; i2 < schemaParticle.countOfParticleChild(); i2++) {
                    SchemaParticle particleChild = schemaParticle.getParticleChild(i2);
                    if (particleChild.getParticleType() == 1) {
                        StscState.get().error(XmlErrorCodes.ALL_GROUP_LIMITED$IN_COMPLEX_TYPE_DEF_PARTICLE, (Object[]) null, xmlObject);
                    } else if (z && (particleChild.getParticleType() != 4 || particleChild.getMaxOccurs() == null || particleChild.getMaxOccurs().compareTo(BigInteger.ONE) > 0)) {
                        StscState.get().error(XmlErrorCodes.ALL_GROUP_LIMITED$CHILD_PARTICLES_MAX_LTE_1, (Object[]) null, xmlObject);
                    }
                }
                return schemaParticle;
            }
        }
        if (schemaParticle.getParticleChildren().length == 0) {
            return null;
        }
        if (schemaParticle.isSingleton() && schemaParticle.countOfParticleChild() == 1) {
            return schemaParticle.getParticleChild(0);
        }
        if (schemaParticle.getParticleType() != 1) {
        }
        StscState.get().error(XmlErrorCodes.ALL_GROUP_LIMITED$IN_MIN_MAX_1_PARTICLE, (Object[]) null, xmlObject);
        while (i2 < schemaParticle.countOfParticleChild()) {
        }
        return schemaParticle;
    }

    public static Group getContentModel(ComplexType complexType) {
        if (complexType.getAll() != null) {
            return complexType.getAll();
        }
        if (complexType.getSequence() != null) {
            return complexType.getSequence();
        }
        if (complexType.getChoice() != null) {
            return complexType.getChoice();
        }
        if (complexType.getGroup() != null) {
            return complexType.getGroup();
        }
        return null;
    }

    public static SchemaDocument.Schema getSchema(XmlObject xmlObject) {
        XmlObject object;
        XmlCursor newCursor = xmlObject.newCursor();
        do {
            try {
                if (newCursor.toParent()) {
                    object = newCursor.getObject();
                } else {
                    newCursor.dispose();
                    return null;
                }
            } finally {
                newCursor.dispose();
            }
        } while (!object.schemaType().equals(SchemaDocument.Schema.type));
        return (SchemaDocument.Schema) object;
    }

    public static SchemaType.Ref[] makeRefArray(Collection collection) {
        SchemaType.Ref[] refArr = new SchemaType.Ref[collection.size()];
        Iterator it = collection.iterator();
        int i2 = 0;
        while (it.hasNext()) {
            refArr[i2] = ((SchemaType) it.next()).getRef();
            i2++;
        }
        return refArr;
    }

    /* JADX WARNING: Removed duplicated region for block: B:16:0x0052  */
    /* JADX WARNING: Removed duplicated region for block: B:19:0x005f  */
    /* JADX WARNING: Removed duplicated region for block: B:22:0x006c  */
    /* JADX WARNING: Removed duplicated region for block: B:25:0x0075  */
    /* JADX WARNING: Removed duplicated region for block: B:31:? A[RETURN, SYNTHETIC] */
    public static void mergeProperties(SchemaPropertyImpl schemaPropertyImpl, SchemaProperty schemaProperty, boolean z) {
        BigInteger bigInteger;
        BigInteger max;
        BigInteger minOccurs = schemaPropertyImpl.getMinOccurs();
        BigInteger maxOccurs = schemaPropertyImpl.getMaxOccurs();
        if (z) {
            bigInteger = minOccurs.add(schemaProperty.getMinOccurs());
            if (maxOccurs != null) {
                if (schemaProperty.getMaxOccurs() != null) {
                    max = maxOccurs.add(schemaProperty.getMaxOccurs());
                    maxOccurs = max;
                }
            }
            schemaPropertyImpl.setMinOccurs(bigInteger);
            schemaPropertyImpl.setMaxOccurs(maxOccurs);
            if (schemaProperty.hasNillable() != schemaPropertyImpl.hasNillable()) {
                schemaPropertyImpl.setNillable(1);
            }
            if (schemaProperty.hasDefault() != schemaPropertyImpl.hasDefault()) {
                schemaPropertyImpl.setDefault(1);
            }
            if (schemaProperty.hasFixed() != schemaPropertyImpl.hasFixed()) {
                schemaPropertyImpl.setFixed(1);
            }
            if (schemaPropertyImpl.getDefaultText() == null) {
                return;
            }
            if (schemaProperty.getDefaultText() == null || !schemaPropertyImpl.getDefaultText().equals(schemaProperty.getDefaultText())) {
                schemaPropertyImpl.setDefaultText(null);
                return;
            }
            return;
        }
        bigInteger = minOccurs.min(schemaProperty.getMinOccurs());
        if (maxOccurs != null) {
            if (schemaProperty.getMaxOccurs() != null) {
                max = maxOccurs.max(schemaProperty.getMaxOccurs());
                maxOccurs = max;
            }
        }
        schemaPropertyImpl.setMinOccurs(bigInteger);
        schemaPropertyImpl.setMaxOccurs(maxOccurs);
        if (schemaProperty.hasNillable() != schemaPropertyImpl.hasNillable()) {
        }
        if (schemaProperty.hasDefault() != schemaPropertyImpl.hasDefault()) {
        }
        if (schemaProperty.hasFixed() != schemaPropertyImpl.hasFixed()) {
        }
        if (schemaPropertyImpl.getDefaultText() == null) {
        }
        maxOccurs = null;
        schemaPropertyImpl.setMinOccurs(bigInteger);
        schemaPropertyImpl.setMaxOccurs(maxOccurs);
        if (schemaProperty.hasNillable() != schemaPropertyImpl.hasNillable()) {
        }
        if (schemaProperty.hasDefault() != schemaPropertyImpl.hasDefault()) {
        }
        if (schemaProperty.hasFixed() != schemaPropertyImpl.hasFixed()) {
        }
        if (schemaPropertyImpl.getDefaultText() == null) {
        }
    }

    public static void particlesMatchingAfter(SchemaParticle schemaParticle, QNameSetSpecification qNameSetSpecification, Map map, QNameSetBuilder qNameSetBuilder, boolean z) {
        SchemaParticle[] particleChildren;
        int particleType = schemaParticle.getParticleType();
        boolean z2 = true;
        if (particleType == 1 || particleType == 2) {
            for (SchemaParticle schemaParticle2 : schemaParticle.getParticleChildren()) {
                particlesMatchingAfter(schemaParticle2, qNameSetSpecification, map, qNameSetBuilder, false);
            }
        } else if (particleType == 3) {
            SchemaParticle[] particleChildren2 = schemaParticle.getParticleChildren();
            if (particleChildren2.length != 0) {
                if (!particleChildren2[particleChildren2.length - 1].isSkippable()) {
                    particlesMatchingAfter(particleChildren2[0], qNameSetSpecification, map, qNameSetBuilder, false);
                } else {
                    QNameSetBuilder qNameSetBuilder2 = new QNameSetBuilder(qNameSetSpecification);
                    QNameSetBuilder qNameSetBuilder3 = new QNameSetBuilder();
                    for (int length = particleChildren2.length - 1; length >= 0; length--) {
                        particlesMatchingAfter(particleChildren2[length], qNameSetBuilder2, map, qNameSetBuilder3, false);
                        qNameSetBuilder.addAll(qNameSetBuilder3);
                        if (!particleChildren2[length].isSkippable()) {
                            break;
                        }
                        qNameSetBuilder2.removeAll(qNameSetBuilder3);
                        if (qNameSetBuilder2.isEmpty()) {
                            break;
                        }
                        qNameSetBuilder3.clear();
                    }
                }
            }
        }
        if (!z) {
            BigInteger minOccurs = schemaParticle.getMinOccurs();
            BigInteger maxOccurs = schemaParticle.getMaxOccurs();
            if (maxOccurs != null && minOccurs.compareTo(maxOccurs) >= 0) {
                z2 = false;
            }
            if (z2) {
                particlesMatchingStart(schemaParticle, qNameSetSpecification, map, qNameSetBuilder);
            }
        }
    }

    public static void particlesMatchingStart(SchemaParticle schemaParticle, QNameSetSpecification qNameSetSpecification, Map map, QNameSetBuilder qNameSetBuilder) {
        int particleType = schemaParticle.getParticleType();
        int i2 = 0;
        if (particleType == 1 || particleType == 2) {
            SchemaParticle[] particleChildren = schemaParticle.getParticleChildren();
            while (i2 < particleChildren.length) {
                particlesMatchingStart(particleChildren[i2], qNameSetSpecification, map, qNameSetBuilder);
                i2++;
            }
        } else if (particleType == 3) {
            SchemaParticle[] particleChildren2 = schemaParticle.getParticleChildren();
            if (particleChildren2.length != 0) {
                if (!particleChildren2[0].isSkippable()) {
                    particlesMatchingStart(particleChildren2[0], qNameSetSpecification, map, qNameSetBuilder);
                    return;
                }
                QNameSetBuilder qNameSetBuilder2 = new QNameSetBuilder(qNameSetSpecification);
                QNameSetBuilder qNameSetBuilder3 = new QNameSetBuilder();
                while (i2 < particleChildren2.length) {
                    particlesMatchingStart(particleChildren2[i2], qNameSetBuilder2, map, qNameSetBuilder3);
                    qNameSetBuilder.addAll(qNameSetBuilder3);
                    if (particleChildren2[i2].isSkippable()) {
                        qNameSetBuilder2.removeAll(qNameSetBuilder3);
                        if (!qNameSetBuilder2.isEmpty()) {
                            qNameSetBuilder3.clear();
                            i2++;
                        } else {
                            return;
                        }
                    } else {
                        return;
                    }
                }
            }
        } else if (particleType != 4) {
            if (particleType == 5 && !qNameSetSpecification.isDisjoint(schemaParticle.getWildcardSet())) {
                map.put(schemaParticle, schemaParticle.getWildcardSet().intersect(qNameSetSpecification));
                qNameSetBuilder.addAll(schemaParticle.getWildcardSet());
            }
        } else if (qNameSetSpecification.contains(schemaParticle.getName())) {
            map.put(schemaParticle, null);
            qNameSetBuilder.add(schemaParticle.getName());
        }
    }

    public static void resolveBasicComplexType(SchemaTypeImpl schemaTypeImpl) {
        ArrayList arrayList = new ArrayList();
        ComplexType complexType = (ComplexType) schemaTypeImpl.getParseObject();
        String targetNamespace = schemaTypeImpl.getTargetNamespace();
        boolean z = schemaTypeImpl.getChameleonNamespace() != null;
        Group contentModel = getContentModel(complexType);
        if (schemaTypeImpl.isRedefinition()) {
            StscState.get().error(XmlErrorCodes.SCHEMA_REDEFINE$EXTEND_OR_RESTRICT, new Object[]{"<complexType>"}, complexType);
        }
        SchemaParticle translateContentModel = translateContentModel(schemaTypeImpl, contentModel, targetNamespace, z, schemaTypeImpl.getElemFormDefault(), schemaTypeImpl.getAttFormDefault(), translateParticleCode(contentModel), arrayList, new LinkedHashMap(), false, null);
        boolean z2 = translateContentModel != null && translateContentModel.getParticleType() == 1;
        SchemaAttributeModelImpl schemaAttributeModelImpl = new SchemaAttributeModelImpl();
        translateAttributeModel(complexType, targetNamespace, z, schemaTypeImpl.getAttFormDefault(), arrayList, schemaTypeImpl, null, schemaAttributeModelImpl, null, true, null);
        WildcardResult summarizeEltWildcards = summarizeEltWildcards(translateContentModel);
        WildcardResult summarizeAttrWildcards = summarizeAttrWildcards(schemaAttributeModelImpl);
        if (translateContentModel != null) {
            buildStateMachine(translateContentModel);
            if (!StscState.get().noUpa() && !((SchemaParticleImpl) translateContentModel).isDeterministic()) {
                StscState.get().error(XmlErrorCodes.UNIQUE_PARTICLE_ATTRIBUTION, (Object[]) null, contentModel);
            }
        }
        Map buildContentPropertyModelByQName = buildContentPropertyModelByQName(translateContentModel, schemaTypeImpl);
        Map buildAttributePropertyModelByQName = buildAttributePropertyModelByQName(schemaAttributeModelImpl, schemaTypeImpl);
        int i2 = complexType.getMixed() ? 4 : translateContentModel == null ? 1 : 3;
        schemaTypeImpl.setBaseTypeRef(BuiltinSchemaTypeSystem.ST_ANY_TYPE.getRef());
        schemaTypeImpl.setBaseDepth(BuiltinSchemaTypeSystem.ST_ANY_TYPE.getBaseDepth() + 1);
        schemaTypeImpl.setDerivationType(2);
        schemaTypeImpl.setComplexTypeVariety(i2);
        schemaTypeImpl.setContentModel(translateContentModel, schemaAttributeModelImpl, buildContentPropertyModelByQName, buildAttributePropertyModelByQName, z2);
        schemaTypeImpl.setAnonymousTypeRefs(makeRefArray(arrayList));
        schemaTypeImpl.setWildcardSummary(summarizeEltWildcards.typedWildcards, summarizeEltWildcards.hasWildcards, summarizeAttrWildcards.typedWildcards, summarizeAttrWildcards.hasWildcards);
    }

    /* JADX DEBUG: Multi-variable search result rejected for r8v2, resolved type: java.lang.Object[] */
    /* JADX DEBUG: Multi-variable search result rejected for r8v5, resolved type: java.lang.Object[] */
    /* JADX DEBUG: Multi-variable search result rejected for r8v6, resolved type: java.lang.Object[] */
    /* JADX WARN: Multi-variable type inference failed */
    /* JADX WARNING: Removed duplicated region for block: B:73:0x019d  */
    /* JADX WARNING: Removed duplicated region for block: B:74:0x01a3  */
    /* JADX WARNING: Removed duplicated region for block: B:77:0x01d8  */
    /* JADX WARNING: Removed duplicated region for block: B:90:0x021d  */
    /* JADX WARNING: Removed duplicated region for block: B:91:0x021f  */
    /* JADX WARNING: Removed duplicated region for block: B:95:0x0226  */
    public static void resolveCcExtension(SchemaTypeImpl schemaTypeImpl, ExtensionType extensionType, boolean z) {
        SchemaTypeImpl schemaTypeImpl2;
        SchemaParticle schemaParticle;
        SchemaType schemaType;
        boolean z2;
        Object[] objArr;
        SchemaParticle extendContentModel;
        SchemaAttributeModelImpl schemaAttributeModelImpl;
        int i2;
        int i3;
        StscState stscState = StscState.get();
        String targetNamespace = schemaTypeImpl.getTargetNamespace();
        boolean z3 = schemaTypeImpl.getChameleonNamespace() != null;
        if (extensionType.getBase() == null) {
            stscState.error("A complexContent must define a base type", 28, extensionType);
            schemaTypeImpl2 = null;
        } else {
            if (schemaTypeImpl.isRedefinition()) {
                schemaTypeImpl2 = stscState.findRedefinedGlobalType(extensionType.getBase(), schemaTypeImpl.getChameleonNamespace(), schemaTypeImpl);
                if (schemaTypeImpl2 != null && !schemaTypeImpl2.getName().equals(schemaTypeImpl.getName())) {
                    stscState.error(XmlErrorCodes.SCHEMA_REDEFINE$SAME_TYPE, new Object[]{"<complexType>", QNameHelper.pretty(schemaTypeImpl2.getName()), QNameHelper.pretty(schemaTypeImpl.getName())}, extensionType);
                }
            } else {
                schemaTypeImpl2 = stscState.findGlobalType(extensionType.getBase(), schemaTypeImpl.getChameleonNamespace(), targetNamespace);
            }
            if (schemaTypeImpl2 == null) {
                stscState.notFoundError(extensionType.getBase(), 0, extensionType.xgetBase(), true);
            }
        }
        if (schemaTypeImpl2 != null && !StscResolver.resolveType(schemaTypeImpl2)) {
            schemaTypeImpl2 = null;
        }
        if (schemaTypeImpl2 != null && schemaTypeImpl2.isSimpleType()) {
            stscState.recover(XmlErrorCodes.SCHEMA_COMPLEX_TYPE$COMPLEX_CONTENT, new Object[]{QNameHelper.pretty(schemaTypeImpl2.getName())}, extensionType.xgetBase());
            schemaTypeImpl2 = null;
        }
        if (schemaTypeImpl2 != null && schemaTypeImpl2.finalExtension()) {
            stscState.error(XmlErrorCodes.COMPLEX_TYPE_EXTENSION$FINAL, new Object[]{QNameHelper.pretty(schemaTypeImpl2.getName()), QNameHelper.pretty(schemaTypeImpl.getName())}, extensionType.xgetBase());
        }
        if (schemaTypeImpl2 == null) {
            schemaParticle = null;
        } else {
            schemaParticle = schemaTypeImpl2.getContentModel();
        }
        ArrayList arrayList = new ArrayList();
        Map extractElementModel = extractElementModel(schemaTypeImpl2);
        Group contentModel = getContentModel(extensionType);
        if (schemaTypeImpl2 == null || schemaTypeImpl2.getContentType() != 2) {
            schemaType = schemaTypeImpl2;
        } else if (contentModel != null) {
            stscState.recover(XmlErrorCodes.COMPLEX_TYPE_EXTENSION$EXTENDING_SIMPLE_CONTENT, new Object[]{QNameHelper.pretty(schemaTypeImpl2.getName())}, extensionType.xgetBase());
            schemaType = null;
        } else {
            resolveScExtensionPart2(schemaTypeImpl, schemaTypeImpl2, extensionType, targetNamespace, z3);
            return;
        }
        SchemaParticle translateContentModel = translateContentModel(schemaTypeImpl, contentModel, targetNamespace, z3, schemaTypeImpl.getElemFormDefault(), schemaTypeImpl.getAttFormDefault(), translateParticleCode(contentModel), arrayList, extractElementModel, false, null);
        if (translateContentModel != null || z) {
            z2 = z;
        } else {
            z2 = schemaType != null && schemaType.getContentType() == 4;
        }
        if (!(schemaType == null || schemaType.getContentType() == 1)) {
            if ((schemaType.getContentType() == 4) != z2) {
                objArr = 0;
                stscState.error(XmlErrorCodes.COMPLEX_TYPE_EXTENSION$BOTH_ELEMEMENT_OR_MIXED, (Object[]) null, extensionType.xgetBase());
                if (!(schemaType == null || !schemaType.hasAllContent() || translateContentModel == null)) {
                    stscState.error("Cannot extend a type with 'all' content model", 42, extensionType.xgetBase());
                    translateContentModel = objArr;
                }
                extendContentModel = extendContentModel(schemaParticle, translateContentModel, extensionType);
                boolean z4 = extendContentModel == null && extendContentModel.getParticleType() == 1;
                if (schemaType != null) {
                    schemaAttributeModelImpl = new SchemaAttributeModelImpl();
                } else {
                    schemaAttributeModelImpl = new SchemaAttributeModelImpl(schemaType.getAttributeModel());
                }
                translateAttributeModel(extensionType, targetNamespace, z3, schemaTypeImpl.getAttFormDefault(), arrayList, schemaTypeImpl, null, schemaAttributeModelImpl, schemaType, true, null);
                WildcardResult summarizeEltWildcards = summarizeEltWildcards(extendContentModel);
                WildcardResult summarizeAttrWildcards = summarizeAttrWildcards(schemaAttributeModelImpl);
                if (extendContentModel != null) {
                    buildStateMachine(extendContentModel);
                    if (!StscState.get().noUpa() && !((SchemaParticleImpl) extendContentModel).isDeterministic()) {
                        StscState.get().error(XmlErrorCodes.UNIQUE_PARTICLE_ATTRIBUTION, objArr, contentModel);
                    }
                }
                Map buildContentPropertyModelByQName = buildContentPropertyModelByQName(extendContentModel, schemaTypeImpl);
                Map buildAttributePropertyModelByQName = buildAttributePropertyModelByQName(schemaAttributeModelImpl, schemaTypeImpl);
                if (extendContentModel == null || schemaType == null) {
                    i3 = 2;
                } else {
                    i3 = 2;
                    if (schemaType.getContentType() == 2) {
                        schemaTypeImpl.setContentBasedOnTypeRef(schemaType.getContentBasedOnType().getRef());
                        i2 = 2;
                        if (schemaType == null) {
                            schemaType = XmlObject.type;
                        }
                        schemaTypeImpl.setBaseTypeRef(schemaType.getRef());
                        schemaTypeImpl.setBaseDepth(((SchemaTypeImpl) schemaType).getBaseDepth() + 1);
                        schemaTypeImpl.setDerivationType(i3);
                        schemaTypeImpl.setComplexTypeVariety(i2);
                        schemaTypeImpl.setContentModel(extendContentModel, schemaAttributeModelImpl, buildContentPropertyModelByQName, buildAttributePropertyModelByQName, z4);
                        schemaTypeImpl.setAnonymousTypeRefs(makeRefArray(arrayList));
                        schemaTypeImpl.setWildcardSummary(summarizeEltWildcards.typedWildcards, summarizeEltWildcards.hasWildcards, summarizeAttrWildcards.typedWildcards, summarizeAttrWildcards.hasWildcards);
                    }
                }
                i2 = !z2 ? 4 : extendContentModel == null ? 1 : 3;
                if (schemaType == null) {
                }
                schemaTypeImpl.setBaseTypeRef(schemaType.getRef());
                schemaTypeImpl.setBaseDepth(((SchemaTypeImpl) schemaType).getBaseDepth() + 1);
                schemaTypeImpl.setDerivationType(i3);
                schemaTypeImpl.setComplexTypeVariety(i2);
                schemaTypeImpl.setContentModel(extendContentModel, schemaAttributeModelImpl, buildContentPropertyModelByQName, buildAttributePropertyModelByQName, z4);
                schemaTypeImpl.setAnonymousTypeRefs(makeRefArray(arrayList));
                schemaTypeImpl.setWildcardSummary(summarizeEltWildcards.typedWildcards, summarizeEltWildcards.hasWildcards, summarizeAttrWildcards.typedWildcards, summarizeAttrWildcards.hasWildcards);
            }
        }
        objArr = 0;
        stscState.error("Cannot extend a type with 'all' content model", 42, extensionType.xgetBase());
        translateContentModel = objArr;
        extendContentModel = extendContentModel(schemaParticle, translateContentModel, extensionType);
        if (extendContentModel == null) {
        }
        if (schemaType != null) {
        }
        translateAttributeModel(extensionType, targetNamespace, z3, schemaTypeImpl.getAttFormDefault(), arrayList, schemaTypeImpl, null, schemaAttributeModelImpl, schemaType, true, null);
        WildcardResult summarizeEltWildcards2 = summarizeEltWildcards(extendContentModel);
        WildcardResult summarizeAttrWildcards2 = summarizeAttrWildcards(schemaAttributeModelImpl);
        if (extendContentModel != null) {
        }
        Map buildContentPropertyModelByQName2 = buildContentPropertyModelByQName(extendContentModel, schemaTypeImpl);
        Map buildAttributePropertyModelByQName2 = buildAttributePropertyModelByQName(schemaAttributeModelImpl, schemaTypeImpl);
        if (extendContentModel == null) {
        }
        i3 = 2;
        if (!z2) {
        }
        if (schemaType == null) {
        }
        schemaTypeImpl.setBaseTypeRef(schemaType.getRef());
        schemaTypeImpl.setBaseDepth(((SchemaTypeImpl) schemaType).getBaseDepth() + 1);
        schemaTypeImpl.setDerivationType(i3);
        schemaTypeImpl.setComplexTypeVariety(i2);
        schemaTypeImpl.setContentModel(extendContentModel, schemaAttributeModelImpl, buildContentPropertyModelByQName2, buildAttributePropertyModelByQName2, z4);
        schemaTypeImpl.setAnonymousTypeRefs(makeRefArray(arrayList));
        schemaTypeImpl.setWildcardSummary(summarizeEltWildcards2.typedWildcards, summarizeEltWildcards2.hasWildcards, summarizeAttrWildcards2.typedWildcards, summarizeAttrWildcards2.hasWildcards);
    }

    public static void resolveCcRestriction(SchemaTypeImpl schemaTypeImpl, ComplexRestrictionType complexRestrictionType, boolean z) {
        SchemaTypeImpl schemaTypeImpl2;
        SchemaAttributeModelImpl schemaAttributeModelImpl;
        StscState stscState = StscState.get();
        String targetNamespace = schemaTypeImpl.getTargetNamespace();
        boolean z2 = schemaTypeImpl.getChameleonNamespace() != null;
        if (complexRestrictionType.getBase() == null) {
            stscState.error("A complexContent must define a base type", 28, complexRestrictionType);
            schemaTypeImpl2 = null;
        } else {
            if (schemaTypeImpl.isRedefinition()) {
                schemaTypeImpl2 = stscState.findRedefinedGlobalType(complexRestrictionType.getBase(), schemaTypeImpl.getChameleonNamespace(), schemaTypeImpl);
                if (schemaTypeImpl2 != null && !schemaTypeImpl2.getName().equals(schemaTypeImpl.getName())) {
                    stscState.error(XmlErrorCodes.SCHEMA_REDEFINE$SAME_TYPE, new Object[]{"<complexType>", QNameHelper.pretty(schemaTypeImpl2.getName()), QNameHelper.pretty(schemaTypeImpl.getName())}, complexRestrictionType);
                }
            } else {
                schemaTypeImpl2 = stscState.findGlobalType(complexRestrictionType.getBase(), schemaTypeImpl.getChameleonNamespace(), targetNamespace);
            }
            if (schemaTypeImpl2 == null) {
                stscState.notFoundError(complexRestrictionType.getBase(), 0, complexRestrictionType.xgetBase(), true);
            }
        }
        if (schemaTypeImpl2 == null) {
            schemaTypeImpl2 = BuiltinSchemaTypeSystem.ST_ANY_TYPE;
        }
        if (schemaTypeImpl2 != null && schemaTypeImpl2.finalRestriction()) {
            stscState.error(XmlErrorCodes.COMPLEX_TYPE_RESTRICTION$FINAL, new Object[]{QNameHelper.pretty(schemaTypeImpl2.getName()), QNameHelper.pretty(schemaTypeImpl.getName())}, complexRestrictionType.xgetBase());
        }
        SchemaTypeImpl schemaTypeImpl3 = (schemaTypeImpl2 == null || StscResolver.resolveType(schemaTypeImpl2)) ? schemaTypeImpl2 : null;
        ArrayList arrayList = new ArrayList();
        Group contentModel = getContentModel(complexRestrictionType);
        SchemaParticle translateContentModel = translateContentModel(schemaTypeImpl, contentModel, targetNamespace, z2, schemaTypeImpl.getElemFormDefault(), schemaTypeImpl.getAttFormDefault(), translateParticleCode(contentModel), arrayList, new LinkedHashMap(), false, null);
        boolean z3 = translateContentModel != null && translateContentModel.getParticleType() == 1;
        if (schemaTypeImpl3 == null) {
            schemaAttributeModelImpl = new SchemaAttributeModelImpl();
        } else {
            schemaAttributeModelImpl = new SchemaAttributeModelImpl(schemaTypeImpl3.getAttributeModel());
        }
        translateAttributeModel(complexRestrictionType, targetNamespace, z2, schemaTypeImpl.getAttFormDefault(), arrayList, schemaTypeImpl, null, schemaAttributeModelImpl, schemaTypeImpl3, false, null);
        WildcardResult summarizeEltWildcards = summarizeEltWildcards(translateContentModel);
        WildcardResult summarizeAttrWildcards = summarizeAttrWildcards(schemaAttributeModelImpl);
        if (translateContentModel != null) {
            buildStateMachine(translateContentModel);
            if (!StscState.get().noUpa() && !((SchemaParticleImpl) translateContentModel).isDeterministic()) {
                StscState.get().error(XmlErrorCodes.UNIQUE_PARTICLE_ATTRIBUTION, (Object[]) null, contentModel);
            }
        }
        Map buildContentPropertyModelByQName = buildContentPropertyModelByQName(translateContentModel, schemaTypeImpl);
        Map buildAttributePropertyModelByQName = buildAttributePropertyModelByQName(schemaAttributeModelImpl, schemaTypeImpl);
        int i2 = z ? 4 : translateContentModel == null ? 1 : 3;
        schemaTypeImpl.setBaseTypeRef(schemaTypeImpl3.getRef());
        schemaTypeImpl.setBaseDepth(schemaTypeImpl3.getBaseDepth() + 1);
        schemaTypeImpl.setDerivationType(1);
        schemaTypeImpl.setComplexTypeVariety(i2);
        schemaTypeImpl.setContentModel(translateContentModel, schemaAttributeModelImpl, buildContentPropertyModelByQName, buildAttributePropertyModelByQName, z3);
        schemaTypeImpl.setAnonymousTypeRefs(makeRefArray(arrayList));
        schemaTypeImpl.setWildcardSummary(summarizeEltWildcards.typedWildcards, summarizeEltWildcards.hasWildcards, summarizeAttrWildcards.typedWildcards, summarizeAttrWildcards.hasWildcards);
    }

    /* JADX WARNING: Code restructure failed: missing block: B:62:0x00d3, code lost:
        if (r1 != null) goto L_0x00d7;
     */
    /* JADX WARNING: Removed duplicated region for block: B:29:0x0072  */
    /* JADX WARNING: Removed duplicated region for block: B:30:0x0077  */
    /* JADX WARNING: Removed duplicated region for block: B:36:0x0087  */
    /* JADX WARNING: Removed duplicated region for block: B:50:0x00bb  */
    /* JADX WARNING: Removed duplicated region for block: B:51:0x00bd  */
    /* JADX WARNING: Removed duplicated region for block: B:53:0x00c0  */
    /* JADX WARNING: Removed duplicated region for block: B:54:0x00c2  */
    /* JADX WARNING: Removed duplicated region for block: B:57:0x00c6  */
    /* JADX WARNING: Removed duplicated region for block: B:60:0x00cc  */
    /* JADX WARNING: Removed duplicated region for block: B:66:0x00df  */
    /* JADX WARNING: Removed duplicated region for block: B:82:0x0124  */
    public static void resolveComplexType(SchemaTypeImpl schemaTypeImpl) {
        Object obj;
        boolean z;
        boolean z2;
        boolean z3;
        boolean z4;
        Object obj2;
        boolean z5;
        boolean z6;
        ComplexContentDocument.ComplexContent complexContent;
        Group contentModel;
        int i2;
        ComplexType complexType = (ComplexType) schemaTypeImpl.getParseObject();
        StscState stscState = StscState.get();
        SchemaDocument.Schema schema = getSchema(complexType);
        int i3 = 0;
        boolean z7 = complexType.isSetAbstract() ? complexType.getAbstract() : false;
        SimpleContentDocument.SimpleContent simpleContent = null;
        if (complexType.isSetFinal()) {
            obj = complexType.getFinal();
        } else {
            obj = (schema == null || !schema.isSetFinalDefault()) ? null : schema.getFinalDefault();
        }
        if (obj != null) {
            if ((obj instanceof String) && obj.equals(SchemaSymbols.ATTVAL_POUNDALL)) {
                z4 = true;
                z3 = true;
                z2 = true;
                z = true;
                schemaTypeImpl.setAbstractFinal(z7, z4, z3, z2, z);
                if (!complexType.isSetBlock()) {
                }
                if (obj2 != null) {
                }
                z6 = false;
                z5 = false;
                schemaTypeImpl.setBlock(z5, z6);
                complexContent = complexType.getComplexContent();
                SimpleContentDocument.SimpleContent simpleContent2 = complexType.getSimpleContent();
                contentModel = getContentModel(complexType);
                i2 = (complexContent == null ? 1 : 0) + (simpleContent2 == null ? 1 : 0);
                if (contentModel != null) {
                }
                if (i2 + i3 > 1) {
                }
                simpleContent = simpleContent2;
                if (complexContent == null) {
                }
            } else if (obj instanceof List) {
                List list = (List) obj;
                z4 = list.contains(SchemaSymbols.ATTVAL_EXTENSION);
                if (list.contains(SchemaSymbols.ATTVAL_RESTRICTION)) {
                    z3 = true;
                    z2 = false;
                    z = false;
                    schemaTypeImpl.setAbstractFinal(z7, z4, z3, z2, z);
                    if (!complexType.isSetBlock()) {
                        obj2 = complexType.getBlock();
                    } else {
                        obj2 = (schema == null || !schema.isSetBlockDefault()) ? null : schema.getBlockDefault();
                    }
                    if (obj2 != null) {
                        if ((obj2 instanceof String) && obj2.equals(SchemaSymbols.ATTVAL_POUNDALL)) {
                            z6 = true;
                            z5 = true;
                            schemaTypeImpl.setBlock(z5, z6);
                            complexContent = complexType.getComplexContent();
                            SimpleContentDocument.SimpleContent simpleContent22 = complexType.getSimpleContent();
                            contentModel = getContentModel(complexType);
                            i2 = (complexContent == null ? 1 : 0) + (simpleContent22 == null ? 1 : 0);
                            if (contentModel != null) {
                            }
                            if (i2 + i3 > 1) {
                            }
                            simpleContent = simpleContent22;
                            if (complexContent == null) {
                            }
                        } else if (obj2 instanceof List) {
                            List list2 = (List) obj2;
                            z5 = list2.contains(SchemaSymbols.ATTVAL_EXTENSION);
                            z6 = list2.contains(SchemaSymbols.ATTVAL_RESTRICTION);
                            schemaTypeImpl.setBlock(z5, z6);
                            complexContent = complexType.getComplexContent();
                            SimpleContentDocument.SimpleContent simpleContent222 = complexType.getSimpleContent();
                            contentModel = getContentModel(complexType);
                            i2 = (complexContent == null ? 1 : 0) + (simpleContent222 == null ? 1 : 0);
                            if (contentModel != null) {
                                i3 = 1;
                            }
                            if (i2 + i3 > 1) {
                                stscState.error("A complex type must define either a content model, or a simpleContent or complexContent derivation: more than one found.", 26, complexType);
                                if (complexContent != null) {
                                }
                            }
                            simpleContent = simpleContent222;
                            if (complexContent == null) {
                                if (!(complexContent.getExtension() == null || complexContent.getRestriction() == null)) {
                                    stscState.error("Restriction conflicts with extension", 26, complexContent.getRestriction());
                                }
                                boolean mixed = complexContent.isSetMixed() ? complexContent.getMixed() : complexType.getMixed();
                                if (complexContent.getExtension() != null) {
                                    resolveCcExtension(schemaTypeImpl, complexContent.getExtension(), mixed);
                                    return;
                                } else if (complexContent.getRestriction() != null) {
                                    resolveCcRestriction(schemaTypeImpl, complexContent.getRestriction(), mixed);
                                    return;
                                } else {
                                    stscState.error("Missing restriction or extension", 27, complexContent);
                                    resolveErrorType(schemaTypeImpl);
                                    return;
                                }
                            } else if (simpleContent != null) {
                                if (!(simpleContent.getExtension() == null || simpleContent.getRestriction() == null)) {
                                    stscState.error("Restriction conflicts with extension", 26, simpleContent.getRestriction());
                                }
                                if (simpleContent.getExtension() != null) {
                                    resolveScExtension(schemaTypeImpl, simpleContent.getExtension());
                                    return;
                                } else if (simpleContent.getRestriction() != null) {
                                    resolveScRestriction(schemaTypeImpl, simpleContent.getRestriction());
                                    return;
                                } else {
                                    stscState.error("Missing restriction or extension", 27, simpleContent);
                                    resolveErrorType(schemaTypeImpl);
                                    return;
                                }
                            } else {
                                resolveBasicComplexType(schemaTypeImpl);
                                return;
                            }
                        }
                    }
                    z6 = false;
                    z5 = false;
                    schemaTypeImpl.setBlock(z5, z6);
                    complexContent = complexType.getComplexContent();
                    SimpleContentDocument.SimpleContent simpleContent2222 = complexType.getSimpleContent();
                    contentModel = getContentModel(complexType);
                    i2 = (complexContent == null ? 1 : 0) + (simpleContent2222 == null ? 1 : 0);
                    if (contentModel != null) {
                    }
                    if (i2 + i3 > 1) {
                    }
                    simpleContent = simpleContent2222;
                    if (complexContent == null) {
                    }
                }
                z3 = false;
                z2 = false;
                z = false;
                schemaTypeImpl.setAbstractFinal(z7, z4, z3, z2, z);
                if (!complexType.isSetBlock()) {
                }
                if (obj2 != null) {
                }
                z6 = false;
                z5 = false;
                schemaTypeImpl.setBlock(z5, z6);
                complexContent = complexType.getComplexContent();
                SimpleContentDocument.SimpleContent simpleContent22222 = complexType.getSimpleContent();
                contentModel = getContentModel(complexType);
                i2 = (complexContent == null ? 1 : 0) + (simpleContent22222 == null ? 1 : 0);
                if (contentModel != null) {
                }
                if (i2 + i3 > 1) {
                }
                simpleContent = simpleContent22222;
                if (complexContent == null) {
                }
            }
        }
        z4 = false;
        z3 = false;
        z2 = false;
        z = false;
        schemaTypeImpl.setAbstractFinal(z7, z4, z3, z2, z);
        if (!complexType.isSetBlock()) {
        }
        if (obj2 != null) {
        }
        z6 = false;
        z5 = false;
        schemaTypeImpl.setBlock(z5, z6);
        complexContent = complexType.getComplexContent();
        SimpleContentDocument.SimpleContent simpleContent222222 = complexType.getSimpleContent();
        contentModel = getContentModel(complexType);
        i2 = (complexContent == null ? 1 : 0) + (simpleContent222222 == null ? 1 : 0);
        if (contentModel != null) {
        }
        if (i2 + i3 > 1) {
        }
        simpleContent = simpleContent222222;
        if (complexContent == null) {
        }
    }

    public static void resolveErrorType(SchemaTypeImpl schemaTypeImpl) {
        throw new RuntimeException("This type of error recovery not yet implemented.");
    }

    public static void resolveScExtension(SchemaTypeImpl schemaTypeImpl, SimpleExtensionType simpleExtensionType) {
        SchemaTypeImpl schemaTypeImpl2;
        StscState stscState = StscState.get();
        String targetNamespace = schemaTypeImpl.getTargetNamespace();
        boolean z = schemaTypeImpl.getChameleonNamespace() != null;
        if (simpleExtensionType.getBase() == null) {
            stscState.error("A simpleContent extension must define a base type", 28, simpleExtensionType);
            schemaTypeImpl2 = BuiltinSchemaTypeSystem.ST_ANY_SIMPLE;
        } else {
            if (schemaTypeImpl.isRedefinition()) {
                schemaTypeImpl2 = stscState.findRedefinedGlobalType(simpleExtensionType.getBase(), schemaTypeImpl.getChameleonNamespace(), schemaTypeImpl);
                if (schemaTypeImpl2 != null && !schemaTypeImpl2.getName().equals(schemaTypeImpl.getName())) {
                    stscState.error(XmlErrorCodes.SCHEMA_REDEFINE$SAME_TYPE, new Object[]{"<simpleType>", QNameHelper.pretty(schemaTypeImpl2.getName()), QNameHelper.pretty(schemaTypeImpl.getName())}, simpleExtensionType);
                }
            } else {
                schemaTypeImpl2 = stscState.findGlobalType(simpleExtensionType.getBase(), schemaTypeImpl.getChameleonNamespace(), targetNamespace);
            }
            if (schemaTypeImpl2 == null) {
                stscState.notFoundError(simpleExtensionType.getBase(), 0, simpleExtensionType.xgetBase(), true);
                schemaTypeImpl2 = BuiltinSchemaTypeSystem.ST_ANY_SIMPLE;
            }
        }
        StscResolver.resolveType(schemaTypeImpl2);
        if (!schemaTypeImpl2.isSimpleType() && schemaTypeImpl2.getContentType() != 2) {
            stscState.error(XmlErrorCodes.SCHEMA_COMPLEX_TYPE$SIMPLE_CONTENT, new Object[]{QNameHelper.pretty(schemaTypeImpl2.getName())}, simpleExtensionType);
            schemaTypeImpl2 = BuiltinSchemaTypeSystem.ST_ANY_SIMPLE;
        }
        if (schemaTypeImpl2 != null && schemaTypeImpl2.finalExtension()) {
            stscState.error(XmlErrorCodes.COMPLEX_TYPE_EXTENSION$FINAL, new Object[]{QNameHelper.pretty(schemaTypeImpl2.getName()), QNameHelper.pretty(schemaTypeImpl.getName())}, simpleExtensionType.xgetBase());
        }
        resolveScExtensionPart2(schemaTypeImpl, schemaTypeImpl2, simpleExtensionType, targetNamespace, z);
    }

    public static void resolveScExtensionPart2(SchemaTypeImpl schemaTypeImpl, SchemaType schemaType, ExtensionType extensionType, String str, boolean z) {
        ArrayList arrayList = new ArrayList();
        SchemaAttributeModelImpl schemaAttributeModelImpl = new SchemaAttributeModelImpl(schemaType.getAttributeModel());
        translateAttributeModel(extensionType, str, z, schemaTypeImpl.getAttFormDefault(), arrayList, schemaTypeImpl, null, schemaAttributeModelImpl, schemaType, true, null);
        WildcardResult summarizeAttrWildcards = summarizeAttrWildcards(schemaAttributeModelImpl);
        Map buildAttributePropertyModelByQName = buildAttributePropertyModelByQName(schemaAttributeModelImpl, schemaTypeImpl);
        schemaTypeImpl.setBaseTypeRef(schemaType.getRef());
        SchemaTypeImpl schemaTypeImpl2 = (SchemaTypeImpl) schemaType;
        schemaTypeImpl.setBaseDepth(schemaTypeImpl2.getBaseDepth() + 1);
        schemaTypeImpl.setContentBasedOnTypeRef(schemaType.getRef());
        schemaTypeImpl.setDerivationType(2);
        schemaTypeImpl.setAnonymousTypeRefs(makeRefArray(arrayList));
        schemaTypeImpl.setWildcardSummary(QNameSet.EMPTY, false, summarizeAttrWildcards.typedWildcards, summarizeAttrWildcards.hasWildcards);
        schemaTypeImpl.setComplexTypeVariety(2);
        schemaTypeImpl.setContentModel(null, schemaAttributeModelImpl, null, buildAttributePropertyModelByQName, false);
        schemaTypeImpl.setSimpleTypeVariety(schemaType.getSimpleVariety());
        schemaTypeImpl.setPrimitiveTypeRef(schemaType.getPrimitiveType() == null ? null : schemaType.getPrimitiveType().getRef());
        int simpleVariety = schemaTypeImpl.getSimpleVariety();
        if (simpleVariety == 2) {
            schemaTypeImpl.setUnionMemberTypeRefs(makeRefArray(Arrays.asList(schemaType.getUnionMemberTypes())));
        } else if (simpleVariety == 3) {
            schemaTypeImpl.setListItemTypeRef(schemaType.getListItemType().getRef());
        }
        StscSimpleTypeResolver.resolveFacets(schemaTypeImpl, null, schemaTypeImpl2);
        StscSimpleTypeResolver.resolveFundamentalFacets(schemaTypeImpl);
    }

    public static void resolveScRestriction(SchemaTypeImpl schemaTypeImpl, SimpleRestrictionType simpleRestrictionType) {
        SchemaTypeImpl schemaTypeImpl2;
        SchemaTypeImpl schemaTypeImpl3;
        SchemaAttributeModelImpl schemaAttributeModelImpl;
        StscState stscState = StscState.get();
        String targetNamespace = schemaTypeImpl.getTargetNamespace();
        boolean z = schemaTypeImpl.getChameleonNamespace() != null;
        ArrayList arrayList = new ArrayList();
        SchemaType.Ref ref = null;
        SchemaTypeImpl translateAnonymousSimpleType = simpleRestrictionType.getSimpleType() != null ? StscTranslator.translateAnonymousSimpleType(simpleRestrictionType.getSimpleType(), targetNamespace, z, schemaTypeImpl.getElemFormDefault(), schemaTypeImpl.getAttFormDefault(), arrayList, schemaTypeImpl) : null;
        if (simpleRestrictionType.getBase() == null) {
            stscState.error("A simpleContent restriction must define a base type", 28, simpleRestrictionType);
            schemaTypeImpl2 = BuiltinSchemaTypeSystem.ST_ANY_SIMPLE;
        } else {
            if (schemaTypeImpl.isRedefinition()) {
                schemaTypeImpl2 = stscState.findRedefinedGlobalType(simpleRestrictionType.getBase(), schemaTypeImpl.getChameleonNamespace(), schemaTypeImpl);
                if (schemaTypeImpl2 != null && !schemaTypeImpl2.getName().equals(schemaTypeImpl.getName())) {
                    stscState.error(XmlErrorCodes.SCHEMA_REDEFINE$SAME_TYPE, new Object[]{"<simpleType>", QNameHelper.pretty(schemaTypeImpl2.getName()), QNameHelper.pretty(schemaTypeImpl.getName())}, simpleRestrictionType);
                }
            } else {
                schemaTypeImpl2 = stscState.findGlobalType(simpleRestrictionType.getBase(), schemaTypeImpl.getChameleonNamespace(), targetNamespace);
            }
            if (schemaTypeImpl2 == null) {
                stscState.notFoundError(simpleRestrictionType.getBase(), 0, simpleRestrictionType.xgetBase(), true);
                schemaTypeImpl2 = BuiltinSchemaTypeSystem.ST_ANY_SIMPLE;
            }
        }
        StscResolver.resolveType(schemaTypeImpl2);
        if (translateAnonymousSimpleType != null) {
            StscResolver.resolveType(translateAnonymousSimpleType);
            schemaTypeImpl3 = translateAnonymousSimpleType;
        } else {
            schemaTypeImpl3 = schemaTypeImpl2;
        }
        if (schemaTypeImpl2.isSimpleType()) {
            stscState.recover(XmlErrorCodes.COMPLEX_TYPE_PROPERTIES$SIMPLE_TYPE_EXTENSION, new Object[]{QNameHelper.pretty(schemaTypeImpl2.getName())}, simpleRestrictionType);
            schemaTypeImpl2 = BuiltinSchemaTypeSystem.ST_ANY_SIMPLE;
        } else if (schemaTypeImpl2.getContentType() != 2 && schemaTypeImpl3 == null) {
            schemaTypeImpl2 = BuiltinSchemaTypeSystem.ST_ANY_SIMPLE;
        }
        if (schemaTypeImpl2 != null && schemaTypeImpl2.finalRestriction()) {
            stscState.error(XmlErrorCodes.COMPLEX_TYPE_RESTRICTION$FINAL, new Object[]{QNameHelper.pretty(schemaTypeImpl2.getName()), QNameHelper.pretty(schemaTypeImpl.getName())}, simpleRestrictionType.xgetBase());
        }
        if (schemaTypeImpl2 == null) {
            schemaAttributeModelImpl = new SchemaAttributeModelImpl();
        } else {
            schemaAttributeModelImpl = new SchemaAttributeModelImpl(schemaTypeImpl2.getAttributeModel());
        }
        translateAttributeModel(simpleRestrictionType, targetNamespace, z, schemaTypeImpl.getAttFormDefault(), arrayList, schemaTypeImpl, null, schemaAttributeModelImpl, schemaTypeImpl2, false, null);
        WildcardResult summarizeAttrWildcards = summarizeAttrWildcards(schemaAttributeModelImpl);
        Map buildAttributePropertyModelByQName = buildAttributePropertyModelByQName(schemaAttributeModelImpl, schemaTypeImpl);
        schemaTypeImpl.setBaseTypeRef(schemaTypeImpl2.getRef());
        schemaTypeImpl.setBaseDepth(schemaTypeImpl2.getBaseDepth() + 1);
        schemaTypeImpl.setContentBasedOnTypeRef(schemaTypeImpl3.getRef());
        schemaTypeImpl.setDerivationType(1);
        schemaTypeImpl.setAnonymousTypeRefs(makeRefArray(arrayList));
        schemaTypeImpl.setWildcardSummary(QNameSet.EMPTY, false, summarizeAttrWildcards.typedWildcards, summarizeAttrWildcards.hasWildcards);
        schemaTypeImpl.setComplexTypeVariety(2);
        schemaTypeImpl.setContentModel(null, schemaAttributeModelImpl, null, buildAttributePropertyModelByQName, false);
        schemaTypeImpl.setSimpleTypeVariety(schemaTypeImpl3.getSimpleVariety());
        if (schemaTypeImpl3.getPrimitiveType() != null) {
            ref = schemaTypeImpl3.getPrimitiveType().getRef();
        }
        schemaTypeImpl.setPrimitiveTypeRef(ref);
        int simpleVariety = schemaTypeImpl.getSimpleVariety();
        if (simpleVariety == 2) {
            schemaTypeImpl.setUnionMemberTypeRefs(makeRefArray(Arrays.asList(schemaTypeImpl3.getUnionMemberTypes())));
        } else if (simpleVariety == 3) {
            schemaTypeImpl.setListItemTypeRef(schemaTypeImpl3.getListItemType().getRef());
        }
        StscSimpleTypeResolver.resolveFacets(schemaTypeImpl, simpleRestrictionType, schemaTypeImpl3);
        StscSimpleTypeResolver.resolveFundamentalFacets(schemaTypeImpl);
    }

    public static WildcardResult summarizeAttrWildcards(SchemaAttributeModel schemaAttributeModel) {
        if (schemaAttributeModel.getWildcardProcess() == 0) {
            return new WildcardResult(QNameSet.EMPTY, false);
        }
        if (schemaAttributeModel.getWildcardProcess() == 3) {
            return new WildcardResult(QNameSet.EMPTY, true);
        }
        return new WildcardResult(schemaAttributeModel.getWildcardSet(), true);
    }

    public static WildcardResult summarizeEltWildcards(SchemaParticle schemaParticle) {
        if (schemaParticle == null) {
            return new WildcardResult(QNameSet.EMPTY, false);
        }
        int particleType = schemaParticle.getParticleType();
        if (particleType == 1 || particleType == 2 || particleType == 3) {
            QNameSetBuilder qNameSetBuilder = new QNameSetBuilder();
            boolean z = false;
            for (int i2 = 0; i2 < schemaParticle.countOfParticleChild(); i2++) {
                WildcardResult summarizeEltWildcards = summarizeEltWildcards(schemaParticle.getParticleChild(i2));
                qNameSetBuilder.addAll(summarizeEltWildcards.typedWildcards);
                z |= summarizeEltWildcards.hasWildcards;
            }
            return new WildcardResult(qNameSetBuilder.toQNameSet(), z);
        } else if (particleType != 5) {
            return new WildcardResult(QNameSet.EMPTY, false);
        } else {
            return new WildcardResult(schemaParticle.getWildcardProcess() == 3 ? QNameSet.EMPTY : schemaParticle.getWildcardSet(), true);
        }
    }

    public static int translateAttributeCode(QName qName) {
        Integer num = (Integer) attributeCodeMap.get(qName);
        if (num == null) {
            return 0;
        }
        return num.intValue();
    }

    /* JADX DEBUG: Failed to insert an additional move for type inference into block B:129:0x02ae */
    /* JADX DEBUG: Multi-variable search result rejected for r2v0, resolved type: java.lang.Object[] */
    /* JADX DEBUG: Multi-variable search result rejected for r2v1, resolved type: java.lang.Object[] */
    /* JADX DEBUG: Multi-variable search result rejected for r2v2, resolved type: java.lang.Object[] */
    /* JADX WARN: Multi-variable type inference failed */
    /* JADX INFO: Can't fix incorrect switch cases order, some code will duplicate */
    /* JADX WARNING: Removed duplicated region for block: B:106:0x0274  */
    /* JADX WARNING: Removed duplicated region for block: B:107:0x027a  */
    /* JADX WARNING: Removed duplicated region for block: B:56:0x0112  */
    /* JADX WARNING: Removed duplicated region for block: B:57:0x011b  */
    public static void translateAttributeModel(XmlObject xmlObject, String str, boolean z, String str2, List list, SchemaType schemaType, Set set, SchemaAttributeModelImpl schemaAttributeModelImpl, SchemaType schemaType2, boolean z2, SchemaAttributeGroupImpl schemaAttributeGroupImpl) {
        Set set2;
        SchemaAttributeModel schemaAttributeModel;
        List list2;
        SchemaAttributeModelImpl schemaAttributeModelImpl2;
        SchemaAttributeGroupImpl schemaAttributeGroupImpl2;
        boolean z3;
        String str3;
        SchemaAttributeGroupImpl schemaAttributeGroupImpl3;
        String str4;
        List list3 = list;
        SchemaAttributeModelImpl schemaAttributeModelImpl3 = schemaAttributeModelImpl;
        SchemaAttributeGroupImpl schemaAttributeGroupImpl4 = schemaAttributeGroupImpl;
        StscState stscState = StscState.get();
        HashSet hashSet = set == null ? new HashSet() : set;
        Object[] objArr = 0;
        SchemaAttributeModel attributeModel = schemaType2 != null ? schemaType2.getAttributeModel() : null;
        XmlCursor newCursor = xmlObject.newCursor();
        boolean firstChild = newCursor.toFirstChild();
        char c = 0;
        boolean z4 = z;
        boolean z5 = false;
        boolean z6 = false;
        StscState stscState2 = stscState;
        while (firstChild) {
            switch (translateAttributeCode(newCursor.getName())) {
                case 100:
                    Attribute attribute = (Attribute) newCursor.getObject();
                    schemaAttributeModel = attributeModel;
                    set2 = hashSet;
                    SchemaLocalAttributeImpl translateAttribute = StscTranslator.translateAttribute(attribute, str, str2, z4, list, schemaType, schemaAttributeModel, true);
                    if (translateAttribute == null) {
                        list2 = list;
                        schemaAttributeModelImpl2 = schemaAttributeModelImpl;
                        stscState2 = stscState2;
                        break;
                    } else {
                        if (set2.contains(translateAttribute.getName())) {
                            stscState2 = stscState2;
                            stscState2.error(XmlErrorCodes.COMPLEX_TYPE_PROPERTIES$DUPLICATE_ATTRIBUTE, new Object[]{QNameHelper.pretty(translateAttribute.getName()), QNameHelper.pretty(schemaType.getName())}, attribute.xgetName());
                            list2 = list;
                            schemaAttributeModelImpl2 = schemaAttributeModelImpl;
                        } else {
                            stscState2 = stscState2;
                            set2.add(translateAttribute.getName());
                            if (schemaAttributeModel != null) {
                                SchemaLocalAttribute attribute2 = schemaAttributeModel.getAttribute(translateAttribute.getName());
                                if (attribute2 == null) {
                                    if (!z2 && !schemaAttributeModel.getWildcardSet().contains(translateAttribute.getName())) {
                                        stscState2.error(XmlErrorCodes.COMPLEX_TYPE_RESTRICTION$ATTR_IN_BASE_WILDCARD_SET, new Object[]{QNameHelper.pretty(translateAttribute.getName()), QNameHelper.pretty(schemaType.getName())}, attribute);
                                    }
                                } else if (z2) {
                                    if (translateAttribute.getUse() == 1) {
                                        stscState2.error("An extension cannot prohibit an attribute from the base type; use restriction instead.", 37, attribute.xgetUse());
                                    }
                                } else if (translateAttribute.getUse() != 3) {
                                    if (attribute2.getUse() == 3) {
                                        stscState2.error(XmlErrorCodes.COMPLEX_TYPE_RESTRICTION$ATTR_REQUIRED, new Object[]{QNameHelper.pretty(translateAttribute.getName()), QNameHelper.pretty(schemaType.getName())}, attribute);
                                    }
                                    if (translateAttribute.getUse() == 1) {
                                        schemaAttributeModelImpl2 = schemaAttributeModelImpl;
                                        schemaAttributeModelImpl2.removeProhibitedAttribute(translateAttribute.getName());
                                        if (translateAttribute.getUse() == 1) {
                                            schemaAttributeModelImpl2.addAttribute(translateAttribute);
                                            list2 = list;
                                        } else {
                                            SchemaType type = translateAttribute.getType();
                                            list2 = list;
                                            if (list2 != null && list2.contains(type)) {
                                                list2.remove(type);
                                            }
                                        }
                                        if (!(translateAttribute.getDefaultText() == null || translateAttribute.isFixed() || translateAttribute.getUse() == 2)) {
                                            stscState2.error(XmlErrorCodes.SCHEMA_ATTR$DEFAULT_AND_USE_OPTIONAL, new Object[]{QNameHelper.pretty(translateAttribute.getName())}, attribute);
                                            continue;
                                        }
                                    }
                                }
                            }
                            schemaAttributeModelImpl2 = schemaAttributeModelImpl;
                            if (translateAttribute.getUse() == 1) {
                            }
                            stscState2.error(XmlErrorCodes.SCHEMA_ATTR$DEFAULT_AND_USE_OPTIONAL, new Object[]{QNameHelper.pretty(translateAttribute.getName())}, attribute);
                            continue;
                        }
                        firstChild = newCursor.toNextSibling();
                        list3 = list2;
                        attributeModel = schemaAttributeModel;
                        hashSet = set2;
                        objArr = 0;
                        c = 0;
                        schemaAttributeModelImpl3 = schemaAttributeModelImpl2;
                        schemaAttributeGroupImpl4 = schemaAttributeGroupImpl;
                        stscState2 = stscState2;
                    }
                case 101:
                    AttributeGroupRef attributeGroupRef = (AttributeGroupRef) newCursor.getObject();
                    QName ref = attributeGroupRef.getRef();
                    if (ref == null) {
                        stscState2.error("Attribute group reference must have a ref attribute", 39, attributeGroupRef);
                        schemaAttributeModel = attributeModel;
                        set2 = hashSet;
                        schemaAttributeModelImpl2 = schemaAttributeModelImpl3;
                        list2 = list3;
                        stscState2 = stscState2;
                        break;
                    } else {
                        if (schemaAttributeGroupImpl4 != null) {
                            schemaAttributeGroupImpl3 = stscState2.findRedefinedAttributeGroup(ref, z4 ? str : objArr, schemaAttributeGroupImpl4);
                            if (schemaAttributeGroupImpl3 != null && schemaAttributeGroupImpl.getName().equals(schemaAttributeGroupImpl3.getName())) {
                                if (z5) {
                                    Object[] objArr2 = new Object[1];
                                    objArr2[c] = QNameHelper.pretty(schemaAttributeGroupImpl.getName());
                                    stscState2.error(XmlErrorCodes.SCHEMA_REDEFINE$ATTR_GROUP_SELF_REF, objArr2, attributeGroupRef);
                                }
                                schemaAttributeGroupImpl2 = schemaAttributeGroupImpl3;
                                z3 = true;
                                if (schemaAttributeGroupImpl2 != null) {
                                    stscState2.notFoundError(ref, 4, attributeGroupRef.xgetRef(), true);
                                } else if (stscState2.isProcessing(schemaAttributeGroupImpl2)) {
                                    Object[] objArr3 = new Object[1];
                                    objArr3[c] = QNameHelper.pretty(schemaAttributeGroupImpl2.getName());
                                    stscState2.error(XmlErrorCodes.SCHEMA_ATTR_GROUP$SELF_REF, objArr3, schemaAttributeGroupImpl2.getParseObject());
                                } else {
                                    if (schemaAttributeGroupImpl2.getTargetNamespace() != null) {
                                        String targetNamespace = schemaAttributeGroupImpl2.getTargetNamespace();
                                        z4 = schemaAttributeGroupImpl2.getChameleonNamespace() != null;
                                        str3 = targetNamespace;
                                    } else {
                                        str3 = str;
                                    }
                                    stscState2.startProcessing(schemaAttributeGroupImpl2);
                                    set2 = hashSet;
                                    translateAttributeModel(schemaAttributeGroupImpl2.getParseObject(), str3, z4, schemaAttributeGroupImpl2.getFormDefault(), list, schemaType, set2, schemaAttributeModelImpl, schemaType2, z2, schemaAttributeGroupImpl2.isRedefinition() ? schemaAttributeGroupImpl2 : null);
                                    stscState2.finishProcessing(schemaAttributeGroupImpl2);
                                    z4 = z4;
                                    schemaAttributeModel = attributeModel;
                                    z5 = z3;
                                    schemaAttributeModelImpl2 = schemaAttributeModelImpl3;
                                    list2 = list3;
                                    stscState2 = stscState2;
                                }
                                schemaAttributeModel = attributeModel;
                                z5 = z3;
                                set2 = hashSet;
                                schemaAttributeModelImpl2 = schemaAttributeModelImpl3;
                                list2 = list3;
                                stscState2 = stscState2;
                            }
                        } else {
                            schemaAttributeGroupImpl3 = stscState2.findAttributeGroup(ref, z4 ? str : null, str);
                        }
                        z3 = z5;
                        schemaAttributeGroupImpl2 = schemaAttributeGroupImpl3;
                        if (schemaAttributeGroupImpl2 != null) {
                        }
                        schemaAttributeModel = attributeModel;
                        z5 = z3;
                        set2 = hashSet;
                        schemaAttributeModelImpl2 = schemaAttributeModelImpl3;
                        list2 = list3;
                        stscState2 = stscState2;
                    }
                case 102:
                    Wildcard wildcard = (Wildcard) newCursor.getObject();
                    if (z6) {
                        stscState2.error("Only one attribute wildcard allowed", 38, wildcard);
                        schemaAttributeModel = attributeModel;
                        set2 = hashSet;
                        schemaAttributeModelImpl2 = schemaAttributeModelImpl3;
                        list2 = list3;
                        stscState2 = stscState2;
                        break;
                    } else {
                        NamespaceList xgetNamespace = wildcard.xgetNamespace();
                        if (xgetNamespace == null) {
                            str4 = SchemaSymbols.ATTVAL_TWOPOUNDANY;
                        } else {
                            str4 = xgetNamespace.getStringValue();
                        }
                        QNameSet forWildcardNamespaceString = QNameSet.forWildcardNamespaceString(str4, str);
                        if (attributeModel != null && !z2) {
                            if (attributeModel.getWildcardSet() == null) {
                                stscState2.error(XmlErrorCodes.COMPLEX_TYPE_RESTRICTION$BASE_HAS_ATTR_WILDCARD, objArr, wildcard);
                            } else if (!attributeModel.getWildcardSet().containsAll(forWildcardNamespaceString)) {
                                Object[] objArr4 = new Object[1];
                                objArr4[c] = str4;
                                stscState2.error(XmlErrorCodes.COMPLEX_TYPE_RESTRICTION$ATTR_WILDCARD_SUBSET, objArr4, wildcard);
                            }
                            schemaAttributeModel = attributeModel;
                            set2 = hashSet;
                            schemaAttributeModelImpl2 = schemaAttributeModelImpl3;
                            list2 = list3;
                            z6 = true;
                            continue;
                            firstChild = newCursor.toNextSibling();
                            list3 = list2;
                            attributeModel = schemaAttributeModel;
                            hashSet = set2;
                            objArr = 0;
                            c = 0;
                            schemaAttributeModelImpl3 = schemaAttributeModelImpl2;
                            schemaAttributeGroupImpl4 = schemaAttributeGroupImpl;
                            stscState2 = stscState2;
                        }
                        int translateWildcardProcess = translateWildcardProcess(wildcard.xgetProcessContents());
                        if (schemaAttributeModelImpl.getWildcardProcess() == 0) {
                            schemaAttributeModelImpl3.setWildcardSet(forWildcardNamespaceString);
                            schemaAttributeModelImpl3.setWildcardProcess(translateWildcardProcess);
                        } else if (z2) {
                            schemaAttributeModelImpl3.setWildcardSet(forWildcardNamespaceString.union(schemaAttributeModelImpl.getWildcardSet()));
                            schemaAttributeModelImpl3.setWildcardProcess(translateWildcardProcess);
                        } else {
                            schemaAttributeModelImpl3.setWildcardSet(forWildcardNamespaceString.intersect(schemaAttributeModelImpl.getWildcardSet()));
                        }
                        schemaAttributeModel = attributeModel;
                        set2 = hashSet;
                        schemaAttributeModelImpl2 = schemaAttributeModelImpl3;
                        list2 = list3;
                        z6 = true;
                        continue;
                        firstChild = newCursor.toNextSibling();
                        list3 = list2;
                        attributeModel = schemaAttributeModel;
                        hashSet = set2;
                        objArr = 0;
                        c = 0;
                        schemaAttributeModelImpl3 = schemaAttributeModelImpl2;
                        schemaAttributeGroupImpl4 = schemaAttributeGroupImpl;
                        stscState2 = stscState2;
                    }
                default:
                    schemaAttributeModel = attributeModel;
                    set2 = hashSet;
                    schemaAttributeModelImpl2 = schemaAttributeModelImpl3;
                    list2 = list3;
                    stscState2 = stscState2;
                    break;
            }
            firstChild = newCursor.toNextSibling();
            list3 = list2;
            attributeModel = schemaAttributeModel;
            hashSet = set2;
            objArr = 0;
            c = 0;
            schemaAttributeModelImpl3 = schemaAttributeModelImpl2;
            schemaAttributeGroupImpl4 = schemaAttributeGroupImpl;
            stscState2 = stscState2;
        }
        if (!z2 && !z6) {
            schemaAttributeModelImpl3.setWildcardSet(null);
            schemaAttributeModelImpl3.setWildcardProcess(0);
        }
    }

    /* JADX DEBUG: Multi-variable search result rejected for r12v0, resolved type: org.apache.xmlbeans.impl.schema.StscState */
    /* JADX WARN: Multi-variable type inference failed */
    /* JADX WARN: Type inference failed for: r1v1, types: [org.apache.xmlbeans.SchemaParticle, java.lang.Object[]] */
    /* JADX WARN: Type inference failed for: r1v4 */
    /* JADX WARN: Type inference failed for: r1v5 */
    /* JADX WARNING: Unknown variable types count: 1 */
    public static SchemaParticle translateContentModel(SchemaType schemaType, XmlObject xmlObject, String str, boolean z, String str2, String str3, int i2, List list, Map map, boolean z2, RedefinitionForGroup redefinitionForGroup) {
        String str4;
        String str5;
        boolean z3;
        String str6;
        XmlObject xmlObject2;
        SchemaLocalElementImpl schemaLocalElementImpl;
        SchemaModelGroupImpl schemaModelGroupImpl;
        boolean z4;
        BigInteger bigInteger;
        BigInteger bigInteger2;
        ?? r1;
        RedefinitionForGroup redefinitionForGroup2;
        SchemaModelGroupImpl schemaModelGroupImpl2;
        SchemaParticleImpl schemaParticleImpl;
        SchemaParticleImpl schemaParticleImpl2;
        String str7;
        ArrayList arrayList;
        SchemaModelGroupImpl schemaModelGroupImpl3;
        boolean z5;
        SchemaModelGroupImpl schemaModelGroupImpl4;
        String str8;
        String str9;
        QNameSet qNameSet;
        XmlObject xmlObject3 = xmlObject;
        String str10 = str;
        int i3 = i2;
        String str11 = null;
        if (xmlObject3 == null || i3 == 0) {
            return null;
        }
        StscState stscState = StscState.get();
        if ($assertionsDisabled || i3 != 0) {
            if (i3 == 4) {
                if (!z2) {
                    stscState.error("Must be a sequence, choice or all here", 32, xmlObject3);
                }
                LocalElement localElement = (LocalElement) xmlObject3;
                SchemaLocalElementImpl translateElement = StscTranslator.translateElement(localElement, str, z, str2, str3, list, schemaType);
                if (translateElement == null) {
                    return null;
                }
                bigInteger2 = extractMinOccurs(localElement.xgetMinOccurs());
                bigInteger = extractMaxOccurs(localElement.xgetMaxOccurs());
                SchemaType schemaType2 = (SchemaType) map.get(translateElement.getName());
                if (schemaType2 == null) {
                    map.put(translateElement.getName(), translateElement.getType());
                } else if (!translateElement.getType().equals(schemaType2)) {
                    stscState.error(XmlErrorCodes.ELEM_CONSISTANT, new Object[]{QNameHelper.pretty(translateElement.getName())}, xmlObject3);
                    return null;
                }
                z4 = false;
                z3 = z;
                str5 = str2;
                str4 = str3;
                xmlObject2 = xmlObject3;
                str6 = str10;
                schemaModelGroupImpl = null;
                schemaLocalElementImpl = translateElement;
            } else if (i3 == 5) {
                if (!z2) {
                    stscState.error("Must be a sequence, choice or all here", 32, xmlObject3);
                }
                AnyDocument.Any any = (AnyDocument.Any) xmlObject3;
                SchemaParticleImpl schemaParticleImpl3 = new SchemaParticleImpl();
                schemaParticleImpl3.setParticleType(5);
                NamespaceList xgetNamespace = any.xgetNamespace();
                if (xgetNamespace == null) {
                    qNameSet = QNameSet.ALL;
                } else {
                    qNameSet = QNameSet.forWildcardNamespaceString(xgetNamespace.getStringValue(), str10);
                }
                schemaParticleImpl3.setWildcardSet(qNameSet);
                schemaParticleImpl3.setWildcardProcess(translateWildcardProcess(any.xgetProcessContents()));
                bigInteger2 = extractMinOccurs(any.xgetMinOccurs());
                z4 = false;
                z3 = z;
                str5 = str2;
                str4 = str3;
                xmlObject2 = xmlObject3;
                str6 = str10;
                schemaModelGroupImpl = null;
                schemaLocalElementImpl = schemaParticleImpl3;
                bigInteger = extractMaxOccurs(any.xgetMaxOccurs());
            } else {
                Group group = (Group) xmlObject3;
                SchemaParticleImpl schemaParticleImpl4 = new SchemaParticleImpl();
                BigInteger extractMinOccurs = extractMinOccurs(group.xgetMinOccurs());
                BigInteger extractMaxOccurs = extractMaxOccurs(group.xgetMaxOccurs());
                if (i3 == 100) {
                    QName ref = group.getRef();
                    if (ref == null) {
                        stscState.error("Group reference must have a ref attribute", 33, xmlObject3);
                        return null;
                    }
                    if (redefinitionForGroup != null) {
                        if (z) {
                            str11 = str10;
                        }
                        schemaModelGroupImpl4 = stscState.findRedefinedModelGroup(ref, str11, redefinitionForGroup.getGroup());
                        if (schemaModelGroupImpl4 != null && schemaModelGroupImpl4.getName().equals(redefinitionForGroup.getGroup().getName())) {
                            if (redefinitionForGroup.isSeenRedefinition()) {
                                stscState.error(XmlErrorCodes.SCHEMA_REDEFINE$GROUP_SELF_REF, new Object[]{QNameHelper.pretty(schemaModelGroupImpl4.getName())}, xmlObject3);
                            }
                            if (!BigInteger.ONE.equals(extractMaxOccurs) || !BigInteger.ONE.equals(extractMinOccurs)) {
                                stscState.error(XmlErrorCodes.SCHEMA_REDEFINE$GROUP_SELF_REF_MIN_MAX_1, new Object[]{QNameHelper.pretty(schemaModelGroupImpl4.getName())}, xmlObject3);
                            }
                            redefinitionForGroup.setSeenRedefinition(true);
                        }
                    } else {
                        schemaModelGroupImpl4 = stscState.findModelGroup(ref, z ? str10 : null, str10);
                    }
                    if (schemaModelGroupImpl4 == null) {
                        stscState.notFoundError(ref, 6, group.xgetRef(), true);
                        return null;
                    } else if (stscState.isProcessing(schemaModelGroupImpl4)) {
                        stscState.error(XmlErrorCodes.MODEL_GROUP_PROPERTIES$CIRCULAR, new Object[]{QNameHelper.pretty(schemaModelGroupImpl4.getName())}, schemaModelGroupImpl4.getParseObject());
                        return null;
                    } else {
                        XmlCursor newCursor = schemaModelGroupImpl4.getParseObject().newCursor();
                        boolean firstChild = newCursor.toFirstChild();
                        while (true) {
                            if (!firstChild) {
                                break;
                            }
                            i3 = translateParticleCode(newCursor.getName());
                            if (i3 != 0) {
                                xmlObject3 = (Group) newCursor.getObject();
                                break;
                            }
                            firstChild = newCursor.toNextSibling();
                        }
                        if (i3 == 0) {
                            StringBuffer a = a.a("Model group ");
                            a.append(QNameHelper.pretty(schemaModelGroupImpl4.getName()));
                            a.append(" is empty");
                            stscState.error(a.toString(), 32, schemaModelGroupImpl4.getParseObject());
                            return null;
                        }
                        if (!(i3 == 1 || i3 == 3 || i3 == 2)) {
                            StringBuffer a2 = a.a("Model group ");
                            a2.append(QNameHelper.pretty(schemaModelGroupImpl4.getName()));
                            a2.append(" is not a sequence, all, or choice");
                            stscState.error(a2.toString(), 32, schemaModelGroupImpl4.getParseObject());
                        }
                        String targetNamespace = schemaModelGroupImpl4.getTargetNamespace();
                        if (targetNamespace != null) {
                            str10 = targetNamespace;
                        }
                        str9 = schemaModelGroupImpl4.getElemFormDefault();
                        str8 = schemaModelGroupImpl4.getAttFormDefault();
                        z5 = schemaModelGroupImpl4.getChameleonNamespace() != null;
                    }
                } else {
                    z5 = z;
                    str8 = str3;
                    schemaModelGroupImpl4 = null;
                    str9 = str2;
                }
                if (i3 == 1 || i3 == 2 || i3 == 3) {
                    schemaParticleImpl4.setParticleType(i3);
                    xmlObject2 = xmlObject3;
                    str5 = str9;
                    bigInteger2 = extractMinOccurs;
                    str4 = str8;
                    str6 = str10;
                    z3 = z5;
                    z4 = true;
                    schemaLocalElementImpl = schemaParticleImpl4;
                    bigInteger = extractMaxOccurs;
                    schemaModelGroupImpl = schemaModelGroupImpl4;
                } else if (!$assertionsDisabled) {
                    throw new AssertionError();
                } else {
                    throw new IllegalStateException();
                }
            }
            if (bigInteger == null || bigInteger2.compareTo(bigInteger) <= 0) {
                r1 = 0;
            } else {
                r1 = 0;
                stscState.error(XmlErrorCodes.PARTICLE_PROPERTIES$MIN_LTE_MAX, (Object[]) null, xmlObject2);
                bigInteger = bigInteger2;
            }
            if (bigInteger == null || bigInteger.compareTo(BigInteger.ONE) >= 0) {
                schemaLocalElementImpl.setMinOccurs(bigInteger2);
                schemaLocalElementImpl.setMaxOccurs(bigInteger);
                if (schemaModelGroupImpl != null) {
                    stscState.startProcessing(schemaModelGroupImpl);
                    redefinitionForGroup2 = schemaModelGroupImpl.isRedefinition() ? new RedefinitionForGroup(schemaModelGroupImpl) : null;
                } else {
                    redefinitionForGroup2 = redefinitionForGroup;
                }
                if (z4) {
                    XmlCursor newCursor2 = xmlObject2.newCursor();
                    ArrayList arrayList2 = new ArrayList();
                    boolean firstChild2 = newCursor2.toFirstChild();
                    while (firstChild2) {
                        int translateParticleCode = translateParticleCode(newCursor2.getName());
                        if (translateParticleCode == 0) {
                            schemaModelGroupImpl3 = schemaModelGroupImpl;
                            schemaParticleImpl2 = schemaLocalElementImpl;
                            str7 = str6;
                            arrayList = arrayList2;
                        } else {
                            schemaModelGroupImpl3 = schemaModelGroupImpl;
                            str7 = str6;
                            arrayList = arrayList2;
                            schemaParticleImpl2 = schemaLocalElementImpl;
                            addMinusPointlessParticles(arrayList, translateContentModel(schemaType, newCursor2.getObject(), str6, z3, str5, str4, translateParticleCode, list, map, true, redefinitionForGroup2), schemaParticleImpl2.getParticleType());
                        }
                        firstChild2 = newCursor2.toNextSibling();
                        schemaLocalElementImpl = schemaParticleImpl2;
                        schemaModelGroupImpl = schemaModelGroupImpl3;
                        arrayList2 = arrayList;
                        str6 = str7;
                    }
                    schemaModelGroupImpl2 = schemaModelGroupImpl;
                    schemaParticleImpl = schemaLocalElementImpl;
                    schemaParticleImpl.setParticleChildren((SchemaParticle[]) arrayList2.toArray(new SchemaParticle[arrayList2.size()]));
                    newCursor2.dispose();
                } else {
                    schemaModelGroupImpl2 = schemaModelGroupImpl;
                    schemaParticleImpl = schemaLocalElementImpl;
                }
                SchemaParticle filterPointlessParticlesAndVerifyAllParticles = filterPointlessParticlesAndVerifyAllParticles(schemaParticleImpl, xmlObject2);
                if (schemaModelGroupImpl2 != null) {
                    stscState.finishProcessing(schemaModelGroupImpl2);
                }
                return filterPointlessParticlesAndVerifyAllParticles;
            }
            stscState.warning(XmlErrorCodes.PARTICLE_PROPERTIES$MAX_GTE_1, (Object[]) r1, xmlObject2);
            list.remove(schemaLocalElementImpl.getType());
            return r1;
        }
        throw new AssertionError();
    }

    public static int translateParticleCode(Group group) {
        if (group == null) {
            return 0;
        }
        return translateParticleCode(group.newCursor().getName());
    }

    public static int translateWildcardProcess(Wildcard.ProcessContents processContents) {
        if (processContents == null) {
            return 1;
        }
        String stringValue = processContents.getStringValue();
        if (SchemaSymbols.ATTVAL_LAX.equals(stringValue)) {
            return 2;
        }
        if (SchemaSymbols.ATTVAL_SKIP.equals(stringValue)) {
            return 3;
        }
        return 1;
    }

    public static int translateParticleCode(QName qName) {
        Integer num = (Integer) particleCodeMap.get(qName);
        if (num == null) {
            return 0;
        }
        return num.intValue();
    }

    public static Group getContentModel(ComplexRestrictionType complexRestrictionType) {
        if (complexRestrictionType.getAll() != null) {
            return complexRestrictionType.getAll();
        }
        if (complexRestrictionType.getSequence() != null) {
            return complexRestrictionType.getSequence();
        }
        if (complexRestrictionType.getChoice() != null) {
            return complexRestrictionType.getChoice();
        }
        if (complexRestrictionType.getGroup() != null) {
            return complexRestrictionType.getGroup();
        }
        return null;
    }

    public static Group getContentModel(ExtensionType extensionType) {
        if (extensionType.getAll() != null) {
            return extensionType.getAll();
        }
        if (extensionType.getSequence() != null) {
            return extensionType.getSequence();
        }
        if (extensionType.getChoice() != null) {
            return extensionType.getChoice();
        }
        if (extensionType.getGroup() != null) {
            return extensionType.getGroup();
        }
        return null;
    }
}
