package org.apache.xmlbeans.impl.schema;

import b.b.a.a.a;
import java.io.ByteArrayInputStream;
import java.io.ByteArrayOutputStream;
import java.io.CharArrayReader;
import java.io.CharArrayWriter;
import java.io.File;
import java.io.FileNotFoundException;
import java.io.FileOutputStream;
import java.io.IOException;
import java.io.InputStream;
import java.io.OutputStreamWriter;
import java.io.PrintStream;
import java.io.Reader;
import java.net.MalformedURLException;
import java.net.URI;
import java.net.URISyntaxException;
import java.net.URL;
import java.util.ArrayList;
import java.util.Arrays;
import java.util.HashMap;
import java.util.HashSet;
import java.util.LinkedList;
import java.util.List;
import java.util.Map;
import java.util.Set;
import org.apache.poi.openxml4j.opc.internal.ZipHelper;
import org.apache.xmlbeans.SchemaType;
import org.apache.xmlbeans.SchemaTypeLoader;
import org.apache.xmlbeans.XmlException;
import org.apache.xmlbeans.XmlObject;
import org.apache.xmlbeans.XmlOptions;
import org.apache.xmlbeans.impl.common.IOUtil;
import org.apache.xmlbeans.impl.common.JarHelper;
import org.apache.xmlbeans.impl.common.XmlEncodingSniffer;
import org.apache.xmlbeans.impl.xb.xsdschema.ImportDocument;
import org.apache.xmlbeans.impl.xb.xsdschema.IncludeDocument;
import org.apache.xmlbeans.impl.xb.xsdschema.RedefineDocument;
import org.apache.xmlbeans.impl.xb.xsdschema.SchemaDocument;
import org.xml.sax.EntityResolver;
import org.xml.sax.InputSource;
import org.xml.sax.SAXException;

public class StscImporter {
    public static final String PROJECT_URL_PREFIX = "project://local";

    public static class SchemaToProcess {
        public String chameleonNamespace;
        public List includes;
        public Set indirectIncludedBy;
        public Set indirectIncludes;
        public List redefineObjects;
        public List redefines;
        public SchemaDocument.Schema schema;

        public SchemaToProcess(SchemaDocument.Schema schema2, String str) {
            this.schema = schema2;
            this.chameleonNamespace = str;
        }

        /* access modifiers changed from: private */
        /* access modifiers changed from: public */
        private void addInclude(SchemaToProcess schemaToProcess) {
            if (this.includes == null) {
                this.includes = new ArrayList();
            }
            this.includes.add(schemaToProcess);
        }

        private void addIndirectIncludes(SchemaToProcess schemaToProcess) {
            if (this.indirectIncludes == null) {
                this.indirectIncludes = new HashSet();
            }
            this.indirectIncludes.add(schemaToProcess);
            if (schemaToProcess.indirectIncludedBy == null) {
                schemaToProcess.indirectIncludedBy = new HashSet();
            }
            schemaToProcess.indirectIncludedBy.add(this);
            addIndirectIncludesHelper(this, schemaToProcess);
            Set<SchemaToProcess> set = this.indirectIncludedBy;
            if (set != null) {
                for (SchemaToProcess schemaToProcess2 : set) {
                    schemaToProcess2.indirectIncludes.add(schemaToProcess);
                    schemaToProcess.indirectIncludedBy.add(schemaToProcess2);
                    addIndirectIncludesHelper(schemaToProcess2, schemaToProcess);
                }
            }
        }

        public static void addIndirectIncludesHelper(SchemaToProcess schemaToProcess, SchemaToProcess schemaToProcess2) {
            Set<SchemaToProcess> set = schemaToProcess2.indirectIncludes;
            if (set != null) {
                for (SchemaToProcess schemaToProcess3 : set) {
                    schemaToProcess.indirectIncludes.add(schemaToProcess3);
                    schemaToProcess3.indirectIncludedBy.add(schemaToProcess);
                }
            }
        }

        /* access modifiers changed from: private */
        /* access modifiers changed from: public */
        private void addRedefine(SchemaToProcess schemaToProcess, RedefineDocument.Redefine redefine) {
            if (this.redefines == null || this.redefineObjects == null) {
                this.redefines = new ArrayList();
                this.redefineObjects = new ArrayList();
            }
            this.redefines.add(schemaToProcess);
            this.redefineObjects.add(redefine);
        }

        /* access modifiers changed from: private */
        /* access modifiers changed from: public */
        private void buildIndirectReferences() {
            if (this.includes != null) {
                for (int i2 = 0; i2 < this.includes.size(); i2++) {
                    addIndirectIncludes((SchemaToProcess) this.includes.get(i2));
                }
            }
            if (this.redefines != null) {
                for (int i3 = 0; i3 < this.redefines.size(); i3++) {
                    addIndirectIncludes((SchemaToProcess) this.redefines.get(i3));
                }
            }
        }

        public boolean equals(Object obj) {
            if (this == obj) {
                return true;
            }
            if (!(obj instanceof SchemaToProcess)) {
                return false;
            }
            SchemaToProcess schemaToProcess = (SchemaToProcess) obj;
            String str = this.chameleonNamespace;
            if (str == null ? schemaToProcess.chameleonNamespace == null : str.equals(schemaToProcess.chameleonNamespace)) {
                return this.schema == schemaToProcess.schema;
            }
            return false;
        }

        public String getChameleonNamespace() {
            return this.chameleonNamespace;
        }

        public List getRedefineObjects() {
            return this.redefineObjects;
        }

        public List getRedefines() {
            return this.redefines;
        }

        public SchemaDocument.Schema getSchema() {
            return this.schema;
        }

        public String getSourceName() {
            return this.schema.documentProperties().getSourceName();
        }

        public int hashCode() {
            int hashCode = this.schema.hashCode() * 29;
            String str = this.chameleonNamespace;
            return hashCode + (str != null ? str.hashCode() : 0);
        }

        public boolean indirectIncludes(SchemaToProcess schemaToProcess) {
            Set set = this.indirectIncludes;
            return set != null && set.contains(schemaToProcess);
        }
    }

    public static String baseURLForDoc(XmlObject xmlObject) {
        String sourceName = xmlObject.documentProperties().getSourceName();
        if (sourceName == null) {
            return null;
        }
        if (sourceName.startsWith(ZipHelper.FORWARD_SLASH)) {
            StringBuffer a = a.a("project://local");
            a.append(sourceName.replace('\\', JarHelper.SEP));
            return a.toString();
        }
        int indexOf = sourceName.indexOf(58);
        if (indexOf > 1 && sourceName.substring(0, indexOf).matches("^\\w+$")) {
            return sourceName;
        }
        StringBuffer a2 = a.a("project://local/");
        a2.append(sourceName.replace('\\', JarHelper.SEP));
        return a2.toString();
    }

    public static URI parseURI(String str) {
        if (str == null) {
            return null;
        }
        try {
            return new URI(str);
        } catch (URISyntaxException unused) {
            return null;
        }
    }

    public static URI resolve(URI uri, String str) {
        URI uri2 = new URI(str);
        URI resolve = uri.resolve(uri2);
        if (uri2.equals(resolve) && !uri2.isAbsolute() && (uri.getScheme().equals("jar") || uri.getScheme().equals("zip"))) {
            String uri3 = uri.toString();
            int lastIndexOf = uri3.lastIndexOf(47);
            StringBuffer stringBuffer = new StringBuffer();
            stringBuffer.append(uri3.substring(0, lastIndexOf));
            stringBuffer.append(ZipHelper.FORWARD_SLASH);
            stringBuffer.append(uri2);
            String stringBuffer2 = stringBuffer.toString();
            int lastIndexOf2 = stringBuffer2.lastIndexOf("!/");
            if (lastIndexOf2 > 0) {
                for (int indexOf = stringBuffer2.indexOf("/..", lastIndexOf2); indexOf > 0; indexOf = stringBuffer2.indexOf("/..", lastIndexOf2)) {
                    int lastIndexOf3 = stringBuffer2.lastIndexOf(ZipHelper.FORWARD_SLASH, indexOf - 1);
                    if (lastIndexOf3 >= lastIndexOf2) {
                        stringBuffer2 = stringBuffer2.substring(0, lastIndexOf3).concat(stringBuffer2.substring(indexOf + 3));
                    }
                }
            }
            return URI.create(stringBuffer2);
        } else if (!"file".equals(resolve.getScheme()) || str.equals(resolve) || !uri.getPath().startsWith("//") || resolve.getPath().startsWith("//")) {
            return resolve;
        } else {
            try {
                return new URI("file", null, "///".concat(resolve.getPath()), resolve.getQuery(), resolve.getFragment());
            } catch (URISyntaxException unused) {
                return resolve;
            }
        }
    }

    public static SchemaToProcess[] resolveImportsAndIncludes(SchemaDocument.Schema[] schemaArr, boolean z) {
        return new DownloadTable(schemaArr).resolveImportsAndIncludes(z);
    }

    public static class DownloadTable {
        public Set emptyNamespaceSchemas = new HashSet();
        public Set failedDownloads = new HashSet();
        public LinkedList scanNeeded = new LinkedList();
        public Map scannedAlready = new HashMap();
        public Map schemaByDigestKey = new HashMap();
        public Map schemaByNsLocPair = new HashMap();

        public static class DigestKey {
            public byte[] _digest;
            public int _hashCode;

            public DigestKey(byte[] bArr) {
                this._digest = bArr;
                int i2 = 0;
                while (i2 < 4 && i2 < bArr.length) {
                    int i3 = this._hashCode << 8;
                    this._hashCode = i3;
                    this._hashCode = i3 + bArr[i2];
                    i2++;
                }
            }

            public boolean equals(Object obj) {
                if (this == obj) {
                    return true;
                }
                if (!(obj instanceof DigestKey)) {
                    return false;
                }
                return Arrays.equals(this._digest, ((DigestKey) obj)._digest);
            }

            public int hashCode() {
                return this._hashCode;
            }
        }

        public static class NsLocPair {
            public String locationURL;
            public String namespaceURI;

            public NsLocPair(String str, String str2) {
                this.namespaceURI = str;
                this.locationURL = str2;
            }

            public boolean equals(Object obj) {
                if (this == obj) {
                    return true;
                }
                if (!(obj instanceof NsLocPair)) {
                    return false;
                }
                NsLocPair nsLocPair = (NsLocPair) obj;
                String str = this.locationURL;
                if (str == null ? nsLocPair.locationURL != null : !str.equals(nsLocPair.locationURL)) {
                    return false;
                }
                String str2 = this.namespaceURI;
                String str3 = nsLocPair.namespaceURI;
                return str2 == null ? str3 == null : str2.equals(str3);
            }

            public String getLocationURL() {
                return this.locationURL;
            }

            public String getNamespaceURI() {
                return this.namespaceURI;
            }

            public int hashCode() {
                String str = this.namespaceURI;
                int i2 = 0;
                int hashCode = (str != null ? str.hashCode() : 0) * 29;
                String str2 = this.locationURL;
                if (str2 != null) {
                    i2 = str2.hashCode();
                }
                return hashCode + i2;
            }
        }

        public DownloadTable(SchemaDocument.Schema[] schemaArr) {
            for (int i2 = 0; i2 < schemaArr.length; i2++) {
                String targetNamespace = schemaArr[i2].getTargetNamespace();
                addSuccessfulDownload(new NsLocPair(targetNamespace, StscImporter.baseURLForDoc(schemaArr[i2])), schemaArr[i2]);
                if (targetNamespace != null) {
                    addScanNeeded(new SchemaToProcess(schemaArr[i2], null));
                } else {
                    addEmptyNamespaceSchema(schemaArr[i2]);
                }
            }
        }

        private void addEmptyNamespaceSchema(SchemaDocument.Schema schema) {
            this.emptyNamespaceSchemas.add(schema);
        }

        private void addFailedDownload(String str) {
            this.failedDownloads.add(str);
        }

        private SchemaToProcess addScanNeeded(SchemaToProcess schemaToProcess) {
            if (this.scannedAlready.containsKey(schemaToProcess)) {
                return (SchemaToProcess) this.scannedAlready.get(schemaToProcess);
            }
            this.scannedAlready.put(schemaToProcess, schemaToProcess);
            this.scanNeeded.add(schemaToProcess);
            return schemaToProcess;
        }

        private void addSuccessfulDownload(NsLocPair nsLocPair, SchemaDocument.Schema schema) {
            byte[] messageDigest = schema.documentProperties().getMessageDigest();
            if (messageDigest == null) {
                StscState.get().addSchemaDigest(null);
            } else {
                if (!this.schemaByDigestKey.containsKey(new DigestKey(messageDigest))) {
                    this.schemaByDigestKey.put(new DigestKey(messageDigest), schema);
                    StscState.get().addSchemaDigest(messageDigest);
                }
            }
            this.schemaByNsLocPair.put(nsLocPair, schema);
            NsLocPair nsLocPair2 = new NsLocPair(nsLocPair.getNamespaceURI(), null);
            if (!this.schemaByNsLocPair.containsKey(nsLocPair2)) {
                this.schemaByNsLocPair.put(nsLocPair2, schema);
            }
            NsLocPair nsLocPair3 = new NsLocPair(null, nsLocPair.getLocationURL());
            if (!this.schemaByNsLocPair.containsKey(nsLocPair3)) {
                this.schemaByNsLocPair.put(nsLocPair3, schema);
            }
        }

        public static ByteArrayInputStream copy(InputStream inputStream) {
            byte[] bArr = new byte[1024];
            ByteArrayOutputStream byteArrayOutputStream = new ByteArrayOutputStream();
            while (true) {
                int read = inputStream.read(bArr, 0, 1024);
                if (read <= 0) {
                    return new ByteArrayInputStream(byteArrayOutputStream.toByteArray());
                }
                byteArrayOutputStream.write(bArr, 0, read);
            }
        }

        public static Reader copySchemaSource(String str, Reader reader, StscState stscState) {
            if (stscState.getSchemasDir() == null) {
                return reader;
            }
            File file = new File(stscState.getSchemasDir(), stscState.sourceNameForUri(str));
            if (file.exists()) {
                return reader;
            }
            try {
                IOUtil.createDir(new File(file.getParent()), null);
                CharArrayReader copy = copy(reader);
                IOUtil.copyCompletely(copy, new OutputStreamWriter(new FileOutputStream(file), new XmlEncodingSniffer(copy, (String) null).getXmlEncoding()));
                copy.reset();
                return copy;
            } catch (IOException e2) {
                PrintStream printStream = System.err;
                StringBuffer stringBuffer = new StringBuffer();
                stringBuffer.append("IO Error ");
                stringBuffer.append(e2);
                printStream.println(stringBuffer.toString());
                return reader;
            }
        }

        public static XmlObject downloadDocument(SchemaTypeLoader schemaTypeLoader, String str, String str2) {
            StscState stscState = StscState.get();
            EntityResolver entityResolver = stscState.getEntityResolver();
            if (entityResolver != null) {
                try {
                    InputSource resolveEntity = entityResolver.resolveEntity(str, str2);
                    if (resolveEntity != null) {
                        stscState.addSourceUri(str2, null);
                        Reader characterStream = resolveEntity.getCharacterStream();
                        if (characterStream != null) {
                            Reader copySchemaSource = copySchemaSource(str2, characterStream, stscState);
                            XmlOptions xmlOptions = new XmlOptions();
                            xmlOptions.setLoadLineNumbers();
                            xmlOptions.setDocumentSourceName(str2);
                            return schemaTypeLoader.parse(copySchemaSource, (SchemaType) null, xmlOptions);
                        }
                        InputStream byteStream = resolveEntity.getByteStream();
                        if (byteStream != null) {
                            InputStream copySchemaSource2 = copySchemaSource(str2, byteStream, stscState);
                            String encoding = resolveEntity.getEncoding();
                            XmlOptions xmlOptions2 = new XmlOptions();
                            xmlOptions2.setLoadLineNumbers();
                            xmlOptions2.setLoadMessageDigest();
                            xmlOptions2.setDocumentSourceName(str2);
                            if (encoding != null) {
                                xmlOptions2.setCharacterEncoding(encoding);
                            }
                            return schemaTypeLoader.parse(copySchemaSource2, (SchemaType) null, xmlOptions2);
                        }
                        String systemId = resolveEntity.getSystemId();
                        if (systemId != null) {
                            copySchemaSource(str2, stscState, false);
                            XmlOptions xmlOptions3 = new XmlOptions();
                            xmlOptions3.setLoadLineNumbers();
                            xmlOptions3.setLoadMessageDigest();
                            xmlOptions3.setDocumentSourceName(str2);
                            return schemaTypeLoader.parse(new URL(systemId), (SchemaType) null, xmlOptions3);
                        }
                        throw new IOException(a.a("EntityResolver unable to resolve ", str2, " (for namespace ", str, ")"));
                    }
                } catch (SAXException e2) {
                    throw new XmlException(e2);
                }
            }
            stscState.addSourceUri(str2, null);
            copySchemaSource(str2, stscState, false);
            XmlOptions xmlOptions4 = new XmlOptions();
            xmlOptions4.setLoadLineNumbers();
            xmlOptions4.setLoadMessageDigest();
            return schemaTypeLoader.parse(new URL(str2), (SchemaType) null, xmlOptions4);
        }

        private SchemaDocument.Schema downloadSchema(XmlObject xmlObject, String str, String str2) {
            SchemaDocument.Schema schema;
            SchemaDocument.Schema schema2;
            SchemaDocument.Schema schema3;
            if (str2 == null) {
                return null;
            }
            StscState stscState = StscState.get();
            URI parseURI = StscImporter.parseURI(StscImporter.baseURLForDoc(xmlObject));
            if (parseURI != null) {
                try {
                    str2 = StscImporter.resolve(parseURI, str2).toString();
                } catch (URISyntaxException e2) {
                    StringBuffer a = a.a("Could not find resource - invalid location URL: ");
                    a.append(e2.getMessage());
                    stscState.error(a.toString(), 56, xmlObject);
                    return null;
                }
            }
            if (stscState.isFileProcessed(str2)) {
                return null;
            }
            if (str2 != null && str != null && (schema3 = (SchemaDocument.Schema) this.schemaByNsLocPair.get(new NsLocPair(str, str2))) != null) {
                return schema3;
            }
            if (str != null && !str.equals("")) {
                if (!stscState.shouldDownloadURI(str2) && (schema2 = (SchemaDocument.Schema) this.schemaByNsLocPair.get(new NsLocPair(str, null))) != null) {
                    return schema2;
                }
                if (stscState.linkerDefinesNamespace(str)) {
                    return null;
                }
            }
            if (str2 != null && (schema = (SchemaDocument.Schema) this.schemaByNsLocPair.get(new NsLocPair(null, str2))) != null) {
                return schema;
            }
            if (str2 == null) {
                stscState.error("Could not find resource - no valid location URL.", 56, xmlObject);
                return null;
            } else if (previouslyFailedToDownload(str2)) {
                return null;
            } else {
                if (!stscState.shouldDownloadURI(str2)) {
                    stscState.error(a.a("Could not load resource \"", str2, "\" (network downloads disabled)."), 56, xmlObject);
                    addFailedDownload(str2);
                    return null;
                }
                try {
                    XmlObject downloadDocument = downloadDocument(stscState.getS4SLoader(), str, str2);
                    SchemaDocument.Schema findMatchByDigest = findMatchByDigest(downloadDocument);
                    String relativize = stscState.relativize(str2);
                    if (findMatchByDigest != null) {
                        String relativize2 = stscState.relativize(findMatchByDigest.documentProperties().getSourceName());
                        if (relativize2 != null) {
                            StringBuffer stringBuffer = new StringBuffer();
                            stringBuffer.append(relativize);
                            stringBuffer.append(" is the same as ");
                            stringBuffer.append(relativize2);
                            stringBuffer.append(" (ignoring the duplicate file)");
                            stscState.info(stringBuffer.toString());
                        } else {
                            StringBuffer stringBuffer2 = new StringBuffer();
                            stringBuffer2.append(relativize);
                            stringBuffer2.append(" is the same as another schema");
                            stscState.info(stringBuffer2.toString());
                        }
                    } else {
                        XmlOptions xmlOptions = new XmlOptions();
                        xmlOptions.setErrorListener(stscState.getErrorListener());
                        if (downloadDocument instanceof SchemaDocument) {
                            if (downloadDocument.validate(xmlOptions)) {
                                findMatchByDigest = ((SchemaDocument) downloadDocument).getSchema();
                                StringBuffer stringBuffer3 = new StringBuffer();
                                stringBuffer3.append("Loading referenced file ");
                                stringBuffer3.append(relativize);
                                stscState.info(stringBuffer3.toString());
                            }
                        }
                        stscState.error("Referenced document is not a valid schema", 56, xmlObject);
                        addFailedDownload(str2);
                        return null;
                    }
                    addSuccessfulDownload(new NsLocPair(emptyStringIfNull(findMatchByDigest.getTargetNamespace()), str2), findMatchByDigest);
                    return findMatchByDigest;
                } catch (MalformedURLException unused) {
                    stscState.error(a.a("URL \"", str2, "\" is not well-formed"), 56, xmlObject);
                } catch (IOException e3) {
                    stscState.error(e3.toString(), 56, xmlObject);
                } catch (XmlException e4) {
                    StringBuffer a2 = a.a("Problem parsing referenced XML resource - ");
                    a2.append(e4.getMessage());
                    stscState.error(a2.toString(), 56, xmlObject);
                }
            }
        }

        public static String emptyStringIfNull(String str) {
            return str == null ? "" : str;
        }

        private boolean fetchRemainingEmptyNamespaceSchemas() {
            if (this.emptyNamespaceSchemas.isEmpty()) {
                return false;
            }
            for (SchemaDocument.Schema schema : this.emptyNamespaceSchemas) {
                addScanNeeded(new SchemaToProcess(schema, null));
            }
            this.emptyNamespaceSchemas.clear();
            return true;
        }

        private SchemaDocument.Schema findMatchByDigest(XmlObject xmlObject) {
            byte[] messageDigest = xmlObject.documentProperties().getMessageDigest();
            if (messageDigest == null) {
                return null;
            }
            return (SchemaDocument.Schema) this.schemaByDigestKey.get(new DigestKey(messageDigest));
        }

        private boolean hasNextToScan() {
            return !this.scanNeeded.isEmpty();
        }

        private SchemaToProcess nextToScan() {
            return (SchemaToProcess) this.scanNeeded.removeFirst();
        }

        public static boolean nullableStringsMatch(String str, String str2) {
            if (str == null && str2 == null) {
                return true;
            }
            if (str == null || str2 == null) {
                return false;
            }
            return str.equals(str2);
        }

        private boolean previouslyFailedToDownload(String str) {
            return this.failedDownloads.contains(str);
        }

        private void usedEmptyNamespaceSchema(SchemaDocument.Schema schema) {
            this.emptyNamespaceSchemas.remove(schema);
        }

        public SchemaToProcess[] resolveImportsAndIncludes(boolean z) {
            StscState stscState = StscState.get();
            ArrayList arrayList = new ArrayList();
            boolean z2 = false;
            while (true) {
                if (hasNextToScan()) {
                    SchemaToProcess nextToScan = nextToScan();
                    String sourceName = nextToScan.getSourceName();
                    String str = null;
                    stscState.addSourceUri(sourceName, null);
                    arrayList.add(nextToScan);
                    copySchemaSource(sourceName, stscState, z);
                    ImportDocument.Import[] importArray = nextToScan.getSchema().getImportArray();
                    for (int i2 = 0; i2 < importArray.length; i2++) {
                        SchemaDocument.Schema downloadSchema = downloadSchema(importArray[i2], emptyStringIfNull(importArray[i2].getNamespace()), importArray[i2].getSchemaLocation());
                        if (downloadSchema != null) {
                            if (!nullableStringsMatch(downloadSchema.getTargetNamespace(), importArray[i2].getNamespace())) {
                                StscState stscState2 = StscState.get();
                                StringBuffer a = a.a("Imported schema has a target namespace \"");
                                a.append(downloadSchema.getTargetNamespace());
                                a.append("\" that does not match the specified \"");
                                a.append(importArray[i2].getNamespace());
                                a.append("\"");
                                stscState2.error(a.toString(), 4, importArray[i2]);
                            } else {
                                addScanNeeded(new SchemaToProcess(downloadSchema, null));
                            }
                        }
                    }
                    IncludeDocument.Include[] includeArray = nextToScan.getSchema().getIncludeArray();
                    String chameleonNamespace = nextToScan.getChameleonNamespace();
                    if (chameleonNamespace == null) {
                        chameleonNamespace = emptyStringIfNull(nextToScan.getSchema().getTargetNamespace());
                    }
                    int i3 = 0;
                    while (i3 < includeArray.length) {
                        SchemaDocument.Schema downloadSchema2 = downloadSchema(includeArray[i3], str, includeArray[i3].getSchemaLocation());
                        if (downloadSchema2 != null) {
                            if (emptyStringIfNull(downloadSchema2.getTargetNamespace()).equals(chameleonNamespace)) {
                                nextToScan.addInclude(addScanNeeded(new SchemaToProcess(downloadSchema2, str)));
                            } else if (downloadSchema2.getTargetNamespace() != null) {
                                StscState stscState3 = StscState.get();
                                StringBuffer a2 = a.a("Included schema has a target namespace \"");
                                a2.append(downloadSchema2.getTargetNamespace());
                                a2.append("\" that does not match the source namespace \"");
                                a2.append(chameleonNamespace);
                                a2.append("\"");
                                stscState3.error(a2.toString(), 4, includeArray[i3]);
                            } else {
                                nextToScan.addInclude(addScanNeeded(new SchemaToProcess(downloadSchema2, chameleonNamespace)));
                                usedEmptyNamespaceSchema(downloadSchema2);
                            }
                        }
                        i3++;
                        str = null;
                    }
                    RedefineDocument.Redefine[] redefineArray = nextToScan.getSchema().getRedefineArray();
                    String chameleonNamespace2 = nextToScan.getChameleonNamespace();
                    if (chameleonNamespace2 == null) {
                        chameleonNamespace2 = emptyStringIfNull(nextToScan.getSchema().getTargetNamespace());
                    }
                    for (int i4 = 0; i4 < redefineArray.length; i4++) {
                        SchemaDocument.Schema downloadSchema3 = downloadSchema(redefineArray[i4], null, redefineArray[i4].getSchemaLocation());
                        if (downloadSchema3 != null) {
                            if (emptyStringIfNull(downloadSchema3.getTargetNamespace()).equals(chameleonNamespace2)) {
                                nextToScan.addRedefine(addScanNeeded(new SchemaToProcess(downloadSchema3, null)), redefineArray[i4]);
                            } else if (downloadSchema3.getTargetNamespace() != null) {
                                StscState stscState4 = StscState.get();
                                StringBuffer a3 = a.a("Redefined schema has a target namespace \"");
                                a3.append(downloadSchema3.getTargetNamespace());
                                a3.append("\" that does not match the source namespace \"");
                                a3.append(chameleonNamespace2);
                                a3.append("\"");
                                stscState4.error(a3.toString(), 4, redefineArray[i4]);
                            } else {
                                nextToScan.addRedefine(addScanNeeded(new SchemaToProcess(downloadSchema3, chameleonNamespace2)), redefineArray[i4]);
                                usedEmptyNamespaceSchema(downloadSchema3);
                            }
                            z2 = true;
                        }
                    }
                } else if (!fetchRemainingEmptyNamespaceSchemas()) {
                    break;
                }
            }
            if (z2) {
                for (int i5 = 0; i5 < arrayList.size(); i5++) {
                    ((SchemaToProcess) arrayList.get(i5)).buildIndirectReferences();
                }
            }
            return (SchemaToProcess[]) arrayList.toArray(new SchemaToProcess[arrayList.size()]);
        }

        public static CharArrayReader copy(Reader reader) {
            char[] cArr = new char[1024];
            CharArrayWriter charArrayWriter = new CharArrayWriter();
            while (true) {
                int read = reader.read(cArr, 0, 1024);
                if (read <= 0) {
                    return new CharArrayReader(charArrayWriter.toCharArray());
                }
                charArrayWriter.write(cArr, 0, read);
            }
        }

        public static InputStream copySchemaSource(String str, InputStream inputStream, StscState stscState) {
            if (stscState.getSchemasDir() == null) {
                return inputStream;
            }
            File file = new File(stscState.getSchemasDir(), stscState.sourceNameForUri(str));
            if (file.exists()) {
                return inputStream;
            }
            try {
                IOUtil.createDir(new File(file.getParent()), null);
                ByteArrayInputStream copy = copy(inputStream);
                IOUtil.copyCompletely(copy, new FileOutputStream(file));
                copy.reset();
                return copy;
            } catch (IOException e2) {
                PrintStream printStream = System.err;
                StringBuffer stringBuffer = new StringBuffer();
                stringBuffer.append("IO Error ");
                stringBuffer.append(e2);
                printStream.println(stringBuffer.toString());
                return inputStream;
            }
        }

        public static void copySchemaSource(String str, StscState stscState, boolean z) {
            if (stscState.getSchemasDir() != null) {
                File file = new File(stscState.getSchemasDir(), stscState.sourceNameForUri(str));
                if (z || !file.exists()) {
                    try {
                        InputStream inputStream = null;
                        IOUtil.createDir(new File(file.getParent()), null);
                        try {
                            inputStream = new URL(str).openStream();
                        } catch (FileNotFoundException e2) {
                            if (!z || !file.exists()) {
                                throw e2;
                            }
                            file.delete();
                        }
                        if (inputStream != null) {
                            IOUtil.copyCompletely(inputStream, new FileOutputStream(file));
                        }
                    } catch (IOException e3) {
                        PrintStream printStream = System.err;
                        StringBuffer stringBuffer = new StringBuffer();
                        stringBuffer.append("IO Error ");
                        stringBuffer.append(e3);
                        printStream.println(stringBuffer.toString());
                    }
                }
            }
        }
    }
}
