package org.apache.xmlbeans.impl.schema;

import b.b.a.a.a;
import java.math.BigInteger;
import java.util.ArrayList;
import java.util.Arrays;
import java.util.Collection;
import java.util.HashSet;
import java.util.Iterator;
import java.util.List;
import java.util.Set;
import org.apache.poi.javax.xml.namespace.QName;
import org.apache.xmlbeans.BindingConfig;
import org.apache.xmlbeans.InterfaceExtension;
import org.apache.xmlbeans.PrePostExtension;
import org.apache.xmlbeans.SchemaField;
import org.apache.xmlbeans.SchemaProperty;
import org.apache.xmlbeans.SchemaStringEnumEntry;
import org.apache.xmlbeans.SchemaType;
import org.apache.xmlbeans.UserType;
import org.apache.xmlbeans.XmlAnySimpleType;
import org.apache.xmlbeans.XmlObject;
import org.apache.xmlbeans.impl.common.NameUtil;

public class StscJavaizer {
    public static final /* synthetic */ boolean $assertionsDisabled;
    public static final int MAX_ENUM_COUNT = 3668;
    public static final String[] PREFIXES = {"get", "xget", "isNil", "isSet", "sizeOf", "set", "xset", "addNew", "setNil", "unset", "insert", "add", "insertNew", "addNew", "remove"};
    public static String[] PROTECTED_PROPERTIES = {"StringValue", "BooleanValue", "ByteValue", "ShortValue", "IntValue", "LongValue", "BigIntegerValue", "BigDecimalValue", "FloatValue", "DoubleValue", "ByteArrayValue", "EnumValue", "CalendarValue", "DateValue", "GDateValue", "GDurationValue", "QNameValue", "ListValue", "ObjectValue", "Class"};
    public static Set PROTECTED_PROPERTIES_SET = new HashSet(Arrays.asList(PROTECTED_PROPERTIES));
    public static /* synthetic */ Class class$org$apache$xmlbeans$impl$schema$StscJavaizer;

    static {
        Class cls = class$org$apache$xmlbeans$impl$schema$StscJavaizer;
        if (cls == null) {
            cls = class$("org.apache.xmlbeans.impl.schema.StscJavaizer");
            class$org$apache$xmlbeans$impl$schema$StscJavaizer = cls;
        }
        $assertionsDisabled = !cls.desiredAssertionStatus();
    }

    public static void addAnonymousTypesFromRedefinition(SchemaType schemaType, List list) {
        while (((SchemaTypeImpl) schemaType).isRedefinition()) {
            if (schemaType.getDerivationType() == 2 || schemaType.isSimpleType()) {
                schemaType = schemaType.getBaseType();
                SchemaType[] anonymousTypes = schemaType.getAnonymousTypes();
                if (anonymousTypes.length > 0) {
                    list.addAll(Arrays.asList(anonymousTypes));
                }
            } else {
                return;
            }
        }
    }

    public static void assignGlobalJavaNames(Collection collection) {
        HashSet hashSet = new HashSet();
        StscState stscState = StscState.get();
        Iterator it = collection.iterator();
        while (it.hasNext()) {
            SchemaTypeImpl schemaTypeImpl = (SchemaTypeImpl) it.next();
            String javaname = stscState.getJavaname(findTopName(schemaTypeImpl), schemaTypeImpl.isDocumentType() ? 2 : 1);
            if (schemaTypeImpl.isUnjavaized()) {
                schemaTypeImpl.setFullJavaName(pickFullJavaClassName(hashSet, findTopName(schemaTypeImpl), javaname, schemaTypeImpl.isDocumentType(), schemaTypeImpl.isAttributeType()));
                schemaTypeImpl.setFullJavaImplName(pickFullJavaImplName(hashSet, schemaTypeImpl.getFullJavaName()));
                setUserTypes(schemaTypeImpl, stscState);
                setExtensions(schemaTypeImpl, stscState);
            }
        }
        verifyInterfaceNameCollisions(hashSet, stscState);
    }

    public static void assignJavaAnonymousTypeNames(SchemaTypeImpl schemaTypeImpl) {
        String str;
        String str2;
        String str3;
        HashSet hashSet = new HashSet();
        SchemaType[] anonymousTypes = schemaTypeImpl.getAnonymousTypes();
        StscState stscState = StscState.get();
        int length = anonymousTypes.length;
        if (schemaTypeImpl.isRedefinition()) {
            ArrayList arrayList = new ArrayList();
            addAnonymousTypesFromRedefinition(schemaTypeImpl, arrayList);
            if (arrayList.size() > 0) {
                SchemaType[] schemaTypeArr = new SchemaType[(arrayList.size() + length)];
                arrayList.toArray(schemaTypeArr);
                System.arraycopy(anonymousTypes, 0, schemaTypeArr, arrayList.size(), length);
                anonymousTypes = schemaTypeArr;
            }
        }
        for (SchemaType schemaType = schemaTypeImpl; schemaType != null; schemaType = schemaType.getOuterType()) {
            hashSet.add(schemaType.getShortJavaName());
        }
        for (SchemaType schemaType2 = schemaTypeImpl; schemaType2 != null; schemaType2 = schemaType2.getOuterType()) {
            hashSet.add(schemaType2.getShortJavaImplName());
        }
        hashSet.add(getOutermostPackage(schemaTypeImpl.getFullJavaName()));
        for (int i2 = 0; i2 < anonymousTypes.length; i2++) {
            SchemaTypeImpl schemaTypeImpl2 = (SchemaTypeImpl) anonymousTypes[i2];
            if (schemaTypeImpl2 != null && !schemaTypeImpl2.isSkippedAnonymousType()) {
                String str4 = null;
                if (schemaTypeImpl2.getContainerField() != null) {
                    str2 = schemaTypeImpl2.getContainerField().getName().getLocalPart();
                    str = stscState.getJavaname(schemaTypeImpl2.getContainerField().getName(), 1);
                } else {
                    int simpleVariety = schemaTypeImpl2.getOuterType().getSimpleVariety();
                    if (simpleVariety == 2) {
                        str3 = "Member";
                    } else if (simpleVariety == 3) {
                        str3 = "Item";
                    } else if ($assertionsDisabled) {
                        str3 = "Base";
                    } else {
                        StringBuffer a = a.a("Weird type ");
                        a.append(schemaTypeImpl2.toString());
                        throw new AssertionError(a.toString());
                    }
                    str = str3;
                    str2 = null;
                }
                if (i2 < length) {
                    schemaTypeImpl2.setShortJavaName(pickInnerJavaClassName(hashSet, str2, str));
                    if (str != null) {
                        str4 = a.a(str, "Impl");
                    }
                    schemaTypeImpl2.setShortJavaImplName(pickInnerJavaImplName(hashSet, str2, str4));
                } else {
                    StringBuffer stringBuffer = new StringBuffer();
                    stringBuffer.append(schemaTypeImpl.getFullJavaName());
                    stringBuffer.append("$");
                    stringBuffer.append(pickInnerJavaClassName(hashSet, str2, str));
                    schemaTypeImpl2.setFullJavaName(stringBuffer.toString());
                    StringBuffer stringBuffer2 = new StringBuffer();
                    stringBuffer2.append(schemaTypeImpl.getFullJavaImplName());
                    stringBuffer2.append("$");
                    if (str != null) {
                        str4 = a.a(str, "Impl");
                    }
                    stringBuffer2.append(pickInnerJavaImplName(hashSet, str2, str4));
                    schemaTypeImpl2.setFullJavaImplName(stringBuffer2.toString());
                }
                setExtensions(schemaTypeImpl2, stscState);
            }
        }
    }

    public static void assignJavaPropertyNames(Set set, SchemaProperty[] schemaPropertyArr, SchemaType schemaType, boolean z) {
        String str;
        StscState stscState = StscState.get();
        for (SchemaProperty schemaProperty : schemaPropertyArr) {
            SchemaPropertyImpl schemaPropertyImpl = (SchemaPropertyImpl) schemaProperty;
            SchemaProperty attributeProperty = schemaPropertyImpl.isAttribute() ? schemaType.getAttributeProperty(schemaPropertyImpl.getName()) : schemaType.getElementProperty(schemaPropertyImpl.getName());
            boolean z2 = true;
            if ((attributeProperty != null) == z) {
                QName name = schemaPropertyImpl.getName();
                if (attributeProperty == null) {
                    str = pickJavaPropertyName(set, name.getLocalPart(), stscState.getJavaname(name, schemaPropertyImpl.isAttribute() ? 4 : 3));
                } else {
                    str = attributeProperty.getJavaPropertyName();
                }
                schemaPropertyImpl.setJavaPropertyName(str);
                boolean z3 = schemaPropertyImpl.getMaxOccurs() == null || schemaPropertyImpl.getMaxOccurs().compareTo(BigInteger.ONE) > 0;
                boolean z4 = !z3 && schemaPropertyImpl.getMaxOccurs().signum() > 0;
                boolean z5 = z4 && schemaPropertyImpl.getMinOccurs().signum() == 0;
                SchemaType type = schemaPropertyImpl.getType();
                if (attributeProperty != null) {
                    if (attributeProperty.extendsJavaArray()) {
                        z3 = true;
                        z4 = false;
                        z5 = false;
                    }
                    if (attributeProperty.extendsJavaSingleton()) {
                        z4 = true;
                    }
                    if (!attributeProperty.extendsJavaOption()) {
                        z2 = z5;
                    }
                    type = attributeProperty.javaBasedOnType();
                    z5 = z2;
                }
                schemaPropertyImpl.setExtendsJava(type.getRef(), z4, z5, z3);
            }
        }
    }

    public static void assignJavaTypeCodes(SchemaProperty[] schemaPropertyArr) {
        for (SchemaProperty schemaProperty : schemaPropertyArr) {
            SchemaPropertyImpl schemaPropertyImpl = (SchemaPropertyImpl) schemaProperty;
            schemaPropertyImpl.setJavaTypeCode(javaTypeCodeForType(schemaPropertyImpl.javaBasedOnType()));
        }
    }

    public static void avoidExtensionMethods(Set set, SchemaTypeImpl schemaTypeImpl) {
        InterfaceExtension.MethodSignature[] methods;
        InterfaceExtension[] interfaceExtensions = schemaTypeImpl.getInterfaceExtensions();
        if (interfaceExtensions != null) {
            for (InterfaceExtension interfaceExtension : interfaceExtensions) {
                for (InterfaceExtension.MethodSignature methodSignature : interfaceExtension.getMethods()) {
                    String name = methodSignature.getName();
                    int i2 = 0;
                    while (true) {
                        String[] strArr = PREFIXES;
                        if (i2 >= strArr.length) {
                            break;
                        }
                        String str = strArr[i2];
                        if (name.startsWith(str)) {
                            set.add(name.substring(str.length()));
                        }
                        i2++;
                    }
                }
            }
        }
    }

    public static /* synthetic */ Class class$(String str) {
        try {
            return Class.forName(str);
        } catch (ClassNotFoundException e2) {
            throw a.a(e2);
        }
    }

    public static QName findTopName(SchemaType schemaType) {
        if (schemaType.getName() != null) {
            return schemaType.getName();
        }
        if (schemaType.isDocumentType()) {
            if (schemaType.getContentModel() != null && schemaType.getContentModel().getParticleType() == 4) {
                return schemaType.getDocumentElementName();
            }
            throw new IllegalStateException();
        } else if (!schemaType.isAttributeType()) {
            SchemaField containerField = schemaType.getContainerField();
            if (!$assertionsDisabled && containerField == null) {
                throw new AssertionError();
            } else if ($assertionsDisabled || schemaType.getOuterType() == null) {
                return containerField.getName();
            } else {
                throw new AssertionError();
            }
        } else if (schemaType.getAttributeModel() != null && schemaType.getAttributeModel().getAttributes().length == 1) {
            return schemaType.getAttributeTypeAttributeName();
        } else {
            throw new IllegalStateException();
        }
    }

    public static String getOutermostPackage(String str) {
        int indexOf;
        if (str != null && (indexOf = str.indexOf(46)) >= 0) {
            return str.substring(0, indexOf);
        }
        return "";
    }

    public static boolean isPropertyModelOrderInsensitive(SchemaProperty[] schemaPropertyArr) {
        for (SchemaProperty schemaProperty : schemaPropertyArr) {
            if (schemaProperty.hasNillable() == 1 || schemaProperty.hasDefault() == 1 || schemaProperty.hasFixed() == 1) {
                return false;
            }
            if (schemaProperty.hasDefault() != 0 && schemaProperty.getDefaultText() == null) {
                return false;
            }
        }
        return true;
    }

    public static boolean isStringType(SchemaType schemaType) {
        if (schemaType != null && schemaType.getSimpleVariety() == 1 && schemaType.getPrimitiveType().getBuiltinTypeCode() == 12) {
            return true;
        }
        return false;
    }

    public static int javaTypeCodeForType(SchemaType schemaType) {
        if (!schemaType.isSimpleType()) {
            return 0;
        }
        if (((SchemaTypeImpl) schemaType).getUserTypeHandlerName() != null) {
            return 20;
        }
        if (schemaType.getSimpleVariety() == 2) {
            SchemaType unionCommonBaseType = schemaType.getUnionCommonBaseType();
            if (unionCommonBaseType == null || unionCommonBaseType.isURType()) {
                return javaTypeCodeInCommon(schemaType.getUnionConstituentTypes());
            }
            schemaType = unionCommonBaseType;
        }
        if (schemaType.getSimpleVariety() == 3) {
            return 16;
        }
        if (schemaType.isURType()) {
            return 0;
        }
        switch (schemaType.getPrimitiveType().getBuiltinTypeCode()) {
            case 2:
                return 10;
            case 3:
                return 1;
            case 4:
            case 5:
                return 11;
            case 6:
                return 10;
            case 7:
                return 15;
            case 8:
                return 0;
            case 9:
                return 2;
            case 10:
                return 3;
            case 11:
                int decimalSize = schemaType.getDecimalSize();
                if (decimalSize == 8) {
                    return 4;
                }
                if (decimalSize == 16) {
                    return 5;
                }
                if (decimalSize == 32) {
                    return 6;
                }
                if (decimalSize != 64) {
                    return decimalSize != 1000000 ? 8 : 9;
                }
                return 7;
            case 12:
                if (!isStringType(schemaType.getBaseEnumType())) {
                    return 10;
                }
                if (schemaType.getEnumerationValues() == null || schemaType.getEnumerationValues().length <= 3668) {
                    return 18;
                }
                return 10;
            case 13:
                return 13;
            case 14:
            case 15:
            case 16:
            case 17:
            case 18:
            case 19:
            case 20:
            case 21:
                return 17;
            default:
                if (!$assertionsDisabled) {
                    StringBuffer a = a.a("unrecognized code ");
                    a.append(schemaType.getPrimitiveType().getBuiltinTypeCode());
                    throw new AssertionError(a.toString());
                }
                StringBuffer a2 = a.a("unrecognized code ");
                a2.append(schemaType.getPrimitiveType().getBuiltinTypeCode());
                a2.append(" of ");
                a2.append(schemaType.getPrimitiveType().getName());
                throw new IllegalStateException(a2.toString());
        }
    }

    public static int javaTypeCodeInCommon(SchemaType[] schemaTypeArr) {
        int i2 = 0;
        if (!(schemaTypeArr == null || schemaTypeArr.length == 0)) {
            i2 = javaTypeCodeForType(schemaTypeArr[0]);
            if (i2 == 19) {
                return i2;
            }
            for (int i3 = 1; i3 < schemaTypeArr.length; i3++) {
                if (i2 != javaTypeCodeForType(schemaTypeArr[i3])) {
                    return 19;
                }
            }
        }
        return i2;
    }

    public static void javaizeAllTypes(boolean z) {
        StscState stscState = StscState.get();
        ArrayList arrayList = new ArrayList();
        arrayList.addAll(Arrays.asList(stscState.documentTypes()));
        arrayList.addAll(Arrays.asList(stscState.attributeTypes()));
        arrayList.addAll(Arrays.asList(stscState.globalTypes()));
        if (z) {
            assignGlobalJavaNames(arrayList);
        }
        for (int i2 = 0; i2 < arrayList.size(); i2++) {
            SchemaType schemaType = (SchemaType) arrayList.get(i2);
            if (z) {
                javaizeType((SchemaTypeImpl) schemaType);
                String fullJavaName = schemaType.getFullJavaName();
                if (fullJavaName != null) {
                    stscState.addClassname(fullJavaName.replace('$', NameUtil.PERIOD), schemaType);
                }
            } else {
                skipJavaizingType((SchemaTypeImpl) schemaType);
            }
            arrayList.addAll(Arrays.asList(schemaType.getAnonymousTypes()));
            addAnonymousTypesFromRedefinition(schemaType, arrayList);
        }
    }

    public static void javaizeType(SchemaTypeImpl schemaTypeImpl) {
        SchemaProperty[] properties;
        if (!schemaTypeImpl.isJavaized()) {
            SchemaTypeImpl schemaTypeImpl2 = (SchemaTypeImpl) schemaTypeImpl.getBaseType();
            if (schemaTypeImpl2 != null) {
                javaizeType(schemaTypeImpl2);
            }
            if (!(schemaTypeImpl.getContentBasedOnType() == null || schemaTypeImpl.getContentBasedOnType() == schemaTypeImpl2)) {
                javaizeType((SchemaTypeImpl) schemaTypeImpl.getContentBasedOnType());
            }
            schemaTypeImpl.startJavaizing();
            schemaTypeImpl.setCompiled(true);
            secondPassProcessType(schemaTypeImpl);
            if (!schemaTypeImpl.isSimpleType()) {
                SchemaProperty[] elementProperties = schemaTypeImpl.getElementProperties();
                SchemaProperty[] attributeProperties = schemaTypeImpl.getAttributeProperties();
                HashSet hashSet = new HashSet();
                for (SchemaProperty schemaProperty : schemaTypeImpl2.getProperties()) {
                    String javaPropertyName = schemaProperty.getJavaPropertyName();
                    if ($assertionsDisabled || !hashSet.contains(javaPropertyName)) {
                        hashSet.add(javaPropertyName);
                    } else {
                        throw new AssertionError();
                    }
                }
                avoidExtensionMethods(hashSet, schemaTypeImpl);
                boolean z = true;
                while (true) {
                    if (elementProperties.length > 0) {
                        assignJavaPropertyNames(hashSet, elementProperties, schemaTypeImpl2, z);
                    }
                    assignJavaPropertyNames(hashSet, attributeProperties, schemaTypeImpl2, z);
                    if (!z) {
                        break;
                    }
                    z = false;
                }
                SchemaProperty[] properties2 = schemaTypeImpl.getProperties();
                boolean isPropertyModelOrderInsensitive = isPropertyModelOrderInsensitive(properties2);
                assignJavaTypeCodes(properties2);
                schemaTypeImpl.setOrderSensitive(!isPropertyModelOrderInsensitive);
            }
            if (!(schemaTypeImpl.getFullJavaName() == null && schemaTypeImpl.getOuterType() == null)) {
                assignJavaAnonymousTypeNames(schemaTypeImpl);
            }
            schemaTypeImpl.finishJavaizing();
        }
    }

    public static String pickConstantName(Set set, String str) {
        String upperCaseUnderbar = NameUtil.upperCaseUnderbar(str);
        if (upperCaseUnderbar.length() == 0) {
            upperCaseUnderbar = "X";
        }
        if (upperCaseUnderbar.startsWith("INT_")) {
            upperCaseUnderbar = a.a("X_", upperCaseUnderbar);
        }
        int i2 = 1;
        String str2 = upperCaseUnderbar;
        while (set.contains(str2)) {
            i2++;
            StringBuffer stringBuffer = new StringBuffer();
            stringBuffer.append(upperCaseUnderbar);
            stringBuffer.append("_");
            stringBuffer.append(i2);
            str2 = stringBuffer.toString();
        }
        set.add(str2);
        return str2;
    }

    public static String pickFullJavaClassName(Set set, QName qName, String str, boolean z, boolean z2) {
        boolean z3;
        if (str == null || str.indexOf(46) < 0) {
            StscState stscState = StscState.get();
            String namespaceURI = qName.getNamespaceURI();
            String classNameFromQName = NameUtil.getClassNameFromQName(qName);
            String packageOverride = stscState.getPackageOverride(namespaceURI);
            if (packageOverride != null) {
                StringBuffer c = a.c(packageOverride, ".");
                c.append(classNameFromQName.substring(classNameFromQName.lastIndexOf(46) + 1));
                classNameFromQName = c.toString();
            }
            String javaPrefix = stscState.getJavaPrefix(namespaceURI);
            if (javaPrefix != null) {
                StringBuffer stringBuffer = new StringBuffer();
                stringBuffer.append(classNameFromQName.substring(0, classNameFromQName.lastIndexOf(46) + 1));
                stringBuffer.append(javaPrefix);
                stringBuffer.append(classNameFromQName.substring(classNameFromQName.lastIndexOf(46) + 1));
                classNameFromQName = stringBuffer.toString();
            }
            if (str != null) {
                StringBuffer stringBuffer2 = new StringBuffer();
                stringBuffer2.append(classNameFromQName.substring(0, classNameFromQName.lastIndexOf(46) + 1));
                stringBuffer2.append(str);
                classNameFromQName = stringBuffer2.toString();
            }
            boolean protectReservedGlobalClassNames = protectReservedGlobalClassNames(classNameFromQName);
            if (str == null) {
                if (z) {
                    classNameFromQName = a.a(classNameFromQName, "Document");
                } else if (z2) {
                    classNameFromQName = a.a(classNameFromQName, "Attribute");
                }
                String javaSuffix = stscState.getJavaSuffix(namespaceURI);
                if (javaSuffix != null) {
                    classNameFromQName = a.a(classNameFromQName, javaSuffix);
                }
            }
            str = classNameFromQName;
            z3 = protectReservedGlobalClassNames;
        } else {
            z3 = protectReservedGlobalClassNames(str);
        }
        String outermostPackage = getOutermostPackage(str);
        String b2 = z3 ? a.b(str, 1) : str;
        int i2 = 1;
        while (true) {
            if (set.contains(b2.toLowerCase()) || b2.equals(outermostPackage)) {
                i2++;
                b2 = a.b(str, i2);
            } else {
                set.add(b2.toLowerCase());
                return b2;
            }
        }
    }

    public static String pickFullJavaImplName(Set set, String str) {
        String str2;
        String str3;
        int lastIndexOf = str.lastIndexOf(46);
        if (lastIndexOf >= 0) {
            str3 = str.substring(lastIndexOf + 1);
            str2 = str.substring(0, lastIndexOf);
        } else {
            str3 = str;
            str2 = null;
        }
        StringBuffer stringBuffer = new StringBuffer();
        stringBuffer.append(str2);
        stringBuffer.append(".impl.");
        stringBuffer.append(str3);
        stringBuffer.append("Impl");
        String stringBuffer2 = stringBuffer.toString();
        int i2 = 1;
        String str4 = stringBuffer2;
        while (set.contains(str4.toLowerCase())) {
            i2++;
            str4 = a.b(stringBuffer2, i2);
        }
        set.add(str4.toLowerCase());
        return str4;
    }

    public static String pickInnerJavaClassName(Set set, String str, String str2) {
        if (str2 == null) {
            str2 = NameUtil.upperCamelCase(str);
        }
        String b2 = protectReservedInnerClassNames(str2) ? a.b(str2, 1) : str2;
        int i2 = 1;
        while (set.contains(b2)) {
            i2++;
            b2 = a.b(str2, i2);
        }
        set.add(b2);
        return b2;
    }

    public static String pickInnerJavaImplName(Set set, String str, String str2) {
        if (str2 == null) {
            StringBuffer stringBuffer = new StringBuffer();
            stringBuffer.append(NameUtil.upperCamelCase(str));
            stringBuffer.append("Impl");
            str2 = stringBuffer.toString();
        }
        int i2 = 1;
        String str3 = str2;
        while (set.contains(str3)) {
            i2++;
            str3 = a.b(str2, i2);
        }
        set.add(str3);
        return str3;
    }

    public static String pickJavaPropertyName(Set set, String str, String str2) {
        if (str2 == null) {
            str2 = NameUtil.upperCamelCase(str);
        }
        String b2 = protectReservedPropertyNames(str2) ? a.b(str2, 1) : str2;
        int i2 = 1;
        while (set.contains(b2)) {
            i2++;
            b2 = a.b(str2, i2);
        }
        set.add(b2);
        return b2;
    }

    public static boolean protectReservedGlobalClassNames(String str) {
        String substring = str.substring(str.lastIndexOf(46) + 1);
        if (!substring.endsWith("Document") || substring.equals("Document")) {
            return false;
        }
        return true;
    }

    public static boolean protectReservedInnerClassNames(String str) {
        return str.equals("Enum") || str.equals("Factory");
    }

    public static boolean protectReservedPropertyNames(String str) {
        return PROTECTED_PROPERTIES_SET.contains(str) || (str.endsWith(SoapEncSchemaTypeSystem.SOAP_ARRAY) && !str.equals(SoapEncSchemaTypeSystem.SOAP_ARRAY));
    }

    public static void secondPassProcessType(SchemaTypeImpl schemaTypeImpl) {
        XmlAnySimpleType[] enumerationValues;
        if (isStringType(schemaTypeImpl) && (enumerationValues = schemaTypeImpl.getEnumerationValues()) != null) {
            if (enumerationValues.length > 3668) {
                StscState stscState = StscState.get();
                StringBuffer a = a.a("SchemaType Enumeration found with too many enumeration values to create a Java enumeration. The base SchemaType \"");
                a.append(schemaTypeImpl.getBaseEnumType());
                a.append("\" will be used instead");
                stscState.warning(a.toString(), 1, (XmlObject) null);
                SchemaTypeImpl schemaTypeImpl2 = (SchemaTypeImpl) schemaTypeImpl.getBaseEnumType();
                return;
            }
            SchemaStringEnumEntry[] schemaStringEnumEntryArr = new SchemaStringEnumEntry[enumerationValues.length];
            SchemaType baseEnumType = schemaTypeImpl.getBaseEnumType();
            int i2 = 0;
            if (baseEnumType == schemaTypeImpl) {
                HashSet hashSet = new HashSet();
                while (i2 < enumerationValues.length) {
                    String stringValue = enumerationValues[i2].getStringValue();
                    int i3 = i2 + 1;
                    schemaStringEnumEntryArr[i2] = new SchemaStringEnumEntryImpl(stringValue, i3, pickConstantName(hashSet, stringValue));
                    i2 = i3;
                }
            } else {
                while (i2 < enumerationValues.length) {
                    schemaStringEnumEntryArr[i2] = baseEnumType.enumEntryForString(enumerationValues[i2].getStringValue());
                    i2++;
                }
            }
            schemaTypeImpl.setStringEnumEntries(schemaStringEnumEntryArr);
        }
    }

    public static void setExtensions(SchemaTypeImpl schemaTypeImpl, StscState stscState) {
        String fullJavaName = schemaTypeImpl.getFullJavaName();
        BindingConfig bindingConfig = stscState.getBindingConfig();
        if (fullJavaName != null && bindingConfig != null) {
            schemaTypeImpl.setInterfaceExtensions(bindingConfig.getInterfaceExtensions(fullJavaName));
            schemaTypeImpl.setPrePostExtension(bindingConfig.getPrePostExtension(fullJavaName));
        }
    }

    public static void setUserTypes(SchemaTypeImpl schemaTypeImpl, StscState stscState) {
        UserType lookupUserTypeForQName;
        BindingConfig bindingConfig = stscState.getBindingConfig();
        if (bindingConfig != null && (lookupUserTypeForQName = bindingConfig.lookupUserTypeForQName(schemaTypeImpl.getName())) != null) {
            schemaTypeImpl.setUserTypeName(lookupUserTypeForQName.getJavaName());
            schemaTypeImpl.setUserTypeHandlerName(lookupUserTypeForQName.getStaticHandler());
        }
    }

    public static void skipJavaizingType(SchemaTypeImpl schemaTypeImpl) {
        if (!schemaTypeImpl.isJavaized()) {
            SchemaTypeImpl schemaTypeImpl2 = (SchemaTypeImpl) schemaTypeImpl.getBaseType();
            if (schemaTypeImpl2 != null) {
                skipJavaizingType(schemaTypeImpl2);
            }
            schemaTypeImpl.startJavaizing();
            secondPassProcessType(schemaTypeImpl);
            schemaTypeImpl.finishJavaizing();
        }
    }

    public static void verifyInterfaceNameCollisions(Set set, StscState stscState) {
        PrePostExtension[] prePostExtensions;
        BindingConfig bindingConfig = stscState.getBindingConfig();
        if (bindingConfig != null) {
            InterfaceExtension[] interfaceExtensions = bindingConfig.getInterfaceExtensions();
            for (int i2 = 0; i2 < interfaceExtensions.length; i2++) {
                if (set.contains(interfaceExtensions[i2].getInterface().toLowerCase())) {
                    StringBuffer a = a.a("InterfaceExtension interface '");
                    a.append(interfaceExtensions[i2].getInterface());
                    a.append("' creates a name collision with one of the generated interfaces or classes.");
                    stscState.error(a.toString(), 0, (XmlObject) null);
                }
                String staticHandler = interfaceExtensions[i2].getStaticHandler();
                if (staticHandler != null && set.contains(staticHandler.toLowerCase())) {
                    stscState.error(a.a("InterfaceExtension handler class '", staticHandler, "' creates a name collision with one of the generated interfaces or classes."), 0, (XmlObject) null);
                }
            }
            for (PrePostExtension prePostExtension : bindingConfig.getPrePostExtensions()) {
                String staticHandler2 = prePostExtension.getStaticHandler();
                if (staticHandler2 != null && set.contains(staticHandler2.toLowerCase())) {
                    stscState.error(a.a("PrePostExtension handler class '", staticHandler2, "' creates a name collision with one of the generated interfaces or classes."), 0, (XmlObject) null);
                }
            }
        }
    }
}
