package org.apache.xmlbeans.impl.schema;

import b.b.a.a.a;
import java.io.File;
import java.net.URI;
import java.net.URISyntaxException;
import java.net.URL;
import java.util.ArrayList;
import java.util.Arrays;
import java.util.Collection;
import java.util.Collections;
import java.util.HashMap;
import java.util.HashSet;
import java.util.LinkedHashMap;
import java.util.LinkedHashSet;
import java.util.List;
import java.util.Map;
import java.util.Set;
import org.apache.lucene.codecs.lucene3x.Lucene3xNormsProducer;
import org.apache.poi.javax.xml.namespace.QName;
import org.apache.poi.openxml4j.opc.internal.ZipHelper;
import org.apache.xerces.impl.xs.SchemaSymbols;
import org.apache.xmlbeans.BindingConfig;
import org.apache.xmlbeans.SchemaAttributeGroup;
import org.apache.xmlbeans.SchemaComponent;
import org.apache.xmlbeans.SchemaGlobalAttribute;
import org.apache.xmlbeans.SchemaGlobalElement;
import org.apache.xmlbeans.SchemaIdentityConstraint;
import org.apache.xmlbeans.SchemaModelGroup;
import org.apache.xmlbeans.SchemaType;
import org.apache.xmlbeans.SchemaTypeLoader;
import org.apache.xmlbeans.SystemProperties;
import org.apache.xmlbeans.XmlBeans;
import org.apache.xmlbeans.XmlError;
import org.apache.xmlbeans.XmlErrorCodes;
import org.apache.xmlbeans.XmlObject;
import org.apache.xmlbeans.XmlOptions;
import org.apache.xmlbeans.impl.common.JarHelper;
import org.apache.xmlbeans.impl.common.QNameHelper;
import org.apache.xmlbeans.impl.common.ResolverUtil;
import org.apache.xmlbeans.impl.jam.xml.JamXmlElements;
import org.apache.xmlbeans.impl.util.HexBin;
import org.apache.xmlbeans.impl.values.XmlStringImpl;
import org.apache.xmlbeans.impl.values.XmlValueOutOfRangeException;
import org.xml.sax.EntityResolver;

public class StscState {
    public static final /* synthetic */ boolean $assertionsDisabled;
    public static final Object CHAMELEON_INCLUDE_URI = new Object();
    public static final SchemaType.Ref[] EMPTY_STREF_ARRAY = new SchemaType.Ref[0];
    public static final SchemaType[] EMPTY_ST_ARRAY = new SchemaType[0];
    public static final XmlValueRef[] FACETS_LIST;
    public static final XmlValueRef[] FACETS_NONE = {null, null, null, null, null, null, null, null, null, null, null, null};
    public static final XmlValueRef[] FACETS_UNION = FACETS_NONE;
    public static final XmlValueRef[] FACETS_WS_COLLAPSE;
    public static final boolean[] FIXED_FACETS_LIST;
    public static final boolean[] FIXED_FACETS_NONE = {false, false, false, false, false, false, false, false, false, false, false, false};
    public static final boolean[] FIXED_FACETS_UNION = FIXED_FACETS_NONE;
    public static final boolean[] FIXED_FACETS_WS;
    public static final String PROJECT_URL_PREFIX = "project://local";
    public static final XmlValueRef XMLSTR_COLLAPSE = buildString(SchemaSymbols.ATTVAL_PRESERVE);
    public static final XmlValueRef XMLSTR_PRESERVE = buildString(SchemaSymbols.ATTVAL_PRESERVE);
    public static final XmlValueRef XMLSTR_REPLACE = buildString(SchemaSymbols.ATTVAL_PRESERVE);
    public static /* synthetic */ Class class$org$apache$xmlbeans$impl$schema$StscState;
    public static /* synthetic */ Class class$org$apache$xmlbeans$impl$xb$xsdschema$SchemaDocument;
    public static ThreadLocal tl_stscStack = new ThreadLocal();
    public boolean _allowPartial;
    public List _annotations;
    public Map _attributeGroups;
    public Map _attributeTypes;
    public URI _baseURI;
    public Map _compatMap;
    public BindingConfig _config;
    public Map _containers;
    public SchemaDependencies _dependencies;
    public byte[] _digest;
    public Map _documentTypes;
    public boolean _doingDownloads;
    public EntityResolver _entityResolver;
    public Collection _errorListener;
    public String _givenStsName;
    public Map _globalAttributes;
    public Map _globalElements;
    public Map _globalTypes;
    public Map _idConstraints;
    public SchemaTypeLoader _importingLoader;
    public boolean _mdefAll;
    public Set _mdefNamespaces;
    public Map _misspelledNames;
    public Map _modelGroups;
    public Set _namespaces;
    public boolean _noAnn;
    public boolean _noDigest;
    public boolean _noPvr;
    public boolean _noUpa;
    public Set _processingGroups;
    public int _recoveredErrors;
    public Map _redefinedAttributeGroups;
    public Map _redefinedGlobalTypes;
    public Map _redefinedModelGroups;
    public SchemaTypeLoader _s4sloader;
    public File _schemasDir;
    public Map _sourceForUri;
    public SchemaTypeSystemImpl _target;
    public Map _typesByClassname;

    public static final class StscStack {
        public StscState current;
        public ArrayList stack;

        public StscStack() {
            this.stack = new ArrayList();
        }

        public final void pop() {
            ArrayList arrayList = this.stack;
            this.current = (StscState) arrayList.get(arrayList.size() - 1);
            ArrayList arrayList2 = this.stack;
            arrayList2.remove(arrayList2.size() - 1);
        }

        public final StscState push() {
            this.stack.add(this.current);
            StscState stscState = new StscState();
            this.current = stscState;
            return stscState;
        }
    }

    static {
        Class cls = class$org$apache$xmlbeans$impl$schema$StscState;
        if (cls == null) {
            cls = class$("org.apache.xmlbeans.impl.schema.StscState");
            class$org$apache$xmlbeans$impl$schema$StscState = cls;
        }
        $assertionsDisabled = !cls.desiredAssertionStatus();
        XmlValueRef[] xmlValueRefArr = {null, null, null, null, null, null, null, null, null, build_wsstring(3), null, null};
        FACETS_WS_COLLAPSE = xmlValueRefArr;
        boolean[] zArr = {false, false, false, false, false, false, false, false, false, true, false, false};
        FIXED_FACETS_WS = zArr;
        FACETS_LIST = xmlValueRefArr;
        FIXED_FACETS_LIST = zArr;
    }

    private void addContainer(SchemaContainer schemaContainer) {
        this._containers.put(schemaContainer.getNamespace(), schemaContainer);
        List redefinedModelGroups = schemaContainer.redefinedModelGroups();
        for (int i2 = 0; i2 < redefinedModelGroups.size(); i2++) {
            this._redefinedModelGroups.put(((SchemaModelGroup) redefinedModelGroups.get(i2)).getName(), redefinedModelGroups.get(i2));
        }
        List redefinedAttributeGroups = schemaContainer.redefinedAttributeGroups();
        for (int i3 = 0; i3 < redefinedAttributeGroups.size(); i3++) {
            this._redefinedAttributeGroups.put(((SchemaAttributeGroup) redefinedAttributeGroups.get(i3)).getName(), redefinedAttributeGroups.get(i3));
        }
        List redefinedGlobalTypes = schemaContainer.redefinedGlobalTypes();
        for (int i4 = 0; i4 < redefinedGlobalTypes.size(); i4++) {
            this._redefinedGlobalTypes.put(((SchemaType) redefinedGlobalTypes.get(i4)).getName(), redefinedGlobalTypes.get(i4));
        }
        List globalElements = schemaContainer.globalElements();
        for (int i5 = 0; i5 < globalElements.size(); i5++) {
            this._globalElements.put(((SchemaGlobalElement) globalElements.get(i5)).getName(), globalElements.get(i5));
        }
        List globalAttributes = schemaContainer.globalAttributes();
        for (int i6 = 0; i6 < globalAttributes.size(); i6++) {
            this._globalAttributes.put(((SchemaGlobalAttribute) globalAttributes.get(i6)).getName(), globalAttributes.get(i6));
        }
        List modelGroups = schemaContainer.modelGroups();
        for (int i7 = 0; i7 < modelGroups.size(); i7++) {
            this._modelGroups.put(((SchemaModelGroup) modelGroups.get(i7)).getName(), modelGroups.get(i7));
        }
        List attributeGroups = schemaContainer.attributeGroups();
        for (int i8 = 0; i8 < attributeGroups.size(); i8++) {
            this._attributeGroups.put(((SchemaAttributeGroup) attributeGroups.get(i8)).getName(), attributeGroups.get(i8));
        }
        List globalTypes = schemaContainer.globalTypes();
        for (int i9 = 0; i9 < globalTypes.size(); i9++) {
            SchemaType schemaType = (SchemaType) globalTypes.get(i9);
            this._globalTypes.put(schemaType.getName(), schemaType);
            if (schemaType.getFullJavaName() != null) {
                addClassname(schemaType.getFullJavaName(), schemaType);
            }
        }
        List documentTypes = schemaContainer.documentTypes();
        for (int i10 = 0; i10 < documentTypes.size(); i10++) {
            SchemaType schemaType2 = (SchemaType) documentTypes.get(i10);
            this._documentTypes.put(schemaType2.getProperties()[0].getName(), schemaType2);
            if (schemaType2.getFullJavaName() != null) {
                addClassname(schemaType2.getFullJavaName(), schemaType2);
            }
        }
        List attributeTypes = schemaContainer.attributeTypes();
        for (int i11 = 0; i11 < attributeTypes.size(); i11++) {
            SchemaType schemaType3 = (SchemaType) attributeTypes.get(i11);
            this._attributeTypes.put(schemaType3.getProperties()[0].getName(), schemaType3);
            if (schemaType3.getFullJavaName() != null) {
                addClassname(schemaType3.getFullJavaName(), schemaType3);
            }
        }
        List identityConstraints = schemaContainer.identityConstraints();
        for (int i12 = 0; i12 < identityConstraints.size(); i12++) {
            this._idConstraints.put(((SchemaIdentityConstraint) identityConstraints.get(i12)).getName(), identityConstraints.get(i12));
        }
        this._annotations.addAll(schemaContainer.annotations());
        this._namespaces.add(schemaContainer.getNamespace());
        schemaContainer.unsetImmutable();
    }

    public static void addError(Collection collection, String str, int i2, XmlObject xmlObject) {
        collection.add(XmlError.forObject(str, 0, xmlObject));
    }

    public static void addInfo(Collection collection, String str) {
        collection.add(XmlError.forMessage(str, 2));
    }

    public static void addWarning(Collection collection, String str, int i2, XmlObject xmlObject) {
        collection.add(XmlError.forObject(str, 1, xmlObject));
    }

    public static Set buildDefaultMdefNamespaces() {
        return new HashSet(Arrays.asList("http://www.openuri.org/2002/04/soap/conversation/"));
    }

    public static XmlValueRef buildString(String str) {
        if (str == null) {
            return null;
        }
        try {
            XmlStringImpl xmlStringImpl = new XmlStringImpl();
            xmlStringImpl.set(str);
            xmlStringImpl.setImmutable();
            return new XmlValueRef(xmlStringImpl);
        } catch (XmlValueOutOfRangeException unused) {
            return null;
        }
    }

    public static XmlValueRef build_wsstring(int i2) {
        if (i2 == 1) {
            return XMLSTR_PRESERVE;
        }
        if (i2 == 2) {
            return XMLSTR_REPLACE;
        }
        if (i2 != 3) {
            return null;
        }
        return XMLSTR_COLLAPSE;
    }

    public static /* synthetic */ Class class$(String str) {
        try {
            return Class.forName(str);
        } catch (ClassNotFoundException e2) {
            throw a.a(e2);
        }
    }

    private QName compatName(QName qName, String str) {
        QName qName2;
        if (qName.getNamespaceURI().length() == 0 && str != null && str.length() > 0) {
            qName = new QName(str, qName.getLocalPart());
        }
        Map map = this._compatMap;
        return (map == null || (qName2 = (QName) map.get(qName)) == null) ? qName : qName2;
    }

    public static String crunchName(QName qName) {
        return qName.getLocalPart().toLowerCase();
    }

    public static void end() {
        StscStack stscStack = (StscStack) tl_stscStack.get();
        stscStack.pop();
        if (stscStack.stack.size() == 0) {
            tl_stscStack.set(null);
        }
    }

    public static StscState get() {
        return ((StscStack) tl_stscStack.get()).current;
    }

    private boolean ignoreMdef(QName qName) {
        return this._mdefNamespaces.contains(qName.getNamespaceURI());
    }

    public static StscState start() {
        StscStack stscStack = (StscStack) tl_stscStack.get();
        if (stscStack == null) {
            stscStack = new StscStack();
            tl_stscStack.set(stscStack);
        }
        return stscStack.push();
    }

    public void addAnnotation(SchemaAnnotationImpl schemaAnnotationImpl, String str) {
        if (schemaAnnotationImpl != null) {
            SchemaContainer container = getContainer(str);
            if ($assertionsDisabled || (container != null && container == schemaAnnotationImpl.getContainer())) {
                this._annotations.add(schemaAnnotationImpl);
                container.addAnnotation(schemaAnnotationImpl);
                return;
            }
            throw new AssertionError();
        }
    }

    public void addAttributeGroup(SchemaAttributeGroupImpl schemaAttributeGroupImpl, SchemaAttributeGroupImpl schemaAttributeGroupImpl2) {
        if (schemaAttributeGroupImpl != null) {
            QName name = schemaAttributeGroupImpl.getName();
            SchemaContainer container = getContainer(name.getNamespaceURI());
            if (!$assertionsDisabled && (container == null || container != schemaAttributeGroupImpl.getContainer())) {
                throw new AssertionError();
            } else if (schemaAttributeGroupImpl2 != null) {
                if (!this._redefinedAttributeGroups.containsKey(schemaAttributeGroupImpl2)) {
                    this._redefinedAttributeGroups.put(schemaAttributeGroupImpl2, schemaAttributeGroupImpl);
                    container.addRedefinedAttributeGroup(schemaAttributeGroupImpl.getRef());
                } else if (ignoreMdef(name)) {
                } else {
                    if (this._mdefAll) {
                        warning(XmlErrorCodes.SCHEMA_PROPERTIES$DUPLICATE, new Object[]{"attribute group", QNameHelper.pretty(name), ((SchemaComponent) this._redefinedAttributeGroups.get(schemaAttributeGroupImpl2)).getSourceName()}, schemaAttributeGroupImpl.getParseObject());
                        return;
                    }
                    error(XmlErrorCodes.SCHEMA_PROPERTIES$DUPLICATE, new Object[]{"attribute group", QNameHelper.pretty(name), ((SchemaComponent) this._redefinedAttributeGroups.get(schemaAttributeGroupImpl2)).getSourceName()}, schemaAttributeGroupImpl.getParseObject());
                }
            } else if (!this._attributeGroups.containsKey(name)) {
                this._attributeGroups.put(schemaAttributeGroupImpl.getName(), schemaAttributeGroupImpl);
                addSpelling(schemaAttributeGroupImpl.getName(), schemaAttributeGroupImpl);
                container.addAttributeGroup(schemaAttributeGroupImpl.getRef());
            } else if (ignoreMdef(name)) {
            } else {
                if (this._mdefAll) {
                    warning(XmlErrorCodes.SCHEMA_PROPERTIES$DUPLICATE, new Object[]{"attribute group", QNameHelper.pretty(name), ((SchemaComponent) this._attributeGroups.get(name)).getSourceName()}, schemaAttributeGroupImpl.getParseObject());
                    return;
                }
                error(XmlErrorCodes.SCHEMA_PROPERTIES$DUPLICATE, new Object[]{"attribute group", QNameHelper.pretty(name), ((SchemaComponent) this._attributeGroups.get(name)).getSourceName()}, schemaAttributeGroupImpl.getParseObject());
            }
        }
    }

    public void addAttributeType(SchemaTypeImpl schemaTypeImpl, QName qName) {
        if (!this._attributeTypes.containsKey(qName)) {
            this._attributeTypes.put(qName, schemaTypeImpl);
            SchemaContainer container = getContainer(qName.getNamespaceURI());
            if ($assertionsDisabled || (container != null && container == schemaTypeImpl.getContainer())) {
                container.addAttributeType(schemaTypeImpl.getRef());
                return;
            }
            throw new AssertionError();
        } else if (ignoreMdef(qName)) {
        } else {
            if (this._mdefAll) {
                warning(XmlErrorCodes.SCHEMA_PROPERTIES$DUPLICATE, new Object[]{"global attribute", QNameHelper.pretty(qName), ((SchemaComponent) this._attributeTypes.get(qName)).getSourceName()}, schemaTypeImpl.getParseObject());
                return;
            }
            error(XmlErrorCodes.SCHEMA_PROPERTIES$DUPLICATE, new Object[]{"global attribute", QNameHelper.pretty(qName), ((SchemaComponent) this._attributeTypes.get(qName)).getSourceName()}, schemaTypeImpl.getParseObject());
        }
    }

    public void addClassname(String str, SchemaType schemaType) {
        this._typesByClassname.put(str, schemaType);
    }

    public void addDocumentType(SchemaTypeImpl schemaTypeImpl, QName qName) {
        if (!this._documentTypes.containsKey(qName)) {
            this._documentTypes.put(qName, schemaTypeImpl);
            SchemaContainer container = getContainer(qName.getNamespaceURI());
            if ($assertionsDisabled || (container != null && container == schemaTypeImpl.getContainer())) {
                container.addDocumentType(schemaTypeImpl.getRef());
                return;
            }
            throw new AssertionError();
        } else if (ignoreMdef(qName)) {
        } else {
            if (this._mdefAll) {
                warning(XmlErrorCodes.SCHEMA_PROPERTIES$DUPLICATE, new Object[]{"global element", QNameHelper.pretty(qName), ((SchemaComponent) this._documentTypes.get(qName)).getSourceName()}, schemaTypeImpl.getParseObject());
                return;
            }
            error(XmlErrorCodes.SCHEMA_PROPERTIES$DUPLICATE, new Object[]{"global element", QNameHelper.pretty(qName), ((SchemaComponent) this._documentTypes.get(qName)).getSourceName()}, schemaTypeImpl.getParseObject());
        }
    }

    public void addGlobalAttribute(SchemaGlobalAttributeImpl schemaGlobalAttributeImpl) {
        if (schemaGlobalAttributeImpl != null) {
            QName name = schemaGlobalAttributeImpl.getName();
            this._globalAttributes.put(name, schemaGlobalAttributeImpl);
            addSpelling(name, schemaGlobalAttributeImpl);
            SchemaContainer container = getContainer(name.getNamespaceURI());
            if ($assertionsDisabled || (container != null && container == schemaGlobalAttributeImpl.getContainer())) {
                container.addGlobalAttribute(schemaGlobalAttributeImpl.getRef());
                return;
            }
            throw new AssertionError();
        }
    }

    public void addGlobalElement(SchemaGlobalElementImpl schemaGlobalElementImpl) {
        if (schemaGlobalElementImpl != null) {
            QName name = schemaGlobalElementImpl.getName();
            this._globalElements.put(name, schemaGlobalElementImpl);
            SchemaContainer container = getContainer(name.getNamespaceURI());
            if ($assertionsDisabled || (container != null && container == schemaGlobalElementImpl.getContainer())) {
                container.addGlobalElement(schemaGlobalElementImpl.getRef());
                addSpelling(name, schemaGlobalElementImpl);
                return;
            }
            throw new AssertionError();
        }
    }

    public void addGlobalType(SchemaTypeImpl schemaTypeImpl, SchemaTypeImpl schemaTypeImpl2) {
        if (schemaTypeImpl != null) {
            QName name = schemaTypeImpl.getName();
            SchemaContainer container = getContainer(name.getNamespaceURI());
            if (!$assertionsDisabled && (container == null || container != schemaTypeImpl.getContainer())) {
                throw new AssertionError();
            } else if (schemaTypeImpl2 != null) {
                if (!this._redefinedGlobalTypes.containsKey(schemaTypeImpl2)) {
                    this._redefinedGlobalTypes.put(schemaTypeImpl2, schemaTypeImpl);
                    container.addRedefinedType(schemaTypeImpl.getRef());
                } else if (ignoreMdef(name)) {
                } else {
                    if (this._mdefAll) {
                        warning(XmlErrorCodes.SCHEMA_PROPERTIES$DUPLICATE, new Object[]{"global type", QNameHelper.pretty(name), ((SchemaType) this._redefinedGlobalTypes.get(schemaTypeImpl2)).getSourceName()}, schemaTypeImpl.getParseObject());
                        return;
                    }
                    error(XmlErrorCodes.SCHEMA_PROPERTIES$DUPLICATE, new Object[]{"global type", QNameHelper.pretty(name), ((SchemaType) this._redefinedGlobalTypes.get(schemaTypeImpl2)).getSourceName()}, schemaTypeImpl.getParseObject());
                }
            } else if (!this._globalTypes.containsKey(name)) {
                this._globalTypes.put(name, schemaTypeImpl);
                container.addGlobalType(schemaTypeImpl.getRef());
                addSpelling(name, schemaTypeImpl);
            } else if (ignoreMdef(name)) {
            } else {
                if (this._mdefAll) {
                    warning(XmlErrorCodes.SCHEMA_PROPERTIES$DUPLICATE, new Object[]{"global type", QNameHelper.pretty(name), ((SchemaType) this._globalTypes.get(name)).getSourceName()}, schemaTypeImpl.getParseObject());
                    return;
                }
                error(XmlErrorCodes.SCHEMA_PROPERTIES$DUPLICATE, new Object[]{"global type", QNameHelper.pretty(name), ((SchemaType) this._globalTypes.get(name)).getSourceName()}, schemaTypeImpl.getParseObject());
            }
        }
    }

    public void addIdConstraint(SchemaIdentityConstraintImpl schemaIdentityConstraintImpl) {
        if (schemaIdentityConstraintImpl != null) {
            QName name = schemaIdentityConstraintImpl.getName();
            SchemaContainer container = getContainer(name.getNamespaceURI());
            if (!$assertionsDisabled && (container == null || container != schemaIdentityConstraintImpl.getContainer())) {
                throw new AssertionError();
            } else if (!this._idConstraints.containsKey(name)) {
                this._idConstraints.put(name, schemaIdentityConstraintImpl);
                addSpelling(schemaIdentityConstraintImpl.getName(), schemaIdentityConstraintImpl);
                container.addIdentityConstraint(schemaIdentityConstraintImpl.getRef());
            } else if (!ignoreMdef(name)) {
                warning(XmlErrorCodes.SCHEMA_PROPERTIES$DUPLICATE, new Object[]{"identity constraint", QNameHelper.pretty(name), ((SchemaComponent) this._idConstraints.get(name)).getSourceName()}, schemaIdentityConstraintImpl.getParseObject());
            }
        }
    }

    public void addModelGroup(SchemaModelGroupImpl schemaModelGroupImpl, SchemaModelGroupImpl schemaModelGroupImpl2) {
        if (schemaModelGroupImpl != null) {
            QName name = schemaModelGroupImpl.getName();
            SchemaContainer container = getContainer(name.getNamespaceURI());
            if (!$assertionsDisabled && (container == null || container != schemaModelGroupImpl.getContainer())) {
                throw new AssertionError();
            } else if (schemaModelGroupImpl2 != null) {
                if (!this._redefinedModelGroups.containsKey(schemaModelGroupImpl2)) {
                    this._redefinedModelGroups.put(schemaModelGroupImpl2, schemaModelGroupImpl);
                    container.addRedefinedModelGroup(schemaModelGroupImpl.getRef());
                } else if (ignoreMdef(name)) {
                } else {
                    if (this._mdefAll) {
                        warning(XmlErrorCodes.SCHEMA_PROPERTIES$DUPLICATE, new Object[]{"model group", QNameHelper.pretty(name), ((SchemaComponent) this._redefinedModelGroups.get(schemaModelGroupImpl2)).getSourceName()}, schemaModelGroupImpl.getParseObject());
                        return;
                    }
                    error(XmlErrorCodes.SCHEMA_PROPERTIES$DUPLICATE, new Object[]{"model group", QNameHelper.pretty(name), ((SchemaComponent) this._redefinedModelGroups.get(schemaModelGroupImpl2)).getSourceName()}, schemaModelGroupImpl.getParseObject());
                }
            } else if (!this._modelGroups.containsKey(name)) {
                this._modelGroups.put(schemaModelGroupImpl.getName(), schemaModelGroupImpl);
                addSpelling(schemaModelGroupImpl.getName(), schemaModelGroupImpl);
                container.addModelGroup(schemaModelGroupImpl.getRef());
            } else if (ignoreMdef(name)) {
            } else {
                if (this._mdefAll) {
                    warning(XmlErrorCodes.SCHEMA_PROPERTIES$DUPLICATE, new Object[]{"model group", QNameHelper.pretty(name), ((SchemaComponent) this._modelGroups.get(name)).getSourceName()}, schemaModelGroupImpl.getParseObject());
                    return;
                }
                error(XmlErrorCodes.SCHEMA_PROPERTIES$DUPLICATE, new Object[]{"model group", QNameHelper.pretty(name), ((SchemaComponent) this._modelGroups.get(name)).getSourceName()}, schemaModelGroupImpl.getParseObject());
            }
        }
    }

    public void addNamespace(String str) {
        this._namespaces.add(str);
    }

    public void addNewContainer(String str) {
        if (!this._containers.containsKey(str)) {
            SchemaContainer schemaContainer = new SchemaContainer(str);
            schemaContainer.setTypeSystem(sts());
            addNamespace(str);
            this._containers.put(str, schemaContainer);
        }
    }

    public void addSchemaDigest(byte[] bArr) {
        if (!this._noDigest) {
            if (bArr == null) {
                this._noDigest = true;
                this._digest = null;
                return;
            }
            if (this._digest == null) {
                this._digest = new byte[16];
            }
            int length = this._digest.length;
            if (bArr.length < length) {
                length = bArr.length;
            }
            for (int i2 = 0; i2 < length; i2++) {
                byte[] bArr2 = this._digest;
                bArr2[i2] = (byte) (bArr2[i2] ^ bArr[i2]);
            }
        }
    }

    public void addSourceUri(String str, String str2) {
        if (str != null) {
            if (str2 == null) {
                str2 = computeSavedFilename(str);
            }
            this._sourceForUri.put(str, str2);
        }
    }

    public void addSpelling(QName qName, SchemaComponent schemaComponent) {
        this._misspelledNames.put(crunchName(qName), schemaComponent);
    }

    public boolean allowPartial() {
        return this._allowPartial;
    }

    public List annotations() {
        return this._annotations;
    }

    public SchemaAttributeGroup[] attributeGroups() {
        return (SchemaAttributeGroup[]) this._attributeGroups.values().toArray(new SchemaAttributeGroup[this._attributeGroups.size()]);
    }

    public SchemaType[] attributeTypes() {
        return (SchemaType[]) this._attributeTypes.values().toArray(new SchemaType[this._attributeTypes.size()]);
    }

    public String computeSavedFilename(String str) {
        return relativize(str, true);
    }

    public SchemaType[] documentTypes() {
        return (SchemaType[]) this._documentTypes.values().toArray(new SchemaType[this._documentTypes.size()]);
    }

    public void error(String str, int i2, XmlObject xmlObject) {
        addError(this._errorListener, str, i2, xmlObject);
    }

    public SchemaAttributeGroupImpl findAttributeGroup(QName qName, String str, String str2) {
        QName compatName = compatName(qName, str);
        SchemaAttributeGroupImpl schemaAttributeGroupImpl = (SchemaAttributeGroupImpl) this._attributeGroups.get(compatName);
        boolean z = false;
        if (schemaAttributeGroupImpl == null && (schemaAttributeGroupImpl = (SchemaAttributeGroupImpl) this._importingLoader.findAttributeGroup(compatName)) != null) {
            z = true;
        }
        if (!z && str2 != null) {
            registerDependency(str2, compatName.getNamespaceURI());
        }
        return schemaAttributeGroupImpl;
    }

    public SchemaTypeImpl findAttributeType(QName qName, String str, String str2) {
        QName compatName = compatName(qName, str);
        SchemaTypeImpl schemaTypeImpl = (SchemaTypeImpl) this._attributeTypes.get(compatName);
        boolean z = false;
        if (schemaTypeImpl == null && (schemaTypeImpl = (SchemaTypeImpl) this._importingLoader.findAttributeType(compatName)) != null) {
            z = true;
        }
        if (!z && str2 != null) {
            registerDependency(str2, compatName.getNamespaceURI());
        }
        return schemaTypeImpl;
    }

    public SchemaTypeImpl findDocumentType(QName qName, String str, String str2) {
        QName compatName = compatName(qName, str);
        SchemaTypeImpl schemaTypeImpl = (SchemaTypeImpl) this._documentTypes.get(compatName);
        boolean z = false;
        if (schemaTypeImpl == null && (schemaTypeImpl = (SchemaTypeImpl) this._importingLoader.findDocumentType(compatName)) != null) {
            z = true;
        }
        if (!z && str2 != null) {
            registerDependency(str2, compatName.getNamespaceURI());
        }
        return schemaTypeImpl;
    }

    public SchemaGlobalAttributeImpl findGlobalAttribute(QName qName, String str, String str2) {
        QName compatName = compatName(qName, str);
        SchemaGlobalAttributeImpl schemaGlobalAttributeImpl = (SchemaGlobalAttributeImpl) this._globalAttributes.get(compatName);
        boolean z = false;
        if (schemaGlobalAttributeImpl == null && (schemaGlobalAttributeImpl = (SchemaGlobalAttributeImpl) this._importingLoader.findAttribute(compatName)) != null) {
            z = true;
        }
        if (!z && str2 != null) {
            registerDependency(str2, compatName.getNamespaceURI());
        }
        return schemaGlobalAttributeImpl;
    }

    public SchemaGlobalElementImpl findGlobalElement(QName qName, String str, String str2) {
        QName compatName = compatName(qName, str);
        SchemaGlobalElementImpl schemaGlobalElementImpl = (SchemaGlobalElementImpl) this._globalElements.get(compatName);
        boolean z = false;
        if (schemaGlobalElementImpl == null && (schemaGlobalElementImpl = (SchemaGlobalElementImpl) this._importingLoader.findElement(compatName)) != null) {
            z = true;
        }
        if (!z && str2 != null) {
            registerDependency(str2, compatName.getNamespaceURI());
        }
        return schemaGlobalElementImpl;
    }

    public SchemaTypeImpl findGlobalType(QName qName, String str, String str2) {
        QName compatName = compatName(qName, str);
        SchemaTypeImpl schemaTypeImpl = (SchemaTypeImpl) this._globalTypes.get(compatName);
        boolean z = false;
        if (schemaTypeImpl == null && (schemaTypeImpl = (SchemaTypeImpl) this._importingLoader.findType(compatName)) != null) {
            z = true;
        }
        if (!z && str2 != null) {
            registerDependency(str2, compatName.getNamespaceURI());
        }
        return schemaTypeImpl;
    }

    public SchemaIdentityConstraintImpl findIdConstraint(QName qName, String str, String str2) {
        QName compatName = compatName(qName, str);
        if (str2 != null) {
            registerDependency(str2, compatName.getNamespaceURI());
        }
        return (SchemaIdentityConstraintImpl) this._idConstraints.get(compatName);
    }

    public SchemaModelGroupImpl findModelGroup(QName qName, String str, String str2) {
        QName compatName = compatName(qName, str);
        SchemaModelGroupImpl schemaModelGroupImpl = (SchemaModelGroupImpl) this._modelGroups.get(compatName);
        boolean z = false;
        if (schemaModelGroupImpl == null && (schemaModelGroupImpl = (SchemaModelGroupImpl) this._importingLoader.findModelGroup(compatName)) != null) {
            z = true;
        }
        if (!z && str2 != null) {
            registerDependency(str2, compatName.getNamespaceURI());
        }
        return schemaModelGroupImpl;
    }

    public SchemaAttributeGroupImpl findRedefinedAttributeGroup(QName qName, String str, SchemaAttributeGroupImpl schemaAttributeGroupImpl) {
        QName name = schemaAttributeGroupImpl.getName();
        QName compatName = compatName(qName, str);
        if (compatName.equals(name)) {
            return (SchemaAttributeGroupImpl) this._redefinedAttributeGroups.get(schemaAttributeGroupImpl);
        }
        SchemaAttributeGroupImpl schemaAttributeGroupImpl2 = (SchemaAttributeGroupImpl) this._attributeGroups.get(compatName);
        return schemaAttributeGroupImpl2 == null ? (SchemaAttributeGroupImpl) this._importingLoader.findAttributeGroup(compatName) : schemaAttributeGroupImpl2;
    }

    public SchemaTypeImpl findRedefinedGlobalType(QName qName, String str, SchemaTypeImpl schemaTypeImpl) {
        QName name = schemaTypeImpl.getName();
        QName compatName = compatName(qName, str);
        if (compatName.equals(name)) {
            return (SchemaTypeImpl) this._redefinedGlobalTypes.get(schemaTypeImpl);
        }
        SchemaTypeImpl schemaTypeImpl2 = (SchemaTypeImpl) this._globalTypes.get(compatName);
        return schemaTypeImpl2 == null ? (SchemaTypeImpl) this._importingLoader.findType(compatName) : schemaTypeImpl2;
    }

    public SchemaModelGroupImpl findRedefinedModelGroup(QName qName, String str, SchemaModelGroupImpl schemaModelGroupImpl) {
        QName name = schemaModelGroupImpl.getName();
        QName compatName = compatName(qName, str);
        if (compatName.equals(name)) {
            return (SchemaModelGroupImpl) this._redefinedModelGroups.get(schemaModelGroupImpl);
        }
        SchemaModelGroupImpl schemaModelGroupImpl2 = (SchemaModelGroupImpl) this._modelGroups.get(compatName);
        return schemaModelGroupImpl2 == null ? (SchemaModelGroupImpl) this._importingLoader.findModelGroup(compatName) : schemaModelGroupImpl2;
    }

    public SchemaComponent findSpelling(QName qName) {
        return (SchemaComponent) this._misspelledNames.get(crunchName(qName));
    }

    public void finishProcessing(Object obj) {
        if ($assertionsDisabled || this._processingGroups.contains(obj)) {
            this._processingGroups.remove(obj);
            return;
        }
        throw new AssertionError();
    }

    public BindingConfig getBindingConfig() {
        return this._config;
    }

    public SchemaContainer getContainer(String str) {
        return (SchemaContainer) this._containers.get(str);
    }

    public Map getContainerMap() {
        return Collections.unmodifiableMap(this._containers);
    }

    public Object[] getCurrentProcessing() {
        return this._processingGroups.toArray();
    }

    public SchemaDependencies getDependencies() {
        return this._dependencies;
    }

    public EntityResolver getEntityResolver() {
        return this._entityResolver;
    }

    public Collection getErrorListener() {
        return this._errorListener;
    }

    public String getJavaPrefix(String str) {
        BindingConfig bindingConfig = this._config;
        if (bindingConfig == null) {
            return null;
        }
        return bindingConfig.lookupPrefixForNamespace(str);
    }

    public String getJavaSuffix(String str) {
        BindingConfig bindingConfig = this._config;
        if (bindingConfig == null) {
            return null;
        }
        return bindingConfig.lookupSuffixForNamespace(str);
    }

    public String getJavaname(QName qName, int i2) {
        BindingConfig bindingConfig = this._config;
        if (bindingConfig == null) {
            return null;
        }
        return bindingConfig.lookupJavanameForQName(qName, i2);
    }

    public String[] getNamespaces() {
        Set set = this._namespaces;
        return (String[]) set.toArray(new String[set.size()]);
    }

    public String getPackageOverride(String str) {
        BindingConfig bindingConfig = this._config;
        if (bindingConfig == null) {
            return null;
        }
        return bindingConfig.lookupPackageForNamespace(str);
    }

    public int getRecovered() {
        return this._recoveredErrors;
    }

    public SchemaTypeLoader getS4SLoader() {
        return this._s4sloader;
    }

    public File getSchemasDir() {
        return this._schemasDir;
    }

    public SchemaGlobalAttribute[] globalAttributes() {
        return (SchemaGlobalAttribute[]) this._globalAttributes.values().toArray(new SchemaGlobalAttribute[this._globalAttributes.size()]);
    }

    public SchemaGlobalElement[] globalElements() {
        return (SchemaGlobalElement[]) this._globalElements.values().toArray(new SchemaGlobalElement[this._globalElements.size()]);
    }

    public SchemaType[] globalTypes() {
        return (SchemaType[]) this._globalTypes.values().toArray(new SchemaType[this._globalTypes.size()]);
    }

    public SchemaIdentityConstraintImpl[] idConstraints() {
        return (SchemaIdentityConstraintImpl[]) this._idConstraints.values().toArray(new SchemaIdentityConstraintImpl[this._idConstraints.size()]);
    }

    public void info(String str) {
        addInfo(this._errorListener, str);
    }

    public void initFromTypeSystem(SchemaTypeSystemImpl schemaTypeSystemImpl, Set set) {
        SchemaContainer[] containers = schemaTypeSystemImpl.containers();
        for (int i2 = 0; i2 < containers.length; i2++) {
            if (!set.contains(containers[i2].getNamespace())) {
                addContainer(containers[i2]);
            }
        }
    }

    public boolean isFileProcessed(String str) {
        return this._dependencies.isFileRepresented(str);
    }

    public boolean isProcessing(Object obj) {
        return this._processingGroups.contains(obj);
    }

    public boolean linkerDefinesNamespace(String str) {
        return this._importingLoader.isNamespaceDefined(str);
    }

    public SchemaModelGroup[] modelGroups() {
        return (SchemaModelGroup[]) this._modelGroups.values().toArray(new SchemaModelGroup[this._modelGroups.size()]);
    }

    public boolean noAnn() {
        return this._noAnn;
    }

    public boolean noPvr() {
        return this._noPvr;
    }

    public boolean noUpa() {
        return this._noUpa;
    }

    public void notFoundError(QName qName, int i2, XmlObject xmlObject, boolean z) {
        String str;
        String str2;
        String str3;
        String str4;
        Integer num;
        Integer num2;
        QName name;
        String str5;
        String pretty = QNameHelper.pretty(qName);
        if (z) {
            this._recoveredErrors++;
        }
        String str6 = "attribute group";
        if (i2 == 0) {
            str = JamXmlElements.TYPE;
        } else if (i2 == 1) {
            str = "element";
        } else if (i2 == 3) {
            str = "attribute";
        } else if (i2 == 4) {
            str = str6;
        } else if (i2 == 5) {
            str = "identity constraint";
        } else if (i2 == 6) {
            str = "model group";
        } else if ($assertionsDisabled) {
            str = "definition";
        } else {
            throw new AssertionError();
        }
        SchemaComponent findSpelling = findSpelling(qName);
        if (findSpelling == null || (name = findSpelling.getName()) == null) {
            str4 = null;
            str3 = null;
            str2 = null;
        } else {
            int componentType = findSpelling.getComponentType();
            if (componentType == 0) {
                str5 = ((SchemaType) findSpelling).getSourceName();
                str6 = JamXmlElements.TYPE;
            } else if (componentType == 1) {
                str5 = ((SchemaGlobalElement) findSpelling).getSourceName();
                str6 = "element";
            } else if (componentType != 3) {
                if (componentType != 4) {
                    if (componentType != 6) {
                        str5 = null;
                        str6 = null;
                    } else {
                        str6 = "model group";
                    }
                }
                str5 = null;
            } else {
                str5 = ((SchemaGlobalAttribute) findSpelling).getSourceName();
                str6 = "attribute";
            }
            if (str5 != null) {
                str5 = str5.substring(str5.lastIndexOf(47) + 1);
            }
            if (!name.equals(qName)) {
                str3 = str5;
                str4 = QNameHelper.pretty(name);
                str2 = str6;
            } else {
                str2 = str6;
                str3 = str5;
                str4 = null;
            }
        }
        if (str2 == null) {
            error(XmlErrorCodes.SCHEMA_QNAME_RESOLVE, new Object[]{str, pretty}, xmlObject);
            return;
        }
        Object[] objArr = new Object[7];
        objArr[0] = str;
        objArr[1] = pretty;
        objArr[2] = str2;
        if (str4 != null) {
            num = new Integer(1);
        }
        objArr[3] = num;
        objArr[4] = str4;
        if (str3 != null) {
            num2 = new Integer(1);
        }
        objArr[5] = num2;
        objArr[6] = str3;
        error(XmlErrorCodes.SCHEMA_QNAME_RESOLVE$HELP, objArr, xmlObject);
    }

    public void recover(String str, Object[] objArr, XmlObject xmlObject) {
        addError(this._errorListener, str, objArr, xmlObject);
        this._recoveredErrors++;
    }

    public SchemaAttributeGroup[] redefinedAttributeGroups() {
        return (SchemaAttributeGroup[]) this._redefinedAttributeGroups.values().toArray(new SchemaAttributeGroup[this._redefinedAttributeGroups.size()]);
    }

    public SchemaType[] redefinedGlobalTypes() {
        return (SchemaType[]) this._redefinedGlobalTypes.values().toArray(new SchemaType[this._redefinedGlobalTypes.size()]);
    }

    public SchemaModelGroup[] redefinedModelGroups() {
        return (SchemaModelGroup[]) this._redefinedModelGroups.values().toArray(new SchemaModelGroup[this._redefinedModelGroups.size()]);
    }

    public void registerContribution(String str, String str2) {
        this._dependencies.registerContribution(str, str2);
    }

    public void registerDependency(String str, String str2) {
        this._dependencies.registerDependency(str, str2);
    }

    public String relativize(String str) {
        return relativize(str, false);
    }

    public void setBaseUri(URI uri) {
        this._baseURI = uri;
    }

    public void setBindingConfig(BindingConfig bindingConfig) {
        this._config = bindingConfig;
    }

    public void setDependencies(SchemaDependencies schemaDependencies) {
        this._dependencies = schemaDependencies;
    }

    public void setErrorListener(Collection collection) {
        this._errorListener = collection;
    }

    public void setGivenTypeSystemName(String str) {
        this._givenStsName = str;
    }

    public void setImportingTypeLoader(SchemaTypeLoader schemaTypeLoader) {
        this._importingLoader = schemaTypeLoader;
    }

    public void setOptions(XmlOptions xmlOptions) {
        if (xmlOptions != null) {
            this._allowPartial = xmlOptions.hasOption("COMPILE_PARTIAL_TYPESYSTEM");
            this._compatMap = (Map) xmlOptions.get(XmlOptions.COMPILE_SUBSTITUTE_NAMES);
            boolean z = false;
            this._noUpa = xmlOptions.hasOption(XmlOptions.COMPILE_NO_UPA_RULE) || !SchemaSymbols.ATTVAL_TRUE.equals(SystemProperties.getProperty("xmlbean.uniqueparticleattribution", SchemaSymbols.ATTVAL_TRUE));
            this._noPvr = xmlOptions.hasOption(XmlOptions.COMPILE_NO_PVR_RULE) || !SchemaSymbols.ATTVAL_TRUE.equals(SystemProperties.getProperty("xmlbean.particlerestriction", SchemaSymbols.ATTVAL_TRUE));
            if (xmlOptions.hasOption(XmlOptions.COMPILE_NO_ANNOTATIONS) || !SchemaSymbols.ATTVAL_TRUE.equals(SystemProperties.getProperty("xmlbean.schemaannotations", SchemaSymbols.ATTVAL_TRUE))) {
                z = true;
            }
            this._noAnn = z;
            this._doingDownloads = xmlOptions.hasOption(XmlOptions.COMPILE_DOWNLOAD_URLS) ? true : SchemaSymbols.ATTVAL_TRUE.equals(SystemProperties.getProperty("xmlbean.downloadurls", SchemaSymbols.ATTVAL_FALSE));
            EntityResolver entityResolver = (EntityResolver) xmlOptions.get(XmlOptions.ENTITY_RESOLVER);
            this._entityResolver = entityResolver;
            if (entityResolver == null) {
                this._entityResolver = ResolverUtil.getGlobalEntityResolver();
            }
            if (this._entityResolver != null) {
                this._doingDownloads = true;
            }
            if (xmlOptions.hasOption(XmlOptions.COMPILE_MDEF_NAMESPACES)) {
                this._mdefNamespaces.addAll((Collection) xmlOptions.get(XmlOptions.COMPILE_MDEF_NAMESPACES));
                if (this._mdefNamespaces.contains(SchemaSymbols.ATTVAL_TWOPOUNDLOCAL)) {
                    this._mdefNamespaces.remove(SchemaSymbols.ATTVAL_TWOPOUNDLOCAL);
                    this._mdefNamespaces.add("");
                }
                if (this._mdefNamespaces.contains(SchemaSymbols.ATTVAL_TWOPOUNDANY)) {
                    this._mdefNamespaces.remove(SchemaSymbols.ATTVAL_TWOPOUNDANY);
                    this._mdefAll = true;
                }
            }
        }
    }

    public void setSchemasDir(File file) {
        this._schemasDir = file;
    }

    public void setTargetSchemaTypeSystem(SchemaTypeSystemImpl schemaTypeSystemImpl) {
        this._target = schemaTypeSystemImpl;
    }

    public boolean shouldDownloadURI(String str) {
        if (this._doingDownloads) {
            return true;
        }
        if (str == null) {
            return false;
        }
        try {
            URI uri = new URI(str);
            if (!uri.getScheme().equalsIgnoreCase("jar")) {
                if (!uri.getScheme().equalsIgnoreCase("zip")) {
                    return uri.getScheme().equalsIgnoreCase("file");
                }
            }
            String schemeSpecificPart = uri.getSchemeSpecificPart();
            int lastIndexOf = schemeSpecificPart.lastIndexOf(33);
            if (lastIndexOf > 0) {
                schemeSpecificPart = schemeSpecificPart.substring(0, lastIndexOf);
            }
            return shouldDownloadURI(schemeSpecificPart);
        } catch (Exception unused) {
            return false;
        }
    }

    public Map sourceCopyMap() {
        return Collections.unmodifiableMap(this._sourceForUri);
    }

    public String sourceNameForUri(String str) {
        return (String) this._sourceForUri.get(str);
    }

    public void startProcessing(Object obj) {
        if ($assertionsDisabled || !this._processingGroups.contains(obj)) {
            this._processingGroups.add(obj);
            return;
        }
        throw new AssertionError();
    }

    public SchemaTypeSystemImpl sts() {
        SchemaTypeSystemImpl schemaTypeSystemImpl = this._target;
        if (schemaTypeSystemImpl != null) {
            return schemaTypeSystemImpl;
        }
        String str = this._givenStsName;
        if (str == null && this._digest != null) {
            StringBuffer a = a.a(Lucene3xNormsProducer.SEPARATE_NORMS_EXTENSION);
            a.append(new String(HexBin.encode(this._digest)));
            str = a.toString();
        }
        SchemaTypeSystemImpl schemaTypeSystemImpl2 = new SchemaTypeSystemImpl(str);
        this._target = schemaTypeSystemImpl2;
        return schemaTypeSystemImpl2;
    }

    public Map typesByClassname() {
        return Collections.unmodifiableMap(this._typesByClassname);
    }

    public void warning(String str, int i2, XmlObject xmlObject) {
        addWarning(this._errorListener, str, i2, xmlObject);
    }

    public StscState() {
        this._digest = null;
        this._noDigest = false;
        this._allowPartial = false;
        this._recoveredErrors = 0;
        this._containers = new LinkedHashMap();
        this._redefinedGlobalTypes = new LinkedHashMap();
        this._redefinedModelGroups = new LinkedHashMap();
        this._redefinedAttributeGroups = new LinkedHashMap();
        this._globalTypes = new LinkedHashMap();
        this._globalElements = new LinkedHashMap();
        this._globalAttributes = new LinkedHashMap();
        this._modelGroups = new LinkedHashMap();
        this._attributeGroups = new LinkedHashMap();
        this._documentTypes = new LinkedHashMap();
        this._attributeTypes = new LinkedHashMap();
        this._typesByClassname = new LinkedHashMap();
        this._misspelledNames = new HashMap();
        this._processingGroups = new LinkedHashSet();
        this._idConstraints = new LinkedHashMap();
        this._namespaces = new HashSet();
        this._annotations = new ArrayList();
        this._mdefNamespaces = buildDefaultMdefNamespaces();
        this._sourceForUri = new HashMap();
        this._baseURI = URI.create("project://local/");
        Class cls = class$org$apache$xmlbeans$impl$xb$xsdschema$SchemaDocument;
        if (cls == null) {
            cls = class$("org.apache.xmlbeans.impl.xb.xsdschema.SchemaDocument");
            class$org$apache$xmlbeans$impl$xb$xsdschema$SchemaDocument = cls;
        }
        this._s4sloader = XmlBeans.typeLoaderForClassLoader(cls.getClassLoader());
    }

    private String relativize(String str, boolean z) {
        String str2;
        if (str == null) {
            return null;
        }
        if (str.startsWith(ZipHelper.FORWARD_SLASH)) {
            StringBuffer a = a.a("project://local");
            a.append(str.replace('\\', JarHelper.SEP));
            str = a.toString();
        } else {
            int indexOf = str.indexOf(58);
            if (indexOf <= 1 || !str.substring(0, indexOf).matches("^\\w+$")) {
                StringBuffer a2 = a.a("project://local/");
                a2.append(str.replace('\\', JarHelper.SEP));
                str = a2.toString();
            }
        }
        URI uri = this._baseURI;
        if (uri != null) {
            try {
                URI relativize = uri.relativize(new URI(str));
                if (!relativize.isAbsolute()) {
                    return relativize.toString();
                }
                str = relativize.toString();
            } catch (URISyntaxException unused) {
            }
        }
        if (!z) {
            return str;
        }
        int lastIndexOf = str.lastIndexOf(47);
        String str3 = "";
        if (lastIndexOf == -1) {
            str2 = str3;
        } else {
            str2 = str.substring(0, lastIndexOf);
        }
        String hexsafe = QNameHelper.hexsafe(str2);
        int i2 = lastIndexOf + 1;
        int indexOf2 = str.indexOf(63, i2);
        if (indexOf2 == -1) {
            StringBuffer c = a.c(hexsafe, ZipHelper.FORWARD_SLASH);
            c.append(str.substring(i2));
            return c.toString();
        }
        if (indexOf2 != -1) {
            str3 = str.substring(indexOf2);
        }
        String hexsafe2 = QNameHelper.hexsafe(str3);
        if (hexsafe2.startsWith(QNameHelper.URI_SHA1_PREFIX)) {
            StringBuffer c2 = a.c(hexsafe, ZipHelper.FORWARD_SLASH);
            c2.append(str.substring(i2, indexOf2));
            return c2.toString();
        }
        StringBuffer c3 = a.c(hexsafe, ZipHelper.FORWARD_SLASH);
        c3.append(str.substring(i2, indexOf2));
        c3.append(hexsafe2);
        return c3.toString();
    }

    public void error(String str, Object[] objArr, XmlObject xmlObject) {
        addError(this._errorListener, str, objArr, xmlObject);
    }

    public void info(String str, Object[] objArr) {
        addInfo(this._errorListener, str, objArr);
    }

    public void warning(String str, Object[] objArr, XmlObject xmlObject) {
        if (str != XmlErrorCodes.RESERVED_TYPE_NAME || xmlObject.documentProperties().getSourceName() == null || xmlObject.documentProperties().getSourceName().indexOf("XMLSchema.xsd") <= 0) {
            addWarning(this._errorListener, str, objArr, xmlObject);
        }
    }

    public static void addError(Collection collection, String str, Object[] objArr, XmlObject xmlObject) {
        collection.add(XmlError.forObject(str, objArr, 0, xmlObject));
    }

    public static void addInfo(Collection collection, String str, Object[] objArr) {
        collection.add(XmlError.forMessage(str, objArr, 2));
    }

    public static void addWarning(Collection collection, String str, Object[] objArr, XmlObject xmlObject) {
        collection.add(XmlError.forObject(str, objArr, 1, xmlObject));
    }

    public static void addError(Collection collection, String str, Object[] objArr, File file) {
        collection.add(XmlError.forLocation(str, objArr, 0, file.toURI().toString(), 0, 0, 0));
    }

    public static void addError(Collection collection, String str, Object[] objArr, URL url) {
        collection.add(XmlError.forLocation(str, objArr, 0, url.toString(), 0, 0, 0));
    }
}
