package org.apache.xmlbeans.impl.schema;

import b.b.a.a.a;
import java.math.BigInteger;
import java.util.ArrayList;
import java.util.Collections;
import java.util.HashMap;
import java.util.Iterator;
import java.util.List;
import java.util.Map;
import org.apache.poi.javax.xml.namespace.QName;
import org.apache.xerces.impl.xs.SchemaSymbols;
import org.apache.xmlbeans.QNameSet;
import org.apache.xmlbeans.QNameSetBuilder;
import org.apache.xmlbeans.SchemaAttributeModel;
import org.apache.xmlbeans.SchemaBookmark;
import org.apache.xmlbeans.SchemaGlobalElement;
import org.apache.xmlbeans.SchemaIdentityConstraint;
import org.apache.xmlbeans.SchemaParticle;
import org.apache.xmlbeans.SchemaType;
import org.apache.xmlbeans.XmlAnySimpleType;
import org.apache.xmlbeans.XmlCursor;
import org.apache.xmlbeans.XmlErrorCodes;
import org.apache.xmlbeans.XmlNonNegativeInteger;
import org.apache.xmlbeans.XmlObject;
import org.apache.xmlbeans.XmlPositiveInteger;
import org.apache.xmlbeans.impl.common.QNameHelper;
import org.apache.xmlbeans.impl.common.XMLChar;
import org.apache.xmlbeans.impl.common.XPath;
import org.apache.xmlbeans.impl.jam.xml.JamXmlElements;
import org.apache.xmlbeans.impl.regex.RegularExpression;
import org.apache.xmlbeans.impl.schema.StscImporter;
import org.apache.xmlbeans.impl.values.NamespaceContext;
import org.apache.xmlbeans.impl.values.XmlNonNegativeIntegerImpl;
import org.apache.xmlbeans.impl.values.XmlPositiveIntegerImpl;
import org.apache.xmlbeans.impl.values.XmlValueOutOfRangeException;
import org.apache.xmlbeans.impl.xb.xsdschema.Annotated;
import org.apache.xmlbeans.impl.xb.xsdschema.AnnotationDocument;
import org.apache.xmlbeans.impl.xb.xsdschema.Attribute;
import org.apache.xmlbeans.impl.xb.xsdschema.AttributeGroup;
import org.apache.xmlbeans.impl.xb.xsdschema.Element;
import org.apache.xmlbeans.impl.xb.xsdschema.FieldDocument;
import org.apache.xmlbeans.impl.xb.xsdschema.FormChoice;
import org.apache.xmlbeans.impl.xb.xsdschema.Keybase;
import org.apache.xmlbeans.impl.xb.xsdschema.KeyrefDocument;
import org.apache.xmlbeans.impl.xb.xsdschema.LocalElement;
import org.apache.xmlbeans.impl.xb.xsdschema.LocalSimpleType;
import org.apache.xmlbeans.impl.xb.xsdschema.NamedAttributeGroup;
import org.apache.xmlbeans.impl.xb.xsdschema.NamedGroup;
import org.apache.xmlbeans.impl.xb.xsdschema.RedefineDocument;
import org.apache.xmlbeans.impl.xb.xsdschema.SchemaDocument;
import org.apache.xmlbeans.impl.xb.xsdschema.SimpleType;
import org.apache.xmlbeans.impl.xb.xsdschema.TopLevelAttribute;
import org.apache.xmlbeans.impl.xb.xsdschema.TopLevelComplexType;
import org.apache.xmlbeans.impl.xb.xsdschema.TopLevelElement;
import org.apache.xmlbeans.impl.xb.xsdschema.TopLevelSimpleType;
import org.apache.xmlbeans.soap.SOAPArrayType;

public class StscTranslator {
    public static final /* synthetic */ boolean $assertionsDisabled;
    public static final String FORM_QUALIFIED = "qualified";
    public static final QName WSDL_ARRAYTYPE_NAME = QNameHelper.forLNS(SoapEncSchemaTypeSystem.ARRAY_TYPE, "http://schemas.xmlsoap.org/wsdl/");
    public static final RegularExpression XPATH_REGEXP = new RegularExpression("(\\.//)?((((child::)?((\\i\\c*:)?(\\i\\c*|\\*)))|\\.)/)*((((child::)?((\\i\\c*:)?(\\i\\c*|\\*)))|\\.)|((attribute::|@)((\\i\\c*:)?(\\i\\c*|\\*))))(\\|(\\.//)?((((child::)?((\\i\\c*:)?(\\i\\c*|\\*)))|\\.)/)*((((child::)?((\\i\\c*:)?(\\i\\c*|\\*)))|\\.)|((attribute::|@)((\\i\\c*:)?(\\i\\c*|\\*)))))*", "X");
    public static /* synthetic */ Class class$org$apache$xmlbeans$SchemaBookmark;
    public static /* synthetic */ Class class$org$apache$xmlbeans$impl$schema$StscTranslator;

    public static class RedefinitionHolder {
        public Map agRedefinitions;
        public Map ctRedefinitions;
        public Map mgRedefinitions;
        public String schemaLocation = "";
        public StscImporter.SchemaToProcess schemaRedefined;
        public Map stRedefinitions;

        public RedefinitionHolder(StscImporter.SchemaToProcess schemaToProcess, RedefineDocument.Redefine redefine) {
            Map map = Collections.EMPTY_MAP;
            this.stRedefinitions = map;
            this.ctRedefinitions = map;
            this.agRedefinitions = map;
            this.mgRedefinitions = map;
            this.schemaRedefined = schemaToProcess;
            if (redefine != null) {
                StscState stscState = StscState.get();
                this.stRedefinitions = new HashMap();
                this.ctRedefinitions = new HashMap();
                this.agRedefinitions = new HashMap();
                this.mgRedefinitions = new HashMap();
                if (redefine.getSchemaLocation() != null) {
                    this.schemaLocation = redefine.getSchemaLocation();
                }
                TopLevelComplexType[] complexTypeArray = redefine.getComplexTypeArray();
                for (int i2 = 0; i2 < complexTypeArray.length; i2++) {
                    if (complexTypeArray[i2].getName() != null) {
                        if (this.ctRedefinitions.containsKey(complexTypeArray[i2].getName())) {
                            StringBuffer a = a.a("Duplicate type redefinition: ");
                            a.append(complexTypeArray[i2].getName());
                            stscState.error(a.toString(), 49, (XmlObject) null);
                        } else {
                            this.ctRedefinitions.put(complexTypeArray[i2].getName(), complexTypeArray[i2]);
                        }
                    }
                }
                TopLevelSimpleType[] simpleTypeArray = redefine.getSimpleTypeArray();
                for (int i3 = 0; i3 < simpleTypeArray.length; i3++) {
                    if (simpleTypeArray[i3].getName() != null) {
                        if (this.stRedefinitions.containsKey(simpleTypeArray[i3].getName())) {
                            StringBuffer a2 = a.a("Duplicate type redefinition: ");
                            a2.append(simpleTypeArray[i3].getName());
                            stscState.error(a2.toString(), 49, (XmlObject) null);
                        } else {
                            this.stRedefinitions.put(simpleTypeArray[i3].getName(), simpleTypeArray[i3]);
                        }
                    }
                }
                NamedGroup[] groupArray = redefine.getGroupArray();
                for (int i4 = 0; i4 < groupArray.length; i4++) {
                    if (groupArray[i4].getName() != null) {
                        if (this.mgRedefinitions.containsKey(groupArray[i4].getName())) {
                            StringBuffer a3 = a.a("Duplicate type redefinition: ");
                            a3.append(groupArray[i4].getName());
                            stscState.error(a3.toString(), 49, (XmlObject) null);
                        } else {
                            this.mgRedefinitions.put(groupArray[i4].getName(), groupArray[i4]);
                        }
                    }
                }
                NamedAttributeGroup[] attributeGroupArray = redefine.getAttributeGroupArray();
                for (int i5 = 0; i5 < attributeGroupArray.length; i5++) {
                    if (attributeGroupArray[i5].getName() != null) {
                        if (this.agRedefinitions.containsKey(attributeGroupArray[i5].getName())) {
                            StringBuffer a4 = a.a("Duplicate type redefinition: ");
                            a4.append(attributeGroupArray[i5].getName());
                            stscState.error(a4.toString(), 49, (XmlObject) null);
                        } else {
                            this.agRedefinitions.put(attributeGroupArray[i5].getName(), attributeGroupArray[i5]);
                        }
                    }
                }
            }
        }

        public void complainAboutMissingDefinitions() {
            if (!this.stRedefinitions.isEmpty() || !this.ctRedefinitions.isEmpty() || !this.agRedefinitions.isEmpty() || !this.mgRedefinitions.isEmpty()) {
                StscState stscState = StscState.get();
                for (String str : this.stRedefinitions.keySet()) {
                    StringBuffer c = a.c("Redefined simple type ", str, " not found in ");
                    c.append(this.schemaLocation);
                    stscState.error(c.toString(), 60, (XmlObject) this.stRedefinitions.get(str));
                }
                for (String str2 : this.ctRedefinitions.keySet()) {
                    StringBuffer c2 = a.c("Redefined complex type ", str2, " not found in ");
                    c2.append(this.schemaLocation);
                    stscState.error(c2.toString(), 60, (XmlObject) this.ctRedefinitions.get(str2));
                }
                for (String str3 : this.agRedefinitions.keySet()) {
                    StringBuffer c3 = a.c("Redefined attribute group ", str3, " not found in ");
                    c3.append(this.schemaLocation);
                    stscState.error(c3.toString(), 60, (XmlObject) this.agRedefinitions.get(str3));
                }
                for (String str4 : this.mgRedefinitions.keySet()) {
                    StringBuffer c4 = a.c("Redefined model group ", str4, " not found in ");
                    c4.append(this.schemaLocation);
                    stscState.error(c4.toString(), 60, (XmlObject) this.mgRedefinitions.get(str4));
                }
            }
        }

        public NamedAttributeGroup redefineAttributeGroup(String str) {
            if (str == null || !this.agRedefinitions.containsKey(str)) {
                return null;
            }
            return (NamedAttributeGroup) this.agRedefinitions.remove(str);
        }

        public TopLevelComplexType redefineComplexType(String str) {
            if (str == null || !this.ctRedefinitions.containsKey(str)) {
                return null;
            }
            return (TopLevelComplexType) this.ctRedefinitions.remove(str);
        }

        public NamedGroup redefineModelGroup(String str) {
            if (str == null || !this.mgRedefinitions.containsKey(str)) {
                return null;
            }
            return (NamedGroup) this.mgRedefinitions.remove(str);
        }

        public TopLevelSimpleType redefineSimpleType(String str) {
            if (str == null || !this.stRedefinitions.containsKey(str)) {
                return null;
            }
            return (TopLevelSimpleType) this.stRedefinitions.remove(str);
        }
    }

    public static class RedefinitionMaster {
        public static final /* synthetic */ boolean $assertionsDisabled;
        public static final short ATTRIBUTE_GROUP = 4;
        public static final short COMPLEX_TYPE = 2;
        public static final RedefinitionHolder[] EMPTY_REDEFINTION_HOLDER_ARRAY = new RedefinitionHolder[0];
        public static final short MODEL_GROUP = 3;
        public static final short SIMPLE_TYPE = 1;
        public Map agRedefinitions;
        public Map ctRedefinitions;
        public Map mgRedefinitions;
        public Map stRedefinitions;

        static {
            Class cls = StscTranslator.class$org$apache$xmlbeans$impl$schema$StscTranslator;
            if (cls == null) {
                cls = StscTranslator.class$("org.apache.xmlbeans.impl.schema.StscTranslator");
                StscTranslator.class$org$apache$xmlbeans$impl$schema$StscTranslator = cls;
            }
            $assertionsDisabled = !cls.desiredAssertionStatus();
        }

        public RedefinitionMaster(RedefinitionHolder[] redefinitionHolderArr) {
            Map map = Collections.EMPTY_MAP;
            this.stRedefinitions = map;
            this.ctRedefinitions = map;
            this.agRedefinitions = map;
            this.mgRedefinitions = map;
            if (redefinitionHolderArr.length > 0) {
                this.stRedefinitions = new HashMap();
                this.ctRedefinitions = new HashMap();
                this.agRedefinitions = new HashMap();
                this.mgRedefinitions = new HashMap();
                for (int i2 = 0; i2 < redefinitionHolderArr.length; i2++) {
                    RedefinitionHolder redefinitionHolder = redefinitionHolderArr[i2];
                    for (Object obj : redefinitionHolder.stRedefinitions.keySet()) {
                        List list = (List) this.stRedefinitions.get(obj);
                        if (list == null) {
                            list = new ArrayList();
                            this.stRedefinitions.put(obj, list);
                        }
                        list.add(redefinitionHolderArr[i2]);
                    }
                    for (Object obj2 : redefinitionHolder.ctRedefinitions.keySet()) {
                        List list2 = (List) this.ctRedefinitions.get(obj2);
                        if (list2 == null) {
                            list2 = new ArrayList();
                            this.ctRedefinitions.put(obj2, list2);
                        }
                        list2.add(redefinitionHolderArr[i2]);
                    }
                    for (Object obj3 : redefinitionHolder.agRedefinitions.keySet()) {
                        List list3 = (List) this.agRedefinitions.get(obj3);
                        if (list3 == null) {
                            list3 = new ArrayList();
                            this.agRedefinitions.put(obj3, list3);
                        }
                        list3.add(redefinitionHolderArr[i2]);
                    }
                    for (Object obj4 : redefinitionHolder.mgRedefinitions.keySet()) {
                        List list4 = (List) this.mgRedefinitions.get(obj4);
                        if (list4 == null) {
                            list4 = new ArrayList();
                            this.mgRedefinitions.put(obj4, list4);
                        }
                        list4.add(redefinitionHolderArr[i2]);
                    }
                }
            }
        }

        private String componentNameFromCode(short s) {
            return s != 1 ? s != 2 ? s != 3 ? s != 4 ? "" : "attribute group" : "model group" : "complex type" : "simple type";
        }

        private RedefinitionHolder[] doTopologicalSort(List list, StscImporter.SchemaToProcess schemaToProcess, String str, short s) {
            RedefinitionHolder[] redefinitionHolderArr = new RedefinitionHolder[list.size()];
            int i2 = 0;
            for (int i3 = 0; i3 < list.size(); i3++) {
                RedefinitionHolder redefinitionHolder = (RedefinitionHolder) list.get(i3);
                if (redefinitionHolder.schemaRedefined == schemaToProcess || redefinitionHolder.schemaRedefined.indirectIncludes(schemaToProcess)) {
                    redefinitionHolderArr[i2] = redefinitionHolder;
                    i2++;
                }
            }
            RedefinitionHolder[] redefinitionHolderArr2 = new RedefinitionHolder[i2];
            int[] iArr = new int[i2];
            int i4 = 0;
            while (i4 < i2 - 1) {
                RedefinitionHolder redefinitionHolder2 = redefinitionHolderArr[i4];
                int i5 = i4 + 1;
                for (int i6 = i5; i6 < i2; i6++) {
                    if (redefinitionHolder2.schemaRedefined.indirectIncludes(redefinitionHolderArr[i6].schemaRedefined)) {
                        iArr[i4] = iArr[i4] + 1;
                    }
                    if (redefinitionHolderArr[i6].schemaRedefined.indirectIncludes(redefinitionHolder2.schemaRedefined)) {
                        iArr[i6] = iArr[i6] + 1;
                    }
                }
                i4 = i5;
            }
            int i7 = 0;
            boolean z = false;
            while (true) {
                XmlObject xmlObject = null;
                if (i7 < i2) {
                    int i8 = -1;
                    for (int i9 = 0; i9 < i2; i9++) {
                        if (iArr[i9] == 0 && i8 < 0) {
                            i8 = i9;
                        }
                    }
                    if (i8 < 0) {
                        if (!z) {
                            StringBuffer stringBuffer = new StringBuffer();
                            for (int i10 = 0; i10 < i2; i10++) {
                                if (redefinitionHolderArr[i10] != null) {
                                    stringBuffer.append(redefinitionHolderArr[i10].schemaLocation);
                                    stringBuffer.append(',');
                                    stringBuffer.append(' ');
                                    if (xmlObject == null) {
                                        xmlObject = locationFromRedefinitionAndCode(redefinitionHolderArr[i10], str, s);
                                    }
                                }
                            }
                            StscState stscState = StscState.get();
                            StringBuffer a = a.a("Detected circular redefinition of ");
                            a.a(a, componentNameFromCode(s), " \"", str, "\"; Files involved: ");
                            a.append(stringBuffer.toString());
                            stscState.error(a.toString(), 60, xmlObject);
                            z = true;
                        }
                        int i11 = i2;
                        for (int i12 = 0; i12 < i2; i12++) {
                            if (iArr[i12] > 0 && iArr[i12] < i11) {
                                i11 = iArr[i12];
                                i8 = i12;
                            }
                        }
                        iArr[i8] = iArr[i8] - 1;
                    } else if ($assertionsDisabled || redefinitionHolderArr[i8] != null) {
                        int i13 = i7 + 1;
                        redefinitionHolderArr2[i7] = redefinitionHolderArr[i8];
                        for (int i14 = 0; i14 < i2; i14++) {
                            if (redefinitionHolderArr[i14] != null && redefinitionHolderArr[i14].schemaRedefined.indirectIncludes(redefinitionHolderArr[i8].schemaRedefined)) {
                                iArr[i14] = iArr[i14] - 1;
                            }
                        }
                        redefinitionHolderArr[i8] = null;
                        iArr[i8] = iArr[i8] - 1;
                        i7 = i13;
                    } else {
                        throw new AssertionError();
                    }
                } else {
                    for (int i15 = 1; i15 < i2; i15++) {
                        int i16 = i15 - 1;
                        while (i16 >= 0 && redefinitionHolderArr2[i16] == null) {
                            i16--;
                        }
                        if (!redefinitionHolderArr2[i15].schemaRedefined.indirectIncludes(redefinitionHolderArr2[i16].schemaRedefined)) {
                            StscState stscState2 = StscState.get();
                            StringBuffer a2 = a.a("Detected multiple redefinitions of ");
                            a.a(a2, componentNameFromCode(s), " \"", str, "\"; Files involved: ");
                            a2.append(redefinitionHolderArr2[i16].schemaRedefined.getSourceName());
                            a2.append(", ");
                            a2.append(redefinitionHolderArr2[i15].schemaRedefined.getSourceName());
                            stscState2.error(a2.toString(), 49, locationFromRedefinitionAndCode(redefinitionHolderArr2[i15], str, s));
                            if (s == 1) {
                                redefinitionHolderArr2[i15].redefineSimpleType(str);
                            } else if (s == 2) {
                                redefinitionHolderArr2[i15].redefineComplexType(str);
                            } else if (s == 3) {
                                redefinitionHolderArr2[i15].redefineModelGroup(str);
                            } else if (s == 4) {
                                redefinitionHolderArr2[i15].redefineAttributeGroup(str);
                            }
                            redefinitionHolderArr2[i15] = null;
                        }
                    }
                    return redefinitionHolderArr2;
                }
            }
        }

        private XmlObject locationFromRedefinitionAndCode(RedefinitionHolder redefinitionHolder, String str, short s) {
            if (s == 1) {
                return (XmlObject) redefinitionHolder.stRedefinitions.get(str);
            }
            if (s == 2) {
                return (XmlObject) redefinitionHolder.ctRedefinitions.get(str);
            }
            if (s == 3) {
                return (XmlObject) redefinitionHolder.mgRedefinitions.get(str);
            }
            if (s != 4) {
                return null;
            }
            return (XmlObject) redefinitionHolder.agRedefinitions.get(str);
        }

        public RedefinitionHolder[] getAttributeGroupRedefinitions(String str, StscImporter.SchemaToProcess schemaToProcess) {
            List list = (List) this.agRedefinitions.get(str);
            if (list == null) {
                return EMPTY_REDEFINTION_HOLDER_ARRAY;
            }
            return doTopologicalSort(list, schemaToProcess, str, 4);
        }

        public RedefinitionHolder[] getComplexTypeRedefinitions(String str, StscImporter.SchemaToProcess schemaToProcess) {
            List list = (List) this.ctRedefinitions.get(str);
            if (list == null) {
                return EMPTY_REDEFINTION_HOLDER_ARRAY;
            }
            return doTopologicalSort(list, schemaToProcess, str, 2);
        }

        public RedefinitionHolder[] getModelGroupRedefinitions(String str, StscImporter.SchemaToProcess schemaToProcess) {
            List list = (List) this.mgRedefinitions.get(str);
            if (list == null) {
                return EMPTY_REDEFINTION_HOLDER_ARRAY;
            }
            return doTopologicalSort(list, schemaToProcess, str, 3);
        }

        public RedefinitionHolder[] getSimpleTypeRedefinitions(String str, StscImporter.SchemaToProcess schemaToProcess) {
            List list = (List) this.stRedefinitions.get(str);
            if (list == null) {
                return EMPTY_REDEFINTION_HOLDER_ARRAY;
            }
            return doTopologicalSort(list, schemaToProcess, str, 1);
        }
    }

    static {
        Class cls = class$org$apache$xmlbeans$impl$schema$StscTranslator;
        if (cls == null) {
            cls = class$("org.apache.xmlbeans.impl.schema.StscTranslator");
            class$org$apache$xmlbeans$impl$schema$StscTranslator = cls;
        }
        $assertionsDisabled = !cls.desiredAssertionStatus();
    }

    public static void addAllDefinitions(StscImporter.SchemaToProcess[] schemaToProcessArr) {
        boolean z;
        AnnotationDocument.Annotation[] annotationArray;
        ArrayList arrayList = new ArrayList();
        int i2 = 0;
        for (int i3 = 0; i3 < schemaToProcessArr.length; i3++) {
            List<StscImporter.SchemaToProcess> redefines = schemaToProcessArr[i3].getRedefines();
            if (redefines != null) {
                Iterator it = schemaToProcessArr[i3].getRedefineObjects().iterator();
                for (StscImporter.SchemaToProcess schemaToProcess : redefines) {
                    if ($assertionsDisabled || it.hasNext()) {
                        arrayList.add(new RedefinitionHolder(schemaToProcess, (RedefineDocument.Redefine) it.next()));
                    } else {
                        throw new AssertionError("The array of redefines and redefine objects have to have the same length");
                    }
                }
                continue;
            }
        }
        RedefinitionMaster redefinitionMaster = new RedefinitionMaster((RedefinitionHolder[]) arrayList.toArray(new RedefinitionHolder[arrayList.size()]));
        StscState stscState = StscState.get();
        int i4 = 0;
        while (i4 < schemaToProcessArr.length) {
            SchemaDocument.Schema schema = schemaToProcessArr[i4].getSchema();
            String chameleonNamespace = schemaToProcessArr[i4].getChameleonNamespace();
            if (schema.sizeOfNotationArray() > 0) {
                stscState.warning("Schema <notation> is not yet supported for this release.", 51, schema.getNotationArray(i2));
            }
            String targetNamespace = schema.getTargetNamespace();
            if (chameleonNamespace == null || targetNamespace != null) {
                chameleonNamespace = targetNamespace;
                z = false;
            } else {
                z = true;
            }
            if (chameleonNamespace == null) {
                chameleonNamespace = "";
            }
            if (chameleonNamespace.length() > 0 || !isEmptySchema(schema)) {
                stscState.registerContribution(chameleonNamespace, schema.documentProperties().getSourceName());
                stscState.addNewContainer(chameleonNamespace);
            }
            ArrayList arrayList2 = new ArrayList();
            TopLevelComplexType[] complexTypeArray = schema.getComplexTypeArray();
            for (int i5 = 0; i5 < complexTypeArray.length; i5++) {
                TopLevelComplexType topLevelComplexType = complexTypeArray[i5];
                RedefinitionHolder[] complexTypeRedefinitions = redefinitionMaster.getComplexTypeRedefinitions(topLevelComplexType.getName(), schemaToProcessArr[i4]);
                for (int i6 = 0; i6 < complexTypeRedefinitions.length; i6++) {
                    if (complexTypeRedefinitions[i6] != null) {
                        TopLevelComplexType redefineComplexType = complexTypeRedefinitions[i6].redefineComplexType(topLevelComplexType.getName());
                        if ($assertionsDisabled || redefineComplexType != null) {
                            arrayList2.add(topLevelComplexType);
                            topLevelComplexType = redefineComplexType;
                        } else {
                            throw new AssertionError();
                        }
                    }
                }
                SchemaTypeImpl translateGlobalComplexType = translateGlobalComplexType(topLevelComplexType, chameleonNamespace, z, arrayList2.size() > 0);
                stscState.addGlobalType(translateGlobalComplexType, null);
                int size = arrayList2.size() - 1;
                while (size >= 0) {
                    SchemaTypeImpl translateGlobalComplexType2 = translateGlobalComplexType((TopLevelComplexType) arrayList2.remove(size), chameleonNamespace, z, size > 0);
                    stscState.addGlobalType(translateGlobalComplexType2, translateGlobalComplexType);
                    size--;
                    translateGlobalComplexType = translateGlobalComplexType2;
                }
            }
            TopLevelSimpleType[] simpleTypeArray = schema.getSimpleTypeArray();
            for (int i7 = 0; i7 < simpleTypeArray.length; i7++) {
                TopLevelSimpleType topLevelSimpleType = simpleTypeArray[i7];
                RedefinitionHolder[] simpleTypeRedefinitions = redefinitionMaster.getSimpleTypeRedefinitions(topLevelSimpleType.getName(), schemaToProcessArr[i4]);
                for (int i8 = 0; i8 < simpleTypeRedefinitions.length; i8++) {
                    if (simpleTypeRedefinitions[i8] != null) {
                        TopLevelSimpleType redefineSimpleType = simpleTypeRedefinitions[i8].redefineSimpleType(topLevelSimpleType.getName());
                        if ($assertionsDisabled || redefineSimpleType != null) {
                            arrayList2.add(topLevelSimpleType);
                            topLevelSimpleType = redefineSimpleType;
                        } else {
                            throw new AssertionError();
                        }
                    }
                }
                SchemaTypeImpl translateGlobalSimpleType = translateGlobalSimpleType(topLevelSimpleType, chameleonNamespace, z, arrayList2.size() > 0);
                stscState.addGlobalType(translateGlobalSimpleType, null);
                int size2 = arrayList2.size() - 1;
                while (size2 >= 0) {
                    SchemaTypeImpl translateGlobalSimpleType2 = translateGlobalSimpleType((TopLevelSimpleType) arrayList2.remove(size2), chameleonNamespace, z, size2 > 0);
                    stscState.addGlobalType(translateGlobalSimpleType2, translateGlobalSimpleType);
                    size2--;
                    translateGlobalSimpleType = translateGlobalSimpleType2;
                }
            }
            TopLevelElement[] elementArray = schema.getElementArray();
            for (TopLevelElement topLevelElement : elementArray) {
                stscState.addDocumentType(translateDocumentType(topLevelElement, chameleonNamespace, z), QNameHelper.forLNS(topLevelElement.getName(), chameleonNamespace));
            }
            TopLevelAttribute[] attributeArray = schema.getAttributeArray();
            for (TopLevelAttribute topLevelAttribute : attributeArray) {
                stscState.addAttributeType(translateAttributeType(topLevelAttribute, chameleonNamespace, z), QNameHelper.forLNS(topLevelAttribute.getName(), chameleonNamespace));
            }
            NamedGroup[] groupArray = schema.getGroupArray();
            for (int i9 = 0; i9 < groupArray.length; i9++) {
                NamedGroup namedGroup = groupArray[i9];
                RedefinitionHolder[] modelGroupRedefinitions = redefinitionMaster.getModelGroupRedefinitions(namedGroup.getName(), schemaToProcessArr[i4]);
                for (int i10 = 0; i10 < modelGroupRedefinitions.length; i10++) {
                    if (modelGroupRedefinitions[i10] != null) {
                        NamedGroup redefineModelGroup = modelGroupRedefinitions[i10].redefineModelGroup(namedGroup.getName());
                        if ($assertionsDisabled || redefineModelGroup != null) {
                            arrayList2.add(namedGroup);
                            namedGroup = redefineModelGroup;
                        } else {
                            throw new AssertionError();
                        }
                    }
                }
                SchemaModelGroupImpl translateModelGroup = translateModelGroup(namedGroup, chameleonNamespace, z, arrayList2.size() > 0);
                stscState.addModelGroup(translateModelGroup, null);
                int size3 = arrayList2.size() - 1;
                while (size3 >= 0) {
                    SchemaModelGroupImpl translateModelGroup2 = translateModelGroup((NamedGroup) arrayList2.remove(size3), chameleonNamespace, z, size3 > 0);
                    stscState.addModelGroup(translateModelGroup2, translateModelGroup);
                    size3--;
                    translateModelGroup = translateModelGroup2;
                }
            }
            NamedAttributeGroup[] attributeGroupArray = schema.getAttributeGroupArray();
            for (int i11 = 0; i11 < attributeGroupArray.length; i11++) {
                NamedAttributeGroup namedAttributeGroup = attributeGroupArray[i11];
                RedefinitionHolder[] attributeGroupRedefinitions = redefinitionMaster.getAttributeGroupRedefinitions(namedAttributeGroup.getName(), schemaToProcessArr[i4]);
                for (int i12 = 0; i12 < attributeGroupRedefinitions.length; i12++) {
                    if (attributeGroupRedefinitions[i12] != null) {
                        NamedAttributeGroup redefineAttributeGroup = attributeGroupRedefinitions[i12].redefineAttributeGroup(namedAttributeGroup.getName());
                        if ($assertionsDisabled || redefineAttributeGroup != null) {
                            arrayList2.add(namedAttributeGroup);
                            namedAttributeGroup = redefineAttributeGroup;
                        } else {
                            throw new AssertionError();
                        }
                    }
                }
                SchemaAttributeGroupImpl translateAttributeGroup = translateAttributeGroup(namedAttributeGroup, chameleonNamespace, z, arrayList2.size() > 0);
                stscState.addAttributeGroup(translateAttributeGroup, null);
                int size4 = arrayList2.size() - 1;
                while (size4 >= 0) {
                    SchemaAttributeGroupImpl translateAttributeGroup2 = translateAttributeGroup((NamedAttributeGroup) arrayList2.remove(size4), chameleonNamespace, z, size4 > 0);
                    stscState.addAttributeGroup(translateAttributeGroup2, translateAttributeGroup);
                    size4--;
                    translateAttributeGroup = translateAttributeGroup2;
                }
            }
            for (AnnotationDocument.Annotation annotation : schema.getAnnotationArray()) {
                stscState.addAnnotation(SchemaAnnotationImpl.getAnnotation(stscState.getContainer(chameleonNamespace), schema, annotation), chameleonNamespace);
            }
            i4++;
            i2 = 0;
        }
        for (int i13 = 0; i13 < arrayList.size(); i13++) {
            ((RedefinitionHolder) arrayList.get(i13)).complainAboutMissingDefinitions();
        }
    }

    public static BigInteger buildBigInt(XmlAnySimpleType xmlAnySimpleType) {
        if (xmlAnySimpleType == null) {
            return null;
        }
        String stringValue = xmlAnySimpleType.getStringValue();
        try {
            BigInteger bigInteger = new BigInteger(stringValue);
            if (bigInteger.signum() >= 0) {
                return bigInteger;
            }
            StscState.get().error(XmlErrorCodes.INVALID_VALUE, new Object[]{stringValue, SchemaSymbols.ATTVAL_NONNEGATIVEINTEGER}, xmlAnySimpleType);
            return null;
        } catch (NumberFormatException e2) {
            StscState.get().error(XmlErrorCodes.INVALID_VALUE_DETAIL, new Object[]{stringValue, SchemaSymbols.ATTVAL_NONNEGATIVEINTEGER, e2.getMessage()}, xmlAnySimpleType);
            return null;
        }
    }

    public static XmlNonNegativeInteger buildNnInteger(XmlAnySimpleType xmlAnySimpleType) {
        BigInteger buildBigInt = buildBigInt(xmlAnySimpleType);
        try {
            XmlNonNegativeIntegerImpl xmlNonNegativeIntegerImpl = new XmlNonNegativeIntegerImpl();
            xmlNonNegativeIntegerImpl.set(buildBigInt);
            xmlNonNegativeIntegerImpl.setImmutable();
            return xmlNonNegativeIntegerImpl;
        } catch (XmlValueOutOfRangeException unused) {
            StscState.get().error("Internal error processing number", 21, xmlAnySimpleType);
            return null;
        }
    }

    public static XmlPositiveInteger buildPosInteger(XmlAnySimpleType xmlAnySimpleType) {
        BigInteger buildBigInt = buildBigInt(xmlAnySimpleType);
        try {
            XmlPositiveIntegerImpl xmlPositiveIntegerImpl = new XmlPositiveIntegerImpl();
            xmlPositiveIntegerImpl.set(buildBigInt);
            xmlPositiveIntegerImpl.setImmutable();
            return xmlPositiveIntegerImpl;
        } catch (XmlValueOutOfRangeException unused) {
            StscState.get().error("Internal error processing number", 21, xmlAnySimpleType);
            return null;
        }
    }

    public static SchemaType checkRecursiveGroupReference(QName[] qNameArr, QName qName, SchemaTypeImpl schemaTypeImpl) {
        QName[] groupReferenceContext;
        if (qNameArr.length < 1) {
            return null;
        }
        while (schemaTypeImpl != null && schemaTypeImpl.getName() == null && !schemaTypeImpl.isDocumentType()) {
            if (qName.equals(schemaTypeImpl.getContainerField().getName()) && (groupReferenceContext = schemaTypeImpl.getGroupReferenceContext()) != null && groupReferenceContext.length == qNameArr.length) {
                boolean z = false;
                int i2 = 0;
                while (true) {
                    if (i2 < qNameArr.length) {
                        if ((qNameArr[i2] != null || groupReferenceContext[i2] != null) && (qNameArr[i2] == null || !qNameArr[i2].equals(groupReferenceContext[i2]))) {
                            break;
                        }
                        i2++;
                    } else {
                        z = true;
                        break;
                    }
                }
                if (z) {
                    return schemaTypeImpl;
                }
            }
            schemaTypeImpl = (SchemaTypeImpl) schemaTypeImpl.getOuterType();
        }
        return null;
    }

    public static boolean checkXPathSyntax(String str) {
        boolean matches;
        if (str == null) {
            return false;
        }
        String removeWhitespace = removeWhitespace(str);
        synchronized (XPATH_REGEXP) {
            matches = XPATH_REGEXP.matches(removeWhitespace);
        }
        return matches;
    }

    public static /* synthetic */ Class class$(String str) {
        try {
            return Class.forName(str);
        } catch (ClassNotFoundException e2) {
            throw a.a(e2);
        }
    }

    public static void copyGlobalAttributeToLocalAttribute(SchemaGlobalAttributeImpl schemaGlobalAttributeImpl, SchemaLocalAttributeImpl schemaLocalAttributeImpl) {
        schemaLocalAttributeImpl.init(schemaGlobalAttributeImpl.getName(), schemaGlobalAttributeImpl.getTypeRef(), schemaGlobalAttributeImpl.getUse(), schemaGlobalAttributeImpl.getDefaultText(), schemaGlobalAttributeImpl.getParseObject(), schemaGlobalAttributeImpl._defaultValue, schemaGlobalAttributeImpl.isFixed(), schemaGlobalAttributeImpl.getWSDLArrayType(), schemaGlobalAttributeImpl.getAnnotation(), null);
    }

    public static void copyGlobalElementToLocalElement(SchemaGlobalElement schemaGlobalElement, SchemaLocalElementImpl schemaLocalElementImpl) {
        schemaLocalElementImpl.setNameAndTypeRef(schemaGlobalElement.getName(), schemaGlobalElement.getType().getRef());
        schemaLocalElementImpl.setNillable(schemaGlobalElement.isNillable());
        schemaLocalElementImpl.setDefault(schemaGlobalElement.getDefaultText(), schemaGlobalElement.isFixed(), ((SchemaGlobalElementImpl) schemaGlobalElement).getParseObject());
        schemaLocalElementImpl.setIdentityConstraints(((SchemaLocalElementImpl) schemaGlobalElement).getIdentityConstraintRefs());
        schemaLocalElementImpl.setBlock(schemaGlobalElement.blockExtension(), schemaGlobalElement.blockRestriction(), schemaGlobalElement.blockSubstitution());
        schemaLocalElementImpl.setAbstract(schemaGlobalElement.isAbstract());
        SchemaParticle schemaParticle = (SchemaParticle) schemaGlobalElement;
        schemaLocalElementImpl.setTransitionRules(schemaParticle.acceptedStartNames(), schemaParticle.isSkippable());
        schemaLocalElementImpl.setAnnotation(schemaGlobalElement.getAnnotation());
    }

    public static FormChoice findAttributeFormDefault(XmlObject xmlObject) {
        XmlCursor newCursor = xmlObject.newCursor();
        while (newCursor.getObject().schemaType() != SchemaDocument.Schema.type) {
            if (!newCursor.toParent()) {
                return null;
            }
        }
        return ((SchemaDocument.Schema) newCursor.getObject()).xgetAttributeFormDefault();
    }

    public static FormChoice findElementFormDefault(XmlObject xmlObject) {
        XmlCursor newCursor = xmlObject.newCursor();
        while (newCursor.getObject().schemaType() != SchemaDocument.Schema.type) {
            if (!newCursor.toParent()) {
                return null;
            }
        }
        return ((SchemaDocument.Schema) newCursor.getObject()).xgetElementFormDefault();
    }

    public static String findFilename(XmlObject xmlObject) {
        return StscState.get().sourceNameForUri(xmlObject.documentProperties().getSourceName());
    }

    public static Object getUserData(XmlObject xmlObject) {
        XmlCursor newCursor = xmlObject.newCursor();
        Class cls = class$org$apache$xmlbeans$SchemaBookmark;
        if (cls == null) {
            cls = class$("org.apache.xmlbeans.SchemaBookmark");
            class$org$apache$xmlbeans$SchemaBookmark = cls;
        }
        XmlCursor.XmlBookmark bookmark = newCursor.getBookmark(cls);
        if (bookmark == null || !(bookmark instanceof SchemaBookmark)) {
            return null;
        }
        return ((SchemaBookmark) bookmark).getValue();
    }

    public static boolean isEmptySchema(SchemaDocument.Schema schema) {
        XmlCursor newCursor = schema.newCursor();
        boolean z = !newCursor.toFirstChild();
        newCursor.dispose();
        return z;
    }

    public static boolean isReservedTypeName(QName qName) {
        return BuiltinSchemaTypeSystem.get().findType(qName) != null;
    }

    public static String removeWhitespace(String str) {
        StringBuffer stringBuffer = new StringBuffer();
        for (int i2 = 0; i2 < str.length(); i2++) {
            char charAt = str.charAt(i2);
            if (!XMLChar.isSpace(charAt)) {
                stringBuffer.append(charAt);
            }
        }
        return stringBuffer.toString();
    }

    public static SchemaTypeImpl translateAnonymousSimpleType(SimpleType simpleType, String str, boolean z, String str2, String str3, List list, SchemaType schemaType) {
        StscState stscState = StscState.get();
        SchemaTypeImpl schemaTypeImpl = new SchemaTypeImpl(stscState.getContainer(str));
        schemaTypeImpl.setSimpleType(true);
        schemaTypeImpl.setParseContext(simpleType, str, z, str2, str3, false);
        schemaTypeImpl.setOuterSchemaTypeRef(schemaType.getRef());
        schemaTypeImpl.setAnnotation(SchemaAnnotationImpl.getAnnotation(stscState.getContainer(str), simpleType));
        schemaTypeImpl.setUserData(getUserData(simpleType));
        list.add(schemaTypeImpl);
        return schemaTypeImpl;
    }

    public static SchemaLocalAttributeImpl translateAttribute(Attribute attribute, String str, String str2, boolean z, List list, SchemaType schemaType, SchemaAttributeModel schemaAttributeModel, boolean z2) {
        SchemaGlobalAttributeImpl schemaGlobalAttributeImpl;
        SchemaGlobalAttributeImpl schemaGlobalAttributeImpl2;
        int i2;
        int i3;
        String str3;
        String str4;
        SchemaType schemaType2;
        boolean z3;
        boolean z4;
        QName qName;
        SchemaTypeImpl schemaTypeImpl;
        LocalSimpleType localSimpleType;
        SchemaTypeImpl schemaTypeImpl2;
        SchemaType.Ref ref;
        boolean z5;
        StscState stscState = StscState.get();
        String name = attribute.getName();
        QName ref2 = attribute.getRef();
        SOAPArrayType sOAPArrayType = null;
        if (!(ref2 == null || name == null)) {
            if (!name.equals(ref2.getLocalPart()) || !uriMatch(str, ref2.getNamespaceURI())) {
                stscState.error(XmlErrorCodes.SCHEMA_ATTR$REF_OR_NAME_HAS_BOTH, new Object[]{name}, attribute.xgetRef());
            } else {
                stscState.warning(XmlErrorCodes.SCHEMA_ATTR$REF_OR_NAME_HAS_BOTH, new Object[]{name}, attribute.xgetRef());
            }
            name = null;
        }
        if (ref2 == null && name == null) {
            stscState.error(XmlErrorCodes.SCHEMA_ATTR$REF_OR_NAME_HAS_NEITHER, (Object[]) null, attribute);
            return null;
        }
        if (name != null && !XMLChar.isValidNCName(name)) {
            stscState.error(XmlErrorCodes.INVALID_VALUE, new Object[]{name, "name"}, attribute.xgetName());
        }
        if (z2) {
            schemaGlobalAttributeImpl = new SchemaLocalAttributeImpl();
        } else {
            SchemaGlobalAttributeImpl schemaGlobalAttributeImpl3 = new SchemaGlobalAttributeImpl(StscState.get().getContainer(str));
            schemaGlobalAttributeImpl3.setParseContext(attribute, str, z);
            schemaGlobalAttributeImpl = schemaGlobalAttributeImpl3;
        }
        if (ref2 != null) {
            if (attribute.getType() != null) {
                stscState.error(XmlErrorCodes.SCHEMA_ATTR$REF_FEATURES, new Object[]{JamXmlElements.TYPE}, attribute.xgetType());
            }
            if (attribute.getSimpleType() != null) {
                stscState.error(XmlErrorCodes.SCHEMA_ATTR$REF_FEATURES, new Object[]{"<simpleType>"}, attribute.getSimpleType());
            }
            if (attribute.getForm() != null) {
                stscState.error(XmlErrorCodes.SCHEMA_ATTR$REF_FEATURES, new Object[]{"form"}, attribute.xgetForm());
            }
            SchemaGlobalAttributeImpl findGlobalAttribute = stscState.findGlobalAttribute(ref2, z ? str : null, str);
            if (findGlobalAttribute == null) {
                stscState.notFoundError(ref2, 3, attribute.xgetRef(), true);
                return null;
            }
            int use = findGlobalAttribute.getUse();
            schemaType2 = findGlobalAttribute.getType();
            str4 = findGlobalAttribute.getDefaultText();
            if (str4 != null) {
                z3 = findGlobalAttribute.isFixed();
                str3 = z3 ? str4 : null;
            } else {
                str3 = null;
                z3 = false;
            }
            i3 = use;
            schemaGlobalAttributeImpl2 = schemaGlobalAttributeImpl;
            i2 = 2;
        } else {
            if (z2) {
                FormChoice xgetForm = attribute.xgetForm();
                if (xgetForm != null) {
                    z5 = xgetForm.getStringValue().equals("qualified");
                } else if (str2 != null) {
                    z5 = str2.equals("qualified");
                } else {
                    FormChoice findAttributeFormDefault = findAttributeFormDefault(attribute);
                    z5 = findAttributeFormDefault != null && findAttributeFormDefault.getStringValue().equals("qualified");
                }
                qName = z5 ? QNameHelper.forLNS(name, str) : QNameHelper.forLN(name);
            } else {
                qName = QNameHelper.forLNS(name, str);
            }
            if (attribute.getType() != null) {
                schemaTypeImpl = stscState.findGlobalType(attribute.getType(), z ? str : null, str);
                if (schemaTypeImpl == null) {
                    stscState.notFoundError(attribute.getType(), 0, attribute.xgetType(), true);
                }
            } else {
                schemaTypeImpl = null;
            }
            if (qName.getNamespaceURI().equals("http://www.w3.org/2001/XMLSchema-instance")) {
                stscState.error(XmlErrorCodes.NO_XSI, new Object[]{"http://www.w3.org/2001/XMLSchema-instance"}, attribute.xgetName());
            }
            if (qName.getNamespaceURI().length() == 0 && qName.getLocalPart().equals("xmlns")) {
                stscState.error(XmlErrorCodes.NO_XMLNS, (Object[]) null, attribute.xgetName());
            }
            LocalSimpleType simpleType = attribute.getSimpleType();
            if (schemaTypeImpl == null || simpleType == null) {
                localSimpleType = simpleType;
            } else {
                stscState.error(XmlErrorCodes.SCHEMA_ATTR$TYPE_ATTR_OR_NESTED_TYPE, (Object[]) null, simpleType);
                localSimpleType = null;
            }
            if (localSimpleType != null) {
                SchemaTypeImpl schemaTypeImpl3 = new SchemaTypeImpl(stscState.getContainer(str));
                schemaTypeImpl3.setContainerField(schemaGlobalAttributeImpl);
                if (schemaType == null) {
                    ref = null;
                } else {
                    ref = schemaType.getRef();
                }
                schemaTypeImpl3.setOuterSchemaTypeRef(ref);
                list.add(schemaTypeImpl3);
                schemaTypeImpl3.setSimpleType(true);
                schemaTypeImpl2 = schemaTypeImpl3;
                schemaGlobalAttributeImpl2 = schemaGlobalAttributeImpl;
                i2 = 2;
                schemaTypeImpl3.setParseContext(localSimpleType, str, z, null, null, false);
                schemaTypeImpl2.setAnnotation(SchemaAnnotationImpl.getAnnotation(stscState.getContainer(str), localSimpleType));
                schemaTypeImpl2.setUserData(getUserData(localSimpleType));
            } else {
                schemaGlobalAttributeImpl2 = schemaGlobalAttributeImpl;
                i2 = 2;
                schemaTypeImpl2 = schemaTypeImpl;
            }
            if (schemaTypeImpl2 != null || schemaAttributeModel == null || schemaAttributeModel.getAttribute(qName) == null) {
                ref2 = qName;
                schemaType2 = schemaTypeImpl2;
            } else {
                schemaType2 = schemaAttributeModel.getAttribute(qName).getType();
                ref2 = qName;
            }
            str4 = null;
            str3 = null;
            z3 = false;
            i3 = 2;
        }
        if (schemaType2 == null) {
            schemaType2 = BuiltinSchemaTypeSystem.ST_ANY_SIMPLE;
        }
        if (!schemaType2.isSimpleType()) {
            stscState.error("Attributes must have a simple type (not complex).", 46, attribute);
            schemaType2 = BuiltinSchemaTypeSystem.ST_ANY_SIMPLE;
        }
        if (attribute.isSetUse()) {
            int translateUseCode = translateUseCode(attribute.xgetUse());
            if (translateUseCode == i2 || z3) {
                i3 = translateUseCode;
            } else {
                i3 = translateUseCode;
                str4 = null;
            }
        }
        if (attribute.isSetDefault() || attribute.isSetFixed()) {
            if (z3 && !attribute.isSetFixed()) {
                stscState.error("A use of a fixed attribute definition must also be fixed", 9, attribute.xgetFixed());
            }
            boolean isSetFixed = attribute.isSetFixed();
            if (attribute.isSetDefault() && isSetFixed) {
                stscState.error(XmlErrorCodes.SCHEMA_ATTR$DEFAULT_OR_FIXED, (Object[]) null, attribute.xgetFixed());
                isSetFixed = false;
            }
            String fixed = isSetFixed ? attribute.getFixed() : attribute.getDefault();
            if (str3 == null || str3.equals(fixed)) {
                z4 = isSetFixed;
                str3 = fixed;
            } else {
                stscState.error(XmlErrorCodes.SCHEMA_ATTR$FIXED_NOT_MATCH, (Object[]) null, attribute.xgetFixed());
                z4 = isSetFixed;
            }
        } else {
            z4 = z3;
            str3 = str4;
        }
        if (!z2) {
            schemaGlobalAttributeImpl2.setFilename(findFilename(attribute));
        }
        XmlCursor newCursor = attribute.newCursor();
        String attributeText = newCursor.getAttributeText(WSDL_ARRAYTYPE_NAME);
        newCursor.dispose();
        if (attributeText != null) {
            try {
                sOAPArrayType = new SOAPArrayType(attributeText, new NamespaceContext(attribute));
            } catch (XmlValueOutOfRangeException unused) {
                stscState.error(XmlErrorCodes.SOAPARRAY, new Object[]{attributeText}, attribute);
            }
        }
        schemaGlobalAttributeImpl2.init(ref2, schemaType2.getRef(), i3, str3, attribute, null, z4, sOAPArrayType, SchemaAnnotationImpl.getAnnotation(stscState.getContainer(str), attribute), getUserData(attribute));
        return schemaGlobalAttributeImpl2;
    }

    public static SchemaAttributeGroupImpl translateAttributeGroup(AttributeGroup attributeGroup, String str, boolean z, boolean z2) {
        String name = attributeGroup.getName();
        if (name == null) {
            StscState.get().error(XmlErrorCodes.MISSING_NAME, new Object[]{"attribute group"}, attributeGroup);
            return null;
        }
        SchemaContainer container = StscState.get().getContainer(str);
        SchemaAttributeGroupImpl schemaAttributeGroupImpl = new SchemaAttributeGroupImpl(container);
        SchemaAnnotationImpl annotation = SchemaAnnotationImpl.getAnnotation(container, attributeGroup);
        FormChoice findAttributeFormDefault = findAttributeFormDefault(attributeGroup);
        schemaAttributeGroupImpl.init(QNameHelper.forLNS(name, str), str, z, findAttributeFormDefault == null ? null : findAttributeFormDefault.getStringValue(), z2, attributeGroup, annotation, getUserData(attributeGroup));
        schemaAttributeGroupImpl.setFilename(findFilename(attributeGroup));
        return schemaAttributeGroupImpl;
    }

    public static SchemaTypeImpl translateAttributeType(TopLevelAttribute topLevelAttribute, String str, boolean z) {
        SchemaTypeImpl schemaTypeImpl = new SchemaTypeImpl(StscState.get().getContainer(str));
        schemaTypeImpl.setAttributeType(true);
        schemaTypeImpl.setParseContext(topLevelAttribute, str, z, null, null, false);
        schemaTypeImpl.setFilename(findFilename(topLevelAttribute));
        return schemaTypeImpl;
    }

    public static SchemaTypeImpl translateDocumentType(TopLevelElement topLevelElement, String str, boolean z) {
        SchemaTypeImpl schemaTypeImpl = new SchemaTypeImpl(StscState.get().getContainer(str));
        schemaTypeImpl.setDocumentType(true);
        schemaTypeImpl.setParseContext(topLevelElement, str, z, null, null, false);
        schemaTypeImpl.setFilename(findFilename(topLevelElement));
        return schemaTypeImpl;
    }

    /* JADX WARNING: Removed duplicated region for block: B:153:0x032a  */
    /* JADX WARNING: Removed duplicated region for block: B:154:0x032c  */
    /* JADX WARNING: Removed duplicated region for block: B:157:0x0333  */
    /* JADX WARNING: Removed duplicated region for block: B:159:0x0339  */
    /* JADX WARNING: Removed duplicated region for block: B:162:0x034a A[SYNTHETIC, Splitter:B:162:0x034a] */
    /* JADX WARNING: Removed duplicated region for block: B:167:0x0362  */
    /* JADX WARNING: Removed duplicated region for block: B:175:0x0393  */
    /* JADX WARNING: Removed duplicated region for block: B:176:0x0398  */
    /* JADX WARNING: Removed duplicated region for block: B:179:0x03a5  */
    /* JADX WARNING: Removed duplicated region for block: B:194:0x03f3  */
    /* JADX WARNING: Removed duplicated region for block: B:202:0x0416  */
    /* JADX WARNING: Removed duplicated region for block: B:210:0x0437  */
    /* JADX WARNING: Removed duplicated region for block: B:216:0x0453  */
    public static SchemaLocalElementImpl translateElement(Element element, String str, boolean z, String str2, String str3, List list, SchemaType schemaType) {
        SchemaTypeImpl schemaTypeImpl;
        SchemaGlobalElementImpl schemaGlobalElementImpl;
        QName qName;
        SchemaType schemaType2;
        boolean z2;
        Annotated annotated;
        Object obj;
        Object obj2;
        Object obj3;
        QName qName2;
        int i2;
        String attributeText;
        SOAPArrayType sOAPArrayType;
        boolean isSetFixed;
        Object block;
        boolean z3;
        boolean z4;
        boolean z5;
        Keybase[] keyArray;
        int i3;
        boolean z6;
        Keybase[] uniqueArray;
        int i4;
        KeyrefDocument.Keyref[] keyrefArray;
        int i5;
        SchemaGlobalElementImpl findGlobalElement;
        SchemaType.Ref ref;
        boolean z7;
        boolean z8;
        boolean z9;
        StscState stscState = StscState.get();
        if (element.isSetSubstitutionGroup()) {
            SchemaTypeImpl findDocumentType = stscState.findDocumentType(element.getSubstitutionGroup(), ((SchemaTypeImpl) schemaType).getChameleonNamespace(), str);
            if (findDocumentType != null) {
                StscResolver.resolveType(findDocumentType);
            }
            schemaTypeImpl = findDocumentType;
        } else {
            schemaTypeImpl = null;
        }
        String name = element.getName();
        QName ref2 = element.getRef();
        if (!(ref2 == null || name == null)) {
            stscState.error(XmlErrorCodes.SCHEMA_ELEM$REF_OR_NAME_HAS_BOTH, new Object[]{name}, element.xgetRef());
            name = null;
        }
        if (ref2 == null && name == null) {
            stscState.error(XmlErrorCodes.SCHEMA_ELEM$REF_OR_NAME_HAS_NEITHER, (Object[]) null, element);
            return null;
        }
        if (name != null && !XMLChar.isValidNCName(name)) {
            stscState.error(XmlErrorCodes.INVALID_VALUE, new Object[]{name, "name"}, element.xgetName());
        }
        if (ref2 != null) {
            if (element.getType() != null) {
                stscState.error(XmlErrorCodes.SCHEMA_ELEM$REF_FEATURES, new Object[]{JamXmlElements.TYPE}, element.xgetType());
            }
            if (element.getSimpleType() != null) {
                stscState.error(XmlErrorCodes.SCHEMA_ELEM$REF_FEATURES, new Object[]{"<simpleType>"}, element.getSimpleType());
            }
            if (element.getComplexType() != null) {
                stscState.error(XmlErrorCodes.SCHEMA_ELEM$REF_FEATURES, new Object[]{"<complexType>"}, element.getComplexType());
            }
            if (element.getForm() != null) {
                stscState.error(XmlErrorCodes.SCHEMA_ELEM$REF_FEATURES, new Object[]{"form"}, element.xgetForm());
            }
            if (element.sizeOfKeyArray() > 0) {
                stscState.warning(XmlErrorCodes.SCHEMA_ELEM$REF_FEATURES, new Object[]{"<key>"}, element);
            }
            if (element.sizeOfKeyrefArray() > 0) {
                stscState.warning(XmlErrorCodes.SCHEMA_ELEM$REF_FEATURES, new Object[]{"<keyref>"}, element);
            }
            if (element.sizeOfUniqueArray() > 0) {
                stscState.warning(XmlErrorCodes.SCHEMA_ELEM$REF_FEATURES, new Object[]{"<unique>"}, element);
            }
            if (element.isSetDefault()) {
                stscState.warning(XmlErrorCodes.SCHEMA_ELEM$REF_FEATURES, new Object[]{"default"}, element.xgetDefault());
            }
            if (element.isSetFixed()) {
                stscState.warning(XmlErrorCodes.SCHEMA_ELEM$REF_FEATURES, new Object[]{"fixed"}, element.xgetFixed());
            }
            if (element.isSetBlock()) {
                stscState.warning(XmlErrorCodes.SCHEMA_ELEM$REF_FEATURES, new Object[]{"block"}, element.xgetBlock());
            }
            if (element.isSetNillable()) {
                stscState.warning(XmlErrorCodes.SCHEMA_ELEM$REF_FEATURES, new Object[]{"nillable"}, element.xgetNillable());
            }
            if ($assertionsDisabled || (element instanceof LocalElement)) {
                SchemaGlobalElementImpl findGlobalElement2 = stscState.findGlobalElement(ref2, z ? str : null, str);
                if (findGlobalElement2 == null) {
                    stscState.notFoundError(ref2, 1, element.xgetRef(), true);
                    return null;
                }
                SchemaLocalElementImpl schemaLocalElementImpl = new SchemaLocalElementImpl();
                schemaLocalElementImpl.setParticleType(4);
                schemaLocalElementImpl.setUserData(getUserData(element));
                copyGlobalElementToLocalElement(findGlobalElement2, schemaLocalElementImpl);
                return schemaLocalElementImpl;
            }
            throw new AssertionError();
        }
        if (element instanceof LocalElement) {
            SchemaLocalElementImpl schemaLocalElementImpl2 = new SchemaLocalElementImpl();
            FormChoice xgetForm = element.xgetForm();
            if (xgetForm != null) {
                z9 = xgetForm.getStringValue().equals("qualified");
            } else if (str2 != null) {
                z9 = str2.equals("qualified");
            } else {
                FormChoice findElementFormDefault = findElementFormDefault(element);
                z9 = findElementFormDefault != null && findElementFormDefault.getStringValue().equals("qualified");
            }
            if (z9) {
                qName = QNameHelper.forLNS(name, str);
                schemaGlobalElementImpl = schemaLocalElementImpl2;
            } else {
                qName = QNameHelper.forLN(name);
                schemaGlobalElementImpl = schemaLocalElementImpl2;
            }
        } else {
            SchemaGlobalElementImpl schemaGlobalElementImpl2 = new SchemaGlobalElementImpl(stscState.getContainer(str));
            if (schemaTypeImpl != null) {
                SchemaGlobalElementImpl findGlobalElement3 = stscState.findGlobalElement(element.getSubstitutionGroup(), z ? str : null, str);
                if (findGlobalElement3 != null) {
                    schemaGlobalElementImpl2.setSubstitutionGroup(findGlobalElement3.getRef());
                }
            }
            qName = QNameHelper.forLNS(name, str);
            QName[] substitutionGroupMembers = ((SchemaTypeImpl) schemaType).getSubstitutionGroupMembers();
            QNameSetBuilder qNameSetBuilder = new QNameSetBuilder();
            qNameSetBuilder.add(qName);
            for (int i6 = 0; i6 < substitutionGroupMembers.length; i6++) {
                schemaGlobalElementImpl2.addSubstitutionGroupMember(substitutionGroupMembers[i6]);
                qNameSetBuilder.add(substitutionGroupMembers[i6]);
            }
            schemaGlobalElementImpl2.setTransitionRules(QNameSet.forSpecification(qNameSetBuilder), false);
            schemaGlobalElementImpl2.setTransitionNotes(QNameSet.EMPTY, true);
            Object obj4 = element.getFinal();
            if (obj4 != null) {
                if ((obj4 instanceof String) && obj4.equals(SchemaSymbols.ATTVAL_POUNDALL)) {
                    z8 = true;
                    z7 = true;
                    schemaGlobalElementImpl2.setFinal(z7, z8);
                    schemaGlobalElementImpl2.setAbstract(element.getAbstract());
                    schemaGlobalElementImpl2.setFilename(findFilename(element));
                    schemaGlobalElementImpl2.setParseContext(element, str, z);
                    schemaGlobalElementImpl = schemaGlobalElementImpl2;
                } else if (obj4 instanceof List) {
                    List list2 = (List) obj4;
                    z7 = list2.contains(SchemaSymbols.ATTVAL_EXTENSION);
                    z8 = list2.contains(SchemaSymbols.ATTVAL_RESTRICTION);
                    schemaGlobalElementImpl2.setFinal(z7, z8);
                    schemaGlobalElementImpl2.setAbstract(element.getAbstract());
                    schemaGlobalElementImpl2.setFilename(findFilename(element));
                    schemaGlobalElementImpl2.setParseContext(element, str, z);
                    schemaGlobalElementImpl = schemaGlobalElementImpl2;
                }
            }
            z8 = false;
            z7 = false;
            schemaGlobalElementImpl2.setFinal(z7, z8);
            schemaGlobalElementImpl2.setAbstract(element.getAbstract());
            schemaGlobalElementImpl2.setFilename(findFilename(element));
            schemaGlobalElementImpl2.setParseContext(element, str, z);
            schemaGlobalElementImpl = schemaGlobalElementImpl2;
        }
        schemaGlobalElementImpl.setAnnotation(SchemaAnnotationImpl.getAnnotation(stscState.getContainer(str), element));
        schemaGlobalElementImpl.setUserData(getUserData(element));
        if (element.getType() != null) {
            schemaType2 = stscState.findGlobalType(element.getType(), z ? str : null, str);
            if (schemaType2 == null) {
                stscState.notFoundError(element.getType(), 0, element.xgetType(), true);
            }
        } else {
            schemaType2 = null;
        }
        Annotated complexType = element.getComplexType();
        if (complexType == null) {
            complexType = element.getSimpleType();
            z2 = true;
        } else {
            z2 = false;
        }
        if (schemaType2 == null || complexType == null) {
            annotated = complexType;
        } else {
            stscState.error(XmlErrorCodes.SCHEMA_ELEM$TYPE_ATTR_OR_NESTED_TYPE, (Object[]) null, complexType);
            annotated = null;
        }
        if (annotated != null) {
            Object[] currentProcessing = stscState.getCurrentProcessing();
            int length = currentProcessing.length;
            QName[] qNameArr = new QName[length];
            int i7 = 0;
            while (i7 < length) {
                if (currentProcessing[i7] instanceof SchemaModelGroupImpl) {
                    qNameArr[i7] = ((SchemaModelGroupImpl) currentProcessing[i7]).getName();
                }
                i7++;
                length = length;
            }
            schemaType2 = checkRecursiveGroupReference(qNameArr, qName, (SchemaTypeImpl) schemaType);
            if (schemaType2 != null) {
                obj2 = SchemaSymbols.ATTVAL_EXTENSION;
                obj = SchemaSymbols.ATTVAL_RESTRICTION;
                obj3 = SchemaSymbols.ATTVAL_POUNDALL;
            } else {
                SchemaTypeImpl schemaTypeImpl2 = new SchemaTypeImpl(stscState.getContainer(str));
                schemaTypeImpl2.setContainerField(schemaGlobalElementImpl);
                if (schemaType == null) {
                    ref = null;
                } else {
                    ref = schemaType.getRef();
                }
                schemaTypeImpl2.setOuterSchemaTypeRef(ref);
                schemaTypeImpl2.setGroupReferenceContext(qNameArr);
                list.add(schemaTypeImpl2);
                schemaTypeImpl2.setSimpleType(z2);
                obj3 = SchemaSymbols.ATTVAL_POUNDALL;
                obj2 = SchemaSymbols.ATTVAL_EXTENSION;
                obj = SchemaSymbols.ATTVAL_RESTRICTION;
                qName2 = qName;
                i2 = 4;
                schemaTypeImpl2.setParseContext(annotated, str, z, str2, str3, false);
                schemaTypeImpl2.setAnnotation(SchemaAnnotationImpl.getAnnotation(stscState.getContainer(str), annotated));
                schemaTypeImpl2.setUserData(getUserData(annotated));
                schemaType2 = schemaTypeImpl2;
                if (schemaType2 == null && schemaTypeImpl != null) {
                    findGlobalElement = stscState.findGlobalElement(element.getSubstitutionGroup(), !z ? str : null, str);
                    if (findGlobalElement != null) {
                        schemaType2 = findGlobalElement.getType();
                    }
                }
                if (schemaType2 == null) {
                    schemaType2 = BuiltinSchemaTypeSystem.ST_ANY_TYPE;
                }
                XmlCursor newCursor = element.newCursor();
                attributeText = newCursor.getAttributeText(WSDL_ARRAYTYPE_NAME);
                newCursor.dispose();
                if (attributeText == null) {
                    try {
                        sOAPArrayType = new SOAPArrayType(attributeText, new NamespaceContext(element));
                    } catch (XmlValueOutOfRangeException unused) {
                        stscState.error(XmlErrorCodes.SOAPARRAY, new Object[]{attributeText}, element);
                    }
                } else {
                    sOAPArrayType = null;
                }
                schemaGlobalElementImpl.setWsdlArrayType(sOAPArrayType);
                isSetFixed = element.isSetFixed();
                if (element.isSetDefault() && isSetFixed) {
                    stscState.error(XmlErrorCodes.SCHEMA_ELEM$DEFAULT_OR_FIXED, (Object[]) null, element.xgetFixed());
                    isSetFixed = false;
                }
                schemaGlobalElementImpl.setParticleType(i2);
                schemaGlobalElementImpl.setNameAndTypeRef(qName2, schemaType2.getRef());
                schemaGlobalElementImpl.setNillable(element.getNillable());
                schemaGlobalElementImpl.setDefault(!isSetFixed ? element.getFixed() : element.getDefault(), isSetFixed, element);
                block = element.getBlock();
                if (block != null) {
                    if ((block instanceof String) && block.equals(obj3)) {
                        z5 = true;
                        z4 = true;
                        z3 = true;
                        schemaGlobalElementImpl.setBlock(z3, z4, z5);
                        int sizeOfUniqueArray = element.sizeOfUniqueArray() + element.sizeOfKeyrefArray() + element.sizeOfKeyArray();
                        SchemaIdentityConstraintImpl[] schemaIdentityConstraintImplArr = new SchemaIdentityConstraintImpl[sizeOfUniqueArray];
                        keyArray = element.getKeyArray();
                        i3 = 0;
                        int i8 = 0;
                        z6 = false;
                        while (i3 < keyArray.length) {
                        }
                        uniqueArray = element.getUniqueArray();
                        i4 = 0;
                        while (i4 < uniqueArray.length) {
                        }
                        keyrefArray = element.getKeyrefArray();
                        i5 = 0;
                        while (i5 < keyrefArray.length) {
                        }
                        if (!z6) {
                        }
                        return schemaGlobalElementImpl;
                    } else if (block instanceof List) {
                        List list3 = (List) block;
                        z3 = list3.contains(obj2);
                        z4 = list3.contains(obj);
                        z5 = list3.contains(SchemaSymbols.ATTVAL_SUBSTITUTION);
                        schemaGlobalElementImpl.setBlock(z3, z4, z5);
                        int sizeOfUniqueArray2 = element.sizeOfUniqueArray() + element.sizeOfKeyrefArray() + element.sizeOfKeyArray();
                        SchemaIdentityConstraintImpl[] schemaIdentityConstraintImplArr2 = new SchemaIdentityConstraintImpl[sizeOfUniqueArray2];
                        keyArray = element.getKeyArray();
                        i3 = 0;
                        int i82 = 0;
                        z6 = false;
                        while (i3 < keyArray.length) {
                            schemaIdentityConstraintImplArr2[i82] = translateIdentityConstraint(keyArray[i3], str, z);
                            if (schemaIdentityConstraintImplArr2[i82] != null) {
                                schemaIdentityConstraintImplArr2[i82].setConstraintCategory(1);
                            } else {
                                z6 = true;
                            }
                            i3++;
                            i82++;
                        }
                        uniqueArray = element.getUniqueArray();
                        i4 = 0;
                        while (i4 < uniqueArray.length) {
                            schemaIdentityConstraintImplArr2[i82] = translateIdentityConstraint(uniqueArray[i4], str, z);
                            if (schemaIdentityConstraintImplArr2[i82] != null) {
                                schemaIdentityConstraintImplArr2[i82].setConstraintCategory(3);
                            } else {
                                z6 = true;
                            }
                            i4++;
                            i82++;
                        }
                        keyrefArray = element.getKeyrefArray();
                        i5 = 0;
                        while (i5 < keyrefArray.length) {
                            schemaIdentityConstraintImplArr2[i82] = translateIdentityConstraint(keyrefArray[i5], str, z);
                            if (schemaIdentityConstraintImplArr2[i82] != null) {
                                schemaIdentityConstraintImplArr2[i82].setConstraintCategory(2);
                            } else {
                                z6 = true;
                            }
                            i5++;
                            i82++;
                        }
                        if (!z6) {
                            SchemaIdentityConstraint.Ref[] refArr = new SchemaIdentityConstraint.Ref[sizeOfUniqueArray2];
                            for (int i9 = 0; i9 < sizeOfUniqueArray2; i9++) {
                                refArr[i9] = schemaIdentityConstraintImplArr2[i9].getRef();
                            }
                            schemaGlobalElementImpl.setIdentityConstraints(refArr);
                        }
                        return schemaGlobalElementImpl;
                    }
                }
                z5 = false;
                z4 = false;
                z3 = false;
                schemaGlobalElementImpl.setBlock(z3, z4, z5);
                int sizeOfUniqueArray22 = element.sizeOfUniqueArray() + element.sizeOfKeyrefArray() + element.sizeOfKeyArray();
                SchemaIdentityConstraintImpl[] schemaIdentityConstraintImplArr22 = new SchemaIdentityConstraintImpl[sizeOfUniqueArray22];
                keyArray = element.getKeyArray();
                i3 = 0;
                int i822 = 0;
                z6 = false;
                while (i3 < keyArray.length) {
                }
                uniqueArray = element.getUniqueArray();
                i4 = 0;
                while (i4 < uniqueArray.length) {
                }
                keyrefArray = element.getKeyrefArray();
                i5 = 0;
                while (i5 < keyrefArray.length) {
                }
                if (!z6) {
                }
                return schemaGlobalElementImpl;
            }
        } else {
            obj3 = SchemaSymbols.ATTVAL_POUNDALL;
            obj2 = SchemaSymbols.ATTVAL_EXTENSION;
            obj = SchemaSymbols.ATTVAL_RESTRICTION;
        }
        qName2 = qName;
        i2 = 4;
        findGlobalElement = stscState.findGlobalElement(element.getSubstitutionGroup(), !z ? str : null, str);
        if (findGlobalElement != null) {
        }
        if (schemaType2 == null) {
        }
        XmlCursor newCursor2 = element.newCursor();
        attributeText = newCursor2.getAttributeText(WSDL_ARRAYTYPE_NAME);
        newCursor2.dispose();
        if (attributeText == null) {
        }
        sOAPArrayType = null;
        schemaGlobalElementImpl.setWsdlArrayType(sOAPArrayType);
        isSetFixed = element.isSetFixed();
        stscState.error(XmlErrorCodes.SCHEMA_ELEM$DEFAULT_OR_FIXED, (Object[]) null, element.xgetFixed());
        isSetFixed = false;
        schemaGlobalElementImpl.setParticleType(i2);
        schemaGlobalElementImpl.setNameAndTypeRef(qName2, schemaType2.getRef());
        schemaGlobalElementImpl.setNillable(element.getNillable());
        schemaGlobalElementImpl.setDefault(!isSetFixed ? element.getFixed() : element.getDefault(), isSetFixed, element);
        block = element.getBlock();
        if (block != null) {
        }
        z5 = false;
        z4 = false;
        z3 = false;
        schemaGlobalElementImpl.setBlock(z3, z4, z5);
        int sizeOfUniqueArray222 = element.sizeOfUniqueArray() + element.sizeOfKeyrefArray() + element.sizeOfKeyArray();
        SchemaIdentityConstraintImpl[] schemaIdentityConstraintImplArr222 = new SchemaIdentityConstraintImpl[sizeOfUniqueArray222];
        keyArray = element.getKeyArray();
        i3 = 0;
        int i8222 = 0;
        z6 = false;
        while (i3 < keyArray.length) {
        }
        uniqueArray = element.getUniqueArray();
        i4 = 0;
        while (i4 < uniqueArray.length) {
        }
        keyrefArray = element.getKeyrefArray();
        i5 = 0;
        while (i5 < keyrefArray.length) {
        }
        if (!z6) {
        }
        return schemaGlobalElementImpl;
    }

    public static SchemaTypeImpl translateGlobalComplexType(TopLevelComplexType topLevelComplexType, String str, boolean z, boolean z2) {
        StscState stscState = StscState.get();
        String name = topLevelComplexType.getName();
        if (name == null) {
            stscState.error(XmlErrorCodes.MISSING_NAME, new Object[]{"global type"}, topLevelComplexType);
            return null;
        }
        if (!XMLChar.isValidNCName(name)) {
            stscState.error(XmlErrorCodes.INVALID_VALUE, new Object[]{name, "name"}, topLevelComplexType.xgetName());
        }
        QName forLNS = QNameHelper.forLNS(name, str);
        if (isReservedTypeName(forLNS)) {
            stscState.warning(XmlErrorCodes.RESERVED_TYPE_NAME, new Object[]{QNameHelper.pretty(forLNS)}, topLevelComplexType);
            return null;
        }
        SchemaTypeImpl schemaTypeImpl = new SchemaTypeImpl(stscState.getContainer(str));
        schemaTypeImpl.setParseContext(topLevelComplexType, str, z, null, null, z2);
        schemaTypeImpl.setFilename(findFilename(topLevelComplexType));
        schemaTypeImpl.setName(QNameHelper.forLNS(name, str));
        schemaTypeImpl.setAnnotation(SchemaAnnotationImpl.getAnnotation(stscState.getContainer(str), topLevelComplexType));
        schemaTypeImpl.setUserData(getUserData(topLevelComplexType));
        return schemaTypeImpl;
    }

    public static SchemaTypeImpl translateGlobalSimpleType(TopLevelSimpleType topLevelSimpleType, String str, boolean z, boolean z2) {
        StscState stscState = StscState.get();
        String name = topLevelSimpleType.getName();
        if (name == null) {
            stscState.error(XmlErrorCodes.MISSING_NAME, new Object[]{"global type"}, topLevelSimpleType);
            return null;
        }
        if (!XMLChar.isValidNCName(name)) {
            stscState.error(XmlErrorCodes.INVALID_VALUE, new Object[]{name, "name"}, topLevelSimpleType.xgetName());
        }
        QName forLNS = QNameHelper.forLNS(name, str);
        if (isReservedTypeName(forLNS)) {
            stscState.warning(XmlErrorCodes.RESERVED_TYPE_NAME, new Object[]{QNameHelper.pretty(forLNS)}, topLevelSimpleType);
            return null;
        }
        SchemaTypeImpl schemaTypeImpl = new SchemaTypeImpl(stscState.getContainer(str));
        schemaTypeImpl.setSimpleType(true);
        schemaTypeImpl.setParseContext(topLevelSimpleType, str, z, null, null, z2);
        schemaTypeImpl.setFilename(findFilename(topLevelSimpleType));
        schemaTypeImpl.setName(forLNS);
        schemaTypeImpl.setAnnotation(SchemaAnnotationImpl.getAnnotation(stscState.getContainer(str), topLevelSimpleType));
        schemaTypeImpl.setUserData(getUserData(topLevelSimpleType));
        return schemaTypeImpl;
    }

    public static SchemaIdentityConstraintImpl translateIdentityConstraint(Keybase keybase, String str, boolean z) {
        StscState stscState = StscState.get();
        String xpath = keybase.getSelector() == null ? null : keybase.getSelector().getXpath();
        if (!checkXPathSyntax(xpath)) {
            stscState.error(XmlErrorCodes.SELECTOR_XPATH, new Object[]{xpath}, keybase.getSelector().xgetXpath());
            return null;
        }
        FieldDocument.Field[] fieldArray = keybase.getFieldArray();
        for (int i2 = 0; i2 < fieldArray.length; i2++) {
            if (!checkXPathSyntax(fieldArray[i2].getXpath())) {
                stscState.error(XmlErrorCodes.FIELDS_XPATH, new Object[]{fieldArray[i2].getXpath()}, fieldArray[i2].xgetXpath());
                return null;
            }
        }
        SchemaIdentityConstraintImpl schemaIdentityConstraintImpl = new SchemaIdentityConstraintImpl(stscState.getContainer(str));
        schemaIdentityConstraintImpl.setName(QNameHelper.forLNS(keybase.getName(), str));
        schemaIdentityConstraintImpl.setSelector(keybase.getSelector().getXpath());
        schemaIdentityConstraintImpl.setParseContext(keybase, str, z);
        schemaIdentityConstraintImpl.setAnnotation(SchemaAnnotationImpl.getAnnotation(stscState.getContainer(str), keybase));
        schemaIdentityConstraintImpl.setUserData(getUserData(keybase));
        XmlCursor newCursor = keybase.newCursor();
        HashMap hashMap = new HashMap();
        newCursor.getAllNamespaces(hashMap);
        hashMap.remove("");
        schemaIdentityConstraintImpl.setNSMap(hashMap);
        newCursor.dispose();
        int length = fieldArray.length;
        String[] strArr = new String[length];
        for (int i3 = 0; i3 < length; i3++) {
            strArr[i3] = fieldArray[i3].getXpath();
        }
        schemaIdentityConstraintImpl.setFields(strArr);
        try {
            schemaIdentityConstraintImpl.buildPaths();
            stscState.addIdConstraint(schemaIdentityConstraintImpl);
            schemaIdentityConstraintImpl.setFilename(findFilename(keybase));
            return stscState.findIdConstraint(schemaIdentityConstraintImpl.getName(), str, null);
        } catch (XPath.XPathCompileException e2) {
            stscState.error(XmlErrorCodes.INVALID_XPATH, new Object[]{e2.getMessage()}, keybase);
            return null;
        }
    }

    public static SchemaModelGroupImpl translateModelGroup(NamedGroup namedGroup, String str, boolean z, boolean z2) {
        String name = namedGroup.getName();
        if (name == null) {
            StscState.get().error(XmlErrorCodes.MISSING_NAME, new Object[]{"model group"}, namedGroup);
            return null;
        }
        SchemaContainer container = StscState.get().getContainer(str);
        SchemaModelGroupImpl schemaModelGroupImpl = new SchemaModelGroupImpl(container);
        SchemaAnnotationImpl annotation = SchemaAnnotationImpl.getAnnotation(container, namedGroup);
        FormChoice findElementFormDefault = findElementFormDefault(namedGroup);
        FormChoice findAttributeFormDefault = findAttributeFormDefault(namedGroup);
        schemaModelGroupImpl.init(QNameHelper.forLNS(name, str), str, z, findElementFormDefault == null ? null : findElementFormDefault.getStringValue(), findAttributeFormDefault == null ? null : findAttributeFormDefault.getStringValue(), z2, namedGroup, annotation, getUserData(namedGroup));
        schemaModelGroupImpl.setFilename(findFilename(namedGroup));
        return schemaModelGroupImpl;
    }

    public static int translateUseCode(Attribute.Use use) {
        if (use == null) {
            return 2;
        }
        String stringValue = use.getStringValue();
        if (stringValue.equals(SchemaSymbols.ATTVAL_OPTIONAL)) {
            return 2;
        }
        if (stringValue.equals(SchemaSymbols.ATTVAL_REQUIRED)) {
            return 3;
        }
        if (stringValue.equals(SchemaSymbols.ATTVAL_PROHIBITED)) {
            return 1;
        }
        return 2;
    }

    public static boolean uriMatch(String str, String str2) {
        if (str == null) {
            return str2 == null || str2.equals("");
        }
        if (str2 == null) {
            return str.equals("");
        }
        return str.equals(str2);
    }
}
