package org.apache.xmlbeans.impl.store;

import b.b.a.a.a;
import java.io.File;
import java.io.FileOutputStream;
import java.io.InputStream;
import java.io.OutputStream;
import java.io.PrintStream;
import java.io.Reader;
import java.io.Writer;
import java.util.ArrayList;
import java.util.Collection;
import java.util.Map;
import org.apache.poi.javax.xml.namespace.QName;
import org.apache.poi.javax.xml.stream.XMLStreamReader;
import org.apache.xmlbeans.SchemaType;
import org.apache.xmlbeans.SchemaTypeLoader;
import org.apache.xmlbeans.XmlCursor;
import org.apache.xmlbeans.XmlDocumentProperties;
import org.apache.xmlbeans.XmlObject;
import org.apache.xmlbeans.XmlOptions;
import org.apache.xmlbeans.impl.common.GlobalLock;
import org.apache.xmlbeans.impl.common.XMLChar;
import org.apache.xmlbeans.impl.store.Locale;
import org.apache.xmlbeans.impl.store.Path;
import org.apache.xmlbeans.impl.store.Saver;
import org.apache.xmlbeans.impl.store.Xobj;
import org.apache.xmlbeans.xml.stream.XMLInputStream;
import org.w3c.dom.Node;
import org.xml.sax.ContentHandler;
import org.xml.sax.ext.LexicalHandler;

public final class Cursor implements XmlCursor, Locale.ChangeListener {
    public static final /* synthetic */ boolean $assertionsDisabled;
    public static final int ATTR = 3;
    public static final int COMMENT = 4;
    public static final int COPY_CHARS = 5;
    public static final int COPY_XML = 1;
    public static final int COPY_XML_CONTENTS = 3;
    public static final int ELEM = 2;
    public static final int MOVE_CHARS = 4;
    public static final int MOVE_XML = 0;
    public static final int MOVE_XML_CONTENTS = 2;
    public static final int PROCINST = 5;
    public static final int ROOT = 1;
    public static final int TEXT = 0;
    public static /* synthetic */ Class class$org$apache$xmlbeans$impl$store$Cursor;
    public Cur _cur;
    public int _currentSelection;
    public Locale.ChangeListener _nextChangeListener;
    public Path.PathEngine _pathEngine;

    public static final class ChangeStampImpl implements XmlCursor.ChangeStamp {
        public final Locale _locale;
        public final long _versionStamp;

        public ChangeStampImpl(Locale locale) {
            this._locale = locale;
            this._versionStamp = locale.version();
        }

        @Override // org.apache.xmlbeans.XmlCursor.ChangeStamp
        public boolean hasChanged() {
            return this._versionStamp != this._locale.version();
        }
    }

    public static final class DomSaver extends Saver {
        public static final /* synthetic */ boolean $assertionsDisabled;
        public boolean _isFrag;
        public Cur _nodeCur;
        public XmlOptions _options;
        public SchemaTypeLoader _stl;
        public SchemaType _type;

        static {
            Class cls = Cursor.class$org$apache$xmlbeans$impl$store$Cursor;
            if (cls == null) {
                cls = Cursor.class$("org.apache.xmlbeans.impl.store.Cursor");
                Cursor.class$org$apache$xmlbeans$impl$store$Cursor = cls;
            }
            $assertionsDisabled = !cls.desiredAssertionStatus();
        }

        public DomSaver(Cur cur, boolean z, XmlOptions xmlOptions) {
            super(cur, xmlOptions);
            if (cur.isUserNode()) {
                this._type = cur.getUser().get_schema_type();
            }
            this._stl = cur._locale._schemaTypeLoader;
            this._options = xmlOptions;
            this._isFrag = z;
        }

        private void emitTextValue(Saver.SaveCur saveCur) {
            saveCur.push();
            saveCur.next();
            if (saveCur.isText()) {
                this._nodeCur.next();
                this._nodeCur.insertChars(saveCur.getChars(), saveCur._offSrc, saveCur._cchSrc);
                this._nodeCur.toParent();
            }
            saveCur.pop();
        }

        private void ensureDoc() {
            if (!this._nodeCur.isPositioned()) {
                if (this._isFrag) {
                    this._nodeCur.createDomDocFragRoot();
                } else {
                    this._nodeCur.createDomDocumentRoot();
                }
                this._nodeCur.next();
            }
        }

        private QName getQualifiedName(Saver.SaveCur saveCur, QName qName) {
            String namespaceURI = qName.getNamespaceURI();
            String uriMapping = namespaceURI.length() > 0 ? getUriMapping(namespaceURI) : "";
            if (uriMapping.equals(qName.getPrefix())) {
                return qName;
            }
            return this._nodeCur._locale.makeQName(namespaceURI, qName.getLocalPart(), uriMapping);
        }

        @Override // org.apache.xmlbeans.impl.store.Saver
        public void emitComment(Saver.SaveCur saveCur) {
            ensureDoc();
            this._nodeCur.createComment();
            emitTextValue(saveCur);
            this._nodeCur.skip();
        }

        @Override // org.apache.xmlbeans.impl.store.Saver
        public void emitDocType(String str, String str2, String str3) {
            ensureDoc();
            XmlDocumentProperties docProps = Locale.getDocProps(this._nodeCur, true);
            docProps.setDoctypeName(str);
            docProps.setDoctypePublicId(str2);
            docProps.setDoctypeSystemId(str3);
        }

        @Override // org.apache.xmlbeans.impl.store.Saver
        public boolean emitElement(Saver.SaveCur saveCur, ArrayList arrayList, ArrayList arrayList2) {
            if (Locale.isFragmentQName(saveCur.getName())) {
                this._nodeCur.moveTo(null, -2);
            }
            ensureDoc();
            this._nodeCur.createElement(getQualifiedName(saveCur, saveCur.getName()));
            this._nodeCur.next();
            iterateMappings();
            while (hasMapping()) {
                Cur cur = this._nodeCur;
                cur.createAttr(cur._locale.createXmlns(mappingPrefix()));
                this._nodeCur.next();
                this._nodeCur.insertString(mappingUri());
                this._nodeCur.toParent();
                this._nodeCur.skipWithAttrs();
                nextMapping();
            }
            for (int i2 = 0; i2 < arrayList.size(); i2++) {
                this._nodeCur.createAttr(getQualifiedName(saveCur, (QName) arrayList.get(i2)));
                this._nodeCur.next();
                this._nodeCur.insertString((String) arrayList2.get(i2));
                this._nodeCur.toParent();
                this._nodeCur.skipWithAttrs();
            }
            return false;
        }

        @Override // org.apache.xmlbeans.impl.store.Saver
        public void emitEndDoc(Saver.SaveCur saveCur) {
        }

        @Override // org.apache.xmlbeans.impl.store.Saver
        public void emitFinish(Saver.SaveCur saveCur) {
            if (Locale.isFragmentQName(saveCur.getName())) {
                return;
            }
            if ($assertionsDisabled || this._nodeCur.isEnd()) {
                this._nodeCur.next();
                return;
            }
            throw new AssertionError();
        }

        @Override // org.apache.xmlbeans.impl.store.Saver
        public void emitProcinst(Saver.SaveCur saveCur) {
            ensureDoc();
            this._nodeCur.createProcinst(saveCur.getName().getLocalPart());
            emitTextValue(saveCur);
            this._nodeCur.skip();
        }

        @Override // org.apache.xmlbeans.impl.store.Saver
        public void emitStartDoc(Saver.SaveCur saveCur) {
            ensureDoc();
        }

        @Override // org.apache.xmlbeans.impl.store.Saver
        public void emitText(Saver.SaveCur saveCur) {
            ensureDoc();
            Object chars = saveCur.getChars();
            int i2 = saveCur._cchSrc;
            if (i2 > 0) {
                this._nodeCur.insertChars(chars, saveCur._offSrc, i2);
                this._nodeCur.next();
            }
        }

        public Node saveDom() {
            Locale locale = Locale.getLocale(this._stl, this._options);
            locale.enter();
            try {
                this._nodeCur = locale.getCur();
                while (process()) {
                }
                while (!this._nodeCur.isRoot()) {
                    this._nodeCur.toParent();
                }
                if (this._type != null) {
                    this._nodeCur.setType(this._type);
                }
                Node node = (Node) this._nodeCur.getDom();
                this._nodeCur.release();
                this._nodeCur = null;
                return node;
            } finally {
                locale.exit();
            }
        }
    }

    static {
        Class cls = class$org$apache$xmlbeans$impl$store$Cursor;
        if (cls == null) {
            cls = class$("org.apache.xmlbeans.impl.store.Cursor");
            class$org$apache$xmlbeans$impl$store$Cursor = cls;
        }
        $assertionsDisabled = !cls.desiredAssertionStatus();
    }

    public Cursor(Xobj xobj, int i2) {
        Cur weakCur = xobj._locale.weakCur(this);
        this._cur = weakCur;
        weakCur.moveTo(xobj, i2);
        this._currentSelection = -1;
    }

    private boolean checkContentInsertionValidity(Cursor cursor) {
        this._cur.push();
        this._cur.next();
        if (this._cur.isFinish()) {
            this._cur.pop();
            return false;
        }
        try {
            cursor.checkInsertionValidity(this._cur);
            this._cur.pop();
            return true;
        } catch (IllegalArgumentException e2) {
            this._cur.pop();
            throw e2;
        }
    }

    private Cursor checkCursors(XmlCursor xmlCursor) {
        checkThisCursor();
        if (xmlCursor == null) {
            throw new IllegalArgumentException("Other cursor is <null>");
        } else if (xmlCursor instanceof Cursor) {
            Cursor cursor = (Cursor) xmlCursor;
            if (cursor._cur != null) {
                return cursor;
            }
            throw new IllegalStateException("Other cursor has been disposed");
        } else {
            StringBuffer stringBuffer = new StringBuffer();
            stringBuffer.append("Incompatible cursors: ");
            stringBuffer.append(xmlCursor);
            throw new IllegalArgumentException(stringBuffer.toString());
        }
    }

    private void checkInsertionValidity(Cur cur) {
        int kind = cur.kind();
        if (kind < 0) {
            complain("Can't move/copy/insert an end token.");
        }
        if (kind == 1) {
            complain("Can't move/copy/insert a whole document.");
        }
        int kind2 = this._cur.kind();
        if (kind2 == 1) {
            complain("Can't insert before the start of the document.");
        }
        if (kind == 3) {
            this._cur.push();
            this._cur.prevWithAttrs();
            int kind3 = this._cur.kind();
            this._cur.pop();
            if (!(kind3 == 2 || kind3 == 1 || kind3 == -3)) {
                complain("Can only insert attributes before other attributes or after containers.");
            }
        }
        if (kind2 == 3 && kind != 3) {
            complain("Can only insert attributes before other attributes or after containers.");
        }
    }

    private void checkThisCursor() {
        if (this._cur == null) {
            throw new IllegalStateException("This cursor has been disposed");
        }
    }

    public static /* synthetic */ Class class$(String str) {
        try {
            return Class.forName(str);
        } catch (ClassNotFoundException e2) {
            throw a.a(e2);
        }
    }

    public static void complain(String str) {
        throw new IllegalArgumentException(str);
    }

    public static XmlCursor.XmlBookmark getBookmark(Object obj, Cur cur) {
        Object bookmark;
        if (obj == null || (bookmark = cur.getBookmark(obj)) == null || !(bookmark instanceof XmlCursor.XmlBookmark)) {
            return null;
        }
        return (XmlCursor.XmlBookmark) bookmark;
    }

    private void insertNode(Cur cur, String str) {
        if (!$assertionsDisabled && cur.isRoot()) {
            throw new AssertionError();
        } else if (!$assertionsDisabled && !cur.isNode()) {
            throw new AssertionError();
        } else if (!$assertionsDisabled && !isValid(cur)) {
            throw new AssertionError();
        } else if ($assertionsDisabled || isValid()) {
            if (str != null && str.length() > 0) {
                cur.next();
                cur.insertString(str);
                cur.toParent();
            }
            checkInsertionValidity(cur);
            cur.moveNode(this._cur);
            this._cur.toEnd();
            this._cur.nextWithAttrs();
        } else {
            throw new AssertionError();
        }
    }

    private boolean isDomFragment() {
        if (!isStartdoc()) {
            return true;
        }
        boolean z = false;
        XmlCursor newCursor = newCursor();
        int intValue = newCursor.toNextToken().intValue();
        while (true) {
            switch (intValue) {
                case 1:
                    if (!$assertionsDisabled) {
                        throw new AssertionError();
                    }
                    break;
                case 3:
                    if (z) {
                        newCursor.dispose();
                        return true;
                    }
                    intValue = newCursor.toEndToken().intValue();
                    z = true;
                case 4:
                case 8:
                case 9:
                    intValue = newCursor.toNextToken().intValue();
                case 5:
                    try {
                        if (!Locale.isWhiteSpace(newCursor.getChars())) {
                            return true;
                        }
                        intValue = newCursor.toNextToken().intValue();
                    } finally {
                        newCursor.dispose();
                    }
                case 6:
                case 7:
                    newCursor.dispose();
                    return true;
            }
        }
        newCursor.dispose();
        return !z;
    }

    public static boolean isValid(Cur cur) {
        int kind;
        if (cur.kind() > 0) {
            return true;
        }
        cur.push();
        if (cur.toParentRaw() && ((kind = cur.kind()) == 4 || kind == 5 || kind == 3)) {
            return false;
        }
        cur.pop();
        return true;
    }

    public static XmlCursor newCursor(Xobj xobj, int i2) {
        Cursor cursor;
        Locale locale = xobj._locale;
        if (locale.noSync()) {
            locale.enter();
            try {
                return new Cursor(xobj, i2);
            } finally {
                locale.exit();
            }
        } else {
            synchronized (locale) {
                locale.enter();
                try {
                    cursor = new Cursor(xobj, i2);
                } finally {
                    locale.exit();
                }
            }
            return cursor;
        }
    }

    private Cursor preCheck(XmlCursor xmlCursor) {
        Cursor checkCursors = checkCursors(xmlCursor);
        if (this._cur._locale == checkCursors._cur._locale) {
            return checkCursors;
        }
        throw new IllegalArgumentException("Cursors not in same document");
    }

    private void setTextValue(Object obj, int i2, int i3) {
        if (this._cur.isNode()) {
            this._cur.moveNodeContents(null, false);
            this._cur.next();
            this._cur.insertChars(obj, i2, i3);
            this._cur.toParent();
            return;
        }
        throw new IllegalStateException("Can't set text value, current token can have no text value");
    }

    /* JADX WARNING: Removed duplicated region for block: B:74:0x0080  */
    private int twoLocaleOp(XmlCursor xmlCursor, int i2, int i3) {
        Throwable th;
        InterruptedException e2;
        Throwable th2;
        Throwable th3;
        int twoLocaleOp;
        int twoLocaleOp2;
        int twoLocaleOp3;
        Cursor checkCursors = checkCursors(xmlCursor);
        Locale locale = this._cur._locale;
        Locale locale2 = checkCursors._cur._locale;
        if (locale == locale2) {
            if (locale.noSync()) {
                return twoLocaleOp(checkCursors, i2, i3);
            }
            synchronized (locale) {
                twoLocaleOp3 = twoLocaleOp(checkCursors, i2, i3);
            }
            return twoLocaleOp3;
        } else if (locale.noSync()) {
            if (locale2.noSync()) {
                return twoLocaleOp(checkCursors, i2, i3);
            }
            synchronized (locale2) {
                twoLocaleOp2 = twoLocaleOp(checkCursors, i2, i3);
            }
            return twoLocaleOp2;
        } else if (locale2.noSync()) {
            synchronized (locale) {
                twoLocaleOp = twoLocaleOp(checkCursors, i2, i3);
            }
            return twoLocaleOp;
        } else {
            boolean z = false;
            try {
                GlobalLock.acquire();
                try {
                    synchronized (locale) {
                        try {
                            synchronized (locale2) {
                                try {
                                    GlobalLock.release();
                                    try {
                                        int twoLocaleOp4 = twoLocaleOp(checkCursors, i2, i3);
                                        try {
                                            return twoLocaleOp4;
                                        } catch (Throwable th4) {
                                            th2 = th4;
                                            throw th2;
                                        }
                                    } catch (Throwable th5) {
                                        th3 = th5;
                                        throw th3;
                                    }
                                } catch (Throwable th6) {
                                    th3 = th6;
                                    throw th3;
                                }
                            }
                        } catch (Throwable th7) {
                            th2 = th7;
                            throw th2;
                        }
                    }
                } catch (InterruptedException e3) {
                    e2 = e3;
                    z = true;
                    try {
                        throw new RuntimeException(e2.getMessage(), e2);
                    } catch (Throwable th8) {
                        th = th8;
                        if (z) {
                            GlobalLock.release();
                        }
                        throw th;
                    }
                } catch (Throwable th9) {
                    th = th9;
                    z = true;
                    if (z) {
                    }
                    throw th;
                }
            } catch (InterruptedException e4) {
                e2 = e4;
                throw new RuntimeException(e2.getMessage(), e2);
            }
        }
    }

    public static void validateLocalName(QName qName) {
        if (qName != null) {
            validateLocalName(qName.getLocalPart());
            return;
        }
        throw new IllegalArgumentException("QName is null");
    }

    public static void validatePrefix(String str) {
        if (str == null) {
            throw new IllegalArgumentException("Prefix is null");
        } else if (str.length() == 0) {
            throw new IllegalArgumentException("Prefix is empty");
        } else if (Locale.beginsWithXml(str)) {
            throw new IllegalArgumentException("Prefix begins with 'xml'");
        } else if (!XMLChar.isValidNCName(str)) {
            throw new IllegalArgumentException("Prefix is not valid");
        }
    }

    public boolean ___toNextSibling() {
        if (!this._cur.hasParent()) {
            return false;
        }
        Xobj parentNoRoot = this._cur.getParentNoRoot();
        if (parentNoRoot == null) {
            this._cur._locale.enter();
            try {
                parentNoRoot = this._cur.getParent();
            } finally {
                this._cur._locale.exit();
            }
        }
        return Locale.toNextSiblingElement(this._cur, parentNoRoot);
    }

    public void _addToSelection() {
        _toSelection(Integer.MAX_VALUE);
        this._cur.addToSelection();
    }

    public void _beginElement(String str) {
        _insertElementWithText(str, null, null);
        _toPrevToken();
    }

    public void _clearBookmark(Object obj) {
        if (obj != null) {
            this._cur.setBookmark(obj, null);
        }
    }

    public void _clearSelections() {
        Path.PathEngine pathEngine = this._pathEngine;
        if (pathEngine != null) {
            pathEngine.release();
            this._pathEngine = null;
        }
        this._cur.clearSelection();
        this._currentSelection = -1;
    }

    public int _comparePosition(Cursor cursor) {
        int comparePosition = this._cur.comparePosition(cursor._cur);
        if (comparePosition == 2) {
            throw new IllegalArgumentException("Cursors not in same document");
        } else if ($assertionsDisabled || (comparePosition >= -1 && comparePosition <= 1)) {
            return comparePosition;
        } else {
            throw new AssertionError();
        }
    }

    public int _copyChars(int i2, Cursor cursor) {
        int cchRight = this._cur.cchRight();
        if (cchRight <= 0 || i2 == 0) {
            return 0;
        }
        if (i2 < 0 || i2 > cchRight) {
            i2 = cchRight;
        }
        cursor.checkInsertionValidity(this._cur);
        Cur cur = cursor._cur;
        Object chars = this._cur.getChars(i2);
        Cur cur2 = this._cur;
        cur.insertChars(chars, cur2._offSrc, cur2._cchSrc);
        cursor._cur.nextChars(this._cur._cchSrc);
        return this._cur._cchSrc;
    }

    public boolean _copyXml(Cursor cursor) {
        cursor.checkInsertionValidity(this._cur);
        if ($assertionsDisabled || this._cur.isText() || this._cur.isNode()) {
            Cur tempCur = cursor.tempCur();
            if (this._cur.isText()) {
                Cur cur = cursor._cur;
                Object chars = this._cur.getChars(-1);
                Cur cur2 = this._cur;
                cur.insertChars(chars, cur2._offSrc, cur2._cchSrc);
            } else {
                this._cur.copyNode(cursor._cur);
            }
            cursor._cur.moveToCur(tempCur);
            tempCur.release();
            return true;
        }
        throw new AssertionError();
    }

    public boolean _copyXmlContents(Cursor cursor) {
        if (!this._cur.isContainer() || this._cur.contains(cursor._cur) || !checkContentInsertionValidity(cursor)) {
            return false;
        }
        Cur tempCur = this._cur._locale.tempCur();
        this._cur.copyNode(tempCur);
        Cur tempCur2 = cursor._cur.tempCur();
        tempCur.moveNodeContents(cursor._cur, false);
        tempCur.release();
        cursor._cur.moveToCur(tempCur2);
        tempCur2.release();
        return true;
    }

    public XmlCursor.TokenType _currentTokenType() {
        if ($assertionsDisabled || isValid()) {
            switch (this._cur.kind()) {
                case -2:
                    return XmlCursor.TokenType.END;
                case -1:
                    return XmlCursor.TokenType.ENDDOC;
                case 0:
                    return XmlCursor.TokenType.TEXT;
                case 1:
                    return XmlCursor.TokenType.STARTDOC;
                case 2:
                    return XmlCursor.TokenType.START;
                case 3:
                    return this._cur.isXmlns() ? XmlCursor.TokenType.NAMESPACE : XmlCursor.TokenType.ATTR;
                case 4:
                    return XmlCursor.TokenType.COMMENT;
                case 5:
                    return XmlCursor.TokenType.PROCINST;
                default:
                    throw new IllegalStateException();
            }
        } else {
            throw new AssertionError();
        }
    }

    public void _dispose() {
        this._cur.release();
        this._cur = null;
    }

    public XmlDocumentProperties _documentProperties() {
        return Locale.getDocProps(this._cur, true);
    }

    public void _dump() {
        this._cur.dump();
    }

    public XmlCursor _execQuery(String str) {
        return _execQuery(str, null);
    }

    public void _getAllBookmarkRefs(Collection collection) {
        if (collection != null) {
            for (Xobj.Bookmark bookmark = this._cur._xobj._bookmarks; bookmark != null; bookmark = bookmark._next) {
                Object obj = bookmark._value;
                if (obj instanceof XmlCursor.XmlBookmark) {
                    collection.add(obj);
                }
            }
        }
    }

    public void _getAllNamespaces(Map map) {
        if (!this._cur.isContainer()) {
            throw new IllegalStateException("Not on a container");
        } else if (map != null) {
            Locale.getAllNamespaces(this._cur, map);
        }
    }

    public String _getAttributeText(QName qName) {
        if (qName == null) {
            throw new IllegalArgumentException("Attr name is null");
        } else if (!this._cur.isContainer()) {
            return null;
        } else {
            return this._cur.getAttrValue(qName);
        }
    }

    public XmlCursor.XmlBookmark _getBookmark(Object obj) {
        if (obj == null) {
            return null;
        }
        return getBookmark(obj, this._cur);
    }

    public String _getChars() {
        return this._cur.getCharsAsString(-1);
    }

    public XmlCursor.ChangeStamp _getDocChangeStamp() {
        return new ChangeStampImpl(this._cur._locale);
    }

    public Node _getDomNode() {
        return (Node) this._cur.getDom();
    }

    public QName _getName() {
        int kind = this._cur.kind();
        if (kind != 2) {
            if (kind != 3) {
                if (kind != 5) {
                    return null;
                }
            } else if (this._cur.isXmlns()) {
                Cur cur = this._cur;
                return cur._locale.makeQNameNoCheck(cur.getXmlnsUri(), this._cur.getXmlnsPrefix());
            }
        }
        return this._cur.getName();
    }

    public XmlObject _getObject() {
        return this._cur.getObject();
    }

    public int _getSelectionCount() {
        _toSelection(Integer.MAX_VALUE);
        return this._cur.selectionCount();
    }

    public String _getTextValue() {
        if (this._cur.isText()) {
            return _getChars();
        }
        if (this._cur.isNode()) {
            return this._cur.hasChildren() ? Locale.getTextValue(this._cur) : this._cur.getValueAsString();
        }
        throw new IllegalStateException("Can't get text value, current token can have no text value");
    }

    public boolean _hasNextSelection() {
        int i2 = this._currentSelection;
        push();
        try {
            return _toNextSelection();
        } finally {
            this._currentSelection = i2;
            pop();
        }
    }

    public boolean _hasNextToken() {
        Cur cur = this._cur;
        return (cur._pos == -1 && cur._xobj.kind() == 1) ? false : true;
    }

    public boolean _hasPrevToken() {
        return this._cur.kind() != 1;
    }

    public void _insertAttribute(String str) {
        _insertAttributeWithValue(str, (String) null);
    }

    public void _insertAttributeWithValue(String str, String str2) {
        _insertAttributeWithValue(str, null, str2);
    }

    public void _insertChars(String str) {
        int length = str == null ? 0 : str.length();
        if (length <= 0) {
            return;
        }
        if (this._cur.isRoot() || this._cur.isAttr()) {
            throw new IllegalStateException("Can't insert before the document or an attribute.");
        }
        this._cur.insertChars(str, 0, length);
        this._cur.nextChars(length);
    }

    public void _insertComment(String str) {
        Cur tempCur = this._cur._locale.tempCur();
        tempCur.createComment();
        insertNode(tempCur, str);
        tempCur.release();
    }

    public void _insertElement(String str) {
        _insertElementWithText(str, null, null);
    }

    public void _insertElementWithText(String str, String str2) {
        _insertElementWithText(str, null, str2);
    }

    public void _insertNamespace(String str, String str2) {
        _insertAttributeWithValue(this._cur._locale.createXmlns(str), str2);
    }

    public void _insertProcInst(String str, String str2) {
        validateLocalName(str);
        if (!Locale.beginsWithXml(str) || str.length() != 3) {
            Cur tempCur = this._cur._locale.tempCur();
            tempCur.createProcinst(str);
            insertNode(tempCur, str2);
            tempCur.release();
            return;
        }
        throw new IllegalArgumentException("Target is 'xml'");
    }

    public boolean _isAnyAttr() {
        if ($assertionsDisabled || isValid()) {
            return this._cur.isAttr();
        }
        throw new AssertionError();
    }

    public boolean _isAtSamePositionAs(Cursor cursor) {
        return this._cur.isSamePos(cursor._cur);
    }

    public boolean _isAttr() {
        if ($assertionsDisabled || isValid()) {
            return this._cur.isNormalAttr();
        }
        throw new AssertionError();
    }

    public boolean _isComment() {
        if ($assertionsDisabled || isValid()) {
            return this._cur.isComment();
        }
        throw new AssertionError();
    }

    public boolean _isContainer() {
        if ($assertionsDisabled || isValid()) {
            return this._cur.isContainer();
        }
        throw new AssertionError();
    }

    public boolean _isEnd() {
        if ($assertionsDisabled || isValid()) {
            return this._cur.isEnd();
        }
        throw new AssertionError();
    }

    public boolean _isEnddoc() {
        if ($assertionsDisabled || isValid()) {
            return this._cur.isEndRoot();
        }
        throw new AssertionError();
    }

    public boolean _isFinish() {
        if ($assertionsDisabled || isValid()) {
            return this._cur.isFinish();
        }
        throw new AssertionError();
    }

    public boolean _isLeftOf(Cursor cursor) {
        return _comparePosition(cursor) < 0;
    }

    public boolean _isNamespace() {
        if ($assertionsDisabled || isValid()) {
            return this._cur.isXmlns();
        }
        throw new AssertionError();
    }

    public boolean _isProcinst() {
        if ($assertionsDisabled || isValid()) {
            return this._cur.isProcinst();
        }
        throw new AssertionError();
    }

    public boolean _isRightOf(Cursor cursor) {
        return _comparePosition(cursor) > 0;
    }

    public boolean _isStart() {
        if ($assertionsDisabled || isValid()) {
            return this._cur.isElem();
        }
        throw new AssertionError();
    }

    public boolean _isStartdoc() {
        if ($assertionsDisabled || isValid()) {
            return this._cur.isRoot();
        }
        throw new AssertionError();
    }

    public boolean _isText() {
        if ($assertionsDisabled || isValid()) {
            return this._cur.isText();
        }
        throw new AssertionError();
    }

    public Object _monitor() {
        return this._cur._locale;
    }

    public int _moveChars(int i2, Cursor cursor) {
        int cchRight = this._cur.cchRight();
        if (cchRight <= 0 || i2 == 0) {
            return 0;
        }
        if (i2 < 0 || i2 > cchRight) {
            i2 = cchRight;
        }
        cursor.checkInsertionValidity(this._cur);
        this._cur.moveChars(cursor._cur, i2);
        cursor._cur.nextChars(this._cur._cchSrc);
        return this._cur._cchSrc;
    }

    public boolean _moveXml(Cursor cursor) {
        cursor.checkInsertionValidity(this._cur);
        if (this._cur.isText()) {
            int cchRight = this._cur.cchRight();
            if (!$assertionsDisabled && cchRight <= 0) {
                throw new AssertionError();
            } else if (this._cur.inChars(cursor._cur, cchRight, true)) {
                return false;
            } else {
                this._cur.moveChars(cursor._cur, cchRight);
                cursor._cur.nextChars(cchRight);
                return true;
            }
        } else if (this._cur.contains(cursor._cur)) {
            return false;
        } else {
            Cur tempCur = cursor.tempCur();
            this._cur.moveNode(cursor._cur);
            cursor._cur.moveToCur(tempCur);
            tempCur.release();
            return true;
        }
    }

    public boolean _moveXmlContents(Cursor cursor) {
        if (!this._cur.isContainer() || this._cur.contains(cursor._cur) || !checkContentInsertionValidity(cursor)) {
            return false;
        }
        Cur tempCur = cursor.tempCur();
        this._cur.moveNodeContents(cursor._cur, false);
        cursor._cur.moveToCur(tempCur);
        tempCur.release();
        return true;
    }

    public String _namespaceForPrefix(String str) {
        if (this._cur.isContainer()) {
            return this._cur.namespaceForPrefix(str, true);
        }
        throw new IllegalStateException("Not on a container");
    }

    public XmlCursor _newCursor() {
        return new Cursor(this._cur);
    }

    public Node _newDomNode() {
        return _newDomNode(null);
    }

    public InputStream _newInputStream() {
        return _newInputStream(null);
    }

    public Reader _newReader() {
        return _newReader(null);
    }

    public XMLInputStream _newXMLInputStream() {
        return _newXMLInputStream(null);
    }

    public XMLStreamReader _newXMLStreamReader() {
        return _newXMLStreamReader(null);
    }

    public boolean _pop() {
        return this._cur.pop();
    }

    public String _prefixForNamespace(String str) {
        if (str != null && str.length() != 0) {
            return this._cur.prefixForNamespace(str, null, true);
        }
        throw new IllegalArgumentException("Must specify a namespace");
    }

    public XmlCursor.TokenType _prevTokenType() {
        this._cur.push();
        XmlCursor.TokenType _toPrevToken = _toPrevToken();
        this._cur.pop();
        return _toPrevToken;
    }

    public void _push() {
        this._cur.push();
    }

    public boolean _removeAttribute(QName qName) {
        if (qName == null) {
            throw new IllegalArgumentException("Attr name is null");
        } else if (!this._cur.isContainer()) {
            return false;
        } else {
            return this._cur.removeAttr(qName);
        }
    }

    public int _removeChars(int i2) {
        int cchRight = this._cur.cchRight();
        if (cchRight == 0 || i2 == 0) {
            return 0;
        }
        if (i2 < 0 || i2 > cchRight) {
            i2 = cchRight;
        }
        this._cur.moveChars(null, i2);
        return this._cur._cchSrc;
    }

    public boolean _removeXml() {
        if (this._cur.isRoot()) {
            throw new IllegalStateException("Can't remove a whole document.");
        } else if (this._cur.isFinish()) {
            return false;
        } else {
            if (!$assertionsDisabled && !this._cur.isText() && !this._cur.isNode()) {
                throw new AssertionError();
            } else if (this._cur.isText()) {
                this._cur.moveChars(null, -1);
                return true;
            } else {
                this._cur.moveNode(null);
                return true;
            }
        }
    }

    public boolean _removeXmlContents() {
        if (!this._cur.isContainer()) {
            return false;
        }
        this._cur.moveNodeContents(null, false);
        return true;
    }

    public void _save(File file) {
        _save(file, (XmlOptions) null);
    }

    public void _selectPath(String str) {
        _selectPath(str, null);
    }

    public boolean _setAttributeText(QName qName, String str) {
        if (qName != null) {
            validateLocalName(qName.getLocalPart());
            if (!this._cur.isContainer()) {
                return false;
            }
            this._cur.setAttrValue(qName, str);
            return true;
        }
        throw new IllegalArgumentException("Attr name is null");
    }

    public void _setBookmark(XmlCursor.XmlBookmark xmlBookmark) {
        if (xmlBookmark == null) {
            return;
        }
        if (xmlBookmark.getKey() != null) {
            xmlBookmark._currentMark = this._cur.setBookmark(xmlBookmark.getKey(), xmlBookmark);
            return;
        }
        throw new IllegalArgumentException("Annotation key is null");
    }

    public void _setName(QName qName) {
        if (qName != null) {
            int kind = this._cur.kind();
            if (kind == 2 || kind == 3) {
                validateLocalName(qName.getLocalPart());
            } else if (kind == 5) {
                validatePrefix(qName.getLocalPart());
                if (qName.getNamespaceURI().length() > 0) {
                    throw new IllegalArgumentException("Procinst name must have no URI");
                } else if (qName.getPrefix().length() > 0) {
                    throw new IllegalArgumentException("Procinst name must have no prefix");
                }
            } else {
                throw new IllegalStateException("Can set name on element, atrtribute and procinst only");
            }
            this._cur.setName(qName);
            return;
        }
        throw new IllegalArgumentException("Name is null");
    }

    public void _setTextValue(String str) {
        if (str == null) {
            str = "";
        }
        setTextValue(str, 0, str.length());
    }

    public boolean _toBookmark(XmlCursor.XmlBookmark xmlBookmark) {
        Xobj.Bookmark bookmark;
        Xobj xobj;
        if (xmlBookmark != null) {
            XmlCursor.XmlMark xmlMark = xmlBookmark._currentMark;
            if ((xmlMark instanceof Xobj.Bookmark) && (xobj = (bookmark = (Xobj.Bookmark) xmlMark)._xobj) != null) {
                Locale locale = xobj._locale;
                Cur cur = this._cur;
                if (locale == cur._locale) {
                    cur.moveTo(xobj, bookmark._pos);
                    return true;
                }
            }
        }
        return false;
    }

    public boolean _toChild(String str) {
        return _toChild((String) null, str);
    }

    public boolean _toCursor(Cursor cursor) {
        if ($assertionsDisabled || this._cur._locale == cursor._cur._locale) {
            this._cur.moveToCur(cursor._cur);
            return true;
        }
        throw new AssertionError();
    }

    public void _toEndDoc() {
        _toStartDoc();
        this._cur.toEnd();
    }

    public XmlCursor.TokenType _toEndToken() {
        if (!this._cur.isContainer()) {
            return XmlCursor.TokenType.NONE;
        }
        this._cur.toEnd();
        return currentTokenType();
    }

    public boolean _toFirstAttribute() {
        return this._cur.isContainer() && Locale.toFirstNormalAttr(this._cur);
    }

    public boolean _toFirstChild() {
        return Locale.toFirstChildElement(this._cur);
    }

    public XmlCursor.TokenType _toFirstContentToken() {
        if (!this._cur.isContainer()) {
            return XmlCursor.TokenType.NONE;
        }
        this._cur.next();
        return currentTokenType();
    }

    public boolean _toLastAttribute() {
        if (this._cur.isContainer()) {
            this._cur.push();
            this._cur.push();
            boolean z = false;
            while (this._cur.toNextAttr()) {
                if (this._cur.isNormalAttr()) {
                    this._cur.popButStay();
                    this._cur.push();
                    z = true;
                }
            }
            this._cur.pop();
            if (z) {
                this._cur.popButStay();
                return true;
            }
            this._cur.pop();
        }
        return false;
    }

    public boolean _toLastChild() {
        return Locale.toLastChildElement(this._cur);
    }

    public boolean _toNextAttribute() {
        return this._cur.isAttr() && Locale.toNextNormalAttr(this._cur);
    }

    public XmlCursor.XmlBookmark _toNextBookmark(Object obj) {
        if (obj == null) {
            return null;
        }
        this._cur.push();
        do {
            int cchRight = this._cur.cchRight();
            if (cchRight > 1) {
                this._cur.nextChars(1);
                Cur cur = this._cur;
                int firstBookmarkInChars = cur.firstBookmarkInChars(obj, cchRight - 1);
                if (firstBookmarkInChars < 0) {
                    firstBookmarkInChars = -1;
                }
                cur.nextChars(firstBookmarkInChars);
            } else if (_toNextToken().isNone()) {
                this._cur.pop();
                return null;
            }
            XmlCursor.XmlBookmark bookmark = getBookmark(obj, this._cur);
            if (bookmark != null) {
                this._cur.popButStay();
                return bookmark;
            }
        } while (this._cur.kind() != -1);
        this._cur.pop();
        return null;
    }

    public int _toNextChar(int i2) {
        return this._cur.nextChars(i2);
    }

    public boolean _toNextSelection() {
        return _toSelection(this._currentSelection + 1);
    }

    public boolean _toNextSibling(String str) {
        return _toNextSibling(new QName(str));
    }

    public XmlCursor.TokenType _toNextToken() {
        if ($assertionsDisabled || isValid()) {
            int kind = this._cur.kind();
            if (kind == 1 || kind == 2) {
                if (!this._cur.toFirstAttr()) {
                    this._cur.next();
                }
            } else if (kind != 3) {
                if (kind == 4 || kind == 5) {
                    this._cur.skip();
                } else if (!this._cur.next()) {
                    return XmlCursor.TokenType.NONE;
                }
            } else if (!this._cur.toNextSibling()) {
                this._cur.toParent();
                this._cur.next();
            }
            return _currentTokenType();
        }
        throw new AssertionError();
    }

    public boolean _toParent() {
        Cur tempCur = this._cur.tempCur();
        if (!tempCur.toParent()) {
            return false;
        }
        this._cur.moveToCur(tempCur);
        tempCur.release();
        return true;
    }

    public boolean _toPrevAttribute() {
        return this._cur.isAttr() && Locale.toPrevNormalAttr(this._cur);
    }

    public XmlCursor.XmlBookmark _toPrevBookmark(Object obj) {
        if (obj == null) {
            return null;
        }
        this._cur.push();
        do {
            int cchLeft = this._cur.cchLeft();
            if (cchLeft > 1) {
                this._cur.prevChars(1);
                Cur cur = this._cur;
                int firstBookmarkInCharsLeft = cur.firstBookmarkInCharsLeft(obj, cchLeft - 1);
                if (firstBookmarkInCharsLeft < 0) {
                    firstBookmarkInCharsLeft = -1;
                }
                cur.prevChars(firstBookmarkInCharsLeft);
            } else if (cchLeft == 1) {
                this._cur.prevChars(1);
            } else if (_toPrevToken().isNone()) {
                this._cur.pop();
                return null;
            }
            XmlCursor.XmlBookmark bookmark = getBookmark(obj, this._cur);
            if (bookmark != null) {
                this._cur.popButStay();
                return bookmark;
            }
        } while (this._cur.kind() != 1);
        this._cur.pop();
        return null;
    }

    public int _toPrevChar(int i2) {
        return this._cur.prevChars(i2);
    }

    public boolean _toPrevSibling() {
        return Locale.toPrevSiblingElement(this._cur);
    }

    public XmlCursor.TokenType _toPrevToken() {
        if ($assertionsDisabled || isValid()) {
            boolean isText = this._cur.isText();
            if (this._cur.prev()) {
                int kind = this._cur.kind();
                if (kind < 0 && (kind == -4 || kind == -5 || kind == -3)) {
                    this._cur.toParent();
                } else if (this._cur.isContainer()) {
                    this._cur.toLastAttr();
                } else if (isText && this._cur.isText()) {
                    return _toPrevToken();
                }
            } else if (!$assertionsDisabled && !this._cur.isRoot() && !this._cur.isAttr()) {
                throw new AssertionError();
            } else if (this._cur.isRoot()) {
                return XmlCursor.TokenType.NONE;
            } else {
                this._cur.toParent();
            }
            return _currentTokenType();
        }
        throw new AssertionError();
    }

    public boolean _toSelection(int i2) {
        if (i2 < 0) {
            return false;
        }
        while (i2 >= this._cur.selectionCount()) {
            Path.PathEngine pathEngine = this._pathEngine;
            if (pathEngine == null) {
                return false;
            }
            if (!pathEngine.next(this._cur)) {
                this._pathEngine.release();
                this._pathEngine = null;
                return false;
            }
        }
        Cur cur = this._cur;
        this._currentSelection = i2;
        cur.moveToSelection(i2);
        return true;
    }

    public void _toStartDoc() {
        this._cur.toRoot();
    }

    public String _xmlText() {
        return _xmlText(null);
    }

    @Override // org.apache.xmlbeans.XmlCursor
    public void addToSelection() {
        if (preCheck()) {
            this._cur._locale.enter();
            try {
                _addToSelection();
            } finally {
                this._cur._locale.exit();
            }
        } else {
            synchronized (this._cur._locale) {
                this._cur._locale.enter();
                try {
                    _addToSelection();
                } finally {
                    this._cur._locale.exit();
                }
            }
        }
    }

    @Override // org.apache.xmlbeans.XmlCursor
    public void beginElement(QName qName) {
        if (preCheck()) {
            this._cur._locale.enter();
            try {
                _beginElement(qName);
            } finally {
                this._cur._locale.exit();
            }
        } else {
            synchronized (this._cur._locale) {
                this._cur._locale.enter();
                try {
                    _beginElement(qName);
                } finally {
                    this._cur._locale.exit();
                }
            }
        }
    }

    @Override // org.apache.xmlbeans.XmlCursor
    public void clearBookmark(Object obj) {
        if (preCheck()) {
            this._cur._locale.enter();
            try {
                _clearBookmark(obj);
            } finally {
                this._cur._locale.exit();
            }
        } else {
            synchronized (this._cur._locale) {
                this._cur._locale.enter();
                try {
                    _clearBookmark(obj);
                } finally {
                    this._cur._locale.exit();
                }
            }
        }
    }

    @Override // org.apache.xmlbeans.XmlCursor
    public void clearSelections() {
        if (preCheck()) {
            this._cur._locale.enter();
            try {
                _clearSelections();
            } finally {
                this._cur._locale.exit();
            }
        } else {
            synchronized (this._cur._locale) {
                this._cur._locale.enter();
                try {
                    _clearSelections();
                } finally {
                    this._cur._locale.exit();
                }
            }
        }
    }

    @Override // org.apache.xmlbeans.XmlCursor
    public int comparePosition(XmlCursor xmlCursor) {
        int _comparePosition;
        Cursor preCheck = preCheck(xmlCursor);
        if (this._cur._locale.noSync()) {
            this._cur._locale.enter();
            try {
                return _comparePosition(preCheck);
            } finally {
                this._cur._locale.exit();
            }
        } else {
            synchronized (this._cur._locale) {
                this._cur._locale.enter();
                try {
                    _comparePosition = _comparePosition(preCheck);
                } finally {
                    this._cur._locale.exit();
                }
            }
            return _comparePosition;
        }
    }

    @Override // org.apache.xmlbeans.XmlCursor
    public int copyChars(int i2, XmlCursor xmlCursor) {
        return twoLocaleOp(xmlCursor, 5, i2);
    }

    @Override // org.apache.xmlbeans.XmlCursor
    public boolean copyXml(XmlCursor xmlCursor) {
        return twoLocaleOp(xmlCursor, 1, 0) == 1;
    }

    @Override // org.apache.xmlbeans.XmlCursor
    public boolean copyXmlContents(XmlCursor xmlCursor) {
        return twoLocaleOp(xmlCursor, 3, 0) == 1;
    }

    @Override // org.apache.xmlbeans.XmlCursor
    public XmlCursor.TokenType currentTokenType() {
        XmlCursor.TokenType _currentTokenType;
        if (preCheck()) {
            return _currentTokenType();
        }
        synchronized (this._cur._locale) {
            _currentTokenType = _currentTokenType();
        }
        return _currentTokenType;
    }

    @Override // org.apache.xmlbeans.XmlCursor
    public void dispose() {
        Cur cur = this._cur;
        if (cur != null) {
            Locale locale = cur._locale;
            if (preCheck()) {
                locale.enter();
                try {
                    _dispose();
                } finally {
                    locale.exit();
                }
            } else {
                synchronized (locale) {
                    locale.enter();
                    try {
                        _dispose();
                    } finally {
                        locale.exit();
                    }
                }
            }
        }
    }

    @Override // org.apache.xmlbeans.XmlTokenSource
    public XmlDocumentProperties documentProperties() {
        XmlDocumentProperties _documentProperties;
        if (preCheck()) {
            this._cur._locale.enter();
            try {
                return _documentProperties();
            } finally {
                this._cur._locale.exit();
            }
        } else {
            synchronized (this._cur._locale) {
                this._cur._locale.enter();
                try {
                    _documentProperties = _documentProperties();
                } finally {
                    this._cur._locale.exit();
                }
            }
            return _documentProperties;
        }
    }

    public void dump(PrintStream printStream) {
        this._cur.dump(printStream);
    }

    @Override // org.apache.xmlbeans.XmlCursor
    public XmlCursor execQuery(String str) {
        XmlCursor _execQuery;
        if (preCheck()) {
            this._cur._locale.enter();
            try {
                return _execQuery(str);
            } finally {
                this._cur._locale.exit();
            }
        } else {
            synchronized (this._cur._locale) {
                this._cur._locale.enter();
                try {
                    _execQuery = _execQuery(str);
                } finally {
                    this._cur._locale.exit();
                }
            }
            return _execQuery;
        }
    }

    @Override // org.apache.xmlbeans.XmlCursor
    public void getAllBookmarkRefs(Collection collection) {
        if (preCheck()) {
            this._cur._locale.enter();
            try {
                _getAllBookmarkRefs(collection);
            } finally {
                this._cur._locale.exit();
            }
        } else {
            synchronized (this._cur._locale) {
                this._cur._locale.enter();
                try {
                    _getAllBookmarkRefs(collection);
                } finally {
                    this._cur._locale.exit();
                }
            }
        }
    }

    @Override // org.apache.xmlbeans.XmlCursor
    public void getAllNamespaces(Map map) {
        if (preCheck()) {
            this._cur._locale.enter();
            try {
                _getAllNamespaces(map);
            } finally {
                this._cur._locale.exit();
            }
        } else {
            synchronized (this._cur._locale) {
                this._cur._locale.enter();
                try {
                    _getAllNamespaces(map);
                } finally {
                    this._cur._locale.exit();
                }
            }
        }
    }

    @Override // org.apache.xmlbeans.XmlCursor
    public String getAttributeText(QName qName) {
        String _getAttributeText;
        if (preCheck()) {
            this._cur._locale.enter();
            try {
                return _getAttributeText(qName);
            } finally {
                this._cur._locale.exit();
            }
        } else {
            synchronized (this._cur._locale) {
                this._cur._locale.enter();
                try {
                    _getAttributeText = _getAttributeText(qName);
                } finally {
                    this._cur._locale.exit();
                }
            }
            return _getAttributeText;
        }
    }

    @Override // org.apache.xmlbeans.XmlCursor
    public String getChars() {
        String _getChars;
        if (preCheck()) {
            this._cur._locale.enter();
            try {
                return _getChars();
            } finally {
                this._cur._locale.exit();
            }
        } else {
            synchronized (this._cur._locale) {
                this._cur._locale.enter();
                try {
                    _getChars = _getChars();
                } finally {
                    this._cur._locale.exit();
                }
            }
            return _getChars;
        }
    }

    @Override // org.apache.xmlbeans.XmlCursor
    public XmlCursor.ChangeStamp getDocChangeStamp() {
        XmlCursor.ChangeStamp _getDocChangeStamp;
        if (preCheck()) {
            this._cur._locale.enter();
            try {
                return _getDocChangeStamp();
            } finally {
                this._cur._locale.exit();
            }
        } else {
            synchronized (this._cur._locale) {
                this._cur._locale.enter();
                try {
                    _getDocChangeStamp = _getDocChangeStamp();
                } finally {
                    this._cur._locale.exit();
                }
            }
            return _getDocChangeStamp;
        }
    }

    @Override // org.apache.xmlbeans.XmlTokenSource
    public Node getDomNode() {
        Node _getDomNode;
        if (preCheck()) {
            this._cur._locale.enter();
            try {
                return _getDomNode();
            } finally {
                this._cur._locale.exit();
            }
        } else {
            synchronized (this._cur._locale) {
                this._cur._locale.enter();
                try {
                    _getDomNode = _getDomNode();
                } finally {
                    this._cur._locale.exit();
                }
            }
            return _getDomNode;
        }
    }

    @Override // org.apache.xmlbeans.XmlCursor
    public QName getName() {
        QName _getName;
        if (preCheck()) {
            this._cur._locale.enter();
            try {
                return _getName();
            } finally {
                this._cur._locale.exit();
            }
        } else {
            synchronized (this._cur._locale) {
                this._cur._locale.enter();
                try {
                    _getName = _getName();
                } finally {
                    this._cur._locale.exit();
                }
            }
            return _getName;
        }
    }

    @Override // org.apache.xmlbeans.impl.store.Locale.ChangeListener
    public Locale.ChangeListener getNextChangeListener() {
        return this._nextChangeListener;
    }

    @Override // org.apache.xmlbeans.XmlCursor
    public XmlObject getObject() {
        XmlObject _getObject;
        if (preCheck()) {
            this._cur._locale.enter();
            try {
                return _getObject();
            } finally {
                this._cur._locale.exit();
            }
        } else {
            synchronized (this._cur._locale) {
                this._cur._locale.enter();
                try {
                    _getObject = _getObject();
                } finally {
                    this._cur._locale.exit();
                }
            }
            return _getObject;
        }
    }

    @Override // org.apache.xmlbeans.XmlCursor
    public int getSelectionCount() {
        int _getSelectionCount;
        if (preCheck()) {
            this._cur._locale.enter();
            try {
                return _getSelectionCount();
            } finally {
                this._cur._locale.exit();
            }
        } else {
            synchronized (this._cur._locale) {
                this._cur._locale.enter();
                try {
                    _getSelectionCount = _getSelectionCount();
                } finally {
                    this._cur._locale.exit();
                }
            }
            return _getSelectionCount;
        }
    }

    @Override // org.apache.xmlbeans.XmlCursor
    public String getTextValue() {
        String _getTextValue;
        if (preCheck()) {
            this._cur._locale.enter();
            try {
                return _getTextValue();
            } finally {
                this._cur._locale.exit();
            }
        } else {
            synchronized (this._cur._locale) {
                this._cur._locale.enter();
                try {
                    _getTextValue = _getTextValue();
                } finally {
                    this._cur._locale.exit();
                }
            }
            return _getTextValue;
        }
    }

    @Override // org.apache.xmlbeans.XmlCursor
    public boolean hasNextSelection() {
        boolean _hasNextSelection;
        if (preCheck()) {
            this._cur._locale.enter();
            try {
                return _hasNextSelection();
            } finally {
                this._cur._locale.exit();
            }
        } else {
            synchronized (this._cur._locale) {
                this._cur._locale.enter();
                try {
                    _hasNextSelection = _hasNextSelection();
                } finally {
                    this._cur._locale.exit();
                }
            }
            return _hasNextSelection;
        }
    }

    @Override // org.apache.xmlbeans.XmlCursor
    public boolean hasNextToken() {
        boolean _hasNextToken;
        if (preCheck()) {
            return _hasNextToken();
        }
        synchronized (this._cur._locale) {
            _hasNextToken = _hasNextToken();
        }
        return _hasNextToken;
    }

    @Override // org.apache.xmlbeans.XmlCursor
    public boolean hasPrevToken() {
        boolean _hasPrevToken;
        if (preCheck()) {
            this._cur._locale.enter();
            try {
                return _hasPrevToken();
            } finally {
                this._cur._locale.exit();
            }
        } else {
            synchronized (this._cur._locale) {
                this._cur._locale.enter();
                try {
                    _hasPrevToken = _hasPrevToken();
                } finally {
                    this._cur._locale.exit();
                }
            }
            return _hasPrevToken;
        }
    }

    @Override // org.apache.xmlbeans.XmlCursor
    public void insertAttribute(String str) {
        if (preCheck()) {
            this._cur._locale.enter();
            try {
                _insertAttribute(str);
            } finally {
                this._cur._locale.exit();
            }
        } else {
            synchronized (this._cur._locale) {
                this._cur._locale.enter();
                try {
                    _insertAttribute(str);
                } finally {
                    this._cur._locale.exit();
                }
            }
        }
    }

    @Override // org.apache.xmlbeans.XmlCursor
    public void insertAttributeWithValue(String str, String str2) {
        if (preCheck()) {
            this._cur._locale.enter();
            try {
                _insertAttributeWithValue(str, str2);
            } finally {
                this._cur._locale.exit();
            }
        } else {
            synchronized (this._cur._locale) {
                this._cur._locale.enter();
                try {
                    _insertAttributeWithValue(str, str2);
                } finally {
                    this._cur._locale.exit();
                }
            }
        }
    }

    @Override // org.apache.xmlbeans.XmlCursor
    public void insertChars(String str) {
        if (preCheck()) {
            this._cur._locale.enter();
            try {
                _insertChars(str);
            } finally {
                this._cur._locale.exit();
            }
        } else {
            synchronized (this._cur._locale) {
                this._cur._locale.enter();
                try {
                    _insertChars(str);
                } finally {
                    this._cur._locale.exit();
                }
            }
        }
    }

    @Override // org.apache.xmlbeans.XmlCursor
    public void insertComment(String str) {
        if (preCheck()) {
            this._cur._locale.enter();
            try {
                _insertComment(str);
            } finally {
                this._cur._locale.exit();
            }
        } else {
            synchronized (this._cur._locale) {
                this._cur._locale.enter();
                try {
                    _insertComment(str);
                } finally {
                    this._cur._locale.exit();
                }
            }
        }
    }

    @Override // org.apache.xmlbeans.XmlCursor
    public void insertElement(QName qName) {
        if (preCheck()) {
            this._cur._locale.enter();
            try {
                _insertElement(qName);
            } finally {
                this._cur._locale.exit();
            }
        } else {
            synchronized (this._cur._locale) {
                this._cur._locale.enter();
                try {
                    _insertElement(qName);
                } finally {
                    this._cur._locale.exit();
                }
            }
        }
    }

    @Override // org.apache.xmlbeans.XmlCursor
    public void insertElementWithText(QName qName, String str) {
        if (preCheck()) {
            this._cur._locale.enter();
            try {
                _insertElementWithText(qName, str);
            } finally {
                this._cur._locale.exit();
            }
        } else {
            synchronized (this._cur._locale) {
                this._cur._locale.enter();
                try {
                    _insertElementWithText(qName, str);
                } finally {
                    this._cur._locale.exit();
                }
            }
        }
    }

    @Override // org.apache.xmlbeans.XmlCursor
    public void insertNamespace(String str, String str2) {
        if (preCheck()) {
            this._cur._locale.enter();
            try {
                _insertNamespace(str, str2);
            } finally {
                this._cur._locale.exit();
            }
        } else {
            synchronized (this._cur._locale) {
                this._cur._locale.enter();
                try {
                    _insertNamespace(str, str2);
                } finally {
                    this._cur._locale.exit();
                }
            }
        }
    }

    @Override // org.apache.xmlbeans.XmlCursor
    public void insertProcInst(String str, String str2) {
        if (preCheck()) {
            this._cur._locale.enter();
            try {
                _insertProcInst(str, str2);
            } finally {
                this._cur._locale.exit();
            }
        } else {
            synchronized (this._cur._locale) {
                this._cur._locale.enter();
                try {
                    _insertProcInst(str, str2);
                } finally {
                    this._cur._locale.exit();
                }
            }
        }
    }

    @Override // org.apache.xmlbeans.XmlCursor
    public boolean isAnyAttr() {
        boolean _isAnyAttr;
        if (preCheck()) {
            return _isAnyAttr();
        }
        synchronized (this._cur._locale) {
            _isAnyAttr = _isAnyAttr();
        }
        return _isAnyAttr;
    }

    @Override // org.apache.xmlbeans.XmlCursor
    public boolean isAtSamePositionAs(XmlCursor xmlCursor) {
        boolean _isAtSamePositionAs;
        Cursor preCheck = preCheck(xmlCursor);
        if (this._cur._locale.noSync()) {
            this._cur._locale.enter();
            try {
                return _isAtSamePositionAs(preCheck);
            } finally {
                this._cur._locale.exit();
            }
        } else {
            synchronized (this._cur._locale) {
                this._cur._locale.enter();
                try {
                    _isAtSamePositionAs = _isAtSamePositionAs(preCheck);
                } finally {
                    this._cur._locale.exit();
                }
            }
            return _isAtSamePositionAs;
        }
    }

    @Override // org.apache.xmlbeans.XmlCursor
    public boolean isAttr() {
        boolean _isAttr;
        if (preCheck()) {
            return _isAttr();
        }
        synchronized (this._cur._locale) {
            _isAttr = _isAttr();
        }
        return _isAttr;
    }

    @Override // org.apache.xmlbeans.XmlCursor
    public boolean isComment() {
        boolean _isComment;
        if (preCheck()) {
            return _isComment();
        }
        synchronized (this._cur._locale) {
            _isComment = _isComment();
        }
        return _isComment;
    }

    @Override // org.apache.xmlbeans.XmlCursor
    public boolean isContainer() {
        boolean _isContainer;
        if (preCheck()) {
            return _isContainer();
        }
        synchronized (this._cur._locale) {
            _isContainer = _isContainer();
        }
        return _isContainer;
    }

    @Override // org.apache.xmlbeans.XmlCursor
    public boolean isEnd() {
        boolean _isEnd;
        if (preCheck()) {
            return _isEnd();
        }
        synchronized (this._cur._locale) {
            _isEnd = _isEnd();
        }
        return _isEnd;
    }

    @Override // org.apache.xmlbeans.XmlCursor
    public boolean isEnddoc() {
        boolean _isEnddoc;
        if (preCheck()) {
            return _isEnddoc();
        }
        synchronized (this._cur._locale) {
            _isEnddoc = _isEnddoc();
        }
        return _isEnddoc;
    }

    @Override // org.apache.xmlbeans.XmlCursor
    public boolean isFinish() {
        boolean _isFinish;
        if (preCheck()) {
            return _isFinish();
        }
        synchronized (this._cur._locale) {
            _isFinish = _isFinish();
        }
        return _isFinish;
    }

    @Override // org.apache.xmlbeans.XmlCursor
    public boolean isInSameDocument(XmlCursor xmlCursor) {
        if (xmlCursor == null) {
            return false;
        }
        return this._cur.isInSameTree(checkCursors(xmlCursor)._cur);
    }

    @Override // org.apache.xmlbeans.XmlCursor
    public boolean isLeftOf(XmlCursor xmlCursor) {
        boolean _isLeftOf;
        Cursor preCheck = preCheck(xmlCursor);
        if (this._cur._locale.noSync()) {
            this._cur._locale.enter();
            try {
                return _isLeftOf(preCheck);
            } finally {
                this._cur._locale.exit();
            }
        } else {
            synchronized (this._cur._locale) {
                this._cur._locale.enter();
                try {
                    _isLeftOf = _isLeftOf(preCheck);
                } finally {
                    this._cur._locale.exit();
                }
            }
            return _isLeftOf;
        }
    }

    @Override // org.apache.xmlbeans.XmlCursor
    public boolean isNamespace() {
        boolean _isNamespace;
        if (preCheck()) {
            return _isNamespace();
        }
        synchronized (this._cur._locale) {
            _isNamespace = _isNamespace();
        }
        return _isNamespace;
    }

    @Override // org.apache.xmlbeans.XmlCursor
    public boolean isProcinst() {
        boolean _isProcinst;
        if (preCheck()) {
            return _isProcinst();
        }
        synchronized (this._cur._locale) {
            _isProcinst = _isProcinst();
        }
        return _isProcinst;
    }

    @Override // org.apache.xmlbeans.XmlCursor
    public boolean isRightOf(XmlCursor xmlCursor) {
        boolean _isRightOf;
        Cursor preCheck = preCheck(xmlCursor);
        if (this._cur._locale.noSync()) {
            this._cur._locale.enter();
            try {
                return _isRightOf(preCheck);
            } finally {
                this._cur._locale.exit();
            }
        } else {
            synchronized (this._cur._locale) {
                this._cur._locale.enter();
                try {
                    _isRightOf = _isRightOf(preCheck);
                } finally {
                    this._cur._locale.exit();
                }
            }
            return _isRightOf;
        }
    }

    @Override // org.apache.xmlbeans.XmlCursor
    public boolean isStart() {
        boolean _isStart;
        if (preCheck()) {
            return _isStart();
        }
        synchronized (this._cur._locale) {
            _isStart = _isStart();
        }
        return _isStart;
    }

    @Override // org.apache.xmlbeans.XmlCursor
    public boolean isStartdoc() {
        boolean _isStartdoc;
        if (preCheck()) {
            return _isStartdoc();
        }
        synchronized (this._cur._locale) {
            _isStartdoc = _isStartdoc();
        }
        return _isStartdoc;
    }

    @Override // org.apache.xmlbeans.XmlCursor
    public boolean isText() {
        boolean _isText;
        if (preCheck()) {
            return _isText();
        }
        synchronized (this._cur._locale) {
            _isText = _isText();
        }
        return _isText;
    }

    public Locale locale() {
        return this._cur._locale;
    }

    @Override // org.apache.xmlbeans.XmlTokenSource
    public Object monitor() {
        Object _monitor;
        if (preCheck()) {
            this._cur._locale.enter();
            try {
                return _monitor();
            } finally {
                this._cur._locale.exit();
            }
        } else {
            synchronized (this._cur._locale) {
                this._cur._locale.enter();
                try {
                    _monitor = _monitor();
                } finally {
                    this._cur._locale.exit();
                }
            }
            return _monitor;
        }
    }

    @Override // org.apache.xmlbeans.XmlCursor
    public int moveChars(int i2, XmlCursor xmlCursor) {
        return twoLocaleOp(xmlCursor, 4, i2);
    }

    @Override // org.apache.xmlbeans.XmlCursor
    public boolean moveXml(XmlCursor xmlCursor) {
        return twoLocaleOp(xmlCursor, 0, 0) == 1;
    }

    @Override // org.apache.xmlbeans.XmlCursor
    public boolean moveXmlContents(XmlCursor xmlCursor) {
        return twoLocaleOp(xmlCursor, 2, 0) == 1;
    }

    @Override // org.apache.xmlbeans.XmlCursor
    public String namespaceForPrefix(String str) {
        String _namespaceForPrefix;
        if (preCheck()) {
            this._cur._locale.enter();
            try {
                return _namespaceForPrefix(str);
            } finally {
                this._cur._locale.exit();
            }
        } else {
            synchronized (this._cur._locale) {
                this._cur._locale.enter();
                try {
                    _namespaceForPrefix = _namespaceForPrefix(str);
                } finally {
                    this._cur._locale.exit();
                }
            }
            return _namespaceForPrefix;
        }
    }

    @Override // org.apache.xmlbeans.XmlTokenSource
    public Node newDomNode() {
        Node _newDomNode;
        if (preCheck()) {
            this._cur._locale.enter();
            try {
                return _newDomNode();
            } finally {
                this._cur._locale.exit();
            }
        } else {
            synchronized (this._cur._locale) {
                this._cur._locale.enter();
                try {
                    _newDomNode = _newDomNode();
                } finally {
                    this._cur._locale.exit();
                }
            }
            return _newDomNode;
        }
    }

    @Override // org.apache.xmlbeans.XmlTokenSource
    public InputStream newInputStream() {
        InputStream _newInputStream;
        if (preCheck()) {
            this._cur._locale.enter();
            try {
                return _newInputStream();
            } finally {
                this._cur._locale.exit();
            }
        } else {
            synchronized (this._cur._locale) {
                this._cur._locale.enter();
                try {
                    _newInputStream = _newInputStream();
                } finally {
                    this._cur._locale.exit();
                }
            }
            return _newInputStream;
        }
    }

    @Override // org.apache.xmlbeans.XmlTokenSource
    public Reader newReader() {
        Reader _newReader;
        if (preCheck()) {
            this._cur._locale.enter();
            try {
                return _newReader();
            } finally {
                this._cur._locale.exit();
            }
        } else {
            synchronized (this._cur._locale) {
                this._cur._locale.enter();
                try {
                    _newReader = _newReader();
                } finally {
                    this._cur._locale.exit();
                }
            }
            return _newReader;
        }
    }

    @Override // org.apache.xmlbeans.XmlTokenSource
    public XMLInputStream newXMLInputStream() {
        XMLInputStream _newXMLInputStream;
        if (preCheck()) {
            this._cur._locale.enter();
            try {
                return _newXMLInputStream();
            } finally {
                this._cur._locale.exit();
            }
        } else {
            synchronized (this._cur._locale) {
                this._cur._locale.enter();
                try {
                    _newXMLInputStream = _newXMLInputStream();
                } finally {
                    this._cur._locale.exit();
                }
            }
            return _newXMLInputStream;
        }
    }

    @Override // org.apache.xmlbeans.XmlTokenSource
    public XMLStreamReader newXMLStreamReader() {
        XMLStreamReader _newXMLStreamReader;
        if (preCheck()) {
            this._cur._locale.enter();
            try {
                return _newXMLStreamReader();
            } finally {
                this._cur._locale.exit();
            }
        } else {
            synchronized (this._cur._locale) {
                this._cur._locale.enter();
                try {
                    _newXMLStreamReader = _newXMLStreamReader();
                } finally {
                    this._cur._locale.exit();
                }
            }
            return _newXMLStreamReader;
        }
    }

    @Override // org.apache.xmlbeans.impl.store.Locale.ChangeListener
    public void notifyChange() {
        if (this._cur != null) {
            _getSelectionCount();
        }
    }

    @Override // org.apache.xmlbeans.XmlCursor
    public boolean pop() {
        boolean _pop;
        if (preCheck()) {
            this._cur._locale.enter();
            try {
                return _pop();
            } finally {
                this._cur._locale.exit();
            }
        } else {
            synchronized (this._cur._locale) {
                this._cur._locale.enter();
                try {
                    _pop = _pop();
                } finally {
                    this._cur._locale.exit();
                }
            }
            return _pop;
        }
    }

    @Override // org.apache.xmlbeans.XmlCursor
    public String prefixForNamespace(String str) {
        String _prefixForNamespace;
        if (preCheck()) {
            this._cur._locale.enter();
            try {
                return _prefixForNamespace(str);
            } finally {
                this._cur._locale.exit();
            }
        } else {
            synchronized (this._cur._locale) {
                this._cur._locale.enter();
                try {
                    _prefixForNamespace = _prefixForNamespace(str);
                } finally {
                    this._cur._locale.exit();
                }
            }
            return _prefixForNamespace;
        }
    }

    @Override // org.apache.xmlbeans.XmlCursor
    public XmlCursor.TokenType prevTokenType() {
        XmlCursor.TokenType _prevTokenType;
        if (preCheck()) {
            this._cur._locale.enter();
            try {
                return _prevTokenType();
            } finally {
                this._cur._locale.exit();
            }
        } else {
            synchronized (this._cur._locale) {
                this._cur._locale.enter();
                try {
                    _prevTokenType = _prevTokenType();
                } finally {
                    this._cur._locale.exit();
                }
            }
            return _prevTokenType;
        }
    }

    @Override // org.apache.xmlbeans.XmlCursor
    public void push() {
        if (preCheck()) {
            this._cur._locale.enter();
            try {
                _push();
            } finally {
                this._cur._locale.exit();
            }
        } else {
            synchronized (this._cur._locale) {
                this._cur._locale.enter();
                try {
                    _push();
                } finally {
                    this._cur._locale.exit();
                }
            }
        }
    }

    @Override // org.apache.xmlbeans.XmlCursor
    public boolean removeAttribute(QName qName) {
        boolean _removeAttribute;
        if (preCheck()) {
            this._cur._locale.enter();
            try {
                return _removeAttribute(qName);
            } finally {
                this._cur._locale.exit();
            }
        } else {
            synchronized (this._cur._locale) {
                this._cur._locale.enter();
                try {
                    _removeAttribute = _removeAttribute(qName);
                } finally {
                    this._cur._locale.exit();
                }
            }
            return _removeAttribute;
        }
    }

    @Override // org.apache.xmlbeans.XmlCursor
    public int removeChars(int i2) {
        int _removeChars;
        if (preCheck()) {
            this._cur._locale.enter();
            try {
                return _removeChars(i2);
            } finally {
                this._cur._locale.exit();
            }
        } else {
            synchronized (this._cur._locale) {
                this._cur._locale.enter();
                try {
                    _removeChars = _removeChars(i2);
                } finally {
                    this._cur._locale.exit();
                }
            }
            return _removeChars;
        }
    }

    @Override // org.apache.xmlbeans.XmlCursor
    public boolean removeXml() {
        boolean _removeXml;
        if (preCheck()) {
            this._cur._locale.enter();
            try {
                return _removeXml();
            } finally {
                this._cur._locale.exit();
            }
        } else {
            synchronized (this._cur._locale) {
                this._cur._locale.enter();
                try {
                    _removeXml = _removeXml();
                } finally {
                    this._cur._locale.exit();
                }
            }
            return _removeXml;
        }
    }

    @Override // org.apache.xmlbeans.XmlCursor
    public boolean removeXmlContents() {
        boolean _removeXmlContents;
        if (preCheck()) {
            this._cur._locale.enter();
            try {
                return _removeXmlContents();
            } finally {
                this._cur._locale.exit();
            }
        } else {
            synchronized (this._cur._locale) {
                this._cur._locale.enter();
                try {
                    _removeXmlContents = _removeXmlContents();
                } finally {
                    this._cur._locale.exit();
                }
            }
            return _removeXmlContents;
        }
    }

    @Override // org.apache.xmlbeans.XmlTokenSource
    public void save(ContentHandler contentHandler, LexicalHandler lexicalHandler) {
        if (preCheck()) {
            this._cur._locale.enter();
            try {
                _save(contentHandler, lexicalHandler);
            } finally {
                this._cur._locale.exit();
            }
        } else {
            synchronized (this._cur._locale) {
                this._cur._locale.enter();
                try {
                    _save(contentHandler, lexicalHandler);
                } finally {
                    this._cur._locale.exit();
                }
            }
        }
    }

    @Override // org.apache.xmlbeans.XmlCursor
    public void selectPath(String str) {
        if (preCheck()) {
            this._cur._locale.enter();
            try {
                _selectPath(str);
            } finally {
                this._cur._locale.exit();
            }
        } else {
            synchronized (this._cur._locale) {
                this._cur._locale.enter();
                try {
                    _selectPath(str);
                } finally {
                    this._cur._locale.exit();
                }
            }
        }
    }

    @Override // org.apache.xmlbeans.XmlCursor
    public boolean setAttributeText(QName qName, String str) {
        boolean _setAttributeText;
        if (preCheck()) {
            this._cur._locale.enter();
            try {
                return _setAttributeText(qName, str);
            } finally {
                this._cur._locale.exit();
            }
        } else {
            synchronized (this._cur._locale) {
                this._cur._locale.enter();
                try {
                    _setAttributeText = _setAttributeText(qName, str);
                } finally {
                    this._cur._locale.exit();
                }
            }
            return _setAttributeText;
        }
    }

    @Override // org.apache.xmlbeans.XmlCursor
    public void setBookmark(XmlCursor.XmlBookmark xmlBookmark) {
        if (preCheck()) {
            this._cur._locale.enter();
            try {
                _setBookmark(xmlBookmark);
            } finally {
                this._cur._locale.exit();
            }
        } else {
            synchronized (this._cur._locale) {
                this._cur._locale.enter();
                try {
                    _setBookmark(xmlBookmark);
                } finally {
                    this._cur._locale.exit();
                }
            }
        }
    }

    @Override // org.apache.xmlbeans.XmlCursor
    public void setName(QName qName) {
        if (preCheck()) {
            this._cur._locale.enter();
            try {
                _setName(qName);
            } finally {
                this._cur._locale.exit();
            }
        } else {
            synchronized (this._cur._locale) {
                this._cur._locale.enter();
                try {
                    _setName(qName);
                } finally {
                    this._cur._locale.exit();
                }
            }
        }
    }

    @Override // org.apache.xmlbeans.impl.store.Locale.ChangeListener
    public void setNextChangeListener(Locale.ChangeListener changeListener) {
        this._nextChangeListener = changeListener;
    }

    public Cur tempCur() {
        return this._cur.tempCur();
    }

    @Override // org.apache.xmlbeans.XmlCursor
    public boolean toBookmark(XmlCursor.XmlBookmark xmlBookmark) {
        boolean _toBookmark;
        if (preCheck()) {
            this._cur._locale.enter();
            try {
                return _toBookmark(xmlBookmark);
            } finally {
                this._cur._locale.exit();
            }
        } else {
            synchronized (this._cur._locale) {
                this._cur._locale.enter();
                try {
                    _toBookmark = _toBookmark(xmlBookmark);
                } finally {
                    this._cur._locale.exit();
                }
            }
            return _toBookmark;
        }
    }

    @Override // org.apache.xmlbeans.XmlCursor
    public boolean toChild(String str) {
        boolean _toChild;
        if (preCheck()) {
            this._cur._locale.enter();
            try {
                return _toChild(str);
            } finally {
                this._cur._locale.exit();
            }
        } else {
            synchronized (this._cur._locale) {
                this._cur._locale.enter();
                try {
                    _toChild = _toChild(str);
                } finally {
                    this._cur._locale.exit();
                }
            }
            return _toChild;
        }
    }

    @Override // org.apache.xmlbeans.XmlCursor
    public boolean toCursor(XmlCursor xmlCursor) {
        boolean _toCursor;
        Cursor checkCursors = checkCursors(xmlCursor);
        Locale locale = this._cur._locale;
        if (locale != checkCursors._cur._locale) {
            return false;
        }
        if (locale.noSync()) {
            this._cur._locale.enter();
            try {
                return _toCursor(checkCursors);
            } finally {
                this._cur._locale.exit();
            }
        } else {
            synchronized (this._cur._locale) {
                this._cur._locale.enter();
                try {
                    _toCursor = _toCursor(checkCursors);
                } finally {
                    this._cur._locale.exit();
                }
            }
            return _toCursor;
        }
    }

    @Override // org.apache.xmlbeans.XmlCursor
    public void toEndDoc() {
        if (preCheck()) {
            _toEndDoc();
            return;
        }
        synchronized (this._cur._locale) {
            _toEndDoc();
        }
    }

    @Override // org.apache.xmlbeans.XmlCursor
    public XmlCursor.TokenType toEndToken() {
        XmlCursor.TokenType _toEndToken;
        if (preCheck()) {
            this._cur._locale.enter();
            try {
                return _toEndToken();
            } finally {
                this._cur._locale.exit();
            }
        } else {
            synchronized (this._cur._locale) {
                this._cur._locale.enter();
                try {
                    _toEndToken = _toEndToken();
                } finally {
                    this._cur._locale.exit();
                }
            }
            return _toEndToken;
        }
    }

    @Override // org.apache.xmlbeans.XmlCursor
    public boolean toFirstAttribute() {
        boolean _toFirstAttribute;
        if (preCheck()) {
            return _toFirstAttribute();
        }
        synchronized (this._cur._locale) {
            _toFirstAttribute = _toFirstAttribute();
        }
        return _toFirstAttribute;
    }

    @Override // org.apache.xmlbeans.XmlCursor
    public boolean toFirstChild() {
        boolean _toFirstChild;
        if (preCheck()) {
            return _toFirstChild();
        }
        synchronized (this._cur._locale) {
            _toFirstChild = _toFirstChild();
        }
        return _toFirstChild;
    }

    @Override // org.apache.xmlbeans.XmlCursor
    public XmlCursor.TokenType toFirstContentToken() {
        XmlCursor.TokenType _toFirstContentToken;
        if (preCheck()) {
            this._cur._locale.enter();
            try {
                return _toFirstContentToken();
            } finally {
                this._cur._locale.exit();
            }
        } else {
            synchronized (this._cur._locale) {
                this._cur._locale.enter();
                try {
                    _toFirstContentToken = _toFirstContentToken();
                } finally {
                    this._cur._locale.exit();
                }
            }
            return _toFirstContentToken;
        }
    }

    @Override // org.apache.xmlbeans.XmlCursor
    public boolean toLastAttribute() {
        boolean _toLastAttribute;
        if (preCheck()) {
            this._cur._locale.enter();
            try {
                return _toLastAttribute();
            } finally {
                this._cur._locale.exit();
            }
        } else {
            synchronized (this._cur._locale) {
                this._cur._locale.enter();
                try {
                    _toLastAttribute = _toLastAttribute();
                } finally {
                    this._cur._locale.exit();
                }
            }
            return _toLastAttribute;
        }
    }

    @Override // org.apache.xmlbeans.XmlCursor
    public boolean toLastChild() {
        boolean _toLastChild;
        if (preCheck()) {
            this._cur._locale.enter();
            try {
                return _toLastChild();
            } finally {
                this._cur._locale.exit();
            }
        } else {
            synchronized (this._cur._locale) {
                this._cur._locale.enter();
                try {
                    _toLastChild = _toLastChild();
                } finally {
                    this._cur._locale.exit();
                }
            }
            return _toLastChild;
        }
    }

    @Override // org.apache.xmlbeans.XmlCursor
    public boolean toNextAttribute() {
        boolean _toNextAttribute;
        if (preCheck()) {
            this._cur._locale.enter();
            try {
                return _toNextAttribute();
            } finally {
                this._cur._locale.exit();
            }
        } else {
            synchronized (this._cur._locale) {
                this._cur._locale.enter();
                try {
                    _toNextAttribute = _toNextAttribute();
                } finally {
                    this._cur._locale.exit();
                }
            }
            return _toNextAttribute;
        }
    }

    @Override // org.apache.xmlbeans.XmlCursor
    public XmlCursor.XmlBookmark toNextBookmark(Object obj) {
        XmlCursor.XmlBookmark _toNextBookmark;
        if (preCheck()) {
            this._cur._locale.enter();
            try {
                return _toNextBookmark(obj);
            } finally {
                this._cur._locale.exit();
            }
        } else {
            synchronized (this._cur._locale) {
                this._cur._locale.enter();
                try {
                    _toNextBookmark = _toNextBookmark(obj);
                } finally {
                    this._cur._locale.exit();
                }
            }
            return _toNextBookmark;
        }
    }

    @Override // org.apache.xmlbeans.XmlCursor
    public int toNextChar(int i2) {
        int _toNextChar;
        if (preCheck()) {
            this._cur._locale.enter();
            try {
                return _toNextChar(i2);
            } finally {
                this._cur._locale.exit();
            }
        } else {
            synchronized (this._cur._locale) {
                this._cur._locale.enter();
                try {
                    _toNextChar = _toNextChar(i2);
                } finally {
                    this._cur._locale.exit();
                }
            }
            return _toNextChar;
        }
    }

    @Override // org.apache.xmlbeans.XmlCursor
    public boolean toNextSelection() {
        boolean _toNextSelection;
        if (preCheck()) {
            this._cur._locale.enter();
            try {
                return _toNextSelection();
            } finally {
                this._cur._locale.exit();
            }
        } else {
            synchronized (this._cur._locale) {
                this._cur._locale.enter();
                try {
                    _toNextSelection = _toNextSelection();
                } finally {
                    this._cur._locale.exit();
                }
            }
            return _toNextSelection;
        }
    }

    @Override // org.apache.xmlbeans.XmlCursor
    public boolean toNextSibling() {
        boolean ___toNextSibling;
        if (preCheck()) {
            return ___toNextSibling();
        }
        synchronized (this._cur._locale) {
            ___toNextSibling = ___toNextSibling();
        }
        return ___toNextSibling;
    }

    @Override // org.apache.xmlbeans.XmlCursor
    public XmlCursor.TokenType toNextToken() {
        XmlCursor.TokenType _toNextToken;
        if (preCheck()) {
            this._cur._locale.enter();
            try {
                return _toNextToken();
            } finally {
                this._cur._locale.exit();
            }
        } else {
            synchronized (this._cur._locale) {
                this._cur._locale.enter();
                try {
                    _toNextToken = _toNextToken();
                } finally {
                    this._cur._locale.exit();
                }
            }
            return _toNextToken;
        }
    }

    @Override // org.apache.xmlbeans.XmlCursor
    public boolean toParent() {
        boolean _toParent;
        if (preCheck()) {
            this._cur._locale.enter();
            try {
                return _toParent();
            } finally {
                this._cur._locale.exit();
            }
        } else {
            synchronized (this._cur._locale) {
                this._cur._locale.enter();
                try {
                    _toParent = _toParent();
                } finally {
                    this._cur._locale.exit();
                }
            }
            return _toParent;
        }
    }

    @Override // org.apache.xmlbeans.XmlCursor
    public boolean toPrevAttribute() {
        boolean _toPrevAttribute;
        if (preCheck()) {
            this._cur._locale.enter();
            try {
                return _toPrevAttribute();
            } finally {
                this._cur._locale.exit();
            }
        } else {
            synchronized (this._cur._locale) {
                this._cur._locale.enter();
                try {
                    _toPrevAttribute = _toPrevAttribute();
                } finally {
                    this._cur._locale.exit();
                }
            }
            return _toPrevAttribute;
        }
    }

    @Override // org.apache.xmlbeans.XmlCursor
    public XmlCursor.XmlBookmark toPrevBookmark(Object obj) {
        XmlCursor.XmlBookmark _toPrevBookmark;
        if (preCheck()) {
            this._cur._locale.enter();
            try {
                return _toPrevBookmark(obj);
            } finally {
                this._cur._locale.exit();
            }
        } else {
            synchronized (this._cur._locale) {
                this._cur._locale.enter();
                try {
                    _toPrevBookmark = _toPrevBookmark(obj);
                } finally {
                    this._cur._locale.exit();
                }
            }
            return _toPrevBookmark;
        }
    }

    @Override // org.apache.xmlbeans.XmlCursor
    public int toPrevChar(int i2) {
        int _toPrevChar;
        if (preCheck()) {
            this._cur._locale.enter();
            try {
                return _toPrevChar(i2);
            } finally {
                this._cur._locale.exit();
            }
        } else {
            synchronized (this._cur._locale) {
                this._cur._locale.enter();
                try {
                    _toPrevChar = _toPrevChar(i2);
                } finally {
                    this._cur._locale.exit();
                }
            }
            return _toPrevChar;
        }
    }

    @Override // org.apache.xmlbeans.XmlCursor
    public boolean toPrevSibling() {
        boolean _toPrevSibling;
        if (preCheck()) {
            this._cur._locale.enter();
            try {
                return _toPrevSibling();
            } finally {
                this._cur._locale.exit();
            }
        } else {
            synchronized (this._cur._locale) {
                this._cur._locale.enter();
                try {
                    _toPrevSibling = _toPrevSibling();
                } finally {
                    this._cur._locale.exit();
                }
            }
            return _toPrevSibling;
        }
    }

    @Override // org.apache.xmlbeans.XmlCursor
    public XmlCursor.TokenType toPrevToken() {
        XmlCursor.TokenType _toPrevToken;
        if (preCheck()) {
            this._cur._locale.enter();
            try {
                return _toPrevToken();
            } finally {
                this._cur._locale.exit();
            }
        } else {
            synchronized (this._cur._locale) {
                this._cur._locale.enter();
                try {
                    _toPrevToken = _toPrevToken();
                } finally {
                    this._cur._locale.exit();
                }
            }
            return _toPrevToken;
        }
    }

    @Override // org.apache.xmlbeans.XmlCursor
    public boolean toSelection(int i2) {
        boolean _toSelection;
        if (preCheck()) {
            this._cur._locale.enter();
            try {
                return _toSelection(i2);
            } finally {
                this._cur._locale.exit();
            }
        } else {
            synchronized (this._cur._locale) {
                this._cur._locale.enter();
                try {
                    _toSelection = _toSelection(i2);
                } finally {
                    this._cur._locale.exit();
                }
            }
            return _toSelection;
        }
    }

    @Override // org.apache.xmlbeans.XmlCursor
    public void toStartDoc() {
        if (preCheck()) {
            _toStartDoc();
            return;
        }
        synchronized (this._cur._locale) {
            _toStartDoc();
        }
    }

    @Override // org.apache.xmlbeans.XmlTokenSource
    public String xmlText() {
        String _xmlText;
        if (preCheck()) {
            this._cur._locale.enter();
            try {
                return _xmlText();
            } finally {
                this._cur._locale.exit();
            }
        } else {
            synchronized (this._cur._locale) {
                this._cur._locale.enter();
                try {
                    _xmlText = _xmlText();
                } finally {
                    this._cur._locale.exit();
                }
            }
            return _xmlText;
        }
    }

    public XmlCursor _execQuery(String str, XmlOptions xmlOptions) {
        checkThisCursor();
        return Query.cursorExecQuery(this._cur, str, xmlOptions);
    }

    public int _getChars(char[] cArr, int i2, int i3) {
        int cchRight = this._cur.cchRight();
        if (i3 < 0 || i3 > cchRight) {
            i3 = cchRight;
        }
        if (cArr == null || i2 >= cArr.length) {
            return 0;
        }
        if (cArr.length - i2 < i3) {
            i3 = cArr.length - i2;
        }
        Object chars = this._cur.getChars(i3);
        Cur cur = this._cur;
        CharUtil.getChars(cArr, i2, chars, cur._offSrc, cur._cchSrc);
        return this._cur._cchSrc;
    }

    public void _insertAttribute(String str, String str2) {
        _insertAttributeWithValue(str, str2, null);
    }

    public void _insertAttributeWithValue(String str, String str2, String str3) {
        validateLocalName(str);
        _insertAttributeWithValue(this._cur._locale.makeQName(str2, str), str3);
    }

    public void _insertElement(String str, String str2) {
        _insertElementWithText(str, str2, null);
    }

    public void _insertElementWithText(String str, String str2, String str3) {
        validateLocalName(str);
        _insertElementWithText(this._cur._locale.makeQName(str2, str), str3);
    }

    public Node _newDomNode(XmlOptions xmlOptions) {
        if (XmlOptions.hasOption(xmlOptions, XmlOptions.SAVE_INNER)) {
            XmlOptions xmlOptions2 = new XmlOptions(xmlOptions);
            xmlOptions2.remove(XmlOptions.SAVE_INNER);
            xmlOptions = xmlOptions2;
        }
        return new DomSaver(this._cur, isDomFragment(), xmlOptions).saveDom();
    }

    public InputStream _newInputStream(XmlOptions xmlOptions) {
        return new Saver.InputStreamSaver(this._cur, xmlOptions);
    }

    public Reader _newReader(XmlOptions xmlOptions) {
        return new Saver.TextReader(this._cur, xmlOptions);
    }

    public XMLInputStream _newXMLInputStream(XmlOptions xmlOptions) {
        return new Saver.XmlInputStreamImpl(this._cur, xmlOptions);
    }

    public XMLStreamReader _newXMLStreamReader(XmlOptions xmlOptions) {
        return Jsr173.newXmlStreamReader(this._cur, xmlOptions);
    }

    public void _save(OutputStream outputStream) {
        _save(outputStream, (XmlOptions) null);
    }

    public void _selectPath(String str, XmlOptions xmlOptions) {
        _clearSelections();
        if ($assertionsDisabled || this._pathEngine == null) {
            this._pathEngine = Path.getCompiledPath(str, xmlOptions).execute(this._cur, xmlOptions);
            this._cur._locale.registerForChange(this);
            return;
        }
        throw new AssertionError();
    }

    public void _setTextValue(char[] cArr, int i2, int i3) {
        if (i3 < 0) {
            throw new IndexOutOfBoundsException("setTextValue: length < 0");
        } else if (cArr == null) {
            if (i3 <= 0) {
                setTextValue((char[]) null, 0, 0);
                return;
            }
            throw new IllegalArgumentException("setTextValue: sourceChars == null");
        } else if (i2 < 0 || i2 >= cArr.length) {
            throw new IndexOutOfBoundsException("setTextValue: offset out of bounds");
        } else {
            if (i2 + i3 > cArr.length) {
                i3 = cArr.length - i2;
            }
            CharUtil charUtil = this._cur._locale.getCharUtil();
            setTextValue(charUtil.saveChars(cArr, i2, i3), charUtil._offSrc, charUtil._cchSrc);
        }
    }

    public boolean _toChild(QName qName) {
        return _toChild(qName, 0);
    }

    public boolean _toNextSibling(String str, String str2) {
        validateLocalName(str2);
        return _toNextSibling(this._cur._locale._qnameFactory.getQName(str, str2));
    }

    public String _xmlText(XmlOptions xmlOptions) {
        if ($assertionsDisabled || isValid()) {
            return new Saver.TextSaver(this._cur, xmlOptions, null).saveToString();
        }
        throw new AssertionError();
    }

    @Override // org.apache.xmlbeans.XmlTokenSource
    public void dump() {
        if (preCheck()) {
            this._cur._locale.enter();
            try {
                _dump();
            } finally {
                this._cur._locale.exit();
            }
        } else {
            synchronized (this._cur._locale) {
                this._cur._locale.enter();
                try {
                    _dump();
                } finally {
                    this._cur._locale.exit();
                }
            }
        }
    }

    public static void validateLocalName(String str) {
        if (str == null) {
            throw new IllegalArgumentException("Name is null");
        } else if (str.length() == 0) {
            throw new IllegalArgumentException("Name is empty");
        } else if (!XMLChar.isValidNCName(str)) {
            throw new IllegalArgumentException("Name is not valid");
        }
    }

    public void _beginElement(String str, String str2) {
        _insertElementWithText(str, str2, null);
        _toPrevToken();
    }

    public void _insertAttribute(QName qName) {
        _insertAttributeWithValue(qName, (String) null);
    }

    public void _insertElement(QName qName) {
        _insertElementWithText(qName, (String) null);
    }

    public void _save(Writer writer) {
        _save(writer, (XmlOptions) null);
    }

    public boolean _toChild(int i2) {
        return _toChild((QName) null, i2);
    }

    @Override // org.apache.xmlbeans.XmlCursor
    public XmlCursor.XmlBookmark getBookmark(Object obj) {
        XmlCursor.XmlBookmark _getBookmark;
        if (preCheck()) {
            this._cur._locale.enter();
            try {
                return _getBookmark(obj);
            } finally {
                this._cur._locale.exit();
            }
        } else {
            synchronized (this._cur._locale) {
                this._cur._locale.enter();
                try {
                    _getBookmark = _getBookmark(obj);
                } finally {
                    this._cur._locale.exit();
                }
            }
            return _getBookmark;
        }
    }

    private boolean preCheck() {
        checkThisCursor();
        return this._cur._locale.noSync();
    }

    public void _insertAttributeWithValue(QName qName, String str) {
        validateLocalName(qName.getLocalPart());
        Cur tempCur = this._cur._locale.tempCur();
        tempCur.createAttr(qName);
        insertNode(tempCur, str);
        tempCur.release();
    }

    public void _insertElementWithText(QName qName, String str) {
        validateLocalName(qName.getLocalPart());
        Cur tempCur = this._cur._locale.tempCur();
        tempCur.createElement(qName);
        insertNode(tempCur, str);
        tempCur.release();
    }

    public void _save(ContentHandler contentHandler, LexicalHandler lexicalHandler) {
        _save(contentHandler, lexicalHandler, null);
    }

    public boolean _toChild(String str, String str2) {
        validateLocalName(str2);
        return _toChild(this._cur._locale.makeQName(str, str2), 0);
    }

    public boolean _toNextSibling(QName qName) {
        this._cur.push();
        while (___toNextSibling()) {
            if (this._cur.getName().equals(qName)) {
                this._cur.popButStay();
                return true;
            }
        }
        this._cur.pop();
        return false;
    }

    public Cursor(Cur cur) {
        this(cur._xobj, cur._pos);
    }

    public void _beginElement(QName qName) {
        _insertElementWithText(qName, (String) null);
        _toPrevToken();
    }

    public void _save(ContentHandler contentHandler, LexicalHandler lexicalHandler, XmlOptions xmlOptions) {
        new Saver.SaxSaver(this._cur, xmlOptions, contentHandler, lexicalHandler);
    }

    private boolean isValid() {
        return isValid(this._cur);
    }

    public int _getTextValue(char[] cArr, int i2, int i3) {
        if (this._cur.isText()) {
            return _getChars(cArr, i2, i3);
        }
        if (cArr == null) {
            throw new IllegalArgumentException("char buffer is null");
        } else if (i2 < 0) {
            throw new IllegalArgumentException("offset < 0");
        } else if (i2 < cArr.length) {
            if (i3 < 0) {
                i3 = Integer.MAX_VALUE;
            }
            if (i2 + i3 > cArr.length) {
                i3 = cArr.length - i2;
            }
            if (!this._cur.isNode()) {
                throw new IllegalStateException("Can't get text value, current token can have no text value");
            } else if (this._cur.hasChildren()) {
                return Locale.getTextValue(this._cur, 1, cArr, i2, i3);
            } else {
                Object firstChars = this._cur.getFirstChars();
                Cur cur = this._cur;
                if (cur._cchSrc > i3) {
                    cur._cchSrc = i3;
                }
                Cur cur2 = this._cur;
                int i4 = cur2._cchSrc;
                if (i4 <= 0) {
                    return 0;
                }
                CharUtil.getChars(cArr, i2, firstChars, cur2._offSrc, i4);
                return this._cur._cchSrc;
            }
        } else {
            throw new IllegalArgumentException("offset off end");
        }
    }

    public void _save(File file, XmlOptions xmlOptions) {
        if (file != null) {
            FileOutputStream fileOutputStream = new FileOutputStream(file);
            try {
                _save(fileOutputStream, xmlOptions);
            } finally {
                fileOutputStream.close();
            }
        } else {
            throw new IllegalArgumentException("Null file specified");
        }
    }

    public boolean _toChild(QName qName, int i2) {
        return Locale.toChild(this._cur, qName, i2);
    }

    @Override // org.apache.xmlbeans.XmlCursor
    public boolean toNextSibling(String str) {
        boolean _toNextSibling;
        if (preCheck()) {
            this._cur._locale.enter();
            try {
                return _toNextSibling(str);
            } finally {
                this._cur._locale.exit();
            }
        } else {
            synchronized (this._cur._locale) {
                this._cur._locale.enter();
                try {
                    _toNextSibling = _toNextSibling(str);
                } finally {
                    this._cur._locale.exit();
                }
            }
            return _toNextSibling;
        }
    }

    @Override // org.apache.xmlbeans.XmlCursor
    public void setTextValue(String str) {
        if (preCheck()) {
            this._cur._locale.enter();
            try {
                _setTextValue(str);
            } finally {
                this._cur._locale.exit();
            }
        } else {
            synchronized (this._cur._locale) {
                this._cur._locale.enter();
                try {
                    _setTextValue(str);
                } finally {
                    this._cur._locale.exit();
                }
            }
        }
    }

    public void _save(OutputStream outputStream, XmlOptions xmlOptions) {
        if (outputStream != null) {
            InputStream _newInputStream = _newInputStream(xmlOptions);
            try {
                byte[] bArr = new byte[8192];
                while (true) {
                    int read = _newInputStream.read(bArr);
                    if (read >= 0) {
                        outputStream.write(bArr, 0, read);
                    } else {
                        return;
                    }
                }
            } finally {
                _newInputStream.close();
            }
        } else {
            throw new IllegalArgumentException("Null OutputStream specified");
        }
    }

    @Override // org.apache.xmlbeans.XmlCursor
    public XmlCursor execQuery(String str, XmlOptions xmlOptions) {
        XmlCursor _execQuery;
        if (preCheck()) {
            this._cur._locale.enter();
            try {
                return _execQuery(str, xmlOptions);
            } finally {
                this._cur._locale.exit();
            }
        } else {
            synchronized (this._cur._locale) {
                this._cur._locale.enter();
                try {
                    _execQuery = _execQuery(str, xmlOptions);
                } finally {
                    this._cur._locale.exit();
                }
            }
            return _execQuery;
        }
    }

    @Override // org.apache.xmlbeans.XmlCursor
    public int getChars(char[] cArr, int i2, int i3) {
        int _getChars;
        if (preCheck()) {
            this._cur._locale.enter();
            try {
                return _getChars(cArr, i2, i3);
            } finally {
                this._cur._locale.exit();
            }
        } else {
            synchronized (this._cur._locale) {
                this._cur._locale.enter();
                try {
                    _getChars = _getChars(cArr, i2, i3);
                } finally {
                    this._cur._locale.exit();
                }
            }
            return _getChars;
        }
    }

    @Override // org.apache.xmlbeans.XmlCursor
    public int getTextValue(char[] cArr, int i2, int i3) {
        int _getTextValue;
        if (preCheck()) {
            this._cur._locale.enter();
            try {
                return _getTextValue(cArr, i2, i3);
            } finally {
                this._cur._locale.exit();
            }
        } else {
            synchronized (this._cur._locale) {
                this._cur._locale.enter();
                try {
                    _getTextValue = _getTextValue(cArr, i2, i3);
                } finally {
                    this._cur._locale.exit();
                }
            }
            return _getTextValue;
        }
    }

    @Override // org.apache.xmlbeans.XmlTokenSource
    public Node newDomNode(XmlOptions xmlOptions) {
        Node _newDomNode;
        if (preCheck()) {
            this._cur._locale.enter();
            try {
                return _newDomNode(xmlOptions);
            } finally {
                this._cur._locale.exit();
            }
        } else {
            synchronized (this._cur._locale) {
                this._cur._locale.enter();
                try {
                    _newDomNode = _newDomNode(xmlOptions);
                } finally {
                    this._cur._locale.exit();
                }
            }
            return _newDomNode;
        }
    }

    @Override // org.apache.xmlbeans.XmlTokenSource
    public InputStream newInputStream(XmlOptions xmlOptions) {
        InputStream _newInputStream;
        if (preCheck()) {
            this._cur._locale.enter();
            try {
                return _newInputStream(xmlOptions);
            } finally {
                this._cur._locale.exit();
            }
        } else {
            synchronized (this._cur._locale) {
                this._cur._locale.enter();
                try {
                    _newInputStream = _newInputStream(xmlOptions);
                } finally {
                    this._cur._locale.exit();
                }
            }
            return _newInputStream;
        }
    }

    @Override // org.apache.xmlbeans.XmlTokenSource
    public Reader newReader(XmlOptions xmlOptions) {
        Reader _newReader;
        if (preCheck()) {
            this._cur._locale.enter();
            try {
                return _newReader(xmlOptions);
            } finally {
                this._cur._locale.exit();
            }
        } else {
            synchronized (this._cur._locale) {
                this._cur._locale.enter();
                try {
                    _newReader = _newReader(xmlOptions);
                } finally {
                    this._cur._locale.exit();
                }
            }
            return _newReader;
        }
    }

    @Override // org.apache.xmlbeans.XmlTokenSource
    public XMLInputStream newXMLInputStream(XmlOptions xmlOptions) {
        XMLInputStream _newXMLInputStream;
        if (preCheck()) {
            this._cur._locale.enter();
            try {
                return _newXMLInputStream(xmlOptions);
            } finally {
                this._cur._locale.exit();
            }
        } else {
            synchronized (this._cur._locale) {
                this._cur._locale.enter();
                try {
                    _newXMLInputStream = _newXMLInputStream(xmlOptions);
                } finally {
                    this._cur._locale.exit();
                }
            }
            return _newXMLInputStream;
        }
    }

    @Override // org.apache.xmlbeans.XmlTokenSource
    public XMLStreamReader newXMLStreamReader(XmlOptions xmlOptions) {
        XMLStreamReader _newXMLStreamReader;
        if (preCheck()) {
            this._cur._locale.enter();
            try {
                return _newXMLStreamReader(xmlOptions);
            } finally {
                this._cur._locale.exit();
            }
        } else {
            synchronized (this._cur._locale) {
                this._cur._locale.enter();
                try {
                    _newXMLStreamReader = _newXMLStreamReader(xmlOptions);
                } finally {
                    this._cur._locale.exit();
                }
            }
            return _newXMLStreamReader;
        }
    }

    @Override // org.apache.xmlbeans.XmlCursor
    public boolean toChild(String str, String str2) {
        boolean _toChild;
        if (preCheck()) {
            this._cur._locale.enter();
            try {
                return _toChild(str, str2);
            } finally {
                this._cur._locale.exit();
            }
        } else {
            synchronized (this._cur._locale) {
                this._cur._locale.enter();
                try {
                    _toChild = _toChild(str, str2);
                } finally {
                    this._cur._locale.exit();
                }
            }
            return _toChild;
        }
    }

    @Override // org.apache.xmlbeans.XmlTokenSource
    public String xmlText(XmlOptions xmlOptions) {
        String _xmlText;
        if (preCheck()) {
            this._cur._locale.enter();
            try {
                return _xmlText(xmlOptions);
            } finally {
                this._cur._locale.exit();
            }
        } else {
            synchronized (this._cur._locale) {
                this._cur._locale.enter();
                try {
                    _xmlText = _xmlText(xmlOptions);
                } finally {
                    this._cur._locale.exit();
                }
            }
            return _xmlText;
        }
    }

    @Override // org.apache.xmlbeans.XmlTokenSource
    public XmlCursor newCursor() {
        XmlCursor _newCursor;
        if (preCheck()) {
            this._cur._locale.enter();
            try {
                return _newCursor();
            } finally {
                this._cur._locale.exit();
            }
        } else {
            synchronized (this._cur._locale) {
                this._cur._locale.enter();
                try {
                    _newCursor = _newCursor();
                } finally {
                    this._cur._locale.exit();
                }
            }
            return _newCursor;
        }
    }

    @Override // org.apache.xmlbeans.XmlCursor
    public void beginElement(String str) {
        if (preCheck()) {
            this._cur._locale.enter();
            try {
                _beginElement(str);
            } finally {
                this._cur._locale.exit();
            }
        } else {
            synchronized (this._cur._locale) {
                this._cur._locale.enter();
                try {
                    _beginElement(str);
                } finally {
                    this._cur._locale.exit();
                }
            }
        }
    }

    @Override // org.apache.xmlbeans.XmlCursor
    public void insertAttribute(String str, String str2) {
        if (preCheck()) {
            this._cur._locale.enter();
            try {
                _insertAttribute(str, str2);
            } finally {
                this._cur._locale.exit();
            }
        } else {
            synchronized (this._cur._locale) {
                this._cur._locale.enter();
                try {
                    _insertAttribute(str, str2);
                } finally {
                    this._cur._locale.exit();
                }
            }
        }
    }

    @Override // org.apache.xmlbeans.XmlCursor
    public void insertAttributeWithValue(String str, String str2, String str3) {
        if (preCheck()) {
            this._cur._locale.enter();
            try {
                _insertAttributeWithValue(str, str2, str3);
            } finally {
                this._cur._locale.exit();
            }
        } else {
            synchronized (this._cur._locale) {
                this._cur._locale.enter();
                try {
                    _insertAttributeWithValue(str, str2, str3);
                } finally {
                    this._cur._locale.exit();
                }
            }
        }
    }

    @Override // org.apache.xmlbeans.XmlCursor
    public void insertElement(String str) {
        if (preCheck()) {
            this._cur._locale.enter();
            try {
                _insertElement(str);
            } finally {
                this._cur._locale.exit();
            }
        } else {
            synchronized (this._cur._locale) {
                this._cur._locale.enter();
                try {
                    _insertElement(str);
                } finally {
                    this._cur._locale.exit();
                }
            }
        }
    }

    @Override // org.apache.xmlbeans.XmlCursor
    public void insertElementWithText(String str, String str2) {
        if (preCheck()) {
            this._cur._locale.enter();
            try {
                _insertElementWithText(str, str2);
            } finally {
                this._cur._locale.exit();
            }
        } else {
            synchronized (this._cur._locale) {
                this._cur._locale.enter();
                try {
                    _insertElementWithText(str, str2);
                } finally {
                    this._cur._locale.exit();
                }
            }
        }
    }

    @Override // org.apache.xmlbeans.XmlTokenSource
    public void save(File file) {
        if (preCheck()) {
            this._cur._locale.enter();
            try {
                _save(file);
            } finally {
                this._cur._locale.exit();
            }
        } else {
            synchronized (this._cur._locale) {
                this._cur._locale.enter();
                try {
                    _save(file);
                } finally {
                    this._cur._locale.exit();
                }
            }
        }
    }

    @Override // org.apache.xmlbeans.XmlCursor
    public void selectPath(String str, XmlOptions xmlOptions) {
        if (preCheck()) {
            this._cur._locale.enter();
            try {
                _selectPath(str, xmlOptions);
            } finally {
                this._cur._locale.exit();
            }
        } else {
            synchronized (this._cur._locale) {
                this._cur._locale.enter();
                try {
                    _selectPath(str, xmlOptions);
                } finally {
                    this._cur._locale.exit();
                }
            }
        }
    }

    @Override // org.apache.xmlbeans.XmlCursor
    public boolean toNextSibling(String str, String str2) {
        boolean _toNextSibling;
        if (preCheck()) {
            this._cur._locale.enter();
            try {
                return _toNextSibling(str, str2);
            } finally {
                this._cur._locale.exit();
            }
        } else {
            synchronized (this._cur._locale) {
                this._cur._locale.enter();
                try {
                    _toNextSibling = _toNextSibling(str, str2);
                } finally {
                    this._cur._locale.exit();
                }
            }
            return _toNextSibling;
        }
    }

    public void _save(Writer writer, XmlOptions xmlOptions) {
        if (writer == null) {
            throw new IllegalArgumentException("Null Writer specified");
        } else if (xmlOptions == null || !xmlOptions.hasOption(XmlOptions.SAVE_OPTIMIZE_FOR_SPEED)) {
            Reader _newReader = _newReader(xmlOptions);
            try {
                char[] cArr = new char[8192];
                while (true) {
                    int read = _newReader.read(cArr);
                    if (read >= 0) {
                        writer.write(cArr, 0, read);
                    } else {
                        return;
                    }
                }
            } finally {
                _newReader.close();
            }
        } else {
            Saver.OptimizedForSpeedSaver.save(this._cur, writer);
        }
    }

    @Override // org.apache.xmlbeans.XmlCursor
    public void setTextValue(char[] cArr, int i2, int i3) {
        if (preCheck()) {
            this._cur._locale.enter();
            try {
                _setTextValue(cArr, i2, i3);
            } finally {
                this._cur._locale.exit();
            }
        } else {
            synchronized (this._cur._locale) {
                this._cur._locale.enter();
                try {
                    _setTextValue(cArr, i2, i3);
                } finally {
                    this._cur._locale.exit();
                }
            }
        }
    }

    @Override // org.apache.xmlbeans.XmlCursor
    public boolean toChild(QName qName) {
        boolean _toChild;
        if (preCheck()) {
            this._cur._locale.enter();
            try {
                return _toChild(qName);
            } finally {
                this._cur._locale.exit();
            }
        } else {
            synchronized (this._cur._locale) {
                this._cur._locale.enter();
                try {
                    _toChild = _toChild(qName);
                } finally {
                    this._cur._locale.exit();
                }
            }
            return _toChild;
        }
    }

    @Override // org.apache.xmlbeans.XmlCursor
    public void beginElement(String str, String str2) {
        if (preCheck()) {
            this._cur._locale.enter();
            try {
                _beginElement(str, str2);
            } finally {
                this._cur._locale.exit();
            }
        } else {
            synchronized (this._cur._locale) {
                this._cur._locale.enter();
                try {
                    _beginElement(str, str2);
                } finally {
                    this._cur._locale.exit();
                }
            }
        }
    }

    @Override // org.apache.xmlbeans.XmlCursor
    public void insertAttribute(QName qName) {
        if (preCheck()) {
            this._cur._locale.enter();
            try {
                _insertAttribute(qName);
            } finally {
                this._cur._locale.exit();
            }
        } else {
            synchronized (this._cur._locale) {
                this._cur._locale.enter();
                try {
                    _insertAttribute(qName);
                } finally {
                    this._cur._locale.exit();
                }
            }
        }
    }

    @Override // org.apache.xmlbeans.XmlCursor
    public void insertAttributeWithValue(QName qName, String str) {
        if (preCheck()) {
            this._cur._locale.enter();
            try {
                _insertAttributeWithValue(qName, str);
            } finally {
                this._cur._locale.exit();
            }
        } else {
            synchronized (this._cur._locale) {
                this._cur._locale.enter();
                try {
                    _insertAttributeWithValue(qName, str);
                } finally {
                    this._cur._locale.exit();
                }
            }
        }
    }

    @Override // org.apache.xmlbeans.XmlCursor
    public void insertElement(String str, String str2) {
        if (preCheck()) {
            this._cur._locale.enter();
            try {
                _insertElement(str, str2);
            } finally {
                this._cur._locale.exit();
            }
        } else {
            synchronized (this._cur._locale) {
                this._cur._locale.enter();
                try {
                    _insertElement(str, str2);
                } finally {
                    this._cur._locale.exit();
                }
            }
        }
    }

    @Override // org.apache.xmlbeans.XmlCursor
    public void insertElementWithText(String str, String str2, String str3) {
        if (preCheck()) {
            this._cur._locale.enter();
            try {
                _insertElementWithText(str, str2, str3);
            } finally {
                this._cur._locale.exit();
            }
        } else {
            synchronized (this._cur._locale) {
                this._cur._locale.enter();
                try {
                    _insertElementWithText(str, str2, str3);
                } finally {
                    this._cur._locale.exit();
                }
            }
        }
    }

    @Override // org.apache.xmlbeans.XmlTokenSource
    public void save(OutputStream outputStream) {
        if (preCheck()) {
            this._cur._locale.enter();
            try {
                _save(outputStream);
            } finally {
                this._cur._locale.exit();
            }
        } else {
            synchronized (this._cur._locale) {
                this._cur._locale.enter();
                try {
                    _save(outputStream);
                } finally {
                    this._cur._locale.exit();
                }
            }
        }
    }

    @Override // org.apache.xmlbeans.XmlCursor
    public boolean toNextSibling(QName qName) {
        boolean _toNextSibling;
        if (preCheck()) {
            this._cur._locale.enter();
            try {
                return _toNextSibling(qName);
            } finally {
                this._cur._locale.exit();
            }
        } else {
            synchronized (this._cur._locale) {
                this._cur._locale.enter();
                try {
                    _toNextSibling = _toNextSibling(qName);
                } finally {
                    this._cur._locale.exit();
                }
            }
            return _toNextSibling;
        }
    }

    private int twoLocaleOp(Cursor cursor, int i2, int i3) {
        Locale locale = this._cur._locale;
        Locale locale2 = cursor._cur._locale;
        locale.enter(locale2);
        if (i2 == 0) {
            boolean _moveXml = _moveXml(cursor);
            locale.exit(locale2);
            return _moveXml ? 1 : 0;
        } else if (i2 == 1) {
            boolean _copyXml = _copyXml(cursor);
            locale.exit(locale2);
            return _copyXml ? 1 : 0;
        } else if (i2 == 2) {
            boolean _moveXmlContents = _moveXmlContents(cursor);
            locale.exit(locale2);
            return _moveXmlContents ? 1 : 0;
        } else if (i2 == 3) {
            boolean _copyXmlContents = _copyXmlContents(cursor);
            locale.exit(locale2);
            return _copyXmlContents ? 1 : 0;
        } else if (i2 == 4) {
            int _moveChars = _moveChars(i3, cursor);
            locale.exit(locale2);
            return _moveChars;
        } else if (i2 == 5) {
            try {
                return _copyChars(i3, cursor);
            } finally {
                locale.exit(locale2);
            }
        } else {
            StringBuffer stringBuffer = new StringBuffer();
            stringBuffer.append("Unknown operation: ");
            stringBuffer.append(i2);
            throw new RuntimeException(stringBuffer.toString());
        }
    }

    @Override // org.apache.xmlbeans.XmlCursor
    public boolean toChild(int i2) {
        boolean _toChild;
        if (preCheck()) {
            this._cur._locale.enter();
            try {
                return _toChild(i2);
            } finally {
                this._cur._locale.exit();
            }
        } else {
            synchronized (this._cur._locale) {
                this._cur._locale.enter();
                try {
                    _toChild = _toChild(i2);
                } finally {
                    this._cur._locale.exit();
                }
            }
            return _toChild;
        }
    }

    @Override // org.apache.xmlbeans.XmlTokenSource
    public void save(Writer writer) {
        if (preCheck()) {
            this._cur._locale.enter();
            try {
                _save(writer);
            } finally {
                this._cur._locale.exit();
            }
        } else {
            synchronized (this._cur._locale) {
                this._cur._locale.enter();
                try {
                    _save(writer);
                } finally {
                    this._cur._locale.exit();
                }
            }
        }
    }

    @Override // org.apache.xmlbeans.XmlCursor
    public boolean toChild(QName qName, int i2) {
        boolean _toChild;
        if (preCheck()) {
            this._cur._locale.enter();
            try {
                return _toChild(qName, i2);
            } finally {
                this._cur._locale.exit();
            }
        } else {
            synchronized (this._cur._locale) {
                this._cur._locale.enter();
                try {
                    _toChild = _toChild(qName, i2);
                } finally {
                    this._cur._locale.exit();
                }
            }
            return _toChild;
        }
    }

    @Override // org.apache.xmlbeans.XmlTokenSource
    public void save(ContentHandler contentHandler, LexicalHandler lexicalHandler, XmlOptions xmlOptions) {
        if (preCheck()) {
            this._cur._locale.enter();
            try {
                _save(contentHandler, lexicalHandler, xmlOptions);
            } finally {
                this._cur._locale.exit();
            }
        } else {
            synchronized (this._cur._locale) {
                this._cur._locale.enter();
                try {
                    _save(contentHandler, lexicalHandler, xmlOptions);
                } finally {
                    this._cur._locale.exit();
                }
            }
        }
    }

    @Override // org.apache.xmlbeans.XmlTokenSource
    public void save(File file, XmlOptions xmlOptions) {
        if (preCheck()) {
            this._cur._locale.enter();
            try {
                _save(file, xmlOptions);
            } finally {
                this._cur._locale.exit();
            }
        } else {
            synchronized (this._cur._locale) {
                this._cur._locale.enter();
                try {
                    _save(file, xmlOptions);
                } finally {
                    this._cur._locale.exit();
                }
            }
        }
    }

    @Override // org.apache.xmlbeans.XmlTokenSource
    public void save(OutputStream outputStream, XmlOptions xmlOptions) {
        if (preCheck()) {
            this._cur._locale.enter();
            try {
                _save(outputStream, xmlOptions);
            } finally {
                this._cur._locale.exit();
            }
        } else {
            synchronized (this._cur._locale) {
                this._cur._locale.enter();
                try {
                    _save(outputStream, xmlOptions);
                } finally {
                    this._cur._locale.exit();
                }
            }
        }
    }

    @Override // org.apache.xmlbeans.XmlTokenSource
    public void save(Writer writer, XmlOptions xmlOptions) {
        if (preCheck()) {
            this._cur._locale.enter();
            try {
                _save(writer, xmlOptions);
            } finally {
                this._cur._locale.exit();
            }
        } else {
            synchronized (this._cur._locale) {
                this._cur._locale.enter();
                try {
                    _save(writer, xmlOptions);
                } finally {
                    this._cur._locale.exit();
                }
            }
        }
    }
}
