package org.apache.xmlbeans.impl.store;

import b.b.a.a.a;
import java.io.BufferedReader;
import java.io.InputStreamReader;
import java.lang.ref.WeakReference;
import java.lang.reflect.InvocationTargetException;
import java.lang.reflect.Method;
import java.math.BigDecimal;
import java.util.ConcurrentModificationException;
import java.util.Date;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import java.util.WeakHashMap;
import org.apache.xmlbeans.SchemaType;
import org.apache.xmlbeans.XmlAnySimpleType;
import org.apache.xmlbeans.XmlBoolean;
import org.apache.xmlbeans.XmlDate;
import org.apache.xmlbeans.XmlDecimal;
import org.apache.xmlbeans.XmlDouble;
import org.apache.xmlbeans.XmlFloat;
import org.apache.xmlbeans.XmlInteger;
import org.apache.xmlbeans.XmlLong;
import org.apache.xmlbeans.XmlOptions;
import org.apache.xmlbeans.XmlString;
import org.apache.xmlbeans.impl.common.XPath;
import org.apache.xmlbeans.impl.store.DomImpl;
import org.apache.xmlbeans.impl.store.PathDelegate;
import org.w3c.dom.Node;

public abstract class Path {
    public static final String PATH_DELEGATE_INTERFACE = "PATH_DELEGATE_INTERFACE";
    public static final int USE_DELEGATE = 4;
    public static final int USE_XBEAN = 1;
    public static final int USE_XDK = 16;
    public static final int USE_XQRL = 2;
    public static final int USE_XQRL2002 = 8;
    public static String _delIntfName = null;
    public static String _forceXqrl2002ForXpathXQuery = "use xqrl-2002 for xpath";
    public static String _useDelegateForXpath = "use delegate for xpath";
    public static String _useXbeanForXpath = "use xbean for xpath";
    public static String _useXdkForXpath = "use xdk for xpath";
    public static String _useXqrlForXpath = "use xqrl for xpath";
    public static Map _xbeanPathCache = new WeakHashMap();
    public static boolean _xdkAvailable = true;
    public static Method _xdkCompilePath;
    public static Map _xdkPathCache = new WeakHashMap();
    public static boolean _xqrl2002Available = true;
    public static Method _xqrl2002CompilePath;
    public static Map _xqrl2002PathCache = new WeakHashMap();
    public static boolean _xqrlAvailable = true;
    public static Method _xqrlCompilePath;
    public static Map _xqrlPathCache = new WeakHashMap();
    public static /* synthetic */ Class class$java$lang$Boolean;
    public static /* synthetic */ Class class$java$lang$String;
    public static /* synthetic */ Class class$org$apache$xmlbeans$impl$store$Path;
    public final String _pathKey;

    public static final class DelegatePathImpl extends Path {
        public static final /* synthetic */ boolean $assertionsDisabled;
        public PathDelegate.SelectPathInterface _xpathImpl;

        public static class DelegatePathEngine extends XPath.ExecutionContext implements PathEngine {
            public static final /* synthetic */ boolean $assertionsDisabled;
            public Cur _cur;
            public PathDelegate.SelectPathInterface _engine;
            public boolean _firstCall = true;
            public long _version;

            static {
                Class cls = Path.class$org$apache$xmlbeans$impl$store$Path;
                if (cls == null) {
                    cls = Path.class$("org.apache.xmlbeans.impl.store.Path");
                    Path.class$org$apache$xmlbeans$impl$store$Path = cls;
                }
                $assertionsDisabled = !cls.desiredAssertionStatus();
            }

            public DelegatePathEngine(PathDelegate.SelectPathInterface selectPathInterface, Cur cur) {
                this._engine = selectPathInterface;
                this._version = cur._locale.version();
                this._cur = cur.weakCur(this);
            }

            private SchemaType getType(Object obj) {
                if (obj instanceof Integer) {
                    return XmlInteger.type;
                }
                if (obj instanceof Double) {
                    return XmlDouble.type;
                }
                if (obj instanceof Long) {
                    return XmlLong.type;
                }
                if (obj instanceof Float) {
                    return XmlFloat.type;
                }
                if (obj instanceof BigDecimal) {
                    return XmlDecimal.type;
                }
                if (obj instanceof Boolean) {
                    return XmlBoolean.type;
                }
                if (obj instanceof String) {
                    return XmlString.type;
                }
                if (obj instanceof Date) {
                    return XmlDate.type;
                }
                return XmlAnySimpleType.type;
            }

            @Override // org.apache.xmlbeans.impl.store.Path.PathEngine
            public boolean next(Cur cur) {
                Cur cur2;
                if (!this._firstCall) {
                    return false;
                }
                this._firstCall = false;
                Cur cur3 = this._cur;
                if (cur3 == null || this._version == cur3._locale.version()) {
                    List selectPath = this._engine.selectPath(this._cur.getDom());
                    for (int i2 = 0; i2 < selectPath.size(); i2++) {
                        Object obj = selectPath.get(i2);
                        if (!(obj instanceof Node)) {
                            String obj2 = selectPath.get(i2).toString();
                            try {
                                cur2 = cur._locale.load("<xml-fragment/>").tempCur();
                                cur2.setValue(obj2);
                                Locale.autoTypeDocument(cur2, getType(obj), null);
                                cur2.next();
                            } catch (Exception e2) {
                                throw new RuntimeException(e2);
                            }
                        } else if ($assertionsDisabled || (obj instanceof DomImpl.Dom)) {
                            cur2 = ((DomImpl.Dom) obj).tempCur();
                        } else {
                            throw new AssertionError("New object created in XPATH!");
                        }
                        cur.addToSelection(cur2);
                        cur2.release();
                    }
                    release();
                    this._engine = null;
                    return true;
                }
                throw new ConcurrentModificationException("Document changed during select");
            }

            @Override // org.apache.xmlbeans.impl.store.Path.PathEngine
            public void release() {
                Cur cur = this._cur;
                if (cur != null) {
                    cur.release();
                    this._cur = null;
                }
            }
        }

        static {
            Class cls = Path.class$org$apache$xmlbeans$impl$store$Path;
            if (cls == null) {
                cls = Path.class$("org.apache.xmlbeans.impl.store.Path");
                Path.class$org$apache$xmlbeans$impl$store$Path = cls;
            }
            $assertionsDisabled = !cls.desiredAssertionStatus();
        }

        public DelegatePathImpl(PathDelegate.SelectPathInterface selectPathInterface, String str) {
            super(str);
            this._xpathImpl = selectPathInterface;
        }

        public static Path create(String str, String str2, String str3, Map map) {
            if ($assertionsDisabled || !str3.startsWith("$")) {
                PathDelegate.SelectPathInterface createInstance = PathDelegate.createInstance(str, str2, str3, map);
                if (createInstance == null) {
                    return null;
                }
                return new DelegatePathImpl(createInstance, str2);
            }
            throw new AssertionError();
        }

        @Override // org.apache.xmlbeans.impl.store.Path
        public PathEngine execute(Cur cur, XmlOptions xmlOptions) {
            return new DelegatePathEngine(this._xpathImpl, cur);
        }
    }

    public interface PathEngine {
        boolean next(Cur cur);

        void release();
    }

    public static final class XbeanPath extends Path {
        public final XPath _compiledPath;
        public final String _currentVar;
        public Map namespaces;

        public XbeanPath(String str, String str2, XPath xPath) {
            super(str);
            this._currentVar = str2;
            this._compiledPath = xPath;
        }

        public static Path create(String str, String str2, Map map) {
            try {
                return new XbeanPath(str, str2, XPath.compileXPath(str, str2, map));
            } catch (XPath.XPathCompileException unused) {
                return null;
            }
        }

        @Override // org.apache.xmlbeans.impl.store.Path
        public PathEngine execute(Cur cur, XmlOptions xmlOptions) {
            XmlOptions maskNull = XmlOptions.maskNull(xmlOptions);
            String str = maskNull.hasOption(Path.PATH_DELEGATE_INTERFACE) ? (String) maskNull.get(Path.PATH_DELEGATE_INTERFACE) : Path._delIntfName;
            if (!cur.isContainer() || this._compiledPath.sawDeepDot()) {
                return Path.getCompiledPath(this._pathKey, 22, this._currentVar, str).execute(cur, maskNull);
            }
            return new XbeanPathEngine(this._compiledPath, cur);
        }
    }

    public static final class XbeanPathEngine extends XPath.ExecutionContext implements PathEngine {
        public static final /* synthetic */ boolean $assertionsDisabled;
        public Cur _cur;
        public final long _version;

        static {
            Class cls = Path.class$org$apache$xmlbeans$impl$store$Path;
            if (cls == null) {
                cls = Path.class$("org.apache.xmlbeans.impl.store.Path");
                Path.class$org$apache$xmlbeans$impl$store$Path = cls;
            }
            $assertionsDisabled = !cls.desiredAssertionStatus();
        }

        public XbeanPathEngine(XPath xPath, Cur cur) {
            if ($assertionsDisabled || cur.isContainer()) {
                this._version = cur._locale.version();
                Cur weakCur = cur.weakCur(this);
                this._cur = weakCur;
                weakCur.push();
                init(xPath);
                int start = start();
                if ((start & 1) != 0) {
                    cur.addToSelection();
                }
                doAttrs(start, cur);
                if ((start & 2) == 0 || !Locale.toFirstChildElement(this._cur)) {
                    release();
                    return;
                }
                return;
            }
            throw new AssertionError();
        }

        private void advance(Cur cur) {
            if (!$assertionsDisabled && this._cur == null) {
                throw new AssertionError();
            } else if (this._cur.isFinish()) {
                if (this._cur.isAtEndOfLastPush()) {
                    release();
                    return;
                }
                end();
                this._cur.next();
            } else if (this._cur.isElem()) {
                int element = element(this._cur.getName());
                if ((element & 1) != 0) {
                    cur.addToSelection(this._cur);
                }
                doAttrs(element, cur);
                if ((element & 2) == 0 || !Locale.toFirstChildElement(this._cur)) {
                    end();
                    this._cur.skip();
                }
            } else {
                do {
                    this._cur.next();
                } while (!this._cur.isContainerOrFinish());
            }
        }

        private void doAttrs(int i2, Cur cur) {
            if (!$assertionsDisabled && !this._cur.isContainer()) {
                throw new AssertionError();
            } else if ((i2 & 4) != 0 && this._cur.toFirstAttr()) {
                do {
                    if (attr(this._cur.getName())) {
                        cur.addToSelection(this._cur);
                    }
                } while (this._cur.toNextAttr());
                this._cur.toParent();
            }
        }

        @Override // org.apache.xmlbeans.impl.store.Path.PathEngine
        public boolean next(Cur cur) {
            Cur cur2 = this._cur;
            if (cur2 == null || this._version == cur2._locale.version()) {
                int selectionCount = cur.selectionCount();
                while (this._cur != null) {
                    advance(cur);
                    if (selectionCount != cur.selectionCount()) {
                        return true;
                    }
                }
                return false;
            }
            throw new ConcurrentModificationException("Document changed during select");
        }

        @Override // org.apache.xmlbeans.impl.store.Path.PathEngine
        public void release() {
            Cur cur = this._cur;
            if (cur != null) {
                cur.release();
                this._cur = null;
            }
        }
    }

    static {
        Class cls = class$org$apache$xmlbeans$impl$store$Path;
        if (cls == null) {
            cls = class$("org.apache.xmlbeans.impl.store.Path");
            class$org$apache$xmlbeans$impl$store$Path = cls;
        }
        try {
            BufferedReader bufferedReader = new BufferedReader(new InputStreamReader(cls.getClassLoader().getResourceAsStream("META-INF/services/org.apache.xmlbeans.impl.store.PathDelegate.SelectPathInterface")));
            _delIntfName = bufferedReader.readLine().trim();
            bufferedReader.close();
        } catch (Exception unused) {
            _delIntfName = null;
        }
    }

    public Path(String str) {
        this._pathKey = str;
    }

    public static /* synthetic */ Class class$(String str) {
        try {
            return Class.forName(str);
        } catch (ClassNotFoundException e2) {
            throw a.a(e2);
        }
    }

    public static synchronized String compilePath(String str, XmlOptions xmlOptions) {
        String str2;
        synchronized (Path.class) {
            str2 = getCompiledPath(str, xmlOptions)._pathKey;
        }
        return str2;
    }

    public static Path createXdkCompiledPath(String str, String str2) {
        Class<?> cls;
        Class<?> cls2;
        Class<?> cls3;
        if (!_xdkAvailable) {
            return null;
        }
        if (_xdkCompilePath == null) {
            try {
                Class<?> cls4 = Class.forName("org.apache.xmlbeans.impl.store.OXQXBXqrlImpl");
                Class<?>[] clsArr = new Class[3];
                if (class$java$lang$String == null) {
                    cls = class$("java.lang.String");
                    class$java$lang$String = cls;
                } else {
                    cls = class$java$lang$String;
                }
                clsArr[0] = cls;
                if (class$java$lang$String == null) {
                    cls2 = class$("java.lang.String");
                    class$java$lang$String = cls2;
                } else {
                    cls2 = class$java$lang$String;
                }
                clsArr[1] = cls2;
                if (class$java$lang$Boolean == null) {
                    cls3 = class$("java.lang.Boolean");
                    class$java$lang$Boolean = cls3;
                } else {
                    cls3 = class$java$lang$Boolean;
                }
                clsArr[2] = cls3;
                _xdkCompilePath = cls4.getDeclaredMethod("compilePath", clsArr);
            } catch (ClassNotFoundException unused) {
                _xdkAvailable = false;
                return null;
            } catch (Exception e2) {
                _xdkAvailable = false;
                throw new RuntimeException(e2.getMessage(), e2);
            }
        }
        try {
            return (Path) _xdkCompilePath.invoke(null, str, str2, new Boolean(true));
        } catch (InvocationTargetException e3) {
            Throwable cause = e3.getCause();
            throw new RuntimeException(cause.getMessage(), cause);
        } catch (IllegalAccessException e4) {
            throw new RuntimeException(e4.getMessage(), e4);
        }
    }

    public static Path createXqrl2002CompiledPath(String str, String str2) {
        Class<?> cls;
        Class<?> cls2;
        Class<?> cls3;
        if (!_xqrl2002Available) {
            return null;
        }
        if (_xqrl2002CompilePath == null) {
            try {
                Class<?> cls4 = Class.forName("org.apache.xmlbeans.impl.store.Xqrl2002Impl");
                Class<?>[] clsArr = new Class[3];
                if (class$java$lang$String == null) {
                    cls = class$("java.lang.String");
                    class$java$lang$String = cls;
                } else {
                    cls = class$java$lang$String;
                }
                clsArr[0] = cls;
                if (class$java$lang$String == null) {
                    cls2 = class$("java.lang.String");
                    class$java$lang$String = cls2;
                } else {
                    cls2 = class$java$lang$String;
                }
                clsArr[1] = cls2;
                if (class$java$lang$Boolean == null) {
                    cls3 = class$("java.lang.Boolean");
                    class$java$lang$Boolean = cls3;
                } else {
                    cls3 = class$java$lang$Boolean;
                }
                clsArr[2] = cls3;
                _xqrl2002CompilePath = cls4.getDeclaredMethod("compilePath", clsArr);
            } catch (ClassNotFoundException unused) {
                _xqrl2002Available = false;
                return null;
            } catch (Exception e2) {
                _xqrl2002Available = false;
                throw new RuntimeException(e2.getMessage(), e2);
            }
        }
        try {
            return (Path) _xqrl2002CompilePath.invoke(null, str, str2, new Boolean(true));
        } catch (InvocationTargetException e3) {
            Throwable cause = e3.getCause();
            throw new RuntimeException(cause.getMessage(), cause);
        } catch (IllegalAccessException e4) {
            throw new RuntimeException(e4.getMessage(), e4);
        }
    }

    public static Path createXqrlCompiledPath(String str, String str2) {
        Class<?> cls;
        Class<?> cls2;
        Class<?> cls3;
        if (!_xqrlAvailable) {
            return null;
        }
        if (_xqrlCompilePath == null) {
            try {
                Class<?> cls4 = Class.forName("org.apache.xmlbeans.impl.store.XqrlImpl");
                Class<?>[] clsArr = new Class[3];
                if (class$java$lang$String == null) {
                    cls = class$("java.lang.String");
                    class$java$lang$String = cls;
                } else {
                    cls = class$java$lang$String;
                }
                clsArr[0] = cls;
                if (class$java$lang$String == null) {
                    cls2 = class$("java.lang.String");
                    class$java$lang$String = cls2;
                } else {
                    cls2 = class$java$lang$String;
                }
                clsArr[1] = cls2;
                if (class$java$lang$Boolean == null) {
                    cls3 = class$("java.lang.Boolean");
                    class$java$lang$Boolean = cls3;
                } else {
                    cls3 = class$java$lang$Boolean;
                }
                clsArr[2] = cls3;
                _xqrlCompilePath = cls4.getDeclaredMethod("compilePath", clsArr);
            } catch (ClassNotFoundException unused) {
                _xqrlAvailable = false;
                return null;
            } catch (Exception e2) {
                _xqrlAvailable = false;
                throw new RuntimeException(e2.getMessage(), e2);
            }
        }
        try {
            return (Path) _xqrlCompilePath.invoke(null, str, str2, new Boolean(true));
        } catch (InvocationTargetException e3) {
            Throwable cause = e3.getCause();
            throw new RuntimeException(cause.getMessage(), cause);
        } catch (IllegalAccessException e4) {
            throw new RuntimeException(e4.getMessage(), e4);
        }
    }

    public static Path getCompiledPath(String str, XmlOptions xmlOptions) {
        XmlOptions maskNull = XmlOptions.maskNull(xmlOptions);
        return getCompiledPath(str, maskNull.hasOption(_useDelegateForXpath) ? 4 : maskNull.hasOption(_useXqrlForXpath) ? 2 : maskNull.hasOption(_useXdkForXpath) ? 16 : maskNull.hasOption(_useXbeanForXpath) ? 1 : maskNull.hasOption(_forceXqrl2002ForXpathXQuery) ? 8 : 23, getCurrentNodeVar(maskNull), maskNull.hasOption(PATH_DELEGATE_INTERFACE) ? (String) maskNull.get(PATH_DELEGATE_INTERFACE) : _delIntfName);
    }

    public static synchronized Path getCompiledPathDelegate(String str, String str2, Map map, String str3) {
        Path create;
        synchronized (Path.class) {
            if (map == null) {
                map = new HashMap();
            }
            try {
                XPath.compileXPath(str, str2, map);
            } catch (XPath.XPathCompileException unused) {
            }
            int intValue = map.get(XPath._NS_BOUNDARY) == null ? 0 : ((Integer) map.get(XPath._NS_BOUNDARY)).intValue();
            map.remove(XPath._NS_BOUNDARY);
            create = DelegatePathImpl.create(str3, str.substring(intValue), str2, map);
        }
        return create;
    }

    public static synchronized Path getCompiledPathXbean(String str, String str2, Map map) {
        Path create;
        synchronized (Path.class) {
            create = XbeanPath.create(str, str2, map);
            if (create != null) {
                _xbeanPathCache.put(create._pathKey, new WeakReference(create));
            }
        }
        return create;
    }

    public static synchronized Path getCompiledPathXdk(String str, String str2) {
        Path createXdkCompiledPath;
        synchronized (Path.class) {
            createXdkCompiledPath = createXdkCompiledPath(str, str2);
            if (createXdkCompiledPath != null) {
                _xdkPathCache.put(createXdkCompiledPath._pathKey, new WeakReference(createXdkCompiledPath));
            }
        }
        return createXdkCompiledPath;
    }

    public static synchronized Path getCompiledPathXqrl(String str, String str2) {
        Path createXqrlCompiledPath;
        synchronized (Path.class) {
            createXqrlCompiledPath = createXqrlCompiledPath(str, str2);
            if (createXqrlCompiledPath != null) {
                _xqrlPathCache.put(createXqrlCompiledPath._pathKey, new WeakReference(createXqrlCompiledPath));
            }
        }
        return createXqrlCompiledPath;
    }

    public static synchronized Path getCompiledPathXqrl2002(String str, String str2) {
        Path createXqrl2002CompiledPath;
        synchronized (Path.class) {
            createXqrl2002CompiledPath = createXqrl2002CompiledPath(str, str2);
            if (createXqrl2002CompiledPath != null) {
                _xqrl2002PathCache.put(createXqrl2002CompiledPath._pathKey, new WeakReference(createXqrl2002CompiledPath));
            }
        }
        return createXqrl2002CompiledPath;
    }

    public static String getCurrentNodeVar(XmlOptions xmlOptions) {
        XmlOptions maskNull = XmlOptions.maskNull(xmlOptions);
        if (!maskNull.hasOption(XmlOptions.XQUERY_CURRENT_NODE_VAR)) {
            return "this";
        }
        String str = (String) maskNull.get(XmlOptions.XQUERY_CURRENT_NODE_VAR);
        if (!str.startsWith("$")) {
            return str;
        }
        throw new IllegalArgumentException("Omit the '$' prefix for the current node variable");
    }

    public abstract PathEngine execute(Cur cur, XmlOptions xmlOptions);

    public static synchronized Path getCompiledPath(String str, int i2, String str2, String str3) {
        HashMap hashMap;
        synchronized (Path.class) {
            int i3 = i2 & 4;
            Path path = null;
            if (i3 != 0) {
                try {
                    hashMap = new HashMap();
                } catch (Throwable th) {
                    throw th;
                }
            } else {
                hashMap = null;
            }
            int i4 = i2 & 1;
            WeakReference weakReference = i4 != 0 ? (WeakReference) _xbeanPathCache.get(str) : null;
            if (weakReference == null && (i2 & 2) != 0) {
                weakReference = (WeakReference) _xqrlPathCache.get(str);
            }
            if (weakReference == null && (i2 & 16) != 0) {
                weakReference = (WeakReference) _xdkPathCache.get(str);
            }
            if (weakReference == null && (i2 & 8) != 0) {
                weakReference = (WeakReference) _xqrl2002PathCache.get(str);
            }
            if (weakReference != null) {
                path = (Path) weakReference.get();
            }
            if (path != null) {
                return path;
            }
            if (i4 != 0) {
                path = getCompiledPathXbean(str, str2, hashMap);
            }
            if (path == null && (i2 & 2) != 0) {
                path = getCompiledPathXqrl(str, str2);
            }
            if (path == null && (i2 & 16) != 0) {
                path = getCompiledPathXdk(str, str2);
            }
            if (path == null && i3 != 0) {
                path = getCompiledPathDelegate(str, str2, hashMap, str3);
            }
            if (path == null && (i2 & 8) != 0) {
                path = getCompiledPathXqrl2002(str, str2);
            }
            if (path != null) {
                return path;
            }
            StringBuffer stringBuffer = new StringBuffer();
            if (i4 != 0) {
                stringBuffer.append(" Trying XBeans path engine...");
            }
            if ((i2 & 2) != 0) {
                stringBuffer.append(" Trying XQRL...");
            }
            if ((i2 & 16) != 0) {
                stringBuffer.append(" Trying XDK...");
            }
            if (i3 != 0) {
                stringBuffer.append(" Trying delegated path engine...");
            }
            if ((i2 & 8) != 0) {
                stringBuffer.append(" Trying XQRL2002...");
            }
            StringBuffer stringBuffer2 = new StringBuffer();
            stringBuffer2.append(stringBuffer.toString());
            stringBuffer2.append(" FAILED on ");
            stringBuffer2.append(str);
            throw new RuntimeException(stringBuffer2.toString());
        }
    }
}
