package org.apache.xmlbeans.impl.store;

import b.b.a.a.a;
import java.io.IOException;
import java.io.InputStream;
import java.io.OutputStream;
import java.io.OutputStreamWriter;
import java.io.Reader;
import java.io.UnsupportedEncodingException;
import java.io.Writer;
import java.util.ArrayList;
import java.util.ConcurrentModificationException;
import java.util.HashMap;
import java.util.LinkedHashMap;
import java.util.List;
import java.util.Map;
import org.apache.poi.javax.xml.namespace.QName;
import org.apache.poi.ss.formula.ptg.GreaterThanPtg;
import org.apache.poi.ss.formula.ptg.StringPtg;
import org.apache.poi.util.LittleEndianCP950Reader;
import org.apache.xerces.impl.dv.util.Base64;
import org.apache.xmlbeans.SystemProperties;
import org.apache.xmlbeans.XmlDocumentProperties;
import org.apache.xmlbeans.XmlOptionCharEscapeMap;
import org.apache.xmlbeans.XmlOptions;
import org.apache.xmlbeans.impl.common.EncodingMap;
import org.apache.xmlbeans.impl.common.GenericXmlInputStream;
import org.apache.xmlbeans.impl.common.JarHelper;
import org.apache.xmlbeans.impl.common.QNameHelper;
import org.apache.xmlbeans.impl.common.Sax2Dom;
import org.apache.xmlbeans.impl.common.XmlEventBase;
import org.apache.xmlbeans.impl.common.XmlNameImpl;
import org.apache.xmlbeans.xml.stream.Attribute;
import org.apache.xmlbeans.xml.stream.AttributeIterator;
import org.apache.xmlbeans.xml.stream.ChangePrefixMapping;
import org.apache.xmlbeans.xml.stream.CharacterData;
import org.apache.xmlbeans.xml.stream.Comment;
import org.apache.xmlbeans.xml.stream.EndDocument;
import org.apache.xmlbeans.xml.stream.EndElement;
import org.apache.xmlbeans.xml.stream.EndPrefixMapping;
import org.apache.xmlbeans.xml.stream.Location;
import org.apache.xmlbeans.xml.stream.ProcessingInstruction;
import org.apache.xmlbeans.xml.stream.StartDocument;
import org.apache.xmlbeans.xml.stream.StartElement;
import org.apache.xmlbeans.xml.stream.StartPrefixMapping;
import org.apache.xmlbeans.xml.stream.XMLEvent;
import org.apache.xmlbeans.xml.stream.XMLName;
import org.xml.sax.ContentHandler;
import org.xml.sax.SAXException;
import org.xml.sax.ext.LexicalHandler;
import org.xml.sax.helpers.AttributesImpl;

public abstract class Saver {
    public static final /* synthetic */ boolean $assertionsDisabled;
    public static final int ATTR = 3;
    public static final int COMMENT = 4;
    public static final int ELEM = 2;
    public static final int PROCINST = 5;
    public static final int ROOT = 1;
    public static final int TEXT = 0;
    public static final String _newLine = (SystemProperties.getProperty("line.separator") == null ? "\n" : SystemProperties.getProperty("line.separator"));
    public static /* synthetic */ Class class$org$apache$xmlbeans$impl$store$Saver;
    public List _ancestorNamespaces;
    public ArrayList _attrNames;
    public ArrayList _attrValues;
    public SaveCur _cur;
    public int _currentMapping;
    public String _initialDefaultUri;
    public final Locale _locale;
    public ArrayList _namespaceStack;
    public Map _preComputedNamespaces;
    public HashMap _prefixMap;
    public XmlOptionCharEscapeMap _replaceChar;
    public boolean _saveNamespacesFirst;
    public Map _suggestedPrefixes;
    public HashMap _uriMap;
    public boolean _useDefaultNamespace;
    public final long _version;

    public static final class DocSaveCur extends SaveCur {
        public static final /* synthetic */ boolean $assertionsDisabled;
        public Cur _cur;

        static {
            Class cls = Saver.class$org$apache$xmlbeans$impl$store$Saver;
            if (cls == null) {
                cls = Saver.class$("org.apache.xmlbeans.impl.store.Saver");
                Saver.class$org$apache$xmlbeans$impl$store$Saver = cls;
            }
            $assertionsDisabled = !cls.desiredAssertionStatus();
        }

        public DocSaveCur(Cur cur) {
            if ($assertionsDisabled || cur.isRoot()) {
                this._cur = cur.weakCur(this);
                return;
            }
            throw new AssertionError();
        }

        @Override // org.apache.xmlbeans.impl.store.Saver.SaveCur
        public List getAncestorNamespaces() {
            return null;
        }

        @Override // org.apache.xmlbeans.impl.store.Saver.SaveCur
        public String getAttrValue() {
            if ($assertionsDisabled || this._cur.isAttr()) {
                return this._cur.getValueAsString();
            }
            throw new AssertionError();
        }

        @Override // org.apache.xmlbeans.impl.store.Saver.SaveCur
        public Object getChars() {
            Object chars = this._cur.getChars(-1);
            Cur cur = this._cur;
            this._offSrc = cur._offSrc;
            this._cchSrc = cur._cchSrc;
            return chars;
        }

        @Override // org.apache.xmlbeans.impl.store.Saver.SaveCur
        public XmlDocumentProperties getDocProps() {
            return Locale.getDocProps(this._cur, false);
        }

        @Override // org.apache.xmlbeans.impl.store.Saver.SaveCur
        public QName getName() {
            return this._cur.getName();
        }

        @Override // org.apache.xmlbeans.impl.store.Saver.SaveCur
        public String getXmlnsPrefix() {
            return this._cur.getXmlnsPrefix();
        }

        @Override // org.apache.xmlbeans.impl.store.Saver.SaveCur
        public String getXmlnsUri() {
            return this._cur.getXmlnsUri();
        }

        @Override // org.apache.xmlbeans.impl.store.Saver.SaveCur
        public boolean hasChildren() {
            return this._cur.hasChildren();
        }

        @Override // org.apache.xmlbeans.impl.store.Saver.SaveCur
        public boolean hasText() {
            return this._cur.hasText();
        }

        @Override // org.apache.xmlbeans.impl.store.Saver.SaveCur
        public boolean isTextCData() {
            return this._cur.isTextCData();
        }

        @Override // org.apache.xmlbeans.impl.store.Saver.SaveCur
        public boolean isXmlns() {
            return this._cur.isXmlns();
        }

        @Override // org.apache.xmlbeans.impl.store.Saver.SaveCur
        public int kind() {
            return this._cur.kind();
        }

        @Override // org.apache.xmlbeans.impl.store.Saver.SaveCur
        public boolean next() {
            return this._cur.next();
        }

        @Override // org.apache.xmlbeans.impl.store.Saver.SaveCur
        public void pop() {
            this._cur.pop();
        }

        @Override // org.apache.xmlbeans.impl.store.Saver.SaveCur
        public void push() {
            this._cur.push();
        }

        @Override // org.apache.xmlbeans.impl.store.Saver.SaveCur
        public void release() {
            this._cur.release();
            this._cur = null;
        }

        @Override // org.apache.xmlbeans.impl.store.Saver.SaveCur
        public void toEnd() {
            this._cur.toEnd();
        }

        @Override // org.apache.xmlbeans.impl.store.Saver.SaveCur
        public boolean toFirstAttr() {
            return this._cur.toFirstAttr();
        }

        @Override // org.apache.xmlbeans.impl.store.Saver.SaveCur
        public boolean toNextAttr() {
            return this._cur.toNextAttr();
        }
    }

    public static final class FilterPiSaveCur extends FilterSaveCur {
        public String _piTarget;

        public FilterPiSaveCur(SaveCur saveCur, String str) {
            super(saveCur);
            this._piTarget = str;
        }

        @Override // org.apache.xmlbeans.impl.store.Saver.FilterSaveCur
        public boolean filter() {
            return kind() == 5 && getName().getLocalPart().equals(this._piTarget);
        }
    }

    public static abstract class FilterSaveCur extends SaveCur {
        public static final /* synthetic */ boolean $assertionsDisabled;
        public SaveCur _cur;

        static {
            Class cls = Saver.class$org$apache$xmlbeans$impl$store$Saver;
            if (cls == null) {
                cls = Saver.class$("org.apache.xmlbeans.impl.store.Saver");
                Saver.class$org$apache$xmlbeans$impl$store$Saver = cls;
            }
            $assertionsDisabled = !cls.desiredAssertionStatus();
        }

        public FilterSaveCur(SaveCur saveCur) {
            if ($assertionsDisabled || saveCur.isRoot()) {
                this._cur = saveCur;
                return;
            }
            throw new AssertionError();
        }

        public abstract boolean filter();

        @Override // org.apache.xmlbeans.impl.store.Saver.SaveCur
        public List getAncestorNamespaces() {
            return this._cur.getAncestorNamespaces();
        }

        @Override // org.apache.xmlbeans.impl.store.Saver.SaveCur
        public String getAttrValue() {
            return this._cur.getAttrValue();
        }

        @Override // org.apache.xmlbeans.impl.store.Saver.SaveCur
        public Object getChars() {
            Object chars = this._cur.getChars();
            SaveCur saveCur = this._cur;
            this._offSrc = saveCur._offSrc;
            this._cchSrc = saveCur._cchSrc;
            return chars;
        }

        @Override // org.apache.xmlbeans.impl.store.Saver.SaveCur
        public XmlDocumentProperties getDocProps() {
            return this._cur.getDocProps();
        }

        @Override // org.apache.xmlbeans.impl.store.Saver.SaveCur
        public QName getName() {
            return this._cur.getName();
        }

        @Override // org.apache.xmlbeans.impl.store.Saver.SaveCur
        public String getXmlnsPrefix() {
            return this._cur.getXmlnsPrefix();
        }

        @Override // org.apache.xmlbeans.impl.store.Saver.SaveCur
        public String getXmlnsUri() {
            return this._cur.getXmlnsUri();
        }

        @Override // org.apache.xmlbeans.impl.store.Saver.SaveCur
        public boolean hasChildren() {
            return this._cur.hasChildren();
        }

        @Override // org.apache.xmlbeans.impl.store.Saver.SaveCur
        public boolean hasText() {
            return this._cur.hasText();
        }

        @Override // org.apache.xmlbeans.impl.store.Saver.SaveCur
        public boolean isTextCData() {
            return this._cur.isTextCData();
        }

        @Override // org.apache.xmlbeans.impl.store.Saver.SaveCur
        public boolean isXmlns() {
            return this._cur.isXmlns();
        }

        @Override // org.apache.xmlbeans.impl.store.Saver.SaveCur
        public int kind() {
            return this._cur.kind();
        }

        @Override // org.apache.xmlbeans.impl.store.Saver.SaveCur
        public boolean next() {
            if (!this._cur.next()) {
                return false;
            }
            if (!filter()) {
                return true;
            }
            if ($assertionsDisabled || (!isRoot() && !isText() && !isAttr())) {
                toEnd();
                return next();
            }
            throw new AssertionError();
        }

        @Override // org.apache.xmlbeans.impl.store.Saver.SaveCur
        public void pop() {
            this._cur.pop();
        }

        @Override // org.apache.xmlbeans.impl.store.Saver.SaveCur
        public void push() {
            this._cur.push();
        }

        @Override // org.apache.xmlbeans.impl.store.Saver.SaveCur
        public void release() {
            this._cur.release();
            this._cur = null;
        }

        @Override // org.apache.xmlbeans.impl.store.Saver.SaveCur
        public void toEnd() {
            this._cur.toEnd();
        }

        @Override // org.apache.xmlbeans.impl.store.Saver.SaveCur
        public boolean toFirstAttr() {
            return this._cur.toFirstAttr();
        }

        @Override // org.apache.xmlbeans.impl.store.Saver.SaveCur
        public boolean toNextAttr() {
            return this._cur.toNextAttr();
        }
    }

    public static final class FragSaveCur extends SaveCur {
        public static final /* synthetic */ boolean $assertionsDisabled;
        public static final int CUR = 5;
        public static final int ELEM_END = 4;
        public static final int ELEM_START = 2;
        public static final int ROOT_END = 3;
        public static final int ROOT_START = 1;
        public ArrayList _ancestorNamespaces;
        public Cur _cur;
        public QName _elem;
        public Cur _end;
        public boolean _saveAttr;
        public int _state;
        public int[] _stateStack;
        public int _stateStackSize;

        static {
            Class cls = Saver.class$org$apache$xmlbeans$impl$store$Saver;
            if (cls == null) {
                cls = Saver.class$("org.apache.xmlbeans.impl.store.Saver");
                Saver.class$org$apache$xmlbeans$impl$store$Saver = cls;
            }
            $assertionsDisabled = !cls.desiredAssertionStatus();
        }

        public FragSaveCur(Cur cur, Cur cur2, QName qName) {
            this._saveAttr = cur.isAttr() && cur.isSamePos(cur2);
            this._cur = cur.weakCur(this);
            this._end = cur2.weakCur(this);
            this._elem = qName;
            this._state = 1;
            this._stateStack = new int[8];
            cur.push();
            computeAncestorNamespaces(cur);
            cur.pop();
        }

        private void computeAncestorNamespaces(Cur cur) {
            this._ancestorNamespaces = new ArrayList();
            while (cur.toParentRaw()) {
                if (cur.toFirstAttr()) {
                    do {
                        if (cur.isXmlns()) {
                            String xmlnsPrefix = cur.getXmlnsPrefix();
                            if (cur.getXmlnsUri().length() > 0 || xmlnsPrefix.length() == 0) {
                                this._ancestorNamespaces.add(cur.getXmlnsPrefix());
                                this._ancestorNamespaces.add(cur.getXmlnsUri());
                            }
                        }
                    } while (cur.toNextAttr());
                    cur.toParent();
                }
            }
        }

        @Override // org.apache.xmlbeans.impl.store.Saver.SaveCur
        public List getAncestorNamespaces() {
            return this._ancestorNamespaces;
        }

        @Override // org.apache.xmlbeans.impl.store.Saver.SaveCur
        public String getAttrValue() {
            if ($assertionsDisabled || (this._state == 5 && this._cur.isAttr())) {
                return this._cur.getValueAsString();
            }
            throw new AssertionError();
        }

        @Override // org.apache.xmlbeans.impl.store.Saver.SaveCur
        public Object getChars() {
            if ($assertionsDisabled || (this._state == 5 && this._cur.isText())) {
                Object chars = this._cur.getChars(-1);
                Cur cur = this._cur;
                this._offSrc = cur._offSrc;
                this._cchSrc = cur._cchSrc;
                return chars;
            }
            throw new AssertionError();
        }

        @Override // org.apache.xmlbeans.impl.store.Saver.SaveCur
        public XmlDocumentProperties getDocProps() {
            return Locale.getDocProps(this._cur, false);
        }

        @Override // org.apache.xmlbeans.impl.store.Saver.SaveCur
        public QName getName() {
            int i2 = this._state;
            if (i2 == 1) {
                return null;
            }
            if (i2 != 2) {
                if (i2 == 3) {
                    return null;
                }
                if (i2 != 4) {
                    if ($assertionsDisabled || i2 == 5) {
                        return this._cur.getName();
                    }
                    throw new AssertionError();
                }
            }
            return this._elem;
        }

        @Override // org.apache.xmlbeans.impl.store.Saver.SaveCur
        public String getXmlnsPrefix() {
            if ($assertionsDisabled || (this._state == 5 && this._cur.isAttr())) {
                return this._cur.getXmlnsPrefix();
            }
            throw new AssertionError();
        }

        @Override // org.apache.xmlbeans.impl.store.Saver.SaveCur
        public String getXmlnsUri() {
            if ($assertionsDisabled || (this._state == 5 && this._cur.isAttr())) {
                return this._cur.getXmlnsUri();
            }
            throw new AssertionError();
        }

        @Override // org.apache.xmlbeans.impl.store.Saver.SaveCur
        public boolean hasChildren() {
            boolean z = false;
            if (isContainer()) {
                push();
                next();
                if (!isText() && !isFinish()) {
                    z = true;
                }
                pop();
            }
            return z;
        }

        @Override // org.apache.xmlbeans.impl.store.Saver.SaveCur
        public boolean hasText() {
            if (!isContainer()) {
                return false;
            }
            push();
            next();
            boolean isText = isText();
            pop();
            return isText;
        }

        @Override // org.apache.xmlbeans.impl.store.Saver.SaveCur
        public boolean isTextCData() {
            return this._cur.isTextCData();
        }

        @Override // org.apache.xmlbeans.impl.store.Saver.SaveCur
        public boolean isXmlns() {
            if ($assertionsDisabled || (this._state == 5 && this._cur.isAttr())) {
                return this._cur.isXmlns();
            }
            throw new AssertionError();
        }

        @Override // org.apache.xmlbeans.impl.store.Saver.SaveCur
        public int kind() {
            int i2 = this._state;
            int i3 = 1;
            if (i2 != 1) {
                i3 = 2;
                if (i2 != 2) {
                    if (i2 == 3) {
                        return -1;
                    }
                    if (i2 == 4) {
                        return -2;
                    }
                    if ($assertionsDisabled || i2 == 5) {
                        return this._cur.kind();
                    }
                    throw new AssertionError();
                }
            }
            return i3;
        }

        @Override // org.apache.xmlbeans.impl.store.Saver.SaveCur
        public boolean next() {
            int i2 = this._state;
            int i3 = 2;
            if (i2 != 1) {
                int i4 = 4;
                if (i2 != 2) {
                    if (i2 == 3) {
                        return false;
                    }
                    if (i2 == 4) {
                        this._state = 3;
                    } else if (i2 == 5) {
                        if ($assertionsDisabled || !this._cur.isAttr()) {
                            this._cur.next();
                            if (this._cur.isSamePos(this._end)) {
                                if (this._elem == null) {
                                    i4 = 3;
                                }
                                this._state = i4;
                            }
                        } else {
                            throw new AssertionError();
                        }
                    }
                } else if (this._saveAttr) {
                    this._state = 4;
                } else {
                    if (this._cur.isAttr()) {
                        this._cur.toParent();
                        this._cur.next();
                    }
                    if (this._cur.isSamePos(this._end)) {
                        this._state = 4;
                    } else {
                        this._state = 5;
                    }
                }
            } else {
                if (this._elem == null) {
                    i3 = 5;
                }
                this._state = i3;
            }
            return true;
        }

        @Override // org.apache.xmlbeans.impl.store.Saver.SaveCur
        public void pop() {
            this._cur.pop();
            int[] iArr = this._stateStack;
            int i2 = this._stateStackSize - 1;
            this._stateStackSize = i2;
            this._state = iArr[i2];
        }

        @Override // org.apache.xmlbeans.impl.store.Saver.SaveCur
        public void push() {
            int i2 = this._stateStackSize;
            int[] iArr = this._stateStack;
            if (i2 == iArr.length) {
                int[] iArr2 = new int[(i2 * 2)];
                System.arraycopy(iArr, 0, iArr2, 0, i2);
                this._stateStack = iArr2;
            }
            int[] iArr3 = this._stateStack;
            int i3 = this._stateStackSize;
            this._stateStackSize = i3 + 1;
            iArr3[i3] = this._state;
            this._cur.push();
        }

        @Override // org.apache.xmlbeans.impl.store.Saver.SaveCur
        public void release() {
            this._cur.release();
            this._cur = null;
            this._end.release();
            this._end = null;
        }

        @Override // org.apache.xmlbeans.impl.store.Saver.SaveCur
        public void toEnd() {
            int i2 = this._state;
            if (i2 == 1) {
                this._state = 3;
            } else if (i2 == 2) {
                this._state = 4;
            } else if (i2 != 3 && i2 != 4) {
                if ($assertionsDisabled || (i2 == 5 && !this._cur.isAttr() && !this._cur.isText())) {
                    this._cur.toEnd();
                    return;
                }
                throw new AssertionError();
            }
        }

        @Override // org.apache.xmlbeans.impl.store.Saver.SaveCur
        public boolean toFirstAttr() {
            int i2 = this._state;
            if (i2 == 1 || i2 == 3 || i2 == 4) {
                return false;
            }
            if (i2 == 5) {
                return this._cur.toFirstAttr();
            }
            if (!$assertionsDisabled && i2 != 2) {
                throw new AssertionError();
            } else if (!this._cur.isAttr()) {
                return false;
            } else {
                this._state = 5;
                return true;
            }
        }

        @Override // org.apache.xmlbeans.impl.store.Saver.SaveCur
        public boolean toNextAttr() {
            if ($assertionsDisabled || this._state == 5) {
                return !this._saveAttr && this._cur.toNextAttr();
            }
            throw new AssertionError();
        }
    }

    public static final class PrettySaveCur extends SaveCur {
        public static final /* synthetic */ boolean $assertionsDisabled;
        public SaveCur _cur;
        public int _depth;
        public boolean _isTextCData = false;
        public int _prettyIndent;
        public int _prettyOffset;
        public StringBuffer _sb = new StringBuffer();
        public ArrayList _stack = new ArrayList();
        public String _txt;
        public boolean _useCDataBookmarks = false;

        static {
            Class cls = Saver.class$org$apache$xmlbeans$impl$store$Saver;
            if (cls == null) {
                cls = Saver.class$("org.apache.xmlbeans.impl.store.Saver");
                Saver.class$org$apache$xmlbeans$impl$store$Saver = cls;
            }
            $assertionsDisabled = !cls.desiredAssertionStatus();
        }

        public PrettySaveCur(SaveCur saveCur, XmlOptions xmlOptions) {
            this._cur = saveCur;
            if ($assertionsDisabled || xmlOptions != null) {
                this._prettyIndent = 2;
                if (xmlOptions.hasOption(XmlOptions.SAVE_PRETTY_PRINT_INDENT)) {
                    this._prettyIndent = ((Integer) xmlOptions.get(XmlOptions.SAVE_PRETTY_PRINT_INDENT)).intValue();
                }
                if (xmlOptions.hasOption(XmlOptions.SAVE_PRETTY_PRINT_OFFSET)) {
                    this._prettyOffset = ((Integer) xmlOptions.get(XmlOptions.SAVE_PRETTY_PRINT_OFFSET)).intValue();
                }
                if (xmlOptions.hasOption(XmlOptions.LOAD_SAVE_CDATA_BOOKMARKS)) {
                    this._useCDataBookmarks = true;
                    return;
                }
                return;
            }
            throw new AssertionError();
        }

        public static void spaces(StringBuffer stringBuffer, int i2, int i3) {
            while (true) {
                int i4 = i3 - 1;
                if (i3 > 0) {
                    stringBuffer.insert(i2, ' ');
                    i3 = i4;
                } else {
                    return;
                }
            }
        }

        public static void trim(StringBuffer stringBuffer) {
            int i2 = 0;
            while (i2 < stringBuffer.length() && CharUtil.isWhiteSpace(stringBuffer.charAt(i2))) {
                i2++;
            }
            stringBuffer.delete(0, i2);
            int length = stringBuffer.length();
            while (length > 0 && CharUtil.isWhiteSpace(stringBuffer.charAt(length - 1))) {
                length--;
            }
            stringBuffer.delete(length, stringBuffer.length());
        }

        @Override // org.apache.xmlbeans.impl.store.Saver.SaveCur
        public List getAncestorNamespaces() {
            return this._cur.getAncestorNamespaces();
        }

        @Override // org.apache.xmlbeans.impl.store.Saver.SaveCur
        public String getAttrValue() {
            if ($assertionsDisabled || this._txt == null) {
                return this._cur.getAttrValue();
            }
            throw new AssertionError();
        }

        @Override // org.apache.xmlbeans.impl.store.Saver.SaveCur
        public Object getChars() {
            String str = this._txt;
            if (str != null) {
                this._offSrc = 0;
                this._cchSrc = str.length();
                return this._txt;
            }
            Object chars = this._cur.getChars();
            SaveCur saveCur = this._cur;
            this._offSrc = saveCur._offSrc;
            this._cchSrc = saveCur._cchSrc;
            return chars;
        }

        @Override // org.apache.xmlbeans.impl.store.Saver.SaveCur
        public XmlDocumentProperties getDocProps() {
            return this._cur.getDocProps();
        }

        @Override // org.apache.xmlbeans.impl.store.Saver.SaveCur
        public QName getName() {
            if ($assertionsDisabled || this._txt == null) {
                return this._cur.getName();
            }
            throw new AssertionError();
        }

        @Override // org.apache.xmlbeans.impl.store.Saver.SaveCur
        public String getXmlnsPrefix() {
            if ($assertionsDisabled || this._txt == null) {
                return this._cur.getXmlnsPrefix();
            }
            throw new AssertionError();
        }

        @Override // org.apache.xmlbeans.impl.store.Saver.SaveCur
        public String getXmlnsUri() {
            if ($assertionsDisabled || this._txt == null) {
                return this._cur.getXmlnsUri();
            }
            throw new AssertionError();
        }

        @Override // org.apache.xmlbeans.impl.store.Saver.SaveCur
        public boolean hasChildren() {
            if (this._txt == null) {
                return this._cur.hasChildren();
            }
            return false;
        }

        @Override // org.apache.xmlbeans.impl.store.Saver.SaveCur
        public boolean hasText() {
            if (this._txt == null) {
                return this._cur.hasText();
            }
            return false;
        }

        @Override // org.apache.xmlbeans.impl.store.Saver.SaveCur
        public boolean isTextCData() {
            if (this._txt == null) {
                return this._useCDataBookmarks && this._cur.isTextCData();
            }
            return this._isTextCData;
        }

        @Override // org.apache.xmlbeans.impl.store.Saver.SaveCur
        public boolean isXmlns() {
            if (this._txt == null) {
                return this._cur.isXmlns();
            }
            return false;
        }

        @Override // org.apache.xmlbeans.impl.store.Saver.SaveCur
        public int kind() {
            if (this._txt == null) {
                return this._cur.kind();
            }
            return 0;
        }

        @Override // org.apache.xmlbeans.impl.store.Saver.SaveCur
        public boolean next() {
            String str = this._txt;
            int i2 = 0;
            if (str == null) {
                int kind = this._cur.kind();
                if (!this._cur.next()) {
                    return false;
                }
                StringBuffer stringBuffer = this._sb;
                stringBuffer.delete(0, stringBuffer.length());
                if ($assertionsDisabled || this._txt == null) {
                    if (this._cur.isText()) {
                        this._isTextCData = this._useCDataBookmarks && this._cur.isTextCData();
                        StringBuffer stringBuffer2 = this._sb;
                        Object chars = this._cur.getChars();
                        SaveCur saveCur = this._cur;
                        CharUtil.getString(stringBuffer2, chars, saveCur._offSrc, saveCur._cchSrc);
                        this._cur.next();
                        trim(this._sb);
                    }
                    int kind2 = this._cur.kind();
                    if (!(this._prettyIndent < 0 || kind == 4 || kind == 5 || (kind == 2 && kind2 == -2))) {
                        if (this._sb.length() > 0) {
                            this._sb.insert(0, Saver._newLine);
                            spaces(this._sb, Saver._newLine.length(), (this._prettyIndent * this._depth) + this._prettyOffset);
                        }
                        if (kind2 != -1) {
                            if (kind != 1) {
                                this._sb.append(Saver._newLine);
                            }
                            int i3 = this._depth;
                            if (kind2 < 0) {
                                i3--;
                            }
                            StringBuffer stringBuffer3 = this._sb;
                            spaces(stringBuffer3, stringBuffer3.length(), (this._prettyIndent * i3) + this._prettyOffset);
                        }
                    }
                    if (this._sb.length() > 0) {
                        this._txt = this._sb.toString();
                    } else {
                        i2 = kind2;
                    }
                } else {
                    throw new AssertionError();
                }
            } else if (!$assertionsDisabled && str.length() <= 0) {
                throw new AssertionError();
            } else if ($assertionsDisabled || !this._cur.isText()) {
                this._txt = null;
                this._isTextCData = false;
                i2 = this._cur.kind();
            } else {
                throw new AssertionError();
            }
            if (i2 == 2) {
                this._depth++;
            } else if (i2 == -2) {
                this._depth--;
            }
            return true;
        }

        @Override // org.apache.xmlbeans.impl.store.Saver.SaveCur
        public void pop() {
            this._cur.pop();
            ArrayList arrayList = this._stack;
            this._depth = ((Integer) arrayList.remove(arrayList.size() - 1)).intValue();
            ArrayList arrayList2 = this._stack;
            this._txt = (String) arrayList2.remove(arrayList2.size() - 1);
            this._isTextCData = false;
        }

        @Override // org.apache.xmlbeans.impl.store.Saver.SaveCur
        public void push() {
            this._cur.push();
            this._stack.add(this._txt);
            this._stack.add(new Integer(this._depth));
            this._isTextCData = false;
        }

        @Override // org.apache.xmlbeans.impl.store.Saver.SaveCur
        public void release() {
            this._cur.release();
        }

        @Override // org.apache.xmlbeans.impl.store.Saver.SaveCur
        public void toEnd() {
            if ($assertionsDisabled || this._txt == null) {
                this._cur.toEnd();
                if (this._cur.kind() == -2) {
                    this._depth--;
                    return;
                }
                return;
            }
            throw new AssertionError();
        }

        @Override // org.apache.xmlbeans.impl.store.Saver.SaveCur
        public boolean toFirstAttr() {
            if ($assertionsDisabled || this._txt == null) {
                return this._cur.toFirstAttr();
            }
            throw new AssertionError();
        }

        @Override // org.apache.xmlbeans.impl.store.Saver.SaveCur
        public boolean toNextAttr() {
            if ($assertionsDisabled || this._txt == null) {
                return this._cur.toNextAttr();
            }
            throw new AssertionError();
        }
    }

    public static abstract class SaveCur {
        public int _cchSrc;
        public int _offSrc;

        public abstract List getAncestorNamespaces();

        public abstract String getAttrValue();

        public abstract Object getChars();

        public abstract XmlDocumentProperties getDocProps();

        public abstract QName getName();

        public abstract String getXmlnsPrefix();

        public abstract String getXmlnsUri();

        public abstract boolean hasChildren();

        public abstract boolean hasText();

        public final boolean isAttr() {
            return kind() == 3;
        }

        public final boolean isComment() {
            return kind() == 4;
        }

        public final boolean isContainer() {
            return Cur.kindIsContainer(kind());
        }

        public final boolean isElem() {
            return kind() == 2;
        }

        public final boolean isFinish() {
            return Cur.kindIsFinish(kind());
        }

        public final boolean isNormalAttr() {
            return kind() == 3 && !isXmlns();
        }

        public final boolean isProcinst() {
            return kind() == 5;
        }

        public final boolean isRoot() {
            return kind() == 1;
        }

        public final boolean isText() {
            return kind() == 0;
        }

        public abstract boolean isTextCData();

        public abstract boolean isXmlns();

        public abstract int kind();

        public abstract boolean next();

        public abstract void pop();

        public abstract void push();

        public abstract void release();

        public final boolean skip() {
            toEnd();
            return next();
        }

        public abstract void toEnd();

        public abstract boolean toFirstAttr();

        public abstract boolean toNextAttr();
    }

    public static final class SaxSaver extends Saver {
        public static final /* synthetic */ boolean $assertionsDisabled;
        public AttributesImpl _attributes = new AttributesImpl();
        public char[] _buf;
        public ContentHandler _contentHandler;
        public LexicalHandler _lexicalHandler;
        public boolean _nsAsAttrs;

        public class SaverSAXException extends RuntimeException {
            public SAXException _saxException;

            public SaverSAXException(SAXException sAXException) {
                this._saxException = sAXException;
            }
        }

        static {
            Class cls = Saver.class$org$apache$xmlbeans$impl$store$Saver;
            if (cls == null) {
                cls = Saver.class$("org.apache.xmlbeans.impl.store.Saver");
                Saver.class$org$apache$xmlbeans$impl$store$Saver = cls;
            }
            $assertionsDisabled = !cls.desiredAssertionStatus();
        }

        public SaxSaver(Cur cur, XmlOptions xmlOptions, ContentHandler contentHandler, LexicalHandler lexicalHandler) {
            super(cur, xmlOptions);
            this._contentHandler = contentHandler;
            this._lexicalHandler = lexicalHandler;
            this._nsAsAttrs = !xmlOptions.hasOption(XmlOptions.SAVE_SAX_NO_NSDECLS_IN_ATTRIBUTES);
            this._contentHandler.startDocument();
            do {
                try {
                } catch (SaverSAXException e2) {
                    throw e2._saxException;
                }
            } while (process());
            this._contentHandler.endDocument();
        }

        private void emitNamespacesHelper() {
            iterateMappings();
            while (hasMapping()) {
                String mappingPrefix = mappingPrefix();
                String mappingUri = mappingUri();
                try {
                    this._contentHandler.startPrefixMapping(mappingPrefix, mappingUri);
                    if (this._nsAsAttrs) {
                        if (mappingPrefix == null || mappingPrefix.length() == 0) {
                            this._attributes.addAttribute("http://www.w3.org/2000/xmlns/", "xmlns", "xmlns", "CDATA", mappingUri);
                        } else {
                            this._attributes.addAttribute("http://www.w3.org/2000/xmlns/", mappingPrefix, a.a(Sax2Dom.XMLNS_STRING, mappingPrefix), "CDATA", mappingUri);
                        }
                    }
                    nextMapping();
                } catch (SAXException e2) {
                    throw new SaverSAXException(e2);
                }
            }
        }

        private String getPrefixedName(QName qName) {
            String namespaceURI = qName.getNamespaceURI();
            String localPart = qName.getLocalPart();
            if (namespaceURI.length() == 0) {
                return localPart;
            }
            String uriMapping = getUriMapping(namespaceURI);
            if (uriMapping.length() == 0) {
                return localPart;
            }
            return a.a(uriMapping, ":", localPart);
        }

        @Override // org.apache.xmlbeans.impl.store.Saver
        public void emitComment(SaveCur saveCur) {
            if (this._lexicalHandler != null) {
                saveCur.push();
                saveCur.next();
                try {
                    if (!saveCur.isText()) {
                        this._lexicalHandler.comment(null, 0, 0);
                    } else {
                        Object chars = saveCur.getChars();
                        if (chars instanceof char[]) {
                            this._lexicalHandler.comment((char[]) chars, saveCur._offSrc, saveCur._cchSrc);
                        } else {
                            if (this._buf == null || this._buf.length < saveCur._cchSrc) {
                                this._buf = new char[Math.max(1024, saveCur._cchSrc)];
                            }
                            CharUtil.getChars(this._buf, 0, chars, saveCur._offSrc, saveCur._cchSrc);
                            this._lexicalHandler.comment(this._buf, 0, saveCur._cchSrc);
                        }
                    }
                    saveCur.pop();
                } catch (SAXException e2) {
                    throw new SaverSAXException(e2);
                }
            }
        }

        @Override // org.apache.xmlbeans.impl.store.Saver
        public void emitDocType(String str, String str2, String str3) {
            LexicalHandler lexicalHandler = this._lexicalHandler;
            if (lexicalHandler != null) {
                try {
                    lexicalHandler.startDTD(str, str2, str3);
                    this._lexicalHandler.endDTD();
                } catch (SAXException e2) {
                    throw new SaverSAXException(e2);
                }
            }
        }

        @Override // org.apache.xmlbeans.impl.store.Saver
        public boolean emitElement(SaveCur saveCur, ArrayList arrayList, ArrayList arrayList2) {
            this._attributes.clear();
            if (saveNamespacesFirst()) {
                emitNamespacesHelper();
            }
            for (int i2 = 0; i2 < arrayList.size(); i2++) {
                QName qName = (QName) arrayList.get(i2);
                this._attributes.addAttribute(qName.getNamespaceURI(), qName.getLocalPart(), getPrefixedName(qName), "CDATA", (String) arrayList2.get(i2));
            }
            if (!saveNamespacesFirst()) {
                emitNamespacesHelper();
            }
            QName name = saveCur.getName();
            try {
                this._contentHandler.startElement(name.getNamespaceURI(), name.getLocalPart(), getPrefixedName(name), this._attributes);
                return false;
            } catch (SAXException e2) {
                throw new SaverSAXException(e2);
            }
        }

        @Override // org.apache.xmlbeans.impl.store.Saver
        public void emitEndDoc(SaveCur saveCur) {
        }

        @Override // org.apache.xmlbeans.impl.store.Saver
        public void emitFinish(SaveCur saveCur) {
            QName name = saveCur.getName();
            try {
                this._contentHandler.endElement(name.getNamespaceURI(), name.getLocalPart(), getPrefixedName(name));
                iterateMappings();
                while (hasMapping()) {
                    this._contentHandler.endPrefixMapping(mappingPrefix());
                    nextMapping();
                }
            } catch (SAXException e2) {
                throw new SaverSAXException(e2);
            }
        }

        @Override // org.apache.xmlbeans.impl.store.Saver
        public void emitProcinst(SaveCur saveCur) {
            saveCur.getName().getLocalPart();
            saveCur.push();
            saveCur.next();
            String string = CharUtil.getString(saveCur.getChars(), saveCur._offSrc, saveCur._cchSrc);
            saveCur.pop();
            try {
                this._contentHandler.processingInstruction(saveCur.getName().getLocalPart(), string);
            } catch (SAXException e2) {
                throw new SaverSAXException(e2);
            }
        }

        @Override // org.apache.xmlbeans.impl.store.Saver
        public void emitStartDoc(SaveCur saveCur) {
        }

        @Override // org.apache.xmlbeans.impl.store.Saver
        public void emitText(SaveCur saveCur) {
            if ($assertionsDisabled || saveCur.isText()) {
                Object chars = saveCur.getChars();
                try {
                    if (chars instanceof char[]) {
                        this._contentHandler.characters((char[]) chars, saveCur._offSrc, saveCur._cchSrc);
                        return;
                    }
                    if (this._buf == null) {
                        this._buf = new char[1024];
                    }
                    while (saveCur._cchSrc > 0) {
                        int min = Math.min(this._buf.length, saveCur._cchSrc);
                        CharUtil.getChars(this._buf, 0, chars, saveCur._offSrc, min);
                        this._contentHandler.characters(this._buf, 0, min);
                        saveCur._offSrc += min;
                        saveCur._cchSrc -= min;
                    }
                } catch (SAXException e2) {
                    throw new SaverSAXException(e2);
                }
            } else {
                throw new AssertionError();
            }
        }
    }

    public static final class SynthNamespaceSaver extends Saver {
        public LinkedHashMap _synthNamespaces = new LinkedHashMap();

        public SynthNamespaceSaver(Cur cur, XmlOptions xmlOptions) {
            super(cur, xmlOptions);
        }

        @Override // org.apache.xmlbeans.impl.store.Saver
        public void emitComment(SaveCur saveCur) {
        }

        @Override // org.apache.xmlbeans.impl.store.Saver
        public void emitDocType(String str, String str2, String str3) {
        }

        @Override // org.apache.xmlbeans.impl.store.Saver
        public boolean emitElement(SaveCur saveCur, ArrayList arrayList, ArrayList arrayList2) {
            return false;
        }

        @Override // org.apache.xmlbeans.impl.store.Saver
        public void emitEndDoc(SaveCur saveCur) {
        }

        @Override // org.apache.xmlbeans.impl.store.Saver
        public void emitFinish(SaveCur saveCur) {
        }

        @Override // org.apache.xmlbeans.impl.store.Saver
        public void emitProcinst(SaveCur saveCur) {
        }

        @Override // org.apache.xmlbeans.impl.store.Saver
        public void emitStartDoc(SaveCur saveCur) {
        }

        @Override // org.apache.xmlbeans.impl.store.Saver
        public void emitText(SaveCur saveCur) {
        }

        @Override // org.apache.xmlbeans.impl.store.Saver
        public void syntheticNamespace(String str, String str2, boolean z) {
            LinkedHashMap linkedHashMap = this._synthNamespaces;
            if (z) {
                str = "";
            }
            linkedHashMap.put(str2, str);
        }
    }

    public static final class XmlInputStreamImpl extends GenericXmlInputStream {
        public XmlInputStreamSaver _xmlInputStreamSaver;

        public XmlInputStreamImpl(Cur cur, XmlOptions xmlOptions) {
            XmlInputStreamSaver xmlInputStreamSaver = new XmlInputStreamSaver(cur, xmlOptions);
            this._xmlInputStreamSaver = xmlInputStreamSaver;
            xmlInputStreamSaver.process();
        }

        @Override // org.apache.xmlbeans.impl.common.GenericXmlInputStream
        public XMLEvent nextEvent() {
            return this._xmlInputStreamSaver.dequeue();
        }
    }

    public static final class XmlInputStreamSaver extends Saver {
        public static final /* synthetic */ boolean $assertionsDisabled;
        public XmlEventImpl _in;
        public XmlEventImpl _out;

        public static class ChangePrefixMappingImpl extends XmlEventImpl implements ChangePrefixMapping {
            public String _newUri;
            public String _oldUri;
            public String _prefix;

            public ChangePrefixMappingImpl(String str, String str2, String str3) {
                super(4096);
                this._oldUri = str2;
                this._newUri = str3;
                this._prefix = str;
            }

            @Override // org.apache.xmlbeans.xml.stream.ChangePrefixMapping
            public String getNewNamespaceUri() {
                return this._newUri;
            }

            @Override // org.apache.xmlbeans.xml.stream.ChangePrefixMapping
            public String getOldNamespaceUri() {
                return this._oldUri;
            }

            @Override // org.apache.xmlbeans.xml.stream.ChangePrefixMapping
            public String getPrefix() {
                return this._prefix;
            }
        }

        public static class CharacterDataImpl extends TripletEventImpl implements CharacterData {
            public CharacterDataImpl(Object obj, int i2, int i3) {
                super(16, obj, i2, i3);
            }
        }

        public static class CommentImpl extends TripletEventImpl implements Comment {
            public CommentImpl(Object obj, int i2, int i3) {
                super(32, obj, i2, i3);
            }
        }

        public static class EndDocumentImpl extends XmlEventImpl implements EndDocument {
            public EndDocumentImpl() {
                super(512);
            }
        }

        public static class EndElementImpl extends XmlEventImpl implements EndElement {
            public XMLName _name;

            public EndElementImpl(XMLName xMLName) {
                super(4);
                this._name = xMLName;
            }

            @Override // org.apache.xmlbeans.xml.stream.XMLEvent, org.apache.xmlbeans.impl.store.Saver.XmlInputStreamSaver.XmlEventImpl
            public XMLName getName() {
                return this._name;
            }

            @Override // org.apache.xmlbeans.xml.stream.XMLEvent, org.apache.xmlbeans.impl.store.Saver.XmlInputStreamSaver.XmlEventImpl
            public boolean hasName() {
                return true;
            }
        }

        public static class EndPrefixMappingImpl extends XmlEventImpl implements EndPrefixMapping {
            public String _prefix;

            public EndPrefixMappingImpl(String str) {
                super(2048);
                this._prefix = str;
            }

            @Override // org.apache.xmlbeans.xml.stream.EndPrefixMapping
            public String getPrefix() {
                return this._prefix;
            }
        }

        public static class ProcessingInstructionImpl extends TripletEventImpl implements ProcessingInstruction {
            public String _target;

            public ProcessingInstructionImpl(String str, Object obj, int i2, int i3) {
                super(8, obj, i2, i3);
                this._target = str;
            }

            @Override // org.apache.xmlbeans.xml.stream.ProcessingInstruction
            public String getData() {
                return getContent();
            }

            @Override // org.apache.xmlbeans.xml.stream.ProcessingInstruction
            public String getTarget() {
                return this._target;
            }
        }

        public static class StartDocumentImpl extends XmlEventImpl implements StartDocument {
            public String _encoding;
            public boolean _standAlone;
            public String _systemID;
            public String _version;

            public StartDocumentImpl(String str, String str2, boolean z, String str3) {
                super(256);
                this._systemID = str;
                this._encoding = str2;
                this._standAlone = z;
                this._version = str3;
            }

            @Override // org.apache.xmlbeans.xml.stream.StartDocument
            public String getCharacterEncodingScheme() {
                return this._encoding;
            }

            @Override // org.apache.xmlbeans.xml.stream.StartDocument
            public String getSystemId() {
                return this._systemID;
            }

            @Override // org.apache.xmlbeans.xml.stream.StartDocument
            public String getVersion() {
                return this._version;
            }

            @Override // org.apache.xmlbeans.xml.stream.StartDocument
            public boolean isStandalone() {
                return this._standAlone;
            }
        }

        public static class StartElementImpl extends XmlEventImpl implements StartElement {
            public AttributeImpl _attributes;
            public XMLName _name;
            public AttributeImpl _namespaces;
            public Map _prefixMap;

            public static abstract class AttributeImpl implements Attribute {
                public XMLName _name;
                public AttributeImpl _next;

                @Override // org.apache.xmlbeans.xml.stream.Attribute
                public XMLName getName() {
                    return this._name;
                }

                @Override // org.apache.xmlbeans.xml.stream.Attribute
                public XMLName getSchemaType() {
                    return null;
                }

                @Override // org.apache.xmlbeans.xml.stream.Attribute
                public String getType() {
                    return "CDATA";
                }
            }

            public static class AttributeIteratorImpl implements AttributeIterator {
                public AttributeImpl _attributes;
                public AttributeImpl _namespaces;

                public AttributeIteratorImpl(AttributeImpl attributeImpl, AttributeImpl attributeImpl2) {
                    this._attributes = attributeImpl;
                    this._namespaces = attributeImpl2;
                }

                private final void checkVersion() {
                }

                @Override // org.apache.xmlbeans.xml.stream.AttributeIterator
                public boolean hasNext() {
                    boolean z;
                    synchronized (monitor()) {
                        checkVersion();
                        if (this._attributes == null) {
                            if (this._namespaces == null) {
                                z = false;
                            }
                        }
                        z = true;
                    }
                    return z;
                }

                public Object monitor() {
                    return this;
                }

                @Override // org.apache.xmlbeans.xml.stream.AttributeIterator
                public Attribute next() {
                    AttributeImpl attributeImpl;
                    synchronized (monitor()) {
                        checkVersion();
                        attributeImpl = null;
                        if (this._attributes != null) {
                            attributeImpl = this._attributes;
                            this._attributes = attributeImpl._next;
                        } else if (this._namespaces != null) {
                            attributeImpl = this._namespaces;
                            this._namespaces = attributeImpl._next;
                        }
                    }
                    return attributeImpl;
                }

                @Override // org.apache.xmlbeans.xml.stream.AttributeIterator
                public Attribute peek() {
                    synchronized (monitor()) {
                        checkVersion();
                        if (this._attributes != null) {
                            return this._attributes;
                        } else if (this._namespaces == null) {
                            return null;
                        } else {
                            return this._namespaces;
                        }
                    }
                }

                @Override // org.apache.xmlbeans.xml.stream.AttributeIterator
                public void skip() {
                    synchronized (monitor()) {
                        checkVersion();
                        if (this._attributes != null) {
                            this._attributes = this._attributes._next;
                        } else if (this._namespaces != null) {
                            this._namespaces = this._namespaces._next;
                        }
                    }
                }
            }

            public static class NormalAttributeImpl extends AttributeImpl {
                public String _value;

                public NormalAttributeImpl(XMLName xMLName, String str) {
                    this._name = xMLName;
                    this._value = str;
                }

                @Override // org.apache.xmlbeans.xml.stream.Attribute
                public String getValue() {
                    return this._value;
                }
            }

            public static class XmlnsAttributeImpl extends AttributeImpl {
                public String _uri;

                public XmlnsAttributeImpl(String str, String str2) {
                    this._uri = str2;
                    String str3 = "xmlns";
                    if (str.length() == 0) {
                        str = str3;
                        str3 = null;
                    }
                    this._name = new XmlNameImpl(null, str, str3);
                }

                @Override // org.apache.xmlbeans.xml.stream.Attribute
                public String getValue() {
                    return this._uri;
                }
            }

            public StartElementImpl(XMLName xMLName, AttributeImpl attributeImpl, AttributeImpl attributeImpl2, Map map) {
                super(2);
                this._name = xMLName;
                this._attributes = attributeImpl;
                this._namespaces = attributeImpl2;
                this._prefixMap = map;
            }

            @Override // org.apache.xmlbeans.xml.stream.StartElement
            public Attribute getAttributeByName(XMLName xMLName) {
                for (AttributeImpl attributeImpl = this._attributes; attributeImpl != null; attributeImpl = attributeImpl._next) {
                    if (xMLName.equals(attributeImpl.getName())) {
                        return attributeImpl;
                    }
                }
                return null;
            }

            @Override // org.apache.xmlbeans.xml.stream.StartElement
            public AttributeIterator getAttributes() {
                return new AttributeIteratorImpl(this._attributes, null);
            }

            @Override // org.apache.xmlbeans.xml.stream.StartElement
            public AttributeIterator getAttributesAndNamespaces() {
                return new AttributeIteratorImpl(this._attributes, this._namespaces);
            }

            @Override // org.apache.xmlbeans.xml.stream.XMLEvent, org.apache.xmlbeans.impl.store.Saver.XmlInputStreamSaver.XmlEventImpl
            public XMLName getName() {
                return this._name;
            }

            @Override // org.apache.xmlbeans.xml.stream.StartElement
            public Map getNamespaceMap() {
                return this._prefixMap;
            }

            @Override // org.apache.xmlbeans.xml.stream.StartElement
            public String getNamespaceUri(String str) {
                Map map = this._prefixMap;
                if (str == null) {
                    str = "";
                }
                return (String) map.get(str);
            }

            @Override // org.apache.xmlbeans.xml.stream.StartElement
            public AttributeIterator getNamespaces() {
                return new AttributeIteratorImpl(null, this._namespaces);
            }

            @Override // org.apache.xmlbeans.xml.stream.XMLEvent, org.apache.xmlbeans.impl.store.Saver.XmlInputStreamSaver.XmlEventImpl
            public boolean hasName() {
                return true;
            }
        }

        public static class StartPrefixMappingImpl extends XmlEventImpl implements StartPrefixMapping {
            public String _prefix;
            public String _uri;

            public StartPrefixMappingImpl(String str, String str2) {
                super(1024);
                this._prefix = str;
                this._uri = str2;
            }

            @Override // org.apache.xmlbeans.xml.stream.StartPrefixMapping
            public String getNamespaceUri() {
                return this._uri;
            }

            @Override // org.apache.xmlbeans.xml.stream.StartPrefixMapping
            public String getPrefix() {
                return this._prefix;
            }
        }

        public static class TripletEventImpl extends XmlEventImpl implements CharacterData {
            public int _cch;
            public Object _obj;
            public int _off;

            public TripletEventImpl(int i2, Object obj, int i3, int i4) {
                super(i2);
                this._obj = obj;
                this._cch = i3;
                this._off = i4;
            }

            @Override // org.apache.xmlbeans.xml.stream.CharacterData
            public String getContent() {
                return CharUtil.getString(this._obj, this._off, this._cch);
            }

            @Override // org.apache.xmlbeans.xml.stream.CharacterData
            public boolean hasContent() {
                return this._cch > 0;
            }
        }

        public static abstract class XmlEventImpl extends XmlEventBase {
            public XmlEventImpl _next;

            public XmlEventImpl(int i2) {
                super(i2);
            }

            @Override // org.apache.xmlbeans.xml.stream.XMLEvent
            public final Location getLocation() {
                return null;
            }

            @Override // org.apache.xmlbeans.xml.stream.XMLEvent
            public XMLName getName() {
                return null;
            }

            @Override // org.apache.xmlbeans.xml.stream.XMLEvent
            public XMLName getSchemaType() {
                throw new RuntimeException("NYI");
            }

            @Override // org.apache.xmlbeans.xml.stream.XMLEvent
            public boolean hasName() {
                return false;
            }
        }

        static {
            Class cls = Saver.class$org$apache$xmlbeans$impl$store$Saver;
            if (cls == null) {
                cls = Saver.class$("org.apache.xmlbeans.impl.store.Saver");
                Saver.class$org$apache$xmlbeans$impl$store$Saver = cls;
            }
            $assertionsDisabled = !cls.desiredAssertionStatus();
        }

        public XmlInputStreamSaver(Cur cur, XmlOptions xmlOptions) {
            super(cur, xmlOptions);
        }

        public static XMLName computeName(QName qName, Saver saver, boolean z) {
            String namespaceURI = qName.getNamespaceURI();
            String localPart = qName.getLocalPart();
            if (!$assertionsDisabled && namespaceURI == null) {
                throw new AssertionError();
            } else if ($assertionsDisabled || localPart.length() > 0) {
                String str = null;
                if (!(namespaceURI == null || namespaceURI.length() == 0)) {
                    String prefix = qName.getPrefix();
                    String namespaceForPrefix = saver.getNamespaceForPrefix(prefix);
                    if (namespaceForPrefix == null || !namespaceForPrefix.equals(namespaceURI)) {
                        prefix = saver.getUriMapping(namespaceURI);
                    }
                    str = prefix;
                    if (z && str.length() == 0) {
                        str = saver.getNonDefaultUriMapping(namespaceURI);
                    }
                }
                return new XmlNameImpl(namespaceURI, localPart, str);
            } else {
                throw new AssertionError();
            }
        }

        private void enqueue(XmlEventImpl xmlEventImpl) {
            if ($assertionsDisabled || xmlEventImpl._next == null) {
                XmlEventImpl xmlEventImpl2 = this._in;
                if (xmlEventImpl2 != null) {
                    xmlEventImpl2._next = xmlEventImpl;
                    this._in = xmlEventImpl;
                } else if ($assertionsDisabled || this._out == null) {
                    this._in = xmlEventImpl;
                    this._out = xmlEventImpl;
                } else {
                    throw new AssertionError();
                }
            } else {
                throw new AssertionError();
            }
        }

        public XMLEvent dequeue() {
            if (this._out == null) {
                enterLocale();
                try {
                    if (!process()) {
                        return null;
                    }
                    exitLocale();
                } finally {
                    exitLocale();
                }
            }
            XmlEventImpl xmlEventImpl = this._out;
            if (xmlEventImpl == null) {
                return null;
            }
            XmlEventImpl xmlEventImpl2 = xmlEventImpl._next;
            this._out = xmlEventImpl2;
            if (xmlEventImpl2 == null) {
                this._in = null;
            }
            return xmlEventImpl;
        }

        @Override // org.apache.xmlbeans.impl.store.Saver
        public void emitComment(SaveCur saveCur) {
            enqueue(new CommentImpl(saveCur.getChars(), saveCur._cchSrc, saveCur._offSrc));
        }

        @Override // org.apache.xmlbeans.impl.store.Saver
        public void emitDocType(String str, String str2, String str3) {
            enqueue(new StartDocumentImpl(str3, null, true, null));
        }

        @Override // org.apache.xmlbeans.impl.store.Saver
        public boolean emitElement(SaveCur saveCur, ArrayList arrayList, ArrayList arrayList2) {
            if ($assertionsDisabled || saveCur.isElem()) {
                iterateMappings();
                while (hasMapping()) {
                    enqueue(new StartPrefixMappingImpl(mappingPrefix(), mappingUri()));
                    nextMapping();
                }
                StartElementImpl.XmlnsAttributeImpl xmlnsAttributeImpl = null;
                StartElementImpl.NormalAttributeImpl normalAttributeImpl = null;
                StartElementImpl.NormalAttributeImpl normalAttributeImpl2 = null;
                int i2 = 0;
                while (i2 < arrayList.size()) {
                    StartElementImpl.NormalAttributeImpl normalAttributeImpl3 = new StartElementImpl.NormalAttributeImpl(computeName((QName) arrayList.get(i2), this, true), (String) arrayList2.get(i2));
                    if (normalAttributeImpl == null) {
                        normalAttributeImpl = normalAttributeImpl3;
                    } else {
                        normalAttributeImpl2._next = normalAttributeImpl3;
                    }
                    i2++;
                    normalAttributeImpl2 = normalAttributeImpl3;
                }
                iterateMappings();
                StartElementImpl.XmlnsAttributeImpl xmlnsAttributeImpl2 = null;
                while (hasMapping()) {
                    StartElementImpl.XmlnsAttributeImpl xmlnsAttributeImpl3 = new StartElementImpl.XmlnsAttributeImpl(mappingPrefix(), mappingUri());
                    if (xmlnsAttributeImpl == null) {
                        xmlnsAttributeImpl = xmlnsAttributeImpl3;
                    } else {
                        xmlnsAttributeImpl2._next = xmlnsAttributeImpl3;
                    }
                    nextMapping();
                    xmlnsAttributeImpl2 = xmlnsAttributeImpl3;
                }
                enqueue(new StartElementImpl(computeName(saveCur.getName(), this, false), normalAttributeImpl, xmlnsAttributeImpl, getPrefixMap()));
                return false;
            }
            throw new AssertionError();
        }

        @Override // org.apache.xmlbeans.impl.store.Saver
        public void emitEndDoc(SaveCur saveCur) {
            enqueue(new EndDocumentImpl());
        }

        public void emitEndPrefixMappings() {
            iterateMappings();
            while (hasMapping()) {
                String mappingPrefix = mappingPrefix();
                mappingUri();
                enqueue(new EndPrefixMappingImpl(mappingPrefix));
                nextMapping();
            }
        }

        @Override // org.apache.xmlbeans.impl.store.Saver
        public void emitFinish(SaveCur saveCur) {
            if (saveCur.isRoot()) {
                enqueue(new EndDocumentImpl());
            } else {
                enqueue(new EndElementImpl(computeName(saveCur.getName(), this, false)));
            }
            emitEndPrefixMappings();
        }

        @Override // org.apache.xmlbeans.impl.store.Saver
        public void emitProcinst(SaveCur saveCur) {
            QName name = saveCur.getName();
            enqueue(new ProcessingInstructionImpl(name != null ? name.getLocalPart() : null, saveCur.getChars(), saveCur._cchSrc, saveCur._offSrc));
        }

        @Override // org.apache.xmlbeans.impl.store.Saver
        public void emitStartDoc(SaveCur saveCur) {
            emitDocType(null, null, null);
        }

        @Override // org.apache.xmlbeans.impl.store.Saver
        public void emitText(SaveCur saveCur) {
            if ($assertionsDisabled || saveCur.isText()) {
                enqueue(new CharacterDataImpl(saveCur.getChars(), saveCur._cchSrc, saveCur._offSrc));
                return;
            }
            throw new AssertionError();
        }
    }

    static {
        Class cls = class$org$apache$xmlbeans$impl$store$Saver;
        if (cls == null) {
            cls = class$("org.apache.xmlbeans.impl.store.Saver");
            class$org$apache$xmlbeans$impl$store$Saver = cls;
        }
        $assertionsDisabled = !cls.desiredAssertionStatus();
    }

    public Saver(Cur cur, XmlOptions xmlOptions) {
        if ($assertionsDisabled || cur._locale.entered()) {
            XmlOptions maskNull = XmlOptions.maskNull(xmlOptions);
            this._cur = createSaveCur(cur, maskNull);
            Locale locale = cur._locale;
            this._locale = locale;
            this._version = locale.version();
            this._namespaceStack = new ArrayList();
            this._uriMap = new HashMap();
            this._prefixMap = new HashMap();
            this._attrNames = new ArrayList();
            this._attrValues = new ArrayList();
            addMapping("xml", "http://www.w3.org/XML/1998/namespace");
            if (maskNull.hasOption(XmlOptions.SAVE_IMPLICIT_NAMESPACES)) {
                Map map = (Map) maskNull.get(XmlOptions.SAVE_IMPLICIT_NAMESPACES);
                for (String str : map.keySet()) {
                    addMapping(str, (String) map.get(str));
                }
            }
            if (maskNull.hasOption(XmlOptions.SAVE_SUBSTITUTE_CHARACTERS)) {
                this._replaceChar = (XmlOptionCharEscapeMap) maskNull.get(XmlOptions.SAVE_SUBSTITUTE_CHARACTERS);
            }
            if (getNamespaceForPrefix("") == null) {
                String str2 = new String("");
                this._initialDefaultUri = str2;
                addMapping("", str2);
            }
            if (maskNull.hasOption(XmlOptions.SAVE_AGGRESSIVE_NAMESPACES) && !(this instanceof SynthNamespaceSaver)) {
                SynthNamespaceSaver synthNamespaceSaver = new SynthNamespaceSaver(cur, maskNull);
                do {
                } while (synthNamespaceSaver.process());
                if (!synthNamespaceSaver._synthNamespaces.isEmpty()) {
                    this._preComputedNamespaces = synthNamespaceSaver._synthNamespaces;
                }
            }
            this._useDefaultNamespace = maskNull.hasOption(XmlOptions.SAVE_USE_DEFAULT_NAMESPACE);
            this._saveNamespacesFirst = maskNull.hasOption(XmlOptions.SAVE_NAMESPACES_FIRST);
            if (maskNull.hasOption(XmlOptions.SAVE_SUGGESTED_PREFIXES)) {
                this._suggestedPrefixes = (Map) maskNull.get(XmlOptions.SAVE_SUGGESTED_PREFIXES);
            }
            this._ancestorNamespaces = this._cur.getAncestorNamespaces();
            return;
        }
        throw new AssertionError();
    }

    private final void addMapping(String str, String str2) {
        String str3;
        if (!$assertionsDisabled && str2 == null) {
            throw new AssertionError();
        } else if ($assertionsDisabled || str != null) {
            String str4 = (String) this._prefixMap.get(str);
            if (str4 == null) {
                str3 = null;
            } else if (str4.equals(str2)) {
                str4 = null;
                str3 = null;
            } else {
                int size = this._namespaceStack.size();
                str3 = null;
                while (size > 0) {
                    if (this._namespaceStack.get(size - 1) != null) {
                        if (this._namespaceStack.get(size - 7).equals(str4) && ((str3 = (String) this._namespaceStack.get(size - 8)) == null || !str3.equals(str))) {
                            break;
                        }
                        size -= 8;
                    } else {
                        size--;
                    }
                }
                if (!$assertionsDisabled && size <= 0) {
                    throw new AssertionError();
                }
            }
            this._namespaceStack.add(this._uriMap.get(str2));
            this._namespaceStack.add(str2);
            if (str4 != null) {
                this._namespaceStack.add(this._uriMap.get(str4));
                this._namespaceStack.add(str4);
            } else {
                this._namespaceStack.add(null);
                this._namespaceStack.add(null);
            }
            this._namespaceStack.add(str);
            this._namespaceStack.add(this._prefixMap.get(str));
            this._namespaceStack.add(str);
            this._namespaceStack.add(str2);
            this._uriMap.put(str2, str);
            this._prefixMap.put(str, str2);
            if (str4 != null) {
                this._uriMap.put(str4, str3);
            }
        } else {
            throw new AssertionError();
        }
    }

    private final void addNewFrameMapping(String str, String str2, boolean z) {
        if (str.length() != 0 && str2.length() <= 0) {
            return;
        }
        if (!z || str.length() > 0 || str2.length() == 0) {
            iterateMappings();
            while (hasMapping()) {
                if (!mappingPrefix().equals(str)) {
                    nextMapping();
                } else {
                    return;
                }
            }
            if (!str2.equals(getNamespaceForPrefix(str))) {
                addMapping(str, str2);
            }
        }
    }

    public static /* synthetic */ Class class$(String str) {
        try {
            return Class.forName(str);
        } catch (ClassNotFoundException e2) {
            throw a.a(e2);
        }
    }

    public static SaveCur createSaveCur(Cur cur, XmlOptions xmlOptions) {
        QName qName = (QName) xmlOptions.get(XmlOptions.SAVE_SYNTHETIC_DOCUMENT_ELEMENT);
        QName qName2 = qName == null ? xmlOptions.hasOption(XmlOptions.SAVE_USE_OPEN_FRAGMENT) ? Locale._openuriFragment : Locale._xmlFragment : qName;
        boolean z = xmlOptions.hasOption(XmlOptions.SAVE_INNER) && !xmlOptions.hasOption(XmlOptions.SAVE_OUTER);
        Cur tempCur = cur.tempCur();
        Cur tempCur2 = cur.tempCur();
        int kind = cur.kind();
        FilterPiSaveCur filterPiSaveCur = null;
        if (kind == 1) {
            positionToInner(cur, tempCur, tempCur2);
            if (Locale.isFragment(tempCur, tempCur2)) {
                filterPiSaveCur = new FragSaveCur(tempCur, tempCur2, qName2);
            } else if (qName != null) {
                filterPiSaveCur = new FragSaveCur(tempCur, tempCur2, qName);
            } else {
                filterPiSaveCur = new DocSaveCur(cur);
            }
        } else if (kind == 2) {
            if (z) {
                positionToInner(cur, tempCur, tempCur2);
                if (Locale.isFragment(tempCur, tempCur2)) {
                    qName = qName2;
                }
                filterPiSaveCur = new FragSaveCur(tempCur, tempCur2, qName);
            } else if (qName != null) {
                positionToInner(cur, tempCur, tempCur2);
                filterPiSaveCur = new FragSaveCur(tempCur, tempCur2, qName);
            } else {
                tempCur.moveToCur(cur);
                tempCur2.moveToCur(cur);
                tempCur2.skip();
                filterPiSaveCur = new FragSaveCur(tempCur, tempCur2, null);
            }
        }
        if (filterPiSaveCur == null) {
            if ($assertionsDisabled || kind < 0 || kind == 3 || kind == 4 || kind == 5 || kind == 0) {
                if (kind < 0) {
                    tempCur.moveToCur(cur);
                    tempCur2.moveToCur(cur);
                } else if (kind == 0) {
                    tempCur.moveToCur(cur);
                    tempCur2.moveToCur(cur);
                    tempCur2.next();
                } else if (z) {
                    tempCur.moveToCur(cur);
                    tempCur.next();
                    tempCur2.moveToCur(cur);
                    tempCur2.toEnd();
                } else if (kind == 3) {
                    tempCur.moveToCur(cur);
                    tempCur2.moveToCur(cur);
                } else if ($assertionsDisabled || kind == 4 || kind == 5) {
                    tempCur.moveToCur(cur);
                    tempCur2.moveToCur(cur);
                    tempCur2.skip();
                } else {
                    throw new AssertionError();
                }
                filterPiSaveCur = new FragSaveCur(tempCur, tempCur2, qName2);
            } else {
                throw new AssertionError();
            }
        }
        String str = (String) xmlOptions.get(XmlOptions.SAVE_FILTER_PROCINST);
        if (str != null) {
            filterPiSaveCur = new FilterPiSaveCur(filterPiSaveCur, str);
        }
        if (xmlOptions.hasOption(XmlOptions.SAVE_PRETTY_PRINT)) {
            filterPiSaveCur = new PrettySaveCur(filterPiSaveCur, xmlOptions);
        }
        tempCur.release();
        tempCur2.release();
        return filterPiSaveCur;
    }

    private final void dumpMappings() {
        int size = this._namespaceStack.size();
        while (size > 0) {
            int i2 = size - 1;
            if (this._namespaceStack.get(i2) == null) {
                System.out.println("----------------");
                size--;
            } else {
                System.out.print("Mapping: ");
                System.out.print(this._namespaceStack.get(size - 2));
                System.out.print(" -> ");
                System.out.print(this._namespaceStack.get(i2));
                System.out.println();
                System.out.print("Prefix Undo: ");
                System.out.print(this._namespaceStack.get(size - 4));
                System.out.print(" -> ");
                System.out.print(this._namespaceStack.get(size - 3));
                System.out.println();
                System.out.print("Uri Rename: ");
                System.out.print(this._namespaceStack.get(size - 5));
                System.out.print(" -> ");
                System.out.print(this._namespaceStack.get(size - 6));
                System.out.println();
                System.out.print("UriUndo: ");
                System.out.print(this._namespaceStack.get(size - 7));
                System.out.print(" -> ");
                System.out.print(this._namespaceStack.get(size - 8));
                System.out.println();
                System.out.println();
                size -= 8;
            }
        }
    }

    private final String ensureMapping(String str, String str2, boolean z, boolean z2) {
        if (!$assertionsDisabled && str == null) {
            throw new AssertionError();
        } else if (str.length() == 0) {
            return null;
        } else {
            String str3 = (String) this._uriMap.get(str);
            if (str3 != null && (str3.length() > 0 || !z2)) {
                return str3;
            }
            if (str2 != null && str2.length() == 0) {
                str2 = null;
            }
            String str4 = "";
            if (str2 == null || !tryPrefix(str2)) {
                Map map = this._suggestedPrefixes;
                if (map == null || !map.containsKey(str) || !tryPrefix((String) this._suggestedPrefixes.get(str))) {
                    if (!z || !this._useDefaultNamespace || !tryPrefix(str4)) {
                        String suggestPrefix = QNameHelper.suggestPrefix(str);
                        str4 = suggestPrefix;
                        int i2 = 1;
                        while (!tryPrefix(str4)) {
                            str4 = a.b(suggestPrefix, i2);
                            i2++;
                        }
                    }
                    str2 = str4;
                } else {
                    str2 = (String) this._suggestedPrefixes.get(str);
                }
            }
            if ($assertionsDisabled || str2 != null) {
                syntheticNamespace(str2, str, z);
                addMapping(str2, str);
                return str2;
            }
            throw new AssertionError();
        }
    }

    private final void popMappings() {
        while (true) {
            int size = this._namespaceStack.size();
            if (size != 0) {
                int i2 = size - 1;
                if (this._namespaceStack.get(i2) == null) {
                    this._namespaceStack.remove(i2);
                    return;
                }
                int i3 = size - 7;
                Object obj = this._namespaceStack.get(i3);
                int i4 = size - 8;
                Object obj2 = this._namespaceStack.get(i4);
                if (obj2 == null) {
                    this._uriMap.remove(obj);
                } else {
                    this._uriMap.put(obj, obj2);
                }
                int i5 = size - 4;
                Object obj3 = this._namespaceStack.get(i5);
                int i6 = size - 3;
                Object obj4 = this._namespaceStack.get(i6);
                if (obj4 == null) {
                    this._prefixMap.remove(obj3);
                } else {
                    this._prefixMap.put(obj3, obj4);
                }
                int i7 = size - 5;
                String str = (String) this._namespaceStack.get(i7);
                if (str != null) {
                    this._uriMap.put(str, this._namespaceStack.get(size - 6));
                }
                this._namespaceStack.remove(i2);
                this._namespaceStack.remove(size - 2);
                this._namespaceStack.remove(i6);
                this._namespaceStack.remove(i5);
                this._namespaceStack.remove(i7);
                this._namespaceStack.remove(size - 6);
                this._namespaceStack.remove(i3);
                this._namespaceStack.remove(i4);
            } else {
                return;
            }
        }
    }

    public static void positionToInner(Cur cur, Cur cur2, Cur cur3) {
        if ($assertionsDisabled || cur.isContainer()) {
            cur2.moveToCur(cur);
            if (!cur2.toFirstAttr()) {
                cur2.next();
            }
            cur3.moveToCur(cur);
            cur3.toEnd();
            return;
        }
        throw new AssertionError();
    }

    private final void processElement() {
        if ($assertionsDisabled || (this._cur.isElem() && this._cur.getName() != null)) {
            QName name = this._cur.getName();
            boolean z = name.getNamespaceURI().length() == 0;
            pushMappings(this._cur, z);
            ensureMapping(name.getNamespaceURI(), name.getPrefix(), !z, false);
            this._attrNames.clear();
            this._attrValues.clear();
            this._cur.push();
            boolean firstAttr = this._cur.toFirstAttr();
            while (firstAttr) {
                if (this._cur.isNormalAttr()) {
                    QName name2 = this._cur.getName();
                    this._attrNames.add(name2);
                    int size = this._attrNames.size() - 2;
                    while (true) {
                        if (size < 0) {
                            this._attrValues.add(this._cur.getAttrValue());
                            ensureMapping(name2.getNamespaceURI(), name2.getPrefix(), false, true);
                            break;
                        } else if (this._attrNames.get(size).equals(name2)) {
                            ArrayList arrayList = this._attrNames;
                            arrayList.remove(arrayList.size() - 1);
                            break;
                        } else {
                            size--;
                        }
                    }
                }
                firstAttr = this._cur.toNextAttr();
            }
            this._cur.pop();
            Map map = this._preComputedNamespaces;
            if (map != null) {
                for (String str : map.keySet()) {
                    String str2 = (String) this._preComputedNamespaces.get(str);
                    ensureMapping(str, str2, str2.length() == 0 && !z, false);
                }
                this._preComputedNamespaces = null;
            }
            if (emitElement(this._cur, this._attrNames, this._attrValues)) {
                popMappings();
                this._cur.toEnd();
                return;
            }
            return;
        }
        throw new AssertionError();
    }

    private final void processFinish() {
        emitFinish(this._cur);
        popMappings();
    }

    /* JADX WARNING: Removed duplicated region for block: B:16:0x0039  */
    private final void processRoot() {
        String str;
        if ($assertionsDisabled || this._cur.isRoot()) {
            XmlDocumentProperties docProps = this._cur.getDocProps();
            String str2 = null;
            if (docProps != null) {
                str2 = docProps.getDoctypeSystemId();
                str = docProps.getDoctypeName();
            } else {
                str = null;
            }
            if (!(str2 == null && str == null)) {
                if (str == null) {
                    this._cur.push();
                    while (!this._cur.isElem() && this._cur.next()) {
                        while (!this._cur.isElem()) {
                            while (!this._cur.isElem()) {
                            }
                        }
                    }
                    if (this._cur.isElem()) {
                        str = this._cur.getName().getLocalPart();
                    }
                    this._cur.pop();
                }
                String doctypePublicId = docProps.getDoctypePublicId();
                if (str != null) {
                    QName name = this._cur.getName();
                    if (name == null) {
                        this._cur.push();
                        while (true) {
                            if (this._cur.isFinish()) {
                                break;
                            } else if (this._cur.isElem()) {
                                name = this._cur.getName();
                                break;
                            } else {
                                this._cur.next();
                            }
                        }
                        this._cur.pop();
                    }
                    if (name != null && str.equals(name.getLocalPart())) {
                        emitDocType(str, doctypePublicId, str2);
                        return;
                    }
                }
            }
            emitStartDoc(this._cur);
            return;
        }
        throw new AssertionError();
    }

    private final void pushMappings(SaveCur saveCur, boolean z) {
        if ($assertionsDisabled || saveCur.isContainer()) {
            this._namespaceStack.add(null);
            saveCur.push();
            boolean firstAttr = saveCur.toFirstAttr();
            while (firstAttr) {
                if (saveCur.isXmlns()) {
                    addNewFrameMapping(saveCur.getXmlnsPrefix(), saveCur.getXmlnsUri(), z);
                }
                firstAttr = saveCur.toNextAttr();
            }
            saveCur.pop();
            if (this._ancestorNamespaces != null) {
                for (int i2 = 0; i2 < this._ancestorNamespaces.size(); i2 += 2) {
                    addNewFrameMapping((String) this._ancestorNamespaces.get(i2), (String) this._ancestorNamespaces.get(i2 + 1), z);
                }
                this._ancestorNamespaces = null;
            }
            if (z) {
                String str = (String) this._prefixMap.get("");
                if (!$assertionsDisabled && str == null) {
                    throw new AssertionError();
                } else if (str.length() > 0) {
                    addMapping("", "");
                }
            }
        } else {
            throw new AssertionError();
        }
    }

    private final boolean tryPrefix(String str) {
        if (str == null || Locale.beginsWithXml(str)) {
            return false;
        }
        String str2 = (String) this._prefixMap.get(str);
        if (str2 == null) {
            return true;
        }
        if (str.length() > 0 || str2 != this._initialDefaultUri) {
            return false;
        }
        return true;
    }

    public abstract void emitComment(SaveCur saveCur);

    public abstract void emitDocType(String str, String str2, String str3);

    public abstract boolean emitElement(SaveCur saveCur, ArrayList arrayList, ArrayList arrayList2);

    public abstract void emitEndDoc(SaveCur saveCur);

    public abstract void emitFinish(SaveCur saveCur);

    public abstract void emitProcinst(SaveCur saveCur);

    public abstract void emitStartDoc(SaveCur saveCur);

    public abstract void emitText(SaveCur saveCur);

    public void enterLocale() {
        this._locale.enter();
    }

    public void exitLocale() {
        this._locale.exit();
    }

    public final String getNamespaceForPrefix(String str) {
        if ($assertionsDisabled || !str.equals("xml") || this._prefixMap.get(str).equals("http://www.w3.org/XML/1998/namespace")) {
            return (String) this._prefixMap.get(str);
        }
        throw new AssertionError();
    }

    public String getNonDefaultUriMapping(String str) {
        String str2 = (String) this._uriMap.get(str);
        if (str2 != null && str2.length() > 0) {
            return str2;
        }
        for (String str3 : this._prefixMap.keySet()) {
            if (str3.length() > 0 && this._prefixMap.get(str3).equals(str)) {
                return str3;
            }
        }
        if ($assertionsDisabled) {
            return null;
        }
        throw new AssertionError("Could not find non-default mapping");
    }

    public Map getPrefixMap() {
        return this._prefixMap;
    }

    public final String getUriMapping(String str) {
        if ($assertionsDisabled || this._uriMap.get(str) != null) {
            return (String) this._uriMap.get(str);
        }
        throw new AssertionError();
    }

    public boolean hasMapping() {
        return this._currentMapping < this._namespaceStack.size();
    }

    public boolean hasMappings() {
        int size = this._namespaceStack.size();
        if (size <= 0 || this._namespaceStack.get(size - 1) == null) {
            return false;
        }
        return true;
    }

    public void iterateMappings() {
        this._currentMapping = this._namespaceStack.size();
        while (true) {
            int i2 = this._currentMapping;
            if (i2 > 0 && this._namespaceStack.get(i2 - 1) != null) {
                this._currentMapping -= 8;
            } else {
                return;
            }
        }
    }

    public String mappingPrefix() {
        if ($assertionsDisabled || hasMapping()) {
            return (String) this._namespaceStack.get(this._currentMapping + 6);
        }
        throw new AssertionError();
    }

    public String mappingUri() {
        if ($assertionsDisabled || hasMapping()) {
            return (String) this._namespaceStack.get(this._currentMapping + 7);
        }
        throw new AssertionError();
    }

    public void nextMapping() {
        this._currentMapping += 8;
    }

    public final boolean process() {
        if (!$assertionsDisabled && !this._locale.entered()) {
            throw new AssertionError();
        } else if (this._cur == null) {
            return false;
        } else {
            if (this._version == this._locale.version()) {
                int kind = this._cur.kind();
                if (kind == -2) {
                    processFinish();
                } else if (kind == -1) {
                    emitEndDoc(this._cur);
                    this._cur.release();
                    this._cur = null;
                    return true;
                } else if (kind == 0) {
                    emitText(this._cur);
                } else if (kind == 1) {
                    processRoot();
                } else if (kind == 2) {
                    processElement();
                } else if (kind == 4) {
                    emitComment(this._cur);
                    this._cur.toEnd();
                } else if (kind == 5) {
                    emitProcinst(this._cur);
                    this._cur.toEnd();
                } else {
                    throw new RuntimeException("Unexpected kind");
                }
                this._cur.next();
                return true;
            }
            throw new ConcurrentModificationException("Document changed during save");
        }
    }

    public boolean saveNamespacesFirst() {
        return this._saveNamespacesFirst;
    }

    public void syntheticNamespace(String str, String str2, boolean z) {
    }

    public static final class OptimizedForSpeedSaver extends Saver {
        public static final /* synthetic */ boolean $assertionsDisabled;
        public char[] _buf = new char[1024];
        public Writer _w;

        public static class SaverIOException extends RuntimeException {
            public SaverIOException(IOException iOException) {
                super(iOException);
            }
        }

        static {
            Class cls = Saver.class$org$apache$xmlbeans$impl$store$Saver;
            if (cls == null) {
                cls = Saver.class$("org.apache.xmlbeans.impl.store.Saver");
                Saver.class$org$apache$xmlbeans$impl$store$Saver = cls;
            }
            $assertionsDisabled = !cls.desiredAssertionStatus();
        }

        public OptimizedForSpeedSaver(Cur cur, Writer writer) {
            super(cur, XmlOptions.maskNull(null));
            this._w = writer;
        }

        private void emit(String str) {
            try {
                this._w.write(str);
            } catch (IOException e2) {
                throw new SaverIOException(e2);
            }
        }

        private void emitAttrHelper(QName qName, String str) {
            emit(' ');
            emitName(qName, true);
            emit(Base64.PAD, StringPtg.FORMULA_DELIMITER);
            emitAttrValue(str);
            emit(StringPtg.FORMULA_DELIMITER);
        }

        private void emitAttrValue(CharSequence charSequence) {
            int length = charSequence.length();
            for (int i2 = 0; i2 < length; i2++) {
                char charAt = charSequence.charAt(i2);
                if (charAt == '<') {
                    emit("&lt;");
                } else if (charAt == '&') {
                    emit("&amp;");
                } else if (charAt == '\"') {
                    emit("&quot;");
                } else {
                    emit(charAt);
                }
            }
        }

        private void emitLiteral(String str) {
            if (str.indexOf("\"") < 0) {
                emit(StringPtg.FORMULA_DELIMITER);
                emit(str);
                emit(StringPtg.FORMULA_DELIMITER);
                return;
            }
            emit('\'');
            emit(str);
            emit('\'');
        }

        private void emitName(QName qName, boolean z) {
            if ($assertionsDisabled || qName != null) {
                String namespaceURI = qName.getNamespaceURI();
                if ($assertionsDisabled || namespaceURI != null) {
                    if (namespaceURI.length() != 0) {
                        String prefix = qName.getPrefix();
                        String namespaceForPrefix = getNamespaceForPrefix(prefix);
                        if (namespaceForPrefix == null || !namespaceForPrefix.equals(namespaceURI)) {
                            prefix = getUriMapping(namespaceURI);
                        }
                        if (z && prefix.length() == 0) {
                            prefix = getNonDefaultUriMapping(namespaceURI);
                        }
                        if (prefix.length() > 0) {
                            emit(prefix);
                            emit(':');
                        }
                    }
                    if ($assertionsDisabled || qName.getLocalPart().length() > 0) {
                        emit(qName.getLocalPart());
                        return;
                    }
                    throw new AssertionError();
                }
                throw new AssertionError();
            }
            throw new AssertionError();
        }

        private void emitNamespacesHelper() {
            iterateMappings();
            while (hasMapping()) {
                emit(' ');
                emitXmlns(mappingPrefix(), mappingUri());
                nextMapping();
            }
        }

        private void entitizeAndWriteCommentText(int i2) {
            int i3 = 0;
            boolean z = false;
            while (i3 < i2) {
                char c = this._buf[i3];
                if (isBadChar(c)) {
                    this._buf[i3] = LittleEndianCP950Reader.UNMAPPABLE;
                } else {
                    if (c == '-') {
                        if (z) {
                            this._buf[i3] = ' ';
                        } else {
                            z = true;
                        }
                    }
                    z = false;
                }
                if (i3 == this._buf.length) {
                    i3 = 0;
                }
                i3++;
            }
            char[] cArr = this._buf;
            int i4 = i2 - 1;
            if (cArr[i4] == '-') {
                cArr[i4] = ' ';
            }
            emit(this._buf, 0, i2);
        }

        private void entitizeAndWritePIText(int i2) {
            boolean z = false;
            for (int i3 = 0; i3 < i2; i3++) {
                char c = this._buf[i3];
                if (isBadChar(c)) {
                    this._buf[i3] = LittleEndianCP950Reader.UNMAPPABLE;
                    c = LittleEndianCP950Reader.UNMAPPABLE;
                }
                if (c == '>') {
                    if (z) {
                        this._buf[i3] = ' ';
                    }
                } else if (c == '?') {
                    z = true;
                }
                z = false;
            }
            emit(this._buf, 0, i2);
        }

        private void entitizeAndWriteText(int i2) {
            int i3 = 0;
            for (int i4 = 0; i4 < i2; i4++) {
                char[] cArr = this._buf;
                char c = cArr[i4];
                if (c == '&') {
                    emit(cArr, i3, i4 - i3);
                    emit("&amp;");
                } else if (c == '<') {
                    emit(cArr, i3, i4 - i3);
                    emit("&lt;");
                }
                i3 = i4 + 1;
            }
            emit(this._buf, i3, i2 - i3);
        }

        private boolean isBadChar(char c) {
            return (c < ' ' || c > 55295) && (c < 57344 || c > 65533) && !((c >= 0 && c <= 65535) || c == '\t' || c == '\n' || c == '\r');
        }

        public static void save(Cur cur, Writer writer) {
            try {
                do {
                } while (new OptimizedForSpeedSaver(cur, writer).process());
            } catch (SaverIOException e2) {
                throw ((IOException) e2.getCause());
            }
        }

        @Override // org.apache.xmlbeans.impl.store.Saver
        public void emitComment(SaveCur saveCur) {
            if ($assertionsDisabled || saveCur.isComment()) {
                emit("<!--");
                saveCur.push();
                saveCur.next();
                emitCommentText(saveCur);
                saveCur.pop();
                emit("-->");
                return;
            }
            throw new AssertionError();
        }

        public void emitCommentText(SaveCur saveCur) {
            if ($assertionsDisabled || saveCur.isText()) {
                Object chars = saveCur.getChars();
                int i2 = saveCur._cchSrc;
                int i3 = saveCur._offSrc;
                int i4 = 0;
                while (i4 < i2) {
                    int i5 = i4 + 512 > i2 ? i2 : 512;
                    CharUtil.getChars(this._buf, 0, chars, i3 + i4, i5);
                    entitizeAndWriteCommentText(i5 - i4);
                    i4 = i5;
                }
                return;
            }
            throw new AssertionError();
        }

        @Override // org.apache.xmlbeans.impl.store.Saver
        public void emitDocType(String str, String str2, String str3) {
            if ($assertionsDisabled || str != null) {
                emit("<!DOCTYPE ");
                emit(str);
                if (str2 == null && str3 != null) {
                    emit(" SYSTEM ");
                    emitLiteral(str3);
                } else if (str2 != null) {
                    emit(" PUBLIC ");
                    emitLiteral(str2);
                    emit(' ');
                    emitLiteral(str3);
                }
                emit('>');
                emit(Saver._newLine);
                return;
            }
            throw new AssertionError();
        }

        @Override // org.apache.xmlbeans.impl.store.Saver
        public boolean emitElement(SaveCur saveCur, ArrayList arrayList, ArrayList arrayList2) {
            if ($assertionsDisabled || saveCur.isElem()) {
                emit('<');
                emitName(saveCur.getName(), false);
                for (int i2 = 0; i2 < arrayList.size(); i2++) {
                    emitAttrHelper((QName) arrayList.get(i2), (String) arrayList2.get(i2));
                }
                if (!saveNamespacesFirst()) {
                    emitNamespacesHelper();
                }
                if (saveCur.hasChildren() || saveCur.hasText()) {
                    emit('>');
                    return false;
                }
                emit(JarHelper.SEP, '>');
                return true;
            }
            throw new AssertionError();
        }

        @Override // org.apache.xmlbeans.impl.store.Saver
        public void emitEndDoc(SaveCur saveCur) {
        }

        @Override // org.apache.xmlbeans.impl.store.Saver
        public void emitFinish(SaveCur saveCur) {
            emit('<', JarHelper.SEP);
            emitName(saveCur.getName(), false);
            emit('>');
        }

        public void emitPiText(SaveCur saveCur) {
            if ($assertionsDisabled || saveCur.isText()) {
                Object chars = saveCur.getChars();
                int i2 = saveCur._cchSrc;
                int i3 = saveCur._offSrc;
                int i4 = 0;
                while (i4 < i2) {
                    int i5 = i4 + 512 > i2 ? i2 : 512;
                    CharUtil.getChars(this._buf, 0, chars, i3 + i4, i5);
                    entitizeAndWritePIText(i5 - i4);
                    i4 = i5;
                }
                return;
            }
            throw new AssertionError();
        }

        @Override // org.apache.xmlbeans.impl.store.Saver
        public void emitProcinst(SaveCur saveCur) {
            if ($assertionsDisabled || saveCur.isProcinst()) {
                emit("<?");
                emit(saveCur.getName().getLocalPart());
                saveCur.push();
                saveCur.next();
                if (saveCur.isText()) {
                    emit(' ');
                    emitPiText(saveCur);
                }
                saveCur.pop();
                emit("?>");
                return;
            }
            throw new AssertionError();
        }

        @Override // org.apache.xmlbeans.impl.store.Saver
        public void emitStartDoc(SaveCur saveCur) {
        }

        @Override // org.apache.xmlbeans.impl.store.Saver
        public void emitText(SaveCur saveCur) {
            if ($assertionsDisabled || saveCur.isText()) {
                Object chars = saveCur.getChars();
                int i2 = saveCur._cchSrc;
                int i3 = saveCur._offSrc;
                int i4 = 0;
                while (i4 < i2) {
                    int i5 = i4 + 512;
                    if (i5 > i2) {
                        i5 = i2;
                    }
                    int i6 = i3 + i4;
                    int i7 = i5 - i4;
                    CharUtil.getChars(this._buf, 0, chars, i6, i7);
                    entitizeAndWriteText(i7);
                    i4 = i5;
                }
                return;
            }
            throw new AssertionError();
        }

        public void emitXmlns(String str, String str2) {
            if (!$assertionsDisabled && str == null) {
                throw new AssertionError();
            } else if ($assertionsDisabled || str2 != null) {
                emit("xmlns");
                if (str.length() > 0) {
                    emit(':');
                    emit(str);
                }
                emit(Base64.PAD, StringPtg.FORMULA_DELIMITER);
                emitAttrValue(str2);
                emit(StringPtg.FORMULA_DELIMITER);
            } else {
                throw new AssertionError();
            }
        }

        private void emit(char c) {
            try {
                this._buf[0] = c;
                this._w.write(this._buf, 0, 1);
            } catch (IOException e2) {
                throw new SaverIOException(e2);
            }
        }

        private void emit(char c, char c2) {
            try {
                this._buf[0] = c;
                this._buf[1] = c2;
                this._w.write(this._buf, 0, 2);
            } catch (IOException e2) {
                throw new SaverIOException(e2);
            }
        }

        private void emit(char[] cArr, int i2, int i3) {
            try {
                this._w.write(cArr, i2, i3);
            } catch (IOException e2) {
                throw new SaverIOException(e2);
            }
        }
    }

    public static final class InputStreamSaver extends InputStream {
        public static final /* synthetic */ boolean $assertionsDisabled;
        public boolean _closed = false;
        public OutputStreamWriter _converter;
        public Locale _locale;
        public OutputStreamImpl _outStreamImpl;
        public TextSaver _textSaver;

        static {
            Class cls = Saver.class$org$apache$xmlbeans$impl$store$Saver;
            if (cls == null) {
                cls = Saver.class$("org.apache.xmlbeans.impl.store.Saver");
                Saver.class$org$apache$xmlbeans$impl$store$Saver = cls;
            }
            $assertionsDisabled = !cls.desiredAssertionStatus();
        }

        public InputStreamSaver(Cur cur, XmlOptions xmlOptions) {
            String java2IANAMapping;
            Locale locale = cur._locale;
            this._locale = locale;
            if ($assertionsDisabled || locale.entered()) {
                XmlOptions maskNull = XmlOptions.maskNull(xmlOptions);
                String str = null;
                this._outStreamImpl = new OutputStreamImpl();
                XmlDocumentProperties docProps = Locale.getDocProps(cur, false);
                if (!(docProps == null || docProps.getEncoding() == null)) {
                    str = EncodingMap.getIANA2JavaMapping(docProps.getEncoding());
                }
                str = maskNull.hasOption(XmlOptions.CHARACTER_ENCODING) ? (String) maskNull.get(XmlOptions.CHARACTER_ENCODING) : str;
                if (!(str == null || (java2IANAMapping = EncodingMap.getJava2IANAMapping(str)) == null)) {
                    str = java2IANAMapping;
                }
                str = str == null ? EncodingMap.getJava2IANAMapping("UTF8") : str;
                String iANA2JavaMapping = EncodingMap.getIANA2JavaMapping(str);
                if (iANA2JavaMapping != null) {
                    try {
                        this._converter = new OutputStreamWriter(this._outStreamImpl, iANA2JavaMapping);
                        this._textSaver = new TextSaver(cur, maskNull, str);
                    } catch (UnsupportedEncodingException e2) {
                        throw new RuntimeException(e2);
                    }
                } else {
                    throw new IllegalStateException(a.a("Unknown encoding: ", str));
                }
            } else {
                throw new AssertionError();
            }
        }

        private void checkClosed() {
            if (this._closed) {
                throw new IOException("Stream closed");
            }
        }

        /* access modifiers changed from: private */
        /* access modifiers changed from: public */
        private int ensure(int i2) {
            if (i2 <= 0) {
                i2 = 1;
            }
            int available = this._outStreamImpl.getAvailable();
            while (available < i2 && this._textSaver.write(this._converter, 2048) >= 2048) {
                available = this._outStreamImpl.getAvailable();
            }
            return this._outStreamImpl.getAvailable();
        }

        @Override // java.io.InputStream
        public int available() {
            int ensure;
            if (this._locale.noSync()) {
                this._locale.enter();
                try {
                    return ensure(1024);
                } finally {
                    this._locale.exit();
                }
            } else {
                synchronized (this._locale) {
                    this._locale.enter();
                    try {
                        ensure = ensure(1024);
                    } finally {
                        this._locale.exit();
                    }
                }
                return ensure;
            }
        }

        @Override // java.io.Closeable, java.lang.AutoCloseable, java.io.InputStream
        public void close() {
            this._closed = true;
        }

        @Override // java.io.InputStream
        public int read() {
            int read;
            checkClosed();
            if (this._locale.noSync()) {
                this._locale.enter();
                try {
                    return this._outStreamImpl.read();
                } finally {
                    this._locale.exit();
                }
            } else {
                synchronized (this._locale) {
                    this._locale.enter();
                    try {
                        read = this._outStreamImpl.read();
                    } finally {
                        this._locale.exit();
                    }
                }
                return read;
            }
        }

        @Override // java.io.InputStream
        public int read(byte[] bArr, int i2, int i3) {
            int read;
            checkClosed();
            if (bArr == null) {
                throw new NullPointerException("buf to read into is null");
            } else if (i2 < 0 || i2 > bArr.length) {
                throw new IndexOutOfBoundsException("Offset is not within buf");
            } else if (this._locale.noSync()) {
                this._locale.enter();
                try {
                    return this._outStreamImpl.read(bArr, i2, i3);
                } finally {
                    this._locale.exit();
                }
            } else {
                synchronized (this._locale) {
                    this._locale.enter();
                    try {
                        read = this._outStreamImpl.read(bArr, i2, i3);
                    } finally {
                        this._locale.exit();
                    }
                }
                return read;
            }
        }

        public final class OutputStreamImpl extends OutputStream {
            public static final /* synthetic */ boolean $assertionsDisabled;
            public static final int _initialBufSize = 4096;
            public byte[] _buf;
            public int _free;
            public int _in;
            public int _out;

            static {
                Class cls = Saver.class$org$apache$xmlbeans$impl$store$Saver;
                if (cls == null) {
                    cls = Saver.class$("org.apache.xmlbeans.impl.store.Saver");
                    Saver.class$org$apache$xmlbeans$impl$store$Saver = cls;
                }
                $assertionsDisabled = !cls.desiredAssertionStatus();
            }

            public OutputStreamImpl() {
            }

            public int getAvailable() {
                byte[] bArr = this._buf;
                if (bArr == null) {
                    return 0;
                }
                return bArr.length - this._free;
            }

            public int read() {
                if (InputStreamSaver.this.ensure(1) == 0) {
                    return -1;
                }
                if ($assertionsDisabled || getAvailable() > 0) {
                    byte[] bArr = this._buf;
                    int i2 = this._out;
                    byte b2 = bArr[i2];
                    this._out = (i2 + 1) % bArr.length;
                    this._free++;
                    return b2;
                }
                throw new AssertionError();
            }

            public void resize(int i2) {
                if ($assertionsDisabled || i2 > this._free) {
                    byte[] bArr = this._buf;
                    int length = bArr == null ? 4096 : bArr.length * 2;
                    int available = getAvailable();
                    while (length - available < i2) {
                        length *= 2;
                    }
                    byte[] bArr2 = new byte[length];
                    if (available > 0) {
                        int i3 = this._in;
                        int i4 = this._out;
                        if (i3 > i4) {
                            System.arraycopy(this._buf, i4, bArr2, 0, available);
                        } else {
                            System.arraycopy(this._buf, i4, bArr2, 0, available - i3);
                            byte[] bArr3 = this._buf;
                            int i5 = this._in;
                            System.arraycopy(bArr3, 0, bArr2, available - i5, i5);
                        }
                        this._out = 0;
                        this._in = available;
                        this._free = (length - this._buf.length) + this._free;
                    } else {
                        this._free = length;
                        if (!$assertionsDisabled && this._in != this._out) {
                            throw new AssertionError();
                        }
                    }
                    this._buf = bArr2;
                    return;
                }
                StringBuffer stringBuffer = new StringBuffer();
                stringBuffer.append(i2);
                stringBuffer.append(" !> ");
                stringBuffer.append(this._free);
                throw new AssertionError(stringBuffer.toString());
            }

            @Override // java.io.OutputStream
            public void write(int i2) {
                if (this._free == 0) {
                    resize(1);
                }
                if ($assertionsDisabled || this._free > 0) {
                    byte[] bArr = this._buf;
                    int i3 = this._in;
                    bArr[i3] = (byte) i2;
                    this._in = (i3 + 1) % bArr.length;
                    this._free--;
                    return;
                }
                throw new AssertionError();
            }

            public int read(byte[] bArr, int i2, int i3) {
                int ensure = InputStreamSaver.this.ensure(i3);
                if (ensure == 0) {
                    return -1;
                }
                if (bArr == null || i3 <= 0) {
                    return 0;
                }
                if (ensure < i3) {
                    i3 = ensure;
                }
                int i4 = this._out;
                if (i4 < this._in) {
                    System.arraycopy(this._buf, i4, bArr, i2, i3);
                } else {
                    byte[] bArr2 = this._buf;
                    int length = bArr2.length - i4;
                    if (length >= i3) {
                        System.arraycopy(bArr2, i4, bArr, i2, i3);
                    } else {
                        System.arraycopy(bArr2, i4, bArr, i2, length);
                        System.arraycopy(this._buf, 0, bArr, i2 + length, i3 - length);
                    }
                }
                this._out = (this._out + i3) % this._buf.length;
                this._free += i3;
                return i3;
            }

            @Override // java.io.OutputStream
            public void write(byte[] bArr, int i2, int i3) {
                if (!$assertionsDisabled && i3 < 0) {
                    throw new AssertionError();
                } else if (i3 != 0) {
                    if (this._free < i3) {
                        resize(i3);
                    }
                    if (this._in == this._out) {
                        if (!$assertionsDisabled && getAvailable() != 0) {
                            throw new AssertionError();
                        } else if ($assertionsDisabled || this._free == this._buf.length - getAvailable()) {
                            this._out = 0;
                            this._in = 0;
                        } else {
                            throw new AssertionError();
                        }
                    }
                    byte[] bArr2 = this._buf;
                    int length = bArr2.length;
                    int i4 = this._in;
                    int i5 = length - i4;
                    if (i4 <= this._out || i3 < i5) {
                        System.arraycopy(bArr, i2, this._buf, this._in, i3);
                        this._in += i3;
                    } else {
                        System.arraycopy(bArr, i2, bArr2, i4, i5);
                        System.arraycopy(bArr, i2 + i5, this._buf, 0, i3 - i5);
                        this._in = (this._in + i3) % this._buf.length;
                    }
                    this._free -= i3;
                }
            }
        }
    }

    public static final class TextReader extends Reader {
        public boolean _closed = false;
        public Locale _locale;
        public TextSaver _textSaver;

        public TextReader(Cur cur, XmlOptions xmlOptions) {
            this._textSaver = new TextSaver(cur, xmlOptions, null);
            this._locale = cur._locale;
        }

        private void checkClosed() {
            if (this._closed) {
                throw new IOException("Reader has been closed");
            }
        }

        @Override // java.io.Closeable, java.io.Reader, java.lang.AutoCloseable
        public void close() {
            this._closed = true;
        }

        @Override // java.io.Reader
        public int read() {
            int read;
            checkClosed();
            if (this._locale.noSync()) {
                this._locale.enter();
                try {
                    return this._textSaver.read();
                } finally {
                    this._locale.exit();
                }
            } else {
                synchronized (this._locale) {
                    this._locale.enter();
                    try {
                        read = this._textSaver.read();
                    } finally {
                        this._locale.exit();
                    }
                }
                return read;
            }
        }

        @Override // java.io.Reader
        public boolean ready() {
            return !this._closed;
        }

        @Override // java.io.Reader
        public int read(char[] cArr) {
            int read;
            checkClosed();
            if (this._locale.noSync()) {
                this._locale.enter();
                try {
                    return this._textSaver.read(cArr, 0, cArr == null ? 0 : cArr.length);
                } finally {
                    this._locale.exit();
                }
            } else {
                synchronized (this._locale) {
                    this._locale.enter();
                    try {
                        read = this._textSaver.read(cArr, 0, cArr == null ? 0 : cArr.length);
                    } finally {
                        this._locale.exit();
                    }
                }
                return read;
            }
        }

        @Override // java.io.Reader
        public int read(char[] cArr, int i2, int i3) {
            int read;
            checkClosed();
            if (this._locale.noSync()) {
                this._locale.enter();
                try {
                    return this._textSaver.read(cArr, i2, i3);
                } finally {
                    this._locale.exit();
                }
            } else {
                synchronized (this._locale) {
                    this._locale.enter();
                    try {
                        read = this._textSaver.read(cArr, i2, i3);
                    } finally {
                        this._locale.exit();
                    }
                }
                return read;
            }
        }
    }

    public static final class TextSaver extends Saver {
        public static final /* synthetic */ boolean $assertionsDisabled;
        public static final int _initialBufSize = 4096;
        public char[] _buf;
        public int _cdataEntityCountThreshold = 5;
        public int _cdataLengthThreshold = 32;
        public int _free;
        public int _in;
        public boolean _isPrettyPrint = false;
        public int _lastEmitCch;
        public int _lastEmitIn;
        public int _out;
        public boolean _useCDataBookmarks = false;

        static {
            Class cls = Saver.class$org$apache$xmlbeans$impl$store$Saver;
            if (cls == null) {
                cls = Saver.class$("org.apache.xmlbeans.impl.store.Saver");
                Saver.class$org$apache$xmlbeans$impl$store$Saver = cls;
            }
            $assertionsDisabled = !cls.desiredAssertionStatus();
        }

        public TextSaver(Cur cur, XmlOptions xmlOptions, String str) {
            super(cur, xmlOptions);
            String str2;
            char[] cArr;
            int i2;
            int i3;
            boolean z = xmlOptions != null && xmlOptions.hasOption(XmlOptions.SAVE_NO_XML_DECL);
            if (xmlOptions != null && xmlOptions.hasOption(XmlOptions.SAVE_CDATA_LENGTH_THRESHOLD)) {
                this._cdataLengthThreshold = ((Integer) xmlOptions.get(XmlOptions.SAVE_CDATA_LENGTH_THRESHOLD)).intValue();
            }
            if (xmlOptions != null && xmlOptions.hasOption(XmlOptions.SAVE_CDATA_ENTITY_COUNT_THRESHOLD)) {
                this._cdataEntityCountThreshold = ((Integer) xmlOptions.get(XmlOptions.SAVE_CDATA_ENTITY_COUNT_THRESHOLD)).intValue();
            }
            if (xmlOptions != null && xmlOptions.hasOption(XmlOptions.LOAD_SAVE_CDATA_BOOKMARKS)) {
                this._useCDataBookmarks = true;
            }
            if (xmlOptions != null && xmlOptions.hasOption(XmlOptions.SAVE_PRETTY_PRINT)) {
                this._isPrettyPrint = true;
            }
            this._out = 0;
            this._in = 0;
            this._free = 0;
            if (!$assertionsDisabled && (cArr = this._buf) != null && ((0 >= 0 || 0 != cArr.length - (0 - 0)) && (((i2 = this._out) <= (i3 = this._in) || this._free != i2 - i3) && ((this._out != this._in || this._free != this._buf.length) && (this._out != this._in || this._free != 0))))) {
                StringBuffer a = a.a("_buf.length:");
                a.append(this._buf.length);
                a.append(" _in:");
                a.append(this._in);
                a.append(" _out:");
                a.append(this._out);
                a.append(" _free:");
                a.append(this._free);
                throw new AssertionError(a.toString());
            } else if (str != null && !z) {
                XmlDocumentProperties docProps = Locale.getDocProps(cur, false);
                if (docProps == null) {
                    str2 = null;
                } else {
                    str2 = docProps.getVersion();
                }
                str2 = str2 == null ? "1.0" : str2;
                emit("<?xml version=\"");
                emit(str2);
                StringBuffer c = a.c("\" encoding=\"", str, "\"?>");
                c.append(Saver._newLine);
                emit(c.toString());
            }
        }

        private void emit(char c) {
            char[] cArr;
            int i2;
            int i3;
            int i4;
            int i5;
            if ($assertionsDisabled || (cArr = this._buf) == null || (((i2 = this._out) < (i3 = this._in) && this._free == cArr.length - (i3 - i2)) || (((i4 = this._out) > (i5 = this._in) && this._free == i4 - i5) || ((this._out == this._in && this._free == this._buf.length) || (this._out == this._in && this._free == 0))))) {
                preEmit(1);
                char[] cArr2 = this._buf;
                int i6 = this._in;
                cArr2[i6] = c;
                int length = (i6 + 1) % cArr2.length;
                this._in = length;
                if (!$assertionsDisabled && cArr2 != null) {
                    int i7 = this._out;
                    if (i7 >= length || this._free != cArr2.length - (length - i7)) {
                        int i8 = this._out;
                        int i9 = this._in;
                        if (i8 > i9 && this._free == i8 - i9) {
                            return;
                        }
                        if (this._out != this._in || this._free != this._buf.length) {
                            if (this._out != this._in || this._free != 0) {
                                StringBuffer a = a.a("_buf.length:");
                                a.append(this._buf.length);
                                a.append(" _in:");
                                a.append(this._in);
                                a.append(" _out:");
                                a.append(this._out);
                                a.append(" _free:");
                                a.append(this._free);
                                throw new AssertionError(a.toString());
                            }
                            return;
                        }
                        return;
                    }
                    return;
                }
                return;
            }
            StringBuffer a2 = a.a("_buf.length:");
            a2.append(this._buf.length);
            a2.append(" _in:");
            a2.append(this._in);
            a2.append(" _out:");
            a2.append(this._out);
            a2.append(" _free:");
            a2.append(this._free);
            throw new AssertionError(a2.toString());
        }

        private void emitAttrHelper(QName qName, String str) {
            emit(' ');
            emitName(qName, true);
            emit(Base64.PAD, StringPtg.FORMULA_DELIMITER);
            emit(str);
            entitizeAttrValue(true);
            emit(StringPtg.FORMULA_DELIMITER);
        }

        private void emitLiteral(String str) {
            if (str.indexOf("\"") < 0) {
                emit(StringPtg.FORMULA_DELIMITER);
                emit(str);
                emit(StringPtg.FORMULA_DELIMITER);
                return;
            }
            emit('\'');
            emit(str);
            emit('\'');
        }

        private void emitName(QName qName, boolean z) {
            if ($assertionsDisabled || qName != null) {
                String namespaceURI = qName.getNamespaceURI();
                if ($assertionsDisabled || namespaceURI != null) {
                    if (namespaceURI.length() != 0) {
                        String prefix = qName.getPrefix();
                        String namespaceForPrefix = getNamespaceForPrefix(prefix);
                        if (namespaceForPrefix == null || !namespaceForPrefix.equals(namespaceURI)) {
                            prefix = getUriMapping(namespaceURI);
                        }
                        if (z && prefix.length() == 0) {
                            prefix = getNonDefaultUriMapping(namespaceURI);
                        }
                        if (prefix.length() > 0) {
                            emit(prefix);
                            emit(':');
                        }
                    }
                    if ($assertionsDisabled || qName.getLocalPart().length() > 0) {
                        emit(qName.getLocalPart());
                        return;
                    }
                    throw new AssertionError();
                }
                throw new AssertionError();
            }
            throw new AssertionError();
        }

        private void emitNamespacesHelper() {
            iterateMappings();
            while (hasMapping()) {
                emit(' ');
                emitXmlns(mappingPrefix(), mappingUri());
                nextMapping();
            }
        }

        private int ensure(int i2) {
            if (i2 <= 0) {
                i2 = 1;
            }
            int available = getAvailable();
            while (available < i2 && process()) {
                available = getAvailable();
            }
            if ($assertionsDisabled || available == getAvailable()) {
                return available;
            }
            throw new AssertionError();
        }

        private void entitizeAttrValue(boolean z) {
            int i2 = this._lastEmitCch;
            if (i2 != 0) {
                int i3 = this._lastEmitIn;
                while (i2 > 0) {
                    char c = this._buf[i3];
                    if (c == '<') {
                        i3 = replace(i3, "&lt;");
                    } else if (c == '&') {
                        i3 = replace(i3, "&amp;");
                    } else if (c == '\"') {
                        i3 = replace(i3, "&quot;");
                    } else if (!isEscapedChar(c)) {
                        i3++;
                    } else if (z) {
                        i3 = replace(i3, this._replaceChar.getEscapedString(c));
                    }
                    if (i3 == this._buf.length) {
                        i3 = 0;
                    }
                    i2--;
                }
            }
        }

        private void entitizeComment() {
            int i2 = this._lastEmitCch;
            if (i2 != 0) {
                int i3 = this._lastEmitIn;
                boolean z = false;
                while (i2 > 0) {
                    char c = this._buf[i3];
                    if (isBadChar(c)) {
                        i3 = replace(i3, "?");
                    } else {
                        if (c != '-') {
                            i3++;
                        } else if (z) {
                            i3 = replace(i3, " ");
                        } else {
                            i3++;
                            z = true;
                        }
                        z = false;
                    }
                    if (i3 == this._buf.length) {
                        i3 = 0;
                    }
                    i2--;
                }
                char[] cArr = this._buf;
                int length = ((this._lastEmitIn + this._lastEmitCch) - 1) % cArr.length;
                if (cArr[length] == '-') {
                    replace(length, " ");
                }
            }
        }

        private void entitizeContent(boolean z) {
            int i2;
            if ($assertionsDisabled || this._free >= 0) {
                int i3 = this._lastEmitCch;
                if (i3 != 0) {
                    int i4 = this._lastEmitIn;
                    int length = this._buf.length;
                    int i5 = 0;
                    boolean z2 = false;
                    char c = 0;
                    char c2 = 0;
                    while (i3 > 0) {
                        char c3 = this._buf[i4];
                        if (c3 == '<' || c3 == '&') {
                            i5++;
                        } else if ((c == ']' && c2 == ']' && c3 == '>') || isBadChar(c3) || isEscapedChar(c3) || (!this._isPrettyPrint && c3 == '\r')) {
                            z2 = true;
                        }
                        i4++;
                        if (i4 == length) {
                            i4 = 0;
                        }
                        i3--;
                        c = c2;
                        c2 = c3;
                    }
                    if (z || i5 != 0 || z2 || i5 >= this._cdataEntityCountThreshold) {
                        int i6 = this._lastEmitIn;
                        if (z || (this._lastEmitCch > this._cdataLengthThreshold && i5 > this._cdataEntityCountThreshold)) {
                            boolean z3 = this._buf[i6] == ']';
                            StringBuffer a = a.a("<![CDATA[");
                            a.append(this._buf[i6]);
                            int replace = replace(i6, a.toString());
                            boolean z4 = this._buf[replace] == ']';
                            int i7 = replace + 1;
                            if (i7 == this._buf.length) {
                                i7 = 0;
                            }
                            int i8 = this._lastEmitCch;
                            while (i8 > 0) {
                                char c4 = this._buf[i7];
                                if (c4 != '>' || !z3 || !z4) {
                                    i2 = isBadChar(c4) ? replace(i7, "?") : i7 + 1;
                                } else {
                                    i2 = replace(i7, "]]>><![CDATA[");
                                }
                                boolean z5 = c4 == ']';
                                if (i2 == this._buf.length) {
                                    i2 = 0;
                                }
                                i8--;
                                i7 = i2;
                                z3 = z4;
                                z4 = z5;
                            }
                            emit("]]>");
                            return;
                        }
                        int i9 = this._lastEmitCch;
                        char c5 = 0;
                        char c6 = 0;
                        while (i9 > 0) {
                            char c7 = this._buf[i6];
                            if (c7 == '<') {
                                i6 = replace(i6, "&lt;");
                            } else if (c7 == '&') {
                                i6 = replace(i6, "&amp;");
                            } else if (c7 == '>' && c5 == ']' && c6 == ']') {
                                i6 = replace(i6, "&gt;");
                            } else if (isBadChar(c7)) {
                                i6 = replace(i6, "?");
                            } else if (this._isPrettyPrint || c7 != '\r') {
                                i6 = isEscapedChar(c7) ? replace(i6, this._replaceChar.getEscapedString(c7)) : i6 + 1;
                            } else {
                                i6 = replace(i6, "&#13;");
                            }
                            if (i6 == this._buf.length) {
                                i6 = 0;
                            }
                            i9--;
                            c6 = c5;
                            c5 = c7;
                        }
                        return;
                    }
                    return;
                }
                return;
            }
            throw new AssertionError();
        }

        private void entitizeProcinst() {
            int i2 = this._lastEmitCch;
            if (i2 != 0) {
                int i3 = this._lastEmitIn;
                boolean z = false;
                while (i2 > 0) {
                    char c = this._buf[i3];
                    if (isBadChar(c)) {
                        i3 = replace(i3, "?");
                    }
                    if (c == '>') {
                        i3 = z ? replace(i3, " ") : i3 + 1;
                        z = false;
                    } else {
                        z = c == '?';
                        i3++;
                    }
                    if (i3 == this._buf.length) {
                        i3 = 0;
                    }
                    i2--;
                }
            }
        }

        private boolean isBadChar(char c) {
            return (c < ' ' || c > 55295) && (c < 57344 || c > 65533) && !((c >= 0 && c <= 65535) || c == '\t' || c == '\n' || c == '\r');
        }

        private boolean isEscapedChar(char c) {
            XmlOptionCharEscapeMap xmlOptionCharEscapeMap = this._replaceChar;
            return xmlOptionCharEscapeMap != null && xmlOptionCharEscapeMap.containsChar(c);
        }

        private boolean preEmit(int i2) {
            char[] cArr;
            int i3;
            int i4;
            int i5;
            int i6;
            char[] cArr2;
            char[] cArr3;
            int i7;
            int i8;
            int i9;
            int i10;
            if (!$assertionsDisabled && i2 < 0) {
                throw new AssertionError();
            } else if ($assertionsDisabled || (cArr3 = this._buf) == null || (((i7 = this._out) < (i8 = this._in) && this._free == cArr3.length - (i8 - i7)) || (((i9 = this._out) > (i10 = this._in) && this._free == i9 - i10) || ((this._out == this._in && this._free == this._buf.length) || (this._out == this._in && this._free == 0))))) {
                this._lastEmitCch = i2;
                if (i2 == 0) {
                    return true;
                }
                if (this._free <= i2) {
                    resize(i2, -1);
                }
                if ($assertionsDisabled || i2 <= this._free) {
                    if (getAvailable() == 0) {
                        if (!$assertionsDisabled && this._in != this._out) {
                            throw new AssertionError();
                        } else if ($assertionsDisabled || this._free == this._buf.length) {
                            this._out = 0;
                            this._in = 0;
                        } else {
                            throw new AssertionError();
                        }
                    }
                    this._lastEmitIn = this._in;
                    int i11 = this._free - i2;
                    this._free = i11;
                    if ($assertionsDisabled || i11 >= 0) {
                        if (!$assertionsDisabled && (cArr2 = this._buf) != null) {
                            int i12 = this._free;
                            int i13 = this._in;
                            int i14 = this._out;
                            if (i12 != (i13 >= i14 ? cArr2.length - (i13 - i14) : i14 - i13) - i2) {
                                StringBuffer a = a.a("_buf.length:");
                                a.append(this._buf.length);
                                a.append(" _in:");
                                a.append(this._in);
                                a.append(" _out:");
                                a.append(this._out);
                                a.append(" _free:");
                                a.append(this._free);
                                throw new AssertionError(a.toString());
                            }
                        }
                        if ($assertionsDisabled || (cArr = this._buf) == null || (((i3 = this._out) < (i4 = this._in) && this._free == (cArr.length - (i4 - i3)) - i2) || (((i5 = this._out) > (i6 = this._in) && this._free == (i5 - i6) - i2) || ((this._out == this._in && this._free == this._buf.length - i2) || (this._out == this._in && this._free == 0))))) {
                            return false;
                        }
                        StringBuffer a2 = a.a("_buf.length:");
                        a2.append(this._buf.length);
                        a2.append(" _in:");
                        a2.append(this._in);
                        a2.append(" _out:");
                        a2.append(this._out);
                        a2.append(" _free:");
                        a2.append(this._free);
                        throw new AssertionError(a2.toString());
                    }
                    throw new AssertionError();
                }
                throw new AssertionError();
            } else {
                StringBuffer a3 = a.a("_buf.length:");
                a3.append(this._buf.length);
                a3.append(" _in:");
                a3.append(this._in);
                a3.append(" _out:");
                a3.append(this._out);
                a3.append(" _free:");
                a3.append(this._free);
                throw new AssertionError(a3.toString());
            }
        }

        private int replace(int i2, String str) {
            char[] cArr;
            int i3;
            int i4;
            int i5;
            int i6;
            if ($assertionsDisabled || str.length() > 0) {
                int length = str.length() - 1;
                if (length == 0) {
                    this._buf[i2] = str.charAt(0);
                    return i2 + 1;
                } else if ($assertionsDisabled || this._free >= 0) {
                    if (length > this._free) {
                        i2 = resize(length, i2);
                    }
                    if (!$assertionsDisabled && this._free < 0) {
                        throw new AssertionError();
                    } else if (!$assertionsDisabled && this._free < length) {
                        throw new AssertionError();
                    } else if ($assertionsDisabled || getAvailable() > 0) {
                        int i7 = length + 1;
                        int i8 = this._out;
                        if (i8 > this._in && i2 >= i8) {
                            char[] cArr2 = this._buf;
                            System.arraycopy(cArr2, i8, cArr2, i8 - length, i2 - i8);
                            this._out -= length;
                            i2 -= length;
                        } else if ($assertionsDisabled || i2 < this._in) {
                            char[] cArr3 = this._buf;
                            int length2 = cArr3.length;
                            int i9 = this._in;
                            int i10 = length2 - i9;
                            if (length <= i10) {
                                System.arraycopy(cArr3, i2, cArr3, i2 + length, i9 - i2);
                                this._in = (this._in + length) % this._buf.length;
                            } else if (length <= ((i10 + i9) - i2) - 1) {
                                int i11 = length - i10;
                                System.arraycopy(cArr3, i9 - i11, cArr3, 0, i11);
                                char[] cArr4 = this._buf;
                                int i12 = i2 + 1;
                                System.arraycopy(cArr4, i12, cArr4, i12 + length, ((this._in - i2) - 1) - i11);
                                this._in = i11;
                            } else {
                                int i13 = (i9 - i2) - 1;
                                int i14 = (i10 + i9) - i2;
                                System.arraycopy(cArr3, i9 - i13, cArr3, (length - i14) + 1, i13);
                                str.getChars(i14, i7, this._buf, 0);
                                this._in = ((i13 + length) - i14) + 1;
                                i7 = i14;
                            }
                        } else {
                            throw new AssertionError();
                        }
                        str.getChars(0, i7, this._buf, i2);
                        int i15 = this._free - length;
                        this._free = i15;
                        if (!$assertionsDisabled && i15 < 0) {
                            throw new AssertionError();
                        } else if ($assertionsDisabled || (cArr = this._buf) == null || (((i3 = this._out) < (i4 = this._in) && this._free == cArr.length - (i4 - i3)) || (((i5 = this._out) > (i6 = this._in) && this._free == i5 - i6) || ((this._out == this._in && this._free == this._buf.length) || (this._out == this._in && this._free == 0))))) {
                            return ((i2 + length) + 1) % this._buf.length;
                        } else {
                            StringBuffer a = a.a("_buf.length:");
                            a.append(this._buf.length);
                            a.append(" _in:");
                            a.append(this._in);
                            a.append(" _out:");
                            a.append(this._out);
                            a.append(" _free:");
                            a.append(this._free);
                            throw new AssertionError(a.toString());
                        }
                    } else {
                        throw new AssertionError();
                    }
                } else {
                    throw new AssertionError();
                }
            } else {
                throw new AssertionError();
            }
        }

        private int resize(int i2, int i3) {
            char[] cArr;
            int i4;
            int i5;
            int i6;
            int i7;
            int i8;
            char[] cArr2;
            int i9;
            int i10;
            int i11;
            int i12;
            if (!$assertionsDisabled && this._free < 0) {
                throw new AssertionError();
            } else if (!$assertionsDisabled && i2 <= 0) {
                throw new AssertionError();
            } else if (!$assertionsDisabled && i2 < this._free) {
                throw new AssertionError();
            } else if ($assertionsDisabled || (cArr2 = this._buf) == null || (((i9 = this._out) < (i10 = this._in) && this._free == cArr2.length - (i10 - i9)) || (((i11 = this._out) > (i12 = this._in) && this._free == i11 - i12) || ((this._out == this._in && this._free == this._buf.length) || (this._out == this._in && this._free == 0))))) {
                char[] cArr3 = this._buf;
                int length = cArr3 == null ? 4096 : cArr3.length * 2;
                int available = getAvailable();
                while (length - available < i2) {
                    length *= 2;
                }
                char[] cArr4 = new char[length];
                if (available > 0) {
                    int i13 = this._in;
                    int i14 = this._out;
                    if (i13 > i14) {
                        if ($assertionsDisabled || i3 == -1 || (i3 >= i14 && i3 < i13)) {
                            System.arraycopy(this._buf, this._out, cArr4, 0, available);
                            i8 = this._out;
                        } else {
                            throw new AssertionError();
                        }
                    } else if ($assertionsDisabled || i3 == -1 || i3 >= i14 || i3 < i13) {
                        System.arraycopy(this._buf, this._out, cArr4, 0, available - this._in);
                        char[] cArr5 = this._buf;
                        int i15 = this._in;
                        System.arraycopy(cArr5, 0, cArr4, available - i15, i15);
                        i8 = this._out;
                        if (i3 < i8) {
                            i3 += i8;
                            this._out = 0;
                            this._in = available;
                            this._free = (length - this._buf.length) + this._free;
                        }
                    } else {
                        throw new AssertionError();
                    }
                    i3 -= i8;
                    this._out = 0;
                    this._in = available;
                    this._free = (length - this._buf.length) + this._free;
                } else {
                    this._free = length;
                    if (!$assertionsDisabled && (this._in != 0 || this._out != 0)) {
                        throw new AssertionError();
                    } else if (!$assertionsDisabled && i3 != -1) {
                        throw new AssertionError();
                    }
                }
                this._buf = cArr4;
                if (!$assertionsDisabled && this._free < 0) {
                    throw new AssertionError();
                } else if ($assertionsDisabled || (cArr = this._buf) == null || (((i4 = this._out) < (i5 = this._in) && this._free == cArr.length - (i5 - i4)) || (((i6 = this._out) > (i7 = this._in) && this._free == i6 - i7) || ((this._out == this._in && this._free == this._buf.length) || (this._out == this._in && this._free == 0))))) {
                    return i3;
                } else {
                    StringBuffer a = a.a("_buf.length:");
                    a.append(this._buf.length);
                    a.append(" _in:");
                    a.append(this._in);
                    a.append(" _out:");
                    a.append(this._out);
                    a.append(" _free:");
                    a.append(this._free);
                    throw new AssertionError(a.toString());
                }
            } else {
                StringBuffer a2 = a.a("_buf.length:");
                a2.append(this._buf.length);
                a2.append(" _in:");
                a2.append(this._in);
                a2.append(" _out:");
                a2.append(this._out);
                a2.append(" _free:");
                a2.append(this._free);
                throw new AssertionError(a2.toString());
            }
        }

        @Override // org.apache.xmlbeans.impl.store.Saver
        public void emitComment(SaveCur saveCur) {
            if ($assertionsDisabled || saveCur.isComment()) {
                emit("<!--");
                saveCur.push();
                saveCur.next();
                emit(saveCur);
                saveCur.pop();
                entitizeComment();
                emit("-->");
                return;
            }
            throw new AssertionError();
        }

        @Override // org.apache.xmlbeans.impl.store.Saver
        public void emitDocType(String str, String str2, String str3) {
            if ($assertionsDisabled || str != null) {
                emit("<!DOCTYPE ");
                emit(str);
                if (str2 == null && str3 != null) {
                    emit(" SYSTEM ");
                    emitLiteral(str3);
                } else if (str2 != null) {
                    emit(" PUBLIC ");
                    emitLiteral(str2);
                    emit(" ");
                    emitLiteral(str3);
                }
                emit(GreaterThanPtg.GREATERTHAN);
                emit(Saver._newLine);
                return;
            }
            throw new AssertionError();
        }

        @Override // org.apache.xmlbeans.impl.store.Saver
        public boolean emitElement(SaveCur saveCur, ArrayList arrayList, ArrayList arrayList2) {
            if ($assertionsDisabled || saveCur.isElem()) {
                emit('<');
                emitName(saveCur.getName(), false);
                if (saveNamespacesFirst()) {
                    emitNamespacesHelper();
                }
                for (int i2 = 0; i2 < arrayList.size(); i2++) {
                    emitAttrHelper((QName) arrayList.get(i2), (String) arrayList2.get(i2));
                }
                if (!saveNamespacesFirst()) {
                    emitNamespacesHelper();
                }
                if (saveCur.hasChildren() || saveCur.hasText()) {
                    emit('>');
                    return false;
                }
                emit(JarHelper.SEP, '>');
                return true;
            }
            throw new AssertionError();
        }

        @Override // org.apache.xmlbeans.impl.store.Saver
        public void emitEndDoc(SaveCur saveCur) {
        }

        @Override // org.apache.xmlbeans.impl.store.Saver
        public void emitFinish(SaveCur saveCur) {
            emit('<', JarHelper.SEP);
            emitName(saveCur.getName(), false);
            emit('>');
        }

        @Override // org.apache.xmlbeans.impl.store.Saver
        public void emitProcinst(SaveCur saveCur) {
            if ($assertionsDisabled || saveCur.isProcinst()) {
                emit("<?");
                emit(saveCur.getName().getLocalPart());
                saveCur.push();
                saveCur.next();
                if (saveCur.isText()) {
                    emit(" ");
                    emit(saveCur);
                    entitizeProcinst();
                }
                saveCur.pop();
                emit("?>");
                return;
            }
            throw new AssertionError();
        }

        @Override // org.apache.xmlbeans.impl.store.Saver
        public void emitStartDoc(SaveCur saveCur) {
        }

        @Override // org.apache.xmlbeans.impl.store.Saver
        public void emitText(SaveCur saveCur) {
            if ($assertionsDisabled || saveCur.isText()) {
                boolean z = this._useCDataBookmarks && saveCur.isTextCData();
                emit(saveCur);
                entitizeContent(z);
                return;
            }
            throw new AssertionError();
        }

        public void emitXmlns(String str, String str2) {
            if (!$assertionsDisabled && str == null) {
                throw new AssertionError();
            } else if ($assertionsDisabled || str2 != null) {
                emit("xmlns");
                if (str.length() > 0) {
                    emit(':');
                    emit(str);
                }
                emit(Base64.PAD, StringPtg.FORMULA_DELIMITER);
                emit(str2);
                entitizeAttrValue(false);
                emit(StringPtg.FORMULA_DELIMITER);
            } else {
                throw new AssertionError();
            }
        }

        public int getAvailable() {
            char[] cArr = this._buf;
            if (cArr == null) {
                return 0;
            }
            return cArr.length - this._free;
        }

        public int read() {
            int i2;
            int i3;
            int i4;
            if (ensure(1) == 0) {
                return -1;
            }
            if ($assertionsDisabled || getAvailable() > 0) {
                char[] cArr = this._buf;
                int i5 = this._out;
                char c = cArr[i5];
                int length = (i5 + 1) % cArr.length;
                this._out = length;
                int i6 = this._free + 1;
                this._free = i6;
                if ($assertionsDisabled || cArr == null || ((length < (i2 = this._in) && i6 == cArr.length - (i2 - length)) || (((i3 = this._out) > (i4 = this._in) && this._free == i3 - i4) || ((this._out == this._in && this._free == this._buf.length) || (this._out == this._in && this._free == 0))))) {
                    return c;
                }
                StringBuffer a = a.a("_buf.length:");
                a.append(this._buf.length);
                a.append(" _in:");
                a.append(this._in);
                a.append(" _out:");
                a.append(this._out);
                a.append(" _free:");
                a.append(this._free);
                throw new AssertionError(a.toString());
            }
            throw new AssertionError();
        }

        public String saveToString() {
            do {
            } while (process());
            if ($assertionsDisabled || this._out == 0) {
                int available = getAvailable();
                if (available == 0) {
                    return "";
                }
                return new String(this._buf, this._out, available);
            }
            throw new AssertionError();
        }

        /* JADX WARNING: Removed duplicated region for block: B:2:0x0006  */
        public int write(Writer writer, int i2) {
            char[] cArr;
            int i3;
            int i4;
            int i5;
            int i6;
            while (getAvailable() < i2 && process()) {
                while (getAvailable() < i2) {
                    while (getAvailable() < i2) {
                    }
                }
            }
            int available = getAvailable();
            if (available > 0) {
                if (!$assertionsDisabled && this._out != 0) {
                    throw new AssertionError();
                } else if (!$assertionsDisabled && this._in < this._out) {
                    StringBuffer a = a.a("_in:");
                    a.append(this._in);
                    a.append(" < _out:");
                    a.append(this._out);
                    throw new AssertionError(a.toString());
                } else if ($assertionsDisabled || this._free == this._buf.length - this._in) {
                    try {
                        writer.write(this._buf, 0, available);
                        writer.flush();
                        int i7 = this._free + available;
                        this._free = i7;
                        if ($assertionsDisabled || i7 >= 0) {
                            this._in = 0;
                        } else {
                            throw new AssertionError();
                        }
                    } catch (IOException e2) {
                        throw new RuntimeException(e2);
                    }
                } else {
                    throw new AssertionError();
                }
            }
            if ($assertionsDisabled || (cArr = this._buf) == null || (((i3 = this._out) < (i4 = this._in) && this._free == cArr.length - (i4 - i3)) || (((i5 = this._out) > (i6 = this._in) && this._free == i5 - i6) || ((this._out == this._in && this._free == this._buf.length) || (this._out == this._in && this._free == 0))))) {
                return available;
            }
            StringBuffer a2 = a.a("_buf.length:");
            a2.append(this._buf.length);
            a2.append(" _in:");
            a2.append(this._in);
            a2.append(" _out:");
            a2.append(this._out);
            a2.append(" _free:");
            a2.append(this._free);
            throw new AssertionError(a2.toString());
        }

        private void emit(char c, char c2) {
            if (!preEmit(2)) {
                char[] cArr = this._buf;
                int i2 = this._in;
                cArr[i2] = c;
                int length = (i2 + 1) % cArr.length;
                this._in = length;
                cArr[length] = c2;
                int length2 = (length + 1) % cArr.length;
                this._in = length2;
                if (!$assertionsDisabled && cArr != null) {
                    int i3 = this._out;
                    if (i3 >= length2 || this._free != cArr.length - (length2 - i3)) {
                        int i4 = this._out;
                        int i5 = this._in;
                        if (i4 > i5 && this._free == i4 - i5) {
                            return;
                        }
                        if (this._out != this._in || this._free != this._buf.length) {
                            if (this._out != this._in || this._free != 0) {
                                StringBuffer a = a.a("_buf.length:");
                                a.append(this._buf.length);
                                a.append(" _in:");
                                a.append(this._in);
                                a.append(" _out:");
                                a.append(this._out);
                                a.append(" _free:");
                                a.append(this._free);
                                throw new AssertionError(a.toString());
                            }
                        }
                    }
                }
            }
        }

        public int read(char[] cArr, int i2, int i3) {
            int i4;
            int i5;
            int i6;
            int ensure = ensure(i3);
            if (ensure == 0) {
                return -1;
            }
            if (cArr == null || i3 <= 0) {
                return 0;
            }
            if (ensure < i3) {
                i3 = ensure;
            }
            int i7 = this._out;
            if (i7 < this._in) {
                System.arraycopy(this._buf, i7, cArr, i2, i3);
            } else {
                char[] cArr2 = this._buf;
                int length = cArr2.length - i7;
                if (length >= i3) {
                    System.arraycopy(cArr2, i7, cArr, i2, i3);
                } else {
                    System.arraycopy(cArr2, i7, cArr, i2, length);
                    System.arraycopy(this._buf, 0, cArr, i2 + length, i3 - length);
                }
            }
            char[] cArr3 = this._buf;
            int length2 = (this._out + i3) % cArr3.length;
            this._out = length2;
            int i8 = this._free + i3;
            this._free = i8;
            if (!$assertionsDisabled && cArr3 != null && ((length2 >= (i4 = this._in) || i8 != cArr3.length - (i4 - length2)) && (((i5 = this._out) <= (i6 = this._in) || this._free != i5 - i6) && ((this._out != this._in || this._free != this._buf.length) && (this._out != this._in || this._free != 0))))) {
                StringBuffer a = a.a("_buf.length:");
                a.append(this._buf.length);
                a.append(" _in:");
                a.append(this._in);
                a.append(" _out:");
                a.append(this._out);
                a.append(" _free:");
                a.append(this._free);
                throw new AssertionError(a.toString());
            } else if ($assertionsDisabled || this._free >= 0) {
                return i3;
            } else {
                throw new AssertionError();
            }
        }

        private void emit(String str) {
            int i2;
            char[] cArr;
            char[] cArr2;
            int i3;
            int i4;
            int i5;
            int i6;
            if ($assertionsDisabled || (cArr2 = this._buf) == null || (((i3 = this._out) < (i4 = this._in) && this._free == cArr2.length - (i4 - i3)) || (((i5 = this._out) > (i6 = this._in) && this._free == i5 - i6) || ((this._out == this._in && this._free == this._buf.length) || (this._out == this._in && this._free == 0))))) {
                if (str == null) {
                    i2 = 0;
                } else {
                    i2 = str.length();
                }
                if (!preEmit(i2)) {
                    int i7 = this._in;
                    if (i7 > this._out) {
                        char[] cArr3 = this._buf;
                        int length = cArr3.length - i7;
                        if (i2 >= length) {
                            str.getChars(0, length, cArr3, i7);
                            str.getChars(length, i2, this._buf, 0);
                            this._in = (this._in + i2) % this._buf.length;
                            if (!$assertionsDisabled && (cArr = this._buf) != null) {
                                int i8 = this._out;
                                int i9 = this._in;
                                if (i8 >= i9 || this._free != cArr.length - (i9 - i8)) {
                                    int i10 = this._out;
                                    int i11 = this._in;
                                    if (i10 > i11 && this._free == i10 - i11) {
                                        return;
                                    }
                                    if (this._out != this._in || this._free != this._buf.length) {
                                        if (this._out != this._in || this._free != 0) {
                                            StringBuffer a = a.a("_buf.length:");
                                            a.append(this._buf.length);
                                            a.append(" _in:");
                                            a.append(this._in);
                                            a.append(" _out:");
                                            a.append(this._out);
                                            a.append(" _free:");
                                            a.append(this._free);
                                            throw new AssertionError(a.toString());
                                        }
                                        return;
                                    }
                                    return;
                                }
                                return;
                            }
                            return;
                        }
                    }
                    str.getChars(0, i2, this._buf, this._in);
                    this._in += i2;
                    if (!$assertionsDisabled) {
                        return;
                    }
                    return;
                }
                return;
            }
            StringBuffer a2 = a.a("_buf.length:");
            a2.append(this._buf.length);
            a2.append(" _in:");
            a2.append(this._in);
            a2.append(" _out:");
            a2.append(this._out);
            a2.append(" _free:");
            a2.append(this._free);
            throw new AssertionError(a2.toString());
        }

        private void emit(SaveCur saveCur) {
            if (saveCur.isText()) {
                Object chars = saveCur.getChars();
                int i2 = saveCur._cchSrc;
                if (!preEmit(i2)) {
                    int i3 = this._in;
                    if (i3 > this._out) {
                        char[] cArr = this._buf;
                        int length = cArr.length - i3;
                        if (i2 >= length) {
                            CharUtil.getChars(cArr, i3, chars, saveCur._offSrc, length);
                            CharUtil.getChars(this._buf, 0, chars, saveCur._offSrc + length, i2 - length);
                            this._in = (this._in + i2) % this._buf.length;
                            return;
                        }
                    }
                    CharUtil.getChars(this._buf, this._in, chars, saveCur._offSrc, i2);
                    this._in += i2;
                    return;
                }
                return;
            }
            preEmit(0);
        }
    }
}
