package org.apache.xmlbeans.impl.tool;

import b.b.a.a.a;
import java.io.ByteArrayInputStream;
import java.io.ByteArrayOutputStream;
import java.io.IOException;
import java.io.InputStream;
import java.net.URI;
import java.net.URISyntaxException;
import java.net.URL;
import java.net.URLConnection;
import java.security.DigestInputStream;
import java.security.MessageDigest;
import java.security.NoSuchAlgorithmException;
import java.util.HashMap;
import java.util.HashSet;
import java.util.Iterator;
import java.util.Map;
import java.util.Set;
import org.apache.poi.openxml4j.opc.internal.ZipHelper;
import org.apache.xerces.xinclude.XIncludeHandler;
import org.apache.xmlbeans.XmlBeans;
import org.apache.xmlbeans.XmlOptions;
import org.apache.xmlbeans.impl.common.IOUtil;
import org.apache.xmlbeans.impl.tool.SchemaImportResolver;
import org.apache.xmlbeans.impl.util.HexBin;
import org.apache.xmlbeans.impl.xb.xsdownload.DownloadedSchemaEntry;
import org.apache.xmlbeans.impl.xb.xsdownload.DownloadedSchemasDocument;
import org.apache.xmlbeans.impl.xb.xsdschema.SchemaDocument;

public abstract class BaseSchemaResourceManager extends SchemaImportResolver {
    public static final String USER_AGENT;
    public String _defaultCopyDirectory;
    public DownloadedSchemasDocument _importsDoc;
    public Set _redownloadSet = new HashSet();
    public Map _resourceForCacheEntry = new HashMap();
    public Map _resourceForDigest = new HashMap();
    public Map _resourceForFilename = new HashMap();
    public Map _resourceForNamespace = new HashMap();
    public Map _resourceForURL = new HashMap();

    public class SchemaResource implements SchemaImportResolver.SchemaResource {
        public DownloadedSchemaEntry _cacheEntry;

        public SchemaResource(DownloadedSchemaEntry downloadedSchemaEntry) {
            this._cacheEntry = downloadedSchemaEntry;
        }

        public void addSchemaLocation(String str) {
            this._cacheEntry.addSchemaLocation(str);
        }

        public boolean equals(Object obj) {
            return this == obj || getFilename().equals(((SchemaResource) obj).getFilename());
        }

        public String getFilename() {
            return this._cacheEntry.getFilename();
        }

        @Override // org.apache.xmlbeans.impl.tool.SchemaImportResolver.SchemaResource
        public String getNamespace() {
            return this._cacheEntry.getNamespace();
        }

        @Override // org.apache.xmlbeans.impl.tool.SchemaImportResolver.SchemaResource
        public SchemaDocument.Schema getSchema() {
            if (!BaseSchemaResourceManager.this.fileExists(getFilename())) {
                BaseSchemaResourceManager.this.redownloadResource(this);
            }
            try {
                return SchemaDocument.Factory.parse(BaseSchemaResourceManager.this.inputStreamForFile(getFilename())).getSchema();
            } catch (Exception unused) {
                return null;
            }
        }

        @Override // org.apache.xmlbeans.impl.tool.SchemaImportResolver.SchemaResource
        public String getSchemaLocation() {
            if (this._cacheEntry.sizeOfSchemaLocationArray() > 0) {
                return this._cacheEntry.getSchemaLocationArray(0);
            }
            return null;
        }

        public String[] getSchemaLocationArray() {
            return this._cacheEntry.getSchemaLocationArray();
        }

        public String getSha1() {
            return this._cacheEntry.getSha1();
        }

        public int hashCode() {
            return getFilename().hashCode();
        }

        public void setFilename(String str) {
            this._cacheEntry.setFilename(str);
        }

        public void setNamespace(String str) {
            this._cacheEntry.setNamespace(str);
        }
    }

    static {
        StringBuffer a = a.a("XMLBeans/");
        a.append(XmlBeans.getVersion());
        a.append(" (");
        a.append(XmlBeans.getTitle());
        a.append(")");
        USER_AGENT = a.toString();
    }

    private DownloadedSchemaEntry addNewEntry() {
        return this._importsDoc.getDownloadedSchemas().addNewEntry();
    }

    private SchemaResource copyOrIdentifyDuplicateURL(String str, String str2) {
        try {
            String uniqueFilenameForURI = uniqueFilenameForURI(str);
            try {
                DigestInputStream digestInputStream = digestInputStream(new URL(str).openStream());
                writeInputStreamToFile(digestInputStream, uniqueFilenameForURI);
                String bytesToString = HexBin.bytesToString(digestInputStream.getMessageDigest().digest());
                SchemaResource schemaResource = (SchemaResource) this._resourceForDigest.get(bytesToString);
                if (schemaResource != null) {
                    deleteFile(uniqueFilenameForURI);
                    schemaResource.addSchemaLocation(str);
                    if (!this._resourceForURL.containsKey(str)) {
                        this._resourceForURL.put(str, schemaResource);
                    }
                    return schemaResource;
                }
                StringBuffer stringBuffer = new StringBuffer();
                stringBuffer.append("Downloaded ");
                stringBuffer.append(str);
                stringBuffer.append(" to ");
                stringBuffer.append(uniqueFilenameForURI);
                warning(stringBuffer.toString());
                DownloadedSchemaEntry addNewEntry = addNewEntry();
                addNewEntry.setFilename(uniqueFilenameForURI);
                addNewEntry.setSha1(bytesToString);
                if (str2 != null) {
                    addNewEntry.setNamespace(str2);
                }
                addNewEntry.addSchemaLocation(str);
                return updateResource(addNewEntry);
            } catch (Exception e2) {
                StringBuffer c = a.c("Could not copy remote resource ", str, ":");
                c.append(e2.getMessage());
                warning(c.toString());
                return null;
            }
        } catch (URISyntaxException e3) {
            StringBuffer c2 = a.c("Invalid URI '", str, "':");
            c2.append(e3.getMessage());
            warning(c2.toString());
            return null;
        } catch (IOException e4) {
            StringBuffer c3 = a.c("Could not create local file for ", str, ":");
            c3.append(e4.getMessage());
            warning(c3.toString());
            return null;
        }
    }

    private void deleteResourcesInSet(Set set, boolean z) {
        HashSet hashSet = new HashSet();
        Iterator it = set.iterator();
        while (it.hasNext()) {
            hashSet.add(((SchemaResource) it.next())._cacheEntry);
        }
        DownloadedSchemasDocument.DownloadedSchemas downloadedSchemas = this._importsDoc.getDownloadedSchemas();
        int i2 = 0;
        while (i2 < downloadedSchemas.sizeOfEntryArray()) {
            DownloadedSchemaEntry entryArray = downloadedSchemas.getEntryArray(i2);
            if (hashSet.contains(entryArray) == z) {
                SchemaResource schemaResource = (SchemaResource) this._resourceForCacheEntry.get(entryArray);
                StringBuffer a = a.a("Removing obsolete cache entry for ");
                a.append(schemaResource.getFilename());
                warning(a.toString());
                this._resourceForCacheEntry.remove(entryArray);
                if (schemaResource == this._resourceForFilename.get(schemaResource.getFilename())) {
                    this._resourceForFilename.remove(schemaResource.getFilename());
                }
                if (schemaResource == this._resourceForDigest.get(schemaResource.getSha1())) {
                    this._resourceForDigest.remove(schemaResource.getSha1());
                }
                if (schemaResource == this._resourceForNamespace.get(schemaResource.getNamespace())) {
                    this._resourceForNamespace.remove(schemaResource.getNamespace());
                }
                String[] schemaLocationArray = schemaResource.getSchemaLocationArray();
                for (int i3 = 0; i3 < schemaLocationArray.length; i3++) {
                    if (schemaResource == this._resourceForURL.get(schemaLocationArray[i3])) {
                        this._resourceForURL.remove(schemaLocationArray[i3]);
                    }
                }
                downloadedSchemas.removeEntry(i2);
                i2--;
            }
            i2++;
        }
    }

    public static DigestInputStream digestInputStream(InputStream inputStream) {
        try {
            return new DigestInputStream(inputStream, MessageDigest.getInstance("SHA"));
        } catch (NoSuchAlgorithmException e2) {
            throw ((IllegalStateException) new IllegalStateException().initCause(e2));
        }
    }

    private SchemaResource fetchFromCache(String str, String str2) {
        SchemaResource schemaResource;
        SchemaResource schemaResource2;
        if (str2 != null && (schemaResource2 = (SchemaResource) this._resourceForURL.get(str2)) != null) {
            return schemaResource2;
        }
        if (str == null || (schemaResource = (SchemaResource) this._resourceForNamespace.get(str)) == null) {
            return null;
        }
        return schemaResource;
    }

    private void redownloadEntries(SchemaResource[] schemaResourceArr) {
        for (SchemaResource schemaResource : schemaResourceArr) {
            redownloadResource(schemaResource);
        }
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private void redownloadResource(SchemaResource schemaResource) {
        Set set = this._redownloadSet;
        if (set != null) {
            if (!set.contains(schemaResource)) {
                this._redownloadSet.add(schemaResource);
            } else {
                return;
            }
        }
        String filename = schemaResource.getFilename();
        String schemaLocation = schemaResource.getSchemaLocation();
        if (schemaLocation != null && filename != null) {
            ByteArrayOutputStream byteArrayOutputStream = new ByteArrayOutputStream();
            try {
                URLConnection openConnection = new URL(schemaLocation).openConnection();
                openConnection.addRequestProperty("User-Agent", USER_AGENT);
                openConnection.addRequestProperty(XIncludeHandler.HTTP_ACCEPT, "application/xml, text/xml, */*");
                DigestInputStream digestInputStream = digestInputStream(openConnection.getInputStream());
                IOUtil.copyCompletely(digestInputStream, byteArrayOutputStream);
                if (!HexBin.bytesToString(digestInputStream.getMessageDigest().digest()).equals(schemaResource.getSha1()) || !fileExists(filename)) {
                    try {
                        writeInputStreamToFile(new ByteArrayInputStream(byteArrayOutputStream.toByteArray()), filename);
                        StringBuffer stringBuffer = new StringBuffer();
                        stringBuffer.append("Refreshed ");
                        stringBuffer.append(filename);
                        stringBuffer.append(" from ");
                        stringBuffer.append(schemaLocation);
                        warning(stringBuffer.toString());
                    } catch (IOException e2) {
                        StringBuffer c = a.c("Could not write to file ", filename, " for ", schemaLocation, ":");
                        c.append(e2.getMessage());
                        warning(c.toString());
                    }
                } else {
                    warning(a.a("Resource ", filename, " is unchanged from ", schemaLocation, "."));
                }
            } catch (Exception e3) {
                StringBuffer c2 = a.c("Could not copy remote resource ", schemaLocation, ":");
                c2.append(e3.getMessage());
                warning(c2.toString());
            }
        }
    }

    private String shaDigestForFile(String str) {
        DigestInputStream digestInputStream = digestInputStream(inputStreamForFile(str));
        byte[] bArr = new byte[4096];
        for (int i2 = 1; i2 > 0; i2 = digestInputStream.read(bArr)) {
        }
        digestInputStream.close();
        return HexBin.bytesToString(digestInputStream.getMessageDigest().digest());
    }

    private String uniqueFilenameForURI(String str) {
        String rawPath = new URI(str).getRawPath();
        int lastIndexOf = rawPath.lastIndexOf(47);
        int i2 = 1;
        if (lastIndexOf >= 0) {
            rawPath = rawPath.substring(lastIndexOf + 1);
        }
        if (rawPath.endsWith(XMLBean.XSD)) {
            rawPath = rawPath.substring(0, rawPath.length() - 4);
        }
        if (rawPath.length() == 0) {
            rawPath = "schema";
        }
        String str2 = rawPath;
        while (i2 < 1000) {
            StringBuffer stringBuffer = new StringBuffer();
            stringBuffer.append(this._defaultCopyDirectory);
            stringBuffer.append(ZipHelper.FORWARD_SLASH);
            stringBuffer.append(str2);
            stringBuffer.append(XMLBean.XSD);
            String stringBuffer2 = stringBuffer.toString();
            if (!fileExists(stringBuffer2)) {
                return stringBuffer2;
            }
            i2++;
            str2 = a.b(rawPath, i2);
        }
        throw new IOException(a.a("Problem with filename ", rawPath, XMLBean.XSD));
    }

    private SchemaResource updateResource(DownloadedSchemaEntry downloadedSchemaEntry) {
        String filename = downloadedSchemaEntry.getFilename();
        if (filename == null) {
            return null;
        }
        SchemaResource schemaResource = new SchemaResource(downloadedSchemaEntry);
        this._resourceForCacheEntry.put(downloadedSchemaEntry, schemaResource);
        if (!this._resourceForFilename.containsKey(filename)) {
            this._resourceForFilename.put(filename, schemaResource);
        }
        String sha1 = schemaResource.getSha1();
        if (sha1 != null && !this._resourceForDigest.containsKey(sha1)) {
            this._resourceForDigest.put(sha1, schemaResource);
        }
        String namespace = schemaResource.getNamespace();
        if (namespace != null && !this._resourceForNamespace.containsKey(namespace)) {
            this._resourceForNamespace.put(namespace, schemaResource);
        }
        String[] schemaLocationArray = schemaResource.getSchemaLocationArray();
        for (int i2 = 0; i2 < schemaLocationArray.length; i2++) {
            if (!this._resourceForURL.containsKey(schemaLocationArray[i2])) {
                this._resourceForURL.put(schemaLocationArray[i2], schemaResource);
            }
        }
        return schemaResource;
    }

    public abstract void deleteFile(String str);

    public abstract boolean fileExists(String str);

    public abstract String[] getAllXSDFilenames();

    public String getDefaultSchemaDir() {
        return "./schema";
    }

    public String getIndexFilename() {
        return "./xsdownload.xml";
    }

    public final void init() {
        DownloadedSchemaEntry[] entryArray;
        if (fileExists(getIndexFilename())) {
            try {
                this._importsDoc = DownloadedSchemasDocument.Factory.parse(inputStreamForFile(getIndexFilename()));
            } catch (IOException unused) {
                this._importsDoc = null;
            } catch (Exception e2) {
                throw ((IllegalStateException) new IllegalStateException("Problem reading xsdownload.xml: please fix or delete this file").initCause(e2));
            }
        }
        if (this._importsDoc == null) {
            try {
                StringBuffer stringBuffer = new StringBuffer();
                stringBuffer.append("<dls:downloaded-schemas xmlns:dls='http://www.bea.com/2003/01/xmlbean/xsdownload' defaultDirectory='");
                stringBuffer.append(getDefaultSchemaDir());
                stringBuffer.append("'/>");
                this._importsDoc = DownloadedSchemasDocument.Factory.parse(stringBuffer.toString());
            } catch (Exception e3) {
                throw ((IllegalStateException) new IllegalStateException().initCause(e3));
            }
        }
        String defaultDirectory = this._importsDoc.getDownloadedSchemas().getDefaultDirectory();
        if (defaultDirectory == null) {
            defaultDirectory = getDefaultSchemaDir();
        }
        this._defaultCopyDirectory = defaultDirectory;
        for (DownloadedSchemaEntry downloadedSchemaEntry : this._importsDoc.getDownloadedSchemas().getEntryArray()) {
            updateResource(downloadedSchemaEntry);
        }
    }

    public abstract InputStream inputStreamForFile(String str);

    @Override // org.apache.xmlbeans.impl.tool.SchemaImportResolver
    public SchemaImportResolver.SchemaResource lookupResource(String str, String str2) {
        SchemaResource fetchFromCache = fetchFromCache(str, str2);
        if (fetchFromCache != null) {
            if (this._redownloadSet != null) {
                redownloadResource(fetchFromCache);
            }
            return fetchFromCache;
        } else if (str2 == null) {
            StringBuffer stringBuffer = new StringBuffer();
            stringBuffer.append("No cached schema for namespace '");
            stringBuffer.append(str);
            stringBuffer.append("', and no url specified");
            warning(stringBuffer.toString());
            return null;
        } else {
            SchemaResource copyOrIdentifyDuplicateURL = copyOrIdentifyDuplicateURL(str2, str);
            Set set = this._redownloadSet;
            if (set != null) {
                set.add(copyOrIdentifyDuplicateURL);
            }
            return copyOrIdentifyDuplicateURL;
        }
    }

    public final void process(String[] strArr, String[] strArr2, boolean z, boolean z2, boolean z3) {
        if (z2) {
            this._redownloadSet = new HashSet();
        } else {
            this._redownloadSet = null;
        }
        if (strArr2.length > 0) {
            syncCacheWithLocalXsdFiles(strArr2, true);
        } else if (z) {
            syncCacheWithLocalXsdFiles(getAllXSDFilenames(), false);
        }
        HashSet hashSet = new HashSet();
        for (String str : strArr) {
            SchemaResource schemaResource = (SchemaResource) lookupResource(null, str);
            if (schemaResource != null) {
                hashSet.add(schemaResource);
            }
        }
        for (int i2 = 0; i2 < strArr2.length; i2++) {
            SchemaResource schemaResource2 = (SchemaResource) this._resourceForFilename.get(strArr2);
            if (schemaResource2 != null) {
                hashSet.add(schemaResource2);
            }
        }
        SchemaResource[] schemaResourceArr = (SchemaResource[]) hashSet.toArray(new SchemaResource[0]);
        if (z2) {
            redownloadEntries(schemaResourceArr);
        }
        if (z3) {
            resolveImports(schemaResourceArr);
        }
        this._redownloadSet = null;
    }

    public final void processAll(boolean z, boolean z2, boolean z3) {
        if (z2) {
            this._redownloadSet = new HashSet();
        } else {
            this._redownloadSet = null;
        }
        String[] allXSDFilenames = getAllXSDFilenames();
        if (z) {
            syncCacheWithLocalXsdFiles(allXSDFilenames, false);
        }
        SchemaResource[] schemaResourceArr = (SchemaResource[]) this._resourceForFilename.values().toArray(new SchemaResource[0]);
        if (z2) {
            redownloadEntries(schemaResourceArr);
        }
        if (z3) {
            resolveImports(schemaResourceArr);
        }
        this._redownloadSet = null;
    }

    @Override // org.apache.xmlbeans.impl.tool.SchemaImportResolver
    public void reportActualNamespace(SchemaImportResolver.SchemaResource schemaResource, String str) {
        SchemaResource schemaResource2 = (SchemaResource) schemaResource;
        String namespace = schemaResource2.getNamespace();
        if (namespace != null && this._resourceForNamespace.get(namespace) == schemaResource2) {
            this._resourceForNamespace.remove(namespace);
        }
        if (!this._resourceForNamespace.containsKey(str)) {
            this._resourceForNamespace.put(str, schemaResource2);
        }
        schemaResource2.setNamespace(str);
    }

    public final void syncCacheWithLocalXsdFiles(String[] strArr, boolean z) {
        HashSet hashSet = new HashSet();
        HashSet hashSet2 = new HashSet();
        for (String str : strArr) {
            SchemaResource schemaResource = (SchemaResource) this._resourceForFilename.get(str);
            if (schemaResource == null) {
                String str2 = null;
                try {
                    str2 = shaDigestForFile(str);
                    SchemaResource schemaResource2 = (SchemaResource) this._resourceForDigest.get(str2);
                    if (schemaResource2 != null) {
                        String filename = schemaResource2.getFilename();
                        if (!fileExists(filename)) {
                            StringBuffer stringBuffer = new StringBuffer();
                            stringBuffer.append("File ");
                            stringBuffer.append(str);
                            stringBuffer.append(" is a rename of ");
                            stringBuffer.append(filename);
                            warning(stringBuffer.toString());
                            schemaResource2.setFilename(str);
                            hashSet.add(schemaResource2);
                            if (this._resourceForFilename.get(filename) == schemaResource2) {
                                this._resourceForFilename.remove(filename);
                            }
                            if (this._resourceForFilename.containsKey(str)) {
                                this._resourceForFilename.put(str, schemaResource2);
                            }
                        }
                    }
                } catch (IOException unused) {
                }
                DownloadedSchemaEntry addNewEntry = addNewEntry();
                addNewEntry.setFilename(str);
                StringBuffer stringBuffer2 = new StringBuffer();
                stringBuffer2.append("Caching information on new local file ");
                stringBuffer2.append(str);
                warning(stringBuffer2.toString());
                if (str2 != null) {
                    addNewEntry.setSha1(str2);
                }
                hashSet.add(updateResource(addNewEntry));
            } else if (fileExists(str)) {
                hashSet.add(schemaResource);
            } else {
                hashSet2.add(schemaResource);
            }
        }
        if (z) {
            deleteResourcesInSet(hashSet2, true);
        } else {
            deleteResourcesInSet(hashSet, false);
        }
    }

    public abstract void warning(String str);

    public final void writeCache() {
        writeInputStreamToFile(this._importsDoc.newInputStream(new XmlOptions().setSavePrettyPrint()), getIndexFilename());
    }

    public abstract void writeInputStreamToFile(InputStream inputStream, String str);
}
