package org.apache.xmlbeans.impl.tool;

import b.b.a.a.a;
import java.io.File;
import java.io.FileInputStream;
import java.io.InputStreamReader;
import java.io.PrintStream;
import java.util.Arrays;
import java.util.HashSet;
import org.apache.xmlbeans.XmlBeans;
import org.apache.xmlbeans.XmlObject;
import org.apache.xmlbeans.XmlOptions;

public class RunXQuery {
    public static void main(String[] strArr) {
        HashSet hashSet = new HashSet();
        hashSet.add("h");
        hashSet.add("help");
        hashSet.add("usage");
        hashSet.add("license");
        hashSet.add("version");
        hashSet.add("verbose");
        hashSet.add("pretty");
        CommandLine commandLine = new CommandLine(strArr, hashSet, Arrays.asList("q", "qf"));
        if (commandLine.getOpt("h") == null && commandLine.getOpt("help") == null && commandLine.getOpt("usage") == null) {
            String[] badOpts = commandLine.getBadOpts();
            if (badOpts.length > 0) {
                for (String str : badOpts) {
                    PrintStream printStream = System.out;
                    StringBuffer a = a.a("Unrecognized option: ");
                    a.append(str);
                    printStream.println(a.toString());
                }
                printUsage();
                System.exit(0);
            } else if (commandLine.getOpt("license") != null) {
                CommandLine.printLicense();
                System.exit(0);
            } else if (commandLine.getOpt("version") != null) {
                CommandLine.printVersion();
                System.exit(0);
            } else if (commandLine.args().length == 0) {
                printUsage();
                System.exit(0);
            } else {
                boolean z = commandLine.getOpt("verbose") != null;
                boolean z2 = commandLine.getOpt("pretty") != null;
                String opt = commandLine.getOpt("q");
                String opt2 = commandLine.getOpt("qf");
                if (opt == null && opt2 == null) {
                    System.err.println("No query specified");
                    System.exit(0);
                } else if (opt == null || opt2 == null) {
                    if (opt2 != null) {
                        try {
                            FileInputStream fileInputStream = new FileInputStream(new File(opt2));
                            InputStreamReader inputStreamReader = new InputStreamReader(fileInputStream);
                            StringBuffer stringBuffer = new StringBuffer();
                            while (true) {
                                int read = inputStreamReader.read();
                                if (read < 0) {
                                    break;
                                }
                                stringBuffer.append((char) read);
                            }
                            inputStreamReader.close();
                            fileInputStream.close();
                            opt = stringBuffer.toString();
                        } catch (Throwable th) {
                            PrintStream printStream2 = System.err;
                            StringBuffer a2 = a.a("Cannot read query file: ");
                            a2.append(th.getMessage());
                            printStream2.println(a2.toString());
                            System.exit(1);
                            return;
                        }
                    }
                    if (z) {
                        System.out.println("Compile Query:");
                        System.out.println(opt);
                        System.out.println();
                    }
                    try {
                        String compileQuery = XmlBeans.compileQuery(opt);
                        File[] files = commandLine.getFiles();
                        for (int i2 = 0; i2 < files.length; i2++) {
                            if (z) {
                                try {
                                    FileInputStream fileInputStream2 = new FileInputStream(files[i2]);
                                    while (true) {
                                        int read2 = fileInputStream2.read();
                                        if (read2 < 0) {
                                            break;
                                        }
                                        System.out.write(read2);
                                    }
                                    fileInputStream2.close();
                                    System.out.println();
                                } catch (Throwable th2) {
                                    PrintStream printStream3 = System.err;
                                    StringBuffer a3 = a.a("Error parsing instance: ");
                                    a3.append(th2.getMessage());
                                    printStream3.println(a3.toString());
                                    System.exit(1);
                                    return;
                                }
                            }
                            XmlObject parse = XmlObject.Factory.parse(files[i2]);
                            if (z) {
                                System.out.println("Executing Query...");
                                System.err.println();
                            }
                            try {
                                XmlObject[] execQuery = parse.execQuery(compileQuery);
                                if (z) {
                                    System.out.println("Query Result:");
                                }
                                XmlOptions xmlOptions = new XmlOptions();
                                xmlOptions.setSaveOuter();
                                if (z2) {
                                    xmlOptions.setSavePrettyPrint();
                                }
                                for (XmlObject xmlObject : execQuery) {
                                    xmlObject.save(System.out, xmlOptions);
                                    System.out.println();
                                }
                            } catch (Throwable th3) {
                                PrintStream printStream4 = System.err;
                                StringBuffer a4 = a.a("Error executing query: ");
                                a4.append(th3.getMessage());
                                printStream4.println(a4.toString());
                                System.exit(1);
                                return;
                            }
                        }
                    } catch (Exception e2) {
                        PrintStream printStream5 = System.err;
                        StringBuffer a5 = a.a("Error compiling query: ");
                        a5.append(e2.getMessage());
                        printStream5.println(a5.toString());
                        System.exit(1);
                    }
                } else {
                    System.err.println("Specify -qf or -q, not both.");
                    System.exit(0);
                }
            }
        } else {
            printUsage();
            System.exit(0);
        }
    }

    public static void printUsage() {
        System.out.println("Run an XQuery against an XML instance");
        System.out.println("Usage:");
        System.out.println("xquery [-verbose] [-pretty] [-q <query> | -qf query.xq] [file.xml]*");
        System.out.println(" -q <query> to specify a query on the command-line");
        System.out.println(" -qf <query> to specify a file containing a query");
        System.out.println(" -pretty pretty-prints the results");
        System.out.println(" -license prints license information");
        System.out.println(" the query is run on each XML file specified");
        System.out.println("");
    }
}
