package org.apache.xmlbeans.impl.tool;

import b.b.a.a.a;
import java.io.File;
import java.io.IOException;
import java.io.PrintStream;
import java.net.URI;
import java.net.URL;
import java.util.ArrayList;
import java.util.Arrays;
import java.util.Collection;
import java.util.Collections;
import java.util.HashMap;
import java.util.HashSet;
import java.util.Iterator;
import java.util.List;
import java.util.Map;
import java.util.Set;
import java.util.StringTokenizer;
import org.apache.xerces.impl.xs.SchemaSymbols;
import org.apache.xmlbeans.ResourceLoader;
import org.apache.xmlbeans.SchemaCodePrinter;
import org.apache.xmlbeans.SchemaType;
import org.apache.xmlbeans.SchemaTypeLoader;
import org.apache.xmlbeans.SchemaTypeSystem;
import org.apache.xmlbeans.SimpleValue;
import org.apache.xmlbeans.SystemProperties;
import org.apache.xmlbeans.XmlBeans;
import org.apache.xmlbeans.XmlErrorCodes;
import org.apache.xmlbeans.XmlException;
import org.apache.xmlbeans.XmlObject;
import org.apache.xmlbeans.XmlOptions;
import org.apache.xmlbeans.impl.common.IOUtil;
import org.apache.xmlbeans.impl.common.JarHelper;
import org.apache.xmlbeans.impl.common.NameUtil;
import org.apache.xmlbeans.impl.common.ResolverUtil;
import org.apache.xmlbeans.impl.common.XmlErrorPrinter;
import org.apache.xmlbeans.impl.common.XmlErrorWatcher;
import org.apache.xmlbeans.impl.config.BindingConfigImpl;
import org.apache.xmlbeans.impl.schema.PathResourceLoader;
import org.apache.xmlbeans.impl.schema.SchemaTypeLoaderImpl;
import org.apache.xmlbeans.impl.schema.SchemaTypeSystemCompiler;
import org.apache.xmlbeans.impl.schema.SchemaTypeSystemImpl;
import org.apache.xmlbeans.impl.schema.StscState;
import org.apache.xmlbeans.impl.tool.Extension;
import org.apache.xmlbeans.impl.util.FilerImpl;
import org.apache.xmlbeans.impl.values.XmlListImpl;
import org.apache.xmlbeans.impl.xb.substwsdl.DefinitionsDocument;
import org.apache.xmlbeans.impl.xb.xmlconfig.ConfigDocument;
import org.apache.xmlbeans.impl.xb.xmlconfig.Extensionconfig;
import org.apache.xmlbeans.impl.xb.xsdschema.SchemaDocument;
import org.xml.sax.EntityResolver;
import repackage.Repackager;

public class SchemaCompiler {
    public static final String COMPATIBILITY_CONFIG_URI = "http://www.bea.com/2002/09/xbean/config";
    public static final String CONFIG_URI = "http://xml.apache.org/xmlbeans/2004/02/xbean/config";
    public static final Map MAP_COMPATIBILITY_CONFIG_URIS;
    public static /* synthetic */ Class class$org$apache$xmlbeans$SchemaTypeSystem;
    public static /* synthetic */ Class class$org$apache$xmlbeans$impl$xb$xsdschema$SchemaDocument;

    public static class Parameters {
        public File baseDir;
        public String catalogFile;
        public File classesDir;
        public File[] classpath;
        public String compiler;
        public File[] configFiles;
        public boolean debug;
        public boolean download;
        public EntityResolver entityResolver;
        public Collection errorListener;
        public List extensions = Collections.EMPTY_LIST;
        public boolean incrementalSrcGen;
        public File[] javaFiles;
        public String javasource;
        public Set mdefNamespaces = Collections.EMPTY_SET;
        public String memoryInitialSize;
        public String memoryMaximumSize;
        public String name;
        public boolean noAnn;
        public boolean noExt;
        public boolean noPvr;
        public boolean noUpa;
        public boolean noVDoc;
        public boolean nojavac;
        public File outputJar;
        public boolean quiet;
        public String repackage;
        public SchemaCodePrinter schemaCodePrinter;
        public File srcDir;
        public URL[] urlFiles;
        public boolean verbose;
        public File[] wsdlFiles;
        public File[] xsdFiles;

        public File getBaseDir() {
            return this.baseDir;
        }

        public String getCatalogFile() {
            return this.catalogFile;
        }

        public File getClassesDir() {
            return this.classesDir;
        }

        public File[] getClasspath() {
            return this.classpath;
        }

        public String getCompiler() {
            return this.compiler;
        }

        public File[] getConfigFiles() {
            return this.configFiles;
        }

        public EntityResolver getEntityResolver() {
            return this.entityResolver;
        }

        public Collection getErrorListener() {
            return this.errorListener;
        }

        public List getExtensions() {
            return this.extensions;
        }

        public String getJar() {
            return null;
        }

        public File[] getJavaFiles() {
            return this.javaFiles;
        }

        public String getJavaSource() {
            return this.javasource;
        }

        public Set getMdefNamespaces() {
            return this.mdefNamespaces;
        }

        public String getMemoryInitialSize() {
            return this.memoryInitialSize;
        }

        public String getMemoryMaximumSize() {
            return this.memoryMaximumSize;
        }

        public String getName() {
            return this.name;
        }

        public File getOutputJar() {
            return this.outputJar;
        }

        public String getRepackage() {
            return this.repackage;
        }

        public SchemaCodePrinter getSchemaCodePrinter() {
            return this.schemaCodePrinter;
        }

        public File getSrcDir() {
            return this.srcDir;
        }

        public URL[] getUrlFiles() {
            return this.urlFiles;
        }

        public File[] getWsdlFiles() {
            return this.wsdlFiles;
        }

        public File[] getXsdFiles() {
            return this.xsdFiles;
        }

        public boolean isDebug() {
            return this.debug;
        }

        public boolean isDownload() {
            return this.download;
        }

        public boolean isIncrementalSrcGen() {
            return this.incrementalSrcGen;
        }

        public boolean isNoAnn() {
            return this.noAnn;
        }

        public boolean isNoExt() {
            return this.noExt;
        }

        public boolean isNoPvr() {
            return this.noPvr;
        }

        public boolean isNoUpa() {
            return this.noUpa;
        }

        public boolean isNoVDoc() {
            return this.noVDoc;
        }

        public boolean isNojavac() {
            return this.nojavac;
        }

        public boolean isQuiet() {
            return this.quiet;
        }

        public boolean isVerbose() {
            return this.verbose;
        }

        public void setBaseDir(File file) {
            this.baseDir = file;
        }

        public void setCatalogFile(String str) {
            this.catalogFile = str;
        }

        public void setClassesDir(File file) {
            this.classesDir = file;
        }

        public void setClasspath(File[] fileArr) {
            this.classpath = fileArr;
        }

        public void setCompiler(String str) {
            this.compiler = str;
        }

        public void setConfigFiles(File[] fileArr) {
            this.configFiles = fileArr;
        }

        public void setDebug(boolean z) {
            this.debug = z;
        }

        public void setDownload(boolean z) {
            this.download = z;
        }

        public void setEntityResolver(EntityResolver entityResolver2) {
            this.entityResolver = entityResolver2;
        }

        public void setErrorListener(Collection collection) {
            this.errorListener = collection;
        }

        public void setExtensions(List list) {
            this.extensions = list;
        }

        public void setIncrementalSrcGen(boolean z) {
            this.incrementalSrcGen = z;
        }

        public void setJar(String str) {
        }

        public void setJavaFiles(File[] fileArr) {
            this.javaFiles = fileArr;
        }

        public void setJavaSource(String str) {
            this.javasource = str;
        }

        public void setMdefNamespaces(Set set) {
            this.mdefNamespaces = set;
        }

        public void setMemoryInitialSize(String str) {
            this.memoryInitialSize = str;
        }

        public void setMemoryMaximumSize(String str) {
            this.memoryMaximumSize = str;
        }

        public void setName(String str) {
            this.name = str;
        }

        public void setNoAnn(boolean z) {
            this.noAnn = z;
        }

        public void setNoExt(boolean z) {
            this.noExt = z;
        }

        public void setNoPvr(boolean z) {
            this.noPvr = z;
        }

        public void setNoUpa(boolean z) {
            this.noUpa = z;
        }

        public void setNoVDoc(boolean z) {
            this.noVDoc = z;
        }

        public void setNojavac(boolean z) {
            this.nojavac = z;
        }

        public void setOutputJar(File file) {
            this.outputJar = file;
        }

        public void setQuiet(boolean z) {
            this.quiet = z;
        }

        public void setRepackage(String str) {
            this.repackage = str;
        }

        public void setSchemaCodePrinter(SchemaCodePrinter schemaCodePrinter2) {
            this.schemaCodePrinter = schemaCodePrinter2;
        }

        public void setSrcDir(File file) {
            this.srcDir = file;
        }

        public void setUrlFiles(URL[] urlArr) {
            this.urlFiles = urlArr;
        }

        public void setVerbose(boolean z) {
            this.verbose = z;
        }

        public void setWsdlFiles(File[] fileArr) {
            this.wsdlFiles = fileArr;
        }

        public void setXsdFiles(File[] fileArr) {
            this.xsdFiles = fileArr;
        }
    }

    static {
        HashMap hashMap = new HashMap();
        MAP_COMPATIBILITY_CONFIG_URIS = hashMap;
        hashMap.put(COMPATIBILITY_CONFIG_URI, CONFIG_URI);
    }

    public static void addSchema(String str, SchemaDocument schemaDocument, XmlErrorWatcher xmlErrorWatcher, boolean z, List list) {
        StringBuffer stringBuffer = new StringBuffer();
        stringBuffer.append("Loading schema file ");
        stringBuffer.append(str);
        StscState.addInfo(xmlErrorWatcher, stringBuffer.toString());
        XmlOptions errorListener = new XmlOptions().setErrorListener(xmlErrorWatcher);
        if (z) {
            errorListener.setValidateTreatLaxAsSkip();
        }
        if (schemaDocument.validate(errorListener)) {
            list.add(schemaDocument.getSchema());
        }
    }

    public static void addWsdlSchemas(String str, DefinitionsDocument definitionsDocument, XmlErrorWatcher xmlErrorWatcher, boolean z, List list) {
        XmlObject[] typesArray;
        if (wsdlContainsEncoded(definitionsDocument)) {
            StscState.addWarning(xmlErrorWatcher, a.a("The WSDL ", str, " uses SOAP encoding. SOAP encoding is not compatible with literal XML Schema."), 60, definitionsDocument);
        }
        StringBuffer stringBuffer = new StringBuffer();
        stringBuffer.append("Loading wsdl file ");
        stringBuffer.append(str);
        StscState.addInfo(xmlErrorWatcher, stringBuffer.toString());
        XmlOptions errorListener = new XmlOptions().setErrorListener(xmlErrorWatcher);
        if (z) {
            errorListener.setValidateTreatLaxAsSkip();
        }
        int i2 = 0;
        for (XmlObject xmlObject : definitionsDocument.getDefinitions().getTypesArray()) {
            XmlObject[] selectPath = xmlObject.selectPath("declare namespace xs=\"http://www.w3.org/2001/XMLSchema\" xs:schema");
            if (selectPath.length == 0) {
                StscState.addWarning(xmlErrorWatcher, a.a("The WSDL ", str, " did not have any schema documents in namespace 'http://www.w3.org/2001/XMLSchema'"), 60, definitionsDocument);
            } else {
                for (int i3 = 0; i3 < selectPath.length; i3++) {
                    if ((selectPath[i3] instanceof SchemaDocument.Schema) && selectPath[i3].validate(errorListener)) {
                        i2++;
                        list.add(selectPath[i3]);
                    }
                }
            }
        }
        StringBuffer stringBuffer2 = new StringBuffer();
        stringBuffer2.append("Processing ");
        stringBuffer2.append(i2);
        stringBuffer2.append(" schema(s) in ");
        stringBuffer2.append(str);
        StscState.addInfo(xmlErrorWatcher, stringBuffer2.toString());
    }

    public static /* synthetic */ Class class$(String str) {
        try {
            return Class.forName(str);
        } catch (ClassNotFoundException e2) {
            throw a.a(e2);
        }
    }

    /* JADX WARNING: Removed duplicated region for block: B:74:0x02a7 A[ADDED_TO_REGION] */
    /* JADX WARNING: Removed duplicated region for block: B:78:0x02b8  */
    public static boolean compile(Parameters parameters) {
        boolean z;
        String str;
        File file;
        String str2;
        File file2;
        Repackager repackager;
        IOException e2;
        File baseDir = parameters.getBaseDir();
        File[] xsdFiles = parameters.getXsdFiles();
        File[] wsdlFiles = parameters.getWsdlFiles();
        URL[] urlFiles = parameters.getUrlFiles();
        File[] javaFiles = parameters.getJavaFiles();
        File[] configFiles = parameters.getConfigFiles();
        File[] classpath = parameters.getClasspath();
        File outputJar = parameters.getOutputJar();
        String name = parameters.getName();
        File srcDir = parameters.getSrcDir();
        File classesDir = parameters.getClassesDir();
        String compiler = parameters.getCompiler();
        String javaSource = parameters.getJavaSource();
        String memoryInitialSize = parameters.getMemoryInitialSize();
        String memoryMaximumSize = parameters.getMemoryMaximumSize();
        boolean isNojavac = parameters.isNojavac();
        boolean isDebug = parameters.isDebug();
        boolean isVerbose = parameters.isVerbose();
        boolean isQuiet = parameters.isQuiet();
        boolean isDownload = parameters.isDownload();
        boolean isNoUpa = parameters.isNoUpa();
        boolean isNoPvr = parameters.isNoPvr();
        boolean isNoAnn = parameters.isNoAnn();
        boolean isNoVDoc = parameters.isNoVDoc();
        boolean isNoExt = parameters.isNoExt();
        boolean isIncrementalSrcGen = parameters.isIncrementalSrcGen();
        Collection errorListener = parameters.getErrorListener();
        String repackage = parameters.getRepackage();
        if (repackage != null) {
            SchemaTypeLoaderImpl.METADATA_PACKAGE_LOAD = SchemaTypeSystemImpl.METADATA_PACKAGE_GEN;
            Class cls = class$org$apache$xmlbeans$SchemaTypeSystem;
            if (cls == null) {
                cls = class$("org.apache.xmlbeans.SchemaTypeSystem");
                class$org$apache$xmlbeans$SchemaTypeSystem = cls;
            }
            str2 = javaSource;
            String name2 = cls.getPackage().getName();
            file = outputJar;
            str = repackage;
            z = isNoPvr;
            SchemaTypeSystemImpl.METADATA_PACKAGE_GEN = new Repackager(repackage).repackage(new StringBuffer(name2)).toString().replace(NameUtil.PERIOD, NameUtil.USCORE);
            PrintStream printStream = System.out;
            StringBuffer c = a.c("\n\n\n", name2, ".SchemaCompiler  Metadata LOAD:");
            c.append(SchemaTypeLoaderImpl.METADATA_PACKAGE_LOAD);
            c.append(" GEN:");
            c.append(SchemaTypeSystemImpl.METADATA_PACKAGE_GEN);
            printStream.println(c.toString());
        } else {
            str = repackage;
            z = isNoPvr;
            str2 = javaSource;
            file = outputJar;
        }
        SchemaCodePrinter schemaCodePrinter = parameters.getSchemaCodePrinter();
        List extensions = parameters.getExtensions();
        Set mdefNamespaces = parameters.getMdefNamespaces();
        EntityResolver resolverForCatalog = parameters.getEntityResolver() == null ? ResolverUtil.resolverForCatalog(parameters.getCatalogFile()) : parameters.getEntityResolver();
        if (srcDir == null || classesDir == null) {
            throw new IllegalArgumentException("src and class gen directories may not be null.");
        }
        long currentTimeMillis = System.currentTimeMillis();
        if (baseDir == null) {
            baseDir = new File(SystemProperties.getProperty("user.dir"));
        }
        HashMap hashMap = new HashMap();
        PathResourceLoader pathResourceLoader = classpath != null ? new PathResourceLoader(classpath) : null;
        StringBuffer a = a.a("schema");
        a.append(SchemaTypeSystemImpl.METADATA_PACKAGE_GEN);
        a.append("/src");
        File createDir = IOUtil.createDir(classesDir, a.toString());
        XmlErrorWatcher xmlErrorWatcher = new XmlErrorWatcher(errorListener);
        SchemaTypeSystem loadTypeSystem = loadTypeSystem(name, xsdFiles, wsdlFiles, urlFiles, configFiles, javaFiles, pathResourceLoader, isDownload, isNoUpa, z, isNoAnn, isNoVDoc, isNoExt, mdefNamespaces, baseDir, hashMap, xmlErrorWatcher, createDir, resolverForCatalog, classpath, str2);
        boolean z2 = !xmlErrorWatcher.hasError();
        long currentTimeMillis2 = System.currentTimeMillis();
        if (!isQuiet) {
            PrintStream printStream2 = System.out;
            StringBuffer a2 = a.a("Time to build schema type system: ");
            a2.append(((double) (currentTimeMillis2 - currentTimeMillis)) / 1000.0d);
            a2.append(" seconds");
            printStream2.println(a2.toString());
        }
        if (z2 && loadTypeSystem != null) {
            long currentTimeMillis3 = System.currentTimeMillis();
            if (str == null) {
                repackager = null;
            } else {
                repackager = new Repackager(str);
            }
            FilerImpl filerImpl = new FilerImpl(classesDir, srcDir, repackager, isVerbose, isIncrementalSrcGen);
            XmlOptions xmlOptions = new XmlOptions();
            if (schemaCodePrinter != null) {
                xmlOptions.setSchemaCodePrinter(schemaCodePrinter);
            }
            if (str2 != null) {
                xmlOptions.setGenerateJavaVersion(str2);
            }
            loadTypeSystem.save(filerImpl);
            z2 &= SchemaTypeSystemCompiler.generateTypes(loadTypeSystem, filerImpl, xmlOptions);
            if (isIncrementalSrcGen) {
                SchemaCodeGenerator.deleteObsoleteFiles(srcDir, srcDir, new HashSet(filerImpl.getSourceFiles()));
            }
            if (z2) {
                long currentTimeMillis4 = System.currentTimeMillis();
                if (!isQuiet) {
                    PrintStream printStream3 = System.out;
                    StringBuffer a3 = a.a("Time to generate code: ");
                    a3.append(((double) (currentTimeMillis4 - currentTimeMillis3)) / 1000.0d);
                    a3.append(" seconds");
                    printStream3.println(a3.toString());
                }
            }
            if (z2 && !isNojavac) {
                long currentTimeMillis5 = System.currentTimeMillis();
                List sourceFiles = filerImpl.getSourceFiles();
                if (javaFiles != null) {
                    sourceFiles.addAll(Arrays.asList(javaFiles));
                }
                if (!CodeGenUtil.externalCompile(sourceFiles, classesDir, classpath, isDebug, compiler, str2, memoryInitialSize, memoryMaximumSize, isQuiet, isVerbose)) {
                    z2 = false;
                }
                long currentTimeMillis6 = System.currentTimeMillis();
                if (z2 && !parameters.isQuiet()) {
                    PrintStream printStream4 = System.out;
                    StringBuffer a4 = a.a("Time to compile code: ");
                    a4.append(((double) (currentTimeMillis6 - currentTimeMillis5)) / 1000.0d);
                    a4.append(" seconds");
                    printStream4.println(a4.toString());
                }
                if (z2 && file != null) {
                    try {
                        file2 = classesDir;
                        try {
                            new JarHelper().jarDir(file2, file);
                        } catch (IOException e3) {
                            e2 = e3;
                        }
                    } catch (IOException e4) {
                        e2 = e4;
                        file2 = classesDir;
                        PrintStream printStream5 = System.err;
                        StringBuffer stringBuffer = new StringBuffer();
                        stringBuffer.append("IO Error ");
                        stringBuffer.append(e2);
                        printStream5.println(stringBuffer.toString());
                        z2 = false;
                        PrintStream printStream6 = System.out;
                        StringBuffer stringBuffer2 = new StringBuffer();
                        stringBuffer2.append("Compiled types to: ");
                        stringBuffer2.append(file);
                        printStream6.println(stringBuffer2.toString());
                        if (!z2) {
                        }
                        runExtensions(extensions, loadTypeSystem, file2);
                        if (pathResourceLoader != null) {
                        }
                        return z2;
                    }
                    if (z2 && !parameters.isQuiet()) {
                        PrintStream printStream62 = System.out;
                        StringBuffer stringBuffer22 = new StringBuffer();
                        stringBuffer22.append("Compiled types to: ");
                        stringBuffer22.append(file);
                        printStream62.println(stringBuffer22.toString());
                    }
                    if (!z2 || isQuiet) {
                        runExtensions(extensions, loadTypeSystem, file2);
                    } else {
                        System.out.println("BUILD FAILED");
                    }
                    if (pathResourceLoader != null) {
                        pathResourceLoader.close();
                    }
                    return z2;
                }
            }
        }
        file2 = classesDir;
        if (!z2) {
        }
        runExtensions(extensions, loadTypeSystem, file2);
        if (pathResourceLoader != null) {
        }
        return z2;
    }

    /* JADX WARNING: Code restructure failed: missing block: B:72:0x01e4, code lost:
        r0 = e;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:80:0x0221, code lost:
        r0 = move-exception;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:81:0x0222, code lost:
        org.apache.xmlbeans.impl.schema.StscState.addError(r11, org.apache.xmlbeans.XmlErrorCodes.CANNOT_LOAD_FILE, new java.lang.Object[]{r9, r23[r4], r0.getMessage()}, r23[r4]);
     */
    /* JADX WARNING: Failed to process nested try/catch */
    /* JADX WARNING: Removed duplicated region for block: B:80:0x0221 A[ExcHandler: Exception (r0v18 'e' java.lang.Exception A[CUSTOM_DECLARE]), Splitter:B:64:0x01b8] */
    public static SchemaTypeSystem loadTypeSystem(String str, File[] fileArr, File[] fileArr2, URL[] urlArr, File[] fileArr3, File[] fileArr4, ResourceLoader resourceLoader, boolean z, boolean z2, boolean z3, boolean z4, boolean z5, boolean z6, Set set, File file, Map map, Collection collection, File file2, EntityResolver entityResolver, File[] fileArr5, String str2) {
        String str3;
        XmlException e2;
        Exception e3;
        String str4 = "xsd config";
        XmlErrorWatcher xmlErrorWatcher = new XmlErrorWatcher(collection);
        StscState.start().setErrorListener(xmlErrorWatcher);
        Class cls = class$org$apache$xmlbeans$impl$xb$xsdschema$SchemaDocument;
        if (cls == null) {
            cls = class$("org.apache.xmlbeans.impl.xb.xsdschema.SchemaDocument");
            class$org$apache$xmlbeans$impl$xb$xsdschema$SchemaDocument = cls;
        }
        SchemaTypeLoader typeLoaderForClassLoader = XmlBeans.typeLoaderForClassLoader(cls.getClassLoader());
        ArrayList arrayList = new ArrayList();
        if (fileArr != null) {
            int i2 = 0;
            while (i2 < fileArr.length) {
                try {
                    XmlOptions xmlOptions = new XmlOptions();
                    xmlOptions.setLoadLineNumbers();
                    xmlOptions.setLoadMessageDigest();
                    xmlOptions.setEntityResolver(entityResolver);
                    str3 = str4;
                    try {
                        XmlObject parse = typeLoaderForClassLoader.parse(fileArr[i2], (SchemaType) null, xmlOptions);
                        if (!(parse instanceof SchemaDocument)) {
                            StscState.addError(xmlErrorWatcher, XmlErrorCodes.INVALID_DOCUMENT_TYPE, new Object[]{fileArr[i2], "schema"}, parse);
                        } else {
                            addSchema(fileArr[i2].toString(), (SchemaDocument) parse, xmlErrorWatcher, z5, arrayList);
                        }
                    } catch (XmlException e4) {
                        e2 = e4;
                        xmlErrorWatcher.add(e2.getError());
                        i2++;
                        str4 = str3;
                    } catch (Exception e5) {
                        e3 = e5;
                        StscState.addError(xmlErrorWatcher, XmlErrorCodes.CANNOT_LOAD_FILE, new Object[]{"xsd", fileArr[i2], e3.getMessage()}, fileArr[i2]);
                        i2++;
                        str4 = str3;
                    }
                } catch (XmlException e6) {
                    e2 = e6;
                    str3 = str4;
                    xmlErrorWatcher.add(e2.getError());
                    i2++;
                    str4 = str3;
                } catch (Exception e7) {
                    e3 = e7;
                    str3 = str4;
                    StscState.addError(xmlErrorWatcher, XmlErrorCodes.CANNOT_LOAD_FILE, new Object[]{"xsd", fileArr[i2], e3.getMessage()}, fileArr[i2]);
                    i2++;
                    str4 = str3;
                }
                i2++;
                str4 = str3;
            }
        }
        if (fileArr2 != null) {
            for (int i3 = 0; i3 < fileArr2.length; i3++) {
                try {
                    XmlOptions xmlOptions2 = new XmlOptions();
                    xmlOptions2.setLoadLineNumbers();
                    xmlOptions2.setLoadSubstituteNamespaces(Collections.singletonMap("http://schemas.xmlsoap.org/wsdl/", "http://www.apache.org/internal/xmlbeans/wsdlsubst"));
                    xmlOptions2.setEntityResolver(entityResolver);
                    XmlObject parse2 = typeLoaderForClassLoader.parse(fileArr2[i3], (SchemaType) null, xmlOptions2);
                    if (!(parse2 instanceof DefinitionsDocument)) {
                        StscState.addError(xmlErrorWatcher, XmlErrorCodes.INVALID_DOCUMENT_TYPE, new Object[]{fileArr2[i3], "wsdl"}, parse2);
                    } else {
                        addWsdlSchemas(fileArr2[i3].toString(), (DefinitionsDocument) parse2, xmlErrorWatcher, z5, arrayList);
                    }
                } catch (XmlException e8) {
                    xmlErrorWatcher.add(e8.getError());
                } catch (Exception e9) {
                    StscState.addError(xmlErrorWatcher, XmlErrorCodes.CANNOT_LOAD_FILE, new Object[]{"wsdl", fileArr2[i3], e9.getMessage()}, fileArr2[i3]);
                }
            }
        }
        if (urlArr != null) {
            for (int i4 = 0; i4 < urlArr.length; i4++) {
                try {
                    XmlOptions xmlOptions3 = new XmlOptions();
                    xmlOptions3.setLoadLineNumbers();
                    xmlOptions3.setLoadSubstituteNamespaces(Collections.singletonMap("http://schemas.xmlsoap.org/wsdl/", "http://www.apache.org/internal/xmlbeans/wsdlsubst"));
                    xmlOptions3.setEntityResolver(entityResolver);
                    XmlObject parse3 = typeLoaderForClassLoader.parse(urlArr[i4], (SchemaType) null, xmlOptions3);
                    if (parse3 instanceof DefinitionsDocument) {
                        addWsdlSchemas(urlArr[i4].toString(), (DefinitionsDocument) parse3, xmlErrorWatcher, z5, arrayList);
                    } else if (parse3 instanceof SchemaDocument) {
                        addSchema(urlArr[i4].toString(), (SchemaDocument) parse3, xmlErrorWatcher, z5, arrayList);
                    } else {
                        StscState.addError(xmlErrorWatcher, XmlErrorCodes.INVALID_DOCUMENT_TYPE, new Object[]{urlArr[i4], "wsdl or schema"}, parse3);
                    }
                } catch (XmlException e10) {
                    xmlErrorWatcher.add(e10.getError());
                } catch (Exception e11) {
                    StscState.addError(xmlErrorWatcher, XmlErrorCodes.CANNOT_LOAD_FILE, new Object[]{"url", urlArr[i4], e11.getMessage()}, urlArr[i4]);
                }
            }
        }
        SchemaDocument.Schema[] schemaArr = (SchemaDocument.Schema[]) arrayList.toArray(new SchemaDocument.Schema[arrayList.size()]);
        ArrayList arrayList2 = new ArrayList();
        if (fileArr3 != null) {
            if (z6) {
                System.out.println("Pre/Post and Interface extensions will be ignored.");
            }
            int i5 = 0;
            while (i5 < fileArr3.length) {
                try {
                    XmlOptions xmlOptions4 = new XmlOptions();
                    xmlOptions4.put(XmlOptions.LOAD_LINE_NUMBERS);
                    xmlOptions4.setEntityResolver(entityResolver);
                    xmlOptions4.setLoadSubstituteNamespaces(MAP_COMPATIBILITY_CONFIG_URIS);
                    XmlObject parse4 = typeLoaderForClassLoader.parse(fileArr3[i5], (SchemaType) null, xmlOptions4);
                    if (!(parse4 instanceof ConfigDocument)) {
                        Object[] objArr = new Object[2];
                        objArr[0] = fileArr3[i5];
                        objArr[1] = str4;
                        StscState.addError(xmlErrorWatcher, XmlErrorCodes.INVALID_DOCUMENT_TYPE, objArr, parse4);
                    } else {
                        StringBuffer stringBuffer = new StringBuffer();
                        stringBuffer.append("Loading config file ");
                        stringBuffer.append(fileArr3[i5]);
                        StscState.addInfo(xmlErrorWatcher, stringBuffer.toString());
                        if (parse4.validate(new XmlOptions().setErrorListener(xmlErrorWatcher))) {
                            ConfigDocument.Config config = ((ConfigDocument) parse4).getConfig();
                            arrayList2.add(config);
                            if (z6) {
                                config.setExtensionArray(new Extensionconfig[0]);
                            }
                        }
                    }
                } catch (XmlException e12) {
                    XmlException e13 = e12;
                    xmlErrorWatcher.add(e13.getError());
                } catch (Exception e14) {
                }
                i5++;
            }
        }
        ConfigDocument.Config[] configArr = (ConfigDocument.Config[]) arrayList2.toArray(new ConfigDocument.Config[arrayList2.size()]);
        SchemaTypeLoader build = SchemaTypeLoaderImpl.build(null, resourceLoader, null);
        URI uri = file != null ? file.toURI() : null;
        XmlOptions xmlOptions5 = new XmlOptions();
        if (z) {
            xmlOptions5.setCompileDownloadUrls();
        }
        if (z2) {
            xmlOptions5.setCompileNoUpaRule();
        }
        if (z3) {
            xmlOptions5.setCompileNoPvrRule();
        }
        if (z4) {
            xmlOptions5.setCompileNoAnnotations();
        }
        if (set != null) {
            xmlOptions5.setCompileMdefNamespaces(set);
        }
        xmlOptions5.setCompileNoValidation();
        xmlOptions5.setEntityResolver(entityResolver);
        if (str2 != null) {
            xmlOptions5.setGenerateJavaVersion(str2);
        }
        SchemaTypeSystemCompiler.Parameters parameters = new SchemaTypeSystemCompiler.Parameters();
        parameters.setName(str);
        parameters.setSchemas(schemaArr);
        parameters.setConfig(BindingConfigImpl.forConfigDocuments(configArr, fileArr4, fileArr5));
        parameters.setLinkTo(build);
        parameters.setOptions(xmlOptions5);
        parameters.setErrorListener(xmlErrorWatcher);
        parameters.setJavaize(true);
        parameters.setBaseURI(uri);
        parameters.setSourcesToCopyMap(map);
        parameters.setSchemasDir(file2);
        return SchemaTypeSystemCompiler.compile(parameters);
    }

    /* JADX WARNING: Removed duplicated region for block: B:104:0x0267  */
    /* JADX WARNING: Removed duplicated region for block: B:112:0x0295  */
    /* JADX WARNING: Removed duplicated region for block: B:119:0x02d1  */
    /* JADX WARNING: Removed duplicated region for block: B:120:0x02d7  */
    /* JADX WARNING: Removed duplicated region for block: B:123:0x02e0  */
    /* JADX WARNING: Removed duplicated region for block: B:124:0x02e6  */
    /* JADX WARNING: Removed duplicated region for block: B:130:0x02f0 A[ADDED_TO_REGION] */
    /* JADX WARNING: Removed duplicated region for block: B:143:0x032c  */
    /* JADX WARNING: Removed duplicated region for block: B:144:0x0332  */
    /* JADX WARNING: Removed duplicated region for block: B:146:0x0335  */
    /* JADX WARNING: Removed duplicated region for block: B:148:0x033b  */
    /* JADX WARNING: Removed duplicated region for block: B:151:0x0349  */
    /* JADX WARNING: Removed duplicated region for block: B:156:0x0378  */
    /* JADX WARNING: Removed duplicated region for block: B:163:0x03d8  */
    /* JADX WARNING: Removed duplicated region for block: B:166:0x03e9  */
    /* JADX WARNING: Removed duplicated region for block: B:167:0x03eb  */
    /* JADX WARNING: Removed duplicated region for block: B:170:0x0484  */
    /* JADX WARNING: Removed duplicated region for block: B:172:0x0489  */
    /* JADX WARNING: Removed duplicated region for block: B:48:0x0185  */
    /* JADX WARNING: Removed duplicated region for block: B:49:0x0188  */
    /* JADX WARNING: Removed duplicated region for block: B:52:0x0190  */
    /* JADX WARNING: Removed duplicated region for block: B:53:0x0193  */
    /* JADX WARNING: Removed duplicated region for block: B:56:0x019b  */
    /* JADX WARNING: Removed duplicated region for block: B:57:0x019e  */
    /* JADX WARNING: Removed duplicated region for block: B:60:0x01a6  */
    /* JADX WARNING: Removed duplicated region for block: B:61:0x01ab  */
    /* JADX WARNING: Removed duplicated region for block: B:64:0x01b5  */
    /* JADX WARNING: Removed duplicated region for block: B:65:0x01ba  */
    /* JADX WARNING: Removed duplicated region for block: B:68:0x01c4  */
    /* JADX WARNING: Removed duplicated region for block: B:69:0x01c9  */
    /* JADX WARNING: Removed duplicated region for block: B:72:0x01d3  */
    /* JADX WARNING: Removed duplicated region for block: B:73:0x01d8  */
    /* JADX WARNING: Removed duplicated region for block: B:76:0x01e2  */
    /* JADX WARNING: Removed duplicated region for block: B:77:0x01e5  */
    /* JADX WARNING: Removed duplicated region for block: B:80:0x01ef  */
    /* JADX WARNING: Removed duplicated region for block: B:81:0x01f6  */
    /* JADX WARNING: Removed duplicated region for block: B:84:0x0214  */
    public static void main(String[] strArr) {
        SchemaCodePrinter schemaCodePrinter;
        boolean z;
        String str;
        boolean z2;
        String str2;
        boolean z3;
        String str3;
        boolean z4;
        String str4;
        String opt;
        HashSet hashSet;
        SchemaCodePrinter schemaCodePrinter2;
        ArrayList arrayList;
        String str5;
        boolean z5;
        boolean z6;
        boolean z7;
        File file;
        File file2;
        boolean z8;
        ArrayList arrayList2;
        File file3;
        String opt2;
        File file4;
        File[] fileArr;
        File[] filesEndingWith;
        File[] filesEndingWith2;
        URL[] uRLs;
        File baseDir;
        URI uri;
        boolean compile;
        StringTokenizer stringTokenizer;
        StringTokenizer stringTokenizer2;
        if (strArr.length == 0) {
            printUsage();
            System.exit(0);
            return;
        }
        HashSet hashSet2 = new HashSet();
        hashSet2.add("h");
        hashSet2.add("help");
        hashSet2.add("usage");
        hashSet2.add("license");
        hashSet2.add("quiet");
        hashSet2.add("verbose");
        hashSet2.add("version");
        hashSet2.add("dl");
        hashSet2.add("noupa");
        hashSet2.add("nopvr");
        hashSet2.add("noann");
        hashSet2.add("novdoc");
        hashSet2.add("noext");
        hashSet2.add("srconly");
        hashSet2.add("debug");
        HashSet hashSet3 = new HashSet();
        hashSet3.add("out");
        hashSet3.add("name");
        hashSet3.add("src");
        hashSet3.add("d");
        hashSet3.add("cp");
        hashSet3.add("compiler");
        hashSet3.add("javasource");
        hashSet3.add("jar");
        hashSet3.add("ms");
        hashSet3.add("mx");
        hashSet3.add("repackage");
        hashSet3.add("schemaCodePrinter");
        hashSet3.add(SchemaSymbols.ATTVAL_EXTENSION);
        hashSet3.add("extensionParms");
        hashSet3.add("allowmdef");
        hashSet3.add("catalog");
        CommandLine commandLine = new CommandLine(strArr, hashSet2, hashSet3);
        if (commandLine.getOpt("h") == null && commandLine.getOpt("help") == null && commandLine.getOpt("usage") == null) {
            String[] badOpts = commandLine.getBadOpts();
            if (badOpts.length > 0) {
                for (String str6 : badOpts) {
                    PrintStream printStream = System.out;
                    StringBuffer a = a.a("Unrecognized option: ");
                    a.append(str6);
                    printStream.println(a.toString());
                }
                printUsage();
                System.exit(0);
            } else if (commandLine.getOpt("license") != null) {
                CommandLine.printLicense();
                System.exit(0);
            } else if (commandLine.getOpt("version") != null) {
                CommandLine.printVersion();
                System.exit(0);
            } else {
                commandLine.args();
                boolean z9 = commandLine.getOpt("verbose") != null;
                boolean z10 = z9 ? false : commandLine.getOpt("quiet") != null;
                if (z9) {
                    CommandLine.printVersion();
                }
                String opt3 = commandLine.getOpt("out");
                String opt4 = commandLine.getOpt("repackage");
                String opt5 = commandLine.getOpt("schemaCodePrinter");
                if (opt5 != null) {
                    try {
                        schemaCodePrinter = (SchemaCodePrinter) Class.forName(opt5).newInstance();
                    } catch (Exception unused) {
                        PrintStream printStream2 = System.err;
                        StringBuffer stringBuffer = new StringBuffer();
                        stringBuffer.append("Failed to load SchemaCodePrinter class ");
                        stringBuffer.append(opt5);
                        stringBuffer.append("; proceeding with default printer");
                        printStream2.println(stringBuffer.toString());
                    }
                    String opt6 = commandLine.getOpt("name");
                    boolean z11 = commandLine.getOpt("dl") == null;
                    boolean z12 = commandLine.getOpt("noupa") == null;
                    boolean z13 = commandLine.getOpt("nopvr") == null;
                    if (commandLine.getOpt("noann") == null) {
                        str = "novdoc";
                        z = true;
                    } else {
                        str = "novdoc";
                        z = false;
                    }
                    if (commandLine.getOpt(str) == null) {
                        str2 = "noext";
                        z2 = true;
                    } else {
                        str2 = "noext";
                        z2 = false;
                    }
                    if (commandLine.getOpt(str2) == null) {
                        str3 = "srconly";
                        z3 = true;
                    } else {
                        str3 = "srconly";
                        z3 = false;
                    }
                    if (commandLine.getOpt(str3) == null) {
                        str4 = "debug";
                        z4 = true;
                    } else {
                        str4 = "debug";
                        z4 = false;
                    }
                    boolean z14 = commandLine.getOpt(str4) == null;
                    opt = commandLine.getOpt("allowmdef");
                    if (opt != null) {
                        hashSet = Collections.EMPTY_SET;
                        schemaCodePrinter2 = schemaCodePrinter;
                    } else {
                        schemaCodePrinter2 = schemaCodePrinter;
                        hashSet = new HashSet(Arrays.asList(XmlListImpl.split_list(opt)));
                    }
                    arrayList = new ArrayList();
                    if (commandLine.getOpt(SchemaSymbols.ATTVAL_EXTENSION) == null) {
                        str5 = opt4;
                        try {
                            Extension extension = new Extension();
                            z7 = z14;
                            try {
                                z5 = z3;
                                try {
                                    z6 = z2;
                                    try {
                                        extension.setClassName(Class.forName(commandLine.getOpt(SchemaSymbols.ATTVAL_EXTENSION), false, Thread.currentThread().getContextClassLoader()));
                                        arrayList.add(extension);
                                    } catch (ClassNotFoundException unused2) {
                                    }
                                } catch (ClassNotFoundException unused3) {
                                    z6 = z2;
                                    PrintStream printStream3 = System.err;
                                    StringBuffer a2 = a.a("Could not find extension class: ");
                                    a2.append(commandLine.getOpt(SchemaSymbols.ATTVAL_EXTENSION));
                                    a2.append("  Is it on your classpath?");
                                    printStream3.println(a2.toString());
                                    System.exit(1);
                                    Extension extension2 = (Extension) arrayList.get(0);
                                    stringTokenizer = new StringTokenizer(commandLine.getOpt("extensionParms"), ";");
                                    while (stringTokenizer.hasMoreTokens()) {
                                    }
                                    String opt7 = commandLine.getOpt("d");
                                    if (opt7 != null) {
                                    }
                                    String opt8 = commandLine.getOpt("src");
                                    if (opt8 != null) {
                                    }
                                    file2 = file;
                                    if (file2 != null) {
                                    }
                                    file3 = SchemaCodeGenerator.createTempDir();
                                    arrayList2 = arrayList;
                                    z8 = z;
                                    opt3 = "xmltypes.jar";
                                    if (opt3 != null) {
                                    }
                                    if (file2 == null) {
                                    }
                                    if (file == null) {
                                    }
                                    opt2 = commandLine.getOpt("cp");
                                    if (opt2 != null) {
                                    }
                                    String opt9 = commandLine.getOpt("javasource");
                                    String opt10 = commandLine.getOpt("compiler");
                                    String opt11 = commandLine.getOpt("jar");
                                    System.out.println("The 'jar' option is no longer supported.");
                                    String opt12 = commandLine.getOpt("ms");
                                    String opt13 = commandLine.getOpt("mx");
                                    filesEndingWith = commandLine.filesEndingWith(XMLBean.XSD);
                                    filesEndingWith2 = commandLine.filesEndingWith(XMLBean.WSDL);
                                    File[] filesEndingWith3 = commandLine.filesEndingWith(XMLBean.JAVA);
                                    File[] filesEndingWith4 = commandLine.filesEndingWith(XMLBean.XSDCONFIG);
                                    uRLs = commandLine.getURLs();
                                    if (filesEndingWith.length + filesEndingWith2.length + uRLs.length == 0) {
                                    }
                                    baseDir = commandLine.getBaseDir();
                                    if (baseDir == null) {
                                    }
                                    XmlErrorPrinter xmlErrorPrinter = new XmlErrorPrinter(z9, uri);
                                    String opt14 = commandLine.getOpt("catalog");
                                    Parameters parameters = new Parameters();
                                    parameters.setBaseDir(baseDir);
                                    parameters.setXsdFiles(filesEndingWith);
                                    parameters.setWsdlFiles(filesEndingWith2);
                                    parameters.setJavaFiles(filesEndingWith3);
                                    parameters.setConfigFiles(filesEndingWith4);
                                    parameters.setUrlFiles(uRLs);
                                    parameters.setClasspath(fileArr);
                                    parameters.setOutputJar(r5);
                                    parameters.setName(opt6);
                                    parameters.setSrcDir(file2);
                                    parameters.setClassesDir(file);
                                    parameters.setCompiler(opt10);
                                    parameters.setJavaSource(opt9);
                                    parameters.setMemoryInitialSize(opt12);
                                    parameters.setMemoryMaximumSize(opt13);
                                    parameters.setNojavac(z4);
                                    parameters.setQuiet(z10);
                                    parameters.setVerbose(z9);
                                    parameters.setDownload(z11);
                                    parameters.setNoUpa(z12);
                                    parameters.setNoPvr(z13);
                                    parameters.setNoAnn(z8);
                                    parameters.setNoVDoc(z6);
                                    parameters.setNoExt(z5);
                                    parameters.setDebug(z7);
                                    parameters.setErrorListener(xmlErrorPrinter);
                                    parameters.setRepackage(str5);
                                    parameters.setExtensions(arrayList2);
                                    parameters.setMdefNamespaces(hashSet);
                                    parameters.setCatalogFile(opt14);
                                    parameters.setSchemaCodePrinter(schemaCodePrinter2);
                                    compile = compile(parameters);
                                    if (file4 != null) {
                                    }
                                    if (!compile) {
                                    }
                                    System.exit(0);
                                }
                            } catch (ClassNotFoundException unused4) {
                                z6 = z2;
                                z5 = z3;
                                PrintStream printStream32 = System.err;
                                StringBuffer a22 = a.a("Could not find extension class: ");
                                a22.append(commandLine.getOpt(SchemaSymbols.ATTVAL_EXTENSION));
                                a22.append("  Is it on your classpath?");
                                printStream32.println(a22.toString());
                                System.exit(1);
                                Extension extension22 = (Extension) arrayList.get(0);
                                stringTokenizer = new StringTokenizer(commandLine.getOpt("extensionParms"), ";");
                                while (stringTokenizer.hasMoreTokens()) {
                                }
                                String opt72 = commandLine.getOpt("d");
                                if (opt72 != null) {
                                }
                                String opt82 = commandLine.getOpt("src");
                                if (opt82 != null) {
                                }
                                file2 = file;
                                if (file2 != null) {
                                }
                                file3 = SchemaCodeGenerator.createTempDir();
                                arrayList2 = arrayList;
                                z8 = z;
                                opt3 = "xmltypes.jar";
                                if (opt3 != null) {
                                }
                                if (file2 == null) {
                                }
                                if (file == null) {
                                }
                                opt2 = commandLine.getOpt("cp");
                                if (opt2 != null) {
                                }
                                String opt92 = commandLine.getOpt("javasource");
                                String opt102 = commandLine.getOpt("compiler");
                                String opt112 = commandLine.getOpt("jar");
                                System.out.println("The 'jar' option is no longer supported.");
                                String opt122 = commandLine.getOpt("ms");
                                String opt132 = commandLine.getOpt("mx");
                                filesEndingWith = commandLine.filesEndingWith(XMLBean.XSD);
                                filesEndingWith2 = commandLine.filesEndingWith(XMLBean.WSDL);
                                File[] filesEndingWith32 = commandLine.filesEndingWith(XMLBean.JAVA);
                                File[] filesEndingWith42 = commandLine.filesEndingWith(XMLBean.XSDCONFIG);
                                uRLs = commandLine.getURLs();
                                if (filesEndingWith.length + filesEndingWith2.length + uRLs.length == 0) {
                                }
                                baseDir = commandLine.getBaseDir();
                                if (baseDir == null) {
                                }
                                XmlErrorPrinter xmlErrorPrinter2 = new XmlErrorPrinter(z9, uri);
                                String opt142 = commandLine.getOpt("catalog");
                                Parameters parameters2 = new Parameters();
                                parameters2.setBaseDir(baseDir);
                                parameters2.setXsdFiles(filesEndingWith);
                                parameters2.setWsdlFiles(filesEndingWith2);
                                parameters2.setJavaFiles(filesEndingWith32);
                                parameters2.setConfigFiles(filesEndingWith42);
                                parameters2.setUrlFiles(uRLs);
                                parameters2.setClasspath(fileArr);
                                parameters2.setOutputJar(r5);
                                parameters2.setName(opt6);
                                parameters2.setSrcDir(file2);
                                parameters2.setClassesDir(file);
                                parameters2.setCompiler(opt102);
                                parameters2.setJavaSource(opt92);
                                parameters2.setMemoryInitialSize(opt122);
                                parameters2.setMemoryMaximumSize(opt132);
                                parameters2.setNojavac(z4);
                                parameters2.setQuiet(z10);
                                parameters2.setVerbose(z9);
                                parameters2.setDownload(z11);
                                parameters2.setNoUpa(z12);
                                parameters2.setNoPvr(z13);
                                parameters2.setNoAnn(z8);
                                parameters2.setNoVDoc(z6);
                                parameters2.setNoExt(z5);
                                parameters2.setDebug(z7);
                                parameters2.setErrorListener(xmlErrorPrinter2);
                                parameters2.setRepackage(str5);
                                parameters2.setExtensions(arrayList2);
                                parameters2.setMdefNamespaces(hashSet);
                                parameters2.setCatalogFile(opt142);
                                parameters2.setSchemaCodePrinter(schemaCodePrinter2);
                                compile = compile(parameters2);
                                if (file4 != null) {
                                }
                                if (!compile) {
                                }
                                System.exit(0);
                            }
                        } catch (ClassNotFoundException unused5) {
                            z6 = z2;
                            z5 = z3;
                            z7 = z14;
                            PrintStream printStream322 = System.err;
                            StringBuffer a222 = a.a("Could not find extension class: ");
                            a222.append(commandLine.getOpt(SchemaSymbols.ATTVAL_EXTENSION));
                            a222.append("  Is it on your classpath?");
                            printStream322.println(a222.toString());
                            System.exit(1);
                            Extension extension222 = (Extension) arrayList.get(0);
                            stringTokenizer = new StringTokenizer(commandLine.getOpt("extensionParms"), ";");
                            while (stringTokenizer.hasMoreTokens()) {
                            }
                            String opt722 = commandLine.getOpt("d");
                            if (opt722 != null) {
                            }
                            String opt822 = commandLine.getOpt("src");
                            if (opt822 != null) {
                            }
                            file2 = file;
                            if (file2 != null) {
                            }
                            file3 = SchemaCodeGenerator.createTempDir();
                            arrayList2 = arrayList;
                            z8 = z;
                            opt3 = "xmltypes.jar";
                            if (opt3 != null) {
                            }
                            if (file2 == null) {
                            }
                            if (file == null) {
                            }
                            opt2 = commandLine.getOpt("cp");
                            if (opt2 != null) {
                            }
                            String opt922 = commandLine.getOpt("javasource");
                            String opt1022 = commandLine.getOpt("compiler");
                            String opt1122 = commandLine.getOpt("jar");
                            System.out.println("The 'jar' option is no longer supported.");
                            String opt1222 = commandLine.getOpt("ms");
                            String opt1322 = commandLine.getOpt("mx");
                            filesEndingWith = commandLine.filesEndingWith(XMLBean.XSD);
                            filesEndingWith2 = commandLine.filesEndingWith(XMLBean.WSDL);
                            File[] filesEndingWith322 = commandLine.filesEndingWith(XMLBean.JAVA);
                            File[] filesEndingWith422 = commandLine.filesEndingWith(XMLBean.XSDCONFIG);
                            uRLs = commandLine.getURLs();
                            if (filesEndingWith.length + filesEndingWith2.length + uRLs.length == 0) {
                            }
                            baseDir = commandLine.getBaseDir();
                            if (baseDir == null) {
                            }
                            XmlErrorPrinter xmlErrorPrinter22 = new XmlErrorPrinter(z9, uri);
                            String opt1422 = commandLine.getOpt("catalog");
                            Parameters parameters22 = new Parameters();
                            parameters22.setBaseDir(baseDir);
                            parameters22.setXsdFiles(filesEndingWith);
                            parameters22.setWsdlFiles(filesEndingWith2);
                            parameters22.setJavaFiles(filesEndingWith322);
                            parameters22.setConfigFiles(filesEndingWith422);
                            parameters22.setUrlFiles(uRLs);
                            parameters22.setClasspath(fileArr);
                            parameters22.setOutputJar(r5);
                            parameters22.setName(opt6);
                            parameters22.setSrcDir(file2);
                            parameters22.setClassesDir(file);
                            parameters22.setCompiler(opt1022);
                            parameters22.setJavaSource(opt922);
                            parameters22.setMemoryInitialSize(opt1222);
                            parameters22.setMemoryMaximumSize(opt1322);
                            parameters22.setNojavac(z4);
                            parameters22.setQuiet(z10);
                            parameters22.setVerbose(z9);
                            parameters22.setDownload(z11);
                            parameters22.setNoUpa(z12);
                            parameters22.setNoPvr(z13);
                            parameters22.setNoAnn(z8);
                            parameters22.setNoVDoc(z6);
                            parameters22.setNoExt(z5);
                            parameters22.setDebug(z7);
                            parameters22.setErrorListener(xmlErrorPrinter22);
                            parameters22.setRepackage(str5);
                            parameters22.setExtensions(arrayList2);
                            parameters22.setMdefNamespaces(hashSet);
                            parameters22.setCatalogFile(opt1422);
                            parameters22.setSchemaCodePrinter(schemaCodePrinter2);
                            compile = compile(parameters22);
                            if (file4 != null) {
                            }
                            if (!compile) {
                            }
                            System.exit(0);
                        }
                    } else {
                        str5 = opt4;
                        z6 = z2;
                        z5 = z3;
                        z7 = z14;
                    }
                    if (arrayList.size() > 0 && commandLine.getOpt("extensionParms") != null) {
                        Extension extension2222 = (Extension) arrayList.get(0);
                        stringTokenizer = new StringTokenizer(commandLine.getOpt("extensionParms"), ";");
                        while (stringTokenizer.hasMoreTokens()) {
                            String nextToken = stringTokenizer.nextToken();
                            int indexOf = nextToken.indexOf(61);
                            if (indexOf < 0) {
                                stringTokenizer2 = stringTokenizer;
                                System.err.println("extensionParms should be name=value;name=value");
                                System.exit(1);
                            } else {
                                stringTokenizer2 = stringTokenizer;
                            }
                            String substring = nextToken.substring(0, indexOf);
                            String substring2 = nextToken.substring(indexOf + 1);
                            Extension.Param createParam = extension2222.createParam();
                            createParam.setName(substring);
                            createParam.setValue(substring2);
                            stringTokenizer = stringTokenizer2;
                        }
                    }
                    String opt7222 = commandLine.getOpt("d");
                    file = opt7222 != null ? new File(opt7222) : null;
                    String opt8222 = commandLine.getOpt("src");
                    file2 = opt8222 != null ? new File(opt8222) : null;
                    if (z4 && opt8222 == null && file != null) {
                        file2 = file;
                    }
                    if (file2 != null || file == null) {
                        file3 = SchemaCodeGenerator.createTempDir();
                        arrayList2 = arrayList;
                        z8 = z;
                    } else {
                        arrayList2 = arrayList;
                        z8 = z;
                        file3 = null;
                    }
                    if (opt3 == null && file == null && !z4) {
                        opt3 = "xmltypes.jar";
                    }
                    File file5 = opt3 != null ? new File(opt3) : null;
                    if (file2 == null) {
                        file2 = IOUtil.createDir(file3, "src");
                    }
                    if (file == null) {
                        file = IOUtil.createDir(file3, "classes");
                    }
                    opt2 = commandLine.getOpt("cp");
                    if (opt2 != null) {
                        String[] split = opt2.split(File.pathSeparator);
                        ArrayList arrayList3 = new ArrayList();
                        int i2 = 0;
                        while (i2 < split.length) {
                            arrayList3.add(new File(split[i2]));
                            i2++;
                            file3 = file3;
                        }
                        file4 = file3;
                        fileArr = (File[]) arrayList3.toArray(new File[arrayList3.size()]);
                    } else {
                        file4 = file3;
                        fileArr = CodeGenUtil.systemClasspath();
                    }
                    String opt9222 = commandLine.getOpt("javasource");
                    String opt10222 = commandLine.getOpt("compiler");
                    String opt11222 = commandLine.getOpt("jar");
                    if (z9 && opt11222 != null) {
                        System.out.println("The 'jar' option is no longer supported.");
                    }
                    String opt12222 = commandLine.getOpt("ms");
                    String opt13222 = commandLine.getOpt("mx");
                    filesEndingWith = commandLine.filesEndingWith(XMLBean.XSD);
                    filesEndingWith2 = commandLine.filesEndingWith(XMLBean.WSDL);
                    File[] filesEndingWith3222 = commandLine.filesEndingWith(XMLBean.JAVA);
                    File[] filesEndingWith4222 = commandLine.filesEndingWith(XMLBean.XSDCONFIG);
                    uRLs = commandLine.getURLs();
                    if (filesEndingWith.length + filesEndingWith2.length + uRLs.length == 0) {
                        System.out.println("Could not find any xsd or wsdl files to process.");
                        System.exit(0);
                    }
                    baseDir = commandLine.getBaseDir();
                    if (baseDir == null) {
                        uri = null;
                    } else {
                        uri = baseDir.toURI();
                    }
                    XmlErrorPrinter xmlErrorPrinter222 = new XmlErrorPrinter(z9, uri);
                    String opt14222 = commandLine.getOpt("catalog");
                    Parameters parameters222 = new Parameters();
                    parameters222.setBaseDir(baseDir);
                    parameters222.setXsdFiles(filesEndingWith);
                    parameters222.setWsdlFiles(filesEndingWith2);
                    parameters222.setJavaFiles(filesEndingWith3222);
                    parameters222.setConfigFiles(filesEndingWith4222);
                    parameters222.setUrlFiles(uRLs);
                    parameters222.setClasspath(fileArr);
                    parameters222.setOutputJar(file5);
                    parameters222.setName(opt6);
                    parameters222.setSrcDir(file2);
                    parameters222.setClassesDir(file);
                    parameters222.setCompiler(opt10222);
                    parameters222.setJavaSource(opt9222);
                    parameters222.setMemoryInitialSize(opt12222);
                    parameters222.setMemoryMaximumSize(opt13222);
                    parameters222.setNojavac(z4);
                    parameters222.setQuiet(z10);
                    parameters222.setVerbose(z9);
                    parameters222.setDownload(z11);
                    parameters222.setNoUpa(z12);
                    parameters222.setNoPvr(z13);
                    parameters222.setNoAnn(z8);
                    parameters222.setNoVDoc(z6);
                    parameters222.setNoExt(z5);
                    parameters222.setDebug(z7);
                    parameters222.setErrorListener(xmlErrorPrinter222);
                    parameters222.setRepackage(str5);
                    parameters222.setExtensions(arrayList2);
                    parameters222.setMdefNamespaces(hashSet);
                    parameters222.setCatalogFile(opt14222);
                    parameters222.setSchemaCodePrinter(schemaCodePrinter2);
                    compile = compile(parameters222);
                    if (file4 != null) {
                        SchemaCodeGenerator.tryHardToDelete(file4);
                    }
                    if (!compile) {
                        System.exit(1);
                    }
                    System.exit(0);
                }
                schemaCodePrinter = null;
                String opt62 = commandLine.getOpt("name");
                if (commandLine.getOpt("dl") == null) {
                }
                if (commandLine.getOpt("noupa") == null) {
                }
                if (commandLine.getOpt("nopvr") == null) {
                }
                if (commandLine.getOpt("noann") == null) {
                }
                if (commandLine.getOpt(str) == null) {
                }
                if (commandLine.getOpt(str2) == null) {
                }
                if (commandLine.getOpt(str3) == null) {
                }
                if (commandLine.getOpt(str4) == null) {
                }
                opt = commandLine.getOpt("allowmdef");
                if (opt != null) {
                }
                arrayList = new ArrayList();
                if (commandLine.getOpt(SchemaSymbols.ATTVAL_EXTENSION) == null) {
                }
                Extension extension22222 = (Extension) arrayList.get(0);
                stringTokenizer = new StringTokenizer(commandLine.getOpt("extensionParms"), ";");
                while (stringTokenizer.hasMoreTokens()) {
                }
                String opt72222 = commandLine.getOpt("d");
                if (opt72222 != null) {
                }
                String opt82222 = commandLine.getOpt("src");
                if (opt82222 != null) {
                }
                file2 = file;
                if (file2 != null) {
                }
                try {
                    file3 = SchemaCodeGenerator.createTempDir();
                    arrayList2 = arrayList;
                    z8 = z;
                } catch (IOException e2) {
                    PrintStream printStream4 = System.err;
                    arrayList2 = arrayList;
                    StringBuffer stringBuffer2 = new StringBuffer();
                    z8 = z;
                    stringBuffer2.append("Error creating temp dir ");
                    stringBuffer2.append(e2);
                    printStream4.println(stringBuffer2.toString());
                    System.exit(1);
                }
                opt3 = "xmltypes.jar";
                if (opt3 != null) {
                }
                if (file2 == null) {
                }
                if (file == null) {
                }
                opt2 = commandLine.getOpt("cp");
                if (opt2 != null) {
                }
                String opt92222 = commandLine.getOpt("javasource");
                String opt102222 = commandLine.getOpt("compiler");
                String opt112222 = commandLine.getOpt("jar");
                System.out.println("The 'jar' option is no longer supported.");
                String opt122222 = commandLine.getOpt("ms");
                String opt132222 = commandLine.getOpt("mx");
                filesEndingWith = commandLine.filesEndingWith(XMLBean.XSD);
                filesEndingWith2 = commandLine.filesEndingWith(XMLBean.WSDL);
                File[] filesEndingWith32222 = commandLine.filesEndingWith(XMLBean.JAVA);
                File[] filesEndingWith42222 = commandLine.filesEndingWith(XMLBean.XSDCONFIG);
                uRLs = commandLine.getURLs();
                if (filesEndingWith.length + filesEndingWith2.length + uRLs.length == 0) {
                }
                baseDir = commandLine.getBaseDir();
                if (baseDir == null) {
                }
                XmlErrorPrinter xmlErrorPrinter2222 = new XmlErrorPrinter(z9, uri);
                String opt142222 = commandLine.getOpt("catalog");
                Parameters parameters2222 = new Parameters();
                parameters2222.setBaseDir(baseDir);
                parameters2222.setXsdFiles(filesEndingWith);
                parameters2222.setWsdlFiles(filesEndingWith2);
                parameters2222.setJavaFiles(filesEndingWith32222);
                parameters2222.setConfigFiles(filesEndingWith42222);
                parameters2222.setUrlFiles(uRLs);
                parameters2222.setClasspath(fileArr);
                parameters2222.setOutputJar(file5);
                parameters2222.setName(opt62);
                parameters2222.setSrcDir(file2);
                parameters2222.setClassesDir(file);
                parameters2222.setCompiler(opt102222);
                parameters2222.setJavaSource(opt92222);
                parameters2222.setMemoryInitialSize(opt122222);
                parameters2222.setMemoryMaximumSize(opt132222);
                parameters2222.setNojavac(z4);
                parameters2222.setQuiet(z10);
                parameters2222.setVerbose(z9);
                parameters2222.setDownload(z11);
                parameters2222.setNoUpa(z12);
                parameters2222.setNoPvr(z13);
                parameters2222.setNoAnn(z8);
                parameters2222.setNoVDoc(z6);
                parameters2222.setNoExt(z5);
                parameters2222.setDebug(z7);
                parameters2222.setErrorListener(xmlErrorPrinter2222);
                parameters2222.setRepackage(str5);
                parameters2222.setExtensions(arrayList2);
                parameters2222.setMdefNamespaces(hashSet);
                parameters2222.setCatalogFile(opt142222);
                parameters2222.setSchemaCodePrinter(schemaCodePrinter2);
                compile = compile(parameters2222);
                if (file4 != null) {
                }
                if (!compile) {
                }
                System.exit(0);
            }
        } else {
            printUsage();
            System.exit(0);
        }
    }

    public static void printUsage() {
        System.out.println("Compiles a schema into XML Bean classes and metadata.");
        System.out.println("Usage: scomp [opts] [dirs]* [schema.xsd]* [service.wsdl]* [config.xsdconfig]*");
        System.out.println("Options include:");
        System.out.println("    -cp [a;b;c] - classpath");
        System.out.println("    -d [dir] - target binary directory for .class and .xsb files");
        System.out.println("    -src [dir] - target directory for generated .java files");
        System.out.println("    -srconly - do not compile .java files or jar the output.");
        System.out.println("    -out [xmltypes.jar] - the name of the output jar");
        System.out.println("    -dl - permit network downloads for imports and includes (default is off)");
        System.out.println("    -noupa - do not enforce the unique particle attribution rule");
        System.out.println("    -nopvr - do not enforce the particle valid (restriction) rule");
        System.out.println("    -noann - ignore annotations");
        System.out.println("    -novdoc - do not validate contents of <documentation>");
        System.out.println("    -noext - ignore all extension (Pre/Post and Interface) found in .xsdconfig files");
        System.out.println("    -compiler - path to external java compiler");
        System.out.println("    -javasource [version] - generate java source compatible for a Java version (1.4 or 1.5)");
        PrintStream printStream = System.out;
        StringBuffer a = a.a("    -ms - initial memory for external java compiler (default '");
        a.append(CodeGenUtil.DEFAULT_MEM_START);
        a.append("')");
        printStream.println(a.toString());
        PrintStream printStream2 = System.out;
        StringBuffer a2 = a.a("    -mx - maximum memory for external java compiler (default '");
        a2.append(CodeGenUtil.DEFAULT_MEM_MAX);
        a2.append("')");
        printStream2.println(a2.toString());
        System.out.println("    -debug - compile with debug symbols");
        System.out.println("    -quiet - print fewer informational messages");
        System.out.println("    -verbose - print more informational messages");
        System.out.println("    -version - prints version information");
        System.out.println("    -license - prints license information");
        System.out.println("    -allowmdef \"[ns] [ns] [ns]\" - ignores multiple defs in given namespaces (use ##local for no-namespace)");
        System.out.println("    -catalog [file] -  catalog file for org.apache.xml.resolver.tools.CatalogResolver. (Note: needs resolver.jar from http://xml.apache.org/commons/components/resolver/index.html)");
        System.out.println();
    }

    public static void runExtensions(List list, SchemaTypeSystem schemaTypeSystem, File file) {
        String str;
        if (list != null && list.size() > 0) {
            Iterator it = list.iterator();
            try {
                str = file.getCanonicalPath();
            } catch (IOException unused) {
                System.out.println("WARNING: Unable to get the path for schema jar file");
                str = file.getAbsolutePath();
            }
            while (it.hasNext()) {
                Extension extension = (Extension) it.next();
                try {
                    SchemaCompilerExtension schemaCompilerExtension = (SchemaCompilerExtension) extension.getClassName().newInstance();
                    PrintStream printStream = System.out;
                    StringBuffer a = a.a("Running Extension: ");
                    a.append(schemaCompilerExtension.getExtensionName());
                    printStream.println(a.toString());
                    HashMap hashMap = new HashMap();
                    for (Extension.Param param : extension.getParams()) {
                        hashMap.put(param.getName(), param.getValue());
                    }
                    hashMap.put("classesDir", str);
                    schemaCompilerExtension.schemaCompilerExtension(schemaTypeSystem, hashMap);
                } catch (InstantiationException unused2) {
                    PrintStream printStream2 = System.out;
                    StringBuffer a2 = a.a("UNABLE to instantiate schema compiler extension:");
                    a2.append(extension.getClassName().getName());
                    printStream2.println(a2.toString());
                    System.out.println("EXTENSION Class was not run");
                    return;
                } catch (IllegalAccessException unused3) {
                    PrintStream printStream3 = System.out;
                    StringBuffer a3 = a.a("ILLEGAL ACCESS Exception when attempting to instantiate schema compiler extension: ");
                    a3.append(extension.getClassName().getName());
                    printStream3.println(a3.toString());
                    System.out.println("EXTENSION Class was not run");
                    return;
                }
            }
        }
    }

    public static boolean wsdlContainsEncoded(XmlObject xmlObject) {
        XmlObject[] selectPath;
        for (XmlObject xmlObject2 : xmlObject.selectPath("declare namespace soap='http://schemas.xmlsoap.org/wsdl/soap/' .//soap:body/@use|.//soap:header/@use|.//soap:fault/@use")) {
            if ("encoded".equals(((SimpleValue) xmlObject2).getStringValue())) {
                return true;
            }
        }
        return false;
    }
}
