package org.apache.xmlbeans.impl.tool;

import java.io.File;
import java.io.IOException;
import java.net.URI;
import java.util.AbstractCollection;
import java.util.ArrayList;
import java.util.Collections;
import java.util.HashMap;
import java.util.HashSet;
import java.util.Iterator;
import java.util.List;
import java.util.Set;
import java.util.StringTokenizer;
import org.apache.poi.xssf.usermodel.XSSFDataValidationConstraint;
import org.apache.tools.ant.BuildException;
import org.apache.tools.ant.DirectoryScanner;
import org.apache.tools.ant.taskdefs.Jar;
import org.apache.tools.ant.taskdefs.Javac;
import org.apache.tools.ant.taskdefs.MatchingTask;
import org.apache.tools.ant.types.FileSet;
import org.apache.tools.ant.types.Path;
import org.apache.tools.ant.types.Reference;
import org.apache.xmlbeans.XmlError;
import org.apache.xmlbeans.XmlOptions;
import org.apache.xmlbeans.impl.common.IOUtil;
import org.apache.xmlbeans.impl.tool.SchemaCompiler;

public class XMLBean extends MatchingTask {
    public static final String JAVA = ".java";
    public static final String WSDL = ".wsdl";
    public static final String XSD = ".xsd";
    public static final String XSDCONFIG = ".xsdconfig";
    public HashMap _extRouter = new HashMap(5);
    public String catalog;
    public File classgendir;
    public Path classpath;
    public String compiler;
    public boolean debug;
    public String debugLevel;
    public File destfile;
    public boolean download;
    public List extensions = new ArrayList();
    public boolean failonerror = true;
    public boolean fork = true;
    public String forkedExecutable;
    public boolean includeAntRuntime = true;
    public boolean includeJavaRuntime = false;
    public String javasource;
    public Set mdefnamespaces;
    public String memoryInitialSize;
    public String memoryMaximumSize;
    public boolean noSrcRegen;
    public boolean noann;
    public boolean noext = false;
    public boolean nopvr;
    public boolean noupa;
    public boolean novdoc;
    public boolean optimize;
    public boolean quiet;
    public File schema;
    public ArrayList schemas = new ArrayList();
    public String source = null;
    public File srcgendir;
    public boolean srconly;
    public String typesystemname;
    public boolean verbose;

    public class ErrorLogger extends AbstractCollection {
        public URI _baseURI;
        public boolean _noisy;

        public ErrorLogger(boolean z) {
            this._noisy = z;
            this._baseURI = XMLBean.uriFromFile(XMLBean.this.project.getBaseDir());
        }

        @Override // java.util.AbstractCollection, java.util.Collection
        public boolean add(Object obj) {
            if (obj instanceof XmlError) {
                XmlError xmlError = (XmlError) obj;
                if (xmlError.getSeverity() == 0) {
                    XMLBean.this.log(xmlError.toString(this._baseURI), 0);
                } else if (xmlError.getSeverity() == 1) {
                    XMLBean.this.log(xmlError.toString(this._baseURI), 1);
                } else if (this._noisy) {
                    XMLBean.this.log(xmlError.toString(this._baseURI), 2);
                }
            }
            return false;
        }

        @Override // java.util.AbstractCollection, java.util.Collection, java.lang.Iterable
        public Iterator iterator() {
            return Collections.EMPTY_LIST.iterator();
        }

        public int size() {
            return 0;
        }
    }

    private void processPaths(String[] strArr, File file) {
        for (int i2 = 0; i2 < strArr.length; i2++) {
            int lastIndexOf = strArr[i2].lastIndexOf(46);
            if (lastIndexOf > -1) {
                String str = strArr[i2];
                Set set = (Set) this._extRouter.get(str.substring(lastIndexOf).toLowerCase());
                if (set != null) {
                    set.add(new File(file, str));
                }
            }
        }
    }

    public static URI uriFromFile(File file) {
        if (file == null) {
            return null;
        }
        try {
            return file.getCanonicalFile().toURI();
        } catch (IOException unused) {
            return file.getAbsoluteFile().toURI();
        }
    }

    public void addFileset(FileSet fileSet) {
        this.schemas.add(fileSet);
    }

    public Path createClasspath() {
        if (this.classpath == null) {
            this.classpath = new Path(this.project);
        }
        return this.classpath.createPath();
    }

    public Extension createExtension() {
        Extension extension = new Extension();
        this.extensions.add(extension);
        return extension;
    }

    /* JADX WARNING: Code restructure failed: missing block: B:101:0x0313, code lost:
        r3 = b.b.a.a.a.a("Exception while building schemas: ");
        r3.append(r0.getMessage());
        log(r3.toString(), 0);
        r2 = new java.io.StringWriter();
        r0.printStackTrace(new java.io.PrintWriter(r2));
        log(r2.toString(), 3);
     */
    /* JADX WARNING: Code restructure failed: missing block: B:109:0x0350, code lost:
        r0 = move-exception;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:110:0x0351, code lost:
        throw r0;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:91:0x0301, code lost:
        r0 = th;
     */
    /* JADX WARNING: Failed to process nested try/catch */
    /* JADX WARNING: Removed duplicated region for block: B:109:0x0350 A[ExcHandler: BuildException (r0v1 'e' org.apache.tools.ant.BuildException A[CUSTOM_DECLARE]), Splitter:B:45:0x014e] */
    public void execute() {
        boolean z;
        if (this.schemas.size() != 0 || this.schema != null || this.fileset.getDir(this.project) != null) {
            this._extRouter.put(XSD, new HashSet());
            this._extRouter.put(WSDL, new HashSet());
            this._extRouter.put(JAVA, new HashSet());
            this._extRouter.put(XSDCONFIG, new HashSet());
            File file = this.schema;
            if (file != null) {
                if (file.isDirectory()) {
                    DirectoryScanner directoryScanner = getDirectoryScanner(this.schema);
                    processPaths(directoryScanner.getIncludedFiles(), directoryScanner.getBasedir());
                } else {
                    file = this.schema.getParentFile();
                    processPaths(new String[]{this.schema.getName()}, file);
                }
            }
            if (this.fileset.getDir(this.project) != null) {
                this.schemas.add(this.fileset);
            }
            Iterator it = this.schemas.iterator();
            while (it.hasNext()) {
                DirectoryScanner directoryScanner2 = ((FileSet) it.next()).getDirectoryScanner(this.project);
                processPaths(directoryScanner2.getIncludedFiles(), directoryScanner2.getBasedir());
            }
            Set set = (Set) this._extRouter.get(XSD);
            Set set2 = (Set) this._extRouter.get(WSDL);
            if (set2.size() + set.size() == 0) {
                log("Could not find any xsd or wsdl files to process.", 1);
                return;
            }
            Set set3 = (Set) this._extRouter.get(JAVA);
            Set set4 = (Set) this._extRouter.get(XSDCONFIG);
            if (this.srcgendir == null && this.srconly) {
                this.srcgendir = this.classgendir;
            }
            if (this.destfile == null && this.classgendir == null && !this.srconly) {
                this.destfile = new File("xmltypes.jar");
            }
            if (this.verbose) {
                this.quiet = false;
            }
            File[] fileArr = (File[]) set.toArray(new File[set.size()]);
            File[] fileArr2 = (File[]) set2.toArray(new File[set2.size()]);
            File[] fileArr3 = (File[]) set3.toArray(new File[set3.size()]);
            File[] fileArr4 = (File[]) set4.toArray(new File[set4.size()]);
            ErrorLogger errorLogger = new ErrorLogger(this.verbose);
            File file2 = null;
            try {
                if (this.srcgendir == null || this.classgendir == null) {
                    file2 = SchemaCodeGenerator.createTempDir();
                }
                if (this.srcgendir == null) {
                    this.srcgendir = IOUtil.createDir(file2, "src");
                }
                if (this.classgendir == null) {
                    this.classgendir = IOUtil.createDir(file2, "classes");
                }
                if (this.classpath == null) {
                    Path path = new Path(this.project);
                    this.classpath = path;
                    path.concatSystemClasspath();
                }
                this.classpath.createPathElement().setLocation(this.classgendir);
                String[] list = this.classpath.list();
                File[] fileArr5 = new File[list.length];
                for (int i2 = 0; i2 < list.length; i2++) {
                    fileArr5[i2] = new File(list[i2]);
                }
                SchemaCompiler.Parameters parameters = new SchemaCompiler.Parameters();
                parameters.setBaseDir(file);
                parameters.setXsdFiles(fileArr);
                parameters.setWsdlFiles(fileArr2);
                parameters.setJavaFiles(fileArr3);
                parameters.setConfigFiles(fileArr4);
                parameters.setClasspath(fileArr5);
                parameters.setName(this.typesystemname);
                parameters.setSrcDir(this.srcgendir);
                parameters.setClassesDir(this.classgendir);
                parameters.setNojavac(true);
                parameters.setDebug(this.debug);
                parameters.setVerbose(this.verbose);
                parameters.setQuiet(this.quiet);
                parameters.setDownload(this.download);
                parameters.setExtensions(this.extensions);
                parameters.setErrorListener(errorLogger);
                parameters.setCatalogFile(this.catalog);
                parameters.setIncrementalSrcGen(this.noSrcRegen);
                parameters.setMdefNamespaces(this.mdefnamespaces);
                parameters.setNoUpa(this.noupa);
                parameters.setNoPvr(this.nopvr);
                parameters.setNoAnn(this.noann);
                parameters.setNoVDoc(this.novdoc);
                parameters.setNoExt(this.noext);
                parameters.setJavaSource(this.javasource);
                z = SchemaCompiler.compile(parameters);
                if (z) {
                    if (!this.srconly) {
                        long currentTimeMillis = System.currentTimeMillis();
                        Javac javac = new Javac();
                        javac.setProject(this.project);
                        javac.setTaskName(getTaskName());
                        javac.setClasspath(this.classpath);
                        if (this.compiler != null) {
                            javac.setCompiler(this.compiler);
                        }
                        javac.setDebug(this.debug);
                        if (this.debugLevel != null) {
                            javac.setDebugLevel(this.debugLevel);
                        }
                        javac.setDestdir(this.classgendir);
                        javac.setExecutable(this.forkedExecutable);
                        javac.setFailonerror(this.failonerror);
                        javac.setFork(this.fork);
                        if (this.javasource != null) {
                            javac.setSource(this.javasource);
                            javac.setTarget(this.javasource);
                        } else {
                            javac.setSource(XmlOptions.GENERATE_JAVA_14);
                            javac.setTarget(XmlOptions.GENERATE_JAVA_14);
                        }
                        javac.setIncludeantruntime(this.includeAntRuntime);
                        javac.setIncludejavaruntime(this.includeJavaRuntime);
                        javac.setSrcdir(new Path(this.project, this.srcgendir.getAbsolutePath()));
                        if (this.memoryInitialSize != null) {
                            javac.setMemoryInitialSize(this.memoryInitialSize);
                        }
                        if (this.memoryMaximumSize != null) {
                            javac.setMemoryMaximumSize(this.memoryMaximumSize);
                        }
                        javac.setOptimize(this.optimize);
                        javac.setVerbose(this.verbose);
                        javac.execute();
                        long currentTimeMillis2 = System.currentTimeMillis();
                        if (!this.quiet) {
                            StringBuffer stringBuffer = new StringBuffer();
                            stringBuffer.append("Time to compile code: ");
                            stringBuffer.append(((double) (currentTimeMillis2 - currentTimeMillis)) / 1000.0d);
                            stringBuffer.append(" seconds");
                            log(stringBuffer.toString());
                        }
                        if (this.destfile != null) {
                            Jar jar = new Jar();
                            jar.setProject(this.project);
                            jar.setTaskName(getTaskName());
                            jar.setBasedir(this.classgendir);
                            jar.setDestFile(this.destfile);
                            jar.execute();
                        }
                    }
                }
                if (file2 != null) {
                    SchemaCodeGenerator.tryHardToDelete(file2);
                }
            } catch (BuildException e2) {
            } catch (Throwable th) {
                Throwable th2 = th;
                z = false;
                if (!(th2 instanceof InterruptedException)) {
                }
                throw new BuildException(th2);
            }
            if (z && this.failonerror) {
                throw new BuildException();
            }
        } else if (!this.failonerror) {
            log("The 'schema' or 'dir' attribute or a nested fileset is required.", 0);
        } else {
            throw new BuildException("The 'schema' or 'dir' attribute or a nested fileset is required.");
        }
    }

    public String getCatalog() {
        return this.catalog;
    }

    public File getClassgendir() {
        return this.classgendir;
    }

    public Path getClasspath() {
        return this.classpath;
    }

    public String getDebugLevel() {
        return this.debugLevel;
    }

    public File getDestfile() {
        return this.destfile;
    }

    public String getExecutable() {
        return this.forkedExecutable;
    }

    public String getIgnoreDuplicatesInNamespaces() {
        if (this.mdefnamespaces == null) {
            return null;
        }
        StringBuffer stringBuffer = new StringBuffer();
        Iterator it = this.mdefnamespaces.iterator();
        while (it.hasNext()) {
            stringBuffer.append((String) it.next());
            if (it.hasNext()) {
                stringBuffer.append(XSSFDataValidationConstraint.LIST_SEPARATOR);
            }
        }
        return stringBuffer.toString();
    }

    public String getJavaSource() {
        return this.javasource;
    }

    public String getMemoryInitialSize() {
        return this.memoryInitialSize;
    }

    public String getMemoryMaximumSize() {
        return this.memoryMaximumSize;
    }

    public boolean getOptimize() {
        return this.optimize;
    }

    public File getSchema() {
        return this.schema;
    }

    public File getSrcgendir() {
        return this.srcgendir;
    }

    public String getTypesystemname() {
        return this.typesystemname;
    }

    public boolean isDebug() {
        return this.debug;
    }

    public boolean isDownload() {
        return this.download;
    }

    public boolean isFailonerror() {
        return this.failonerror;
    }

    public boolean isIncludeAntRuntime() {
        return this.includeAntRuntime;
    }

    public boolean isIncludeJavaRuntime() {
        return this.includeJavaRuntime;
    }

    public boolean isNoAnnotations() {
        return this.noann;
    }

    public boolean isNoExt() {
        return this.noext;
    }

    public boolean isNoPvr() {
        return this.nopvr;
    }

    public boolean isNoSrcRegen() {
        return this.noSrcRegen;
    }

    public boolean isNoUpa() {
        return this.noupa;
    }

    public boolean isNoValidateDoc() {
        return this.novdoc;
    }

    public boolean isQuiet() {
        return this.quiet;
    }

    public boolean isSrconly() {
        return this.srconly;
    }

    public boolean isVerbose() {
        return this.verbose;
    }

    public void setCatalog(String str) {
        this.catalog = str;
    }

    public void setClassgendir(File file) {
        this.classgendir = file;
    }

    public void setClasspath(Path path) {
        Path path2 = this.classpath;
        if (path2 != null) {
            path2.append(path);
        } else {
            this.classpath = path;
        }
    }

    public void setClasspathRef(Reference reference) {
        if (this.classpath == null) {
            this.classpath = new Path(this.project);
        }
        this.classpath.createPath().setRefid(reference);
    }

    public void setCompiler(String str) {
        this.compiler = str;
    }

    public void setDebug(boolean z) {
        this.debug = z;
    }

    public void setDebugLevel(String str) {
        this.debugLevel = str;
    }

    public void setDestfile(File file) {
        this.destfile = file;
    }

    public void setDownload(boolean z) {
        this.download = z;
    }

    public void setExecutable(String str) {
        this.forkedExecutable = str;
    }

    public void setFailonerror(boolean z) {
        this.failonerror = z;
    }

    public void setFork(boolean z) {
        this.fork = z;
    }

    public void setIgnoreDuplicatesInNamespaces(String str) {
        this.mdefnamespaces = new HashSet();
        StringTokenizer stringTokenizer = new StringTokenizer(str, XSSFDataValidationConstraint.LIST_SEPARATOR);
        while (stringTokenizer.hasMoreTokens()) {
            this.mdefnamespaces.add(stringTokenizer.nextToken().trim());
        }
    }

    public void setIncludeAntRuntime(boolean z) {
        this.includeAntRuntime = z;
    }

    public void setIncludeJavaRuntime(boolean z) {
        this.includeJavaRuntime = z;
    }

    public void setJavaSource(String str) {
        this.javasource = str;
    }

    public void setMemoryInitialSize(String str) {
        this.memoryInitialSize = str;
    }

    public void setMemoryMaximumSize(String str) {
        this.memoryMaximumSize = str;
    }

    public void setNoAnnotations(boolean z) {
        this.noann = z;
    }

    public void setNoExt(boolean z) {
        this.noext = z;
    }

    public void setNoPvr(boolean z) {
        this.nopvr = z;
    }

    public void setNoSrcRegen(boolean z) {
        this.noSrcRegen = z;
    }

    public void setNoUpa(boolean z) {
        this.noupa = z;
    }

    public void setNoValidateDoc(boolean z) {
        this.novdoc = z;
    }

    public void setOptimize(boolean z) {
        this.optimize = z;
    }

    public void setQuiet(boolean z) {
        this.quiet = z;
    }

    public void setSchema(File file) {
        this.schema = file;
    }

    public void setSource(String str) {
        this.source = str;
    }

    public void setSrcgendir(File file) {
        this.srcgendir = file;
    }

    public void setSrconly(boolean z) {
        this.srconly = z;
    }

    public void setTypesystemname(String str) {
        this.typesystemname = str;
    }

    public void setVerbose(boolean z) {
        this.verbose = z;
    }
}
