package org.apache.xmlbeans.impl.tool;

import b.b.a.a.a;
import java.io.File;
import java.io.FileWriter;
import java.io.PrintStream;
import java.io.PrintWriter;
import java.net.URI;
import java.util.ArrayList;
import java.util.Collection;
import java.util.Collections;
import java.util.Date;
import java.util.HashSet;
import java.util.Iterator;
import java.util.regex.Pattern;
import org.apache.poi.openxml4j.opc.internal.ZipHelper;
import org.apache.xmlbeans.SystemProperties;
import org.apache.xmlbeans.XmlCalendar;
import org.apache.xmlbeans.XmlError;
import org.apache.xmlbeans.XmlException;
import org.apache.xmlbeans.XmlOptions;
import org.apache.xmlbeans.impl.xb.ltgfmt.FileDesc;
import org.apache.xmlbeans.impl.xb.ltgfmt.TestsDocument;

public class XSTCTester {
    public static final Pattern leadingSpace = Pattern.compile("^\\s+", 8);

    public interface Harness {
        void runTestCase(TestCaseResult testCaseResult);
    }

    public static class TestCase {
        public String description;
        public String errorCode;
        public String id;
        public File instanceFile;
        public boolean ivExpected;
        public File ltgFile;
        public String origin;
        public File resourceFile;
        public boolean rvExpected;
        public File schemaFile;
        public boolean svExpected;

        public String getDescription() {
            return this.description;
        }

        public String getErrorCode() {
            return this.errorCode;
        }

        public String getId() {
            return this.id;
        }

        public File getInstanceFile() {
            return this.instanceFile;
        }

        public File getLtgFile() {
            return this.ltgFile;
        }

        public String getOrigin() {
            return this.origin;
        }

        public File getResourceFile() {
            return this.resourceFile;
        }

        public File getSchemaFile() {
            return this.schemaFile;
        }

        public boolean isIvExpected() {
            return this.ivExpected;
        }

        public boolean isRvExpected() {
            return this.rvExpected;
        }

        public boolean isSvExpected() {
            return this.svExpected;
        }
    }

    public static class TestCaseResult {
        public boolean crash;
        public boolean ivActual;
        public Collection ivMessages = new ArrayList();
        public boolean svActual;
        public Collection svMessages = new ArrayList();
        public TestCase testCase;

        public void addIvMessages(Collection collection) {
            this.ivMessages.addAll(collection);
        }

        public void addSvMessages(Collection collection) {
            this.svMessages.addAll(collection);
        }

        public Collection getIvMessages() {
            return Collections.unmodifiableCollection(this.ivMessages);
        }

        public Collection getSvMessages() {
            return Collections.unmodifiableCollection(this.svMessages);
        }

        public TestCase getTestCase() {
            return this.testCase;
        }

        public boolean isCrash() {
            return this.crash;
        }

        public boolean isIvActual() {
            return this.ivActual;
        }

        public boolean isSvActual() {
            return this.svActual;
        }

        public void setCrash(boolean z) {
            this.crash = z;
        }

        public void setIvActual(boolean z) {
            this.ivActual = z;
        }

        public void setSvActual(boolean z) {
            this.svActual = z;
        }

        public boolean succeeded(boolean z) {
            boolean z2 = true;
            boolean z3 = !this.crash && isIvActual() == this.testCase.isIvExpected() && isSvActual() == this.testCase.isSvExpected();
            if (!z || this.testCase.getErrorCode() == null) {
                return z3;
            }
            if (!XSTCTester.errorReported(this.testCase.getErrorCode(), this.svMessages) && !XSTCTester.errorReported(this.testCase.getErrorCode(), this.ivMessages)) {
                z2 = false;
            }
            return z3 & z2;
        }
    }

    public static boolean errorReported(String str, Collection collection) {
        if (!(str == null || collection == null || collection.size() == 0)) {
            Iterator it = collection.iterator();
            while (it.hasNext()) {
                if (str.equals(((XmlError) it.next()).getErrorCode())) {
                    return true;
                }
            }
        }
        return false;
    }

    public static void main(String[] strArr) {
        HashSet hashSet = new HashSet();
        hashSet.add("h");
        hashSet.add("help");
        hashSet.add("usage");
        hashSet.add("version");
        hashSet.add("showpass");
        hashSet.add("errcode");
        long currentTimeMillis = System.currentTimeMillis();
        CommandLine commandLine = new CommandLine(strArr, hashSet, Collections.EMPTY_SET);
        if (commandLine.getOpt("h") != null || commandLine.getOpt("help") != null || commandLine.getOpt("usage") != null) {
            printUsage();
            System.exit(0);
        } else if (commandLine.getOpt("version") != null) {
            CommandLine.printVersion();
            System.exit(0);
        } else {
            String[] badOpts = commandLine.getBadOpts();
            if (badOpts.length > 0) {
                for (String str : badOpts) {
                    PrintStream printStream = System.out;
                    StringBuffer a = a.a("Unrecognized option: ");
                    a.append(str);
                    printStream.println(a.toString());
                }
                printUsage();
                System.exit(0);
            } else if (commandLine.args().length == 0) {
                printUsage();
            } else {
                boolean z = true;
                boolean z2 = commandLine.getOpt("showpass") != null;
                if (commandLine.getOpt("errcode") == null) {
                    z = false;
                }
                File[] files = commandLine.getFiles();
                ArrayList arrayList = new ArrayList();
                XMLBeanXSTCHarness xMLBeanXSTCHarness = new XMLBeanXSTCHarness();
                for (int i2 = 0; i2 < files.length; i2++) {
                    if (files[i2].getName().indexOf("LTG") >= 0) {
                        arrayList.add(files[i2]);
                    }
                }
                File file = new File("out.html");
                PrintWriter printWriter = new PrintWriter(new FileWriter(file));
                printWriter.println("<html>");
                printWriter.println("<style>td {border-bottom: 1px solid black} xmp {white-space: normal; word-wrap: break-word; word-break: break-all} </style>");
                printWriter.println("<body>");
                printWriter.println("<script language='JavaScript' type='text/javascript'>");
                printWriter.println("var w;");
                printWriter.println("function openWindow(schema, instance) {");
                printWriter.println("  if (w == null) {");
                printWriter.println("    w = window.open('about:blank', 'xstc');");
                printWriter.println("  }");
                printWriter.println("  if (w.closed) {");
                printWriter.println("    w = window.open('about:blank', 'xstc');");
                printWriter.println("  }");
                printWriter.println("  w.document.open();");
                printWriter.println("  w.document.write(\"<frameset rows=*,*><frame src='\" + schema + \"'><frame src='\" + instance + \"'></frameset>\");");
                printWriter.println("  w.document.close();");
                printWriter.println("  w.focus();");
                printWriter.println("}");
                printWriter.println("</script>");
                printWriter.println("<h1>XML Schema Test Collection Results</h1>");
                StringBuffer stringBuffer = new StringBuffer();
                stringBuffer.append("<p>Run on ");
                stringBuffer.append(new XmlCalendar(new Date()));
                stringBuffer.append("</p>");
                printWriter.println(stringBuffer.toString());
                printWriter.println("<p>Values in schema or instance valid columns are results from compiling or validating respectively.");
                printWriter.println("Red or orange background mean the test failed.</p>");
                printWriter.println("<table style='border: 1px solid black' cellpadding=0 cellspacing=0>");
                printWriter.println("<tr><td witdh=10%>id</td><td width=70%>Description</td><td width=10%>sch v</td><td width=10%>ins v</td></tr>");
                Iterator it = arrayList.iterator();
                int i3 = 0;
                int i4 = 0;
                while (it.hasNext()) {
                    File file2 = (File) it.next();
                    PrintStream printStream2 = System.out;
                    StringBuffer stringBuffer2 = new StringBuffer();
                    stringBuffer2.append("Processing test cases in ");
                    stringBuffer2.append(file2);
                    printStream2.println(stringBuffer2.toString());
                    ArrayList arrayList2 = new ArrayList();
                    TestCase[] parseLTGFile = parseLTGFile(file2, arrayList2);
                    ArrayList arrayList3 = new ArrayList();
                    if (parseLTGFile != null) {
                        int i5 = 0;
                        while (i5 < parseLTGFile.length) {
                            TestCaseResult testCaseResult = new TestCaseResult();
                            testCaseResult.testCase = parseLTGFile[i5];
                            xMLBeanXSTCHarness.runTestCase(testCaseResult);
                            i4++;
                            if (!testCaseResult.succeeded(z)) {
                                i3++;
                            } else if (!z2) {
                                i5++;
                                it = it;
                            }
                            arrayList3.add(testCaseResult);
                            i5++;
                            it = it;
                        }
                    }
                    StringBuffer stringBuffer3 = new StringBuffer();
                    stringBuffer3.append("<tr><td colspan=4 bgcolor=skyblue>");
                    stringBuffer3.append(file2);
                    stringBuffer3.append("</td></tr>");
                    printWriter.println(stringBuffer3.toString());
                    if (!arrayList2.isEmpty()) {
                        printWriter.println("<tr><td>Errors within the LTG file:");
                        printWriter.println("<xmp>");
                        Iterator it2 = arrayList2.iterator();
                        while (it2.hasNext()) {
                            printWriter.println(it2.next());
                        }
                        printWriter.println("</xmp>");
                        printWriter.println("</td></tr>");
                    } else if (arrayList3.size() == 0) {
                        printWriter.println("<tr><td colspan=4 bgcolor=green>Nothing to report</td></tr>");
                    }
                    Iterator it3 = arrayList3.iterator();
                    while (it3.hasNext()) {
                        summarizeResultAsHTMLTableRows((TestCaseResult) it3.next(), printWriter, z);
                    }
                    it = it;
                }
                StringBuffer stringBuffer4 = new StringBuffer();
                stringBuffer4.append("<tr><td colspan=4>Summary: ");
                stringBuffer4.append(i3);
                stringBuffer4.append(" failures out of ");
                stringBuffer4.append(i4);
                stringBuffer4.append(" cases run.</td></tr>");
                printWriter.println(stringBuffer4.toString());
                printWriter.println("</table>");
                printWriter.close();
                long currentTimeMillis2 = System.currentTimeMillis();
                PrintStream printStream3 = System.out;
                StringBuffer a2 = a.a("Time run tests: ");
                a2.append(((double) (currentTimeMillis2 - currentTimeMillis)) / 1000.0d);
                a2.append(" seconds");
                printStream3.println(a2.toString());
                PrintStream printStream4 = System.out;
                StringBuffer stringBuffer5 = new StringBuffer();
                stringBuffer5.append("Results output to ");
                stringBuffer5.append(file);
                printStream4.println(stringBuffer5.toString());
                if (SystemProperties.getProperty("os.name").toLowerCase().indexOf("windows") >= 0) {
                    Runtime runtime = Runtime.getRuntime();
                    StringBuffer a3 = a.a("cmd /c start iexplore \"");
                    a3.append(file.getAbsolutePath());
                    a3.append("\"");
                    runtime.exec(a3.toString());
                    return;
                }
                Runtime runtime2 = Runtime.getRuntime();
                StringBuffer a4 = a.a("mozilla file://");
                a4.append(file.getAbsolutePath());
                runtime2.exec(a4.toString());
            }
        }
    }

    public static String makeHTMLDescription(TestCase testCase) {
        StringBuffer a = a.a("<a class=noline href='javascript:openWindow(\"");
        if (testCase.getSchemaFile() == null) {
            a.append("about:No schema");
        } else {
            a.append(testCase.getSchemaFile().getAbsolutePath().replaceAll("\\\\", "\\\\\\\\"));
        }
        a.append("\", \"");
        if (testCase.getInstanceFile() == null) {
            a.append("about:No instance");
        } else {
            a.append(testCase.getInstanceFile().getAbsolutePath().replaceAll("\\\\", "\\\\\\\\"));
        }
        a.append("\")'><xmp>");
        a.append(leadingSpace.matcher(testCase.getDescription()).replaceAll(""));
        a.append("</xmp></a>");
        return a.toString();
    }

    public static String makeHTMLLink(File file, boolean z) {
        if (file == null) {
            return "&nbsp;";
        }
        URI uri = file.getAbsoluteFile().toURI();
        StringBuffer stringBuffer = new StringBuffer();
        stringBuffer.append("<a href=\"");
        stringBuffer.append(uri);
        stringBuffer.append("\" target=_blank>");
        stringBuffer.append(Boolean.toString(z));
        stringBuffer.append("</a>");
        return stringBuffer.toString();
    }

    public static TestCase[] parseLTGFile(File file, Collection collection) {
        ArrayList arrayList = new ArrayList();
        try {
            XmlOptions xmlOptions = new XmlOptions();
            xmlOptions.setLoadSubstituteNamespaces(Collections.singletonMap("", "http://www.bea.com/2003/05/xmlbean/ltgfmt"));
            xmlOptions.setErrorListener(arrayList);
            xmlOptions.setLoadLineNumbers();
            TestsDocument parse = TestsDocument.Factory.parse(file, xmlOptions);
            if (parse.validate(xmlOptions)) {
                org.apache.xmlbeans.impl.xb.ltgfmt.TestCase[] testArray = parse.getTests().getTestArray();
                ArrayList arrayList2 = new ArrayList();
                for (int i2 = 0; i2 < testArray.length; i2++) {
                    TestCase testCase = new TestCase();
                    testCase.ltgFile = file;
                    testCase.id = testArray[i2].getId();
                    testCase.origin = testArray[i2].getOrigin();
                    testCase.description = testArray[i2].getDescription();
                    FileDesc[] fileArray = testArray[i2].getFiles().getFileArray();
                    testArray[i2].getOrigin();
                    for (int i3 = 0; i3 < fileArray.length; i3++) {
                        String folder = fileArray[i3].getFolder();
                        String fileName = fileArray[i3].getFileName();
                        File parentFile = file.getParentFile();
                        StringBuffer stringBuffer = new StringBuffer();
                        stringBuffer.append(folder);
                        stringBuffer.append(ZipHelper.FORWARD_SLASH);
                        stringBuffer.append(fileName);
                        File file2 = new File(parentFile, stringBuffer.toString());
                        if (file2.exists() && file2.isFile()) {
                            if (file2.canRead()) {
                                int intValue = fileArray[i3].getRole().intValue();
                                if (intValue == 1) {
                                    if (testCase.schemaFile != null) {
                                        collection.add(XmlError.forObject("More than one schema file speicifed - ignoring all but last", fileArray[i3]).toString());
                                    }
                                    testCase.schemaFile = file2;
                                    testCase.svExpected = fileArray[i3].getValidity();
                                } else if (intValue == 2) {
                                    if (testCase.instanceFile != null) {
                                        collection.add(XmlError.forObject("More than one instance file speicifed - ignoring all but last", fileArray[i3]).toString());
                                    }
                                    testCase.instanceFile = file2;
                                    testCase.ivExpected = fileArray[i3].getValidity();
                                } else if (intValue == 3) {
                                    if (testCase.resourceFile != null) {
                                        collection.add(XmlError.forObject("More than one resource file speicifed - ignoring all but last", fileArray[i3]).toString());
                                    }
                                    testCase.resourceFile = file2;
                                    testCase.rvExpected = fileArray[i3].getValidity();
                                } else {
                                    throw new XmlException(XmlError.forObject("Unexpected file role", fileArray[i3]));
                                }
                                if (fileArray[i3].getCode() != null) {
                                    testCase.errorCode = fileArray[i3].getCode().getID();
                                }
                            }
                        }
                        StringBuffer stringBuffer2 = new StringBuffer();
                        stringBuffer2.append("Can't read file ");
                        stringBuffer2.append(file2);
                        collection.add(XmlError.forObject(stringBuffer2.toString(), fileArray[i3]).toString());
                    }
                    arrayList2.add(testCase);
                }
                return (TestCase[]) arrayList2.toArray(new TestCase[arrayList2.size()]);
            }
            StringBuffer stringBuffer3 = new StringBuffer();
            stringBuffer3.append("Document ");
            stringBuffer3.append(file);
            stringBuffer3.append(" not valid.");
            throw new Exception(stringBuffer3.toString());
        } catch (Exception e2) {
            if (arrayList.isEmpty()) {
                collection.add(e2.getMessage());
                return null;
            }
            Iterator it = arrayList.iterator();
            while (it.hasNext()) {
                collection.add(it.next().toString());
            }
            return null;
        }
    }

    public static void printUsage() {
        System.out.println("Usage: xstc [-showpass] [-errcode] foo_LTGfmt.xml ...");
    }

    public static void summarizeResultAsHTMLTableRows(TestCaseResult testCaseResult, PrintWriter printWriter, boolean z) {
        String str;
        TestCase testCase = testCaseResult.getTestCase();
        boolean z2 = false;
        boolean z3 = true;
        int i2 = (!z || testCase.getErrorCode() == null) ? 0 : 1;
        int i3 = (!testCaseResult.getIvMessages().isEmpty() || !testCaseResult.getSvMessages().isEmpty()) ? 1 : 0;
        boolean z4 = testCase.getSchemaFile() == null || testCase.isSvExpected() == testCaseResult.isSvActual();
        boolean z5 = testCase.getInstanceFile() == null || testCase.isIvExpected() == testCaseResult.isIvActual();
        if (i2 != 0) {
            if (errorReported(testCase.getErrorCode(), testCaseResult.svMessages) || errorReported(testCase.getErrorCode(), testCaseResult.ivMessages)) {
                z2 = true;
            }
            z3 = z2;
        }
        printWriter.println(testCaseResult.isCrash() ? "<tr bgcolor=black color=white>" : "<tr>");
        StringBuffer stringBuffer = new StringBuffer();
        stringBuffer.append("<td rowspan=");
        stringBuffer.append(i2 + 1 + i3);
        stringBuffer.append(" valign=top>");
        stringBuffer.append(testCase.getId());
        stringBuffer.append("</td>");
        printWriter.println(stringBuffer.toString());
        StringBuffer stringBuffer2 = new StringBuffer();
        String str2 = "<td valign=top>";
        stringBuffer2.append(str2);
        stringBuffer2.append(makeHTMLDescription(testCase));
        stringBuffer2.append("</td>");
        printWriter.println(stringBuffer2.toString());
        if (testCase.getResourceFile() == null) {
            str = makeHTMLLink(testCase.getSchemaFile(), testCaseResult.isSvActual());
        } else {
            StringBuffer stringBuffer3 = new StringBuffer();
            stringBuffer3.append(makeHTMLLink(testCase.getSchemaFile(), testCaseResult.isSvActual()));
            stringBuffer3.append("<br>");
            stringBuffer3.append(makeHTMLLink(testCase.getResourceFile(), testCaseResult.isSvActual()));
            str = stringBuffer3.toString();
        }
        StringBuffer stringBuffer4 = new StringBuffer();
        stringBuffer4.append(z4 ? str2 : testCaseResult.isSvActual() ? "<td bgcolor=orange valign=top>" : "<td bgcolor=red valign=top>");
        stringBuffer4.append(str);
        stringBuffer4.append("</td>");
        printWriter.println(stringBuffer4.toString());
        StringBuffer stringBuffer5 = new StringBuffer();
        if (!z5) {
            str2 = testCaseResult.isIvActual() ? "<td bgcolor=orange valign=top>" : "<td bgcolor=red valign=top>";
        }
        stringBuffer5.append(str2);
        stringBuffer5.append(makeHTMLLink(testCase.getInstanceFile(), testCaseResult.isIvActual()));
        stringBuffer5.append("</td>");
        printWriter.println(stringBuffer5.toString());
        printWriter.println("</tr>");
        if (i2 != 0) {
            printWriter.println("<tr>");
            StringBuffer stringBuffer6 = new StringBuffer();
            stringBuffer6.append(z3 ? "<td colspan=4 valid=top>" : "<td colspan=4 bgcolor=orange valign=top>");
            stringBuffer6.append("expected error: ");
            stringBuffer6.append(testCase.getErrorCode());
            stringBuffer6.append("</td>");
            printWriter.println(stringBuffer6.toString());
            printWriter.println("</tr>");
        }
        if (i3 != 0) {
            if (!testCaseResult.succeeded(z)) {
                printWriter.println("<tr><td colspan=4 bgcolor=yellow><xmp>");
            } else {
                printWriter.println("<tr><td colspan=4><xmp>");
            }
            for (Object obj : testCaseResult.getSvMessages()) {
                printWriter.println(obj);
            }
            for (Object obj2 : testCaseResult.getIvMessages()) {
                printWriter.println(obj2);
            }
            printWriter.println("</xmp></tr></td>");
        }
    }
}
