package org.apache.xmlbeans.impl.tool;

import b.b.a.a.a;
import java.io.DataInputStream;
import java.io.File;
import java.io.FileFilter;
import java.io.FileInputStream;
import java.io.FileNotFoundException;
import java.io.IOException;
import java.io.InputStream;
import java.io.PrintStream;
import java.math.BigInteger;
import java.util.ArrayList;
import java.util.Enumeration;
import java.util.HashMap;
import java.util.HashSet;
import java.util.List;
import java.util.Map;
import java.util.zip.ZipEntry;
import java.util.zip.ZipFile;
import org.apache.poi.javax.xml.namespace.QName;
import org.apache.poi.ss.formula.function.FunctionMetadataReader;
import org.apache.poi.ss.formula.functions.NumericFunction;
import org.apache.xmlbeans.QNameSet;
import org.apache.xmlbeans.XmlException;
import org.apache.xmlbeans.XmlObject;
import org.apache.xmlbeans.XmlOptions;
import org.apache.xmlbeans.impl.common.QNameHelper;
import org.apache.xmlbeans.impl.jam.internal.JamPrinter;
import org.apache.xmlbeans.impl.util.HexBin;
import org.apache.xmlbeans.soap.SOAPArrayType;

public class XsbDumper {
    public static final /* synthetic */ boolean $assertionsDisabled;
    public static final int DATA_BABE = -629491010;
    public static final int FIELD_GLOBAL = 1;
    public static final int FIELD_LOCALATTR = 2;
    public static final int FIELD_LOCALELT = 3;
    public static final int FIELD_NONE = 0;
    public static final int FILETYPE_SCHEMAATTRIBUTE = 4;
    public static final int FILETYPE_SCHEMAATTRIBUTEGROUP = 7;
    public static final int FILETYPE_SCHEMAELEMENT = 3;
    public static final int FILETYPE_SCHEMAINDEX = 1;
    public static final int FILETYPE_SCHEMAMODELGROUP = 6;
    public static final int FILETYPE_SCHEMAPOINTER = 5;
    public static final int FILETYPE_SCHEMATYPE = 2;
    public static final int FLAG_ABSTRACT = 262144;
    public static final int FLAG_ATTRIBUTE_TYPE = 524288;
    public static final int FLAG_BLOCK_EXT = 4096;
    public static final int FLAG_BLOCK_REST = 8192;
    public static final int FLAG_BOUNDED = 8;
    public static final int FLAG_COMPILED = 2048;
    public static final int FLAG_DOCUMENT_TYPE = 2;
    public static final int FLAG_FINAL_EXT = 16384;
    public static final int FLAG_FINAL_LIST = 131072;
    public static final int FLAG_FINAL_REST = 32768;
    public static final int FLAG_FINAL_UNION = 65536;
    public static final int FLAG_FINITE = 16;
    public static final int FLAG_HAS_PATTERN = 256;
    public static final int FLAG_NUMERIC = 32;
    public static final int FLAG_ORDERED = 4;
    public static final int FLAG_ORDER_SENSITIVE = 512;
    public static final int FLAG_PART_ABSTRACT = 128;
    public static final int FLAG_PART_BLOCKEXT = 16;
    public static final int FLAG_PART_BLOCKREST = 32;
    public static final int FLAG_PART_BLOCKSUBST = 64;
    public static final int FLAG_PART_FINALEXT = 256;
    public static final int FLAG_PART_FINALREST = 512;
    public static final int FLAG_PART_FIXED = 4;
    public static final int FLAG_PART_NILLABLE = 8;
    public static final int FLAG_PART_SKIPPABLE = 1;
    public static final int FLAG_PROP_ISATTR = 1;
    public static final int FLAG_PROP_JAVAARRAY = 8;
    public static final int FLAG_PROP_JAVAOPTIONAL = 4;
    public static final int FLAG_PROP_JAVASINGLETON = 2;
    public static final int FLAG_SIMPLE_TYPE = 1;
    public static final int FLAG_STRINGENUM = 64;
    public static final int FLAG_TOTAL_ORDER = 1024;
    public static final int FLAG_UNION_OF_LISTS = 128;
    public static final int MAJOR_VERSION = 2;
    public static final int MINOR_VERSION = 24;
    public static final byte[] SINGLE_ZERO_BYTE = {0};
    public static /* synthetic */ Class class$org$apache$xmlbeans$impl$tool$XsbDumper;
    public static final XmlOptions prettyOptions = new XmlOptions().setSavePrettyPrint();
    public String _indent;
    public DataInputStream _input;
    public int _majorver;
    public int _minorver;
    public PrintStream _out;
    public int _releaseno;
    public StringPool _stringPool;

    public class StringPool {
        public List intsToStrings = new ArrayList();
        public Map stringsToInts = new HashMap();

        public StringPool() {
            this.intsToStrings.add(null);
        }

        public int codeForString(String str) {
            if (str == null) {
                return 0;
            }
            Integer num = (Integer) this.stringsToInts.get(str);
            if (num == null) {
                num = new Integer(this.intsToStrings.size());
                this.intsToStrings.add(str);
                this.stringsToInts.put(str, num);
            }
            return num.intValue();
        }

        public void readFrom(DataInputStream dataInputStream) {
            if (this.intsToStrings.size() == 1 && this.stringsToInts.size() == 0) {
                try {
                    short readShort = dataInputStream.readShort();
                    XsbDumper xsbDumper = XsbDumper.this;
                    StringBuffer stringBuffer = new StringBuffer();
                    stringBuffer.append("String pool (");
                    stringBuffer.append((int) readShort);
                    stringBuffer.append("):");
                    xsbDumper.emit(stringBuffer.toString());
                    XsbDumper.this.indent();
                    for (int i2 = 1; i2 < readShort; i2++) {
                        String readUTF = dataInputStream.readUTF();
                        int codeForString = codeForString(readUTF);
                        if (codeForString == i2) {
                            XsbDumper xsbDumper2 = XsbDumper.this;
                            StringBuffer stringBuffer2 = new StringBuffer();
                            stringBuffer2.append(codeForString);
                            stringBuffer2.append(" = \"");
                            stringBuffer2.append(readUTF);
                            stringBuffer2.append("\"");
                            xsbDumper2.emit(stringBuffer2.toString());
                        } else {
                            throw new IllegalStateException();
                        }
                    }
                    XsbDumper.this.outdent();
                } catch (IOException e2) {
                    XsbDumper.this.emit(e2.toString());
                }
            } else {
                throw new IllegalStateException();
            }
        }

        public String stringForCode(int i2) {
            if (i2 == 0) {
                return null;
            }
            return (String) this.intsToStrings.get(i2);
        }
    }

    static {
        Class cls = class$org$apache$xmlbeans$impl$tool$XsbDumper;
        if (cls == null) {
            cls = class$("org.apache.xmlbeans.impl.tool.XsbDumper");
            class$org$apache$xmlbeans$impl$tool$XsbDumper = cls;
        }
        $assertionsDisabled = !cls.desiredAssertionStatus();
    }

    public XsbDumper(InputStream inputStream, String str, PrintStream printStream) {
        this._input = new DataInputStream(inputStream);
        this._indent = str;
        this._out = printStream;
    }

    public static String alwaysString(int i2) {
        if (i2 == 0) {
            return "NEVER";
        }
        if (i2 == 1) {
            return "VARIABLE";
        }
        if (i2 == 2) {
            return "CONSISTENTLY";
        }
        StringBuffer stringBuffer = new StringBuffer();
        stringBuffer.append("Unknown frequency code (");
        stringBuffer.append(i2);
        stringBuffer.append(")");
        return stringBuffer.toString();
    }

    public static String attruseCodeString(int i2) {
        if (i2 == 1) {
            return "PROHIBITED";
        }
        if (i2 == 2) {
            return "OPTIONAL";
        }
        if (i2 == 3) {
            return "REQUIRED";
        }
        StringBuffer stringBuffer = new StringBuffer();
        stringBuffer.append("Unknown use code (");
        stringBuffer.append(i2);
        stringBuffer.append(")");
        return stringBuffer.toString();
    }

    public static String bigIntegerString(BigInteger bigInteger) {
        return bigInteger == null ? "(null)" : bigInteger.toString();
    }

    public static /* synthetic */ Class class$(String str) {
        try {
            return Class.forName(str);
        } catch (ClassNotFoundException e2) {
            throw a.a(e2);
        }
    }

    public static String complexVarietyString(int i2) {
        if (i2 == 1) {
            return "EMPTY_CONTENT";
        }
        if (i2 == 2) {
            return "SIMPLE_CONTENT";
        }
        if (i2 == 3) {
            return "ELEMENT_CONTENT";
        }
        if (i2 == 4) {
            return "MIXED_CONTENT";
        }
        StringBuffer stringBuffer = new StringBuffer();
        stringBuffer.append("Unknown complex variety (");
        stringBuffer.append(i2);
        stringBuffer.append(")");
        return stringBuffer.toString();
    }

    public static String containerfieldTypeString(int i2) {
        if (i2 == 0) {
            return "FIELD_NONE";
        }
        if (i2 == 1) {
            return "FIELD_GLOBAL";
        }
        if (i2 == 2) {
            return "FIELD_LOCALATTR";
        }
        if (i2 == 3) {
            return "FIELD_LOCALELT";
        }
        StringBuffer stringBuffer = new StringBuffer();
        stringBuffer.append("Unknown container field type (");
        stringBuffer.append(i2);
        stringBuffer.append(")");
        return stringBuffer.toString();
    }

    public static void dump(File file, boolean z) {
        File[] listFiles;
        if (file.isDirectory()) {
            for (File file2 : file.listFiles(new FileFilter() {
                /* class org.apache.xmlbeans.impl.tool.XsbDumper.AnonymousClass1 */

                public boolean accept(File file) {
                    return file.isDirectory() || (file.isFile() && file.getName().endsWith(".xsb"));
                }
            })) {
                dump(file2, false);
            }
        } else if (file.getName().endsWith(".jar") || file.getName().endsWith(".zip")) {
            dumpZip(file);
        } else if (z || file.getName().endsWith(".xsb")) {
            try {
                System.out.println(file.toString());
                dump(new FileInputStream(file), JamPrinter.INDENT);
                System.out.println();
            } catch (FileNotFoundException e2) {
                System.out.println(e2.toString());
            }
        }
    }

    public static void dumpZip(File file) {
        try {
            ZipFile zipFile = new ZipFile(file);
            Enumeration<? extends ZipEntry> entries = zipFile.entries();
            while (entries.hasMoreElements()) {
                ZipEntry zipEntry = (ZipEntry) entries.nextElement();
                if (zipEntry.getName().endsWith(".xsb")) {
                    System.out.println(zipEntry.getName());
                    dump(zipFile.getInputStream(zipEntry), JamPrinter.INDENT);
                    System.out.println();
                }
            }
        } catch (IOException e2) {
            System.out.println(e2.toString());
        }
    }

    public static String filetypeString(int i2) {
        switch (i2) {
            case 1:
                return "FILETYPE_SCHEMAINDEX";
            case 2:
                return "FILETYPE_SCHEMATYPE";
            case 3:
                return "FILETYPE_SCHEMAELEMENT";
            case 4:
                return "FILETYPE_SCHEMAATTRIBUTE";
            case 5:
                return "FILETYPE_SCHEMAPOINTER";
            case 6:
                return "FILETYPE_SCHEMAMODELGROUP";
            case 7:
                return "FILETYPE_SCHEMAATTRIBUTEGROUP";
            default:
                StringBuffer stringBuffer = new StringBuffer();
                stringBuffer.append("Unknown FILETYPE (");
                stringBuffer.append(i2);
                stringBuffer.append(")");
                return stringBuffer.toString();
        }
    }

    public static String hex32String(int i2) {
        return Integer.toHexString(i2);
    }

    public static String jtcString(int i2) {
        switch (i2) {
            case 0:
                return "XML_OBJECT";
            case 1:
                return "JAVA_BOOLEAN";
            case 2:
                return "JAVA_FLOAT";
            case 3:
                return "JAVA_DOUBLE";
            case 4:
                return "JAVA_BYTE";
            case 5:
                return "JAVA_SHORT";
            case 6:
                return "JAVA_INT";
            case 7:
                return "JAVA_LONG";
            case 8:
                return "JAVA_BIG_DECIMAL";
            case 9:
                return "JAVA_BIG_INTEGER";
            case 10:
                return "JAVA_STRING";
            case 11:
                return "JAVA_BYTE_ARRAY";
            case 12:
                return "JAVA_GDATE";
            case 13:
                return "JAVA_GDURATION";
            case 14:
                return "JAVA_DATE";
            case 15:
                return "JAVA_QNAME";
            case 16:
                return "JAVA_LIST";
            case 17:
                return "JAVA_CALENDAR";
            case 18:
                return "JAVA_ENUM";
            case 19:
                return "JAVA_OBJECT";
            default:
                StringBuffer stringBuffer = new StringBuffer();
                stringBuffer.append("Unknown java type code (");
                stringBuffer.append(i2);
                stringBuffer.append(")");
                return stringBuffer.toString();
        }
    }

    public static void main(String[] strArr) {
        if (strArr.length == 0) {
            printUsage();
            System.exit(0);
            return;
        }
        for (String str : strArr) {
            dump(new File(str), true);
        }
    }

    public static String particleTypeString(int i2) {
        if (i2 == 1) {
            return "ALL";
        }
        if (i2 == 2) {
            return "CHOICE";
        }
        if (i2 == 3) {
            return "SEQUENCE";
        }
        if (i2 == 4) {
            return "ELEMENT";
        }
        if (i2 == 5) {
            return "WILDCARD";
        }
        StringBuffer stringBuffer = new StringBuffer();
        stringBuffer.append("Unknown particle type (");
        stringBuffer.append(i2);
        stringBuffer.append(")");
        return stringBuffer.toString();
    }

    public static String particleflagsString(int i2) {
        StringBuffer stringBuffer = new StringBuffer();
        if ((i2 & 1) != 0) {
            stringBuffer.append("FLAG_PART_SKIPPABLE | ");
        }
        if ((i2 & 4) != 0) {
            stringBuffer.append("FLAG_PART_FIXED | ");
        }
        if ((i2 & 8) != 0) {
            stringBuffer.append("FLAG_PART_NILLABLE | ");
        }
        if ((i2 & 16) != 0) {
            stringBuffer.append("FLAG_PART_BLOCKEXT | ");
        }
        if ((i2 & 32) != 0) {
            stringBuffer.append("FLAG_PART_BLOCKREST | ");
        }
        if ((i2 & 64) != 0) {
            stringBuffer.append("FLAG_PART_BLOCKSUBST | ");
        }
        if ((i2 & 128) != 0) {
            stringBuffer.append("FLAG_PART_ABSTRACT | ");
        }
        if ((i2 & 256) != 0) {
            stringBuffer.append("FLAG_PART_FINALEXT | ");
        }
        if ((i2 & 512) != 0) {
            stringBuffer.append("FLAG_PART_FINALREST | ");
        }
        if (stringBuffer.length() == 0) {
            stringBuffer.append("0 | ");
        }
        return stringBuffer.substring(0, stringBuffer.length() - 3);
    }

    public static void printUsage() {
        System.out.println("Prints the contents of an XSB file in human-readable form.");
        System.out.println("An XSB file contains schema meta information needed to ");
        System.out.println("perform tasks such as binding and validation.");
        System.out.println("Usage: dumpxsb myfile.xsb");
        System.out.println("    myfile.xsb - Path to an XSB file.");
        System.out.println();
    }

    public static String propertyflagsString(int i2) {
        StringBuffer stringBuffer = new StringBuffer();
        if ((i2 & 1) != 0) {
            stringBuffer.append("FLAG_PROP_ISATTR | ");
        }
        if ((i2 & 2) != 0) {
            stringBuffer.append("FLAG_PROP_JAVASINGLETON | ");
        }
        if ((i2 & 4) != 0) {
            stringBuffer.append("FLAG_PROP_JAVAOPTIONAL | ");
        }
        if ((i2 & 8) != 0) {
            stringBuffer.append("FLAG_PROP_JAVAARRAY | ");
        }
        if (stringBuffer.length() == 0) {
            stringBuffer.append("0 | ");
        }
        return stringBuffer.substring(0, stringBuffer.length() - 3);
    }

    public static String qnameSetString(QNameSet qNameSet) {
        return qNameSet.toString();
    }

    public static String qnameString(QName qName) {
        if (qName == null) {
            return "(null)";
        }
        if (qName.getNamespaceURI() == null) {
            return qName.getLocalPart();
        }
        StringBuffer stringBuffer = new StringBuffer();
        stringBuffer.append(qName.getLocalPart());
        stringBuffer.append("@");
        stringBuffer.append(qName.getNamespaceURI());
        return stringBuffer.toString();
    }

    public static String simpleVarietyString(int i2) {
        if (i2 == 1) {
            return "ATOMIC";
        }
        if (i2 == 2) {
            return "UNION";
        }
        if (i2 == 3) {
            return "LIST";
        }
        StringBuffer stringBuffer = new StringBuffer();
        stringBuffer.append("Unknown simple variety (");
        stringBuffer.append(i2);
        stringBuffer.append(")");
        return stringBuffer.toString();
    }

    public static String typeflagsString(int i2) {
        StringBuffer stringBuffer = new StringBuffer();
        if ((i2 & 1) != 0) {
            stringBuffer.append("FLAG_SIMPLE_TYPE | ");
        }
        if ((i2 & 2) != 0) {
            stringBuffer.append("FLAG_DOCUMENT_TYPE | ");
        }
        if ((524288 & i2) != 0) {
            stringBuffer.append("FLAG_ATTRIBUTE_TYPE | ");
        }
        if ((i2 & 4) != 0) {
            stringBuffer.append("FLAG_ORDERED | ");
        }
        if ((i2 & 8) != 0) {
            stringBuffer.append("FLAG_BOUNDED | ");
        }
        if ((i2 & 16) != 0) {
            stringBuffer.append("FLAG_FINITE | ");
        }
        if ((i2 & 32) != 0) {
            stringBuffer.append("FLAG_NUMERIC | ");
        }
        if ((i2 & 64) != 0) {
            stringBuffer.append("FLAG_STRINGENUM | ");
        }
        if ((i2 & 128) != 0) {
            stringBuffer.append("FLAG_UNION_OF_LISTS | ");
        }
        if ((i2 & 256) != 0) {
            stringBuffer.append("FLAG_HAS_PATTERN | ");
        }
        if ((i2 & 1024) != 0) {
            stringBuffer.append("FLAG_TOTAL_ORDER | ");
        }
        if ((i2 & 2048) != 0) {
            stringBuffer.append("FLAG_COMPILED | ");
        }
        if ((i2 & 4096) != 0) {
            stringBuffer.append("FLAG_BLOCK_EXT | ");
        }
        if ((i2 & 8192) != 0) {
            stringBuffer.append("FLAG_BLOCK_REST | ");
        }
        if ((i2 & 16384) != 0) {
            stringBuffer.append("FLAG_FINAL_EXT | ");
        }
        if ((32768 & i2) != 0) {
            stringBuffer.append("FLAG_FINAL_REST | ");
        }
        if ((65536 & i2) != 0) {
            stringBuffer.append("FLAG_FINAL_UNION | ");
        }
        if ((131072 & i2) != 0) {
            stringBuffer.append("FLAG_FINAL_LIST | ");
        }
        if ((i2 & 262144) != 0) {
            stringBuffer.append("FLAG_ABSTRACT | ");
        }
        if (stringBuffer.length() == 0) {
            stringBuffer.append("0 | ");
        }
        return stringBuffer.substring(0, stringBuffer.length() - 3);
    }

    public static String wcprocessString(int i2) {
        if (i2 == 0) {
            return "NOT_WILDCARD";
        }
        if (i2 == 1) {
            return "STRICT";
        }
        if (i2 == 2) {
            return "LAX";
        }
        if (i2 == 3) {
            return "SKIP";
        }
        StringBuffer stringBuffer = new StringBuffer();
        stringBuffer.append("Unknown process type (");
        stringBuffer.append(i2);
        stringBuffer.append(")");
        return stringBuffer.toString();
    }

    public String SOAPArrayTypeString(SOAPArrayType sOAPArrayType) {
        if (sOAPArrayType == null) {
            return "null";
        }
        StringBuffer stringBuffer = new StringBuffer();
        stringBuffer.append(QNameHelper.pretty(sOAPArrayType.getQName()));
        stringBuffer.append(sOAPArrayType.soap11DimensionString());
        return stringBuffer.toString();
    }

    public boolean atLeast(int i2, int i3, int i4) {
        int i5 = this._majorver;
        if (i5 > i2) {
            return true;
        }
        if (i5 < i2) {
            return false;
        }
        int i6 = this._minorver;
        if (i6 > i3) {
            return true;
        }
        if (i6 >= i3 && this._releaseno >= i4) {
            return true;
        }
        return false;
    }

    public boolean atMost(int i2, int i3, int i4) {
        int i5 = this._majorver;
        if (i5 > i2) {
            return false;
        }
        if (i5 < i2) {
            return true;
        }
        int i6 = this._minorver;
        if (i6 > i3) {
            return false;
        }
        if (i6 >= i3 && this._releaseno > i4) {
            return false;
        }
        return true;
    }

    public String derivationTypeString(int i2) {
        if (i2 == 0) {
            return "DT_NOT_DERIVED";
        }
        if (i2 == 1) {
            return "DT_RESTRICTION";
        }
        if (i2 == 2) {
            return "DT_EXTENSION";
        }
        StringBuffer stringBuffer = new StringBuffer();
        stringBuffer.append("Unknown derivation code (");
        stringBuffer.append(i2);
        stringBuffer.append(")");
        return stringBuffer.toString();
    }

    public void dumpAll() {
        switch (dumpHeader()) {
            case 1:
                dumpIndexData();
                return;
            case 2:
                dumpTypeFileData();
                break;
            case 3:
                dumpParticleData(true);
                break;
            case 4:
                dumpAttributeData(true);
                break;
            case 5:
                dumpPointerData();
                break;
            case 6:
                dumpModelGroupData();
                break;
            case 7:
                dumpAttributeGroupData();
                break;
        }
        readEnd();
    }

    public void dumpAnnotation() {
        int readInt;
        boolean z;
        boolean z2 = false;
        if (atLeast(2, 19, 0) && (readInt = readInt()) != -1) {
            emit("Annotation");
            indent();
            if (readInt > 0) {
                StringBuffer stringBuffer = new StringBuffer();
                stringBuffer.append("Attributes (");
                stringBuffer.append(readInt);
                stringBuffer.append("):");
                emit(stringBuffer.toString());
                indent();
                for (int i2 = 0; i2 < readInt; i2++) {
                    if (atLeast(2, 24, 0)) {
                        StringBuffer a = a.a("Name: ");
                        a.append(qnameString(readQName()));
                        a.append(", Value: ");
                        a.append(readString());
                        a.append(", ValueURI: ");
                        a.append(readString());
                        emit(a.toString());
                    } else {
                        StringBuffer a2 = a.a("Name: ");
                        a2.append(qnameString(readQName()));
                        a2.append(", Value: ");
                        a2.append(readString());
                        emit(a2.toString());
                    }
                }
                outdent();
                z = false;
            } else {
                z = true;
            }
            int readInt2 = readInt();
            if (readInt2 > 0) {
                StringBuffer stringBuffer2 = new StringBuffer();
                stringBuffer2.append("Documentation elements (");
                stringBuffer2.append(readInt2);
                stringBuffer2.append("):");
                emit(stringBuffer2.toString());
                indent();
                for (int i3 = 0; i3 < readInt2; i3++) {
                    emit(readString());
                }
                outdent();
                z = false;
            }
            int readInt3 = readInt();
            if (readInt3 > 0) {
                StringBuffer stringBuffer3 = new StringBuffer();
                stringBuffer3.append("Appinfo elements (");
                stringBuffer3.append(readInt3);
                stringBuffer3.append("):");
                emit(stringBuffer3.toString());
                indent();
                for (int i4 = 0; i4 < readInt3; i4++) {
                    emit(readString());
                }
                outdent();
            } else {
                z2 = z;
            }
            if (z2) {
                emit("<empty>");
            }
            outdent();
        }
    }

    public void dumpAnnotations() {
        int readInt = readInt();
        if (readInt > 0) {
            StringBuffer stringBuffer = new StringBuffer();
            stringBuffer.append("Top-level annotations (");
            stringBuffer.append(readInt);
            stringBuffer.append("):");
            emit(stringBuffer.toString());
            indent();
            for (int i2 = 0; i2 < readInt; i2++) {
                dumpAnnotation();
            }
            outdent();
        }
    }

    public void dumpAttributeData(boolean z) {
        StringBuffer a = a.a("Name: ");
        a.append(qnameString(readQName()));
        emit(a.toString());
        StringBuffer stringBuffer = new StringBuffer();
        stringBuffer.append("Type: ");
        stringBuffer.append(readType());
        emit(stringBuffer.toString());
        StringBuffer stringBuffer2 = new StringBuffer();
        stringBuffer2.append("Use: ");
        stringBuffer2.append(attruseCodeString(readShort()));
        emit(stringBuffer2.toString());
        StringBuffer stringBuffer3 = new StringBuffer();
        stringBuffer3.append("Default: ");
        stringBuffer3.append(readString());
        emit(stringBuffer3.toString());
        if (atLeast(2, 16, 0)) {
            StringBuffer a2 = a.a("Default value: ");
            a2.append(readXmlValueObject());
            emit(a2.toString());
        }
        StringBuffer a3 = a.a("Fixed: ");
        a3.append(readShort());
        emit(a3.toString());
        StringBuffer stringBuffer4 = new StringBuffer();
        stringBuffer4.append("WsdlArrayType: ");
        stringBuffer4.append(SOAPArrayTypeString(readSOAPArrayType()));
        emit(stringBuffer4.toString());
        dumpAnnotation();
        if (z) {
            StringBuffer a4 = a.a("Filename: ");
            a4.append(readString());
            emit(a4.toString());
        }
    }

    public void dumpAttributeGroupData() {
        StringBuffer a = a.a("Name: ");
        a.append(qnameString(readQName()));
        emit(a.toString());
        StringBuffer stringBuffer = new StringBuffer();
        stringBuffer.append("Target namespace: ");
        stringBuffer.append(readString());
        emit(stringBuffer.toString());
        StringBuffer stringBuffer2 = new StringBuffer();
        stringBuffer2.append("Chameleon: ");
        stringBuffer2.append(readShort());
        emit(stringBuffer2.toString());
        if (atLeast(2, 22, 0)) {
            StringBuffer a2 = a.a("Form default: ");
            a2.append(readString());
            emit(a2.toString());
        }
        if (atLeast(2, 15, 0)) {
            StringBuffer a3 = a.a("Redefine: ");
            a3.append(readShort());
            emit(a3.toString());
        }
        emit("Attribute Group Xml: ");
        dumpXml();
        dumpAnnotation();
        if (atLeast(2, 21, 0)) {
            StringBuffer a4 = a.a("Filename: ");
            a4.append(readString());
            emit(a4.toString());
        }
    }

    public void dumpClassnameIndex(String str) {
        int readShort = readShort();
        StringBuffer stringBuffer = new StringBuffer();
        stringBuffer.append(str);
        stringBuffer.append(" (");
        stringBuffer.append(readShort);
        stringBuffer.append("):");
        emit(stringBuffer.toString());
        indent();
        for (int i2 = 0; i2 < readShort; i2++) {
            StringBuffer stringBuffer2 = new StringBuffer();
            stringBuffer2.append(readString());
            stringBuffer2.append(" = ");
            stringBuffer2.append(readType());
            emit(stringBuffer2.toString());
        }
        outdent();
    }

    public int dumpHeader() {
        int readInt = readInt();
        StringBuffer a = a.a("Magic cookie: ");
        a.append(hex32String(readInt));
        emit(a.toString());
        if (readInt != -629491010) {
            emit("Wrong magic cookie.");
            return 0;
        }
        this._majorver = readShort();
        this._minorver = readShort();
        if (atLeast(2, 18, 0)) {
            this._releaseno = readShort();
        }
        StringBuffer a2 = a.a("Major version: ");
        a2.append(this._majorver);
        emit(a2.toString());
        StringBuffer stringBuffer = new StringBuffer();
        stringBuffer.append("Minor version: ");
        stringBuffer.append(this._minorver);
        emit(stringBuffer.toString());
        StringBuffer stringBuffer2 = new StringBuffer();
        stringBuffer2.append("Release number: ");
        stringBuffer2.append(this._releaseno);
        emit(stringBuffer2.toString());
        if (this._majorver != 2 || this._minorver > 24) {
            emit("Incompatible version.");
            return 0;
        }
        int readShort = readShort();
        StringBuffer a3 = a.a("Filetype: ");
        a3.append(filetypeString(readShort));
        emit(a3.toString());
        StringPool stringPool = new StringPool();
        this._stringPool = stringPool;
        stringPool.readFrom(this._input);
        return readShort;
    }

    public void dumpIndexData() {
        int readShort = readShort();
        StringBuffer stringBuffer = new StringBuffer();
        stringBuffer.append("Handle pool (");
        stringBuffer.append(readShort);
        stringBuffer.append("):");
        emit(stringBuffer.toString());
        indent();
        for (int i2 = 0; i2 < readShort; i2++) {
            String readString = readString();
            int readShort2 = readShort();
            StringBuffer c = a.c(readString, " (");
            c.append(filetypeString(readShort2));
            c.append(")");
            emit(c.toString());
        }
        outdent();
        dumpQNameMap("Global elements");
        dumpQNameMap("Global attributes");
        dumpQNameMap("Model groups");
        dumpQNameMap("Attribute groups");
        dumpQNameMap("Identity constraints");
        dumpQNameMap("Global types");
        dumpQNameMap("Document types");
        dumpQNameMap("Attribute types");
        dumpClassnameIndex("All types by classname");
        dumpStringArray("Defined namespaces");
        if (atLeast(2, 15, 0)) {
            dumpQNameMap("Redefined global types");
            dumpQNameMap("Redfined model groups");
            dumpQNameMap("Redfined attribute groups");
        }
        if (atLeast(2, 19, 0)) {
            dumpAnnotations();
        }
        readEnd();
    }

    public void dumpModelGroupData() {
        StringBuffer a = a.a("Name: ");
        a.append(qnameString(readQName()));
        emit(a.toString());
        StringBuffer stringBuffer = new StringBuffer();
        stringBuffer.append("Target namespace: ");
        stringBuffer.append(readString());
        emit(stringBuffer.toString());
        StringBuffer stringBuffer2 = new StringBuffer();
        stringBuffer2.append("Chameleon: ");
        stringBuffer2.append(readShort());
        emit(stringBuffer2.toString());
        if (atLeast(2, 22, 0)) {
            StringBuffer a2 = a.a("Element form default: ");
            a2.append(readString());
            emit(a2.toString());
        }
        if (atLeast(2, 22, 0)) {
            StringBuffer a3 = a.a("Attribute form default: ");
            a3.append(readString());
            emit(a3.toString());
        }
        if (atLeast(2, 15, 0)) {
            StringBuffer a4 = a.a("Redefine: ");
            a4.append(readShort());
            emit(a4.toString());
        }
        emit("Model Group Xml: ");
        dumpXml();
        dumpAnnotation();
        if (atLeast(2, 21, 0)) {
            StringBuffer a5 = a.a("Filename: ");
            a5.append(readString());
            emit(a5.toString());
        }
    }

    public void dumpParticleArray(String str) {
        int readShort = readShort();
        StringBuffer stringBuffer = new StringBuffer();
        stringBuffer.append(str);
        stringBuffer.append("(");
        stringBuffer.append(readShort);
        stringBuffer.append("):");
        emit(stringBuffer.toString());
        indent();
        for (int i2 = 0; i2 < readShort; i2++) {
            dumpParticleData(false);
        }
        outdent();
    }

    public void dumpParticleData(boolean z) {
        int readShort = readShort();
        StringBuffer stringBuffer = new StringBuffer();
        stringBuffer.append(particleTypeString(readShort));
        stringBuffer.append(":");
        emit(stringBuffer.toString());
        indent();
        int readShort2 = readShort();
        StringBuffer a = a.a("Flags: ");
        a.append(particleflagsString(readShort2));
        emit(a.toString());
        StringBuffer stringBuffer2 = new StringBuffer();
        stringBuffer2.append("MinOccurs: ");
        stringBuffer2.append(bigIntegerString(readBigInteger()));
        emit(stringBuffer2.toString());
        StringBuffer stringBuffer3 = new StringBuffer();
        stringBuffer3.append("MaxOccurs: ");
        stringBuffer3.append(bigIntegerString(readBigInteger()));
        emit(stringBuffer3.toString());
        StringBuffer stringBuffer4 = new StringBuffer();
        stringBuffer4.append("Transition: ");
        stringBuffer4.append(qnameSetString(readQNameSet()));
        emit(stringBuffer4.toString());
        if (readShort == 1 || readShort == 2 || readShort == 3) {
            dumpParticleArray("Particle children");
        } else if (readShort == 4) {
            StringBuffer a2 = a.a("Name: ");
            a2.append(qnameString(readQName()));
            emit(a2.toString());
            StringBuffer stringBuffer5 = new StringBuffer();
            stringBuffer5.append("Type: ");
            stringBuffer5.append(readType());
            emit(stringBuffer5.toString());
            StringBuffer stringBuffer6 = new StringBuffer();
            stringBuffer6.append("Default: ");
            stringBuffer6.append(readString());
            emit(stringBuffer6.toString());
            if (atLeast(2, 16, 0)) {
                StringBuffer a3 = a.a("Default value: ");
                a3.append(readXmlValueObject());
                emit(a3.toString());
            }
            StringBuffer a4 = a.a("WsdlArrayType: ");
            a4.append(SOAPArrayTypeString(readSOAPArrayType()));
            emit(a4.toString());
            dumpAnnotation();
            if (z) {
                if (atLeast(2, 17, 0)) {
                    StringBuffer a5 = a.a("Substitution group ref: ");
                    a5.append(readHandle());
                    emit(a5.toString());
                }
                int readShort3 = readShort();
                StringBuffer stringBuffer7 = new StringBuffer();
                stringBuffer7.append("Substitution group members (");
                stringBuffer7.append(readShort3);
                stringBuffer7.append(")");
                emit(stringBuffer7.toString());
                indent();
                for (int i2 = 0; i2 < readShort3; i2++) {
                    emit(qnameString(readQName()));
                }
                outdent();
            }
            int readShort4 = readShort();
            StringBuffer stringBuffer8 = new StringBuffer();
            stringBuffer8.append("Identity constraints (");
            stringBuffer8.append(readShort4);
            stringBuffer8.append("):");
            emit(stringBuffer8.toString());
            indent();
            for (int i3 = 0; i3 < readShort4; i3++) {
                emit(readHandle());
            }
            outdent();
            if (z) {
                StringBuffer a6 = a.a("Filename: ");
                a6.append(readString());
                emit(a6.toString());
            }
        } else if (readShort != 5) {
            error("Unrecognized schema particle type");
        } else {
            StringBuffer a7 = a.a("Wildcard set: ");
            a7.append(qnameSetString(readQNameSet()));
            emit(a7.toString());
            StringBuffer stringBuffer9 = new StringBuffer();
            stringBuffer9.append("Wildcard process: ");
            stringBuffer9.append(wcprocessString(readShort()));
            emit(stringBuffer9.toString());
        }
        outdent();
    }

    public void dumpPointerData() {
        StringBuffer a = a.a("Type system: ");
        a.append(readString());
        emit(a.toString());
    }

    public void dumpPropertyData() {
        emit("Property");
        indent();
        StringBuffer stringBuffer = new StringBuffer();
        stringBuffer.append("Name: ");
        stringBuffer.append(qnameString(readQName()));
        emit(stringBuffer.toString());
        StringBuffer stringBuffer2 = new StringBuffer();
        stringBuffer2.append("Type: ");
        stringBuffer2.append(readType());
        emit(stringBuffer2.toString());
        int readShort = readShort();
        StringBuffer a = a.a("Flags: ");
        a.append(propertyflagsString(readShort));
        emit(a.toString());
        StringBuffer stringBuffer3 = new StringBuffer();
        stringBuffer3.append("Container type: ");
        stringBuffer3.append(readType());
        emit(stringBuffer3.toString());
        StringBuffer stringBuffer4 = new StringBuffer();
        stringBuffer4.append("Min occurances: ");
        stringBuffer4.append(bigIntegerString(readBigInteger()));
        emit(stringBuffer4.toString());
        StringBuffer stringBuffer5 = new StringBuffer();
        stringBuffer5.append("Max occurances: ");
        stringBuffer5.append(bigIntegerString(readBigInteger()));
        emit(stringBuffer5.toString());
        StringBuffer stringBuffer6 = new StringBuffer();
        stringBuffer6.append("Nillable: ");
        stringBuffer6.append(alwaysString(readShort()));
        emit(stringBuffer6.toString());
        StringBuffer stringBuffer7 = new StringBuffer();
        stringBuffer7.append("Default: ");
        stringBuffer7.append(alwaysString(readShort()));
        emit(stringBuffer7.toString());
        StringBuffer stringBuffer8 = new StringBuffer();
        stringBuffer8.append("Fixed: ");
        stringBuffer8.append(alwaysString(readShort()));
        emit(stringBuffer8.toString());
        StringBuffer stringBuffer9 = new StringBuffer();
        stringBuffer9.append("Default text: ");
        stringBuffer9.append(readString());
        emit(stringBuffer9.toString());
        StringBuffer stringBuffer10 = new StringBuffer();
        stringBuffer10.append("Java prop name: ");
        stringBuffer10.append(readString());
        emit(stringBuffer10.toString());
        StringBuffer stringBuffer11 = new StringBuffer();
        stringBuffer11.append("Java type code: ");
        stringBuffer11.append(jtcString(readShort()));
        emit(stringBuffer11.toString());
        StringBuffer stringBuffer12 = new StringBuffer();
        stringBuffer12.append("Type for java signature: ");
        stringBuffer12.append(readType());
        emit(stringBuffer12.toString());
        if (atMost(2, 19, 0)) {
            StringBuffer a2 = a.a("Java setter delimiter: ");
            a2.append(qnameSetString(readQNameSet()));
            emit(a2.toString());
        }
        if (atLeast(2, 16, 0)) {
            StringBuffer a3 = a.a("Default value: ");
            a3.append(readXmlValueObject());
            emit(a3.toString());
        }
        if ((readShort & 1) == 0 && atLeast(2, 17, 0)) {
            int readShort2 = readShort();
            StringBuffer stringBuffer13 = new StringBuffer();
            stringBuffer13.append("Accepted substitutions (");
            stringBuffer13.append(readShort2);
            stringBuffer13.append("):");
            emit(stringBuffer13.toString());
            for (int i2 = 0; i2 < readShort2; i2++) {
                StringBuffer a4 = a.a("  Accepted name ");
                a4.append(readQName());
                emit(a4.toString());
            }
        }
        outdent();
    }

    public void dumpQNameMap(String str) {
        int readShort = readShort();
        StringBuffer stringBuffer = new StringBuffer();
        stringBuffer.append(str);
        stringBuffer.append(" (");
        stringBuffer.append(readShort);
        stringBuffer.append("):");
        emit(stringBuffer.toString());
        indent();
        for (int i2 = 0; i2 < readShort; i2++) {
            StringBuffer stringBuffer2 = new StringBuffer();
            stringBuffer2.append(qnameString(readQName()));
            stringBuffer2.append(" = ");
            stringBuffer2.append(readHandle());
            emit(stringBuffer2.toString());
        }
        outdent();
    }

    public void dumpStringArray(String str) {
        int readShort = readShort();
        StringBuffer stringBuffer = new StringBuffer();
        stringBuffer.append(str);
        stringBuffer.append(" (");
        stringBuffer.append(readShort);
        stringBuffer.append("):");
        emit(stringBuffer.toString());
        indent();
        for (int i2 = 0; i2 < readShort; i2++) {
            emit(readString());
        }
        outdent();
    }

    public void dumpTypeArray(String str) {
        int readShort = readShort();
        StringBuffer stringBuffer = new StringBuffer();
        stringBuffer.append(str);
        stringBuffer.append(" (");
        stringBuffer.append(readShort);
        stringBuffer.append("):");
        emit(stringBuffer.toString());
        indent();
        for (int i2 = 0; i2 < readShort; i2++) {
            StringBuffer stringBuffer2 = new StringBuffer();
            stringBuffer2.append(i2);
            stringBuffer2.append(" = ");
            stringBuffer2.append(readType());
            emit(stringBuffer2.toString());
        }
        outdent();
    }

    public void dumpTypeFileData() {
        int i2;
        StringBuffer a = a.a("Name: ");
        a.append(qnameString(readQName()));
        emit(a.toString());
        StringBuffer stringBuffer = new StringBuffer();
        stringBuffer.append("Outer type: ");
        stringBuffer.append(readType());
        emit(stringBuffer.toString());
        StringBuffer stringBuffer2 = new StringBuffer();
        stringBuffer2.append("Depth: ");
        stringBuffer2.append(readShort());
        emit(stringBuffer2.toString());
        StringBuffer stringBuffer3 = new StringBuffer();
        stringBuffer3.append("Base type: ");
        stringBuffer3.append(readType());
        emit(stringBuffer3.toString());
        StringBuffer stringBuffer4 = new StringBuffer();
        stringBuffer4.append("Derivation type: ");
        stringBuffer4.append(derivationTypeString(readShort()));
        emit(stringBuffer4.toString());
        dumpAnnotation();
        emit("Container field:");
        indent();
        int readShort = readShort();
        StringBuffer a2 = a.a("Reftype: ");
        a2.append(containerfieldTypeString(readShort));
        emit(a2.toString());
        if (readShort == 1) {
            StringBuffer a3 = a.a("Handle: ");
            a3.append(readHandle());
            emit(a3.toString());
        } else if (readShort == 2) {
            StringBuffer a4 = a.a("Index: ");
            a4.append(readShort());
            emit(a4.toString());
        } else if (readShort == 3) {
            StringBuffer a5 = a.a("Index: ");
            a5.append(readShort());
            emit(a5.toString());
        }
        outdent();
        StringBuffer stringBuffer5 = new StringBuffer();
        stringBuffer5.append("Java class name: ");
        stringBuffer5.append(readString());
        emit(stringBuffer5.toString());
        StringBuffer stringBuffer6 = new StringBuffer();
        stringBuffer6.append("Java impl class name: ");
        stringBuffer6.append(readString());
        emit(stringBuffer6.toString());
        dumpTypeArray("Anonymous types");
        StringBuffer stringBuffer7 = new StringBuffer();
        stringBuffer7.append("Anonymous union member ordinal: ");
        stringBuffer7.append(readShort());
        emit(stringBuffer7.toString());
        int readInt = readInt();
        StringBuffer a6 = a.a("Flags: ");
        a6.append(typeflagsString(readInt));
        emit(a6.toString());
        boolean z = (readInt & 1) == 0;
        if (z) {
            i2 = readShort();
            StringBuffer a7 = a.a("Complex variety: ");
            a7.append(complexVarietyString(i2));
            emit(a7.toString());
            if (atLeast(2, 23, 0)) {
                StringBuffer a8 = a.a("Content based on type: ");
                a8.append(readType());
                emit(a8.toString());
            }
            int readShort2 = readShort();
            StringBuffer stringBuffer8 = new StringBuffer();
            stringBuffer8.append("Attribute model (");
            stringBuffer8.append(readShort2);
            stringBuffer8.append("):");
            emit(stringBuffer8.toString());
            indent();
            for (int i3 = 0; i3 < readShort2; i3++) {
                dumpAttributeData(false);
            }
            StringBuffer a9 = a.a("Wildcard set: ");
            a9.append(qnameSetString(readQNameSet()));
            emit(a9.toString());
            StringBuffer stringBuffer9 = new StringBuffer();
            stringBuffer9.append("Wildcard process: ");
            stringBuffer9.append(wcprocessString(readShort()));
            emit(stringBuffer9.toString());
            outdent();
            int readShort3 = readShort();
            StringBuffer stringBuffer10 = new StringBuffer();
            stringBuffer10.append("Attribute properties (");
            stringBuffer10.append(readShort3);
            stringBuffer10.append("):");
            emit(stringBuffer10.toString());
            indent();
            for (int i4 = 0; i4 < readShort3; i4++) {
                dumpPropertyData();
            }
            outdent();
            if (i2 == 3 || i2 == 4) {
                StringBuffer a10 = a.a("IsAll: ");
                a10.append(readShort());
                emit(a10.toString());
                dumpParticleArray("Content model");
                int readShort4 = readShort();
                StringBuffer stringBuffer11 = new StringBuffer();
                stringBuffer11.append("Element properties (");
                stringBuffer11.append(readShort4);
                stringBuffer11.append("):");
                emit(stringBuffer11.toString());
                indent();
                for (int i5 = 0; i5 < readShort4; i5++) {
                    dumpPropertyData();
                }
                outdent();
            }
        } else {
            i2 = 0;
        }
        if (!z || i2 == 2) {
            int readShort5 = readShort();
            StringBuffer a11 = a.a("Simple type variety: ");
            a11.append(simpleVarietyString(readShort5));
            emit(a11.toString());
            boolean z2 = (readInt & 64) != 0;
            int readShort6 = readShort();
            StringBuffer stringBuffer12 = new StringBuffer();
            stringBuffer12.append("Facets (");
            stringBuffer12.append(readShort6);
            stringBuffer12.append("):");
            emit(stringBuffer12.toString());
            indent();
            for (int i6 = 0; i6 < readShort6; i6++) {
                emit(facetCodeString(readShort()));
                StringBuffer stringBuffer13 = new StringBuffer();
                stringBuffer13.append("Value: ");
                stringBuffer13.append(readXmlValueObject());
                emit(stringBuffer13.toString());
                StringBuffer stringBuffer14 = new StringBuffer();
                stringBuffer14.append("Fixed: ");
                stringBuffer14.append(readShort());
                emit(stringBuffer14.toString());
            }
            outdent();
            StringBuffer stringBuffer15 = new StringBuffer();
            stringBuffer15.append("Whitespace rule: ");
            stringBuffer15.append(whitespaceCodeString(readShort()));
            emit(stringBuffer15.toString());
            int readShort7 = readShort();
            StringBuffer stringBuffer16 = new StringBuffer();
            stringBuffer16.append("Patterns (");
            stringBuffer16.append(readShort7);
            stringBuffer16.append("):");
            emit(stringBuffer16.toString());
            indent();
            for (int i7 = 0; i7 < readShort7; i7++) {
                emit(readString());
            }
            outdent();
            int readShort8 = readShort();
            StringBuffer stringBuffer17 = new StringBuffer();
            stringBuffer17.append("Enumeration values (");
            stringBuffer17.append(readShort8);
            stringBuffer17.append("):");
            emit(stringBuffer17.toString());
            indent();
            for (int i8 = 0; i8 < readShort8; i8++) {
                emit(readXmlValueObject());
            }
            outdent();
            StringBuffer stringBuffer18 = new StringBuffer();
            stringBuffer18.append("Base enum type: ");
            stringBuffer18.append(readType());
            emit(stringBuffer18.toString());
            if (z2) {
                int readShort9 = readShort();
                StringBuffer stringBuffer19 = new StringBuffer();
                stringBuffer19.append("String enum entries (");
                stringBuffer19.append(readShort9);
                stringBuffer19.append("):");
                emit(stringBuffer19.toString());
                indent();
                for (int i9 = 0; i9 < readShort9; i9++) {
                    StringBuffer a12 = a.a("\"");
                    a12.append(readString());
                    a12.append("\" -> ");
                    a12.append(readShort());
                    a12.append(" = ");
                    a12.append(readString());
                    emit(a12.toString());
                }
                outdent();
            }
            if (readShort5 == 1) {
                StringBuffer a13 = a.a("Primitive type: ");
                a13.append(readType());
                emit(a13.toString());
                StringBuffer stringBuffer20 = new StringBuffer();
                stringBuffer20.append("Decimal size: ");
                stringBuffer20.append(readInt());
                emit(stringBuffer20.toString());
            } else if (readShort5 == 2) {
                dumpTypeArray("Union members");
            } else if (readShort5 != 3) {
                error("Unknown simple type variety");
            } else {
                StringBuffer a14 = a.a("List item type: ");
                a14.append(readType());
                emit(a14.toString());
            }
        }
        StringBuffer a15 = a.a("Filename: ");
        a15.append(readString());
        emit(a15.toString());
    }

    public void dumpXml() {
        String readString = readString();
        try {
            emit(XmlObject.Factory.parse(readString).xmlText(prettyOptions));
        } catch (XmlException unused) {
            emit("!!!!!! BAD XML !!!!!");
            emit(readString);
        }
    }

    public void emit(String str) {
        PrintStream printStream = this._out;
        StringBuffer stringBuffer = new StringBuffer();
        stringBuffer.append(this._indent);
        stringBuffer.append(str);
        printStream.println(stringBuffer.toString());
        flush();
    }

    public void error(Exception exc) {
        this._out.println(exc.toString());
        flush();
        IllegalStateException illegalStateException = new IllegalStateException(exc.getMessage());
        illegalStateException.initCause(exc);
        throw illegalStateException;
    }

    public String facetCodeString(int i2) {
        switch (i2) {
            case 0:
                return "FACET_LENGTH";
            case 1:
                return "FACET_MIN_LENGTH";
            case 2:
                return "FACET_MAX_LENGTH";
            case 3:
                return "FACET_MIN_EXCLUSIVE";
            case 4:
                return "FACET_MIN_INCLUSIVE";
            case 5:
                return "FACET_MAX_INCLUSIVE";
            case 6:
                return "FACET_MAX_EXCLUSIVE";
            case 7:
                return "FACET_TOTAL_DIGITS";
            case 8:
                return "FACET_FRACTION_DIGITS";
            default:
                StringBuffer stringBuffer = new StringBuffer();
                stringBuffer.append("Unknown facet code (");
                stringBuffer.append(i2);
                stringBuffer.append(")");
                return stringBuffer.toString();
        }
    }

    public void flush() {
        this._out.flush();
    }

    public void indent() {
        this._indent = a.a(new StringBuffer(), this._indent, JamPrinter.INDENT);
    }

    public void outdent() {
        String str = this._indent;
        this._indent = str.substring(0, str.length() - 2);
    }

    public BigInteger readBigInteger() {
        byte[] readByteArray = readByteArray();
        if (readByteArray.length == 0) {
            return null;
        }
        if (readByteArray.length == 1 && readByteArray[0] == 0) {
            return BigInteger.ZERO;
        }
        if (readByteArray.length == 1 && readByteArray[0] == 1) {
            return BigInteger.ONE;
        }
        return new BigInteger(readByteArray);
    }

    public byte[] readByteArray() {
        try {
            byte[] bArr = new byte[this._input.readShort()];
            this._input.readFully(bArr);
            return bArr;
        } catch (IOException e2) {
            error(e2);
            return null;
        }
    }

    public double readDouble() {
        try {
            return this._input.readDouble();
        } catch (IOException e2) {
            error(e2);
            return NumericFunction.LOG_10_TO_BASE_e;
        }
    }

    public void readEnd() {
        try {
            this._input.close();
        } catch (IOException unused) {
        }
        this._input = null;
        this._stringPool = null;
    }

    public String readHandle() {
        return readString();
    }

    public int readInt() {
        try {
            return this._input.readInt();
        } catch (IOException e2) {
            error(e2);
            return 0;
        }
    }

    public QName readQName() {
        String readString = readString();
        String readString2 = readString();
        if (readString2 == null) {
            return null;
        }
        return new QName(readString, readString2);
    }

    public QNameSet readQNameSet() {
        int readShort = readShort();
        HashSet hashSet = new HashSet();
        int readShort2 = readShort();
        for (int i2 = 0; i2 < readShort2; i2++) {
            hashSet.add(readString());
        }
        HashSet hashSet2 = new HashSet();
        int readShort3 = readShort();
        for (int i3 = 0; i3 < readShort3; i3++) {
            hashSet2.add(readQName());
        }
        HashSet hashSet3 = new HashSet();
        int readShort4 = readShort();
        for (int i4 = 0; i4 < readShort4; i4++) {
            hashSet3.add(readQName());
        }
        if (readShort == 1) {
            return QNameSet.forSets(hashSet, null, hashSet2, hashSet3);
        }
        return QNameSet.forSets(null, hashSet, hashSet3, hashSet2);
    }

    public SOAPArrayType readSOAPArrayType() {
        QName readQName = readQName();
        String readString = readString();
        if (readQName == null) {
            return null;
        }
        return new SOAPArrayType(readQName, readString);
    }

    public int readShort() {
        try {
            return this._input.readUnsignedShort();
        } catch (IOException e2) {
            error(e2);
            return 0;
        }
    }

    public String readString() {
        return this._stringPool.stringForCode(readShort());
    }

    public String readType() {
        return readHandle();
    }

    public String readXmlValueObject() {
        String str;
        String readType = readType();
        if (readType == null) {
            return "null";
        }
        int readShort = readShort();
        if (readShort != 0) {
            switch (readShort) {
                case 2:
                case 3:
                case 6:
                case 11:
                case 12:
                case 13:
                case 14:
                case 15:
                case 16:
                case 17:
                case 18:
                case 19:
                case 20:
                case 21:
                    str = readString();
                    break;
                case 4:
                case 5:
                    str = new String(HexBin.encode(readByteArray()));
                    if (str.length() > 19) {
                        StringBuffer stringBuffer = new StringBuffer();
                        stringBuffer.append((Object) str.subSequence(0, 16));
                        stringBuffer.append(FunctionMetadataReader.ELLIPSIS);
                        str = stringBuffer.toString();
                        break;
                    }
                    break;
                case 7:
                case 8:
                    str = QNameHelper.pretty(readQName());
                    break;
                case 9:
                case 10:
                    str = Double.toString(readDouble());
                    break;
                default:
                    if (!$assertionsDisabled) {
                        throw new AssertionError();
                    }
                    break;
            }
            StringBuffer stringBuffer2 = new StringBuffer();
            stringBuffer2.append(str);
            stringBuffer2.append(" (");
            stringBuffer2.append(readType);
            stringBuffer2.append(": ");
            stringBuffer2.append(readShort);
            stringBuffer2.append(")");
            return stringBuffer2.toString();
        }
        str = "nil";
        StringBuffer stringBuffer22 = new StringBuffer();
        stringBuffer22.append(str);
        stringBuffer22.append(" (");
        stringBuffer22.append(readType);
        stringBuffer22.append(": ");
        stringBuffer22.append(readShort);
        stringBuffer22.append(")");
        return stringBuffer22.toString();
    }

    public String whitespaceCodeString(int i2) {
        if (i2 == 0) {
            return "WS_UNSPECIFIED";
        }
        if (i2 == 1) {
            return "WS_PRESERVE";
        }
        if (i2 == 2) {
            return "WS_REPLACE";
        }
        if (i2 == 3) {
            return "WS_COLLAPSE";
        }
        StringBuffer stringBuffer = new StringBuffer();
        stringBuffer.append("Unknown whitespace code (");
        stringBuffer.append(i2);
        stringBuffer.append(")");
        return stringBuffer.toString();
    }

    public void emit() {
        this._out.println();
        flush();
    }

    public void error(String str) {
        this._out.println(str);
        flush();
        throw new IllegalStateException(str);
    }

    public static void dump(InputStream inputStream) {
        dump(inputStream, "", System.out);
    }

    public static void dump(InputStream inputStream, String str) {
        dump(inputStream, str, System.out);
    }

    public static void dump(InputStream inputStream, String str, PrintStream printStream) {
        new XsbDumper(inputStream, str, printStream).dumpAll();
    }
}
