package org.apache.xmlbeans.impl.util;

import org.apache.poi.hssf.usermodel.HSSFShapeTypes;

public final class Base64 {
    public static final int BASELENGTH = 255;
    public static final int EIGHTBIT = 8;
    public static final int FOURBYTE = 4;
    public static final int LOOKUPLENGTH = 64;
    public static final byte PAD = 61;
    public static final int SIGN = -128;
    public static final int SIXTEENBIT = 16;
    public static final int TWENTYFOURBITGROUP = 24;
    public static byte[] base64Alphabet = new byte[255];
    public static final boolean fDebug = false;
    public static byte[] lookUpBase64Alphabet = new byte[64];

    static {
        int i2;
        int i3;
        int i4 = 0;
        for (int i5 = 0; i5 < 255; i5++) {
            base64Alphabet[i5] = -1;
        }
        for (int i6 = 90; i6 >= 65; i6--) {
            base64Alphabet[i6] = (byte) (i6 - 65);
        }
        int i7 = 122;
        while (true) {
            i2 = 26;
            if (i7 < 97) {
                break;
            }
            base64Alphabet[i7] = (byte) ((i7 - 97) + 26);
            i7--;
        }
        int i8 = 57;
        while (true) {
            i3 = 52;
            if (i8 < 48) {
                break;
            }
            base64Alphabet[i8] = (byte) ((i8 - 48) + 52);
            i8--;
        }
        byte[] bArr = base64Alphabet;
        bArr[43] = 62;
        bArr[47] = 63;
        for (int i9 = 0; i9 <= 25; i9++) {
            lookUpBase64Alphabet[i9] = (byte) (i9 + 65);
        }
        int i10 = 0;
        while (i2 <= 51) {
            lookUpBase64Alphabet[i2] = (byte) (i10 + 97);
            i2++;
            i10++;
        }
        while (i3 <= 61) {
            lookUpBase64Alphabet[i3] = (byte) (i4 + 48);
            i3++;
            i4++;
        }
        byte[] bArr2 = lookUpBase64Alphabet;
        bArr2[62] = 43;
        bArr2[63] = 47;
    }

    public static byte[] decode(byte[] bArr) {
        if (bArr == null) {
            return null;
        }
        byte[] removeWhiteSpace = removeWhiteSpace(bArr);
        if (removeWhiteSpace.length % 4 != 0) {
            return null;
        }
        int length = removeWhiteSpace.length / 4;
        if (length == 0) {
            return new byte[0];
        }
        byte[] bArr2 = new byte[(length * 3)];
        int i2 = 0;
        int i3 = 0;
        int i4 = 0;
        while (i2 < length - 1) {
            int i5 = i3 + 1;
            byte b2 = removeWhiteSpace[i3];
            if (isData(b2)) {
                int i6 = i5 + 1;
                byte b3 = removeWhiteSpace[i5];
                if (isData(b3)) {
                    int i7 = i6 + 1;
                    byte b4 = removeWhiteSpace[i6];
                    if (isData(b4)) {
                        int i8 = i7 + 1;
                        byte b5 = removeWhiteSpace[i7];
                        if (isData(b5)) {
                            byte[] bArr3 = base64Alphabet;
                            byte b6 = bArr3[b2];
                            byte b7 = bArr3[b3];
                            byte b8 = bArr3[b4];
                            byte b9 = bArr3[b5];
                            int i9 = i4 + 1;
                            bArr2[i4] = (byte) ((b6 << 2) | (b7 >> 4));
                            int i10 = i9 + 1;
                            bArr2[i9] = (byte) (((b7 & 15) << 4) | ((b8 >> 2) & 15));
                            i4 = i10 + 1;
                            bArr2[i10] = (byte) ((b8 << 6) | b9);
                            i2++;
                            i3 = i8;
                        }
                    }
                }
            }
            return null;
        }
        int i11 = i3 + 1;
        byte b10 = removeWhiteSpace[i3];
        if (!isData(b10)) {
            return null;
        }
        int i12 = i11 + 1;
        byte b11 = removeWhiteSpace[i11];
        if (!isData(b11)) {
            return null;
        }
        byte[] bArr4 = base64Alphabet;
        byte b12 = bArr4[b10];
        byte b13 = bArr4[b11];
        int i13 = i12 + 1;
        byte b14 = removeWhiteSpace[i12];
        byte b15 = removeWhiteSpace[i13];
        if (isData(b14) && isData(b15)) {
            byte[] bArr5 = base64Alphabet;
            byte b16 = bArr5[b14];
            byte b17 = bArr5[b15];
            int i14 = i4 + 1;
            bArr2[i4] = (byte) ((b12 << 2) | (b13 >> 4));
            bArr2[i14] = (byte) (((b13 & 15) << 4) | ((b16 >> 2) & 15));
            bArr2[i14 + 1] = (byte) (b17 | (b16 << 6));
            return bArr2;
        } else if (!isPad(b14) || !isPad(b15)) {
            if (isPad(b14) || !isPad(b15)) {
                return null;
            }
            byte b18 = base64Alphabet[b14];
            if ((b18 & 3) != 0) {
                return null;
            }
            int i15 = i2 * 3;
            byte[] bArr6 = new byte[(i15 + 2)];
            System.arraycopy(bArr2, 0, bArr6, 0, i15);
            bArr6[i4] = (byte) ((b12 << 2) | (b13 >> 4));
            bArr6[i4 + 1] = (byte) (((b18 >> 2) & 15) | ((b13 & 15) << 4));
            return bArr6;
        } else if ((b13 & 15) != 0) {
            return null;
        } else {
            int i16 = i2 * 3;
            byte[] bArr7 = new byte[(i16 + 1)];
            System.arraycopy(bArr2, 0, bArr7, 0, i16);
            bArr7[i4] = (byte) ((b12 << 2) | (b13 >> 4));
            return bArr7;
        }
    }

    public static byte[] encode(byte[] bArr) {
        byte[] bArr2;
        if (bArr == null) {
            return null;
        }
        int length = bArr.length * 8;
        int i2 = length % 24;
        int i3 = length / 24;
        if (i2 != 0) {
            bArr2 = new byte[((i3 + 1) * 4)];
        } else {
            bArr2 = new byte[(i3 * 4)];
        }
        int i4 = 0;
        while (i4 < i3) {
            int i5 = i4 * 3;
            byte b2 = bArr[i5];
            byte b3 = bArr[i5 + 1];
            byte b4 = bArr[i5 + 2];
            byte b5 = (byte) (b3 & 15);
            byte b6 = (byte) (b2 & 3);
            int i6 = i4 * 4;
            int i7 = b2 & Byte.MIN_VALUE;
            int i8 = b2 >> 2;
            if (i7 != 0) {
                i8 ^= HSSFShapeTypes.ActionButtonInformation;
            }
            byte b7 = (byte) i8;
            int i9 = b3 & Byte.MIN_VALUE;
            int i10 = b3 >> 4;
            if (i9 != 0) {
                i10 ^= 240;
            }
            byte b8 = (byte) i10;
            int i11 = (b4 & Byte.MIN_VALUE) == 0 ? b4 >> 6 : (b4 >> 6) ^ 252;
            byte[] bArr3 = lookUpBase64Alphabet;
            bArr2[i6] = bArr3[b7];
            bArr2[i6 + 1] = bArr3[b8 | (b6 << 4)];
            bArr2[i6 + 2] = bArr3[(b5 << 2) | ((byte) i11)];
            bArr2[i6 + 3] = bArr3[b4 & 63];
            i4++;
        }
        int i12 = i4 * 3;
        int i13 = i4 * 4;
        if (i2 == 8) {
            byte b9 = bArr[i12];
            byte b10 = (byte) (b9 & 3);
            int i14 = b9 & Byte.MIN_VALUE;
            int i15 = b9 >> 2;
            if (i14 != 0) {
                i15 ^= HSSFShapeTypes.ActionButtonInformation;
            }
            byte[] bArr4 = lookUpBase64Alphabet;
            bArr2[i13] = bArr4[(byte) i15];
            bArr2[i13 + 1] = bArr4[b10 << 4];
            bArr2[i13 + 2] = 61;
            bArr2[i13 + 3] = 61;
        } else if (i2 == 16) {
            byte b11 = bArr[i12];
            byte b12 = bArr[i12 + 1];
            byte b13 = (byte) (b12 & 15);
            byte b14 = (byte) (b11 & 3);
            int i16 = b11 & Byte.MIN_VALUE;
            int i17 = b11 >> 2;
            if (i16 != 0) {
                i17 ^= HSSFShapeTypes.ActionButtonInformation;
            }
            byte b15 = (byte) i17;
            int i18 = b12 & Byte.MIN_VALUE;
            int i19 = b12 >> 4;
            if (i18 != 0) {
                i19 ^= 240;
            }
            byte[] bArr5 = lookUpBase64Alphabet;
            bArr2[i13] = bArr5[b15];
            bArr2[i13 + 1] = bArr5[((byte) i19) | (b14 << 4)];
            bArr2[i13 + 2] = bArr5[b13 << 2];
            bArr2[i13 + 3] = 61;
        }
        return bArr2;
    }

    public static boolean isBase64(byte b2) {
        return isWhiteSpace(b2) || isPad(b2) || isData(b2);
    }

    public static boolean isData(byte b2) {
        return base64Alphabet[b2] != -1;
    }

    public static boolean isPad(byte b2) {
        return b2 == 61;
    }

    public static boolean isWhiteSpace(byte b2) {
        return b2 == 32 || b2 == 13 || b2 == 10 || b2 == 9;
    }

    public static byte[] removeWhiteSpace(byte[] bArr) {
        if (bArr == null) {
            return null;
        }
        int length = bArr.length;
        int i2 = 0;
        for (byte b2 : bArr) {
            if (!isWhiteSpace(b2)) {
                i2++;
            }
        }
        if (i2 == length) {
            return bArr;
        }
        byte[] bArr2 = new byte[i2];
        int i3 = 0;
        for (int i4 = 0; i4 < length; i4++) {
            if (!isWhiteSpace(bArr[i4])) {
                bArr2[i3] = bArr[i4];
                i3++;
            }
        }
        return bArr2;
    }
}
