package org.apache.xmlbeans.impl.util;

import b.b.a.a.a;
import java.math.BigDecimal;
import java.math.BigInteger;
import java.net.URI;
import java.util.Calendar;
import java.util.Collection;
import java.util.Date;
import org.apache.poi.javax.xml.namespace.NamespaceContext;
import org.apache.poi.javax.xml.namespace.QName;
import org.apache.poi.ss.formula.functions.NumericFunction;
import org.apache.poi.ss.util.SheetUtil;
import org.apache.xerces.impl.xs.SchemaSymbols;
import org.apache.xmlbeans.GDate;
import org.apache.xmlbeans.GDateBuilder;
import org.apache.xmlbeans.GDateSpecification;
import org.apache.xmlbeans.XmlCalendar;
import org.apache.xmlbeans.XmlError;
import org.apache.xmlbeans.impl.common.InvalidLexicalValueException;
import org.apache.xmlbeans.impl.common.NameUtil;

public final class XsTypeConverter {
    public static final /* synthetic */ boolean $assertionsDisabled;
    public static final char[] CH_ZEROS = {SheetUtil.defaultChar, SheetUtil.defaultChar, SheetUtil.defaultChar, SheetUtil.defaultChar, SheetUtil.defaultChar, SheetUtil.defaultChar, SheetUtil.defaultChar, SheetUtil.defaultChar, SheetUtil.defaultChar, SheetUtil.defaultChar, SheetUtil.defaultChar, SheetUtil.defaultChar, SheetUtil.defaultChar, SheetUtil.defaultChar, SheetUtil.defaultChar, SheetUtil.defaultChar, SheetUtil.defaultChar, SheetUtil.defaultChar, SheetUtil.defaultChar};
    public static final BigDecimal DECIMAL__ZERO = new BigDecimal((double) NumericFunction.LOG_10_TO_BASE_e);
    public static final String EMPTY_PREFIX = "";
    public static final char NAMESPACE_SEP = ':';
    public static final String NAN_LEX = "NaN";
    public static final String NEG_INF_LEX = "-INF";
    public static final String POS_INF_LEX = "INF";
    public static final String[] URI_CHARS_REPLACED_WITH = {"%20", "%7b", "%7d", "%7c", "%5c", "%5e", "%5b", "%5d", "%60"};
    public static final String[] URI_CHARS_TO_BE_REPLACED = {" ", "{", "}", "|", "\\", "^", "[", "]", "`"};
    public static /* synthetic */ Class class$org$apache$xmlbeans$impl$util$XsTypeConverter;

    static {
        Class cls = class$org$apache$xmlbeans$impl$util$XsTypeConverter;
        if (cls == null) {
            cls = class$("org.apache.xmlbeans.impl.util.XsTypeConverter");
            class$org$apache$xmlbeans$impl$util$XsTypeConverter = cls;
        }
        $assertionsDisabled = !cls.desiredAssertionStatus();
    }

    public static /* synthetic */ Class class$(String str) {
        try {
            return Class.forName(str);
        } catch (ClassNotFoundException e2) {
            throw a.a(e2);
        }
    }

    public static GDateSpecification getGDateValue(Date date, int i2) {
        GDateBuilder gDateBuilder = new GDateBuilder(date);
        gDateBuilder.setBuiltinTypeCode(i2);
        return gDateBuilder.toGDate();
    }

    public static String getQNameString(String str, String str2, String str3) {
        if (str3 == null || str == null || str.length() <= 0 || str3.length() <= 0) {
            return str2;
        }
        StringBuffer stringBuffer = new StringBuffer();
        stringBuffer.append(str3);
        stringBuffer.append(':');
        stringBuffer.append(str2);
        return stringBuffer.toString();
    }

    public static CharSequence lexAnyURI(CharSequence charSequence) {
        StringBuffer stringBuffer = new StringBuffer(charSequence.toString());
        for (int i2 = 0; i2 < URI_CHARS_TO_BE_REPLACED.length; i2++) {
            int i3 = 0;
            while (true) {
                int indexOf = stringBuffer.indexOf(URI_CHARS_TO_BE_REPLACED[i2], i3);
                if (indexOf < 0) {
                    break;
                }
                stringBuffer.replace(indexOf, indexOf + 1, URI_CHARS_REPLACED_WITH[i2]);
                i3 = indexOf + 3;
            }
        }
        try {
            URI.create(stringBuffer.toString());
            return charSequence;
        } catch (IllegalArgumentException e2) {
            StringBuffer stringBuffer2 = new StringBuffer();
            stringBuffer2.append("invalid anyURI value: ");
            stringBuffer2.append((Object) charSequence);
            throw new InvalidLexicalValueException(stringBuffer2.toString(), e2);
        }
    }

    public static byte[] lexBase64Binary(CharSequence charSequence) {
        byte[] decode = Base64.decode(charSequence.toString().getBytes());
        if (decode != null) {
            return decode;
        }
        throw new InvalidLexicalValueException("invalid base64Binary value");
    }

    public static boolean lexBoolean(CharSequence charSequence) {
        int length = charSequence.length();
        if (length == 1) {
            char charAt = charSequence.charAt(0);
            if ('0' == charAt) {
                return false;
            }
            if ('1' == charAt) {
                return true;
            }
        } else if (length != 4) {
            if (length == 5 && 'f' == charSequence.charAt(0) && 'a' == charSequence.charAt(1) && 'l' == charSequence.charAt(2) && 's' == charSequence.charAt(3) && 'e' == charSequence.charAt(4)) {
                return false;
            }
        } else if ('t' == charSequence.charAt(0) && 'r' == charSequence.charAt(1) && 'u' == charSequence.charAt(2) && 'e' == charSequence.charAt(3)) {
            return true;
        }
        StringBuffer stringBuffer = new StringBuffer();
        stringBuffer.append("invalid boolean: ");
        stringBuffer.append((Object) charSequence);
        throw new InvalidLexicalValueException(stringBuffer.toString());
    }

    public static byte lexByte(CharSequence charSequence) {
        return parseByte(charSequence);
    }

    public static XmlCalendar lexDateTime(CharSequence charSequence) {
        return getGDateValue(charSequence, 14).getCalendar();
    }

    public static BigDecimal lexDecimal(CharSequence charSequence) {
        return new BigDecimal(trimTrailingZeros(charSequence.toString()));
    }

    public static double lexDouble(CharSequence charSequence) {
        String obj = charSequence.toString();
        try {
            if (charSequence.length() > 0) {
                char charAt = charSequence.charAt(charSequence.length() - 1);
                if (charAt == 'd' || charAt == 'D') {
                    StringBuffer stringBuffer = new StringBuffer();
                    stringBuffer.append("Invalid char '");
                    stringBuffer.append(charAt);
                    stringBuffer.append("' in double.");
                    throw new NumberFormatException(stringBuffer.toString());
                }
            }
            return Double.parseDouble(obj);
        } catch (NumberFormatException e2) {
            if (obj.equals(POS_INF_LEX)) {
                return Double.POSITIVE_INFINITY;
            }
            if (obj.equals(NEG_INF_LEX)) {
                return Double.NEGATIVE_INFINITY;
            }
            if (obj.equals(NAN_LEX)) {
                return Double.NaN;
            }
            throw e2;
        }
    }

    public static float lexFloat(CharSequence charSequence) {
        char charAt;
        String obj = charSequence.toString();
        try {
            if (charSequence.length() > 0 && ((charAt = charSequence.charAt(charSequence.length() - 1)) == 'f' || charAt == 'F')) {
                if (charSequence.charAt(charSequence.length() - 2) != 'N') {
                    StringBuffer stringBuffer = new StringBuffer();
                    stringBuffer.append("Invalid char '");
                    stringBuffer.append(charAt);
                    stringBuffer.append("' in float.");
                    throw new NumberFormatException(stringBuffer.toString());
                }
            }
            return Float.parseFloat(obj);
        } catch (NumberFormatException e2) {
            if (obj.equals(POS_INF_LEX)) {
                return Float.POSITIVE_INFINITY;
            }
            if (obj.equals(NEG_INF_LEX)) {
                return Float.NEGATIVE_INFINITY;
            }
            if (obj.equals(NAN_LEX)) {
                return Float.NaN;
            }
            throw e2;
        }
    }

    public static GDate lexGDate(CharSequence charSequence) {
        return new GDate(charSequence);
    }

    public static byte[] lexHexBinary(CharSequence charSequence) {
        byte[] decode = HexBin.decode(charSequence.toString().getBytes());
        if (decode != null) {
            return decode;
        }
        throw new InvalidLexicalValueException("invalid hexBinary value");
    }

    public static int lexInt(CharSequence charSequence) {
        return parseInt(charSequence);
    }

    public static BigInteger lexInteger(CharSequence charSequence) {
        if (charSequence.length() <= 1 || charSequence.charAt(0) != '+' || charSequence.charAt(1) != '-') {
            return new BigInteger(trimInitialPlus(charSequence.toString()));
        }
        throw new NumberFormatException("Illegal char sequence '+-'");
    }

    public static long lexLong(CharSequence charSequence) {
        return Long.parseLong(trimInitialPlus(charSequence.toString()));
    }

    public static QName lexQName(CharSequence charSequence, NamespaceContext namespaceContext) {
        boolean z;
        String str;
        String str2;
        int i2 = 0;
        while (true) {
            if (i2 >= charSequence.length()) {
                z = false;
                break;
            } else if (charSequence.charAt(i2) == ':') {
                z = true;
                break;
            } else {
                i2++;
            }
        }
        String str3 = "";
        if (z) {
            str2 = charSequence.subSequence(0, i2).toString();
            str = charSequence.subSequence(i2 + 1, charSequence.length()).toString();
            if (i2 == 0) {
                StringBuffer a = a.a("invalid xsd:QName '");
                a.append(charSequence.toString());
                a.append("'");
                throw new InvalidLexicalValueException(a.toString());
            }
        } else {
            str = charSequence.toString();
            str2 = str3;
        }
        String namespaceURI = namespaceContext.getNamespaceURI(str2);
        if (namespaceURI != null) {
            str3 = namespaceURI;
        } else if (str2 != null && str2.length() > 0) {
            throw new InvalidLexicalValueException(a.a("Can't resolve prefix: ", str2));
        }
        return new QName(str3, str);
    }

    public static short lexShort(CharSequence charSequence) {
        return parseShort(charSequence);
    }

    public static String lexString(CharSequence charSequence, Collection collection) {
        return charSequence.toString();
    }

    public static byte parseByte(CharSequence charSequence) {
        return (byte) parseIntXsdNumber(charSequence, -128, 127);
    }

    public static int parseInt(CharSequence charSequence) {
        return parseIntXsdNumber(charSequence, Integer.MIN_VALUE, Integer.MAX_VALUE);
    }

    public static int parseIntXsdNumber(CharSequence charSequence, int i2, int i3) {
        int i4;
        int i5;
        int i6;
        int i7;
        int i8;
        int length = charSequence.length();
        int i9 = 1;
        if (length >= 1) {
            char charAt = charSequence.charAt(0);
            if (charAt == '-') {
                i4 = i2 / 10;
                i5 = -(i2 % 10);
                i6 = 1;
            } else {
                if (charAt == '+') {
                    i8 = -(i3 / 10);
                    i7 = i3 % 10;
                    i9 = -1;
                    i6 = 1;
                } else {
                    i8 = -(i3 / 10);
                    i7 = i3 % 10;
                    i9 = -1;
                    i6 = 0;
                }
                i4 = i8;
                i5 = i7;
            }
            int i10 = 0;
            for (int i11 = 0; i11 < length - i6; i11++) {
                int digit = Character.digit(charSequence.charAt(i11 + i6), 10);
                if (digit < 0) {
                    StringBuffer a = a.a("For input string: \"");
                    a.append(charSequence.toString());
                    a.append("\"");
                    throw new NumberFormatException(a.toString());
                } else if (i10 < i4 || (i10 == i4 && digit > i5)) {
                    StringBuffer a2 = a.a("For input string: \"");
                    a2.append(charSequence.toString());
                    a2.append("\"");
                    throw new NumberFormatException(a2.toString());
                } else {
                    i10 = (i10 * 10) - digit;
                }
            }
            return i9 * i10;
        }
        StringBuffer a3 = a.a("For input string: \"");
        a3.append(charSequence.toString());
        a3.append("\"");
        throw new NumberFormatException(a3.toString());
    }

    public static short parseShort(CharSequence charSequence) {
        return (short) parseIntXsdNumber(charSequence, -32768, 32767);
    }

    public static CharSequence printAnyURI(CharSequence charSequence) {
        return charSequence;
    }

    public static CharSequence printBase64Binary(byte[] bArr) {
        return new String(Base64.encode(bArr));
    }

    public static String printBoolean(boolean z) {
        return z ? SchemaSymbols.ATTVAL_TRUE : SchemaSymbols.ATTVAL_FALSE;
    }

    public static String printByte(byte b2) {
        return Byte.toString(b2);
    }

    public static String printDate(Calendar calendar) {
        return printDateTime(calendar, 16);
    }

    public static String printDateTime(Calendar calendar) {
        return printDateTime(calendar, 14);
    }

    public static String printDecimal(BigDecimal bigDecimal) {
        char[] cArr;
        char[] cArr2;
        String bigInteger = bigDecimal.unscaledValue().toString();
        int scale = bigDecimal.scale();
        if (scale == 0 || (bigDecimal.longValue() == 0 && scale < 0)) {
            return bigInteger;
        }
        int i2 = bigDecimal.signum() < 0 ? 1 : 0;
        StringBuffer stringBuffer = new StringBuffer(Math.abs(scale) + bigInteger.length() + 1);
        if (i2 == 1) {
            stringBuffer.append(NameUtil.HYPHEN);
        }
        if (scale > 0) {
            int length = scale - (bigInteger.length() - i2);
            if (length >= 0) {
                stringBuffer.append("0.");
                while (true) {
                    cArr2 = CH_ZEROS;
                    if (length <= cArr2.length) {
                        break;
                    }
                    stringBuffer.append(cArr2);
                    length -= CH_ZEROS.length;
                }
                stringBuffer.append(cArr2, 0, length);
                stringBuffer.append(bigInteger.substring(i2));
            } else {
                int i3 = i2 - length;
                stringBuffer.append(bigInteger.substring(i2, i3));
                stringBuffer.append(NameUtil.PERIOD);
                stringBuffer.append(bigInteger.substring(i3));
            }
        } else {
            stringBuffer.append(bigInteger.substring(i2));
            while (true) {
                cArr = CH_ZEROS;
                if (scale >= (-cArr.length)) {
                    break;
                }
                stringBuffer.append(cArr);
                scale += CH_ZEROS.length;
            }
            stringBuffer.append(cArr, 0, -scale);
        }
        return stringBuffer.toString();
    }

    public static String printDouble(double d2) {
        if (d2 == Double.POSITIVE_INFINITY) {
            return POS_INF_LEX;
        }
        if (d2 == Double.NEGATIVE_INFINITY) {
            return NEG_INF_LEX;
        }
        if (Double.isNaN(d2)) {
            return NAN_LEX;
        }
        return Double.toString(d2);
    }

    public static String printFloat(float f2) {
        if (f2 == Float.POSITIVE_INFINITY) {
            return POS_INF_LEX;
        }
        if (f2 == Float.NEGATIVE_INFINITY) {
            return NEG_INF_LEX;
        }
        if (Float.isNaN(f2)) {
            return NAN_LEX;
        }
        return Float.toString(f2);
    }

    public static String printGDate(GDate gDate, Collection collection) {
        return gDate.toString();
    }

    public static CharSequence printHexBinary(byte[] bArr) {
        return HexBin.bytesToString(bArr);
    }

    public static String printInt(int i2) {
        return Integer.toString(i2);
    }

    public static String printInteger(BigInteger bigInteger) {
        return bigInteger.toString();
    }

    public static String printLong(long j) {
        return Long.toString(j);
    }

    public static String printQName(QName qName, NamespaceContext namespaceContext, Collection collection) {
        String str;
        String namespaceURI = qName.getNamespaceURI();
        if ($assertionsDisabled || namespaceURI != null) {
            if (namespaceURI.length() > 0) {
                str = namespaceContext.getPrefix(namespaceURI);
                if (str == null) {
                    StringBuffer stringBuffer = new StringBuffer();
                    stringBuffer.append("NamespaceContext does not provide prefix for namespaceURI ");
                    stringBuffer.append(namespaceURI);
                    collection.add(XmlError.forMessage(stringBuffer.toString()));
                }
            } else {
                str = null;
            }
            return getQNameString(namespaceURI, qName.getLocalPart(), str);
        }
        throw new AssertionError();
    }

    public static String printShort(short s) {
        return Short.toString(s);
    }

    public static String printString(String str) {
        return str;
    }

    public static String printTime(Calendar calendar) {
        return printDateTime(calendar, 15);
    }

    public static String trimInitialPlus(String str) {
        return (str.length() <= 0 || str.charAt(0) != '+') ? str : str.substring(1);
    }

    public static String trimTrailingZeros(String str) {
        int lastIndexOf;
        int length = str.length() - 1;
        if (str.charAt(length) != '0' || (lastIndexOf = str.lastIndexOf(46)) < 0) {
            return str;
        }
        while (length > lastIndexOf) {
            if (str.charAt(length) != '0') {
                return str.substring(0, length + 1);
            }
            length--;
        }
        return str.substring(0, lastIndexOf);
    }

    public static byte lexByte(CharSequence charSequence, Collection collection) {
        try {
            return lexByte(charSequence);
        } catch (NumberFormatException unused) {
            StringBuffer stringBuffer = new StringBuffer();
            stringBuffer.append("invalid byte: ");
            stringBuffer.append((Object) charSequence);
            collection.add(XmlError.forMessage(stringBuffer.toString()));
            return 0;
        }
    }

    public static GDate lexGDate(String str, Collection collection) {
        try {
            return lexGDate(str);
        } catch (IllegalArgumentException e2) {
            collection.add(XmlError.forMessage(e2.getMessage()));
            return new GDateBuilder().toGDate();
        }
    }

    public static int lexInt(CharSequence charSequence, Collection collection) {
        try {
            return lexInt(charSequence);
        } catch (NumberFormatException unused) {
            StringBuffer stringBuffer = new StringBuffer();
            stringBuffer.append("invalid int:");
            stringBuffer.append((Object) charSequence);
            collection.add(XmlError.forMessage(stringBuffer.toString()));
            return 0;
        }
    }

    public static short lexShort(CharSequence charSequence, Collection collection) {
        try {
            return lexShort(charSequence);
        } catch (NumberFormatException unused) {
            StringBuffer stringBuffer = new StringBuffer();
            stringBuffer.append("invalid short: ");
            stringBuffer.append((Object) charSequence);
            collection.add(XmlError.forMessage(stringBuffer.toString()));
            return 0;
        }
    }

    public static String lexString(CharSequence charSequence) {
        return charSequence.toString();
    }

    public static String printDate(Date date) {
        return getGDateValue(date, 16).toString();
    }

    public static String printDateTime(Calendar calendar, int i2) {
        return getGDateValue(calendar, i2).toString();
    }

    public static BigDecimal lexDecimal(CharSequence charSequence, Collection collection) {
        try {
            return lexDecimal(charSequence);
        } catch (NumberFormatException unused) {
            StringBuffer stringBuffer = new StringBuffer();
            stringBuffer.append("invalid long: ");
            stringBuffer.append((Object) charSequence);
            collection.add(XmlError.forMessage(stringBuffer.toString()));
            return DECIMAL__ZERO;
        }
    }

    public static long lexLong(CharSequence charSequence, Collection collection) {
        try {
            return lexLong(charSequence);
        } catch (NumberFormatException unused) {
            StringBuffer stringBuffer = new StringBuffer();
            stringBuffer.append("invalid long: ");
            stringBuffer.append((Object) charSequence);
            collection.add(XmlError.forMessage(stringBuffer.toString()));
            return 0;
        }
    }

    public static GDateSpecification getGDateValue(Calendar calendar, int i2) {
        GDateBuilder gDateBuilder = new GDateBuilder(calendar);
        gDateBuilder.setBuiltinTypeCode(i2);
        return gDateBuilder.toGDate();
    }

    public static String printDateTime(Date date) {
        return getGDateValue(date, 14).toString();
    }

    public static BigInteger lexInteger(CharSequence charSequence, Collection collection) {
        try {
            return lexInteger(charSequence);
        } catch (NumberFormatException unused) {
            StringBuffer stringBuffer = new StringBuffer();
            stringBuffer.append("invalid long: ");
            stringBuffer.append((Object) charSequence);
            collection.add(XmlError.forMessage(stringBuffer.toString()));
            return BigInteger.ZERO;
        }
    }

    public static GDateSpecification getGDateValue(CharSequence charSequence, int i2) {
        GDateBuilder gDateBuilder = new GDateBuilder(charSequence);
        gDateBuilder.setBuiltinTypeCode(i2);
        return gDateBuilder.toGDate();
    }

    public static boolean lexBoolean(CharSequence charSequence, Collection collection) {
        try {
            return lexBoolean(charSequence);
        } catch (InvalidLexicalValueException e2) {
            collection.add(XmlError.forMessage(e2.getMessage()));
            return false;
        }
    }

    public static double lexDouble(CharSequence charSequence, Collection collection) {
        try {
            return lexDouble(charSequence);
        } catch (NumberFormatException unused) {
            StringBuffer stringBuffer = new StringBuffer();
            stringBuffer.append("invalid double: ");
            stringBuffer.append((Object) charSequence);
            collection.add(XmlError.forMessage(stringBuffer.toString()));
            return Double.NaN;
        }
    }

    public static float lexFloat(CharSequence charSequence, Collection collection) {
        try {
            return lexFloat(charSequence);
        } catch (NumberFormatException unused) {
            StringBuffer stringBuffer = new StringBuffer();
            stringBuffer.append("invalid float: ");
            stringBuffer.append((Object) charSequence);
            collection.add(XmlError.forMessage(stringBuffer.toString()));
            return Float.NaN;
        }
    }

    public static QName lexQName(String str, Collection collection, NamespaceContext namespaceContext) {
        try {
            return lexQName(str, namespaceContext);
        } catch (InvalidLexicalValueException e2) {
            collection.add(XmlError.forMessage(e2.getMessage()));
            return new QName(null, str.substring(str.indexOf(58)));
        }
    }
}
