package org.apache.xmlbeans.impl.validator;

import b.b.a.a.a;
import java.util.ArrayList;
import java.util.Collection;
import java.util.List;
import org.apache.poi.javax.xml.namespace.QName;
import org.apache.poi.javax.xml.stream.Location;
import org.apache.poi.javax.xml.stream.XMLStreamReader;
import org.apache.poi.javax.xml.stream.util.StreamReaderDelegate;
import org.apache.xmlbeans.SchemaType;
import org.apache.xmlbeans.SchemaTypeLoader;
import org.apache.xmlbeans.XmlCursor;
import org.apache.xmlbeans.XmlError;
import org.apache.xmlbeans.XmlOptions;
import org.apache.xmlbeans.impl.common.QNameHelper;
import org.apache.xmlbeans.impl.common.ValidatorListener;
import org.apache.xmlbeans.impl.common.XmlWhitespace;
import org.apache.xmlbeans.impl.jam.xml.JamXmlElements;

public class ValidatingXMLStreamReader extends StreamReaderDelegate implements XMLStreamReader {
    public static final /* synthetic */ boolean $assertionsDisabled;
    public static final String OPTION_ATTTRIBUTE_VALIDATION_COMPAT_MODE = "OPTION_ATTTRIBUTE_VALIDATION_COMPAT_MODE";
    public static final String URI_XSI = "http://www.w3.org/2001/XMLSchema-instance";
    public static final QName XSI_NIL = new QName("http://www.w3.org/2001/XMLSchema-instance", "nil");
    public static final QName XSI_NSL = new QName("http://www.w3.org/2001/XMLSchema-instance", "noNamespaceSchemaLocation");
    public static final QName XSI_SL = new QName("http://www.w3.org/2001/XMLSchema-instance", "schemaLocation");
    public static final QName XSI_TYPE = new QName("http://www.w3.org/2001/XMLSchema-instance", JamXmlElements.TYPE);
    public static /* synthetic */ Class class$org$apache$xmlbeans$impl$validator$ValidatingXMLStreamReader;
    public final int STATE_ATTBUFFERING = 2;
    public final int STATE_ERROR = 3;
    public final int STATE_FIRSTEVENT = 0;
    public final int STATE_VALIDATING = 1;
    public final AttributeEventImpl _attEvent = new AttributeEventImpl();
    public List _attNamesList;
    public List _attValuesList;
    public SchemaType _contentType;
    public int _depth;
    public final ElementEventImpl _elemEvent = new ElementEventImpl();
    public Collection _errorListener;
    public XmlOptions _options;
    public PackTextXmlStreamReader _packTextXmlStreamReader = new PackTextXmlStreamReader();
    public final SimpleEventImpl _simpleEvent = new SimpleEventImpl();
    public int _state;
    public SchemaTypeLoader _stl;
    public Validator _validator;
    public SchemaType _xsiType;

    public static final class SimpleEventImpl implements ValidatorListener.Event {
        public QName _qname;
        public String _text;
        public XMLStreamReader _xmlStream;

        public SimpleEventImpl() {
        }

        /* access modifiers changed from: private */
        /* access modifiers changed from: public */
        private void setXMLStreamReader(XMLStreamReader xMLStreamReader) {
            this._xmlStream = xMLStreamReader;
        }

        @Override // org.apache.xmlbeans.impl.common.ValidatorListener.Event
        public Location getLocation() {
            return this._xmlStream.getLocation();
        }

        @Override // org.apache.xmlbeans.impl.common.ValidatorListener.Event
        public XmlCursor getLocationAsCursor() {
            return null;
        }

        @Override // org.apache.xmlbeans.impl.common.ValidatorListener.Event
        public QName getName() {
            return this._qname;
        }

        @Override // org.apache.xmlbeans.impl.common.PrefixResolver
        public String getNamespaceForPrefix(String str) {
            return this._xmlStream.getNamespaceURI(str);
        }

        @Override // org.apache.xmlbeans.impl.common.ValidatorListener.Event
        public String getText() {
            return this._text;
        }

        @Override // org.apache.xmlbeans.impl.common.ValidatorListener.Event
        public String getXsiLoc() {
            return null;
        }

        @Override // org.apache.xmlbeans.impl.common.ValidatorListener.Event
        public String getXsiNil() {
            return null;
        }

        @Override // org.apache.xmlbeans.impl.common.ValidatorListener.Event
        public String getXsiNoLoc() {
            return null;
        }

        @Override // org.apache.xmlbeans.impl.common.ValidatorListener.Event
        public String getXsiType() {
            return null;
        }

        @Override // org.apache.xmlbeans.impl.common.ValidatorListener.Event
        public boolean textIsWhitespace() {
            return false;
        }

        @Override // org.apache.xmlbeans.impl.common.ValidatorListener.Event
        public String getText(int i2) {
            return XmlWhitespace.collapse(this._text, i2);
        }
    }

    static {
        Class cls = class$org$apache$xmlbeans$impl$validator$ValidatingXMLStreamReader;
        if (cls == null) {
            cls = class$("org.apache.xmlbeans.impl.validator.ValidatingXMLStreamReader");
            class$org$apache$xmlbeans$impl$validator$ValidatingXMLStreamReader = cls;
        }
        $assertionsDisabled = !cls.desiredAssertionStatus();
    }

    private void addError(String str) {
        Location location = getLocation();
        if (location != null) {
            String publicId = location.getPublicId();
            if (publicId == null) {
                publicId = location.getSystemId();
            }
            this._errorListener.add(XmlError.forLocation(str, publicId, location));
            return;
        }
        this._errorListener.add(XmlError.forMessage(str));
    }

    public static /* synthetic */ Class class$(String str) {
        try {
            return Class.forName(str);
        } catch (ClassNotFoundException e2) {
            throw a.a(e2);
        }
    }

    private void initValidator(SchemaType schemaType) {
        if ($assertionsDisabled || schemaType != null) {
            this._validator = new Validator(schemaType, null, this._stl, this._options, this._errorListener);
            return;
        }
        throw new AssertionError();
    }

    private boolean isSpecialAttribute(QName qName) {
        if (!qName.getNamespaceURI().equals("http://www.w3.org/2001/XMLSchema-instance")) {
            return false;
        }
        if (qName.getLocalPart().equals(XSI_TYPE.getLocalPart()) || qName.getLocalPart().equals(XSI_NIL.getLocalPart()) || qName.getLocalPart().equals(XSI_SL.getLocalPart()) || qName.getLocalPart().equals(XSI_NSL.getLocalPart())) {
            return true;
        }
        return false;
    }

    private void pushBufferedAttributes() {
        SchemaType schemaType = this._xsiType;
        if (schemaType != null) {
            SchemaType schemaType2 = this._contentType;
            if (schemaType2 != null) {
                if (schemaType2.isAssignableFrom(schemaType)) {
                    schemaType = this._xsiType;
                } else {
                    StringBuffer a = a.a("Specified type '");
                    a.append(this._contentType);
                    a.append("' not compatible with found xsi:type '");
                    a.append(this._xsiType);
                    a.append("'.");
                    addError(a.toString());
                    this._state = 3;
                    return;
                }
            }
        } else {
            schemaType = this._contentType;
            if (schemaType == null) {
                List list = this._attNamesList;
                if (list != null) {
                    schemaType = this._stl.findAttributeType((QName) list.get(0));
                    if (schemaType == null) {
                        StringBuffer a2 = a.a("A schema global attribute with name '");
                        a2.append(this._attNamesList.get(0));
                        a2.append("' could not be found in the current schema type loader.");
                        addError(a2.toString());
                        this._state = 3;
                        return;
                    }
                } else {
                    addError("No content type provided for validation of a content model.");
                    this._state = 3;
                    return;
                }
            }
        }
        initValidator(schemaType);
        this._validator.nextEvent(1, this._simpleEvent);
        validate_attributes(this._attNamesList.size());
        this._attNamesList = null;
        this._attValuesList = null;
        this._state = 1;
    }

    private SchemaType typeForGlobalElement(QName qName) {
        if ($assertionsDisabled || qName != null) {
            SchemaType findDocumentType = this._stl.findDocumentType(qName);
            if (findDocumentType == null) {
                StringBuffer stringBuffer = new StringBuffer();
                stringBuffer.append("Schema document type not found for element '");
                stringBuffer.append(qName);
                stringBuffer.append("'.");
                addError(stringBuffer.toString());
                this._state = 3;
            }
            return findDocumentType;
        }
        throw new AssertionError();
    }

    private void validate_event(int i2) {
        int i3 = this._state;
        if (i3 != 3) {
            int i4 = this._depth;
            if (i4 >= 0) {
                switch (i2) {
                    case 1:
                        this._depth = i4 + 1;
                        if (i3 == 2) {
                            pushBufferedAttributes();
                        }
                        if (this._validator == null) {
                            QName qName = new QName(getNamespaceURI(), getLocalName());
                            if (this._contentType == null) {
                                this._contentType = typeForGlobalElement(qName);
                            }
                            if (this._state != 3) {
                                initValidator(this._contentType);
                                this._validator.nextEvent(1, this._elemEvent);
                            } else {
                                return;
                            }
                        }
                        this._validator.nextEvent(1, this._elemEvent);
                        validate_attributes(getAttributeCount());
                        return;
                    case 2:
                    case 8:
                        this._depth = i4 - 1;
                        if (i3 == 2) {
                            pushBufferedAttributes();
                        }
                        this._validator.nextEvent(2, this._elemEvent);
                        return;
                    case 3:
                    case 5:
                    case 6:
                    case 9:
                    case 11:
                    case 13:
                    case 14:
                    case 15:
                        return;
                    case 4:
                    case 12:
                        if (i3 == 2) {
                            pushBufferedAttributes();
                        }
                        if (this._validator == null) {
                            SchemaType schemaType = this._contentType;
                            if (schemaType != null) {
                                initValidator(schemaType);
                                this._validator.nextEvent(1, this._simpleEvent);
                            } else if (!isWhiteSpace()) {
                                addError("No content type provided for validation of a content model.");
                                this._state = 3;
                                return;
                            } else {
                                return;
                            }
                        }
                        this._validator.nextEvent(3, this._elemEvent);
                        return;
                    case 7:
                        this._depth = i4 + 1;
                        return;
                    case 10:
                        if (getAttributeCount() != 0) {
                            int i5 = this._state;
                            if (i5 == 0 || i5 == 2) {
                                for (int i6 = 0; i6 < getAttributeCount(); i6++) {
                                    QName qName2 = new QName(getAttributeNamespace(i6), getAttributeLocalName(i6));
                                    if (qName2.equals(XSI_TYPE)) {
                                        String attributeValue = getAttributeValue(i6);
                                        this._xsiType = this._stl.findType(new QName(super.getNamespaceURI(QNameHelper.getPrefixPart(attributeValue)), QNameHelper.getLocalPart(attributeValue)));
                                    }
                                    if (this._attNamesList == null) {
                                        this._attNamesList = new ArrayList();
                                        this._attValuesList = new ArrayList();
                                    }
                                    if (!isSpecialAttribute(qName2)) {
                                        this._attNamesList.add(qName2);
                                        this._attValuesList.add(getAttributeValue(i6));
                                    }
                                }
                                this._state = 2;
                                return;
                            }
                            throw new IllegalStateException("ATT event must be only at the beggining of the stream.");
                        }
                        return;
                    default:
                        throw new IllegalStateException("Unknown event type.");
                }
            } else {
                throw new IllegalArgumentException("ValidatingXMLStreamReader cannot go further than the subtree is was initialized on.");
            }
        }
    }

    @Override // org.apache.poi.javax.xml.stream.XMLStreamReader, org.apache.poi.javax.xml.stream.util.StreamReaderDelegate
    public Object getProperty(String str) {
        return super.getProperty(str);
    }

    public void init(XMLStreamReader xMLStreamReader, boolean z, SchemaType schemaType, SchemaTypeLoader schemaTypeLoader, XmlOptions xmlOptions, Collection collection) {
        this._packTextXmlStreamReader.init(xMLStreamReader);
        setParent(this._packTextXmlStreamReader);
        this._contentType = schemaType;
        this._stl = schemaTypeLoader;
        this._options = xmlOptions;
        this._errorListener = collection;
        this._elemEvent.setXMLStreamReader(this._packTextXmlStreamReader);
        this._attEvent.setXMLStreamReader(this._packTextXmlStreamReader);
        this._simpleEvent.setXMLStreamReader(this._packTextXmlStreamReader);
        this._validator = null;
        this._state = 0;
        List list = this._attNamesList;
        if (list != null) {
            list.clear();
            this._attValuesList.clear();
        }
        this._xsiType = null;
        this._depth = 0;
        if (z) {
            validate_event(getEventType());
        }
    }

    public boolean isValid() {
        Validator validator;
        if (this._state == 3 || (validator = this._validator) == null) {
            return false;
        }
        return validator.isValid();
    }

    @Override // org.apache.poi.javax.xml.stream.XMLStreamReader, org.apache.poi.javax.xml.stream.util.StreamReaderDelegate
    public int next() {
        int next = super.next();
        validate_event(next);
        return next;
    }

    public void validate_attribute(int i2) {
        ValidatorListener.Event event;
        List list = this._attNamesList;
        if (list == null) {
            this._attEvent.setAttributeIndex(i2);
            if (!isSpecialAttribute(this._attEvent.getName())) {
                event = this._attEvent;
            } else {
                return;
            }
        } else {
            this._simpleEvent._qname = (QName) list.get(i2);
            this._simpleEvent._text = (String) this._attValuesList.get(i2);
            event = this._simpleEvent;
        }
        this._validator.nextEvent(4, event);
    }

    public void validate_attributes(int i2) {
        for (int i3 = 0; i3 < i2; i3++) {
            validate_attribute(i3);
        }
        XmlOptions xmlOptions = this._options;
        if (xmlOptions == null || !xmlOptions.hasOption(OPTION_ATTTRIBUTE_VALIDATION_COMPAT_MODE)) {
            this._validator.nextEvent(5, this._simpleEvent);
        }
    }

    public static final class AttributeEventImpl implements ValidatorListener.Event {
        public static final /* synthetic */ boolean $assertionsDisabled;
        public int _attIndex;
        public XMLStreamReader _xmlStream;

        static {
            Class cls = ValidatingXMLStreamReader.class$org$apache$xmlbeans$impl$validator$ValidatingXMLStreamReader;
            if (cls == null) {
                cls = ValidatingXMLStreamReader.class$("org.apache.xmlbeans.impl.validator.ValidatingXMLStreamReader");
                ValidatingXMLStreamReader.class$org$apache$xmlbeans$impl$validator$ValidatingXMLStreamReader = cls;
            }
            $assertionsDisabled = !cls.desiredAssertionStatus();
        }

        public AttributeEventImpl() {
        }

        /* access modifiers changed from: private */
        /* access modifiers changed from: public */
        private void setAttributeIndex(int i2) {
            this._attIndex = i2;
        }

        /* access modifiers changed from: private */
        /* access modifiers changed from: public */
        private void setXMLStreamReader(XMLStreamReader xMLStreamReader) {
            this._xmlStream = xMLStreamReader;
        }

        @Override // org.apache.xmlbeans.impl.common.ValidatorListener.Event
        public Location getLocation() {
            return this._xmlStream.getLocation();
        }

        @Override // org.apache.xmlbeans.impl.common.ValidatorListener.Event
        public XmlCursor getLocationAsCursor() {
            return null;
        }

        @Override // org.apache.xmlbeans.impl.common.ValidatorListener.Event
        public QName getName() {
            if ($assertionsDisabled || this._xmlStream.isStartElement()) {
                String attributeNamespace = this._xmlStream.getAttributeNamespace(this._attIndex);
                if (attributeNamespace == null) {
                    attributeNamespace = "";
                }
                return new QName(attributeNamespace, this._xmlStream.getAttributeLocalName(this._attIndex));
            }
            throw new AssertionError("Not on Start Element.");
        }

        @Override // org.apache.xmlbeans.impl.common.PrefixResolver
        public String getNamespaceForPrefix(String str) {
            if ($assertionsDisabled || this._xmlStream.isStartElement()) {
                return this._xmlStream.getNamespaceURI(str);
            }
            throw new AssertionError("Not on Start Element.");
        }

        @Override // org.apache.xmlbeans.impl.common.ValidatorListener.Event
        public String getText() {
            if ($assertionsDisabled || this._xmlStream.isStartElement()) {
                return this._xmlStream.getAttributeValue(this._attIndex);
            }
            throw new AssertionError("Not on Start Element.");
        }

        @Override // org.apache.xmlbeans.impl.common.ValidatorListener.Event
        public String getXsiLoc() {
            throw new IllegalStateException();
        }

        @Override // org.apache.xmlbeans.impl.common.ValidatorListener.Event
        public String getXsiNil() {
            throw new IllegalStateException();
        }

        @Override // org.apache.xmlbeans.impl.common.ValidatorListener.Event
        public String getXsiNoLoc() {
            throw new IllegalStateException();
        }

        @Override // org.apache.xmlbeans.impl.common.ValidatorListener.Event
        public String getXsiType() {
            throw new IllegalStateException();
        }

        @Override // org.apache.xmlbeans.impl.common.ValidatorListener.Event
        public boolean textIsWhitespace() {
            throw new IllegalStateException();
        }

        @Override // org.apache.xmlbeans.impl.common.ValidatorListener.Event
        public String getText(int i2) {
            if ($assertionsDisabled || this._xmlStream.isStartElement()) {
                return XmlWhitespace.collapse(this._xmlStream.getAttributeValue(this._attIndex), i2);
            }
            throw new AssertionError("Not on Start Element.");
        }
    }

    public static class PackTextXmlStreamReader extends StreamReaderDelegate implements XMLStreamReader {
        public static final /* synthetic */ boolean $assertionsDisabled;
        public StringBuffer _buffer;
        public boolean _hasBufferedText;
        public int _textEventType;

        static {
            Class cls = ValidatingXMLStreamReader.class$org$apache$xmlbeans$impl$validator$ValidatingXMLStreamReader;
            if (cls == null) {
                cls = ValidatingXMLStreamReader.class$("org.apache.xmlbeans.impl.validator.ValidatingXMLStreamReader");
                ValidatingXMLStreamReader.class$org$apache$xmlbeans$impl$validator$ValidatingXMLStreamReader = cls;
            }
            $assertionsDisabled = !cls.desiredAssertionStatus();
        }

        public PackTextXmlStreamReader() {
            this._buffer = new StringBuffer();
        }

        private void bufferText() {
            if (super.hasText()) {
                this._buffer.append(super.getText());
            }
            this._hasBufferedText = true;
            while (hasNext()) {
                int next = super.next();
                if (next != 4) {
                    if (next == 5) {
                        continue;
                    } else if (!(next == 6 || next == 12)) {
                        return;
                    }
                }
                if (super.hasText()) {
                    this._buffer.append(super.getText());
                }
            }
        }

        private void clearBuffer() {
            StringBuffer stringBuffer = this._buffer;
            stringBuffer.delete(0, stringBuffer.length());
            this._hasBufferedText = false;
        }

        @Override // org.apache.poi.javax.xml.stream.XMLStreamReader, org.apache.poi.javax.xml.stream.util.StreamReaderDelegate
        public int getEventType() {
            if (this._hasBufferedText) {
                return this._textEventType;
            }
            return super.getEventType();
        }

        @Override // org.apache.poi.javax.xml.stream.XMLStreamReader, org.apache.poi.javax.xml.stream.util.StreamReaderDelegate
        public String getText() {
            if ($assertionsDisabled || this._hasBufferedText) {
                return this._buffer.toString();
            }
            throw new AssertionError();
        }

        @Override // org.apache.poi.javax.xml.stream.XMLStreamReader, org.apache.poi.javax.xml.stream.util.StreamReaderDelegate
        public char[] getTextCharacters() {
            if ($assertionsDisabled || this._hasBufferedText) {
                return this._buffer.toString().toCharArray();
            }
            throw new AssertionError();
        }

        @Override // org.apache.poi.javax.xml.stream.XMLStreamReader, org.apache.poi.javax.xml.stream.util.StreamReaderDelegate
        public int getTextLength() {
            if ($assertionsDisabled || this._hasBufferedText) {
                return this._buffer.length();
            }
            throw new AssertionError();
        }

        @Override // org.apache.poi.javax.xml.stream.XMLStreamReader, org.apache.poi.javax.xml.stream.util.StreamReaderDelegate
        public int getTextStart() {
            if ($assertionsDisabled || this._hasBufferedText) {
                return 0;
            }
            throw new AssertionError();
        }

        @Override // org.apache.poi.javax.xml.stream.XMLStreamReader, org.apache.poi.javax.xml.stream.util.StreamReaderDelegate
        public boolean hasText() {
            if (this._hasBufferedText) {
                return true;
            }
            return super.hasText();
        }

        public void init(XMLStreamReader xMLStreamReader) {
            setParent(xMLStreamReader);
            this._hasBufferedText = false;
            StringBuffer stringBuffer = this._buffer;
            stringBuffer.delete(0, stringBuffer.length());
        }

        @Override // org.apache.poi.javax.xml.stream.XMLStreamReader, org.apache.poi.javax.xml.stream.util.StreamReaderDelegate
        public boolean isWhiteSpace() {
            if ($assertionsDisabled || this._hasBufferedText) {
                return XmlWhitespace.isAllSpace(this._buffer);
            }
            throw new AssertionError();
        }

        @Override // org.apache.poi.javax.xml.stream.XMLStreamReader, org.apache.poi.javax.xml.stream.util.StreamReaderDelegate
        public int next() {
            if (this._hasBufferedText) {
                clearBuffer();
                return super.getEventType();
            }
            int next = super.next();
            if (next == 4 || next == 12 || next == 6) {
                this._textEventType = next;
                bufferText();
            }
            return next;
        }

        @Override // org.apache.poi.javax.xml.stream.XMLStreamReader, org.apache.poi.javax.xml.stream.util.StreamReaderDelegate
        public int getTextCharacters(int i2, char[] cArr, int i3, int i4) {
            if ($assertionsDisabled || this._hasBufferedText) {
                this._buffer.getChars(i2, i2 + i4, cArr, i3);
                return i4;
            }
            throw new AssertionError();
        }
    }

    public static class ElementEventImpl implements ValidatorListener.Event {
        public static final int BUF_LENGTH = 1024;
        public char[] _buf;
        public int _length;
        public boolean _supportForGetTextCharacters;
        public XMLStreamReader _xmlStream;

        public ElementEventImpl() {
            this._buf = new char[1024];
            this._supportForGetTextCharacters = true;
        }

        private void addTextToBuffer() {
            int textLength = this._xmlStream.getTextLength();
            ensureBufferLength(textLength);
            if (this._supportForGetTextCharacters) {
                try {
                    this._length = this._xmlStream.getTextCharacters(0, this._buf, this._length, textLength);
                } catch (Exception unused) {
                    this._supportForGetTextCharacters = false;
                }
            }
            if (!this._supportForGetTextCharacters) {
                System.arraycopy(this._xmlStream.getTextCharacters(), this._xmlStream.getTextStart(), this._buf, this._length, textLength);
                this._length += textLength;
            }
        }

        private void ensureBufferLength(int i2) {
            int i3 = this._length;
            int i4 = i3 + i2;
            char[] cArr = this._buf;
            if (i4 > cArr.length) {
                char[] cArr2 = new char[(i2 + i3)];
                if (i3 > 0) {
                    System.arraycopy(cArr, 0, cArr2, 0, i3);
                }
                this._buf = cArr2;
            }
        }

        /* access modifiers changed from: private */
        /* access modifiers changed from: public */
        private void setXMLStreamReader(XMLStreamReader xMLStreamReader) {
            this._xmlStream = xMLStreamReader;
        }

        @Override // org.apache.xmlbeans.impl.common.ValidatorListener.Event
        public Location getLocation() {
            return this._xmlStream.getLocation();
        }

        @Override // org.apache.xmlbeans.impl.common.ValidatorListener.Event
        public XmlCursor getLocationAsCursor() {
            return null;
        }

        @Override // org.apache.xmlbeans.impl.common.ValidatorListener.Event
        public QName getName() {
            if (this._xmlStream.hasName()) {
                return new QName(this._xmlStream.getNamespaceURI(), this._xmlStream.getLocalName());
            }
            return null;
        }

        @Override // org.apache.xmlbeans.impl.common.PrefixResolver
        public String getNamespaceForPrefix(String str) {
            return this._xmlStream.getNamespaceURI(str);
        }

        @Override // org.apache.xmlbeans.impl.common.ValidatorListener.Event
        public String getText() {
            this._length = 0;
            addTextToBuffer();
            return new String(this._buf, 0, this._length);
        }

        @Override // org.apache.xmlbeans.impl.common.ValidatorListener.Event
        public String getXsiLoc() {
            return this._xmlStream.getAttributeValue("http://www.w3.org/2001/XMLSchema-instance", "schemaLocation");
        }

        @Override // org.apache.xmlbeans.impl.common.ValidatorListener.Event
        public String getXsiNil() {
            return this._xmlStream.getAttributeValue("http://www.w3.org/2001/XMLSchema-instance", "nil");
        }

        @Override // org.apache.xmlbeans.impl.common.ValidatorListener.Event
        public String getXsiNoLoc() {
            return this._xmlStream.getAttributeValue("http://www.w3.org/2001/XMLSchema-instance", "noNamespaceSchemaLocation");
        }

        @Override // org.apache.xmlbeans.impl.common.ValidatorListener.Event
        public String getXsiType() {
            return this._xmlStream.getAttributeValue("http://www.w3.org/2001/XMLSchema-instance", JamXmlElements.TYPE);
        }

        @Override // org.apache.xmlbeans.impl.common.ValidatorListener.Event
        public boolean textIsWhitespace() {
            return this._xmlStream.isWhiteSpace();
        }

        @Override // org.apache.xmlbeans.impl.common.ValidatorListener.Event
        public String getText(int i2) {
            return XmlWhitespace.collapse(this._xmlStream.getText(), i2);
        }
    }
}
