package org.apache.xmlbeans.impl.values;

import org.apache.poi.javax.xml.namespace.QName;
import org.apache.xerces.impl.xs.SchemaSymbols;
import org.apache.xmlbeans.SchemaType;
import org.apache.xmlbeans.XmlAnySimpleType;
import org.apache.xmlbeans.XmlErrorCodes;
import org.apache.xmlbeans.impl.common.PrefixResolver;
import org.apache.xmlbeans.impl.common.QNameHelper;
import org.apache.xmlbeans.impl.common.ValidationContext;

public abstract class JavaNotationHolderEx extends JavaNotationHolder {
    public SchemaType _schemaType;

    public JavaNotationHolderEx(SchemaType schemaType, boolean z) {
        this._schemaType = schemaType;
        initComplexType(z, false);
    }

    public static boolean check(String str, SchemaType schemaType) {
        XmlAnySimpleType facet = schemaType.getFacet(0);
        if (facet != null && str.length() == ((XmlObjectBase) facet).getBigIntegerValue().intValue()) {
            return false;
        }
        XmlAnySimpleType facet2 = schemaType.getFacet(1);
        if (facet2 != null && str.length() < ((XmlObjectBase) facet2).getBigIntegerValue().intValue()) {
            return false;
        }
        XmlAnySimpleType facet3 = schemaType.getFacet(2);
        if (facet3 == null || str.length() <= ((XmlObjectBase) facet3).getBigIntegerValue().intValue()) {
            return true;
        }
        return false;
    }

    public static QName validateLexical(String str, SchemaType schemaType, ValidationContext validationContext, PrefixResolver prefixResolver) {
        QName validateLexical = JavaQNameHolder.validateLexical(str, validationContext, prefixResolver);
        if (schemaType.hasPatternFacet() && !schemaType.matchPatternFacet(str)) {
            validationContext.invalid(XmlErrorCodes.DATATYPE_VALID$PATTERN_VALID, new Object[]{SchemaSymbols.ATTVAL_NOTATION, str, QNameHelper.readable(schemaType)});
        }
        check(str, schemaType);
        return validateLexical;
    }

    public static void validateValue(QName qName, SchemaType schemaType, ValidationContext validationContext) {
        XmlAnySimpleType[] enumerationValues = schemaType.getEnumerationValues();
        if (enumerationValues != null) {
            for (XmlAnySimpleType xmlAnySimpleType : enumerationValues) {
                if (qName.equals(((XmlObjectBase) xmlAnySimpleType).getQNameValue())) {
                    return;
                }
            }
            validationContext.invalid(XmlErrorCodes.DATATYPE_ENUM_VALID, new Object[]{SchemaSymbols.ATTVAL_NOTATION, qName, QNameHelper.readable(schemaType)});
        }
    }

    @Override // org.apache.xmlbeans.impl.values.XmlObjectBase, org.apache.xmlbeans.impl.values.JavaQNameHolder
    public int get_wscanon_rule() {
        return schemaType().getWhiteSpaceRule();
    }

    @Override // org.apache.xmlbeans.impl.values.XmlObjectBase, org.apache.xmlbeans.impl.values.JavaQNameHolder, org.apache.xmlbeans.XmlObject, org.apache.xmlbeans.impl.values.JavaNotationHolder
    public SchemaType schemaType() {
        return this._schemaType;
    }

    @Override // org.apache.xmlbeans.impl.values.XmlObjectBase
    public void set_notation(String str) {
        set_text(str);
    }

    @Override // org.apache.xmlbeans.impl.values.XmlObjectBase, org.apache.xmlbeans.impl.values.JavaQNameHolder
    public void set_text(String str) {
        if (_validateOnSet()) {
            if (!check(str, this._schemaType)) {
                throw new XmlValueOutOfRangeException();
            } else if (!this._schemaType.matchPatternFacet(str)) {
                throw new XmlValueOutOfRangeException();
            }
        }
        super.set_text(str);
    }

    @Override // org.apache.xmlbeans.impl.values.XmlObjectBase, org.apache.xmlbeans.impl.values.JavaQNameHolder
    public void set_xmlanysimple(XmlAnySimpleType xmlAnySimpleType) {
        QName qName;
        if (_validateOnSet()) {
            qName = validateLexical(xmlAnySimpleType.getStringValue(), this._schemaType, XmlObjectBase._voorVc, NamespaceContext.getCurrent());
            if (qName != null) {
                validateValue(qName, this._schemaType, XmlObjectBase._voorVc);
            }
        } else {
            qName = JavaQNameHolder.validateLexical(xmlAnySimpleType.getStringValue(), XmlObjectBase._voorVc, NamespaceContext.getCurrent());
        }
        super.set_QName(qName);
    }
}
