package org.apache.xmlbeans.impl.values;

import org.apache.poi.javax.xml.namespace.QName;
import org.apache.xmlbeans.SchemaType;
import org.apache.xmlbeans.XmlAnySimpleType;
import org.apache.xmlbeans.XmlErrorCodes;
import org.apache.xmlbeans.impl.common.PrefixResolver;
import org.apache.xmlbeans.impl.common.QNameHelper;
import org.apache.xmlbeans.impl.common.ValidationContext;

public abstract class JavaQNameHolderEx extends JavaQNameHolder {
    public SchemaType _schemaType;

    public JavaQNameHolderEx(SchemaType schemaType, boolean z) {
        this._schemaType = schemaType;
        initComplexType(z, false);
    }

    public static QName validateLexical(String str, SchemaType schemaType, ValidationContext validationContext, PrefixResolver prefixResolver) {
        QName validateLexical = JavaQNameHolder.validateLexical(str, validationContext, prefixResolver);
        if (schemaType.hasPatternFacet() && !schemaType.matchPatternFacet(str)) {
            validationContext.invalid(XmlErrorCodes.DATATYPE_VALID$PATTERN_VALID, new Object[]{"QName", str, QNameHelper.readable(schemaType)});
        }
        return validateLexical;
    }

    public static void validateValue(QName qName, SchemaType schemaType, ValidationContext validationContext) {
        XmlAnySimpleType[] enumerationValues = schemaType.getEnumerationValues();
        if (enumerationValues != null) {
            for (XmlAnySimpleType xmlAnySimpleType : enumerationValues) {
                if (qName.equals(((XmlObjectBase) xmlAnySimpleType).getQNameValue())) {
                    return;
                }
            }
            validationContext.invalid(XmlErrorCodes.DATATYPE_ENUM_VALID, new Object[]{"QName", qName, QNameHelper.readable(schemaType)});
        }
    }

    @Override // org.apache.xmlbeans.impl.values.XmlObjectBase, org.apache.xmlbeans.impl.values.JavaQNameHolder
    public int get_wscanon_rule() {
        return schemaType().getWhiteSpaceRule();
    }

    @Override // org.apache.xmlbeans.impl.values.XmlObjectBase, org.apache.xmlbeans.impl.values.JavaQNameHolder, org.apache.xmlbeans.XmlObject
    public SchemaType schemaType() {
        return this._schemaType;
    }

    @Override // org.apache.xmlbeans.impl.values.XmlObjectBase, org.apache.xmlbeans.impl.values.JavaQNameHolder
    public void set_QName(QName qName) {
        if (_validateOnSet()) {
            validateValue(qName, this._schemaType, XmlObjectBase._voorVc);
        }
        super.set_QName(qName);
    }

    @Override // org.apache.xmlbeans.impl.values.XmlObjectBase, org.apache.xmlbeans.impl.values.JavaQNameHolder
    public void set_text(String str) {
        QName qName;
        PrefixResolver current = NamespaceContext.getCurrent();
        if (current == null && has_store()) {
            current = get_store();
        }
        if (_validateOnSet()) {
            qName = validateLexical(str, this._schemaType, XmlObjectBase._voorVc, current);
            if (qName != null) {
                validateValue(qName, this._schemaType, XmlObjectBase._voorVc);
            }
        } else {
            qName = JavaQNameHolder.validateLexical(str, XmlObjectBase._voorVc, current);
        }
        super.set_QName(qName);
    }

    @Override // org.apache.xmlbeans.impl.values.XmlObjectBase, org.apache.xmlbeans.impl.values.JavaQNameHolder
    public void set_xmlanysimple(XmlAnySimpleType xmlAnySimpleType) {
        QName qName;
        if (_validateOnSet()) {
            qName = validateLexical(xmlAnySimpleType.getStringValue(), this._schemaType, XmlObjectBase._voorVc, NamespaceContext.getCurrent());
            if (qName != null) {
                validateValue(qName, this._schemaType, XmlObjectBase._voorVc);
            }
        } else {
            qName = JavaQNameHolder.validateLexical(xmlAnySimpleType.getStringValue(), XmlObjectBase._voorVc, NamespaceContext.getCurrent());
        }
        super.set_QName(qName);
    }

    @Override // org.apache.xmlbeans.impl.values.XmlObjectBase
    public void validate_simpleval(String str, ValidationContext validationContext) {
        validateValue(getQNameValue(), schemaType(), validationContext);
    }
}
