package org.apache.xmlbeans.impl.values;

import java.util.ArrayList;
import java.util.Arrays;
import java.util.List;
import org.apache.xmlbeans.SchemaType;
import org.apache.xmlbeans.SimpleValue;
import org.apache.xmlbeans.XmlAnySimpleType;
import org.apache.xmlbeans.XmlErrorCodes;
import org.apache.xmlbeans.XmlObject;
import org.apache.xmlbeans.XmlSimpleList;
import org.apache.xmlbeans.impl.common.PrefixResolver;
import org.apache.xmlbeans.impl.common.QNameHelper;
import org.apache.xmlbeans.impl.common.ValidationContext;
import org.apache.xmlbeans.impl.common.XMLChar;

public class XmlListImpl extends XmlObjectBase implements XmlAnySimpleType {
    public static final String[] EMPTY_STRINGARRAY = new String[0];
    public XmlSimpleList _jvalue;
    public SchemaType _schemaType;
    public XmlSimpleList _value;

    public XmlListImpl(SchemaType schemaType, boolean z) {
        this._schemaType = schemaType;
        initComplexType(z, false);
    }

    public static String compute_list_text(List list) {
        if (list.size() == 0) {
            return "";
        }
        StringBuffer stringBuffer = new StringBuffer();
        stringBuffer.append(nullAsEmpty(((SimpleValue) list.get(0)).getStringValue()));
        for (int i2 = 1; i2 < list.size(); i2++) {
            stringBuffer.append(' ');
            stringBuffer.append(nullAsEmpty(((SimpleValue) list.get(i2)).getStringValue()));
        }
        return stringBuffer.toString();
    }

    public static boolean contains_white_space(String str) {
        return str.indexOf(32) >= 0 || str.indexOf(9) >= 0 || str.indexOf(10) >= 0 || str.indexOf(13) >= 0;
    }

    public static boolean equal_xmlLists(List list, List list2) {
        if (list.size() != list2.size()) {
            return false;
        }
        for (int i2 = 0; i2 < list.size(); i2++) {
            if (!list.get(i2).equals(list2.get(i2))) {
                return false;
            }
        }
        return true;
    }

    public static XmlSimpleList lex(String str, SchemaType schemaType, ValidationContext validationContext, PrefixResolver prefixResolver) {
        boolean z;
        Object[] split_list = split_list(str);
        XmlAnySimpleType[] xmlAnySimpleTypeArr = new XmlAnySimpleType[split_list.length];
        if (prefixResolver != null) {
            NamespaceContext.push(new NamespaceContext(prefixResolver));
            z = true;
        } else {
            z = false;
        }
        for (int i2 = 0; i2 < split_list.length; i2++) {
            try {
                try {
                    xmlAnySimpleTypeArr[i2] = schemaType.newValue(split_list[i2]);
                } catch (XmlValueOutOfRangeException unused) {
                    StringBuffer stringBuffer = new StringBuffer();
                    stringBuffer.append("item '");
                    stringBuffer.append(split_list[i2]);
                    stringBuffer.append("' is not a valid value of ");
                    stringBuffer.append(QNameHelper.readable(schemaType));
                    validationContext.invalid("list", new Object[]{stringBuffer.toString()});
                }
            } finally {
                if (z) {
                    NamespaceContext.pop();
                }
            }
        }
        return new XmlSimpleList(Arrays.asList(xmlAnySimpleTypeArr));
    }

    public static String nullAsEmpty(String str) {
        return str == null ? "" : str;
    }

    public static boolean permits_inner_space(XmlObject xmlObject) {
        int builtinTypeCode = ((SimpleValue) xmlObject).instanceType().getPrimitiveType().getBuiltinTypeCode();
        return builtinTypeCode == 1 || builtinTypeCode == 2 || builtinTypeCode == 6 || builtinTypeCode == 12;
    }

    public static String[] split_list(String str) {
        if (str.length() == 0) {
            return EMPTY_STRINGARRAY;
        }
        ArrayList arrayList = new ArrayList();
        int i2 = 0;
        while (true) {
            if (i2 < str.length() && XMLChar.isSpace(str.charAt(i2))) {
                i2++;
            } else if (i2 >= str.length()) {
                return (String[]) arrayList.toArray(EMPTY_STRINGARRAY);
            } else {
                int i3 = i2;
                while (i3 < str.length() && !XMLChar.isSpace(str.charAt(i3))) {
                    i3++;
                }
                arrayList.add(str.substring(i2, i3));
                i2 = i3;
            }
        }
    }

    public static void validateValue(XmlSimpleList xmlSimpleList, SchemaType schemaType, ValidationContext validationContext) {
        int intValue;
        int intValue2;
        int intValue3;
        XmlAnySimpleType[] enumerationValues = schemaType.getEnumerationValues();
        if (enumerationValues != null) {
            int i2 = 0;
            while (true) {
                if (i2 >= enumerationValues.length) {
                    validationContext.invalid(XmlErrorCodes.DATATYPE_ENUM_VALID, new Object[]{"list", xmlSimpleList, QNameHelper.readable(schemaType)});
                    break;
                } else if (equal_xmlLists(xmlSimpleList, ((XmlObjectBase) enumerationValues[i2]).xlistValue())) {
                    break;
                } else {
                    i2++;
                }
            }
        }
        XmlAnySimpleType facet = schemaType.getFacet(0);
        if (!(facet == null || (intValue3 = ((SimpleValue) facet).getIntValue()) == xmlSimpleList.size())) {
            validationContext.invalid(XmlErrorCodes.DATATYPE_LENGTH_VALID$LIST_LENGTH, new Object[]{xmlSimpleList, new Integer(xmlSimpleList.size()), new Integer(intValue3), QNameHelper.readable(schemaType)});
        }
        XmlAnySimpleType facet2 = schemaType.getFacet(1);
        if (facet2 != null && (intValue2 = ((SimpleValue) facet2).getIntValue()) > xmlSimpleList.size()) {
            validationContext.invalid(XmlErrorCodes.DATATYPE_MIN_LENGTH_VALID$LIST_LENGTH, new Object[]{xmlSimpleList, new Integer(xmlSimpleList.size()), new Integer(intValue2), QNameHelper.readable(schemaType)});
        }
        XmlAnySimpleType facet3 = schemaType.getFacet(2);
        if (facet3 != null && (intValue = ((SimpleValue) facet3).getIntValue()) < xmlSimpleList.size()) {
            validationContext.invalid(XmlErrorCodes.DATATYPE_MAX_LENGTH_VALID$LIST_LENGTH, new Object[]{xmlSimpleList, new Integer(xmlSimpleList.size()), new Integer(intValue), QNameHelper.readable(schemaType)});
        }
    }

    @Override // org.apache.xmlbeans.impl.values.XmlObjectBase
    public String compute_text(NamespaceManager namespaceManager) {
        return compute_list_text(this._value);
    }

    @Override // org.apache.xmlbeans.impl.values.XmlObjectBase
    public boolean equal_to(XmlObject xmlObject) {
        return equal_xmlLists(this._value, ((XmlObjectBase) xmlObject).xlistValue());
    }

    @Override // org.apache.xmlbeans.impl.values.XmlObjectBase, org.apache.xmlbeans.SimpleValue
    public List getListValue() {
        check_dated();
        if (this._value == null) {
            return null;
        }
        XmlSimpleList xmlSimpleList = this._jvalue;
        if (xmlSimpleList != null) {
            return xmlSimpleList;
        }
        ArrayList arrayList = new ArrayList();
        for (int i2 = 0; i2 < this._value.size(); i2++) {
            arrayList.add(XmlObjectBase.java_value((XmlObject) this._value.get(i2)));
        }
        XmlSimpleList xmlSimpleList2 = new XmlSimpleList(arrayList);
        this._jvalue = xmlSimpleList2;
        return xmlSimpleList2;
    }

    @Override // org.apache.xmlbeans.impl.values.XmlObjectBase
    public boolean is_defaultable_ws(String str) {
        try {
            XmlSimpleList xmlSimpleList = this._value;
            set_text(str);
            this._value = xmlSimpleList;
            return false;
        } catch (XmlValueOutOfRangeException unused) {
            return true;
        }
    }

    @Override // org.apache.xmlbeans.impl.values.XmlObjectBase, org.apache.xmlbeans.XmlObject
    public SchemaType schemaType() {
        return this._schemaType;
    }

    @Override // org.apache.xmlbeans.impl.values.XmlObjectBase
    public void set_list(List list) {
        boolean z;
        SchemaType listItemType = this._schemaType.getListItemType();
        if (has_store()) {
            NamespaceContext.push(new NamespaceContext(get_store()));
            z = true;
        } else {
            z = false;
        }
        try {
            XmlAnySimpleType[] xmlAnySimpleTypeArr = new XmlAnySimpleType[list.size()];
            for (int i2 = 0; i2 < list.size(); i2++) {
                Object obj = list.get(i2);
                if ((obj instanceof XmlObject) && permits_inner_space((XmlObject) list.get(i2))) {
                    if (contains_white_space(list.get(i2).toString())) {
                        throw new XmlValueOutOfRangeException();
                    }
                }
                xmlAnySimpleTypeArr[i2] = listItemType.newValue(obj);
            }
            XmlSimpleList xmlSimpleList = new XmlSimpleList(Arrays.asList(xmlAnySimpleTypeArr));
            if (_validateOnSet()) {
                validateValue(xmlSimpleList, this._schemaType, XmlObjectBase._voorVc);
            }
            this._value = xmlSimpleList;
            this._jvalue = null;
        } finally {
            if (z) {
                NamespaceContext.pop();
            }
        }
    }

    @Override // org.apache.xmlbeans.impl.values.XmlObjectBase
    public void set_nil() {
        this._value = null;
    }

    @Override // org.apache.xmlbeans.impl.values.XmlObjectBase
    public void set_text(String str) {
        if (!_validateOnSet() || this._schemaType.matchPatternFacet(str)) {
            XmlSimpleList lex = lex(str, this._schemaType.getListItemType(), XmlObjectBase._voorVc, has_store() ? get_store() : null);
            if (_validateOnSet()) {
                validateValue(lex, this._schemaType, XmlObjectBase._voorVc);
            }
            this._value = lex;
            this._jvalue = null;
            return;
        }
        throw new XmlValueOutOfRangeException(XmlErrorCodes.DATATYPE_VALID$PATTERN_VALID, new Object[]{"list", str, QNameHelper.readable(this._schemaType)});
    }

    @Override // org.apache.xmlbeans.impl.values.XmlObjectBase
    public void validate_simpleval(String str, ValidationContext validationContext) {
        validateValue((XmlSimpleList) xlistValue(), schemaType(), validationContext);
    }

    @Override // org.apache.xmlbeans.impl.values.XmlObjectBase
    public int value_hash_code() {
        XmlSimpleList xmlSimpleList = this._value;
        int i2 = 0;
        if (xmlSimpleList == null) {
            return 0;
        }
        int size = xmlSimpleList.size();
        int size2 = this._value.size() / 9;
        if (size2 < 1) {
            size2 = 1;
        }
        while (i2 < this._value.size()) {
            size = (size * 19) + this._value.get(i2).hashCode();
            i2 += size2;
        }
        return i2 < this._value.size() ? (size * 19) + this._value.get(i2).hashCode() : size;
    }

    @Override // org.apache.xmlbeans.impl.values.XmlObjectBase, org.apache.xmlbeans.SimpleValue
    public List xgetListValue() {
        check_dated();
        return this._value;
    }
}
