package org.apache.xmlbeans.impl.values;

import b.b.a.a.a;
import java.io.ByteArrayInputStream;
import java.io.DataInputStream;
import java.io.File;
import java.io.IOException;
import java.io.InputStream;
import java.io.ObjectInputStream;
import java.io.ObjectOutputStream;
import java.io.OutputStream;
import java.io.Reader;
import java.io.Serializable;
import java.io.Writer;
import java.lang.reflect.Array;
import java.math.BigDecimal;
import java.math.BigInteger;
import java.util.ArrayList;
import java.util.Arrays;
import java.util.Calendar;
import java.util.Collection;
import java.util.Date;
import java.util.HashSet;
import java.util.List;
import org.apache.poi.javax.xml.namespace.QName;
import org.apache.poi.javax.xml.stream.XMLStreamReader;
import org.apache.poi.ss.formula.functions.NumericFunction;
import org.apache.xmlbeans.DelegateXmlObject;
import org.apache.xmlbeans.GDate;
import org.apache.xmlbeans.GDateSpecification;
import org.apache.xmlbeans.GDuration;
import org.apache.xmlbeans.GDurationSpecification;
import org.apache.xmlbeans.QNameSet;
import org.apache.xmlbeans.SchemaAttributeModel;
import org.apache.xmlbeans.SchemaField;
import org.apache.xmlbeans.SchemaLocalAttribute;
import org.apache.xmlbeans.SchemaProperty;
import org.apache.xmlbeans.SchemaType;
import org.apache.xmlbeans.SimpleValue;
import org.apache.xmlbeans.StringEnumAbstractBase;
import org.apache.xmlbeans.XmlAnySimpleType;
import org.apache.xmlbeans.XmlBeans;
import org.apache.xmlbeans.XmlCursor;
import org.apache.xmlbeans.XmlDocumentProperties;
import org.apache.xmlbeans.XmlError;
import org.apache.xmlbeans.XmlErrorCodes;
import org.apache.xmlbeans.XmlException;
import org.apache.xmlbeans.XmlObject;
import org.apache.xmlbeans.XmlOptions;
import org.apache.xmlbeans.XmlRuntimeException;
import org.apache.xmlbeans.impl.common.GlobalLock;
import org.apache.xmlbeans.impl.common.QNameHelper;
import org.apache.xmlbeans.impl.common.ValidationContext;
import org.apache.xmlbeans.impl.common.XmlErrorWatcher;
import org.apache.xmlbeans.impl.common.XmlLocale;
import org.apache.xmlbeans.impl.common.XmlWhitespace;
import org.apache.xmlbeans.impl.schema.SchemaTypeImpl;
import org.apache.xmlbeans.impl.schema.SchemaTypeVisitorImpl;
import org.apache.xmlbeans.impl.validator.Validator;
import org.apache.xmlbeans.xml.stream.XMLInputStream;
import org.w3c.dom.Node;
import org.xml.sax.ContentHandler;
import org.xml.sax.ext.LexicalHandler;

public abstract class XmlObjectBase implements TypeStoreUser, Serializable, XmlObject, SimpleValue {
    public static final /* synthetic */ boolean $assertionsDisabled;
    public static final XmlObject[] EMPTY_RESULT = new XmlObject[0];
    public static final int FLAGS_DATED = 672;
    public static final int FLAGS_ELEMENT = 7;
    public static final int FLAG_ATTRIBUTE = 8;
    public static final int FLAG_COMPLEXCONTENT = 16384;
    public static final int FLAG_COMPLEXTYPE = 8192;
    public static final int FLAG_ELEMENT_DATED = 512;
    public static final int FLAG_FIXED = 4;
    public static final int FLAG_HASDEFAULT = 2;
    public static final int FLAG_IMMUTABLE = 4096;
    public static final int FLAG_ISDEFAULT = 256;
    public static final int FLAG_NIL = 64;
    public static final int FLAG_NILLABLE = 1;
    public static final int FLAG_NIL_DATED = 128;
    public static final int FLAG_NOT_VARIABLE = 32768;
    public static final int FLAG_ORPHANED = 2048;
    public static final int FLAG_SETTINGDEFAULT = 1024;
    public static final int FLAG_STORE = 16;
    public static final int FLAG_VALIDATE_ON_SET = 65536;
    public static final int FLAG_VALUE_DATED = 32;
    public static final short KIND_SETTERHELPER_ARRAYITEM = 2;
    public static final short KIND_SETTERHELPER_SINGLETON = 1;
    public static final short MAJOR_VERSION_NUMBER = 1;
    public static final short MINOR_VERSION_NUMBER = 1;
    public static final BigInteger _max = BigInteger.valueOf(Long.MAX_VALUE);
    public static final BigInteger _min = BigInteger.valueOf(Long.MIN_VALUE);
    public static final XmlOptions _toStringOptions = buildInnerPrettyOptions();
    public static final ValidationContext _voorVc = new ValueOutOfRangeValidationContext();
    public static /* synthetic */ Class class$org$apache$xmlbeans$impl$values$XmlObjectBase;
    public int _flags = 65;
    public Object _textsource;

    public static final class ImmutableValueValidationContext implements ValidationContext {
        public Collection _coll;
        public XmlObject _loc;

        public ImmutableValueValidationContext(Collection collection, XmlObject xmlObject) {
            this._coll = collection;
            this._loc = xmlObject;
        }

        @Override // org.apache.xmlbeans.impl.common.ValidationContext
        public void invalid(String str) {
            this._coll.add(XmlError.forObject(str, this._loc));
        }

        @Override // org.apache.xmlbeans.impl.common.ValidationContext
        public void invalid(String str, Object[] objArr) {
            this._coll.add(XmlError.forObject(str, objArr, this._loc));
        }
    }

    public static class SerializedInteriorObject implements Serializable {
        public static final long serialVersionUID = 1;
        public transient XmlObject _impl;
        public transient XmlObject _root;

        private int distanceToRoot() {
            XmlCursor newCursor = this._impl.newCursor();
            int i2 = 0;
            while (!newCursor.toPrevToken().isNone()) {
                if (!newCursor.currentTokenType().isNamespace()) {
                    i2++;
                }
            }
            newCursor.dispose();
            return i2;
        }

        private XmlObject objectAtDistance(int i2) {
            XmlCursor newCursor = this._root.newCursor();
            while (i2 > 0) {
                newCursor.toNextToken();
                if (!newCursor.currentTokenType().isNamespace()) {
                    i2--;
                }
            }
            XmlObject object = newCursor.getObject();
            newCursor.dispose();
            return object;
        }

        private void readObject(ObjectInputStream objectInputStream) {
            this._root = (XmlObject) objectInputStream.readObject();
            objectInputStream.readBoolean();
            this._impl = objectAtDistance(objectInputStream.readInt());
        }

        private Object readResolve() {
            return this._impl;
        }

        private void writeObject(ObjectOutputStream objectOutputStream) {
            objectOutputStream.writeObject(this._root);
            objectOutputStream.writeBoolean(false);
            objectOutputStream.writeInt(distanceToRoot());
        }

        public SerializedInteriorObject() {
        }

        public SerializedInteriorObject(XmlObject xmlObject, XmlObject xmlObject2) {
            this._impl = xmlObject;
            this._root = xmlObject2;
        }
    }

    public static class SerializedRootObject implements Serializable {
        public static final long serialVersionUID = 1;
        public transient XmlObject _impl;
        public transient Class _xbeanClass;

        private void readObject(ObjectInputStream objectInputStream) {
            int i2;
            String str;
            try {
                this._xbeanClass = (Class) objectInputStream.readObject();
                int readUnsignedShort = objectInputStream.readUnsignedShort();
                int i3 = 0;
                if (readUnsignedShort == 0) {
                    i3 = objectInputStream.readUnsignedShort();
                    i2 = objectInputStream.readUnsignedShort();
                } else {
                    i2 = 0;
                }
                if (i3 == 0) {
                    str = readObjectV0(objectInputStream, readUnsignedShort);
                    objectInputStream.readBoolean();
                } else if (i3 != 1) {
                    StringBuffer stringBuffer = new StringBuffer();
                    stringBuffer.append("Deserialization error: version number ");
                    stringBuffer.append(i3);
                    stringBuffer.append(".");
                    stringBuffer.append(i2);
                    stringBuffer.append(" not supported.");
                    throw new IOException(stringBuffer.toString());
                } else if (i2 == 1) {
                    str = (String) objectInputStream.readObject();
                    objectInputStream.readBoolean();
                } else {
                    StringBuffer stringBuffer2 = new StringBuffer();
                    stringBuffer2.append("Deserialization error: version number ");
                    stringBuffer2.append(i3);
                    stringBuffer2.append(".");
                    stringBuffer2.append(i2);
                    stringBuffer2.append(" not supported.");
                    throw new IOException(stringBuffer2.toString());
                }
                this._impl = XmlBeans.getContextTypeLoader().parse(str, (SchemaType) null, new XmlOptions().setDocumentType(XmlBeans.typeForClass(this._xbeanClass)));
            } catch (Exception e2) {
                throw ((IOException) new IOException(e2.getMessage()).initCause(e2));
            }
        }

        /* JADX WARNING: Removed duplicated region for block: B:17:0x003f  */
        private String readObjectV0(ObjectInputStream objectInputStream, int i2) {
            DataInputStream dataInputStream;
            Throwable th;
            byte[] bArr = new byte[(i2 + 2)];
            int i3 = 0;
            bArr[0] = (byte) ((i2 >> 8) & 255);
            bArr[1] = (byte) (i2 & 255);
            while (i3 < i2) {
                int read = objectInputStream.read(bArr, i3 + 2, i2 - i3);
                if (read == -1) {
                    break;
                }
                i3 += read;
            }
            if (i3 == i2) {
                try {
                    dataInputStream = new DataInputStream(new ByteArrayInputStream(bArr));
                    try {
                        String readUTF = dataInputStream.readUTF();
                        dataInputStream.close();
                        return readUTF;
                    } catch (Throwable th2) {
                        th = th2;
                        if (dataInputStream != null) {
                            dataInputStream.close();
                        }
                        throw th;
                    }
                } catch (Throwable th3) {
                    dataInputStream = null;
                    th = th3;
                    if (dataInputStream != null) {
                    }
                    throw th;
                }
            } else {
                StringBuffer stringBuffer = new StringBuffer();
                stringBuffer.append("Error reading backwards compatible XmlObject: number of bytes read (");
                stringBuffer.append(i3);
                stringBuffer.append(") != number expected (");
                stringBuffer.append(i2);
                stringBuffer.append(")");
                throw new IOException(stringBuffer.toString());
            }
        }

        private Object readResolve() {
            return this._impl;
        }

        private void writeObject(ObjectOutputStream objectOutputStream) {
            objectOutputStream.writeObject(this._xbeanClass);
            objectOutputStream.writeShort(0);
            objectOutputStream.writeShort(1);
            objectOutputStream.writeShort(1);
            objectOutputStream.writeObject(this._impl.xmlText());
            objectOutputStream.writeBoolean(false);
        }

        public SerializedRootObject() {
        }

        public SerializedRootObject(XmlObject xmlObject) {
            this._xbeanClass = xmlObject.schemaType().getJavaClass();
            this._impl = xmlObject;
        }
    }

    public static final class ValueOutOfRangeValidationContext implements ValidationContext {
        public ValueOutOfRangeValidationContext() {
        }

        @Override // org.apache.xmlbeans.impl.common.ValidationContext
        public void invalid(String str) {
            throw new XmlValueOutOfRangeException(str);
        }

        @Override // org.apache.xmlbeans.impl.common.ValidationContext
        public void invalid(String str, Object[] objArr) {
            throw new XmlValueOutOfRangeException(str, objArr);
        }
    }

    static {
        Class cls = class$org$apache$xmlbeans$impl$values$XmlObjectBase;
        if (cls == null) {
            cls = class$("org.apache.xmlbeans.impl.values.XmlObjectBase");
            class$org$apache$xmlbeans$impl$values$XmlObjectBase = cls;
        }
        $assertionsDisabled = !cls.desiredAssertionStatus();
    }

    public static XmlObject[] _typedArray(XmlObject[] xmlObjectArr) {
        if (xmlObjectArr.length == 0) {
            return xmlObjectArr;
        }
        SchemaType schemaType = xmlObjectArr[0].schemaType();
        if (schemaType.equals(XmlObject.type) || schemaType.isNoType()) {
            return xmlObjectArr;
        }
        for (int i2 = 1; i2 < xmlObjectArr.length; i2++) {
            if (xmlObjectArr[i2].schemaType().isNoType()) {
                return xmlObjectArr;
            }
            schemaType = schemaType.getCommonBaseType(xmlObjectArr[i2].schemaType());
            if (schemaType.equals(XmlObject.type)) {
                return xmlObjectArr;
            }
        }
        Class javaClass = schemaType.getJavaClass();
        while (javaClass == null) {
            schemaType = schemaType.getBaseType();
            if (XmlObject.type.equals(schemaType)) {
                return xmlObjectArr;
            }
            javaClass = schemaType.getJavaClass();
        }
        XmlObject[] xmlObjectArr2 = (XmlObject[]) Array.newInstance(javaClass, xmlObjectArr.length);
        System.arraycopy(xmlObjectArr, 0, xmlObjectArr2, 0, xmlObjectArr.length);
        return xmlObjectArr2;
    }

    private final String apply_wscanon(String str) {
        return XmlWhitespace.collapse(str, get_wscanon_rule());
    }

    public static final XmlOptions buildInnerPrettyOptions() {
        XmlOptions xmlOptions = new XmlOptions();
        xmlOptions.put(XmlOptions.SAVE_INNER);
        xmlOptions.put(XmlOptions.SAVE_PRETTY_PRINT);
        xmlOptions.put(XmlOptions.SAVE_AGGRESSIVE_NAMESPACES);
        xmlOptions.put(XmlOptions.SAVE_USE_DEFAULT_NAMESPACE);
        return xmlOptions;
    }

    private final void check_element_dated() {
        int i2 = this._flags;
        if ((i2 & 512) != 0 && (i2 & 32768) == 0) {
            if ((i2 & 2048) == 0) {
                int compute_flags = get_store().compute_flags();
                int i3 = this._flags & -520;
                this._flags = i3;
                this._flags = compute_flags | i3;
            } else {
                throw new XmlValueDisconnectedException();
            }
        }
        int i4 = this._flags;
        if ((i4 & 32768) != 0) {
            this._flags = i4 & -513;
        }
    }

    public static /* synthetic */ Class class$(String str) {
        try {
            return Class.forName(str);
        } catch (ClassNotFoundException e2) {
            throw a.a(e2);
        }
    }

    private final boolean comparable_value_spaces(SchemaType schemaType, SchemaType schemaType2) {
        if (!$assertionsDisabled && (schemaType.getSimpleVariety() == 2 || schemaType2.getSimpleVariety() == 2)) {
            throw new AssertionError();
        } else if (schemaType.isSimpleType() || schemaType2.isSimpleType()) {
            if (schemaType.isSimpleType() && schemaType2.isSimpleType()) {
                if (schemaType.getSimpleVariety() == 3 && schemaType2.getSimpleVariety() == 3) {
                    return true;
                }
                if (!(schemaType.getSimpleVariety() == 3 || schemaType2.getSimpleVariety() == 3)) {
                    return schemaType.getPrimitiveType().equals(schemaType2.getPrimitiveType());
                }
            }
            return false;
        } else if (schemaType.getContentType() == schemaType2.getContentType()) {
            return true;
        } else {
            return false;
        }
    }

    private final int compareValueImpl(XmlObject xmlObject) {
        try {
            SchemaType instanceType = instanceType();
            SchemaType instanceType2 = ((SimpleValue) xmlObject).instanceType();
            if (instanceType == null && instanceType2 == null) {
                return 0;
            }
            if (instanceType != null && instanceType2 != null && instanceType.isSimpleType() && !instanceType.isURType() && instanceType2.isSimpleType() && !instanceType2.isURType()) {
                if (instanceType.getPrimitiveType().getBuiltinTypeCode() != instanceType2.getPrimitiveType().getBuiltinTypeCode()) {
                    return 2;
                }
                return compare_to(xmlObject);
            }
            return 2;
        } catch (XmlValueOutOfRangeException unused) {
        }
    }

    private XmlObject ensureStore() {
        String str;
        if ((this._flags & 16) != 0) {
            return this;
        }
        check_dated();
        if ((this._flags & 64) != 0) {
            str = "";
        } else {
            str = compute_text(has_store() ? get_store() : null);
        }
        XmlObject newInstance = XmlObject.Factory.newInstance(new XmlOptions().setDocumentType(schemaType()));
        XmlCursor newCursor = newInstance.newCursor();
        newCursor.toNextToken();
        newCursor.insertChars(str);
        return newInstance;
    }

    private final String getPrimitiveTypeName() {
        SchemaType schemaType = schemaType();
        if (schemaType.isNoType()) {
            return "unknown";
        }
        SchemaType primitiveType = schemaType.getPrimitiveType();
        if (primitiveType == null) {
            return "complex";
        }
        return primitiveType.getName().getLocalPart();
    }

    private XmlObject getRootXmlObject() {
        XmlCursor newCursor = newCursor();
        if (newCursor == null) {
            return this;
        }
        newCursor.toStartDoc();
        XmlObject object = newCursor.getObject();
        newCursor.dispose();
        return object;
    }

    private XmlObjectBase getTargetForSetter(QName qName, int i2, short s) {
        if (s == 1) {
            check_orphaned();
            XmlObjectBase xmlObjectBase = (XmlObjectBase) get_store().find_element_user(qName, i2);
            if (xmlObjectBase == null) {
                xmlObjectBase = (XmlObjectBase) get_store().add_element_user(qName);
            }
            if (!xmlObjectBase.isImmutable()) {
                return xmlObjectBase;
            }
            throw new IllegalStateException("Cannot set the value of an immutable XmlObject");
        } else if (s == 2) {
            check_orphaned();
            XmlObjectBase xmlObjectBase2 = (XmlObjectBase) get_store().find_element_user(qName, i2);
            if (xmlObjectBase2 == null) {
                throw new IndexOutOfBoundsException();
            } else if (!xmlObjectBase2.isImmutable()) {
                return xmlObjectBase2;
            } else {
                throw new IllegalStateException("Cannot set the value of an immutable XmlObject");
            }
        } else {
            throw new IllegalArgumentException(a.b("Unknown kindSetterHelper: ", s));
        }
    }

    private boolean isRootXmlObject() {
        XmlCursor newCursor = newCursor();
        if (newCursor == null) {
            return false;
        }
        boolean z = !newCursor.toParent();
        newCursor.dispose();
        return z;
    }

    /* JADX INFO: Can't fix incorrect switch cases order, some code will duplicate */
    public static Object java_value(XmlObject xmlObject) {
        if (xmlObject.isNil()) {
            return null;
        }
        if (!(xmlObject instanceof XmlAnySimpleType)) {
            return xmlObject;
        }
        SimpleValue simpleValue = (SimpleValue) xmlObject;
        SchemaType instanceType = simpleValue.instanceType();
        if (!$assertionsDisabled && instanceType == null) {
            throw new AssertionError("Nil case should have been handled above");
        } else if (instanceType.getSimpleVariety() == 3) {
            return simpleValue.getListValue();
        } else {
            switch (instanceType.getPrimitiveType().getBuiltinTypeCode()) {
                case 2:
                case 8:
                case 12:
                    break;
                case 3:
                    return simpleValue.getBooleanValue() ? Boolean.TRUE : Boolean.FALSE;
                case 4:
                case 5:
                    return simpleValue.getByteArrayValue();
                case 6:
                    return simpleValue.getStringValue();
                case 7:
                    return simpleValue.getQNameValue();
                case 9:
                    return new Float(simpleValue.getFloatValue());
                case 10:
                    return new Double(simpleValue.getDoubleValue());
                case 11:
                    int decimalSize = instanceType.getDecimalSize();
                    if (decimalSize == 8) {
                        return new Byte(simpleValue.getByteValue());
                    }
                    if (decimalSize == 16) {
                        return new Short(simpleValue.getShortValue());
                    }
                    if (decimalSize == 32) {
                        return new Integer(simpleValue.getIntValue());
                    }
                    if (decimalSize == 64) {
                        return new Long(simpleValue.getLongValue());
                    }
                    switch (decimalSize) {
                        case 1000000:
                            return simpleValue.getBigIntegerValue();
                        case SchemaType.SIZE_BIG_DECIMAL:
                            break;
                        default:
                            if (!$assertionsDisabled) {
                                throw new AssertionError("invalid numeric bit count");
                            }
                            break;
                    }
                    return simpleValue.getBigDecimalValue();
                case 13:
                    return simpleValue.getGDurationValue();
                case 14:
                case 15:
                case 16:
                case 17:
                case 18:
                case 19:
                case 20:
                case 21:
                    return simpleValue.getCalendarValue();
                default:
                    if (!$assertionsDisabled) {
                        throw new AssertionError("encountered nonprimitive type.");
                    }
                    break;
            }
            return simpleValue.getStringValue();
        }
    }

    public static XmlOptions makeInnerOptions(XmlOptions xmlOptions) {
        XmlOptions xmlOptions2 = new XmlOptions(xmlOptions);
        xmlOptions2.put(XmlOptions.SAVE_INNER);
        return xmlOptions2;
    }

    private TypeStoreUser objSetterHelper(XmlObjectBase xmlObjectBase, QName qName, int i2, short s) {
        XmlObjectBase targetForSetter = getTargetForSetter(qName, i2, s);
        targetForSetter.check_orphaned();
        xmlObjectBase.check_orphaned();
        return targetForSetter.get_store().copy_contents_from(xmlObjectBase.get_store()).get_store().change_type(xmlObjectBase.schemaType());
    }

    private boolean preCheck() {
        if (has_store()) {
            return get_store().get_locale().noSync();
        }
        return false;
    }

    private SchemaField schemaField() {
        SchemaField containerField = schemaType().getContainerField();
        return containerField == null ? get_store().get_schema_field() : containerField;
    }

    private final void set_commit() {
        boolean z = (this._flags & 64) != 0;
        int i2 = this._flags & -321;
        this._flags = i2;
        if ((i2 & 16) != 0) {
            this._flags = i2 & -673;
            get_store().invalidate_text();
            if (z) {
                get_store().invalidate_nil();
                return;
            }
            return;
        }
        this._textsource = null;
    }

    private final void set_prepare() {
        check_element_dated();
        if ((this._flags & 4096) != 0) {
            throw new IllegalStateException();
        }
    }

    private TypeStoreUser setterHelper(XmlObjectBase xmlObjectBase) {
        check_orphaned();
        xmlObjectBase.check_orphaned();
        return get_store().copy_contents_from(xmlObjectBase.get_store()).get_store().change_type(xmlObjectBase.schemaType());
    }

    public static XmlObjectBase underlying(XmlObject xmlObject) {
        if (xmlObject == null) {
            return null;
        }
        if (xmlObject instanceof XmlObjectBase) {
            return (XmlObjectBase) xmlObject;
        }
        while (xmlObject instanceof DelegateXmlObject) {
            xmlObject = ((DelegateXmlObject) xmlObject).underlyingXmlObject();
        }
        if (xmlObject instanceof XmlObjectBase) {
            return (XmlObjectBase) xmlObject;
        }
        throw new IllegalStateException("Non-native implementations of XmlObject should extend FilterXmlObject or implement DelegateXmlObject");
    }

    /* JADX INFO: finally extract failed */
    private final void update_from_wscanon_text(String str) {
        int i2 = this._flags;
        if ((i2 & 2) == 0 || (i2 & 1024) != 0 || (i2 & 8) != 0 || !str.equals("")) {
            set_text(str);
            this._flags &= -321;
            return;
        }
        String compute_default_text = get_store().compute_default_text();
        if (compute_default_text != null) {
            this._flags |= 1024;
            try {
                setStringValue(compute_default_text);
                int i3 = this._flags & -1025;
                this._flags = i3;
                int i4 = i3 & -65;
                this._flags = i4;
                this._flags = i4 | 256;
            } catch (Throwable th) {
                this._flags &= -1025;
                throw th;
            }
        } else {
            throw new XmlValueOutOfRangeException();
        }
    }

    private boolean validate_immutable(XmlOptions xmlOptions) {
        XmlErrorWatcher xmlErrorWatcher = new XmlErrorWatcher(xmlOptions == null ? null : (Collection) xmlOptions.get(XmlOptions.ERROR_LISTENER));
        if (!schemaType().isSimpleType() && (xmlOptions == null || !xmlOptions.hasOption(XmlOptions.VALIDATE_TEXT_ONLY))) {
            SchemaProperty[] properties = schemaType().getProperties();
            for (int i2 = 0; i2 < properties.length; i2++) {
                if (properties[i2].getMinOccurs().signum() > 0) {
                    if (properties[i2].isAttribute()) {
                        xmlErrorWatcher.add(XmlError.forObject(XmlErrorCodes.ELEM_COMPLEX_TYPE_LOCALLY_VALID$MISSING_REQUIRED_ATTRIBUTE, new Object[]{QNameHelper.pretty(properties[i2].getName())}, this));
                    } else {
                        xmlErrorWatcher.add(XmlError.forObject(XmlErrorCodes.ELEM_COMPLEX_TYPE_LOCALLY_VALID$MISSING_ELEMENT, new Object[]{properties[i2].getMinOccurs(), QNameHelper.pretty(properties[i2].getName())}, this));
                    }
                }
            }
            if (schemaType().getContentType() != 2) {
                return !xmlErrorWatcher.hasError();
            }
        }
        String str = (String) this._textsource;
        if (str == null) {
            str = "";
        }
        validate_simpleval(str, new ImmutableValueValidationContext(xmlErrorWatcher, this));
        return !xmlErrorWatcher.hasError();
    }

    private final boolean valueEqualsImpl(XmlObject xmlObject) {
        check_dated();
        SchemaType instanceType = instanceType();
        SchemaType instanceType2 = ((SimpleValue) xmlObject).instanceType();
        if (instanceType == null && instanceType2 == null) {
            return true;
        }
        if (instanceType == null || instanceType2 == null || !comparable_value_spaces(instanceType, instanceType2)) {
            return false;
        }
        if (xmlObject.schemaType().getSimpleVariety() == 2) {
            return underlying(xmlObject).equal_to(this);
        }
        return equal_to(xmlObject);
    }

    public final XmlObject _copy() {
        return _copy(null);
    }

    public boolean _isComplexContent() {
        return (this._flags & 16384) != 0;
    }

    public boolean _isComplexType() {
        return (this._flags & 8192) != 0;
    }

    public final XmlObject _set(XmlObject xmlObject) {
        TypeStoreUser typeStoreUser;
        if (!isImmutable()) {
            XmlObjectBase underlying = underlying(xmlObject);
            if (underlying == null) {
                setNil();
                return this;
            }
            if (underlying.isImmutable()) {
                set(underlying.stringValue());
                typeStoreUser = this;
            } else {
                check_orphaned();
                underlying.check_orphaned();
                typeStoreUser = get_store().copy_contents_from(underlying.get_store()).get_store().change_type(underlying.schemaType());
            }
            return (XmlObject) typeStoreUser;
        }
        throw new IllegalStateException("Cannot set the value of an immutable XmlObject");
    }

    public boolean _validateOnSet() {
        return (this._flags & 65536) != 0;
    }

    @Override // org.apache.xmlbeans.impl.values.TypeStoreUser
    public final void attach_store(TypeStore typeStore) {
        this._textsource = typeStore;
        int i2 = this._flags;
        if ((i2 & 4096) == 0) {
            this._flags = i2 | 688;
            if (typeStore.is_attribute()) {
                this._flags |= 8;
            }
            if (typeStore.validate_on_set()) {
                this._flags |= 65536;
                return;
            }
            return;
        }
        throw new IllegalStateException();
    }

    @Override // org.apache.xmlbeans.SimpleValue
    public BigDecimal bigDecimalValue() {
        return getBigDecimalValue();
    }

    @Override // org.apache.xmlbeans.SimpleValue
    public BigInteger bigIntegerValue() {
        return getBigIntegerValue();
    }

    @Override // org.apache.xmlbeans.SimpleValue
    public boolean booleanValue() {
        return getBooleanValue();
    }

    @Override // org.apache.xmlbeans.impl.values.TypeStoreUser
    public boolean build_nil() {
        if (!$assertionsDisabled && (this._flags & 16) == 0) {
            throw new AssertionError();
        } else if ($assertionsDisabled || (this._flags & 32) == 0) {
            return (this._flags & 64) != 0;
        } else {
            throw new AssertionError();
        }
    }

    @Override // org.apache.xmlbeans.impl.values.TypeStoreUser
    public final String build_text(NamespaceManager namespaceManager) {
        if (!$assertionsDisabled && (this._flags & 16) == 0) {
            throw new AssertionError();
        } else if (!$assertionsDisabled && (this._flags & 32) != 0) {
            throw new AssertionError();
        } else if ((this._flags & 320) != 0) {
            return "";
        } else {
            if (namespaceManager == null) {
                namespaceManager = has_store() ? get_store() : null;
            }
            return compute_text(namespaceManager);
        }
    }

    @Override // org.apache.xmlbeans.SimpleValue
    public byte[] byteArrayValue() {
        return getByteArrayValue();
    }

    @Override // org.apache.xmlbeans.SimpleValue
    public byte byteValue() {
        return getByteValue();
    }

    @Override // org.apache.xmlbeans.SimpleValue
    public Calendar calendarValue() {
        return getCalendarValue();
    }

    @Override // org.apache.xmlbeans.XmlObject
    public XmlObject changeType(SchemaType schemaType) {
        XmlObject xmlObject;
        if (schemaType == null) {
            throw new IllegalArgumentException("Invalid type (null)");
        } else if ((this._flags & 16) != 0) {
            synchronized (monitor()) {
                check_orphaned();
                xmlObject = (XmlObject) get_store().change_type(schemaType);
            }
            return xmlObject;
        } else {
            throw new IllegalStateException("XML Value Objects cannot have thier type changed");
        }
    }

    public final void check_dated() {
        String str;
        int i2 = this._flags;
        if ((i2 & FLAGS_DATED) == 0) {
            return;
        }
        if ((i2 & 2048) != 0) {
            throw new XmlValueDisconnectedException();
        } else if ($assertionsDisabled || (i2 & 16) != 0) {
            check_element_dated();
            if ((this._flags & 512) != 0) {
                int compute_flags = get_store().compute_flags();
                int i3 = this._flags & -520;
                this._flags = i3;
                this._flags = compute_flags | i3;
            }
            boolean z = false;
            if ((this._flags & 128) != 0) {
                if (get_store().find_nil()) {
                    int i4 = this._flags;
                    if ((i4 & 1) != 0 || (i4 & 65536) == 0) {
                        set_nil();
                        this._flags |= 64;
                        z = true;
                    } else {
                        throw new XmlValueOutOfRangeException();
                    }
                } else {
                    this._flags &= -65;
                }
                this._flags &= -129;
            }
            if (!z) {
                if ((this._flags & 16384) != 0 || (str = get_wscanon_text()) == null) {
                    update_from_complex_content();
                } else {
                    NamespaceContext.push(new NamespaceContext(get_store()));
                    try {
                        update_from_wscanon_text(str);
                    } finally {
                        NamespaceContext.pop();
                    }
                }
            }
            this._flags &= -33;
        } else {
            throw new AssertionError();
        }
    }

    public final void check_orphaned() {
        if (is_orphaned()) {
            throw new XmlValueDisconnectedException();
        }
    }

    @Override // org.apache.xmlbeans.XmlObject
    public final int compareTo(Object obj) {
        int compareValue = compareValue((XmlObject) obj);
        if (compareValue != 2) {
            return compareValue;
        }
        throw new ClassCastException();
    }

    /* JADX WARNING: Removed duplicated region for block: B:67:0x0078  */
    @Override // org.apache.xmlbeans.XmlObject
    public final int compareValue(XmlObject xmlObject) {
        Throwable th;
        InterruptedException e2;
        int compareValueImpl;
        Throwable th2;
        Throwable th3;
        int compareValueImpl2;
        if (xmlObject == null) {
            return 2;
        }
        boolean z = false;
        try {
            if (isImmutable()) {
                if (xmlObject.isImmutable()) {
                    return compareValueImpl(xmlObject);
                }
                synchronized (xmlObject.monitor()) {
                    compareValueImpl2 = compareValueImpl(xmlObject);
                }
                return compareValueImpl2;
            } else if (xmlObject.isImmutable() || monitor() == xmlObject.monitor()) {
                synchronized (monitor()) {
                    compareValueImpl = compareValueImpl(xmlObject);
                }
                return compareValueImpl;
            } else {
                GlobalLock.acquire();
                try {
                    synchronized (monitor()) {
                        try {
                            synchronized (xmlObject.monitor()) {
                                try {
                                    GlobalLock.release();
                                    try {
                                        int compareValueImpl3 = compareValueImpl(xmlObject);
                                        try {
                                            return compareValueImpl3;
                                        } catch (Throwable th4) {
                                            th2 = th4;
                                            throw th2;
                                        }
                                    } catch (Throwable th5) {
                                        th3 = th5;
                                        throw th3;
                                    }
                                } catch (Throwable th6) {
                                    th3 = th6;
                                    throw th3;
                                }
                            }
                        } catch (Throwable th7) {
                            th2 = th7;
                            throw th2;
                        }
                    }
                } catch (InterruptedException e3) {
                    e2 = e3;
                    z = true;
                    try {
                        throw new XmlRuntimeException(e2);
                    } catch (Throwable th8) {
                        th = th8;
                        if (z) {
                        }
                        throw th;
                    }
                } catch (Throwable th9) {
                    th = th9;
                    z = true;
                    if (z) {
                        GlobalLock.release();
                    }
                    throw th;
                }
            }
        } catch (InterruptedException e4) {
            e2 = e4;
            throw new XmlRuntimeException(e2);
        }
    }

    public int compare_to(XmlObject xmlObject) {
        return equal_to(xmlObject) ? 0 : 2;
    }

    public abstract String compute_text(NamespaceManager namespaceManager);

    @Override // org.apache.xmlbeans.XmlObject
    public final XmlObject copy() {
        XmlObject _copy;
        if (preCheck()) {
            return _copy();
        }
        synchronized (monitor()) {
            _copy = _copy();
        }
        return _copy;
    }

    @Override // org.apache.xmlbeans.impl.values.TypeStoreUser
    public TypeStoreUser create_attribute_user(QName qName) {
        return (TypeStoreUser) ((SchemaTypeImpl) schemaType()).createAttributeType(qName, get_store().get_schematypeloader());
    }

    @Override // org.apache.xmlbeans.impl.values.TypeStoreUser
    public TypeStoreUser create_element_user(QName qName, QName qName2) {
        return (TypeStoreUser) ((SchemaTypeImpl) schemaType()).createElementType(qName, qName2, get_store().get_schematypeloader());
    }

    @Override // org.apache.xmlbeans.SimpleValue
    public Date dateValue() {
        return getDateValue();
    }

    @Override // org.apache.xmlbeans.impl.values.TypeStoreUser
    public void disconnect_store() {
        if ($assertionsDisabled || (this._flags & 16) != 0) {
            this._flags |= 2720;
            return;
        }
        throw new AssertionError();
    }

    @Override // org.apache.xmlbeans.XmlTokenSource
    public XmlDocumentProperties documentProperties() {
        XmlCursor newCursorForce = newCursorForce();
        try {
            return newCursorForce.documentProperties();
        } finally {
            newCursorForce.dispose();
        }
    }

    @Override // org.apache.xmlbeans.SimpleValue
    public double doubleValue() {
        return getDoubleValue();
    }

    @Override // org.apache.xmlbeans.XmlTokenSource
    public void dump() {
        XmlCursor newCursorForce = newCursorForce();
        try {
            newCursorForce.dump();
        } finally {
            newCursorForce.dispose();
        }
    }

    public int elementFlags() {
        check_element_dated();
        return this._flags & 7;
    }

    @Override // org.apache.xmlbeans.SimpleValue
    public StringEnumAbstractBase enumValue() {
        return getEnumValue();
    }

    public abstract boolean equal_to(XmlObject xmlObject);

    public final boolean equals(Object obj) {
        if (!isImmutable()) {
            return super.equals(obj);
        }
        if (!(obj instanceof XmlObject)) {
            return false;
        }
        XmlObject xmlObject = (XmlObject) obj;
        if (!xmlObject.isImmutable()) {
            return false;
        }
        return valueEquals(xmlObject);
    }

    @Override // org.apache.xmlbeans.XmlObject
    public XmlObject[] execQuery(String str) {
        return execQuery(str, null);
    }

    @Override // org.apache.xmlbeans.SimpleValue
    public float floatValue() {
        return getFloatValue();
    }

    @Override // org.apache.xmlbeans.SimpleValue
    public GDate gDateValue() {
        return getGDateValue();
    }

    @Override // org.apache.xmlbeans.SimpleValue
    public GDuration gDurationValue() {
        return getGDurationValue();
    }

    /* JADX WARNING: Removed duplicated region for block: B:97:0x00c2  */
    public final XmlObject generatedSetterHelperImpl(XmlObject xmlObject, QName qName, int i2, short s) {
        Throwable th;
        InterruptedException e2;
        Throwable th2;
        Throwable th3;
        XmlObject xmlObject2;
        XmlObject xmlObject3;
        XmlObject xmlObject4;
        XmlObject xmlObject5;
        XmlObjectBase targetForSetter;
        XmlObjectBase targetForSetter2;
        XmlObjectBase underlying = underlying(xmlObject);
        if (underlying == null) {
            synchronized (monitor()) {
                targetForSetter2 = getTargetForSetter(qName, i2, s);
                targetForSetter2.setNil();
            }
            return targetForSetter2;
        } else if (underlying.isImmutable()) {
            synchronized (monitor()) {
                targetForSetter = getTargetForSetter(qName, i2, s);
                targetForSetter.setStringValue(underlying.getStringValue());
            }
            return targetForSetter;
        } else {
            boolean preCheck = preCheck();
            boolean preCheck2 = underlying.preCheck();
            if (monitor() == underlying.monitor()) {
                if (preCheck) {
                    return (XmlObject) objSetterHelper(underlying, qName, i2, s);
                }
                synchronized (monitor()) {
                    xmlObject5 = (XmlObject) objSetterHelper(underlying, qName, i2, s);
                }
                return xmlObject5;
            } else if (preCheck) {
                if (preCheck2) {
                    return (XmlObject) objSetterHelper(underlying, qName, i2, s);
                }
                synchronized (underlying.monitor()) {
                    xmlObject4 = (XmlObject) objSetterHelper(underlying, qName, i2, s);
                }
                return xmlObject4;
            } else if (preCheck2) {
                synchronized (monitor()) {
                    xmlObject3 = (XmlObject) objSetterHelper(underlying, qName, i2, s);
                }
                return xmlObject3;
            } else {
                boolean z = false;
                try {
                    GlobalLock.acquire();
                    try {
                        synchronized (monitor()) {
                            try {
                                synchronized (underlying.monitor()) {
                                    try {
                                        GlobalLock.release();
                                        try {
                                            xmlObject2 = (XmlObject) objSetterHelper(underlying, qName, i2, s);
                                        } catch (Throwable th4) {
                                            th3 = th4;
                                            throw th3;
                                        }
                                    } catch (Throwable th5) {
                                        th3 = th5;
                                        throw th3;
                                    }
                                    try {
                                        return xmlObject2;
                                    } catch (Throwable th6) {
                                        th2 = th6;
                                        throw th2;
                                    }
                                }
                            } catch (Throwable th7) {
                                th2 = th7;
                                throw th2;
                            }
                        }
                    } catch (InterruptedException e3) {
                        e2 = e3;
                        z = true;
                        try {
                            throw new XmlRuntimeException(e2);
                        } catch (Throwable th8) {
                            th = th8;
                            if (z) {
                            }
                            throw th;
                        }
                    } catch (Throwable th9) {
                        th = th9;
                        z = true;
                        if (z) {
                            GlobalLock.release();
                        }
                        throw th;
                    }
                } catch (InterruptedException e4) {
                    e2 = e4;
                    throw new XmlRuntimeException(e2);
                }
            }
        }
    }

    @Override // org.apache.xmlbeans.SimpleValue
    public BigDecimal getBigDecimalValue() {
        throw new XmlValueNotSupportedException(XmlErrorCodes.EXCEPTION_VALUE_NOT_SUPPORTED_S2J, new Object[]{getPrimitiveTypeName(), "numeric"});
    }

    @Override // org.apache.xmlbeans.SimpleValue
    public BigInteger getBigIntegerValue() {
        BigDecimal bigDecimalValue = bigDecimalValue();
        if (bigDecimalValue == null) {
            return null;
        }
        return bigDecimalValue.toBigInteger();
    }

    @Override // org.apache.xmlbeans.SimpleValue
    public boolean getBooleanValue() {
        throw new XmlValueNotSupportedException(XmlErrorCodes.EXCEPTION_VALUE_NOT_SUPPORTED_S2J, new Object[]{getPrimitiveTypeName(), "boolean"});
    }

    @Override // org.apache.xmlbeans.SimpleValue
    public byte[] getByteArrayValue() {
        throw new XmlValueNotSupportedException(XmlErrorCodes.EXCEPTION_VALUE_NOT_SUPPORTED_S2J, new Object[]{getPrimitiveTypeName(), "byte[]"});
    }

    @Override // org.apache.xmlbeans.SimpleValue
    public byte getByteValue() {
        long intValue = (long) getIntValue();
        if (intValue > 127) {
            throw new XmlValueOutOfRangeException();
        } else if (intValue >= -128) {
            return (byte) ((int) intValue);
        } else {
            throw new XmlValueOutOfRangeException();
        }
    }

    @Override // org.apache.xmlbeans.SimpleValue
    public Calendar getCalendarValue() {
        throw new XmlValueNotSupportedException(XmlErrorCodes.EXCEPTION_VALUE_NOT_SUPPORTED_S2J, new Object[]{getPrimitiveTypeName(), "Calendar"});
    }

    @Override // org.apache.xmlbeans.SimpleValue
    public Date getDateValue() {
        throw new XmlValueNotSupportedException(XmlErrorCodes.EXCEPTION_VALUE_NOT_SUPPORTED_S2J, new Object[]{getPrimitiveTypeName(), "Date"});
    }

    @Override // org.apache.xmlbeans.XmlTokenSource
    public Node getDomNode() {
        XmlCursor newCursorForce = newCursorForce();
        try {
            return newCursorForce.getDomNode();
        } finally {
            newCursorForce.dispose();
        }
    }

    @Override // org.apache.xmlbeans.SimpleValue
    public double getDoubleValue() {
        BigDecimal bigDecimalValue = getBigDecimalValue();
        return bigDecimalValue == null ? NumericFunction.LOG_10_TO_BASE_e : bigDecimalValue.doubleValue();
    }

    @Override // org.apache.xmlbeans.SimpleValue
    public StringEnumAbstractBase getEnumValue() {
        throw new XmlValueNotSupportedException(XmlErrorCodes.EXCEPTION_VALUE_NOT_SUPPORTED_S2J, new Object[]{getPrimitiveTypeName(), "enum"});
    }

    @Override // org.apache.xmlbeans.SimpleValue
    public float getFloatValue() {
        BigDecimal bigDecimalValue = getBigDecimalValue();
        if (bigDecimalValue == null) {
            return 0.0f;
        }
        return bigDecimalValue.floatValue();
    }

    @Override // org.apache.xmlbeans.SimpleValue
    public GDate getGDateValue() {
        throw new XmlValueNotSupportedException(XmlErrorCodes.EXCEPTION_VALUE_NOT_SUPPORTED_S2J, new Object[]{getPrimitiveTypeName(), "Date"});
    }

    @Override // org.apache.xmlbeans.SimpleValue
    public GDuration getGDurationValue() {
        throw new XmlValueNotSupportedException(XmlErrorCodes.EXCEPTION_VALUE_NOT_SUPPORTED_S2J, new Object[]{getPrimitiveTypeName(), "Duration"});
    }

    @Override // org.apache.xmlbeans.SimpleValue
    public int getIntValue() {
        long longValue = getLongValue();
        if (longValue > 2147483647L) {
            throw new XmlValueOutOfRangeException();
        } else if (longValue >= -2147483648L) {
            return (int) longValue;
        } else {
            throw new XmlValueOutOfRangeException();
        }
    }

    @Override // org.apache.xmlbeans.SimpleValue
    public List getListValue() {
        throw new XmlValueNotSupportedException(XmlErrorCodes.EXCEPTION_VALUE_NOT_SUPPORTED_S2J, new Object[]{getPrimitiveTypeName(), "List"});
    }

    @Override // org.apache.xmlbeans.SimpleValue
    public long getLongValue() {
        BigInteger bigIntegerValue = getBigIntegerValue();
        if (bigIntegerValue == null) {
            return 0;
        }
        if (bigIntegerValue.compareTo(_max) >= 0) {
            throw new XmlValueOutOfRangeException();
        } else if (bigIntegerValue.compareTo(_min) > 0) {
            return bigIntegerValue.longValue();
        } else {
            throw new XmlValueOutOfRangeException();
        }
    }

    @Override // org.apache.xmlbeans.SimpleValue
    public Object getObjectValue() {
        return java_value(this);
    }

    @Override // org.apache.xmlbeans.SimpleValue
    public QName getQNameValue() {
        throw new XmlValueNotSupportedException(XmlErrorCodes.EXCEPTION_VALUE_NOT_SUPPORTED_S2J, new Object[]{getPrimitiveTypeName(), "QName"});
    }

    @Override // org.apache.xmlbeans.SimpleValue
    public short getShortValue() {
        long intValue = (long) getIntValue();
        if (intValue > 32767) {
            throw new XmlValueOutOfRangeException();
        } else if (intValue >= -32768) {
            return (short) ((int) intValue);
        } else {
            throw new XmlValueOutOfRangeException();
        }
    }

    @Override // org.apache.xmlbeans.SimpleValue
    public String getStringValue() {
        TypeStore typeStore = null;
        if (!isImmutable()) {
            synchronized (monitor()) {
                if (_isComplexContent()) {
                    return get_store().fetch_text(1);
                }
                check_dated();
                if ((this._flags & 64) != 0) {
                    return null;
                }
                if (has_store()) {
                    typeStore = get_store();
                }
                return compute_text(typeStore);
            }
        } else if ((this._flags & 64) != 0) {
            return null;
        } else {
            return compute_text(null);
        }
    }

    public final XmlLocale getXmlLocale() {
        return get_store().get_locale();
    }

    @Override // org.apache.xmlbeans.impl.values.TypeStoreUser
    public SchemaField get_attribute_field(QName qName) {
        SchemaAttributeModel attributeModel = schemaType().getAttributeModel();
        if (attributeModel == null) {
            return null;
        }
        return attributeModel.getAttribute(qName);
    }

    @Override // org.apache.xmlbeans.impl.values.TypeStoreUser
    public SchemaType get_attribute_type(QName qName) {
        return schemaType().getAttributeType(qName, get_store().get_schematypeloader());
    }

    @Override // org.apache.xmlbeans.impl.values.TypeStoreUser
    public int get_attributeflags(QName qName) {
        SchemaProperty attributeProperty;
        int i2 = 0;
        if (!_isComplexType() || (attributeProperty = schemaType().getAttributeProperty(qName)) == null) {
            return 0;
        }
        int i3 = attributeProperty.hasDefault() == 0 ? 0 : 2;
        if (attributeProperty.hasFixed() != 0) {
            i2 = 4;
        }
        return i3 | i2;
    }

    @Override // org.apache.xmlbeans.impl.values.TypeStoreUser
    public String get_default_attribute_text(QName qName) {
        if (!$assertionsDisabled && !_isComplexType()) {
            throw new AssertionError();
        } else if (_isComplexType()) {
            SchemaProperty attributeProperty = schemaType().getAttributeProperty(qName);
            if (attributeProperty == null) {
                return "";
            }
            return attributeProperty.getDefaultText();
        } else {
            throw new IllegalStateException();
        }
    }

    public XmlAnySimpleType get_default_attribute_value(QName qName) {
        SchemaLocalAttribute attribute;
        SchemaAttributeModel attributeModel = schemaType().getAttributeModel();
        if (attributeModel == null || (attribute = attributeModel.getAttribute(qName)) == null) {
            return null;
        }
        return attribute.getDefaultValue();
    }

    @Override // org.apache.xmlbeans.impl.values.TypeStoreUser
    public String get_default_element_text(QName qName) {
        if (!$assertionsDisabled && !_isComplexContent()) {
            throw new AssertionError();
        } else if (_isComplexContent()) {
            SchemaProperty elementProperty = schemaType().getElementProperty(qName);
            if (elementProperty == null) {
                return "";
            }
            return elementProperty.getDefaultText();
        } else {
            throw new IllegalStateException();
        }
    }

    @Override // org.apache.xmlbeans.impl.values.TypeStoreUser
    public final QNameSet get_element_ending_delimiters(QName qName) {
        SchemaProperty elementProperty = schemaType().getElementProperty(qName);
        if (elementProperty == null) {
            return null;
        }
        return elementProperty.getJavaSetterDelimiter();
    }

    @Override // org.apache.xmlbeans.impl.values.TypeStoreUser
    public SchemaType get_element_type(QName qName, QName qName2) {
        return schemaType().getElementType(qName, qName2, get_store().get_schematypeloader());
    }

    @Override // org.apache.xmlbeans.impl.values.TypeStoreUser
    public int get_elementflags(QName qName) {
        SchemaProperty elementProperty;
        int i2 = 0;
        if (!_isComplexContent() || (elementProperty = schemaType().getElementProperty(qName)) == null) {
            return 0;
        }
        if (elementProperty.hasDefault() == 1 || elementProperty.hasFixed() == 1 || elementProperty.hasNillable() == 1) {
            return -1;
        }
        int i3 = (elementProperty.hasDefault() == 0 ? 0 : 2) | (elementProperty.hasFixed() == 0 ? 0 : 4);
        if (elementProperty.hasNillable() != 0) {
            i2 = 1;
        }
        return i3 | i2;
    }

    @Override // org.apache.xmlbeans.impl.values.TypeStoreUser
    public SchemaType get_schema_type() {
        return schemaType();
    }

    @Override // org.apache.xmlbeans.impl.values.TypeStoreUser
    public final TypeStore get_store() {
        if ($assertionsDisabled || (this._flags & 16) != 0) {
            return (TypeStore) this._textsource;
        }
        throw new AssertionError();
    }

    public int get_wscanon_rule() {
        return 3;
    }

    public final String get_wscanon_text() {
        if ((this._flags & 16) == 0) {
            return apply_wscanon((String) this._textsource);
        }
        return get_store().fetch_text(get_wscanon_rule());
    }

    public final boolean has_store() {
        return (this._flags & 16) != 0;
    }

    public final int hashCode() {
        if (!isImmutable()) {
            return super.hashCode();
        }
        synchronized (monitor()) {
            if (isNil()) {
                return 0;
            }
            return value_hash_code();
        }
    }

    public void initComplexType(boolean z, boolean z2) {
        int i2 = this._flags;
        int i3 = 0;
        int i4 = z ? 8192 : 0;
        if (z2) {
            i3 = 16384;
        }
        this._flags = i4 | i3 | i2;
    }

    public void init_flags(SchemaProperty schemaProperty) {
        if (schemaProperty != null) {
            int i2 = 1;
            if (schemaProperty.hasDefault() != 1 && schemaProperty.hasFixed() != 1 && schemaProperty.hasNillable() != 1) {
                int i3 = this._flags & -8;
                this._flags = i3;
                int i4 = (schemaProperty.hasDefault() == 0 ? 0 : 2) | (schemaProperty.hasFixed() == 0 ? 0 : 4);
                if (schemaProperty.hasNillable() == 0) {
                    i2 = 0;
                }
                this._flags = i4 | i2 | 32768 | i3;
            }
        }
    }

    @Override // org.apache.xmlbeans.SimpleValue
    public SchemaType instanceType() {
        SchemaType schemaType;
        synchronized (monitor()) {
            schemaType = isNil() ? null : schemaType();
        }
        return schemaType;
    }

    @Override // org.apache.xmlbeans.SimpleValue
    public int intValue() {
        return getIntValue();
    }

    @Override // org.apache.xmlbeans.impl.values.TypeStoreUser
    public final void invalidate_element_order() {
        if ($assertionsDisabled || (this._flags & 16) != 0) {
            this._flags |= FLAGS_DATED;
            return;
        }
        throw new AssertionError();
    }

    @Override // org.apache.xmlbeans.impl.values.TypeStoreUser
    public final void invalidate_nilvalue() {
        if ($assertionsDisabled || (this._flags & 16) != 0) {
            this._flags |= 160;
            return;
        }
        throw new AssertionError();
    }

    @Override // org.apache.xmlbeans.impl.values.TypeStoreUser
    public final void invalidate_value() {
        if ($assertionsDisabled || (this._flags & 16) != 0) {
            this._flags |= 32;
            return;
        }
        throw new AssertionError();
    }

    public final boolean isDefault() {
        check_dated();
        return (this._flags & 256) != 0;
    }

    public final boolean isDefaultable() {
        check_element_dated();
        return (this._flags & 2) != 0;
    }

    public final boolean isFixed() {
        check_element_dated();
        return (this._flags & 4) != 0;
    }

    @Override // org.apache.xmlbeans.XmlObject
    public boolean isImmutable() {
        return (this._flags & 4096) != 0;
    }

    public boolean isInstanceOf(SchemaType schemaType) {
        if (schemaType.getSimpleVariety() != 2) {
            for (SchemaType instanceType = instanceType(); instanceType != null; instanceType = instanceType.getBaseType()) {
                if (schemaType == instanceType) {
                    return true;
                }
            }
            return false;
        }
        HashSet hashSet = new HashSet(Arrays.asList(schemaType.getUnionConstituentTypes()));
        for (SchemaType instanceType2 = instanceType(); instanceType2 != null; instanceType2 = instanceType2.getBaseType()) {
            if (hashSet.contains(instanceType2)) {
                return true;
            }
        }
        return false;
    }

    @Override // org.apache.xmlbeans.XmlObject
    public final boolean isNil() {
        boolean z;
        synchronized (monitor()) {
            check_dated();
            z = (this._flags & 64) != 0;
        }
        return z;
    }

    public final boolean isNillable() {
        check_element_dated();
        return (this._flags & 1) != 0;
    }

    @Override // org.apache.xmlbeans.impl.values.TypeStoreUser
    public boolean is_child_element_order_sensitive() {
        if (!_isComplexType()) {
            return false;
        }
        return schemaType().isOrderSensitive();
    }

    public boolean is_defaultable_ws(String str) {
        return true;
    }

    public final boolean is_orphaned() {
        return (this._flags & 2048) != 0;
    }

    @Override // org.apache.xmlbeans.SimpleValue
    public List listValue() {
        return getListValue();
    }

    @Override // org.apache.xmlbeans.SimpleValue
    public long longValue() {
        return getLongValue();
    }

    @Override // org.apache.xmlbeans.XmlTokenSource
    public final Object monitor() {
        return has_store() ? get_store().get_locale() : this;
    }

    @Override // org.apache.xmlbeans.XmlTokenSource
    public XmlCursor newCursor() {
        XmlCursor new_cursor;
        if ((this._flags & 16) != 0) {
            check_orphaned();
            XmlLocale xmlLocale = getXmlLocale();
            if (xmlLocale.noSync()) {
                xmlLocale.enter();
                try {
                    return get_store().new_cursor();
                } finally {
                    xmlLocale.exit();
                }
            } else {
                synchronized (xmlLocale) {
                    xmlLocale.enter();
                    try {
                        new_cursor = get_store().new_cursor();
                    } finally {
                        xmlLocale.exit();
                    }
                }
                return new_cursor;
            }
        } else {
            throw new IllegalStateException("XML Value Objects cannot create cursors");
        }
    }

    public XmlCursor newCursorForce() {
        XmlCursor newCursor;
        synchronized (monitor()) {
            newCursor = ensureStore().newCursor();
        }
        return newCursor;
    }

    @Override // org.apache.xmlbeans.XmlTokenSource
    public Node newDomNode() {
        return newDomNode(null);
    }

    @Override // org.apache.xmlbeans.XmlTokenSource
    public InputStream newInputStream() {
        return newInputStream(null);
    }

    @Override // org.apache.xmlbeans.XmlTokenSource
    public Reader newReader() {
        return newReader(null);
    }

    @Override // org.apache.xmlbeans.XmlTokenSource
    public XMLInputStream newXMLInputStream() {
        return newXMLInputStream(null);
    }

    @Override // org.apache.xmlbeans.XmlTokenSource
    public XMLStreamReader newXMLStreamReader() {
        return newXMLStreamReader(null);
    }

    @Override // org.apache.xmlbeans.impl.values.TypeStoreUser
    public TypeStoreVisitor new_visitor() {
        if (!_isComplexContent()) {
            return null;
        }
        return new SchemaTypeVisitorImpl(schemaType().getContentModel());
    }

    @Override // org.apache.xmlbeans.SimpleValue
    public void objectSet(Object obj) {
        setObjectValue(obj);
    }

    @Override // org.apache.xmlbeans.SimpleValue
    public Object objectValue() {
        return getObjectValue();
    }

    @Override // org.apache.xmlbeans.SimpleValue
    public QName qNameValue() {
        return getQNameValue();
    }

    @Override // org.apache.xmlbeans.XmlTokenSource
    public void save(ContentHandler contentHandler, LexicalHandler lexicalHandler, XmlOptions xmlOptions) {
        XmlCursor newCursorForce = newCursorForce();
        try {
            newCursorForce.save(contentHandler, lexicalHandler, makeInnerOptions(xmlOptions));
        } finally {
            newCursorForce.dispose();
        }
    }

    @Override // org.apache.xmlbeans.XmlObject
    public abstract SchemaType schemaType();

    @Override // org.apache.xmlbeans.XmlObject
    public XmlObject selectAttribute(QName qName) {
        XmlCursor newCursor = newCursor();
        try {
            if (!newCursor.isContainer()) {
                return null;
            }
            if (newCursor.toFirstAttribute()) {
                while (!newCursor.getName().equals(qName)) {
                    if (!newCursor.toNextAttribute()) {
                    }
                }
                XmlObject object = newCursor.getObject();
                newCursor.dispose();
                return object;
            }
            newCursor.dispose();
            return null;
        } finally {
            newCursor.dispose();
        }
    }

    @Override // org.apache.xmlbeans.XmlObject
    public XmlObject[] selectAttributes(QNameSet qNameSet) {
        if (qNameSet != null) {
            XmlCursor newCursor = newCursor();
            try {
                if (!newCursor.isContainer()) {
                    return EMPTY_RESULT;
                }
                ArrayList arrayList = new ArrayList();
                if (newCursor.toFirstAttribute()) {
                    do {
                        if (qNameSet.contains(newCursor.getName())) {
                            arrayList.add(newCursor.getObject());
                        }
                    } while (newCursor.toNextAttribute());
                }
                if (arrayList.size() == 0) {
                    XmlObject[] xmlObjectArr = EMPTY_RESULT;
                    newCursor.dispose();
                    return xmlObjectArr;
                }
                XmlObject[] xmlObjectArr2 = (XmlObject[]) arrayList.toArray(EMPTY_RESULT);
                newCursor.dispose();
                return xmlObjectArr2;
            } finally {
                newCursor.dispose();
            }
        } else {
            throw new IllegalArgumentException();
        }
    }

    @Override // org.apache.xmlbeans.XmlObject
    public XmlObject[] selectChildren(QName qName) {
        XmlCursor newCursor = newCursor();
        try {
            if (!newCursor.isContainer()) {
                return EMPTY_RESULT;
            }
            ArrayList arrayList = new ArrayList();
            if (newCursor.toChild(qName)) {
                do {
                    arrayList.add(newCursor.getObject());
                } while (newCursor.toNextSibling(qName));
            }
            if (arrayList.size() == 0) {
                XmlObject[] xmlObjectArr = EMPTY_RESULT;
                newCursor.dispose();
                return xmlObjectArr;
            }
            XmlObject[] xmlObjectArr2 = (XmlObject[]) arrayList.toArray(EMPTY_RESULT);
            newCursor.dispose();
            return xmlObjectArr2;
        } finally {
            newCursor.dispose();
        }
    }

    @Override // org.apache.xmlbeans.XmlObject
    public XmlObject[] selectPath(String str) {
        return selectPath(str, null);
    }

    @Override // org.apache.xmlbeans.SimpleValue
    public void set(String str) {
        setStringValue(str);
    }

    @Override // org.apache.xmlbeans.SimpleValue
    public final void setBigDecimalValue(BigDecimal bigDecimal) {
        if (bigDecimal == null) {
            setNil();
            return;
        }
        synchronized (monitor()) {
            set_prepare();
            set_BigDecimal(bigDecimal);
            set_commit();
        }
    }

    @Override // org.apache.xmlbeans.SimpleValue
    public final void setBigIntegerValue(BigInteger bigInteger) {
        if (bigInteger == null) {
            setNil();
            return;
        }
        synchronized (monitor()) {
            set_prepare();
            set_BigInteger(bigInteger);
            set_commit();
        }
    }

    @Override // org.apache.xmlbeans.SimpleValue
    public final void setBooleanValue(boolean z) {
        synchronized (monitor()) {
            set_prepare();
            set_boolean(z);
            set_commit();
        }
    }

    @Override // org.apache.xmlbeans.SimpleValue
    public final void setByteArrayValue(byte[] bArr) {
        if (bArr == null) {
            setNil();
            return;
        }
        synchronized (monitor()) {
            set_prepare();
            set_ByteArray(bArr);
            set_commit();
        }
    }

    @Override // org.apache.xmlbeans.SimpleValue
    public final void setByteValue(byte b2) {
        synchronized (monitor()) {
            set_prepare();
            set_byte(b2);
            set_commit();
        }
    }

    @Override // org.apache.xmlbeans.SimpleValue
    public final void setCalendarValue(Calendar calendar) {
        if (calendar == null) {
            setNil();
            return;
        }
        synchronized (monitor()) {
            set_prepare();
            set_Calendar(calendar);
            set_commit();
        }
    }

    @Override // org.apache.xmlbeans.SimpleValue
    public final void setDateValue(Date date) {
        if (date == null) {
            setNil();
            return;
        }
        synchronized (monitor()) {
            set_prepare();
            set_Date(date);
            set_commit();
        }
    }

    @Override // org.apache.xmlbeans.SimpleValue
    public final void setDoubleValue(double d2) {
        synchronized (monitor()) {
            set_prepare();
            set_double(d2);
            set_commit();
        }
    }

    @Override // org.apache.xmlbeans.SimpleValue
    public final void setEnumValue(StringEnumAbstractBase stringEnumAbstractBase) {
        if (stringEnumAbstractBase == null) {
            setNil();
            return;
        }
        synchronized (monitor()) {
            set_prepare();
            set_enum(stringEnumAbstractBase);
            set_commit();
        }
    }

    @Override // org.apache.xmlbeans.SimpleValue
    public final void setFloatValue(float f2) {
        synchronized (monitor()) {
            set_prepare();
            set_float(f2);
            set_commit();
        }
    }

    @Override // org.apache.xmlbeans.SimpleValue
    public final void setGDateValue(GDate gDate) {
        if (gDate == null) {
            setNil();
            return;
        }
        synchronized (monitor()) {
            set_prepare();
            set_GDate(gDate);
            set_commit();
        }
    }

    @Override // org.apache.xmlbeans.SimpleValue
    public final void setGDurationValue(GDuration gDuration) {
        if (gDuration == null) {
            setNil();
            return;
        }
        synchronized (monitor()) {
            set_prepare();
            set_GDuration(gDuration);
            set_commit();
        }
    }

    public void setImmutable() {
        int i2 = this._flags;
        if ((i2 & 4112) == 0) {
            this._flags = i2 | 4096;
            return;
        }
        throw new IllegalStateException();
    }

    @Override // org.apache.xmlbeans.SimpleValue
    public final void setIntValue(int i2) {
        synchronized (monitor()) {
            set_prepare();
            set_int(i2);
            set_commit();
        }
    }

    @Override // org.apache.xmlbeans.SimpleValue
    public final void setListValue(List list) {
        if (list == null) {
            setNil();
            return;
        }
        synchronized (monitor()) {
            set_prepare();
            set_list(list);
            set_commit();
        }
    }

    @Override // org.apache.xmlbeans.SimpleValue
    public final void setLongValue(long j) {
        synchronized (monitor()) {
            set_prepare();
            set_long(j);
            set_commit();
        }
    }

    @Override // org.apache.xmlbeans.XmlObject
    public final void setNil() {
        synchronized (monitor()) {
            set_prepare();
            if ((this._flags & 1) == 0) {
                if ((this._flags & 65536) != 0) {
                    throw new XmlValueNotNillableException();
                }
            }
            set_nil();
            int i2 = this._flags | 64;
            this._flags = i2;
            if ((i2 & 16) != 0) {
                get_store().invalidate_text();
                this._flags &= -673;
                get_store().invalidate_nil();
            } else {
                this._textsource = null;
            }
        }
    }

    @Override // org.apache.xmlbeans.SimpleValue
    public void setObjectValue(Object obj) {
        if (obj == null) {
            setNil();
        } else if (obj instanceof XmlObject) {
            set((XmlObject) obj);
        } else if (obj instanceof String) {
            setStringValue((String) obj);
        } else if (obj instanceof StringEnumAbstractBase) {
            setEnumValue((StringEnumAbstractBase) obj);
        } else if (obj instanceof BigInteger) {
            setBigIntegerValue((BigInteger) obj);
        } else if (obj instanceof BigDecimal) {
            setBigDecimalValue((BigDecimal) obj);
        } else if (obj instanceof Byte) {
            setByteValue(((Byte) obj).byteValue());
        } else if (obj instanceof Short) {
            setShortValue(((Short) obj).shortValue());
        } else if (obj instanceof Integer) {
            setIntValue(((Integer) obj).intValue());
        } else if (obj instanceof Long) {
            setLongValue(((Long) obj).longValue());
        } else if (obj instanceof Boolean) {
            setBooleanValue(((Boolean) obj).booleanValue());
        } else if (obj instanceof Float) {
            setFloatValue(((Float) obj).floatValue());
        } else if (obj instanceof Double) {
            setDoubleValue(((Double) obj).doubleValue());
        } else if (obj instanceof Calendar) {
            setCalendarValue((Calendar) obj);
        } else if (obj instanceof Date) {
            setDateValue((Date) obj);
        } else if (obj instanceof GDateSpecification) {
            setGDateValue((GDateSpecification) obj);
        } else if (obj instanceof GDurationSpecification) {
            setGDurationValue((GDurationSpecification) obj);
        } else if (obj instanceof QName) {
            setQNameValue((QName) obj);
        } else if (obj instanceof List) {
            setListValue((List) obj);
        } else if (obj instanceof byte[]) {
            setByteArrayValue((byte[]) obj);
        } else {
            StringBuffer a = a.a("Can't set union object of class : ");
            a.append(obj.getClass().getName());
            throw new XmlValueNotSupportedException(a.toString());
        }
    }

    @Override // org.apache.xmlbeans.SimpleValue
    public final void setQNameValue(QName qName) {
        if (qName == null) {
            setNil();
            return;
        }
        synchronized (monitor()) {
            set_prepare();
            set_QName(qName);
            set_commit();
        }
    }

    @Override // org.apache.xmlbeans.SimpleValue
    public final void setShortValue(short s) {
        synchronized (monitor()) {
            set_prepare();
            set_short(s);
            set_commit();
        }
    }

    @Override // org.apache.xmlbeans.SimpleValue
    public final void setStringValue(String str) {
        if (str == null) {
            setNil();
            return;
        }
        synchronized (monitor()) {
            set_prepare();
            set_String(str);
        }
    }

    public void setValidateOnSet() {
        this._flags |= 65536;
    }

    public void set_BigDecimal(BigDecimal bigDecimal) {
        throw new XmlValueNotSupportedException(XmlErrorCodes.EXCEPTION_VALUE_NOT_SUPPORTED_J2S, new Object[]{"numeric", getPrimitiveTypeName()});
    }

    public void set_BigInteger(BigInteger bigInteger) {
        set_BigDecimal(new BigDecimal(bigInteger));
    }

    public void set_ByteArray(byte[] bArr) {
        throw new XmlValueNotSupportedException(XmlErrorCodes.EXCEPTION_VALUE_NOT_SUPPORTED_J2S, new Object[]{"byte[]", getPrimitiveTypeName()});
    }

    public void set_Calendar(Calendar calendar) {
        throw new XmlValueNotSupportedException(XmlErrorCodes.EXCEPTION_VALUE_NOT_SUPPORTED_J2S, new Object[]{"Calendar", getPrimitiveTypeName()});
    }

    public void set_ComplexXml(XmlObject xmlObject) {
        throw new XmlValueNotSupportedException(XmlErrorCodes.EXCEPTION_VALUE_NOT_SUPPORTED_J2S, new Object[]{"complex content", getPrimitiveTypeName()});
    }

    public void set_Date(Date date) {
        throw new XmlValueNotSupportedException(XmlErrorCodes.EXCEPTION_VALUE_NOT_SUPPORTED_J2S, new Object[]{"Date", getPrimitiveTypeName()});
    }

    public void set_GDate(GDateSpecification gDateSpecification) {
        throw new XmlValueNotSupportedException(XmlErrorCodes.EXCEPTION_VALUE_NOT_SUPPORTED_J2S, new Object[]{"Date", getPrimitiveTypeName()});
    }

    public void set_GDuration(GDurationSpecification gDurationSpecification) {
        throw new XmlValueNotSupportedException(XmlErrorCodes.EXCEPTION_VALUE_NOT_SUPPORTED_J2S, new Object[]{"Duration", getPrimitiveTypeName()});
    }

    public void set_QName(QName qName) {
        throw new XmlValueNotSupportedException(XmlErrorCodes.EXCEPTION_VALUE_NOT_SUPPORTED_J2S, new Object[]{"QName", getPrimitiveTypeName()});
    }

    public void set_String(String str) {
        int i2 = this._flags;
        if ((i2 & 4096) == 0) {
            boolean z = (i2 & 64) != 0;
            update_from_wscanon_text(apply_wscanon(str));
            int i3 = this._flags;
            if ((i3 & 16) != 0) {
                int i4 = i3 & -33;
                this._flags = i4;
                if ((i4 & 1024) == 0) {
                    get_store().store_text(str);
                }
                if (z) {
                    get_store().invalidate_nil();
                    return;
                }
                return;
            }
            this._textsource = str;
            return;
        }
        throw new IllegalStateException();
    }

    public void set_b64(byte[] bArr) {
        set_ByteArray(bArr);
    }

    public void set_boolean(boolean z) {
        throw new XmlValueNotSupportedException(XmlErrorCodes.EXCEPTION_VALUE_NOT_SUPPORTED_J2S, new Object[]{"boolean", getPrimitiveTypeName()});
    }

    public void set_byte(byte b2) {
        set_int(b2);
    }

    public void set_char(char c) {
        set_String(Character.toString(c));
    }

    public void set_double(double d2) {
        set_BigDecimal(new BigDecimal(d2));
    }

    public void set_enum(StringEnumAbstractBase stringEnumAbstractBase) {
        throw new XmlValueNotSupportedException(XmlErrorCodes.EXCEPTION_VALUE_NOT_SUPPORTED_J2S, new Object[]{"enum", getPrimitiveTypeName()});
    }

    public void set_float(float f2) {
        set_BigDecimal(new BigDecimal((double) f2));
    }

    public void set_hex(byte[] bArr) {
        set_ByteArray(bArr);
    }

    public void set_int(int i2) {
        set_long((long) i2);
    }

    public void set_list(List list) {
        throw new XmlValueNotSupportedException(XmlErrorCodes.EXCEPTION_VALUE_NOT_SUPPORTED_J2S, new Object[]{"List", getPrimitiveTypeName()});
    }

    public void set_long(long j) {
        set_BigInteger(BigInteger.valueOf(j));
    }

    public final void set_newValue(XmlObject xmlObject) {
        if (xmlObject == null || xmlObject.isNil()) {
            setNil();
            return;
        }
        if (xmlObject instanceof XmlAnySimpleType) {
            XmlAnySimpleType xmlAnySimpleType = (XmlAnySimpleType) xmlObject;
            SchemaType instanceType = ((SimpleValue) xmlAnySimpleType).instanceType();
            if (!$assertionsDisabled && instanceType == null) {
                throw new AssertionError("Nil case should have been handled already");
            } else if (instanceType.getSimpleVariety() == 3) {
                synchronized (monitor()) {
                    set_prepare();
                    set_list(((SimpleValue) xmlAnySimpleType).xgetListValue());
                    set_commit();
                }
                return;
            } else {
                synchronized (monitor()) {
                    int i2 = 1;
                    if (!$assertionsDisabled) {
                        if (instanceType.getSimpleVariety() != i2) {
                            throw new AssertionError();
                        }
                    }
                    switch (instanceType.getPrimitiveType().getBuiltinTypeCode()) {
                        case 2:
                            if (!xmlAnySimpleType.isImmutable()) {
                                NamespaceContext.push(new NamespaceContext(xmlAnySimpleType));
                            } else {
                                i2 = 0;
                            }
                            try {
                                set_prepare();
                                set_xmlanysimple(xmlAnySimpleType);
                                if (i2 != 0) {
                                    break;
                                }
                            } finally {
                                if (i2 != 0) {
                                    NamespaceContext.pop();
                                }
                            }
                            break;
                        case 3:
                            boolean booleanValue = ((SimpleValue) xmlAnySimpleType).getBooleanValue();
                            set_prepare();
                            set_boolean(booleanValue);
                            break;
                        case 4:
                            byte[] byteArrayValue = ((SimpleValue) xmlAnySimpleType).getByteArrayValue();
                            set_prepare();
                            set_b64(byteArrayValue);
                            break;
                        case 5:
                            byte[] byteArrayValue2 = ((SimpleValue) xmlAnySimpleType).getByteArrayValue();
                            set_prepare();
                            set_hex(byteArrayValue2);
                            break;
                        case 6:
                            String stringValue = xmlAnySimpleType.getStringValue();
                            set_prepare();
                            set_text(stringValue);
                            break;
                        case 7:
                            QName qNameValue = ((SimpleValue) xmlAnySimpleType).getQNameValue();
                            set_prepare();
                            set_QName(qNameValue);
                            break;
                        case 8:
                            String stringValue2 = xmlAnySimpleType.getStringValue();
                            set_prepare();
                            set_notation(stringValue2);
                            break;
                        case 9:
                            float floatValue = ((SimpleValue) xmlAnySimpleType).getFloatValue();
                            set_prepare();
                            set_float(floatValue);
                            break;
                        case 10:
                            double doubleValue = ((SimpleValue) xmlAnySimpleType).getDoubleValue();
                            set_prepare();
                            set_double(doubleValue);
                            break;
                        case 11:
                            int decimalSize = instanceType.getDecimalSize();
                            if (decimalSize != 8) {
                                if (decimalSize != 16) {
                                    if (decimalSize != 32) {
                                        if (decimalSize == 64) {
                                            long longValue = ((SimpleValue) xmlAnySimpleType).getLongValue();
                                            set_prepare();
                                            set_long(longValue);
                                            break;
                                        } else {
                                            switch (decimalSize) {
                                                case 1000000:
                                                    BigInteger bigIntegerValue = ((SimpleValue) xmlAnySimpleType).getBigIntegerValue();
                                                    set_prepare();
                                                    set_BigInteger(bigIntegerValue);
                                                    break;
                                                default:
                                                    if (!$assertionsDisabled) {
                                                        throw new AssertionError("invalid numeric bit count");
                                                    }
                                                case SchemaType.SIZE_BIG_DECIMAL:
                                                    BigDecimal bigDecimalValue = ((SimpleValue) xmlAnySimpleType).getBigDecimalValue();
                                                    set_prepare();
                                                    set_BigDecimal(bigDecimalValue);
                                                    break;
                                            }
                                        }
                                    } else {
                                        int intValue = ((SimpleValue) xmlAnySimpleType).getIntValue();
                                        set_prepare();
                                        set_int(intValue);
                                        break;
                                    }
                                } else {
                                    short shortValue = ((SimpleValue) xmlAnySimpleType).getShortValue();
                                    set_prepare();
                                    set_short(shortValue);
                                    break;
                                }
                            } else {
                                byte byteValue = ((SimpleValue) xmlAnySimpleType).getByteValue();
                                set_prepare();
                                set_byte(byteValue);
                                break;
                            }
                        case 12:
                            String stringValue3 = xmlAnySimpleType.getStringValue();
                            set_prepare();
                            set_String(stringValue3);
                            break;
                        case 13:
                            GDuration gDurationValue = ((SimpleValue) xmlAnySimpleType).getGDurationValue();
                            set_prepare();
                            set_GDuration(gDurationValue);
                            break;
                        case 14:
                        case 15:
                        case 16:
                        case 17:
                        case 18:
                        case 19:
                        case 20:
                        case 21:
                            GDate gDateValue = ((SimpleValue) xmlAnySimpleType).getGDateValue();
                            set_prepare();
                            set_GDate(gDateValue);
                            break;
                        default:
                            if (!$assertionsDisabled) {
                                throw new AssertionError("encountered nonprimitive type.");
                            }
                            break;
                    }
                    set_commit();
                    return;
                }
            }
        }
        throw new IllegalStateException("Complex type unexpected");
    }

    public abstract void set_nil();

    public void set_notation(String str) {
        throw new XmlValueNotSupportedException();
    }

    public void set_short(short s) {
        set_int(s);
    }

    public abstract void set_text(String str);

    public void set_xmlanysimple(XmlAnySimpleType xmlAnySimpleType) {
        set_String(xmlAnySimpleType.getStringValue());
    }

    @Override // org.apache.xmlbeans.SimpleValue
    public short shortValue() {
        return getShortValue();
    }

    @Override // org.apache.xmlbeans.SimpleValue
    public String stringValue() {
        return getStringValue();
    }

    @Override // org.apache.xmlbeans.XmlObject
    public XmlObject substitute(QName qName, SchemaType schemaType) {
        XmlObject xmlObject;
        if (qName == null) {
            throw new IllegalArgumentException("Invalid name (null)");
        } else if (schemaType == null) {
            throw new IllegalArgumentException("Invalid type (null)");
        } else if ((this._flags & 16) != 0) {
            synchronized (monitor()) {
                check_orphaned();
                xmlObject = (XmlObject) get_store().substitute(qName, schemaType);
            }
            return xmlObject;
        } else {
            throw new IllegalStateException("XML Value Objects cannot be used with substitution");
        }
    }

    @Override // org.apache.xmlbeans.XmlObject
    public final String toString() {
        String xmlText;
        synchronized (monitor()) {
            xmlText = ensureStore().xmlText(_toStringOptions);
        }
        return xmlText;
    }

    public void update_from_complex_content() {
        throw new XmlValueNotSupportedException("Complex content");
    }

    @Override // org.apache.xmlbeans.impl.values.TypeStoreUser
    public final boolean uses_invalidate_value() {
        SchemaType schemaType = schemaType();
        return schemaType.isSimpleType() || schemaType.getContentType() == 2;
    }

    @Override // org.apache.xmlbeans.XmlObject
    public boolean validate() {
        return validate(null);
    }

    @Override // org.apache.xmlbeans.impl.values.TypeStoreUser
    public void validate_now() {
        check_dated();
    }

    public void validate_simpleval(String str, ValidationContext validationContext) {
    }

    /* JADX WARNING: Removed duplicated region for block: B:65:0x0074  */
    @Override // org.apache.xmlbeans.XmlObject
    public final boolean valueEquals(XmlObject xmlObject) {
        Throwable th;
        InterruptedException e2;
        boolean valueEqualsImpl;
        Throwable th2;
        Throwable th3;
        boolean valueEqualsImpl2;
        boolean z = false;
        try {
            if (isImmutable()) {
                if (xmlObject.isImmutable()) {
                    return valueEqualsImpl(xmlObject);
                }
                synchronized (xmlObject.monitor()) {
                    valueEqualsImpl2 = valueEqualsImpl(xmlObject);
                }
                return valueEqualsImpl2;
            } else if (xmlObject.isImmutable() || monitor() == xmlObject.monitor()) {
                synchronized (monitor()) {
                    valueEqualsImpl = valueEqualsImpl(xmlObject);
                }
                return valueEqualsImpl;
            } else {
                GlobalLock.acquire();
                try {
                    synchronized (monitor()) {
                        try {
                            synchronized (xmlObject.monitor()) {
                                try {
                                    GlobalLock.release();
                                    try {
                                        boolean valueEqualsImpl3 = valueEqualsImpl(xmlObject);
                                        try {
                                            return valueEqualsImpl3;
                                        } catch (Throwable th4) {
                                            th2 = th4;
                                            throw th2;
                                        }
                                    } catch (Throwable th5) {
                                        th3 = th5;
                                        throw th3;
                                    }
                                } catch (Throwable th6) {
                                    th3 = th6;
                                    throw th3;
                                }
                            }
                        } catch (Throwable th7) {
                            th2 = th7;
                            throw th2;
                        }
                    }
                } catch (InterruptedException e3) {
                    e2 = e3;
                    z = true;
                    try {
                        throw new XmlRuntimeException(e2);
                    } catch (Throwable th8) {
                        th = th8;
                        if (z) {
                        }
                        throw th;
                    }
                } catch (Throwable th9) {
                    th = th9;
                    z = true;
                    if (z) {
                        GlobalLock.release();
                    }
                    throw th;
                }
            }
        } catch (InterruptedException e4) {
            e2 = e4;
            throw new XmlRuntimeException(e2);
        }
    }

    @Override // org.apache.xmlbeans.XmlObject
    public int valueHashCode() {
        int value_hash_code;
        synchronized (monitor()) {
            value_hash_code = value_hash_code();
        }
        return value_hash_code;
    }

    public abstract int value_hash_code();

    public Object writeReplace() {
        synchronized (monitor()) {
            if (isRootXmlObject()) {
                return new SerializedRootObject(this);
            }
            return new SerializedInteriorObject(this, getRootXmlObject());
        }
    }

    @Override // org.apache.xmlbeans.SimpleValue
    public List xgetListValue() {
        throw new XmlValueNotSupportedException(XmlErrorCodes.EXCEPTION_VALUE_NOT_SUPPORTED_S2J, new Object[]{getPrimitiveTypeName(), "List"});
    }

    @Override // org.apache.xmlbeans.SimpleValue
    public List xlistValue() {
        return xgetListValue();
    }

    @Override // org.apache.xmlbeans.XmlTokenSource
    public String xmlText() {
        return xmlText(null);
    }

    public final XmlObject _copy(XmlOptions xmlOptions) {
        if (isImmutable()) {
            return this;
        }
        check_orphaned();
        return (XmlObject) get_store().copy(get_store().get_schematypeloader(), schemaType(), xmlOptions);
    }

    @Override // org.apache.xmlbeans.XmlObject
    public XmlObject[] execQuery(String str, XmlOptions xmlOptions) {
        XmlObject[] _typedArray;
        synchronized (monitor()) {
            TypeStore typeStore = get_store();
            if (typeStore != null) {
                try {
                    _typedArray = _typedArray(typeStore.exec_query(str, xmlOptions));
                } catch (XmlException e2) {
                    throw new XmlRuntimeException(e2);
                }
            } else {
                throw new XmlRuntimeException("Cannot do XQuery on XML Value Objects");
            }
        }
        return _typedArray;
    }

    @Override // org.apache.xmlbeans.XmlTokenSource
    public Node newDomNode(XmlOptions xmlOptions) {
        XmlCursor newCursorForce = newCursorForce();
        try {
            return newCursorForce.newDomNode(makeInnerOptions(xmlOptions));
        } finally {
            newCursorForce.dispose();
        }
    }

    @Override // org.apache.xmlbeans.XmlTokenSource
    public InputStream newInputStream(XmlOptions xmlOptions) {
        XmlCursor newCursorForce = newCursorForce();
        try {
            return newCursorForce.newInputStream(makeInnerOptions(xmlOptions));
        } finally {
            newCursorForce.dispose();
        }
    }

    @Override // org.apache.xmlbeans.XmlTokenSource
    public Reader newReader(XmlOptions xmlOptions) {
        XmlCursor newCursorForce = newCursorForce();
        try {
            return newCursorForce.newReader(makeInnerOptions(xmlOptions));
        } finally {
            newCursorForce.dispose();
        }
    }

    @Override // org.apache.xmlbeans.XmlTokenSource
    public XMLInputStream newXMLInputStream(XmlOptions xmlOptions) {
        XmlCursor newCursorForce = newCursorForce();
        try {
            return newCursorForce.newXMLInputStream(makeInnerOptions(xmlOptions));
        } finally {
            newCursorForce.dispose();
        }
    }

    @Override // org.apache.xmlbeans.XmlTokenSource
    public XMLStreamReader newXMLStreamReader(XmlOptions xmlOptions) {
        XmlCursor newCursorForce = newCursorForce();
        try {
            return newCursorForce.newXMLStreamReader(makeInnerOptions(xmlOptions));
        } finally {
            newCursorForce.dispose();
        }
    }

    @Override // org.apache.xmlbeans.XmlTokenSource
    public void save(File file, XmlOptions xmlOptions) {
        XmlCursor newCursorForce = newCursorForce();
        try {
            newCursorForce.save(file, makeInnerOptions(xmlOptions));
        } finally {
            newCursorForce.dispose();
        }
    }

    /* JADX INFO: finally extract failed */
    @Override // org.apache.xmlbeans.XmlObject
    public XmlObject[] selectPath(String str, XmlOptions xmlOptions) {
        XmlObject[] xmlObjectArr;
        XmlCursor newCursor = newCursor();
        if (newCursor != null) {
            try {
                newCursor.selectPath(str, xmlOptions);
                if (!newCursor.hasNextSelection()) {
                    xmlObjectArr = EMPTY_RESULT;
                } else {
                    xmlObjectArr = new XmlObject[newCursor.getSelectionCount()];
                    int i2 = 0;
                    while (newCursor.toNextSelection()) {
                        XmlObject object = newCursor.getObject();
                        xmlObjectArr[i2] = object;
                        if (object == null) {
                            if (newCursor.toParent()) {
                                XmlObject object2 = newCursor.getObject();
                                xmlObjectArr[i2] = object2;
                                if (object2 != null) {
                                }
                            }
                            throw new XmlRuntimeException("Path must select only elements and attributes");
                        }
                        i2++;
                    }
                }
                newCursor.dispose();
                return _typedArray(xmlObjectArr);
            } catch (Throwable th) {
                newCursor.dispose();
                throw th;
            }
        } else {
            throw new XmlValueDisconnectedException();
        }
    }

    @Override // org.apache.xmlbeans.SimpleValue
    public void set(boolean z) {
        setBooleanValue(z);
    }

    public final void setGDateValue(GDateSpecification gDateSpecification) {
        if (gDateSpecification == null) {
            setNil();
            return;
        }
        synchronized (monitor()) {
            set_prepare();
            set_GDate(gDateSpecification);
            set_commit();
        }
    }

    public final void setGDurationValue(GDurationSpecification gDurationSpecification) {
        if (gDurationSpecification == null) {
            setNil();
            return;
        }
        synchronized (monitor()) {
            set_prepare();
            set_GDuration(gDurationSpecification);
            set_commit();
        }
    }

    @Override // org.apache.xmlbeans.XmlObject
    public boolean validate(XmlOptions xmlOptions) {
        boolean isValid;
        int i2 = this._flags;
        if ((i2 & 16) != 0) {
            synchronized (monitor()) {
                if ((this._flags & 2048) == 0) {
                    SchemaField schemaField = schemaField();
                    SchemaType schemaType = schemaType();
                    TypeStore typeStore = get_store();
                    Validator validator = new Validator(schemaType, schemaField, typeStore.get_schematypeloader(), xmlOptions, null);
                    typeStore.validate(validator);
                    isValid = validator.isValid();
                } else {
                    throw new XmlValueDisconnectedException();
                }
            }
            return isValid;
        } else if ((i2 & 4096) != 0) {
            return validate_immutable(xmlOptions);
        } else {
            throw new IllegalStateException("XML objects with no underlying store cannot be validated");
        }
    }

    @Override // org.apache.xmlbeans.XmlTokenSource
    public String xmlText(XmlOptions xmlOptions) {
        XmlCursor newCursorForce = newCursorForce();
        try {
            return newCursorForce.xmlText(makeInnerOptions(xmlOptions));
        } finally {
            newCursorForce.dispose();
        }
    }

    @Override // org.apache.xmlbeans.XmlTokenSource
    public void save(OutputStream outputStream, XmlOptions xmlOptions) {
        XmlCursor newCursorForce = newCursorForce();
        try {
            newCursorForce.save(outputStream, makeInnerOptions(xmlOptions));
        } finally {
            newCursorForce.dispose();
        }
    }

    @Override // org.apache.xmlbeans.SimpleValue
    public void set(byte b2) {
        setByteValue(b2);
    }

    @Override // org.apache.xmlbeans.XmlTokenSource
    public void save(Writer writer, XmlOptions xmlOptions) {
        XmlCursor newCursorForce = newCursorForce();
        try {
            newCursorForce.save(writer, makeInnerOptions(xmlOptions));
        } finally {
            newCursorForce.dispose();
        }
    }

    @Override // org.apache.xmlbeans.SimpleValue
    public void set(short s) {
        setShortValue(s);
    }

    @Override // org.apache.xmlbeans.XmlTokenSource
    public void save(ContentHandler contentHandler, LexicalHandler lexicalHandler) {
        save(contentHandler, lexicalHandler, null);
    }

    @Override // org.apache.xmlbeans.SimpleValue
    public void set(int i2) {
        setIntValue(i2);
    }

    @Override // org.apache.xmlbeans.XmlObject
    public final XmlObject copy(XmlOptions xmlOptions) {
        XmlObject _copy;
        if (preCheck()) {
            return _copy(xmlOptions);
        }
        synchronized (monitor()) {
            _copy = _copy(xmlOptions);
        }
        return _copy;
    }

    @Override // org.apache.xmlbeans.XmlTokenSource
    public void save(File file) {
        save(file, (XmlOptions) null);
    }

    @Override // org.apache.xmlbeans.SimpleValue
    public void set(long j) {
        setLongValue(j);
    }

    @Override // org.apache.xmlbeans.XmlTokenSource
    public void save(OutputStream outputStream) {
        save(outputStream, (XmlOptions) null);
    }

    @Override // org.apache.xmlbeans.SimpleValue
    public void set(BigInteger bigInteger) {
        setBigIntegerValue(bigInteger);
    }

    @Override // org.apache.xmlbeans.XmlTokenSource
    public void save(Writer writer) {
        save(writer, (XmlOptions) null);
    }

    @Override // org.apache.xmlbeans.SimpleValue
    public void set(BigDecimal bigDecimal) {
        setBigDecimalValue(bigDecimal);
    }

    @Override // org.apache.xmlbeans.SimpleValue
    public void set(float f2) {
        setFloatValue(f2);
    }

    @Override // org.apache.xmlbeans.XmlObject
    public XmlObject selectAttribute(String str, String str2) {
        return selectAttribute(new QName(str, str2));
    }

    @Override // org.apache.xmlbeans.SimpleValue
    public void set(double d2) {
        setDoubleValue(d2);
    }

    @Override // org.apache.xmlbeans.SimpleValue
    public void set(byte[] bArr) {
        setByteArrayValue(bArr);
    }

    @Override // org.apache.xmlbeans.SimpleValue
    public void set(StringEnumAbstractBase stringEnumAbstractBase) {
        setEnumValue(stringEnumAbstractBase);
    }

    @Override // org.apache.xmlbeans.SimpleValue
    public void set(Calendar calendar) {
        setCalendarValue(calendar);
    }

    @Override // org.apache.xmlbeans.XmlObject
    public XmlObject[] selectChildren(String str, String str2) {
        return selectChildren(new QName(str, str2));
    }

    @Override // org.apache.xmlbeans.SimpleValue
    public void set(Date date) {
        setDateValue(date);
    }

    @Override // org.apache.xmlbeans.XmlObject
    public XmlObject[] selectChildren(QNameSet qNameSet) {
        if (qNameSet != null) {
            XmlCursor newCursor = newCursor();
            try {
                if (!newCursor.isContainer()) {
                    return EMPTY_RESULT;
                }
                ArrayList arrayList = new ArrayList();
                if (newCursor.toFirstChild()) {
                    do {
                        if (!$assertionsDisabled && !newCursor.isContainer()) {
                            throw new AssertionError();
                        } else if (qNameSet.contains(newCursor.getName())) {
                            arrayList.add(newCursor.getObject());
                        }
                    } while (newCursor.toNextSibling());
                }
                if (arrayList.size() == 0) {
                    XmlObject[] xmlObjectArr = EMPTY_RESULT;
                    newCursor.dispose();
                    return xmlObjectArr;
                }
                XmlObject[] xmlObjectArr2 = (XmlObject[]) arrayList.toArray(EMPTY_RESULT);
                newCursor.dispose();
                return xmlObjectArr2;
            } finally {
                newCursor.dispose();
            }
        } else {
            throw new IllegalArgumentException();
        }
    }

    @Override // org.apache.xmlbeans.SimpleValue
    public void set(GDateSpecification gDateSpecification) {
        setGDateValue(gDateSpecification);
    }

    @Override // org.apache.xmlbeans.SimpleValue
    public void set(GDurationSpecification gDurationSpecification) {
        setGDurationValue(gDurationSpecification);
    }

    @Override // org.apache.xmlbeans.SimpleValue
    public void set(QName qName) {
        setQNameValue(qName);
    }

    @Override // org.apache.xmlbeans.SimpleValue
    public void set(List list) {
        setListValue(list);
    }

    /* JADX WARNING: Code restructure failed: missing block: B:72:0x0092, code lost:
        r5 = th;
     */
    /* JADX WARNING: Removed duplicated region for block: B:83:0x00a5  */
    @Override // org.apache.xmlbeans.XmlObject
    public final XmlObject set(XmlObject xmlObject) {
        TypeStoreUser typeStoreUser;
        Throwable th;
        InterruptedException e2;
        Throwable th2;
        if (!isImmutable()) {
            XmlObjectBase underlying = underlying(xmlObject);
            if (underlying == null) {
                setNil();
                return this;
            }
            if (underlying.isImmutable()) {
                setStringValue(underlying.getStringValue());
                typeStoreUser = this;
            } else {
                boolean preCheck = preCheck();
                boolean preCheck2 = underlying.preCheck();
                if (monitor() == underlying.monitor()) {
                    if (preCheck) {
                        typeStoreUser = setterHelper(underlying);
                    } else {
                        synchronized (monitor()) {
                            typeStoreUser = setterHelper(underlying);
                        }
                    }
                } else if (preCheck) {
                    if (preCheck2) {
                        typeStoreUser = setterHelper(underlying);
                    } else {
                        synchronized (underlying.monitor()) {
                            typeStoreUser = setterHelper(underlying);
                        }
                    }
                } else if (preCheck2) {
                    synchronized (monitor()) {
                        typeStoreUser = setterHelper(underlying);
                    }
                } else {
                    boolean z = false;
                    try {
                        GlobalLock.acquire();
                        try {
                            synchronized (monitor()) {
                                try {
                                    synchronized (underlying.monitor()) {
                                        try {
                                            GlobalLock.release();
                                            try {
                                                typeStoreUser = setterHelper(underlying);
                                            } catch (Throwable th3) {
                                                th2 = th3;
                                                throw th2;
                                            }
                                        } catch (Throwable th4) {
                                            th2 = th4;
                                            throw th2;
                                        }
                                    }
                                } catch (Throwable th5) {
                                    Throwable th6 = th5;
                                    throw th6;
                                }
                            }
                        } catch (InterruptedException e3) {
                            e2 = e3;
                            z = true;
                            try {
                                throw new XmlRuntimeException(e2);
                            } catch (Throwable th7) {
                                th = th7;
                                if (z) {
                                }
                                throw th;
                            }
                        } catch (Throwable th8) {
                            th = th8;
                            z = true;
                            if (z) {
                                GlobalLock.release();
                            }
                            throw th;
                        }
                    } catch (InterruptedException e4) {
                        e2 = e4;
                        throw new XmlRuntimeException(e2);
                    }
                }
            }
            return (XmlObject) typeStoreUser;
        }
        throw new IllegalStateException("Cannot set the value of an immutable XmlObject");
    }
}
