package org.apache.xmlbeans.impl.xsd2inst;

import b.b.a.a.a;
import java.io.UnsupportedEncodingException;
import java.math.BigDecimal;
import java.math.BigInteger;
import java.util.ArrayList;
import java.util.Arrays;
import java.util.Date;
import java.util.HashSet;
import java.util.Random;
import java.util.Set;
import org.apache.poi.javax.xml.namespace.QName;
import org.apache.poi.openxml4j.opc.internal.ZipHelper;
import org.apache.poi.ss.util.SheetUtil;
import org.apache.xerces.impl.xs.SchemaSymbols;
import org.apache.xmlbeans.GDate;
import org.apache.xmlbeans.GDateBuilder;
import org.apache.xmlbeans.GDuration;
import org.apache.xmlbeans.GDurationBuilder;
import org.apache.xmlbeans.SchemaLocalElement;
import org.apache.xmlbeans.SchemaParticle;
import org.apache.xmlbeans.SchemaProperty;
import org.apache.xmlbeans.SchemaType;
import org.apache.xmlbeans.SimpleValue;
import org.apache.xmlbeans.XmlAnySimpleType;
import org.apache.xmlbeans.XmlCalendar;
import org.apache.xmlbeans.XmlCursor;
import org.apache.xmlbeans.XmlDate;
import org.apache.xmlbeans.XmlDateTime;
import org.apache.xmlbeans.XmlDecimal;
import org.apache.xmlbeans.XmlDuration;
import org.apache.xmlbeans.XmlGDay;
import org.apache.xmlbeans.XmlGMonth;
import org.apache.xmlbeans.XmlGMonthDay;
import org.apache.xmlbeans.XmlGYear;
import org.apache.xmlbeans.XmlGYearMonth;
import org.apache.xmlbeans.XmlInteger;
import org.apache.xmlbeans.XmlObject;
import org.apache.xmlbeans.XmlOptions;
import org.apache.xmlbeans.XmlTime;
import org.apache.xmlbeans.impl.jam.xml.JamXmlElements;
import org.apache.xmlbeans.impl.schema.SoapEncSchemaTypeSystem;
import org.apache.xmlbeans.impl.util.Base64;
import org.apache.xmlbeans.impl.util.HexBin;
import org.apache.xmlbeans.soap.SOAPArrayType;
import org.apache.xmlbeans.soap.SchemaWSDLArrayType;

public class SampleXmlUtil {
    public static final String[] DNS1 = {"corp", "your", "my", "sample", "company", "test", "any"};
    public static final String[] DNS2 = {"com", "org", "com", "gov", "org", "com", "org", "com", "edu"};
    public static final QName ENC_ARRAYTYPE = new QName("http://schemas.xmlsoap.org/soap/encoding/", SoapEncSchemaTypeSystem.ARRAY_TYPE);
    public static final QName ENC_OFFSET = new QName("http://schemas.xmlsoap.org/soap/encoding/", SoapEncSchemaTypeSystem.ATTR_OFFSET);
    public static final QName HREF = new QName(SoapEncSchemaTypeSystem.ATTR_HREF);
    public static final QName ID = new QName("id");
    public static final int MAX_ELEMENTS = 1000;
    public static final Set SKIPPED_SOAP_ATTRS = new HashSet(Arrays.asList(HREF, ID, ENC_OFFSET));
    public static final String[] WORDS = {"ipsa", "iovis", "rapidum", "iaculata", "e", "nubibus", "ignem", "disiecitque", "rates", "evertitque", "aequora", "ventis", "illum", "exspirantem", "transfixo", "pectore", "flammas", "turbine", "corripuit", "scopuloque", "infixit", "acuto", "ast", "ego", "quae", "divum", "incedo", "regina", "iovisque", "et", "soror", "et", "coniunx", "una", "cum", "gente", "tot", "annos", "bella", "gero", "et", "quisquam", "numen", "iunonis", "adorat", "praeterea", "aut", "supplex", "aris", "imponet", "honorem", "talia", "flammato", "secum", "dea", "corde", "volutans", "nimborum", "in", "patriam", "loca", "feta", "furentibus", "austris", "aeoliam", "venit", "hic", "vasto", "rex", "aeolus", "antro", "luctantis", "ventos", "tempestatesque", "sonoras", "imperio", "premit", "ac", "vinclis", "et", "carcere", "frenat", "illi", "indignantes", "magno", "cum", "murmure", "montis", "circum", "claustra", "fremunt", "celsa", "sedet", "aeolus", "arce", "sceptra", "tenens", "mollitque", "animos", "et", "temperat", "iras", "ni", "faciat", "maria", "ac", "terras", "caelumque", "profundum", "quippe", "ferant", "rapidi", "secum", "verrantque", "per", "auras", "sed", "pater", "omnipotens", "speluncis", "abdidit", "atris", "hoc", "metuens", "molemque", "et", "montis", "insuper", "altos", "imposuit", "regemque", "dedit", "qui", "foedere", "certo", "et", "premere", "et", "laxas", "sciret", "dare", "iussus", "habenas"};
    public static final QName XSI_TYPE = new QName("http://www.w3.org/2001/XMLSchema-instance", JamXmlElements.TYPE);
    public int _nElements;
    public Random _picker = new Random(1);
    public boolean _soapEnc;
    public ArrayList _typeStack = new ArrayList();

    public SampleXmlUtil(boolean z) {
        this._soapEnc = z;
    }

    private SchemaType closestBuiltin(SchemaType schemaType) {
        while (!schemaType.isBuiltinType()) {
            schemaType = schemaType.getBaseType();
        }
        return schemaType;
    }

    public static QName crackQName(String str) {
        String str2;
        int lastIndexOf = str.lastIndexOf(58);
        if (lastIndexOf >= 0) {
            str2 = str.substring(0, lastIndexOf);
            str = str.substring(lastIndexOf + 1);
        } else {
            str2 = "";
        }
        return new QName(str2, str);
    }

    public static String createSampleForType(SchemaType schemaType) {
        XmlObject newInstance = XmlObject.Factory.newInstance();
        XmlCursor newCursor = newInstance.newCursor();
        newCursor.toNextToken();
        new SampleXmlUtil(false).createSampleForType(schemaType, newCursor);
        XmlOptions xmlOptions = new XmlOptions();
        xmlOptions.put(XmlOptions.SAVE_PRETTY_PRINT);
        xmlOptions.put(XmlOptions.SAVE_PRETTY_PRINT_INDENT, 2);
        xmlOptions.put(XmlOptions.SAVE_AGGRESSIVE_NAMESPACES);
        return newInstance.xmlText(xmlOptions);
    }

    private int determineMinMaxForSample(SchemaParticle schemaParticle, XmlCursor xmlCursor) {
        int intMinOccurs = schemaParticle.getIntMinOccurs();
        if (intMinOccurs == schemaParticle.getIntMaxOccurs()) {
            return intMinOccurs;
        }
        int i2 = (intMinOccurs != 0 || this._nElements >= 1000) ? intMinOccurs : 1;
        if (schemaParticle.getParticleType() != 4) {
            return i2;
        }
        if (schemaParticle.getMaxOccurs() == null) {
            if (intMinOccurs == 0) {
                xmlCursor.insertComment("Zero or more repetitions:");
            } else {
                StringBuffer stringBuffer = new StringBuffer();
                stringBuffer.append(intMinOccurs);
                stringBuffer.append(" or more repetitions:");
                xmlCursor.insertComment(stringBuffer.toString());
            }
        } else if (schemaParticle.getIntMaxOccurs() > 1) {
            StringBuffer stringBuffer2 = new StringBuffer();
            stringBuffer2.append(intMinOccurs);
            stringBuffer2.append(" to ");
            stringBuffer2.append(String.valueOf(schemaParticle.getMaxOccurs()));
            stringBuffer2.append(" repetitions:");
            xmlCursor.insertComment(stringBuffer2.toString());
        } else {
            xmlCursor.insertComment("Optional:");
        }
        return i2;
    }

    /* JADX WARNING: Removed duplicated region for block: B:186:0x034a  */
    private String formatDate(SchemaType schemaType) {
        GDate gDate;
        GDateBuilder gDateBuilder;
        GDate gDate2;
        GDateBuilder gDateBuilder2 = new GDateBuilder(new Date(((((long) pick(20)) + 30) * 365 * 24 * 60 * 60 * 1000) + (((long) pick(31536000)) * 1000)));
        GDate gDate3 = null;
        switch (schemaType.getPrimitiveType().getBuiltinTypeCode()) {
            case 14:
                XmlDateTime xmlDateTime = (XmlDateTime) schemaType.getFacet(4);
                gDate2 = xmlDateTime != null ? xmlDateTime.getGDateValue() : null;
                XmlDateTime xmlDateTime2 = (XmlDateTime) schemaType.getFacet(3);
                if (xmlDateTime2 != null && (gDate2 == null || gDate2.compareToGDate(xmlDateTime2.getGDateValue()) <= 0)) {
                    gDate2 = xmlDateTime2.getGDateValue();
                }
                XmlDateTime xmlDateTime3 = (XmlDateTime) schemaType.getFacet(5);
                if (xmlDateTime3 != null) {
                    gDate3 = xmlDateTime3.getGDateValue();
                }
                XmlDateTime xmlDateTime4 = (XmlDateTime) schemaType.getFacet(6);
                if (xmlDateTime4 != null && (gDate3 == null || gDate3.compareToGDate(xmlDateTime4.getGDateValue()) >= 0)) {
                    gDate3 = xmlDateTime4.getGDateValue();
                }
                gDate3 = gDate2;
                gDate = gDate3;
                break;
            case 15:
                XmlTime xmlTime = (XmlTime) schemaType.getFacet(4);
                gDate2 = xmlTime != null ? xmlTime.getGDateValue() : null;
                XmlTime xmlTime2 = (XmlTime) schemaType.getFacet(3);
                if (xmlTime2 != null && (gDate2 == null || gDate2.compareToGDate(xmlTime2.getGDateValue()) <= 0)) {
                    gDate2 = xmlTime2.getGDateValue();
                }
                XmlTime xmlTime3 = (XmlTime) schemaType.getFacet(5);
                if (xmlTime3 != null) {
                    gDate3 = xmlTime3.getGDateValue();
                }
                XmlTime xmlTime4 = (XmlTime) schemaType.getFacet(6);
                if (xmlTime4 != null && (gDate3 == null || gDate3.compareToGDate(xmlTime4.getGDateValue()) >= 0)) {
                    gDate3 = xmlTime4.getGDateValue();
                }
                gDate3 = gDate2;
                gDate = gDate3;
                break;
            case 16:
                XmlDate xmlDate = (XmlDate) schemaType.getFacet(4);
                gDate2 = xmlDate != null ? xmlDate.getGDateValue() : null;
                XmlDate xmlDate2 = (XmlDate) schemaType.getFacet(3);
                if (xmlDate2 != null && (gDate2 == null || gDate2.compareToGDate(xmlDate2.getGDateValue()) <= 0)) {
                    gDate2 = xmlDate2.getGDateValue();
                }
                XmlDate xmlDate3 = (XmlDate) schemaType.getFacet(5);
                if (xmlDate3 != null) {
                    gDate3 = xmlDate3.getGDateValue();
                }
                XmlDate xmlDate4 = (XmlDate) schemaType.getFacet(6);
                if (xmlDate4 != null && (gDate3 == null || gDate3.compareToGDate(xmlDate4.getGDateValue()) >= 0)) {
                    gDate3 = xmlDate4.getGDateValue();
                }
                gDate3 = gDate2;
                gDate = gDate3;
                break;
            case 17:
                XmlGYearMonth xmlGYearMonth = (XmlGYearMonth) schemaType.getFacet(4);
                gDate2 = xmlGYearMonth != null ? xmlGYearMonth.getGDateValue() : null;
                XmlGYearMonth xmlGYearMonth2 = (XmlGYearMonth) schemaType.getFacet(3);
                if (xmlGYearMonth2 != null && (gDate2 == null || gDate2.compareToGDate(xmlGYearMonth2.getGDateValue()) <= 0)) {
                    gDate2 = xmlGYearMonth2.getGDateValue();
                }
                XmlGYearMonth xmlGYearMonth3 = (XmlGYearMonth) schemaType.getFacet(5);
                if (xmlGYearMonth3 != null) {
                    gDate3 = xmlGYearMonth3.getGDateValue();
                }
                XmlGYearMonth xmlGYearMonth4 = (XmlGYearMonth) schemaType.getFacet(6);
                if (xmlGYearMonth4 != null && (gDate3 == null || gDate3.compareToGDate(xmlGYearMonth4.getGDateValue()) >= 0)) {
                    gDate3 = xmlGYearMonth4.getGDateValue();
                }
                gDate3 = gDate2;
                gDate = gDate3;
                break;
            case 18:
                XmlGYear xmlGYear = (XmlGYear) schemaType.getFacet(4);
                gDate2 = xmlGYear != null ? xmlGYear.getGDateValue() : null;
                XmlGYear xmlGYear2 = (XmlGYear) schemaType.getFacet(3);
                if (xmlGYear2 != null && (gDate2 == null || gDate2.compareToGDate(xmlGYear2.getGDateValue()) <= 0)) {
                    gDate2 = xmlGYear2.getGDateValue();
                }
                XmlGYear xmlGYear3 = (XmlGYear) schemaType.getFacet(5);
                if (xmlGYear3 != null) {
                    gDate3 = xmlGYear3.getGDateValue();
                }
                XmlGYear xmlGYear4 = (XmlGYear) schemaType.getFacet(6);
                if (xmlGYear4 != null && (gDate3 == null || gDate3.compareToGDate(xmlGYear4.getGDateValue()) >= 0)) {
                    gDate3 = xmlGYear4.getGDateValue();
                }
                gDate3 = gDate2;
                gDate = gDate3;
                break;
            case 19:
                XmlGMonthDay xmlGMonthDay = (XmlGMonthDay) schemaType.getFacet(4);
                gDate2 = xmlGMonthDay != null ? xmlGMonthDay.getGDateValue() : null;
                XmlGMonthDay xmlGMonthDay2 = (XmlGMonthDay) schemaType.getFacet(3);
                if (xmlGMonthDay2 != null && (gDate2 == null || gDate2.compareToGDate(xmlGMonthDay2.getGDateValue()) <= 0)) {
                    gDate2 = xmlGMonthDay2.getGDateValue();
                }
                XmlGMonthDay xmlGMonthDay3 = (XmlGMonthDay) schemaType.getFacet(5);
                if (xmlGMonthDay3 != null) {
                    gDate3 = xmlGMonthDay3.getGDateValue();
                }
                XmlGMonthDay xmlGMonthDay4 = (XmlGMonthDay) schemaType.getFacet(6);
                if (xmlGMonthDay4 != null && (gDate3 == null || gDate3.compareToGDate(xmlGMonthDay4.getGDateValue()) >= 0)) {
                    gDate3 = xmlGMonthDay4.getGDateValue();
                }
                gDate3 = gDate2;
                gDate = gDate3;
                break;
            case 20:
                XmlGDay xmlGDay = (XmlGDay) schemaType.getFacet(4);
                gDate2 = xmlGDay != null ? xmlGDay.getGDateValue() : null;
                XmlGDay xmlGDay2 = (XmlGDay) schemaType.getFacet(3);
                if (xmlGDay2 != null && (gDate2 == null || gDate2.compareToGDate(xmlGDay2.getGDateValue()) <= 0)) {
                    gDate2 = xmlGDay2.getGDateValue();
                }
                XmlGDay xmlGDay3 = (XmlGDay) schemaType.getFacet(5);
                if (xmlGDay3 != null) {
                    gDate3 = xmlGDay3.getGDateValue();
                }
                XmlGDay xmlGDay4 = (XmlGDay) schemaType.getFacet(6);
                if (xmlGDay4 != null && (gDate3 == null || gDate3.compareToGDate(xmlGDay4.getGDateValue()) >= 0)) {
                    gDate3 = xmlGDay4.getGDateValue();
                }
                gDate3 = gDate2;
                gDate = gDate3;
                break;
            case 21:
                XmlGMonth xmlGMonth = (XmlGMonth) schemaType.getFacet(4);
                gDate2 = xmlGMonth != null ? xmlGMonth.getGDateValue() : null;
                XmlGMonth xmlGMonth2 = (XmlGMonth) schemaType.getFacet(3);
                if (xmlGMonth2 != null && (gDate2 == null || gDate2.compareToGDate(xmlGMonth2.getGDateValue()) <= 0)) {
                    gDate2 = xmlGMonth2.getGDateValue();
                }
                XmlGMonth xmlGMonth3 = (XmlGMonth) schemaType.getFacet(5);
                if (xmlGMonth3 != null) {
                    gDate3 = xmlGMonth3.getGDateValue();
                }
                XmlGMonth xmlGMonth4 = (XmlGMonth) schemaType.getFacet(6);
                if (xmlGMonth4 != null && (gDate3 == null || gDate3.compareToGDate(xmlGMonth4.getGDateValue()) >= 0)) {
                    gDate3 = xmlGMonth4.getGDateValue();
                }
                gDate3 = gDate2;
                gDate = gDate3;
                break;
            default:
                gDate = null;
                break;
        }
        if (gDate3 != null && gDate == null) {
            if (gDate3.compareToGDate(gDateBuilder2) >= 0) {
                XmlCalendar calendar = gDateBuilder2.getCalendar();
                calendar.add(11, pick(8));
                gDateBuilder = new GDateBuilder(calendar);
            }
            gDateBuilder2.setBuiltinTypeCode(schemaType.getPrimitiveType().getBuiltinTypeCode());
            if (pick(2) == 0) {
            }
            return gDateBuilder2.toString();
        } else if (gDate3 != null || gDate == null) {
            if (!(gDate3 == null || gDate == null || (gDate3.compareToGDate(gDateBuilder2) < 0 && gDate.compareToGDate(gDateBuilder2) > 0))) {
                XmlCalendar calendar2 = gDate3.getCalendar();
                XmlCalendar calendar3 = gDate.getCalendar();
                calendar2.add(11, 1);
                if (calendar2.after(calendar3)) {
                    calendar2.add(11, -1);
                    calendar2.add(12, 1);
                    if (calendar2.after(calendar3)) {
                        calendar2.add(12, -1);
                        calendar2.add(13, 1);
                        if (calendar2.after(calendar3)) {
                            calendar2.add(13, -1);
                            calendar2.add(14, 1);
                            if (calendar2.after(calendar3)) {
                                calendar2.add(14, -1);
                            }
                        }
                    }
                }
                gDateBuilder = new GDateBuilder(calendar2);
            }
            gDateBuilder2.setBuiltinTypeCode(schemaType.getPrimitiveType().getBuiltinTypeCode());
            if (pick(2) == 0) {
                gDateBuilder2.clearTimeZone();
            }
            return gDateBuilder2.toString();
        } else {
            if (gDate.compareToGDate(gDateBuilder2) <= 0) {
                XmlCalendar calendar4 = gDateBuilder2.getCalendar();
                calendar4.add(11, 0 - pick(8));
                gDateBuilder = new GDateBuilder(calendar4);
            }
            gDateBuilder2.setBuiltinTypeCode(schemaType.getPrimitiveType().getBuiltinTypeCode());
            if (pick(2) == 0) {
            }
            return gDateBuilder2.toString();
        }
        gDateBuilder2 = gDateBuilder;
        gDateBuilder2.setBuiltinTypeCode(schemaType.getPrimitiveType().getBuiltinTypeCode());
        if (pick(2) == 0) {
        }
        return gDateBuilder2.toString();
    }

    /* JADX WARNING: Removed duplicated region for block: B:17:0x0046  */
    /* JADX WARNING: Removed duplicated region for block: B:25:0x0060  */
    /* JADX WARNING: Removed duplicated region for block: B:38:0x009a  */
    /* JADX WARNING: Removed duplicated region for block: B:40:0x009d  */
    /* JADX WARNING: Removed duplicated region for block: B:41:0x009f  */
    /* JADX WARNING: Removed duplicated region for block: B:43:0x00a5  */
    /* JADX WARNING: Removed duplicated region for block: B:44:0x00a7  */
    /* JADX WARNING: Removed duplicated region for block: B:46:0x00ad A[ADDED_TO_REGION] */
    /* JADX WARNING: Removed duplicated region for block: B:51:0x00b7 A[ADDED_TO_REGION] */
    /* JADX WARNING: Removed duplicated region for block: B:57:0x00c9  */
    /* JADX WARNING: Removed duplicated region for block: B:58:0x00cf  */
    /* JADX WARNING: Removed duplicated region for block: B:68:0x0109 A[ADDED_TO_REGION] */
    /* JADX WARNING: Removed duplicated region for block: B:75:0x011a  */
    /* JADX WARNING: Removed duplicated region for block: B:76:0x011c  */
    /* JADX WARNING: Removed duplicated region for block: B:80:0x0133 A[LOOP:2: B:78:0x0129->B:80:0x0133, LOOP_END] */
    /* JADX WARNING: Removed duplicated region for block: B:82:0x013c  */
    /* JADX WARNING: Removed duplicated region for block: B:85:0x014d  */
    private String formatDecimal(String str, SchemaType schemaType) {
        boolean z;
        XmlDecimal xmlDecimal;
        boolean z2;
        XmlDecimal xmlDecimal2;
        int i2;
        int i3;
        int i4;
        int i5;
        boolean z3;
        XmlDecimal xmlDecimal3;
        BigDecimal bigDecimal;
        BigDecimal bigDecimal2;
        BigDecimal bigDecimal3;
        BigDecimal bigDecimal4 = new BigDecimal(str);
        XmlDecimal xmlDecimal4 = (XmlDecimal) schemaType.getFacet(4);
        BigDecimal bigDecimal5 = null;
        BigDecimal bigDecimalValue = xmlDecimal4 != null ? xmlDecimal4.getBigDecimalValue() : null;
        XmlDecimal xmlDecimal5 = (XmlDecimal) schemaType.getFacet(5);
        if (xmlDecimal5 != null) {
            bigDecimal5 = xmlDecimal5.getBigDecimalValue();
        }
        XmlDecimal xmlDecimal6 = (XmlDecimal) schemaType.getFacet(3);
        if (xmlDecimal6 != null) {
            BigDecimal bigDecimalValue2 = xmlDecimal6.getBigDecimalValue();
            if (bigDecimalValue == null || bigDecimalValue.compareTo(bigDecimalValue2) < 0) {
                bigDecimalValue = bigDecimalValue2;
                z = false;
                xmlDecimal = (XmlDecimal) schemaType.getFacet(6);
                if (xmlDecimal != null) {
                    BigDecimal bigDecimalValue3 = xmlDecimal.getBigDecimalValue();
                    if (bigDecimal5 == null || bigDecimal5.compareTo(bigDecimalValue3) > 0) {
                        bigDecimal5 = bigDecimalValue3;
                        z2 = false;
                        xmlDecimal2 = (XmlDecimal) schemaType.getFacet(7);
                        i2 = -1;
                        if (xmlDecimal2 != null) {
                            i3 = xmlDecimal2.getBigDecimalValue().intValue();
                            StringBuffer stringBuffer = new StringBuffer(i3);
                            for (int i6 = 0; i6 < i3; i6++) {
                                stringBuffer.append('9');
                            }
                            BigDecimal bigDecimal6 = new BigDecimal(stringBuffer.toString());
                            if (bigDecimal5 != null && bigDecimal5.compareTo(bigDecimal6) > 0) {
                                bigDecimal5 = bigDecimal6;
                                z2 = true;
                            }
                            BigDecimal negate = bigDecimal6.negate();
                            if (bigDecimalValue != null && bigDecimalValue.compareTo(negate) < 0) {
                                bigDecimalValue = negate;
                                z = true;
                            }
                        } else {
                            i3 = -1;
                        }
                        if (bigDecimalValue == null) {
                            i4 = 1;
                        } else {
                            i4 = bigDecimal4.compareTo(bigDecimalValue);
                        }
                        if (bigDecimal5 == null) {
                            i5 = -1;
                        } else {
                            i5 = bigDecimal4.compareTo(bigDecimal5);
                        }
                        z3 = i4 <= 0 || (i4 == 0 && z);
                        boolean z4 = i5 >= 0 || (i5 == 0 && z2);
                        xmlDecimal3 = (XmlDecimal) schemaType.getFacet(8);
                        if (xmlDecimal3 == null) {
                            bigDecimal = new BigDecimal(1);
                        } else {
                            i2 = xmlDecimal3.getBigDecimalValue().intValue();
                            if (i2 > 0) {
                                StringBuffer stringBuffer2 = new StringBuffer("0.");
                                for (int i7 = 1; i7 < i2; i7++) {
                                    stringBuffer2.append(SheetUtil.defaultChar);
                                }
                                stringBuffer2.append('1');
                                bigDecimal = new BigDecimal(stringBuffer2.toString());
                            } else {
                                bigDecimal = new BigDecimal(1.0d);
                            }
                        }
                        if (!z3 || !z4) {
                            if (!z3 && !z4) {
                                bigDecimal4 = z2 ? bigDecimal5 : bigDecimal5.subtract(bigDecimal);
                            } else if (!z3 && z4) {
                                bigDecimal4 = z ? bigDecimalValue : bigDecimalValue.add(bigDecimal);
                            }
                        }
                        bigDecimal2 = new BigDecimal(BigInteger.ONE);
                        bigDecimal3 = bigDecimal4;
                        int i8 = 0;
                        while (bigDecimal3.abs().compareTo(bigDecimal2) >= 0) {
                            bigDecimal3 = bigDecimal3.movePointLeft(1);
                            i8++;
                        }
                        if (i2 > 0) {
                            if (i3 >= 0) {
                                bigDecimal4 = bigDecimal4.setScale(Math.max(i2, i3 - i8));
                            } else {
                                bigDecimal4 = bigDecimal4.setScale(i2);
                            }
                        } else if (i2 == 0) {
                            bigDecimal4 = bigDecimal4.setScale(0);
                        }
                        return bigDecimal4.toString();
                    }
                }
                z2 = true;
                xmlDecimal2 = (XmlDecimal) schemaType.getFacet(7);
                i2 = -1;
                if (xmlDecimal2 != null) {
                }
                if (bigDecimalValue == null) {
                }
                if (bigDecimal5 == null) {
                }
                if (i4 <= 0) {
                }
                if (i5 >= 0) {
                }
                xmlDecimal3 = (XmlDecimal) schemaType.getFacet(8);
                if (xmlDecimal3 == null) {
                }
                if (!z3) {
                }
                if (z) {
                }
                bigDecimal2 = new BigDecimal(BigInteger.ONE);
                bigDecimal3 = bigDecimal4;
                int i82 = 0;
                while (bigDecimal3.abs().compareTo(bigDecimal2) >= 0) {
                }
                if (i2 > 0) {
                }
                return bigDecimal4.toString();
            }
        }
        z = true;
        xmlDecimal = (XmlDecimal) schemaType.getFacet(6);
        if (xmlDecimal != null) {
        }
        z2 = true;
        xmlDecimal2 = (XmlDecimal) schemaType.getFacet(7);
        i2 = -1;
        if (xmlDecimal2 != null) {
        }
        if (bigDecimalValue == null) {
        }
        if (bigDecimal5 == null) {
        }
        if (i4 <= 0) {
        }
        if (i5 >= 0) {
        }
        xmlDecimal3 = (XmlDecimal) schemaType.getFacet(8);
        if (xmlDecimal3 == null) {
        }
        if (!z3) {
        }
        if (z) {
        }
        bigDecimal2 = new BigDecimal(BigInteger.ONE);
        bigDecimal3 = bigDecimal4;
        int i822 = 0;
        while (bigDecimal3.abs().compareTo(bigDecimal2) >= 0) {
        }
        if (i2 > 0) {
        }
        return bigDecimal4.toString();
    }

    private String formatDuration(SchemaType schemaType) {
        XmlDuration xmlDuration = (XmlDuration) schemaType.getFacet(4);
        GDuration gDuration = null;
        GDuration gDurationValue = xmlDuration != null ? xmlDuration.getGDurationValue() : null;
        XmlDuration xmlDuration2 = (XmlDuration) schemaType.getFacet(5);
        GDuration gDurationValue2 = xmlDuration2 != null ? xmlDuration2.getGDurationValue() : null;
        XmlDuration xmlDuration3 = (XmlDuration) schemaType.getFacet(3);
        GDuration gDurationValue3 = xmlDuration3 != null ? xmlDuration3.getGDurationValue() : null;
        XmlDuration xmlDuration4 = (XmlDuration) schemaType.getFacet(6);
        if (xmlDuration4 != null) {
            gDuration = xmlDuration4.getGDurationValue();
        }
        GDurationBuilder gDurationBuilder = new GDurationBuilder();
        gDurationBuilder.setSecond(pick(800000));
        gDurationBuilder.setMonth(pick(20));
        if (gDurationValue != null) {
            if (gDurationBuilder.getYear() < gDurationValue.getYear()) {
                gDurationBuilder.setYear(gDurationValue.getYear());
            }
            if (gDurationBuilder.getMonth() < gDurationValue.getMonth()) {
                gDurationBuilder.setMonth(gDurationValue.getMonth());
            }
            if (gDurationBuilder.getDay() < gDurationValue.getDay()) {
                gDurationBuilder.setDay(gDurationValue.getDay());
            }
            if (gDurationBuilder.getHour() < gDurationValue.getHour()) {
                gDurationBuilder.setHour(gDurationValue.getHour());
            }
            if (gDurationBuilder.getMinute() < gDurationValue.getMinute()) {
                gDurationBuilder.setMinute(gDurationValue.getMinute());
            }
            if (gDurationBuilder.getSecond() < gDurationValue.getSecond()) {
                gDurationBuilder.setSecond(gDurationValue.getSecond());
            }
            if (gDurationBuilder.getFraction().compareTo(gDurationValue.getFraction()) < 0) {
                gDurationBuilder.setFraction(gDurationValue.getFraction());
            }
        }
        if (gDurationValue2 != null) {
            if (gDurationBuilder.getYear() > gDurationValue2.getYear()) {
                gDurationBuilder.setYear(gDurationValue2.getYear());
            }
            if (gDurationBuilder.getMonth() > gDurationValue2.getMonth()) {
                gDurationBuilder.setMonth(gDurationValue2.getMonth());
            }
            if (gDurationBuilder.getDay() > gDurationValue2.getDay()) {
                gDurationBuilder.setDay(gDurationValue2.getDay());
            }
            if (gDurationBuilder.getHour() > gDurationValue2.getHour()) {
                gDurationBuilder.setHour(gDurationValue2.getHour());
            }
            if (gDurationBuilder.getMinute() > gDurationValue2.getMinute()) {
                gDurationBuilder.setMinute(gDurationValue2.getMinute());
            }
            if (gDurationBuilder.getSecond() > gDurationValue2.getSecond()) {
                gDurationBuilder.setSecond(gDurationValue2.getSecond());
            }
            if (gDurationBuilder.getFraction().compareTo(gDurationValue2.getFraction()) > 0) {
                gDurationBuilder.setFraction(gDurationValue2.getFraction());
            }
        }
        if (gDurationValue3 != null) {
            if (gDurationBuilder.getYear() <= gDurationValue3.getYear()) {
                gDurationBuilder.setYear(gDurationValue3.getYear() + 1);
            }
            if (gDurationBuilder.getMonth() <= gDurationValue3.getMonth()) {
                gDurationBuilder.setMonth(gDurationValue3.getMonth() + 1);
            }
            if (gDurationBuilder.getDay() <= gDurationValue3.getDay()) {
                gDurationBuilder.setDay(gDurationValue3.getDay() + 1);
            }
            if (gDurationBuilder.getHour() <= gDurationValue3.getHour()) {
                gDurationBuilder.setHour(gDurationValue3.getHour() + 1);
            }
            if (gDurationBuilder.getMinute() <= gDurationValue3.getMinute()) {
                gDurationBuilder.setMinute(gDurationValue3.getMinute() + 1);
            }
            if (gDurationBuilder.getSecond() <= gDurationValue3.getSecond()) {
                gDurationBuilder.setSecond(gDurationValue3.getSecond() + 1);
            }
            if (gDurationBuilder.getFraction().compareTo(gDurationValue3.getFraction()) <= 0) {
                gDurationBuilder.setFraction(gDurationValue3.getFraction().add(new BigDecimal(0.001d)));
            }
        }
        if (gDuration != null) {
            if (gDurationBuilder.getYear() > gDuration.getYear()) {
                gDurationBuilder.setYear(gDuration.getYear());
            }
            if (gDurationBuilder.getMonth() > gDuration.getMonth()) {
                gDurationBuilder.setMonth(gDuration.getMonth());
            }
            if (gDurationBuilder.getDay() > gDuration.getDay()) {
                gDurationBuilder.setDay(gDuration.getDay());
            }
            if (gDurationBuilder.getHour() > gDuration.getHour()) {
                gDurationBuilder.setHour(gDuration.getHour());
            }
            if (gDurationBuilder.getMinute() > gDuration.getMinute()) {
                gDurationBuilder.setMinute(gDuration.getMinute());
            }
            if (gDurationBuilder.getSecond() > gDuration.getSecond()) {
                gDurationBuilder.setSecond(gDuration.getSecond());
            }
            if (gDurationBuilder.getFraction().compareTo(gDuration.getFraction()) > 0) {
                gDurationBuilder.setFraction(gDuration.getFraction());
            }
        }
        gDurationBuilder.normalize();
        return gDurationBuilder.toString();
    }

    public static final String formatQName(XmlCursor xmlCursor, QName qName) {
        XmlCursor newCursor = xmlCursor.newCursor();
        newCursor.toParent();
        String prefixForNamespace = newCursor.prefixForNamespace(qName.getNamespaceURI());
        newCursor.dispose();
        if (prefixForNamespace == null || prefixForNamespace.length() == 0) {
            return qName.getLocalPart();
        }
        StringBuffer c = a.c(prefixForNamespace, ":");
        c.append(qName.getLocalPart());
        return c.toString();
    }

    private String formatToLength(String str, SchemaType schemaType) {
        int intValue;
        try {
            SimpleValue simpleValue = (SimpleValue) schemaType.getFacet(0);
            if (simpleValue == null) {
                simpleValue = (SimpleValue) schemaType.getFacet(1);
            }
            if (simpleValue != null) {
                int intValue2 = simpleValue.getIntValue();
                while (str.length() < intValue2) {
                    StringBuffer stringBuffer = new StringBuffer();
                    stringBuffer.append(str);
                    stringBuffer.append(str);
                    str = stringBuffer.toString();
                }
            }
            SimpleValue simpleValue2 = (SimpleValue) schemaType.getFacet(0);
            if (simpleValue2 == null) {
                simpleValue2 = (SimpleValue) schemaType.getFacet(2);
            }
            return (simpleValue2 == null || str.length() <= (intValue = simpleValue2.getIntValue())) ? str : str.substring(0, intValue);
        } catch (Exception unused) {
            return str;
        }
    }

    public static QName getClosestName(SchemaType schemaType) {
        while (schemaType.getName() == null) {
            schemaType = schemaType.getBaseType();
        }
        return schemaType.getName();
    }

    private String getItemNameOrType(SchemaParticle schemaParticle, XmlCursor xmlCursor) {
        if (schemaParticle.getParticleType() != 4) {
            return printParticleType(schemaParticle.getParticleType());
        }
        StringBuffer a = a.a("Element (");
        a.append(schemaParticle.getName().getLocalPart());
        a.append(")");
        return a.toString();
    }

    private void moveToken(int i2, XmlCursor xmlCursor) {
        for (int i3 = 0; i3 < Math.abs(i2); i3++) {
            if (i2 < 0) {
                xmlCursor.toPrevToken();
            } else {
                xmlCursor.toNextToken();
            }
        }
    }

    private int pick(int i2) {
        return this._picker.nextInt(i2);
    }

    private String pickDigits(int i2) {
        StringBuffer stringBuffer = new StringBuffer();
        while (true) {
            int i3 = i2 - 1;
            if (i2 <= 0) {
                return stringBuffer.toString();
            }
            stringBuffer.append(Integer.toString(pick(10)));
            i2 = i3;
        }
    }

    private int pickLength(SchemaType schemaType) {
        int i2;
        int i3 = 0;
        XmlInteger xmlInteger = (XmlInteger) schemaType.getFacet(0);
        if (xmlInteger != null) {
            return xmlInteger.getBigIntegerValue().intValue();
        }
        int i4 = 1;
        XmlInteger xmlInteger2 = (XmlInteger) schemaType.getFacet(1);
        XmlInteger xmlInteger3 = (XmlInteger) schemaType.getFacet(2);
        if (xmlInteger2 != null) {
            i3 = xmlInteger2.getBigIntegerValue().intValue();
        }
        if (xmlInteger3 == null) {
            i2 = Integer.MAX_VALUE;
        } else {
            i2 = xmlInteger3.getBigIntegerValue().intValue();
        }
        if (i3 != 0 || i2 < 1) {
            i4 = i3;
        }
        int i5 = i4 + 2;
        if (i2 > i5) {
            i2 = i5;
        }
        if (i2 < i4) {
            i2 = i4;
        }
        return i4 + pick(i2 - i4);
    }

    private String printParticleType(int i2) {
        StringBuffer a = a.a("Schema Particle Type: ");
        if (i2 == 1) {
            a.append("ALL\n");
        } else if (i2 == 2) {
            a.append("CHOICE\n");
        } else if (i2 == 3) {
            a.append("SEQUENCE\n");
        } else if (i2 == 4) {
            a.append("ELEMENT\n");
        } else if (i2 != 5) {
            a.append("Schema Particle Type Unknown");
        } else {
            a.append("WILDCARD\n");
        }
        return a.toString();
    }

    private void processAll(SchemaParticle schemaParticle, XmlCursor xmlCursor, boolean z) {
        SchemaParticle[] particleChildren = schemaParticle.getParticleChildren();
        for (int i2 = 0; i2 < particleChildren.length; i2++) {
            processParticle(particleChildren[i2], xmlCursor, z);
            if (z && i2 < particleChildren.length - 1) {
                xmlCursor.insertChars(pick(WORDS));
            }
        }
    }

    private void processAttributes(SchemaType schemaType, XmlCursor xmlCursor) {
        QName name;
        if (this._soapEnc && (name = schemaType.getName()) != null) {
            xmlCursor.insertAttributeWithValue(XSI_TYPE, formatQName(xmlCursor, name));
        }
        SchemaProperty[] attributeProperties = schemaType.getAttributeProperties();
        for (SchemaProperty schemaProperty : attributeProperties) {
            if (this._soapEnc) {
                if (!SKIPPED_SOAP_ATTRS.contains(schemaProperty.getName())) {
                    if (ENC_ARRAYTYPE.equals(schemaProperty.getName())) {
                        SOAPArrayType wSDLArrayType = ((SchemaWSDLArrayType) schemaType.getAttributeModel().getAttribute(schemaProperty.getName())).getWSDLArrayType();
                        if (wSDLArrayType != null) {
                            QName name2 = schemaProperty.getName();
                            StringBuffer stringBuffer = new StringBuffer();
                            stringBuffer.append(formatQName(xmlCursor, wSDLArrayType.getQName()));
                            stringBuffer.append(wSDLArrayType.soap11DimensionString());
                            xmlCursor.insertAttributeWithValue(name2, stringBuffer.toString());
                        }
                    }
                }
            }
            String defaultText = schemaProperty.getDefaultText();
            QName name3 = schemaProperty.getName();
            if (defaultText == null) {
                defaultText = sampleDataForSimpleType(schemaProperty.getType());
            }
            xmlCursor.insertAttributeWithValue(name3, defaultText);
        }
    }

    private void processChoice(SchemaParticle schemaParticle, XmlCursor xmlCursor, boolean z) {
        SchemaParticle[] particleChildren = schemaParticle.getParticleChildren();
        StringBuffer a = a.a("You have a CHOICE of the next ");
        a.append(String.valueOf(particleChildren.length));
        a.append(" items at this level");
        xmlCursor.insertComment(a.toString());
        for (SchemaParticle schemaParticle2 : particleChildren) {
            processParticle(schemaParticle2, xmlCursor, z);
        }
    }

    private void processElement(SchemaParticle schemaParticle, XmlCursor xmlCursor, boolean z) {
        SchemaLocalElement schemaLocalElement = (SchemaLocalElement) schemaParticle;
        if (this._soapEnc) {
            xmlCursor.insertElement(schemaLocalElement.getName().getLocalPart());
        } else {
            xmlCursor.insertElement(schemaLocalElement.getName().getLocalPart(), schemaLocalElement.getName().getNamespaceURI());
        }
        this._nElements++;
        xmlCursor.toPrevToken();
        createSampleForType(schemaLocalElement.getType(), xmlCursor);
        xmlCursor.toNextToken();
    }

    private void processParticle(SchemaParticle schemaParticle, XmlCursor xmlCursor, boolean z) {
        int determineMinMaxForSample = determineMinMaxForSample(schemaParticle, xmlCursor);
        while (true) {
            int i2 = determineMinMaxForSample - 1;
            if (determineMinMaxForSample > 0) {
                int particleType = schemaParticle.getParticleType();
                if (particleType == 1) {
                    processAll(schemaParticle, xmlCursor, z);
                } else if (particleType == 2) {
                    processChoice(schemaParticle, xmlCursor, z);
                } else if (particleType == 3) {
                    processSequence(schemaParticle, xmlCursor, z);
                } else if (particleType == 4) {
                    processElement(schemaParticle, xmlCursor, z);
                } else if (particleType == 5) {
                    processWildCard(schemaParticle, xmlCursor, z);
                }
                determineMinMaxForSample = i2;
            } else {
                return;
            }
        }
    }

    private void processSequence(SchemaParticle schemaParticle, XmlCursor xmlCursor, boolean z) {
        SchemaParticle[] particleChildren = schemaParticle.getParticleChildren();
        for (int i2 = 0; i2 < particleChildren.length; i2++) {
            processParticle(particleChildren[i2], xmlCursor, z);
            if (z && i2 < particleChildren.length - 1) {
                xmlCursor.insertChars(pick(WORDS));
            }
        }
    }

    private void processSimpleType(SchemaType schemaType, XmlCursor xmlCursor) {
        xmlCursor.insertChars(sampleDataForSimpleType(schemaType));
    }

    private void processWildCard(SchemaParticle schemaParticle, XmlCursor xmlCursor, boolean z) {
        xmlCursor.insertComment("You may enter ANY elements at this point");
        xmlCursor.insertElement("AnyElement");
    }

    private String sampleDataForSimpleType(SchemaType schemaType) {
        if (XmlObject.type.equals(schemaType)) {
            return "anyType";
        }
        if (XmlAnySimpleType.type.equals(schemaType)) {
            return SchemaSymbols.ATTVAL_ANYSIMPLETYPE;
        }
        if (schemaType.getSimpleVariety() == 3) {
            SchemaType listItemType = schemaType.getListItemType();
            StringBuffer stringBuffer = new StringBuffer();
            int pickLength = pickLength(schemaType);
            if (pickLength > 0) {
                stringBuffer.append(sampleDataForSimpleType(listItemType));
            }
            for (int i2 = 1; i2 < pickLength; i2++) {
                stringBuffer.append(' ');
                stringBuffer.append(sampleDataForSimpleType(listItemType));
            }
            return stringBuffer.toString();
        } else if (schemaType.getSimpleVariety() == 2) {
            SchemaType[] unionConstituentTypes = schemaType.getUnionConstituentTypes();
            if (unionConstituentTypes.length == 0) {
                return "";
            }
            return sampleDataForSimpleType(unionConstituentTypes[pick(unionConstituentTypes.length)]);
        } else {
            XmlAnySimpleType[] enumerationValues = schemaType.getEnumerationValues();
            if (enumerationValues != null && enumerationValues.length > 0) {
                return enumerationValues[pick(enumerationValues.length)].getStringValue();
            }
            switch (schemaType.getPrimitiveType().getBuiltinTypeCode()) {
                case 1:
                case 2:
                    return "anything";
                case 3:
                    return pick(2) == 0 ? SchemaSymbols.ATTVAL_TRUE : SchemaSymbols.ATTVAL_FALSE;
                case 4:
                    try {
                        return new String(Base64.encode(formatToLength(pick(WORDS), schemaType).getBytes("utf-8")));
                    } catch (UnsupportedEncodingException unused) {
                        return null;
                    }
                case 5:
                    return HexBin.encode(formatToLength(pick(WORDS), schemaType));
                case 6:
                    StringBuffer a = a.a("http://www.");
                    a.append(pick(DNS1));
                    a.append(".");
                    a.append(pick(DNS2));
                    a.append(ZipHelper.FORWARD_SLASH);
                    a.append(pick(WORDS));
                    a.append(ZipHelper.FORWARD_SLASH);
                    a.append(pick(WORDS));
                    return formatToLength(a.toString(), schemaType);
                case 7:
                    return formatToLength("qname", schemaType);
                case 8:
                    return formatToLength("notation", schemaType);
                case 9:
                    return "1.5E2";
                case 10:
                    return "1.051732E7";
                case 11:
                    switch (closestBuiltin(schemaType).getBuiltinTypeCode()) {
                        case 22:
                            return formatDecimal("100", schemaType);
                        case 23:
                            return formatDecimal("10", schemaType);
                        case 24:
                            return formatDecimal("3", schemaType);
                        case 25:
                            return formatDecimal("1", schemaType);
                        case 26:
                            return formatDecimal("2", schemaType);
                        case 27:
                            return formatDecimal("-200", schemaType);
                        case 28:
                            return formatDecimal("-201", schemaType);
                        case 29:
                            return formatDecimal("200", schemaType);
                        case 30:
                            return formatDecimal("201", schemaType);
                        case 31:
                            return formatDecimal("11", schemaType);
                        case 32:
                            return formatDecimal("7", schemaType);
                        case 33:
                            return formatDecimal("5", schemaType);
                        case 34:
                            return formatDecimal("6", schemaType);
                        default:
                            return formatDecimal("1000.00", schemaType);
                    }
                case 12:
                    int builtinTypeCode = closestBuiltin(schemaType).getBuiltinTypeCode();
                    String str = SchemaSymbols.ATTVAL_STRING;
                    if (!(builtinTypeCode == 12 || builtinTypeCode == 35 || builtinTypeCode != 36)) {
                        str = SchemaSymbols.ATTVAL_TOKEN;
                    }
                    return formatToLength(str, schemaType);
                case 13:
                    return formatDuration(schemaType);
                case 14:
                case 15:
                case 16:
                case 17:
                case 18:
                case 19:
                case 20:
                case 21:
                    return formatDate(schemaType);
                default:
                    return "";
            }
        }
    }

    private String pick(String[] strArr) {
        return strArr[pick(strArr.length)];
    }

    private String pick(String[] strArr, int i2) {
        if (i2 <= 0) {
            return "";
        }
        int pick = pick(strArr.length);
        StringBuffer stringBuffer = new StringBuffer(strArr[pick]);
        while (true) {
            int i3 = i2 - 1;
            if (i2 <= 0) {
                return stringBuffer.toString();
            }
            pick++;
            if (pick >= strArr.length) {
                pick = 0;
            }
            stringBuffer.append(' ');
            stringBuffer.append(strArr[pick]);
            i2 = i3;
        }
    }

    private void createSampleForType(SchemaType schemaType, XmlCursor xmlCursor) {
        ArrayList arrayList;
        if (!this._typeStack.contains(schemaType)) {
            this._typeStack.add(schemaType);
            try {
                if (!schemaType.isSimpleType()) {
                    if (!schemaType.isURType()) {
                        processAttributes(schemaType, xmlCursor);
                        int contentType = schemaType.getContentType();
                        if (contentType == 2) {
                            processSimpleType(schemaType, xmlCursor);
                        } else if (contentType != 3) {
                            if (contentType == 4) {
                                StringBuffer stringBuffer = new StringBuffer();
                                stringBuffer.append(pick(WORDS));
                                stringBuffer.append(" ");
                                xmlCursor.insertChars(stringBuffer.toString());
                                if (schemaType.getContentModel() != null) {
                                    processParticle(schemaType.getContentModel(), xmlCursor, true);
                                }
                                xmlCursor.insertChars(pick(WORDS));
                            }
                        } else if (schemaType.getContentModel() != null) {
                            processParticle(schemaType.getContentModel(), xmlCursor, false);
                        }
                        ArrayList arrayList2 = this._typeStack;
                        arrayList2.remove(arrayList2.size() - 1);
                        return;
                    }
                }
                processSimpleType(schemaType, xmlCursor);
            } finally {
                arrayList = this._typeStack;
                arrayList.remove(arrayList.size() - 1);
            }
        }
    }
}
