package org.apache.xmlbeans.soap;

import java.util.ArrayList;
import java.util.Iterator;
import org.apache.poi.javax.xml.namespace.QName;
import org.apache.xmlbeans.impl.common.PrefixResolver;
import org.apache.xmlbeans.impl.common.QNameHelper;
import org.apache.xmlbeans.impl.common.XmlWhitespace;
import org.apache.xmlbeans.impl.values.XmlValueOutOfRangeException;

public final class SOAPArrayType {
    public static int[] EMPTY_INT_ARRAY = new int[0];
    public int[] _dimensions;
    public int[] _ranks;
    public QName _type;

    public SOAPArrayType(String str, PrefixResolver prefixResolver) {
        int indexOf = str.indexOf(91);
        if (indexOf >= 0) {
            String collapse = XmlWhitespace.collapse(str.substring(0, indexOf), 3);
            int indexOf2 = collapse.indexOf(58);
            String namespaceForPrefix = prefixResolver.getNamespaceForPrefix(indexOf2 >= 0 ? collapse.substring(0, indexOf2) : "");
            if (namespaceForPrefix != null) {
                this._type = QNameHelper.forLNS(collapse.substring(indexOf2 + 1), namespaceForPrefix);
                initDimensions(str, indexOf);
                return;
            }
            throw new XmlValueOutOfRangeException();
        }
        throw new XmlValueOutOfRangeException();
    }

    private void initDimensions(String str, int i2) {
        ArrayList arrayList = new ArrayList();
        int i3 = -1;
        while (i2 >= 0) {
            i3 = str.indexOf(93, i2);
            if (i3 >= 0) {
                arrayList.add(str.substring(i2 + 1, i3));
                i2 = str.indexOf(91, i3);
            } else {
                throw new XmlValueOutOfRangeException();
            }
        }
        if (XmlWhitespace.isAllSpace(str.substring(i3 + 1))) {
            this._ranks = new int[(arrayList.size() - 1)];
            for (int i4 = 0; i4 < this._ranks.length; i4++) {
                String str2 = (String) arrayList.get(i4);
                int i5 = 0;
                for (int i6 = 0; i6 < str2.length(); i6++) {
                    char charAt = str2.charAt(i6);
                    if (charAt == ',') {
                        i5++;
                    } else if (!XmlWhitespace.isSpace(charAt)) {
                        throw new XmlValueOutOfRangeException();
                    }
                }
                this._ranks[i4] = i5 + 1;
            }
            this._dimensions = internalParseCommaIntString((String) arrayList.get(arrayList.size() - 1));
            return;
        }
        throw new XmlValueOutOfRangeException();
    }

    public static int[] internalParseCommaIntString(String str) {
        ArrayList arrayList = new ArrayList();
        int i2 = 0;
        int i3 = 0;
        while (true) {
            int indexOf = str.indexOf(44, i3);
            if (indexOf < 0) {
                break;
            }
            arrayList.add(str.substring(i3, indexOf));
            i3 = indexOf + 1;
        }
        arrayList.add(str.substring(i3));
        int[] iArr = new int[arrayList.size()];
        Iterator it = arrayList.iterator();
        while (it.hasNext()) {
            String collapse = XmlWhitespace.collapse((String) it.next(), 3);
            if (collapse.equals("*") || collapse.equals("")) {
                iArr[i2] = -1;
            } else {
                try {
                    iArr[i2] = Integer.parseInt(collapse);
                } catch (Exception unused) {
                    throw new XmlValueOutOfRangeException("Malformed integer in SOAP array index");
                }
            }
            i2++;
        }
        return iArr;
    }

    public static SOAPArrayType newSoap12Array(QName qName, String str) {
        int[] iArr = EMPTY_INT_ARRAY;
        String[] split = XmlWhitespace.collapse(str, 3).split(" ");
        int[] iArr2 = new int[split.length];
        for (int i2 = 0; i2 < split.length; i2++) {
            String str2 = split[i2];
            if (i2 != 0 || !str2.equals("*")) {
                try {
                    iArr2[i2] = Integer.parseInt(split[i2]);
                } catch (Exception unused) {
                    throw new XmlValueOutOfRangeException();
                }
            } else {
                iArr2[i2] = -1;
            }
        }
        SOAPArrayType sOAPArrayType = new SOAPArrayType();
        sOAPArrayType._ranks = iArr;
        sOAPArrayType._type = qName;
        sOAPArrayType._dimensions = iArr2;
        return sOAPArrayType;
    }

    public static int[] parseSoap11Index(String str) {
        String collapse = XmlWhitespace.collapse(str, 3);
        if (collapse.startsWith("[") && collapse.endsWith("]")) {
            return internalParseCommaIntString(collapse.substring(1, collapse.length() - 1));
        }
        throw new IllegalArgumentException("Misformed SOAP 1.1 index: must be contained in braces []");
    }

    public boolean containsNestedArrays() {
        return this._ranks.length > 0;
    }

    public boolean equals(Object obj) {
        if (obj == this) {
            return true;
        }
        if (!obj.getClass().equals(SOAPArrayType.class)) {
            return false;
        }
        SOAPArrayType sOAPArrayType = (SOAPArrayType) obj;
        if (!this._type.equals(sOAPArrayType._type) || this._ranks.length != sOAPArrayType._ranks.length || this._dimensions.length != sOAPArrayType._dimensions.length) {
            return false;
        }
        int i2 = 0;
        while (true) {
            int[] iArr = this._ranks;
            if (i2 >= iArr.length) {
                int i3 = 0;
                while (true) {
                    int[] iArr2 = this._dimensions;
                    if (i3 >= iArr2.length) {
                        return true;
                    }
                    if (iArr2[i3] != sOAPArrayType._dimensions[i3]) {
                        return false;
                    }
                    i3++;
                }
            } else if (iArr[i2] != sOAPArrayType._ranks[i2]) {
                return false;
            } else {
                i2++;
            }
        }
    }

    public int[] getDimensions() {
        int[] iArr = this._dimensions;
        int length = iArr.length;
        int[] iArr2 = new int[length];
        System.arraycopy(iArr, 0, iArr2, 0, length);
        return iArr2;
    }

    public QName getQName() {
        return this._type;
    }

    public int[] getRanks() {
        int[] iArr = this._ranks;
        int length = iArr.length;
        int[] iArr2 = new int[length];
        System.arraycopy(iArr, 0, iArr2, 0, length);
        return iArr2;
    }

    public int hashCode() {
        int hashCode = this._type.hashCode();
        int[] iArr = this._dimensions;
        int length = hashCode + iArr.length + this._ranks.length;
        int i2 = 0;
        if (iArr.length != 0) {
            i2 = iArr[0];
        }
        return length + i2;
    }

    public boolean isSameRankAs(SOAPArrayType sOAPArrayType) {
        if (this._ranks.length != sOAPArrayType._ranks.length) {
            return false;
        }
        int i2 = 0;
        while (true) {
            int[] iArr = this._ranks;
            if (i2 < iArr.length) {
                if (iArr[i2] != sOAPArrayType._ranks[i2]) {
                    return false;
                }
                i2++;
            } else if (this._dimensions.length != sOAPArrayType._dimensions.length) {
                return false;
            } else {
                return true;
            }
        }
    }

    public SOAPArrayType nestedArrayType() {
        if (containsNestedArrays()) {
            SOAPArrayType sOAPArrayType = new SOAPArrayType();
            sOAPArrayType._type = this._type;
            int[] iArr = new int[(this._ranks.length - 1)];
            sOAPArrayType._ranks = iArr;
            int i2 = 0;
            System.arraycopy(this._ranks, 0, iArr, 0, iArr.length);
            int[] iArr2 = this._ranks;
            sOAPArrayType._dimensions = new int[iArr2[iArr2.length - 1]];
            while (true) {
                int[] iArr3 = sOAPArrayType._dimensions;
                if (i2 >= iArr3.length) {
                    return sOAPArrayType;
                }
                iArr3[i2] = -1;
                i2++;
            }
        } else {
            throw new IllegalStateException();
        }
    }

    public String soap11DimensionString() {
        return soap11DimensionString(this._dimensions);
    }

    public String soap12DimensionString(int[] iArr) {
        StringBuffer stringBuffer = new StringBuffer();
        for (int i2 = 0; i2 < iArr.length; i2++) {
            if (i2 > 0) {
                stringBuffer.append(' ');
            }
            if (iArr[i2] >= 0) {
                stringBuffer.append(iArr[i2]);
            }
        }
        return stringBuffer.toString();
    }

    public String soap11DimensionString(int[] iArr) {
        StringBuffer stringBuffer = new StringBuffer();
        for (int i2 = 0; i2 < this._ranks.length; i2++) {
            stringBuffer.append('[');
            for (int i3 = 1; i3 < this._ranks[i2]; i3++) {
                stringBuffer.append(',');
            }
            stringBuffer.append(']');
        }
        stringBuffer.append('[');
        for (int i4 = 0; i4 < iArr.length; i4++) {
            if (i4 > 0) {
                stringBuffer.append(',');
            }
            if (iArr[i4] >= 0) {
                stringBuffer.append(iArr[i4]);
            }
        }
        stringBuffer.append(']');
        return stringBuffer.toString();
    }

    public SOAPArrayType(QName qName, String str) {
        int indexOf = str.indexOf(91);
        if (indexOf < 0) {
            this._type = qName;
            this._ranks = EMPTY_INT_ARRAY;
            String[] split = XmlWhitespace.collapse(str, 3).split(" ");
            for (int i2 = 0; i2 < split.length; i2++) {
                if (split[i2].equals("*")) {
                    this._dimensions[i2] = -1;
                } else {
                    try {
                        this._dimensions[i2] = Integer.parseInt(split[i2]);
                    } catch (Exception unused) {
                        throw new XmlValueOutOfRangeException();
                    }
                }
            }
            return;
        }
        this._type = qName;
        initDimensions(str, indexOf);
    }

    public SOAPArrayType(SOAPArrayType sOAPArrayType, int[] iArr) {
        this._type = sOAPArrayType._type;
        int[] iArr2 = new int[(sOAPArrayType._ranks.length + 1)];
        this._ranks = iArr2;
        int[] iArr3 = sOAPArrayType._ranks;
        System.arraycopy(iArr3, 0, iArr2, 0, iArr3.length);
        int[] iArr4 = this._ranks;
        iArr4[iArr4.length - 1] = sOAPArrayType._dimensions.length;
        int[] iArr5 = new int[iArr.length];
        this._dimensions = iArr5;
        System.arraycopy(iArr, 0, iArr5, 0, iArr.length);
    }

    public SOAPArrayType() {
    }
}
