package org.w3c.dom.bootstrap;

import java.io.BufferedReader;
import java.io.InputStream;
import java.io.InputStreamReader;
import java.io.UnsupportedEncodingException;
import java.security.AccessController;
import java.security.PrivilegedAction;
import java.util.StringTokenizer;
import java.util.Vector;
import org.w3c.dom.DOMImplementation;
import org.w3c.dom.DOMImplementationList;
import org.w3c.dom.DOMImplementationSource;

public final class DOMImplementationRegistry {
    public static final String DEFAULT_DOM_IMPLEMENTATION_SOURCE = "org.apache.xerces.dom.DOMXSImplementationSourceImpl";
    public static final int DEFAULT_LINE_LENGTH = 80;
    public static final String PROPERTY = "org.w3c.dom.DOMImplementationSourceList";
    public static /* synthetic */ Class class$org$w3c$dom$bootstrap$DOMImplementationRegistry;
    public Vector sources;

    public DOMImplementationRegistry(Vector vector) {
        this.sources = vector;
    }

    public static /* synthetic */ Class class$(String str) {
        try {
            return Class.forName(str);
        } catch (ClassNotFoundException e2) {
            throw new NoClassDefFoundError(e2.getMessage());
        }
    }

    public static ClassLoader getClassLoader() {
        try {
            ClassLoader contextClassLoader = getContextClassLoader();
            if (contextClassLoader != null) {
                return contextClassLoader;
            }
            Class cls = class$org$w3c$dom$bootstrap$DOMImplementationRegistry;
            if (cls == null) {
                cls = class$("org.w3c.dom.bootstrap.DOMImplementationRegistry");
                class$org$w3c$dom$bootstrap$DOMImplementationRegistry = cls;
            }
            return cls.getClassLoader();
        } catch (Exception unused) {
            Class cls2 = class$org$w3c$dom$bootstrap$DOMImplementationRegistry;
            if (cls2 == null) {
                cls2 = class$("org.w3c.dom.bootstrap.DOMImplementationRegistry");
                class$org$w3c$dom$bootstrap$DOMImplementationRegistry = cls2;
            }
            return cls2.getClassLoader();
        }
    }

    public static ClassLoader getContextClassLoader() {
        if (isJRE11()) {
            return null;
        }
        return (ClassLoader) AccessController.doPrivileged(new PrivilegedAction() {
            /* class org.w3c.dom.bootstrap.DOMImplementationRegistry.AnonymousClass2 */

            @Override // java.security.PrivilegedAction
            public Object run() {
                try {
                    return Thread.currentThread().getContextClassLoader();
                } catch (SecurityException unused) {
                    return null;
                }
            }
        });
    }

    public static InputStream getResourceAsStream(final ClassLoader classLoader, final String str) {
        return isJRE11() ? classLoader == null ? ClassLoader.getSystemResourceAsStream(str) : classLoader.getResourceAsStream(str) : (InputStream) AccessController.doPrivileged(new PrivilegedAction() {
            /* class org.w3c.dom.bootstrap.DOMImplementationRegistry.AnonymousClass4 */

            @Override // java.security.PrivilegedAction
            public Object run() {
                ClassLoader classLoader = classLoader;
                return classLoader == null ? ClassLoader.getSystemResourceAsStream(str) : classLoader.getResourceAsStream(str);
            }
        });
    }

    public static String getServiceValue(ClassLoader classLoader) {
        BufferedReader bufferedReader;
        try {
            InputStream resourceAsStream = getResourceAsStream(classLoader, "META-INF/services/org.w3c.dom.DOMImplementationSourceList");
            if (resourceAsStream != null) {
                try {
                    bufferedReader = new BufferedReader(new InputStreamReader(resourceAsStream, "UTF-8"), 80);
                } catch (UnsupportedEncodingException unused) {
                    bufferedReader = new BufferedReader(new InputStreamReader(resourceAsStream), 80);
                }
                try {
                    String readLine = bufferedReader.readLine();
                    if (readLine == null || readLine.length() <= 0) {
                        return null;
                    }
                    return readLine;
                } finally {
                    bufferedReader.close();
                }
            }
        } catch (Exception unused2) {
        }
        return null;
    }

    public static String getSystemProperty(final String str) {
        return isJRE11() ? System.getProperty(str) : (String) AccessController.doPrivileged(new PrivilegedAction() {
            /* class org.w3c.dom.bootstrap.DOMImplementationRegistry.AnonymousClass3 */

            @Override // java.security.PrivilegedAction
            public Object run() {
                return System.getProperty(str);
            }
        });
    }

    public static boolean isJRE11() {
        try {
            Class.forName("java.security.AccessController");
            return false;
        } catch (Exception unused) {
            return true;
        }
    }

    public static DOMImplementationRegistry newInstance() {
        Vector vector = new Vector();
        ClassLoader classLoader = getClassLoader();
        String systemProperty = getSystemProperty(PROPERTY);
        if (systemProperty == null || systemProperty.length() == 0) {
            systemProperty = getServiceValue(classLoader);
        }
        if (systemProperty == null) {
            systemProperty = DEFAULT_DOM_IMPLEMENTATION_SOURCE;
        }
        StringTokenizer stringTokenizer = new StringTokenizer(systemProperty);
        while (stringTokenizer.hasMoreTokens()) {
            String nextToken = stringTokenizer.nextToken();
            vector.addElement((DOMImplementationSource) (classLoader != null ? classLoader.loadClass(nextToken) : Class.forName(nextToken)).newInstance());
        }
        return new DOMImplementationRegistry(vector);
    }

    public void addSource(DOMImplementationSource dOMImplementationSource) {
        if (dOMImplementationSource == null) {
            throw null;
        } else if (!this.sources.contains(dOMImplementationSource)) {
            this.sources.addElement(dOMImplementationSource);
        }
    }

    public DOMImplementation getDOMImplementation(String str) {
        int size = this.sources.size();
        for (int i2 = 0; i2 < size; i2++) {
            DOMImplementation dOMImplementation = ((DOMImplementationSource) this.sources.elementAt(i2)).getDOMImplementation(str);
            if (dOMImplementation != null) {
                return dOMImplementation;
            }
        }
        return null;
    }

    public DOMImplementationList getDOMImplementationList(String str) {
        final Vector vector = new Vector();
        int size = this.sources.size();
        for (int i2 = 0; i2 < size; i2++) {
            DOMImplementationList dOMImplementationList = ((DOMImplementationSource) this.sources.elementAt(i2)).getDOMImplementationList(str);
            for (int i3 = 0; i3 < dOMImplementationList.getLength(); i3++) {
                vector.addElement(dOMImplementationList.item(i3));
            }
        }
        return new DOMImplementationList() {
            /* class org.w3c.dom.bootstrap.DOMImplementationRegistry.AnonymousClass1 */

            @Override // org.w3c.dom.DOMImplementationList
            public int getLength() {
                return vector.size();
            }

            @Override // org.w3c.dom.DOMImplementationList
            public DOMImplementation item(int i2) {
                if (i2 >= 0 && i2 < vector.size()) {
                    try {
                        return (DOMImplementation) vector.elementAt(i2);
                    } catch (ArrayIndexOutOfBoundsException unused) {
                    }
                }
                return null;
            }
        };
    }
}
