package org.xml.sax.helpers;

import b.b.a.a.a;
import java.util.Enumeration;
import java.util.Vector;
import org.xml.sax.AttributeList;
import org.xml.sax.Attributes;
import org.xml.sax.ContentHandler;
import org.xml.sax.DTDHandler;
import org.xml.sax.DocumentHandler;
import org.xml.sax.EntityResolver;
import org.xml.sax.ErrorHandler;
import org.xml.sax.InputSource;
import org.xml.sax.Locator;
import org.xml.sax.Parser;
import org.xml.sax.SAXException;
import org.xml.sax.SAXNotRecognizedException;
import org.xml.sax.SAXNotSupportedException;
import org.xml.sax.SAXParseException;
import org.xml.sax.XMLReader;

public class ParserAdapter implements XMLReader, DocumentHandler {
    public static final String FEATURES = "http://xml.org/sax/features/";
    public static final String NAMESPACES = "http://xml.org/sax/features/namespaces";
    public static final String NAMESPACE_PREFIXES = "http://xml.org/sax/features/namespace-prefixes";
    public static final String XMLNS_URIs = "http://xml.org/sax/features/xmlns-uris";
    public AttributeListAdapter attAdapter;
    public AttributesImpl atts;
    public ContentHandler contentHandler;
    public DTDHandler dtdHandler;
    public EntityResolver entityResolver;
    public ErrorHandler errorHandler;
    public Locator locator;
    public String[] nameParts;
    public boolean namespaces;
    public NamespaceSupport nsSupport;
    public Parser parser;
    public boolean parsing;
    public boolean prefixes;
    public boolean uris;

    public final class AttributeListAdapter implements Attributes {
        public AttributeList qAtts;

        public AttributeListAdapter() {
        }

        @Override // org.xml.sax.Attributes
        public int getIndex(String str) {
            int length = ParserAdapter.this.atts.getLength();
            for (int i2 = 0; i2 < length; i2++) {
                if (this.qAtts.getName(i2).equals(str)) {
                    return i2;
                }
            }
            return -1;
        }

        @Override // org.xml.sax.Attributes
        public int getIndex(String str, String str2) {
            return -1;
        }

        @Override // org.xml.sax.Attributes
        public int getLength() {
            return this.qAtts.getLength();
        }

        @Override // org.xml.sax.Attributes
        public String getLocalName(int i2) {
            return "";
        }

        @Override // org.xml.sax.Attributes
        public String getQName(int i2) {
            return this.qAtts.getName(i2).intern();
        }

        @Override // org.xml.sax.Attributes
        public String getType(int i2) {
            return this.qAtts.getType(i2).intern();
        }

        @Override // org.xml.sax.Attributes
        public String getType(String str) {
            return this.qAtts.getType(str).intern();
        }

        @Override // org.xml.sax.Attributes
        public String getType(String str, String str2) {
            return null;
        }

        @Override // org.xml.sax.Attributes
        public String getURI(int i2) {
            return "";
        }

        @Override // org.xml.sax.Attributes
        public String getValue(int i2) {
            return this.qAtts.getValue(i2);
        }

        @Override // org.xml.sax.Attributes
        public String getValue(String str) {
            return this.qAtts.getValue(str);
        }

        @Override // org.xml.sax.Attributes
        public String getValue(String str, String str2) {
            return null;
        }

        public void setAttributeList(AttributeList attributeList) {
            this.qAtts = attributeList;
        }
    }

    public ParserAdapter() {
        this.parsing = false;
        this.nameParts = new String[3];
        this.parser = null;
        this.atts = null;
        this.namespaces = true;
        this.prefixes = false;
        this.uris = false;
        this.entityResolver = null;
        this.dtdHandler = null;
        this.contentHandler = null;
        this.errorHandler = null;
        String property = System.getProperty("org.xml.sax.parser");
        try {
            setup(ParserFactory.makeParser());
        } catch (ClassNotFoundException e2) {
            throw new SAXException(a.a("Cannot find SAX1 driver class ", property), e2);
        } catch (IllegalAccessException e3) {
            throw new SAXException(a.a("SAX1 driver class ", property, " found but cannot be loaded"), e3);
        } catch (InstantiationException e4) {
            throw new SAXException(a.a("SAX1 driver class ", property, " loaded but cannot be instantiated"), e4);
        } catch (ClassCastException unused) {
            throw new SAXException(a.a("SAX1 driver class ", property, " does not implement org.xml.sax.Parser"));
        } catch (NullPointerException unused2) {
            throw new SAXException("System property org.xml.sax.parser not specified");
        }
    }

    public ParserAdapter(Parser parser2) {
        this.parsing = false;
        this.nameParts = new String[3];
        this.parser = null;
        this.atts = null;
        this.namespaces = true;
        this.prefixes = false;
        this.uris = false;
        this.entityResolver = null;
        this.dtdHandler = null;
        this.contentHandler = null;
        this.errorHandler = null;
        setup(parser2);
    }

    private void checkNotParsing(String str, String str2) {
        if (this.parsing) {
            StringBuffer stringBuffer = new StringBuffer();
            stringBuffer.append("Cannot change ");
            stringBuffer.append(str);
            stringBuffer.append(' ');
            stringBuffer.append(str2);
            stringBuffer.append(" while parsing");
            throw new SAXNotSupportedException(stringBuffer.toString());
        }
    }

    private SAXParseException makeException(String str) {
        return this.locator != null ? new SAXParseException(str, this.locator) : new SAXParseException(str, null, null, -1, -1);
    }

    private String[] processName(String str, boolean z, boolean z2) {
        String[] processName = this.nsSupport.processName(str, this.nameParts, z);
        if (processName != null) {
            return processName;
        }
        if (!z2) {
            StringBuffer stringBuffer = new StringBuffer();
            stringBuffer.append("Undeclared prefix: ");
            stringBuffer.append(str);
            reportError(stringBuffer.toString());
            String[] strArr = new String[3];
            strArr[1] = "";
            strArr[0] = "";
            strArr[2] = str.intern();
            return strArr;
        }
        throw makeException(a.a("Undeclared prefix: ", str));
    }

    private void setup(Parser parser2) {
        if (parser2 != null) {
            this.parser = parser2;
            this.atts = new AttributesImpl();
            this.nsSupport = new NamespaceSupport();
            this.attAdapter = new AttributeListAdapter();
            return;
        }
        throw new NullPointerException("Parser argument must not be null");
    }

    private void setupParser() {
        if (this.prefixes || this.namespaces) {
            this.nsSupport.reset();
            if (this.uris) {
                this.nsSupport.setNamespaceDeclUris(true);
            }
            EntityResolver entityResolver2 = this.entityResolver;
            if (entityResolver2 != null) {
                this.parser.setEntityResolver(entityResolver2);
            }
            DTDHandler dTDHandler = this.dtdHandler;
            if (dTDHandler != null) {
                this.parser.setDTDHandler(dTDHandler);
            }
            ErrorHandler errorHandler2 = this.errorHandler;
            if (errorHandler2 != null) {
                this.parser.setErrorHandler(errorHandler2);
            }
            this.parser.setDocumentHandler(this);
            this.locator = null;
            return;
        }
        throw new IllegalStateException();
    }

    @Override // org.xml.sax.DocumentHandler
    public void characters(char[] cArr, int i2, int i3) {
        ContentHandler contentHandler2 = this.contentHandler;
        if (contentHandler2 != null) {
            contentHandler2.characters(cArr, i2, i3);
        }
    }

    @Override // org.xml.sax.DocumentHandler
    public void endDocument() {
        ContentHandler contentHandler2 = this.contentHandler;
        if (contentHandler2 != null) {
            contentHandler2.endDocument();
        }
    }

    @Override // org.xml.sax.DocumentHandler
    public void endElement(String str) {
        if (!this.namespaces) {
            ContentHandler contentHandler2 = this.contentHandler;
            if (contentHandler2 != null) {
                contentHandler2.endElement("", "", str.intern());
                return;
            }
            return;
        }
        String[] processName = processName(str, false, false);
        ContentHandler contentHandler3 = this.contentHandler;
        if (contentHandler3 != null) {
            contentHandler3.endElement(processName[0], processName[1], processName[2]);
            Enumeration declaredPrefixes = this.nsSupport.getDeclaredPrefixes();
            while (declaredPrefixes.hasMoreElements()) {
                this.contentHandler.endPrefixMapping((String) declaredPrefixes.nextElement());
            }
        }
        this.nsSupport.popContext();
    }

    @Override // org.xml.sax.XMLReader
    public ContentHandler getContentHandler() {
        return this.contentHandler;
    }

    @Override // org.xml.sax.XMLReader
    public DTDHandler getDTDHandler() {
        return this.dtdHandler;
    }

    @Override // org.xml.sax.XMLReader
    public EntityResolver getEntityResolver() {
        return this.entityResolver;
    }

    @Override // org.xml.sax.XMLReader
    public ErrorHandler getErrorHandler() {
        return this.errorHandler;
    }

    @Override // org.xml.sax.XMLReader
    public boolean getFeature(String str) {
        if (str.equals("http://xml.org/sax/features/namespaces")) {
            return this.namespaces;
        }
        if (str.equals("http://xml.org/sax/features/namespace-prefixes")) {
            return this.prefixes;
        }
        if (str.equals(XMLNS_URIs)) {
            return this.uris;
        }
        throw new SAXNotRecognizedException(a.a("Feature: ", str));
    }

    @Override // org.xml.sax.XMLReader
    public Object getProperty(String str) {
        throw new SAXNotRecognizedException(a.a("Property: ", str));
    }

    @Override // org.xml.sax.DocumentHandler
    public void ignorableWhitespace(char[] cArr, int i2, int i3) {
        ContentHandler contentHandler2 = this.contentHandler;
        if (contentHandler2 != null) {
            contentHandler2.ignorableWhitespace(cArr, i2, i3);
        }
    }

    @Override // org.xml.sax.XMLReader
    public void parse(String str) {
        parse(new InputSource(str));
    }

    @Override // org.xml.sax.XMLReader
    public void parse(InputSource inputSource) {
        if (!this.parsing) {
            setupParser();
            this.parsing = true;
            try {
                this.parser.parse(inputSource);
                this.parsing = false;
            } finally {
                this.parsing = false;
            }
        } else {
            throw new SAXException("Parser is already in use");
        }
    }

    @Override // org.xml.sax.DocumentHandler
    public void processingInstruction(String str, String str2) {
        ContentHandler contentHandler2 = this.contentHandler;
        if (contentHandler2 != null) {
            contentHandler2.processingInstruction(str, str2);
        }
    }

    public void reportError(String str) {
        ErrorHandler errorHandler2 = this.errorHandler;
        if (errorHandler2 != null) {
            errorHandler2.error(makeException(str));
        }
    }

    @Override // org.xml.sax.XMLReader
    public void setContentHandler(ContentHandler contentHandler2) {
        this.contentHandler = contentHandler2;
    }

    @Override // org.xml.sax.XMLReader
    public void setDTDHandler(DTDHandler dTDHandler) {
        this.dtdHandler = dTDHandler;
    }

    @Override // org.xml.sax.DocumentHandler
    public void setDocumentLocator(Locator locator2) {
        this.locator = locator2;
        ContentHandler contentHandler2 = this.contentHandler;
        if (contentHandler2 != null) {
            contentHandler2.setDocumentLocator(locator2);
        }
    }

    @Override // org.xml.sax.XMLReader
    public void setEntityResolver(EntityResolver entityResolver2) {
        this.entityResolver = entityResolver2;
    }

    @Override // org.xml.sax.XMLReader
    public void setErrorHandler(ErrorHandler errorHandler2) {
        this.errorHandler = errorHandler2;
    }

    @Override // org.xml.sax.XMLReader
    public void setFeature(String str, boolean z) {
        if (str.equals("http://xml.org/sax/features/namespaces")) {
            checkNotParsing("feature", str);
            this.namespaces = z;
            if (!z && !this.prefixes) {
                this.prefixes = true;
            }
        } else if (str.equals("http://xml.org/sax/features/namespace-prefixes")) {
            checkNotParsing("feature", str);
            this.prefixes = z;
            if (!z && !this.namespaces) {
                this.namespaces = true;
            }
        } else if (str.equals(XMLNS_URIs)) {
            checkNotParsing("feature", str);
            this.uris = z;
        } else {
            throw new SAXNotRecognizedException(a.a("Feature: ", str));
        }
    }

    @Override // org.xml.sax.XMLReader
    public void setProperty(String str, Object obj) {
        throw new SAXNotRecognizedException(a.a("Property: ", str));
    }

    @Override // org.xml.sax.DocumentHandler
    public void startDocument() {
        ContentHandler contentHandler2 = this.contentHandler;
        if (contentHandler2 != null) {
            contentHandler2.startDocument();
        }
    }

    @Override // org.xml.sax.DocumentHandler
    public void startElement(String str, AttributeList attributeList) {
        int i2;
        String str2;
        String str3;
        AttributesImpl attributesImpl;
        String str4;
        if (this.namespaces) {
            this.nsSupport.pushContext();
            int length = attributeList.getLength();
            int i3 = 0;
            while (true) {
                i2 = -1;
                if (i3 >= length) {
                    break;
                }
                String name = attributeList.getName(i3);
                if (name.startsWith("xmlns")) {
                    int indexOf = name.indexOf(58);
                    if (indexOf == -1 && name.length() == 5) {
                        str4 = "";
                    } else if (indexOf == 5) {
                        str4 = name.substring(indexOf + 1);
                    }
                    String value = attributeList.getValue(i3);
                    if (!this.nsSupport.declarePrefix(str4, value)) {
                        StringBuffer stringBuffer = new StringBuffer();
                        stringBuffer.append("Illegal Namespace prefix: ");
                        stringBuffer.append(str4);
                        reportError(stringBuffer.toString());
                    } else {
                        ContentHandler contentHandler2 = this.contentHandler;
                        if (contentHandler2 != null) {
                            contentHandler2.startPrefixMapping(str4, value);
                        }
                    }
                }
                i3++;
            }
            this.atts.clear();
            int i4 = 0;
            Vector vector = null;
            while (i4 < length) {
                String name2 = attributeList.getName(i4);
                String type = attributeList.getType(i4);
                String value2 = attributeList.getValue(i4);
                if (name2.startsWith("xmlns")) {
                    int indexOf2 = name2.indexOf(58);
                    String substring = (indexOf2 == i2 && name2.length() == 5) ? "" : indexOf2 != 5 ? null : name2.substring(6);
                    if (substring != null) {
                        if (this.prefixes) {
                            if (this.uris) {
                                attributesImpl = this.atts;
                                str2 = name2.intern();
                                str3 = "http://www.w3.org/XML/1998/namespace";
                            } else {
                                attributesImpl = this.atts;
                                str2 = name2.intern();
                                str3 = "";
                                substring = "";
                            }
                            attributesImpl.addAttribute(str3, substring, str2, type, value2);
                        }
                        i4++;
                        i2 = -1;
                    }
                }
                try {
                    String[] processName = processName(name2, true, true);
                    this.atts.addAttribute(processName[0], processName[1], processName[2], type, value2);
                } catch (SAXException e2) {
                    if (vector == null) {
                        vector = new Vector();
                    }
                    vector.addElement(e2);
                    this.atts.addAttribute("", name2, name2, type, value2);
                }
                i4++;
                i2 = -1;
            }
            if (!(vector == null || this.errorHandler == null)) {
                for (int i5 = 0; i5 < vector.size(); i5++) {
                    this.errorHandler.error((SAXParseException) vector.elementAt(i5));
                }
            }
            if (this.contentHandler != null) {
                String[] processName2 = processName(str, false, false);
                this.contentHandler.startElement(processName2[0], processName2[1], processName2[2], this.atts);
            }
        } else if (this.contentHandler != null) {
            this.attAdapter.setAttributeList(attributeList);
            this.contentHandler.startElement("", "", str.intern(), this.attAdapter);
        }
    }
}
