package org.xml.sax.helpers;

import java.util.Locale;
import org.xml.sax.AttributeList;
import org.xml.sax.Attributes;
import org.xml.sax.ContentHandler;
import org.xml.sax.DTDHandler;
import org.xml.sax.DocumentHandler;
import org.xml.sax.EntityResolver;
import org.xml.sax.ErrorHandler;
import org.xml.sax.InputSource;
import org.xml.sax.Locator;
import org.xml.sax.Parser;
import org.xml.sax.SAXException;
import org.xml.sax.SAXNotSupportedException;
import org.xml.sax.XMLReader;

public class XMLReaderAdapter implements Parser, ContentHandler {
    public DocumentHandler documentHandler;
    public AttributesAdapter qAtts;
    public XMLReader xmlReader;

    public final class AttributesAdapter implements AttributeList {
        public Attributes attributes;

        public AttributesAdapter() {
        }

        @Override // org.xml.sax.AttributeList
        public int getLength() {
            return this.attributes.getLength();
        }

        @Override // org.xml.sax.AttributeList
        public String getName(int i2) {
            return this.attributes.getQName(i2);
        }

        @Override // org.xml.sax.AttributeList
        public String getType(int i2) {
            return this.attributes.getType(i2);
        }

        @Override // org.xml.sax.AttributeList
        public String getType(String str) {
            return this.attributes.getType(str);
        }

        @Override // org.xml.sax.AttributeList
        public String getValue(int i2) {
            return this.attributes.getValue(i2);
        }

        @Override // org.xml.sax.AttributeList
        public String getValue(String str) {
            return this.attributes.getValue(str);
        }

        public void setAttributes(Attributes attributes2) {
            this.attributes = attributes2;
        }
    }

    public XMLReaderAdapter() {
        setup(XMLReaderFactory.createXMLReader());
    }

    public XMLReaderAdapter(XMLReader xMLReader) {
        setup(xMLReader);
    }

    private void setup(XMLReader xMLReader) {
        if (xMLReader != null) {
            this.xmlReader = xMLReader;
            this.qAtts = new AttributesAdapter();
            return;
        }
        throw new NullPointerException("XMLReader must not be null");
    }

    private void setupXMLReader() {
        this.xmlReader.setFeature("http://xml.org/sax/features/namespace-prefixes", true);
        try {
            this.xmlReader.setFeature("http://xml.org/sax/features/namespaces", false);
        } catch (SAXException unused) {
        }
        this.xmlReader.setContentHandler(this);
    }

    @Override // org.xml.sax.ContentHandler
    public void characters(char[] cArr, int i2, int i3) {
        DocumentHandler documentHandler2 = this.documentHandler;
        if (documentHandler2 != null) {
            documentHandler2.characters(cArr, i2, i3);
        }
    }

    @Override // org.xml.sax.ContentHandler
    public void endDocument() {
        DocumentHandler documentHandler2 = this.documentHandler;
        if (documentHandler2 != null) {
            documentHandler2.endDocument();
        }
    }

    @Override // org.xml.sax.ContentHandler
    public void endElement(String str, String str2, String str3) {
        DocumentHandler documentHandler2 = this.documentHandler;
        if (documentHandler2 != null) {
            documentHandler2.endElement(str3);
        }
    }

    @Override // org.xml.sax.ContentHandler
    public void endPrefixMapping(String str) {
    }

    @Override // org.xml.sax.ContentHandler
    public void ignorableWhitespace(char[] cArr, int i2, int i3) {
        DocumentHandler documentHandler2 = this.documentHandler;
        if (documentHandler2 != null) {
            documentHandler2.ignorableWhitespace(cArr, i2, i3);
        }
    }

    @Override // org.xml.sax.Parser
    public void parse(String str) {
        parse(new InputSource(str));
    }

    @Override // org.xml.sax.Parser
    public void parse(InputSource inputSource) {
        setupXMLReader();
        this.xmlReader.parse(inputSource);
    }

    @Override // org.xml.sax.ContentHandler
    public void processingInstruction(String str, String str2) {
        DocumentHandler documentHandler2 = this.documentHandler;
        if (documentHandler2 != null) {
            documentHandler2.processingInstruction(str, str2);
        }
    }

    @Override // org.xml.sax.Parser
    public void setDTDHandler(DTDHandler dTDHandler) {
        this.xmlReader.setDTDHandler(dTDHandler);
    }

    @Override // org.xml.sax.Parser
    public void setDocumentHandler(DocumentHandler documentHandler2) {
        this.documentHandler = documentHandler2;
    }

    @Override // org.xml.sax.ContentHandler
    public void setDocumentLocator(Locator locator) {
        DocumentHandler documentHandler2 = this.documentHandler;
        if (documentHandler2 != null) {
            documentHandler2.setDocumentLocator(locator);
        }
    }

    @Override // org.xml.sax.Parser
    public void setEntityResolver(EntityResolver entityResolver) {
        this.xmlReader.setEntityResolver(entityResolver);
    }

    @Override // org.xml.sax.Parser
    public void setErrorHandler(ErrorHandler errorHandler) {
        this.xmlReader.setErrorHandler(errorHandler);
    }

    @Override // org.xml.sax.Parser
    public void setLocale(Locale locale) {
        throw new SAXNotSupportedException("setLocale not supported");
    }

    @Override // org.xml.sax.ContentHandler
    public void skippedEntity(String str) {
    }

    @Override // org.xml.sax.ContentHandler
    public void startDocument() {
        DocumentHandler documentHandler2 = this.documentHandler;
        if (documentHandler2 != null) {
            documentHandler2.startDocument();
        }
    }

    @Override // org.xml.sax.ContentHandler
    public void startElement(String str, String str2, String str3, Attributes attributes) {
        if (this.documentHandler != null) {
            this.qAtts.setAttributes(attributes);
            this.documentHandler.startElement(str3, this.qAtts);
        }
    }

    @Override // org.xml.sax.ContentHandler
    public void startPrefixMapping(String str, String str2) {
    }
}
