package org.apache.poi.dev;

import java.io.BufferedOutputStream;
import java.io.File;
import java.io.FileOutputStream;
import java.io.IOException;
import java.io.OutputStream;
import java.io.PrintStream;
import java.util.Enumeration;
import java.util.zip.ZipEntry;
import java.util.zip.ZipFile;
import java.util.zip.ZipOutputStream;
import javax.xml.parsers.DocumentBuilder;
import javax.xml.parsers.DocumentBuilderFactory;
import javax.xml.transform.OutputKeys;
import javax.xml.transform.Transformer;
import javax.xml.transform.TransformerFactory;
import javax.xml.transform.dom.DOMSource;
import javax.xml.transform.stream.StreamResult;
import org.apache.poi.openxml4j.opc.internal.ZipHelper;
import org.apache.poi.openxml4j.util.ZipSecureFile;
import org.apache.poi.util.IOUtils;
import org.w3c.dom.Document;
import org.xml.sax.InputSource;

public class OOXMLPrettyPrint {
    public final DocumentBuilder documentBuilder;
    public final DocumentBuilderFactory documentBuilderFactory = DocumentBuilderFactory.newInstance();

    public OOXMLPrettyPrint() {
        ZipSecureFile.setMinInflateRatio(1.0E-5d);
        this.documentBuilder = this.documentBuilderFactory.newDocumentBuilder();
    }

    private void handle(ZipFile zipFile, ZipOutputStream zipOutputStream) {
        Enumeration<? extends ZipEntry> entries = zipFile.entries();
        while (entries.hasMoreElements()) {
            ZipEntry zipEntry = (ZipEntry) entries.nextElement();
            String name = zipEntry.getName();
            zipOutputStream.putNextEntry(new ZipEntry(name));
            try {
                if (!name.endsWith(".xml")) {
                    if (!name.endsWith(".rels")) {
                        PrintStream printStream = System.out;
                        printStream.println("Not pretty-printing non-XML file " + name);
                        IOUtils.copy(zipFile.getInputStream(zipEntry), zipOutputStream);
                        zipOutputStream.closeEntry();
                        System.out.print(".");
                    }
                }
                Document parse = this.documentBuilder.parse(new InputSource(zipFile.getInputStream(zipEntry)));
                parse.setXmlStandalone(true);
                pretty(parse, zipOutputStream, 2);
                zipOutputStream.closeEntry();
                System.out.print(".");
            } catch (Exception e2) {
                throw new IOException("While handling entry " + name, e2);
            } catch (Throwable th) {
                zipOutputStream.closeEntry();
                throw th;
            }
        }
    }

    /* JADX INFO: finally extract failed */
    public static void handleFile(File file, File file2) {
        PrintStream printStream = System.out;
        printStream.println("Reading zip-file " + file + " and writing pretty-printed XML to " + file2);
        ZipFile openZipFile = ZipHelper.openZipFile(file);
        try {
            ZipOutputStream zipOutputStream = new ZipOutputStream(new BufferedOutputStream(new FileOutputStream(file2)));
            try {
                new OOXMLPrettyPrint().handle(openZipFile, zipOutputStream);
                zipOutputStream.close();
            } catch (Throwable th) {
                zipOutputStream.close();
                throw th;
            }
        } finally {
            openZipFile.close();
            System.out.println();
        }
    }

    public static void main(String[] strArr) {
        if (strArr.length <= 1 || strArr.length % 2 != 0) {
            System.err.println("Use:");
            System.err.println("\tjava OOXMLPrettyPrint [<filename> <outfilename>] ...");
            System.exit(1);
        }
        for (int i2 = 0; i2 < strArr.length; i2 += 2) {
            File file = new File(strArr[i2]);
            if (!file.exists()) {
                System.err.println("Error, file not found!");
                PrintStream printStream = System.err;
                printStream.println("\t" + file);
                System.exit(2);
            }
            handleFile(file, new File(strArr[i2 + 1]));
        }
        System.out.println("Done.");
    }

    public static void pretty(Document document, OutputStream outputStream, int i2) {
        Transformer newTransformer = TransformerFactory.newInstance().newTransformer();
        newTransformer.setOutputProperty(OutputKeys.ENCODING, "UTF-8");
        if (i2 > 0) {
            newTransformer.setOutputProperty(OutputKeys.INDENT, "yes");
            newTransformer.setOutputProperty("{http://xml.apache.org/xslt}indent-amount", Integer.toString(i2));
        }
        newTransformer.transform(new DOMSource(document), new StreamResult(outputStream));
    }
}
