package org.apache.poi.hdgf.chunks;

import b.b.a.a.a;
import java.io.BufferedReader;
import java.io.InputStream;
import java.io.InputStreamReader;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.Map;
import java.util.StringTokenizer;
import org.apache.poi.util.LocaleUtil;
import org.apache.poi.util.POILogFactory;
import org.apache.poi.util.POILogger;

public final class ChunkFactory {
    public static final String chunkTableName = "/org/apache/poi/hdgf/chunks_parse_cmds.tbl";
    public static final POILogger logger = POILogFactory.getLogger(ChunkFactory.class);
    public final Map<Integer, CommandDefinition[]> chunkCommandDefinitions = new HashMap();
    public int version;

    public static class CommandDefinition {
        public String name;
        public int offset;
        public int type;

        public CommandDefinition(int i2, int i3, String str) {
            this.type = i2;
            this.offset = i3;
            this.name = str;
        }

        public String getName() {
            return this.name;
        }

        public int getOffset() {
            return this.offset;
        }

        public int getType() {
            return this.type;
        }
    }

    public ChunkFactory(int i2) {
        this.version = i2;
        processChunkParseCommands();
    }

    /* JADX WARNING: Removed duplicated region for block: B:36:0x00cb  */
    /* JADX WARNING: Removed duplicated region for block: B:38:0x00d0  */
    private void processChunkParseCommands() {
        BufferedReader bufferedReader;
        InputStream inputStream;
        Throwable th;
        try {
            inputStream = ChunkFactory.class.getResourceAsStream(chunkTableName);
            if (inputStream != null) {
                try {
                    bufferedReader = new BufferedReader(new InputStreamReader(inputStream, LocaleUtil.CHARSET_1252));
                    while (true) {
                        try {
                            String readLine = bufferedReader.readLine();
                            if (readLine == null) {
                                bufferedReader.close();
                                inputStream.close();
                                return;
                            } else if (!readLine.isEmpty()) {
                                if (!"# \t".contains(readLine.substring(0, 1))) {
                                    if (readLine.matches("^start [0-9]+$")) {
                                        int parseInt = Integer.parseInt(readLine.substring(6));
                                        ArrayList arrayList = new ArrayList();
                                        while (true) {
                                            String readLine2 = bufferedReader.readLine();
                                            if (readLine2 == null) {
                                                break;
                                            } else if (readLine2.startsWith("end")) {
                                                break;
                                            } else {
                                                StringTokenizer stringTokenizer = new StringTokenizer(readLine2, " ");
                                                arrayList.add(new CommandDefinition(Integer.parseInt(stringTokenizer.nextToken()), Integer.parseInt(stringTokenizer.nextToken()), stringTokenizer.nextToken("￿").substring(1)));
                                            }
                                        }
                                        this.chunkCommandDefinitions.put(Integer.valueOf(parseInt), (CommandDefinition[]) arrayList.toArray(new CommandDefinition[arrayList.size()]));
                                    } else {
                                        throw new IllegalStateException("Expecting start xxx, found " + readLine);
                                    }
                                }
                            }
                        } catch (Throwable th2) {
                            th = th2;
                            if (bufferedReader != null) {
                            }
                            if (inputStream != null) {
                            }
                            throw th;
                        }
                    }
                } catch (Throwable th3) {
                    bufferedReader = null;
                    th = th3;
                    if (bufferedReader != null) {
                    }
                    if (inputStream != null) {
                    }
                    throw th;
                }
            } else {
                throw new IllegalStateException("Unable to find HDGF chunk definition on the classpath - /org/apache/poi/hdgf/chunks_parse_cmds.tbl");
            }
        } catch (Throwable th4) {
            bufferedReader = null;
            th = th4;
            inputStream = null;
            if (bufferedReader != null) {
                bufferedReader.close();
            }
            if (inputStream != null) {
                inputStream.close();
            }
            throw th;
        }
    }

    /* JADX WARNING: Removed duplicated region for block: B:19:0x009d  */
    /* JADX WARNING: Removed duplicated region for block: B:25:0x00e1  */
    public Chunk createChunk(byte[] bArr, int i2) {
        ChunkTrailer chunkTrailer;
        CommandDefinition[] commandDefinitionArr;
        ChunkHeader createChunkHeader = ChunkHeader.createChunkHeader(this.version, bArr, i2);
        if (createChunkHeader.getLength() >= 0) {
            int sizeInBytes = createChunkHeader.getSizeInBytes() + createChunkHeader.getLength() + i2;
            if (sizeInBytes > bArr.length) {
                POILogger pOILogger = logger;
                StringBuilder b2 = a.b("Header called for ");
                b2.append(createChunkHeader.getLength());
                b2.append(" bytes, but that would take us past the end of the data!");
                pOILogger.log(5, b2.toString());
                int length = bArr.length;
                createChunkHeader.setLength((bArr.length - i2) - createChunkHeader.getSizeInBytes());
                if (createChunkHeader.hasTrailer()) {
                    createChunkHeader.setLength(createChunkHeader.getLength() - 8);
                    length -= 8;
                }
                sizeInBytes = length;
                if (createChunkHeader.hasSeparator()) {
                    createChunkHeader.setLength(createChunkHeader.getLength() - 4);
                    sizeInBytes -= 4;
                }
            }
            ChunkSeparator chunkSeparator = null;
            if (createChunkHeader.hasTrailer()) {
                if (sizeInBytes <= bArr.length - 8) {
                    chunkTrailer = new ChunkTrailer(bArr, sizeInBytes);
                    sizeInBytes += 8;
                    if (createChunkHeader.hasSeparator()) {
                        if (sizeInBytes <= bArr.length - 4) {
                            chunkSeparator = new ChunkSeparator(bArr, sizeInBytes);
                        } else {
                            logger.log(7, a.a(a.a("Header claims a length to ", sizeInBytes, " there's then no space for the separator in the data ("), bArr.length, ")"));
                        }
                    }
                    int length2 = createChunkHeader.getLength();
                    byte[] bArr2 = new byte[length2];
                    System.arraycopy(bArr, createChunkHeader.getSizeInBytes() + i2, bArr2, 0, length2);
                    Chunk chunk = new Chunk(createChunkHeader, chunkTrailer, chunkSeparator, bArr2);
                    commandDefinitionArr = this.chunkCommandDefinitions.get(Integer.valueOf(createChunkHeader.getType()));
                    if (commandDefinitionArr == null) {
                        commandDefinitionArr = new CommandDefinition[0];
                    }
                    chunk.commandDefinitions = commandDefinitionArr;
                    chunk.processCommands();
                    return chunk;
                }
                logger.log(7, a.a(a.a("Header claims a length to ", sizeInBytes, " there's then no space for the trailer in the data ("), bArr.length, ")"));
            }
            chunkTrailer = null;
            if (createChunkHeader.hasSeparator()) {
            }
            int length22 = createChunkHeader.getLength();
            byte[] bArr22 = new byte[length22];
            System.arraycopy(bArr, createChunkHeader.getSizeInBytes() + i2, bArr22, 0, length22);
            Chunk chunk2 = new Chunk(createChunkHeader, chunkTrailer, chunkSeparator, bArr22);
            commandDefinitionArr = this.chunkCommandDefinitions.get(Integer.valueOf(createChunkHeader.getType()));
            if (commandDefinitionArr == null) {
            }
            chunk2.commandDefinitions = commandDefinitionArr;
            chunk2.processCommands();
            return chunk2;
        }
        throw new IllegalArgumentException("Found a chunk with a negative length, which isn't allowed");
    }

    public int getVersion() {
        return this.version;
    }
}
