package org.apache.poi.hpbf.extractor;

import java.io.FileInputStream;
import java.io.InputStream;
import org.apache.poi.POIOLE2TextExtractor;
import org.apache.poi.hpbf.HPBFDocument;
import org.apache.poi.hpbf.model.qcbits.QCBit;
import org.apache.poi.hpbf.model.qcbits.QCPLCBit;
import org.apache.poi.hpbf.model.qcbits.QCTextBit;
import org.apache.poi.poifs.filesystem.DirectoryNode;
import org.apache.poi.poifs.filesystem.NPOIFSFileSystem;
import org.apache.poi.poifs.filesystem.POIFSFileSystem;
import org.apache.poi.ss.formula.FormulaParser;
import org.apache.poi.ss.formula.ptg.LessThanPtg;

public final class PublisherTextExtractor extends POIOLE2TextExtractor {
    public HPBFDocument doc;
    public boolean hyperlinksByDefault;

    public PublisherTextExtractor(HPBFDocument hPBFDocument) {
        super(hPBFDocument);
        this.hyperlinksByDefault = false;
        this.doc = hPBFDocument;
    }

    /* JADX INFO: finally extract failed */
    public static void main(String[] strArr) {
        if (strArr.length == 0) {
            System.err.println("Use:");
            System.err.println("  PublisherTextExtractor <file.pub>");
        }
        for (String str : strArr) {
            FileInputStream fileInputStream = new FileInputStream(str);
            try {
                PublisherTextExtractor publisherTextExtractor = new PublisherTextExtractor(fileInputStream);
                System.out.println(publisherTextExtractor.getText());
                publisherTextExtractor.close();
                fileInputStream.close();
            } catch (Throwable th) {
                fileInputStream.close();
                throw th;
            }
        }
    }

    @Override // org.apache.poi.POITextExtractor
    public String getText() {
        StringBuffer stringBuffer = new StringBuffer();
        QCBit[] bits = this.doc.getQuillContents().getBits();
        for (int i2 = 0; i2 < bits.length; i2++) {
            if (bits[i2] != null && (bits[i2] instanceof QCTextBit)) {
                stringBuffer.append(((QCTextBit) bits[i2]).getText().replace(FormulaParser.CR, '\n'));
            }
        }
        if (this.hyperlinksByDefault) {
            for (int i3 = 0; i3 < bits.length; i3++) {
                if (bits[i3] != null && (bits[i3] instanceof QCPLCBit.Type12)) {
                    QCPLCBit.Type12 type12 = (QCPLCBit.Type12) bits[i3];
                    for (int i4 = 0; i4 < type12.getNumberOfHyperlinks(); i4++) {
                        stringBuffer.append(LessThanPtg.LESSTHAN);
                        stringBuffer.append(type12.getHyperlink(i4));
                        stringBuffer.append(">\n");
                    }
                }
            }
        }
        return stringBuffer.toString();
    }

    public void setHyperlinksByDefault(boolean z) {
        this.hyperlinksByDefault = z;
    }

    public PublisherTextExtractor(DirectoryNode directoryNode) {
        this(new HPBFDocument(directoryNode));
    }

    public PublisherTextExtractor(POIFSFileSystem pOIFSFileSystem) {
        this(new HPBFDocument(pOIFSFileSystem));
    }

    public PublisherTextExtractor(NPOIFSFileSystem nPOIFSFileSystem) {
        this(new HPBFDocument(nPOIFSFileSystem));
    }

    public PublisherTextExtractor(InputStream inputStream) {
        this(new POIFSFileSystem(inputStream));
    }
}
