package org.apache.poi.hpsf;

import b.b.a.a.a;
import java.math.BigInteger;
import org.apache.poi.util.Internal;
import org.apache.poi.util.LittleEndianByteArrayInputStream;
import org.apache.poi.util.POILogFactory;
import org.apache.poi.util.POILogger;

@Internal
public class TypedPropertyValue {
    public static final POILogger LOG = POILogFactory.getLogger(TypedPropertyValue.class);
    public int _type;
    public Object _value;

    public TypedPropertyValue(int i2, Object obj) {
        this._type = i2;
        this._value = obj;
    }

    public static void skipPadding(LittleEndianByteArrayInputStream littleEndianByteArrayInputStream) {
        int readIndex = (4 - (littleEndianByteArrayInputStream.getReadIndex() & 3)) & 3;
        for (int i2 = 0; i2 < readIndex; i2++) {
            littleEndianByteArrayInputStream.mark(1);
            int read = littleEndianByteArrayInputStream.read();
            if (read == -1 || read != 0) {
                littleEndianByteArrayInputStream.reset();
                return;
            }
        }
    }

    public Object getValue() {
        return this._value;
    }

    public void read(LittleEndianByteArrayInputStream littleEndianByteArrayInputStream) {
        this._type = littleEndianByteArrayInputStream.readShort();
        short readShort = littleEndianByteArrayInputStream.readShort();
        if (readShort != 0) {
            POILogger pOILogger = LOG;
            StringBuilder b2 = a.b("TypedPropertyValue padding at offset ");
            b2.append(littleEndianByteArrayInputStream.getReadIndex());
            b2.append(" MUST be 0, but it's value is ");
            b2.append((int) readShort);
            pOILogger.log(5, b2.toString());
        }
        readValue(littleEndianByteArrayInputStream);
    }

    /* JADX INFO: Can't fix incorrect switch cases order, some code will duplicate */
    /* JADX WARNING: Removed duplicated region for block: B:38:0x00ee  */
    public void readValue(LittleEndianByteArrayInputStream littleEndianByteArrayInputStream) {
        int i2 = this._type;
        if (i2 != 10) {
            if (i2 != 11) {
                if (i2 != 30) {
                    if (i2 != 31) {
                        if (!(i2 == 4126 || i2 == 4127 || i2 == 4167 || i2 == 4168)) {
                            switch (i2) {
                                case 0:
                                case 1:
                                    this._value = null;
                                    return;
                                case 2:
                                    this._value = Short.valueOf(littleEndianByteArrayInputStream.readShort());
                                    return;
                                case 3:
                                    this._value = Integer.valueOf(littleEndianByteArrayInputStream.readInt());
                                    return;
                                case 4:
                                    this._value = Float.valueOf(Float.intBitsToFloat(littleEndianByteArrayInputStream.readInt()));
                                    return;
                                case 5:
                                    this._value = Double.valueOf(littleEndianByteArrayInputStream.readDouble());
                                    return;
                                case 6:
                                    Currency currency = new Currency();
                                    currency.read(littleEndianByteArrayInputStream);
                                    this._value = currency;
                                    return;
                                case 7:
                                    Date date = new Date();
                                    date.read(littleEndianByteArrayInputStream);
                                    this._value = date;
                                    return;
                                case 8:
                                    break;
                                default:
                                    switch (i2) {
                                        case 14:
                                            Decimal decimal = new Decimal();
                                            decimal.read(littleEndianByteArrayInputStream);
                                            this._value = decimal;
                                            return;
                                        case 64:
                                            Filetime filetime = new Filetime();
                                            filetime.read(littleEndianByteArrayInputStream);
                                            this._value = filetime;
                                            return;
                                        case 65:
                                        case 70:
                                            Blob blob = new Blob();
                                            blob.read(littleEndianByteArrayInputStream);
                                            this._value = blob;
                                            return;
                                        case 66:
                                        case 67:
                                        case 68:
                                        case 69:
                                            IndirectPropertyName indirectPropertyName = new IndirectPropertyName();
                                            indirectPropertyName.read(littleEndianByteArrayInputStream);
                                            this._value = indirectPropertyName;
                                            return;
                                        case 71:
                                            ClipboardData clipboardData = new ClipboardData();
                                            clipboardData.read(littleEndianByteArrayInputStream);
                                            this._value = clipboardData;
                                            return;
                                        case 72:
                                            new GUID().read(littleEndianByteArrayInputStream);
                                            this._value = littleEndianByteArrayInputStream;
                                            return;
                                        case 73:
                                            VersionedStream versionedStream = new VersionedStream();
                                            versionedStream.read(littleEndianByteArrayInputStream);
                                            this._value = versionedStream;
                                            return;
                                        case 4160:
                                            break;
                                        case 8194:
                                        case 8195:
                                        case 8196:
                                        case 8197:
                                        case 8198:
                                        case 8199:
                                        case 8200:
                                        case 8202:
                                        case 8203:
                                        case 8204:
                                        case 8206:
                                        case 8208:
                                        case 8209:
                                        case 8210:
                                        case 8211:
                                        case 8214:
                                        case 8215:
                                            Array array = new Array();
                                            array.read(littleEndianByteArrayInputStream);
                                            this._value = array;
                                            return;
                                        default:
                                            switch (i2) {
                                                case 16:
                                                    this._value = Byte.valueOf(littleEndianByteArrayInputStream.readByte());
                                                    return;
                                                case 17:
                                                    this._value = Integer.valueOf(littleEndianByteArrayInputStream.readUByte());
                                                    return;
                                                case 18:
                                                    this._value = Integer.valueOf(littleEndianByteArrayInputStream.readUShort());
                                                    return;
                                                case 19:
                                                case 23:
                                                    break;
                                                case 20:
                                                    this._value = Long.valueOf(littleEndianByteArrayInputStream.readLong());
                                                    return;
                                                case 21:
                                                    byte[] bArr = new byte[8];
                                                    littleEndianByteArrayInputStream.readFully(bArr);
                                                    byte[] bArr2 = new byte[9];
                                                    int i3 = 8;
                                                    for (int i4 = 0; i4 < 8; i4++) {
                                                        byte b2 = bArr[i4];
                                                        if (i3 <= 8) {
                                                            bArr2[i3] = b2;
                                                        }
                                                        i3--;
                                                    }
                                                    this._value = new BigInteger(bArr2);
                                                    return;
                                                case 22:
                                                    break;
                                                default:
                                                    switch (i2) {
                                                        case 4098:
                                                        case 4099:
                                                        case 4100:
                                                        case 4101:
                                                        case 4102:
                                                        case 4103:
                                                        case 4104:
                                                            break;
                                                        default:
                                                            switch (i2) {
                                                                case 4106:
                                                                case 4107:
                                                                case 4108:
                                                                    break;
                                                                default:
                                                                    switch (i2) {
                                                                        case 4112:
                                                                        case 4113:
                                                                        case 4114:
                                                                        case 4115:
                                                                        case 4116:
                                                                        case 4117:
                                                                            break;
                                                                        default:
                                                                            StringBuilder b3 = a.b("Unknown (possibly, incorrect) TypedPropertyValue type: ");
                                                                            b3.append(this._type);
                                                                            throw new UnsupportedOperationException(b3.toString());
                                                                    }
                                                            }
                                                    }
                                            }
                                    }
                            }
                        }
                        Vector vector = new Vector((short) (this._type & 4095));
                        vector.read(littleEndianByteArrayInputStream);
                        this._value = vector;
                        return;
                    }
                    UnicodeString unicodeString = new UnicodeString();
                    unicodeString.read(littleEndianByteArrayInputStream);
                    this._value = unicodeString;
                    return;
                }
                CodePageString codePageString = new CodePageString();
                codePageString.read(littleEndianByteArrayInputStream);
                this._value = codePageString;
                return;
            }
            VariantBool variantBool = new VariantBool();
            variantBool.read(littleEndianByteArrayInputStream);
            this._value = variantBool;
            return;
        }
        this._value = Long.valueOf(littleEndianByteArrayInputStream.readUInt());
    }
}
