package org.apache.poi.hpsf;

import java.io.OutputStream;
import java.math.BigInteger;
import java.util.Date;
import java.util.LinkedList;
import java.util.List;
import org.apache.poi.util.CodePageUtil;
import org.apache.poi.util.LittleEndian;
import org.apache.poi.util.LittleEndianByteArrayInputStream;
import org.apache.poi.util.POILogFactory;
import org.apache.poi.util.POILogger;
import org.apache.poi.util.Removal;

public class VariantSupport extends Variant {
    public static final int[] SUPPORTED_TYPES = {0, 2, 3, 20, 5, 64, 30, 31, 71, 11};
    public static boolean logUnsupportedTypes;
    public static final POILogger logger = POILogFactory.getLogger(VariantSupport.class);
    public static final byte[] paddingBytes = new byte[3];
    public static List<Long> unsupportedMessage;

    @Removal(version = "3.18")
    @Deprecated
    public static String codepageToEncoding(int i2) {
        return CodePageUtil.codepageToEncoding(i2);
    }

    public static boolean isLogUnsupportedTypes() {
        return logUnsupportedTypes;
    }

    public static Object read(byte[] bArr, int i2, int i3, long j, int i4) {
        return read(new LittleEndianByteArrayInputStream(bArr, i2), i3, j, i4);
    }

    public static void setLogUnsupportedTypes(boolean z) {
        logUnsupportedTypes = z;
    }

    /* JADX INFO: Can't fix incorrect switch cases order, some code will duplicate */
    /* JADX WARNING: Removed duplicated region for block: B:82:0x014c  */
    public static int write(OutputStream outputStream, long j, Object obj, int i2) {
        int i3 = (int) j;
        int i4 = 2;
        if (i3 != 0) {
            if (i3 != 11) {
                if (i3 == 64) {
                    i4 = (obj instanceof Date ? new Filetime((Date) obj) : new Filetime()).write(outputStream);
                } else if (i3 != 71) {
                    if (i3 != 2) {
                        if (i3 != 3) {
                            if (i3 != 4) {
                                if (i3 != 5) {
                                    if (i3 != 30) {
                                        if (i3 != 31) {
                                            switch (i3) {
                                                case 18:
                                                    if (obj instanceof Number) {
                                                        LittleEndian.putUShort(((Number) obj).intValue(), outputStream);
                                                        break;
                                                    }
                                                    break;
                                                case 19:
                                                    if (obj instanceof Number) {
                                                        LittleEndian.putUInt(((Number) obj).longValue(), outputStream);
                                                        break;
                                                    }
                                                    break;
                                                case 20:
                                                    if (obj instanceof Number) {
                                                        LittleEndian.putLong(((Number) obj).longValue(), outputStream);
                                                        break;
                                                    }
                                                    break;
                                                case 21:
                                                    if (obj instanceof Number) {
                                                        BigInteger valueOf = obj instanceof BigInteger ? (BigInteger) obj : BigInteger.valueOf(((Number) obj).longValue());
                                                        if (valueOf.bitLength() <= 64) {
                                                            byte[] byteArray = valueOf.toByteArray();
                                                            byte[] bArr = new byte[8];
                                                            int length = byteArray.length;
                                                            for (byte b2 : byteArray) {
                                                                if (length <= 8) {
                                                                    bArr[length - 1] = b2;
                                                                }
                                                                length--;
                                                            }
                                                            outputStream.write(bArr);
                                                            break;
                                                        } else {
                                                            throw new WritingNotSupportedException(j, obj);
                                                        }
                                                    }
                                                    break;
                                            }
                                        } else if (obj instanceof String) {
                                            UnicodeString unicodeString = new UnicodeString();
                                            unicodeString.setJavaValue((String) obj);
                                            i4 = unicodeString.write(outputStream);
                                        }
                                    } else if (obj instanceof String) {
                                        CodePageString codePageString = new CodePageString();
                                        codePageString.setJavaValue((String) obj, i2);
                                        i4 = codePageString.write(outputStream);
                                    }
                                } else if (obj instanceof Number) {
                                    LittleEndian.putDouble(((Number) obj).doubleValue(), outputStream);
                                }
                                i4 = 8;
                            } else if (obj instanceof Number) {
                                LittleEndian.putInt(Float.floatToIntBits(((Number) obj).floatValue()), outputStream);
                            }
                        } else if (obj instanceof Number) {
                            LittleEndian.putInt(((Number) obj).intValue(), outputStream);
                        }
                    } else if (obj instanceof Number) {
                        LittleEndian.putShort(outputStream, ((Number) obj).shortValue());
                    }
                } else if (obj instanceof byte[]) {
                    byte[] bArr2 = (byte[]) obj;
                    outputStream.write(bArr2);
                    i4 = bArr2.length;
                }
                if (i4 == -1) {
                    if (obj instanceof byte[]) {
                        byte[] bArr3 = (byte[]) obj;
                        outputStream.write(bArr3);
                        i4 = bArr3.length;
                        writeUnsupportedTypeMessage(new WritingNotSupportedException(j, obj));
                    } else {
                        throw new WritingNotSupportedException(j, obj);
                    }
                }
                int i5 = (4 - (i4 & 3)) & 3;
                outputStream.write(paddingBytes, 0, i5);
                return i4 + i5;
            } else if (obj instanceof Boolean) {
                int i6 = ((Boolean) obj).booleanValue() ? 255 : 0;
                outputStream.write(i6);
                outputStream.write(i6);
                if (i4 == -1) {
                }
                int i52 = (4 - (i4 & 3)) & 3;
                outputStream.write(paddingBytes, 0, i52);
                return i4 + i52;
            }
            i4 = -1;
            if (i4 == -1) {
            }
            int i522 = (4 - (i4 & 3)) & 3;
            outputStream.write(paddingBytes, 0, i522);
            return i4 + i522;
        }
        LittleEndian.putUInt(0, outputStream);
        i4 = 4;
        if (i4 == -1) {
        }
        int i5222 = (4 - (i4 & 3)) & 3;
        outputStream.write(paddingBytes, 0, i5222);
        return i4 + i5222;
    }

    public static void writeUnsupportedTypeMessage(UnsupportedVariantTypeException unsupportedVariantTypeException) {
        if (isLogUnsupportedTypes()) {
            if (unsupportedMessage == null) {
                unsupportedMessage = new LinkedList();
            }
            Long valueOf = Long.valueOf(unsupportedVariantTypeException.getVariantType());
            if (!unsupportedMessage.contains(valueOf)) {
                logger.log(7, unsupportedVariantTypeException.getMessage());
                unsupportedMessage.add(valueOf);
            }
        }
    }

    public boolean isSupportedType(int i2) {
        for (int i3 : SUPPORTED_TYPES) {
            if (i2 == i3) {
                return true;
            }
        }
        return false;
    }

    public static Object read(LittleEndianByteArrayInputStream littleEndianByteArrayInputStream, int i2, long j, int i3) {
        int readIndex = littleEndianByteArrayInputStream.getReadIndex();
        int i4 = (int) j;
        TypedPropertyValue typedPropertyValue = new TypedPropertyValue(i4, null);
        try {
            typedPropertyValue.readValue(littleEndianByteArrayInputStream);
            if (i4 != 0) {
                if (i4 == 11) {
                    return Boolean.valueOf(((VariantBool) typedPropertyValue.getValue()).getValue());
                }
                if (i4 == 64) {
                    return ((Filetime) typedPropertyValue.getValue()).getJavaValue();
                }
                if (i4 == 71) {
                    return ((ClipboardData) typedPropertyValue.getValue()).toByteArray();
                }
                if (i4 == 2) {
                    return Integer.valueOf(((Short) typedPropertyValue.getValue()).intValue());
                }
                if (!(i4 == 3 || i4 == 4 || i4 == 5)) {
                    if (i4 == 30) {
                        return ((CodePageString) typedPropertyValue.getValue()).getJavaValue(i3);
                    }
                    if (i4 == 31) {
                        return ((UnicodeString) typedPropertyValue.getValue()).toJavaString();
                    }
                    switch (i4) {
                        case 16:
                        case 17:
                        case 18:
                        case 19:
                        case 20:
                        case 21:
                            break;
                        default:
                            int readIndex2 = littleEndianByteArrayInputStream.getReadIndex() - readIndex;
                            littleEndianByteArrayInputStream.setReadIndex(readIndex);
                            byte[] bArr = new byte[readIndex2];
                            littleEndianByteArrayInputStream.readFully(bArr, 0, readIndex2);
                            throw new ReadingNotSupportedException(j, bArr);
                    }
                }
            }
            return typedPropertyValue.getValue();
        } catch (UnsupportedOperationException unused) {
            int min = Math.min(i2, littleEndianByteArrayInputStream.available());
            byte[] bArr2 = new byte[min];
            littleEndianByteArrayInputStream.readFully(bArr2, 0, min);
            throw new ReadingNotSupportedException(j, bArr2);
        }
    }
}
