package org.apache.poi.hpsf.extractor;

import java.io.File;
import org.apache.poi.POIDocument;
import org.apache.poi.POIOLE2TextExtractor;
import org.apache.poi.POITextExtractor;
import org.apache.poi.hpsf.CustomProperties;
import org.apache.poi.hpsf.DocumentSummaryInformation;
import org.apache.poi.hpsf.HPSFPropertiesOnlyDocument;
import org.apache.poi.hpsf.Property;
import org.apache.poi.hpsf.PropertySet;
import org.apache.poi.hpsf.wellknown.PropertyIDMap;
import org.apache.poi.poifs.filesystem.NPOIFSFileSystem;
import org.apache.poi.poifs.filesystem.POIFSFileSystem;

public class HPSFPropertiesExtractor extends POIOLE2TextExtractor {
    public HPSFPropertiesExtractor(POIOLE2TextExtractor pOIOLE2TextExtractor) {
        super(pOIOLE2TextExtractor);
    }

    public static String getPropertiesText(PropertySet propertySet) {
        String str;
        if (propertySet == null) {
            return "";
        }
        StringBuilder sb = new StringBuilder();
        PropertyIDMap propertySetIDMap = propertySet.getPropertySetIDMap();
        Property[] properties = propertySet.getProperties();
        for (Property property : properties) {
            String l = Long.toString(property.getID());
            if (propertySetIDMap == null) {
                str = null;
            } else {
                str = propertySetIDMap.get((Object) Long.valueOf(property.getID()));
            }
            if (str != null) {
                l = str.toString();
            }
            String propertyValueText = getPropertyValueText(property.getValue());
            sb.append(l);
            sb.append(" = ");
            sb.append(propertyValueText);
            sb.append("\n");
        }
        return sb.toString();
    }

    public static String getPropertyValueText(Object obj) {
        return obj == null ? "(not set)" : PropertySet.getPropertyStringValue(obj);
    }

    /* JADX INFO: finally extract failed */
    public static void main(String[] strArr) {
        for (String str : strArr) {
            HPSFPropertiesExtractor hPSFPropertiesExtractor = new HPSFPropertiesExtractor(new NPOIFSFileSystem(new File(str)));
            try {
                System.out.println(hPSFPropertiesExtractor.getText());
                hPSFPropertiesExtractor.close();
            } catch (Throwable th) {
                hPSFPropertiesExtractor.close();
                throw th;
            }
        }
    }

    public boolean equals(Object obj) {
        return super.equals(obj);
    }

    public String getDocumentSummaryInformationText() {
        CustomProperties customProperties;
        POIDocument pOIDocument = this.document;
        if (pOIDocument == null) {
            return "";
        }
        DocumentSummaryInformation documentSummaryInformation = pOIDocument.getDocumentSummaryInformation();
        StringBuilder sb = new StringBuilder();
        sb.append(getPropertiesText(documentSummaryInformation));
        if (documentSummaryInformation == null) {
            customProperties = null;
        } else {
            customProperties = documentSummaryInformation.getCustomProperties();
        }
        if (customProperties != null) {
            for (String str : customProperties.nameSet()) {
                String propertyValueText = getPropertyValueText(customProperties.get(str));
                sb.append(str);
                sb.append(" = ");
                sb.append(propertyValueText);
                sb.append("\n");
            }
        }
        return sb.toString();
    }

    @Override // org.apache.poi.POITextExtractor, org.apache.poi.POIOLE2TextExtractor
    public POITextExtractor getMetadataTextExtractor() {
        throw new IllegalStateException("You already have the Metadata Text Extractor, not recursing!");
    }

    public String getSummaryInformationText() {
        POIDocument pOIDocument = this.document;
        if (pOIDocument == null) {
            return "";
        }
        return getPropertiesText(pOIDocument.getSummaryInformation());
    }

    @Override // org.apache.poi.POITextExtractor
    public String getText() {
        return getSummaryInformationText() + getDocumentSummaryInformationText();
    }

    public int hashCode() {
        return super.hashCode();
    }

    public HPSFPropertiesExtractor(POIDocument pOIDocument) {
        super(pOIDocument);
    }

    public HPSFPropertiesExtractor(POIFSFileSystem pOIFSFileSystem) {
        super(new HPSFPropertiesOnlyDocument(pOIFSFileSystem));
    }

    public HPSFPropertiesExtractor(NPOIFSFileSystem nPOIFSFileSystem) {
        super(new HPSFPropertiesOnlyDocument(nPOIFSFileSystem));
    }
}
