package org.apache.poi.hslf.model;

import org.apache.poi.ddf.EscherComplexProperty;
import org.apache.poi.ddf.EscherContainerRecord;
import org.apache.poi.ddf.EscherProperties;
import org.apache.poi.ddf.EscherSpRecord;
import org.apache.poi.hslf.exceptions.HSLFException;
import org.apache.poi.hslf.record.ExControl;
import org.apache.poi.hslf.record.ExObjList;
import org.apache.poi.hslf.record.ExObjRefAtom;
import org.apache.poi.hslf.record.Record;
import org.apache.poi.hslf.record.RecordTypes;
import org.apache.poi.hslf.usermodel.HSLFPictureData;
import org.apache.poi.hslf.usermodel.HSLFPictureShape;
import org.apache.poi.hslf.usermodel.HSLFShape;
import org.apache.poi.hslf.usermodel.HSLFSheet;
import org.apache.poi.hslf.usermodel.HSLFTextParagraph;
import org.apache.poi.sl.usermodel.ShapeContainer;
import org.apache.poi.sl.usermodel.ShapeType;
import org.apache.poi.ss.formula.ptg.UnaryMinusPtg;
import org.apache.poi.util.StringUtil;

public final class ActiveXShape extends HSLFPictureShape {
    public static final int DEFAULT_ACTIVEX_THUMBNAIL = -1;

    public ActiveXShape(int i2, HSLFPictureData hSLFPictureData) {
        super(hSLFPictureData, (ShapeContainer<HSLFShape, HSLFTextParagraph>) null);
        setActiveXIndex(i2);
    }

    @Override // org.apache.poi.hslf.usermodel.HSLFShape, org.apache.poi.hslf.usermodel.HSLFPictureShape
    public void afterInsert(HSLFSheet hSLFSheet) {
        ExControl exControl = getExControl();
        if (exControl != null) {
            exControl.getExControlAtom().setSlideId(hSLFSheet._getSheetNumber());
            getEscherOptRecord().addEscherProperty(new EscherComplexProperty(EscherProperties.GROUPSHAPE__SHAPENAME, false, StringUtil.getToUnicodeLE(exControl.getProgId() + UnaryMinusPtg.MINUS + getControlIndex() + (char) 0)));
            return;
        }
        throw new NullPointerException("ExControl is not defined");
    }

    @Override // org.apache.poi.hslf.usermodel.HSLFPictureShape
    public EscherContainerRecord createSpContainer(int i2, boolean z) {
        EscherContainerRecord createSpContainer = super.createSpContainer(i2, z);
        ((EscherSpRecord) createSpContainer.getChildById(EscherSpRecord.RECORD_ID)).setFlags(2576);
        setShapeType(ShapeType.HOST_CONTROL);
        setEscherProperty(267, i2);
        setEscherProperty(EscherProperties.LINESTYLE__COLOR, 134217729);
        setEscherProperty(EscherProperties.LINESTYLE__NOLINEDRAWDASH, 524296);
        setEscherProperty(513, 134217730);
        setEscherProperty(127, -1);
        getClientData(true).addChild(new ExObjRefAtom());
        return createSpContainer;
    }

    public int getControlIndex() {
        ExObjRefAtom exObjRefAtom = (ExObjRefAtom) getClientDataRecord(RecordTypes.ExObjRefAtom.typeID);
        if (exObjRefAtom != null) {
            return exObjRefAtom.getExObjIdRef();
        }
        return -1;
    }

    /* JADX WARN: Type inference failed for: r1v0, types: [org.apache.poi.hslf.usermodel.HSLFSheet] */
    /* JADX WARN: Type inference failed for: r1v1, types: [org.apache.poi.hslf.usermodel.HSLFSlideShow] */
    /* JADX WARNING: Unknown variable types count: 2 */
    public ExControl getExControl() {
        int controlIndex = getControlIndex();
        ExObjList exObjList = (ExObjList) getSheet().getSlideShow().getDocumentRecord().findFirstOfType((long) RecordTypes.ExObjList.typeID);
        if (exObjList == null) {
            return null;
        }
        Record[] childRecords = exObjList.getChildRecords();
        for (Record record : childRecords) {
            if (record instanceof ExControl) {
                ExControl exControl = (ExControl) record;
                if (exControl.getExOleObjAtom().getObjID() == controlIndex) {
                    return exControl;
                }
            }
        }
        return null;
    }

    public void setActiveXIndex(int i2) {
        ExObjRefAtom exObjRefAtom = (ExObjRefAtom) getClientDataRecord(RecordTypes.ExObjRefAtom.typeID);
        if (exObjRefAtom != null) {
            exObjRefAtom.setExObjIdRef(i2);
            return;
        }
        throw new HSLFException("OEShapeAtom for ActiveX doesn't exist");
    }

    public void setProperty(String str, String str2) {
    }

    public ActiveXShape(EscherContainerRecord escherContainerRecord, ShapeContainer<HSLFShape, HSLFTextParagraph> shapeContainer) {
        super(escherContainerRecord, shapeContainer);
    }
}
