package org.apache.poi.hslf.usermodel;

import org.apache.poi.common.usermodel.fonts.FontCharset;
import org.apache.poi.common.usermodel.fonts.FontFamily;
import org.apache.poi.common.usermodel.fonts.FontInfo;
import org.apache.poi.common.usermodel.fonts.FontPitch;
import org.apache.poi.hslf.record.FontEntityAtom;
import org.apache.poi.util.BitField;
import org.apache.poi.util.BitFieldFactory;

public class HSLFFontInfo implements FontInfo {
    public static final BitField FLAGS_EMBED_SUBSETTED = BitFieldFactory.getInstance(1);
    public static final BitField FLAGS_NO_FONT_SUBSTITUTION = BitFieldFactory.getInstance(8);
    public static final BitField FLAGS_RENDER_FONTTYPE = BitFieldFactory.getInstance(7);
    public FontCharset charset = FontCharset.ANSI;
    public FontFamily family = FontFamily.FF_SWISS;
    public int index = -1;
    public boolean isSubsetted = false;
    public boolean isSubstitutable = true;
    public FontPitch pitch = FontPitch.VARIABLE;
    public FontRenderType renderType = FontRenderType.truetype;
    public String typeface = "undefined";

    /* renamed from: org.apache.poi.hslf.usermodel.HSLFFontInfo$1  reason: invalid class name */
    public static /* synthetic */ class AnonymousClass1 {
        public static final /* synthetic */ int[] $SwitchMap$org$apache$poi$hslf$usermodel$HSLFFontInfo$FontRenderType;

        /* JADX WARNING: Can't wrap try/catch for region: R(8:0|(2:1|2)|3|5|6|7|8|10) */
        /* JADX WARNING: Code restructure failed: missing block: B:11:?, code lost:
            return;
         */
        /* JADX WARNING: Failed to process nested try/catch */
        /* JADX WARNING: Missing exception handler attribute for start block: B:7:0x0016 */
        static {
            int[] iArr = new int[FontRenderType.values().length];
            $SwitchMap$org$apache$poi$hslf$usermodel$HSLFFontInfo$FontRenderType = iArr;
            try {
                FontRenderType fontRenderType = FontRenderType.device;
                iArr[1] = 1;
            } catch (NoSuchFieldError unused) {
            }
            int[] iArr2 = $SwitchMap$org$apache$poi$hslf$usermodel$HSLFFontInfo$FontRenderType;
            FontRenderType fontRenderType2 = FontRenderType.raster;
            iArr2[0] = 2;
            int[] iArr3 = $SwitchMap$org$apache$poi$hslf$usermodel$HSLFFontInfo$FontRenderType;
            FontRenderType fontRenderType3 = FontRenderType.truetype;
            iArr3[2] = 3;
        }
    }

    public enum FontRenderType {
        raster,
        device,
        truetype
    }

    public HSLFFontInfo(String str) {
        setTypeface(str);
    }

    public FontEntityAtom createRecord() {
        int i2;
        FontEntityAtom fontEntityAtom = new FontEntityAtom();
        fontEntityAtom.setFontIndex(getIndex().intValue() << 4);
        fontEntityAtom.setFontName(getTypeface());
        fontEntityAtom.setCharSet(getCharset().getNativeId());
        fontEntityAtom.setFontFlags(isEmbedSubsetted() ? (byte) 1 : 0);
        int ordinal = this.renderType.ordinal();
        if (ordinal == 0) {
            i2 = FLAGS_RENDER_FONTTYPE.setValue(0, 2);
        } else if (ordinal != 1) {
            i2 = FLAGS_RENDER_FONTTYPE.setValue(0, 4);
        } else {
            i2 = FLAGS_RENDER_FONTTYPE.setValue(0, 1);
        }
        fontEntityAtom.setFontType(FLAGS_NO_FONT_SUBSTITUTION.setBoolean(i2, isFontSubstitutable()));
        fontEntityAtom.setPitchAndFamily(FontPitch.getNativeId(this.pitch, this.family));
        return fontEntityAtom;
    }

    @Override // org.apache.poi.common.usermodel.fonts.FontInfo
    public FontCharset getCharset() {
        return this.charset;
    }

    @Override // org.apache.poi.common.usermodel.fonts.FontInfo
    public FontFamily getFamily() {
        return this.family;
    }

    @Override // org.apache.poi.common.usermodel.fonts.FontInfo
    public Integer getIndex() {
        return Integer.valueOf(this.index);
    }

    @Override // org.apache.poi.common.usermodel.fonts.FontInfo
    public FontPitch getPitch() {
        return this.pitch;
    }

    public FontRenderType getRenderType() {
        return this.renderType;
    }

    @Override // org.apache.poi.common.usermodel.fonts.FontInfo
    public String getTypeface() {
        return this.typeface;
    }

    public boolean isEmbedSubsetted() {
        return this.isSubsetted;
    }

    public boolean isFontSubstitutable() {
        return this.isSubstitutable;
    }

    @Override // org.apache.poi.common.usermodel.fonts.FontInfo
    public void setCharset(FontCharset fontCharset) {
        if (fontCharset == null) {
            fontCharset = FontCharset.ANSI;
        }
        this.charset = fontCharset;
    }

    public void setEmbedSubsetted(boolean z) {
        this.isSubsetted = z;
    }

    @Override // org.apache.poi.common.usermodel.fonts.FontInfo
    public void setFamily(FontFamily fontFamily) {
        if (fontFamily == null) {
            fontFamily = FontFamily.FF_SWISS;
        }
        this.family = fontFamily;
    }

    public void setFontSubstitutable(boolean z) {
        this.isSubstitutable = z;
    }

    @Override // org.apache.poi.common.usermodel.fonts.FontInfo
    public void setIndex(int i2) {
        this.index = i2;
    }

    @Override // org.apache.poi.common.usermodel.fonts.FontInfo
    public void setPitch(FontPitch fontPitch) {
        if (fontPitch == null) {
            fontPitch = FontPitch.VARIABLE;
        }
        this.pitch = fontPitch;
    }

    public void setRenderType(FontRenderType fontRenderType) {
        if (fontRenderType == null) {
            fontRenderType = FontRenderType.truetype;
        }
        this.renderType = fontRenderType;
    }

    @Override // org.apache.poi.common.usermodel.fonts.FontInfo
    public void setTypeface(String str) {
        if (str == null || "".equals(str)) {
            throw new IllegalArgumentException("typeface can't be null nor empty");
        }
        this.typeface = str;
    }

    public HSLFFontInfo(FontEntityAtom fontEntityAtom) {
        setIndex(fontEntityAtom.getFontIndex());
        setTypeface(fontEntityAtom.getFontName());
        setCharset(FontCharset.valueOf(fontEntityAtom.getCharSet()));
        int value = FLAGS_RENDER_FONTTYPE.getValue(fontEntityAtom.getFontType());
        if (value == 1) {
            setRenderType(FontRenderType.raster);
        } else if (value != 2) {
            setRenderType(FontRenderType.truetype);
        } else {
            setRenderType(FontRenderType.device);
        }
        byte pitchAndFamily = (byte) fontEntityAtom.getPitchAndFamily();
        setPitch(FontPitch.valueOfPitchFamily(pitchAndFamily));
        setFamily(FontFamily.valueOfPitchFamily(pitchAndFamily));
        setEmbedSubsetted(FLAGS_EMBED_SUBSETTED.isSet(fontEntityAtom.getFontFlags()));
        setFontSubstitutable(!FLAGS_NO_FONT_SUBSTITUTION.isSet(fontEntityAtom.getFontType()));
    }

    public HSLFFontInfo(FontInfo fontInfo) {
        setTypeface(fontInfo.getTypeface());
        setCharset(fontInfo.getCharset());
        setFamily(fontInfo.getFamily());
        setPitch(fontInfo.getPitch());
        if (fontInfo instanceof HSLFFontInfo) {
            HSLFFontInfo hSLFFontInfo = (HSLFFontInfo) fontInfo;
            setRenderType(hSLFFontInfo.getRenderType());
            setEmbedSubsetted(hSLFFontInfo.isEmbedSubsetted());
            setFontSubstitutable(hSLFFontInfo.isFontSubstitutable());
        }
    }
}
