package org.apache.poi.hslf.usermodel;

import b.b.a.a.a;
import java.awt.geom.AffineTransform;
import java.awt.geom.Path2D;
import java.awt.geom.PathIterator;
import java.awt.geom.Point2D;
import java.awt.geom.Rectangle2D;
import java.util.ArrayList;
import java.util.Iterator;
import org.apache.poi.ddf.AbstractEscherOptRecord;
import org.apache.poi.ddf.EscherArrayProperty;
import org.apache.poi.ddf.EscherContainerRecord;
import org.apache.poi.ddf.EscherProperties;
import org.apache.poi.ddf.EscherProperty;
import org.apache.poi.ddf.EscherSimpleProperty;
import org.apache.poi.sl.usermodel.FreeformShape;
import org.apache.poi.sl.usermodel.ShapeContainer;
import org.apache.poi.sl.usermodel.ShapeType;
import org.apache.poi.util.BitField;
import org.apache.poi.util.BitFieldFactory;
import org.apache.poi.util.LittleEndian;
import org.apache.poi.util.POILogFactory;
import org.apache.poi.util.POILogger;
import org.apache.poi.util.Units;

public final class HSLFFreeformShape extends HSLFAutoShape implements FreeformShape<HSLFShape, HSLFTextParagraph> {
    public static final POILogger LOG = POILogFactory.getLogger(HSLFFreeformShape.class);
    public static final BitField PATH_INFO = BitFieldFactory.getInstance(57344);
    public static final byte[] SEGMENTINFO_CLOSE = {1, 96};
    public static final byte[] SEGMENTINFO_CUBICTO = {0, -83};
    public static final byte[] SEGMENTINFO_END = {0, Byte.MIN_VALUE};
    public static final byte[] SEGMENTINFO_ESCAPE = {1, 0};
    public static final byte[] SEGMENTINFO_ESCAPE2 = {1, 32};
    public static final byte[] SEGMENTINFO_LINETO = {0, -84};
    public static final byte[] SEGMENTINFO_MOVETO = {0, 64};

    /* renamed from: org.apache.poi.hslf.usermodel.HSLFFreeformShape$1  reason: invalid class name */
    public static /* synthetic */ class AnonymousClass1 {
        public static final /* synthetic */ int[] $SwitchMap$org$apache$poi$hslf$usermodel$HSLFFreeformShape$PathInfo;

        /* JADX WARNING: Can't wrap try/catch for region: R(13:0|1|2|3|4|5|7|8|9|10|11|12|14) */
        /* JADX WARNING: Code restructure failed: missing block: B:15:?, code lost:
            return;
         */
        /* JADX WARNING: Failed to process nested try/catch */
        /* JADX WARNING: Missing exception handler attribute for start block: B:11:0x0025 */
        /* JADX WARNING: Missing exception handler attribute for start block: B:3:0x000f */
        /* JADX WARNING: Missing exception handler attribute for start block: B:9:0x001d */
        static {
            int[] iArr = new int[PathInfo.values().length];
            $SwitchMap$org$apache$poi$hslf$usermodel$HSLFFreeformShape$PathInfo = iArr;
            PathInfo pathInfo = PathInfo.escape;
            iArr[5] = 1;
            try {
                int[] iArr2 = $SwitchMap$org$apache$poi$hslf$usermodel$HSLFFreeformShape$PathInfo;
                PathInfo pathInfo2 = PathInfo.moveTo;
                iArr2[2] = 2;
            } catch (NoSuchFieldError unused) {
            }
            int[] iArr3 = $SwitchMap$org$apache$poi$hslf$usermodel$HSLFFreeformShape$PathInfo;
            PathInfo pathInfo3 = PathInfo.curveTo;
            iArr3[1] = 3;
            int[] iArr4 = $SwitchMap$org$apache$poi$hslf$usermodel$HSLFFreeformShape$PathInfo;
            PathInfo pathInfo4 = PathInfo.lineTo;
            iArr4[0] = 4;
            int[] iArr5 = $SwitchMap$org$apache$poi$hslf$usermodel$HSLFFreeformShape$PathInfo;
            PathInfo pathInfo5 = PathInfo.close;
            iArr5[3] = 5;
        }
    }

    public enum EscapeInfo {
        EXTENSION(0),
        ANGLE_ELLIPSE_TO(1),
        ANGLE_ELLIPSE(2),
        ARC_TO(3),
        ARC(4),
        CLOCKWISE_ARC_TO(5),
        CLOCKWISE_ARC(6),
        ELLIPTICAL_QUADRANT_X(7),
        ELLIPTICAL_QUADRANT_Y(8),
        QUADRATIC_BEZIER(9),
        NO_FILL(10),
        NO_LINE(11),
        AUTO_LINE(12),
        AUTO_CURVE(13),
        CORNER_LINE(14),
        CORNER_CURVE(15),
        SMOOTH_LINE(16),
        SMOOTH_CURVE(17),
        SYMMETRIC_LINE(18),
        SYMMETRIC_CURVE(19),
        FREEFORM(20),
        FILL_COLOR(21),
        LINE_COLOR(22);
        
        public final int flag;

        /* access modifiers changed from: public */
        EscapeInfo(int i2) {
            this.flag = i2;
        }

        public int getFlag() {
            return this.flag;
        }

        public static EscapeInfo valueOf(int i2) {
            EscapeInfo[] values = values();
            for (EscapeInfo escapeInfo : values) {
                if (escapeInfo.flag == i2) {
                    return escapeInfo;
                }
            }
            return null;
        }
    }

    public enum PathInfo {
        lineTo(0),
        curveTo(1),
        moveTo(2),
        close(3),
        end(4),
        escape(5),
        clientEscape(6);
        
        public final int flag;

        /* access modifiers changed from: public */
        PathInfo(int i2) {
            this.flag = i2;
        }

        public int getFlag() {
            return this.flag;
        }

        public static PathInfo valueOf(int i2) {
            PathInfo[] values = values();
            for (PathInfo pathInfo : values) {
                if (pathInfo.flag == i2) {
                    return pathInfo;
                }
            }
            return null;
        }
    }

    public enum ShapePath {
        LINES(0),
        LINES_CLOSED(1),
        CURVES(2),
        CURVES_CLOSED(3),
        COMPLEX(4);
        
        public final int flag;

        /* access modifiers changed from: public */
        ShapePath(int i2) {
            this.flag = i2;
        }

        public int getFlag() {
            return this.flag;
        }

        public static ShapePath valueOf(int i2) {
            ShapePath[] values = values();
            for (ShapePath shapePath : values) {
                if (shapePath.flag == i2) {
                    return shapePath;
                }
            }
            return null;
        }
    }

    public HSLFFreeformShape(EscherContainerRecord escherContainerRecord, ShapeContainer<HSLFShape, HSLFTextParagraph> shapeContainer) {
        super(escherContainerRecord, shapeContainer);
    }

    private void fillPoint(byte[] bArr, double[] dArr) {
        int i2;
        int i3;
        if (bArr == null || dArr == null) {
            LOG.log(5, "Master bytes or points not set - ignore point");
        } else if ((bArr.length == 4 || bArr.length == 8) && dArr.length == 2) {
            if (bArr.length == 4) {
                i3 = LittleEndian.getShort(bArr, 0);
                i2 = LittleEndian.getShort(bArr, 2);
            } else {
                i3 = LittleEndian.getInt(bArr, 0);
                i2 = LittleEndian.getInt(bArr, 4);
            }
            dArr[0] = Units.masterToPoints(i3);
            dArr[1] = Units.masterToPoints(i2);
        } else {
            LOG.log(5, "Invalid number of master bytes for a single point - ignore point");
        }
    }

    public static PathInfo getPathInfo(byte[] bArr) {
        return PathInfo.valueOf(PATH_INFO.getValue(LittleEndian.getUShort(bArr, 0)));
    }

    public static <T extends EscherProperty> T getShapeProp(AbstractEscherOptRecord abstractEscherOptRecord, int i2) {
        T t = (T) HSLFShape.getEscherProperty(abstractEscherOptRecord, (short) (i2 + 16384));
        return t == null ? (T) HSLFShape.getEscherProperty(abstractEscherOptRecord, i2) : t;
    }

    @Override // org.apache.poi.sl.usermodel.FreeformShape
    public Path2D.Double getPath() {
        int i2;
        Iterator<byte[]> it;
        AbstractEscherOptRecord abstractEscherOptRecord;
        double[] dArr;
        Path2D.Double r1;
        AbstractEscherOptRecord escherOptRecord = getEscherOptRecord();
        EscherArrayProperty escherArrayProperty = (EscherArrayProperty) getShapeProp(escherOptRecord, 325);
        EscherArrayProperty escherArrayProperty2 = (EscherArrayProperty) getShapeProp(escherOptRecord, 326);
        Path2D.Double r15 = new Path2D.Double();
        int i3 = 1;
        if (escherArrayProperty == null) {
            LOG.log(5, "Freeform is missing GEOMETRY__VERTICES ");
            return r15;
        } else if (escherArrayProperty2 == null) {
            LOG.log(5, "Freeform is missing GEOMETRY__SEGMENTINFO ");
            return r15;
        } else {
            Iterator<byte[]> it2 = escherArrayProperty.iterator();
            Iterator<byte[]> it3 = escherArrayProperty2.iterator();
            int i4 = 2;
            double[] dArr2 = new double[2];
            while (it2.hasNext() && it3.hasNext()) {
                int ordinal = getPathInfo(it3.next()).ordinal();
                if (ordinal == 0) {
                    abstractEscherOptRecord = escherOptRecord;
                    it = it3;
                    dArr = dArr2;
                    r1 = r15;
                    if (it2.hasNext()) {
                        fillPoint(it2.next(), dArr);
                        r1.lineTo(dArr[0], dArr[1]);
                    }
                } else if (ordinal != i3) {
                    if (ordinal == i4) {
                        fillPoint(it2.next(), dArr2);
                        r15.moveTo(dArr2[0], dArr2[i3]);
                    } else if (ordinal == 3) {
                        r15.closePath();
                    }
                    abstractEscherOptRecord = escherOptRecord;
                    it = it3;
                    dArr = dArr2;
                    r1 = r15;
                } else {
                    fillPoint(it2.next(), dArr2);
                    double d2 = dArr2[0];
                    double d3 = dArr2[i3];
                    fillPoint(it2.next(), dArr2);
                    double d4 = dArr2[0];
                    double d5 = dArr2[i3];
                    fillPoint(it2.next(), dArr2);
                    it = it3;
                    dArr = dArr2;
                    abstractEscherOptRecord = escherOptRecord;
                    r1 = r15;
                    r15.curveTo(d2, d3, d4, d5, dArr2[0], dArr2[i3]);
                }
                r15 = r1;
                dArr2 = dArr;
                escherOptRecord = abstractEscherOptRecord;
                it3 = it;
                i3 = 1;
                i4 = 2;
            }
            EscherSimpleProperty escherSimpleProperty = (EscherSimpleProperty) getShapeProp(escherOptRecord, 324);
            if (escherSimpleProperty == null) {
                i2 = 1;
            } else {
                i2 = escherSimpleProperty.getPropertyValue();
            }
            ShapePath valueOf = ShapePath.valueOf(i2);
            if (valueOf == ShapePath.LINES_CLOSED || valueOf == ShapePath.CURVES_CLOSED) {
                r15.closePath();
            }
            Rectangle2D anchor = getAnchor();
            Rectangle2D bounds2D = r15.getBounds2D();
            AffineTransform affineTransform = new AffineTransform();
            affineTransform.translate(anchor.getX(), anchor.getY());
            affineTransform.scale(anchor.getWidth() / bounds2D.getWidth(), anchor.getHeight() / bounds2D.getHeight());
            return new Path2D.Double(affineTransform.createTransformedShape(r15));
        }
    }

    @Override // org.apache.poi.sl.usermodel.FreeformShape
    public int setPath(Path2D.Double r18) {
        Rectangle2D bounds2D = r18.getBounds2D();
        PathIterator pathIterator = r18.getPathIterator(new AffineTransform());
        ArrayList arrayList = new ArrayList();
        ArrayList arrayList2 = new ArrayList();
        int i2 = 0;
        boolean z = false;
        int i3 = 0;
        while (!pathIterator.isDone()) {
            double[] dArr = new double[6];
            int currentSegment = pathIterator.currentSegment(dArr);
            if (currentSegment == 0) {
                arrayList2.add(new Point2D.Double(dArr[0], dArr[1]));
                arrayList.add(SEGMENTINFO_MOVETO);
            } else if (currentSegment != 1) {
                if (currentSegment == 2) {
                    LOG.log(5, "SEG_QUADTO is not supported");
                } else if (currentSegment == 3) {
                    arrayList2.add(new Point2D.Double(dArr[i2], dArr[1]));
                    arrayList2.add(new Point2D.Double(dArr[2], dArr[3]));
                    arrayList2.add(new Point2D.Double(dArr[4], dArr[5]));
                    arrayList.add(SEGMENTINFO_CUBICTO);
                    arrayList.add(SEGMENTINFO_ESCAPE2);
                } else if (currentSegment != 4) {
                    POILogger pOILogger = LOG;
                    Object[] objArr = new Object[1];
                    objArr[i2] = a.c("Ignoring invalid segment type ", currentSegment);
                    pOILogger.log(5, objArr);
                } else {
                    arrayList2.add(arrayList2.get(i2));
                    arrayList.add(SEGMENTINFO_LINETO);
                    arrayList.add(SEGMENTINFO_ESCAPE);
                    arrayList.add(SEGMENTINFO_LINETO);
                    arrayList.add(SEGMENTINFO_CLOSE);
                    i3++;
                    z = true;
                }
                pathIterator.next();
                i2 = 0;
            } else {
                arrayList2.add(new Point2D.Double(dArr[0], dArr[1]));
                arrayList.add(SEGMENTINFO_LINETO);
                arrayList.add(SEGMENTINFO_ESCAPE);
            }
            i3++;
            pathIterator.next();
            i2 = 0;
        }
        if (!z) {
            arrayList.add(SEGMENTINFO_LINETO);
        }
        arrayList.add(SEGMENTINFO_END);
        AbstractEscherOptRecord escherOptRecord = getEscherOptRecord();
        escherOptRecord.addEscherProperty(new EscherSimpleProperty(EscherProperties.GEOMETRY__SHAPEPATH, 4));
        EscherArrayProperty escherArrayProperty = new EscherArrayProperty(16709, false, null);
        escherArrayProperty.setNumberOfElementsInArray(arrayList2.size());
        escherArrayProperty.setNumberOfElementsInMemory(arrayList2.size());
        escherArrayProperty.setSizeOfElements(8);
        for (int i4 = 0; i4 < arrayList2.size(); i4++) {
            Point2D.Double r11 = (Point2D.Double) arrayList2.get(i4);
            byte[] bArr = new byte[8];
            LittleEndian.putInt(bArr, 0, Units.pointsToMaster(r11.getX() - bounds2D.getX()));
            LittleEndian.putInt(bArr, 4, Units.pointsToMaster(r11.getY() - bounds2D.getY()));
            escherArrayProperty.setElement(i4, bArr);
        }
        escherOptRecord.addEscherProperty(escherArrayProperty);
        EscherArrayProperty escherArrayProperty2 = new EscherArrayProperty(16710, false, null);
        escherArrayProperty2.setNumberOfElementsInArray(arrayList.size());
        escherArrayProperty2.setNumberOfElementsInMemory(arrayList.size());
        escherArrayProperty2.setSizeOfElements(2);
        for (int i5 = 0; i5 < arrayList.size(); i5++) {
            escherArrayProperty2.setElement(i5, (byte[]) arrayList.get(i5));
        }
        escherOptRecord.addEscherProperty(escherArrayProperty2);
        escherOptRecord.addEscherProperty(new EscherSimpleProperty(EscherProperties.GEOMETRY__RIGHT, Units.pointsToMaster(bounds2D.getWidth())));
        escherOptRecord.addEscherProperty(new EscherSimpleProperty(EscherProperties.GEOMETRY__BOTTOM, Units.pointsToMaster(bounds2D.getHeight())));
        escherOptRecord.sortProperties();
        setAnchor(bounds2D);
        return i3;
    }

    public HSLFFreeformShape(ShapeContainer<HSLFShape, HSLFTextParagraph> shapeContainer) {
        super((EscherContainerRecord) null, shapeContainer);
        createSpContainer(ShapeType.NOT_PRIMITIVE, shapeContainer instanceof HSLFGroupShape);
    }

    public HSLFFreeformShape() {
        this(null);
    }
}
