package org.apache.poi.hslf.usermodel;

import java.awt.Dimension;
import java.io.OutputStream;
import java.security.MessageDigest;
import org.apache.poi.hslf.blip.DIB;
import org.apache.poi.hslf.blip.EMF;
import org.apache.poi.hslf.blip.JPEG;
import org.apache.poi.hslf.blip.PICT;
import org.apache.poi.hslf.blip.PNG;
import org.apache.poi.hslf.blip.WMF;
import org.apache.poi.poifs.crypt.CryptoFunctions;
import org.apache.poi.poifs.crypt.HashAlgorithm;
import org.apache.poi.sl.usermodel.PictureData;
import org.apache.poi.util.LittleEndian;
import org.apache.poi.util.Units;

public abstract class HSLFPictureData implements PictureData {
    public static final int CHECKSUM_SIZE = 16;
    public int index = -1;
    public int offset;
    public byte[] rawdata;
    public int uidInstanceCount = 1;

    /* renamed from: org.apache.poi.hslf.usermodel.HSLFPictureData$1  reason: invalid class name */
    public static /* synthetic */ class AnonymousClass1 {
        public static final /* synthetic */ int[] $SwitchMap$org$apache$poi$sl$usermodel$PictureData$PictureType;

        /* JADX WARNING: Failed to process nested try/catch */
        /* JADX WARNING: Missing exception handler attribute for start block: B:19:0x002b */
        static {
            int[] iArr = new int[PictureData.PictureType.values().length];
            $SwitchMap$org$apache$poi$sl$usermodel$PictureData$PictureType = iArr;
            try {
                PictureData.PictureType pictureType = PictureData.PictureType.EMF;
                iArr[0] = 1;
            } catch (NoSuchFieldError unused) {
            }
            try {
                int[] iArr2 = $SwitchMap$org$apache$poi$sl$usermodel$PictureData$PictureType;
                PictureData.PictureType pictureType2 = PictureData.PictureType.WMF;
                iArr2[1] = 2;
            } catch (NoSuchFieldError unused2) {
            }
            try {
                int[] iArr3 = $SwitchMap$org$apache$poi$sl$usermodel$PictureData$PictureType;
                PictureData.PictureType pictureType3 = PictureData.PictureType.PICT;
                iArr3[2] = 3;
            } catch (NoSuchFieldError unused3) {
            }
            try {
                int[] iArr4 = $SwitchMap$org$apache$poi$sl$usermodel$PictureData$PictureType;
                PictureData.PictureType pictureType4 = PictureData.PictureType.JPEG;
                iArr4[3] = 4;
            } catch (NoSuchFieldError unused4) {
            }
            int[] iArr5 = $SwitchMap$org$apache$poi$sl$usermodel$PictureData$PictureType;
            PictureData.PictureType pictureType5 = PictureData.PictureType.PNG;
            iArr5[4] = 5;
            try {
                int[] iArr6 = $SwitchMap$org$apache$poi$sl$usermodel$PictureData$PictureType;
                PictureData.PictureType pictureType6 = PictureData.PictureType.DIB;
                iArr6[5] = 6;
            } catch (NoSuchFieldError unused5) {
            }
        }
    }

    public static HSLFPictureData create(PictureData.PictureType pictureType) {
        int ordinal = pictureType.ordinal();
        if (ordinal == 0) {
            return new EMF();
        }
        if (ordinal == 1) {
            return new WMF();
        }
        if (ordinal == 2) {
            return new PICT();
        }
        if (ordinal == 3) {
            return new JPEG();
        }
        if (ordinal == 4) {
            return new PNG();
        }
        if (ordinal == 5) {
            return new DIB();
        }
        throw new IllegalArgumentException("Unsupported picture type: " + pictureType);
    }

    @Override // org.apache.poi.sl.usermodel.PictureData
    public byte[] getChecksum() {
        return getChecksum(getData());
    }

    @Override // org.apache.poi.sl.usermodel.PictureData
    public final String getContentType() {
        return getType().contentType;
    }

    public byte[] getHeader() {
        byte[] bArr = new byte[24];
        LittleEndian.putInt(bArr, 0, getSignature());
        LittleEndian.putInt(bArr, 4, getRawData().length);
        System.arraycopy(this.rawdata, 0, bArr, 8, 16);
        return bArr;
    }

    @Override // org.apache.poi.sl.usermodel.PictureData
    public Dimension getImageDimensionInPixels() {
        Dimension imageDimension = getImageDimension();
        return new Dimension(Units.pointsToPixel(imageDimension.getWidth()), Units.pointsToPixel(imageDimension.getHeight()));
    }

    public int getIndex() {
        return this.index;
    }

    public int getOffset() {
        return this.offset;
    }

    public byte[] getRawData() {
        return this.rawdata;
    }

    public abstract int getSignature();

    public byte[] getUID() {
        byte[] bArr = new byte[16];
        System.arraycopy(this.rawdata, 0, bArr, 0, 16);
        return bArr;
    }

    public int getUIDInstanceCount() {
        return this.uidInstanceCount;
    }

    public void setIndex(int i2) {
        this.index = i2;
    }

    public void setOffset(int i2) {
        this.offset = i2;
    }

    public void setRawData(byte[] bArr) {
        this.rawdata = bArr == null ? null : (byte[]) bArr.clone();
    }

    public abstract void setSignature(int i2);

    public void setUIDInstanceCount(int i2) {
        this.uidInstanceCount = i2;
    }

    public void write(OutputStream outputStream) {
        byte[] bArr = new byte[2];
        LittleEndian.putUShort(bArr, 0, getSignature());
        outputStream.write(bArr);
        byte[] bArr2 = new byte[2];
        LittleEndian.putUShort(bArr2, 0, getType().nativeId + 61464);
        outputStream.write(bArr2);
        byte[] rawData = getRawData();
        byte[] bArr3 = new byte[4];
        LittleEndian.putInt(bArr3, 0, rawData.length);
        outputStream.write(bArr3);
        outputStream.write(rawData);
    }

    public static byte[] getChecksum(byte[] bArr) {
        MessageDigest messageDigest = CryptoFunctions.getMessageDigest(HashAlgorithm.md5);
        messageDigest.update(bArr);
        return messageDigest.digest();
    }
}
