package org.apache.poi.hslf.usermodel;

import b.b.a.a.a;
import java.awt.Insets;
import java.util.List;
import org.apache.poi.ddf.AbstractEscherOptRecord;
import org.apache.poi.ddf.EscherBSERecord;
import org.apache.poi.ddf.EscherComplexProperty;
import org.apache.poi.ddf.EscherContainerRecord;
import org.apache.poi.ddf.EscherRecord;
import org.apache.poi.ddf.EscherSimpleProperty;
import org.apache.poi.ddf.EscherSpRecord;
import org.apache.poi.sl.draw.DrawPictureShape;
import org.apache.poi.sl.usermodel.PictureShape;
import org.apache.poi.sl.usermodel.ShapeContainer;
import org.apache.poi.sl.usermodel.ShapeType;
import org.apache.poi.ss.formula.functions.NumericFunction;
import org.apache.poi.util.POILogFactory;
import org.apache.poi.util.POILogger;
import org.apache.poi.util.StringUtil;
import org.apache.poi.util.Units;

public class HSLFPictureShape extends HSLFSimpleShape implements PictureShape<HSLFShape, HSLFTextParagraph> {
    public static final POILogger LOG = POILogFactory.getLogger(HSLFPictureShape.class);

    public HSLFPictureShape(HSLFPictureData hSLFPictureData) {
        this(hSLFPictureData, (ShapeContainer<HSLFShape, HSLFTextParagraph>) null);
    }

    public static double getFractProp(AbstractEscherOptRecord abstractEscherOptRecord, short s) {
        EscherSimpleProperty escherSimpleProperty = (EscherSimpleProperty) HSLFShape.getEscherProperty(abstractEscherOptRecord, s);
        if (escherSimpleProperty == null) {
            return NumericFunction.LOG_10_TO_BASE_e;
        }
        return Units.fixedPointToDouble(escherSimpleProperty.getPropertyValue());
    }

    @Override // org.apache.poi.hslf.usermodel.HSLFShape
    public void afterInsert(HSLFSheet hSLFSheet) {
        super.afterInsert(hSLFSheet);
        EscherBSERecord escherBSERecord = getEscherBSERecord();
        escherBSERecord.setRef(escherBSERecord.getRef() + 1);
        if (getAnchor().isEmpty()) {
            new DrawPictureShape(this).resize();
        }
    }

    public EscherContainerRecord createSpContainer(int i2, boolean z) {
        EscherContainerRecord createSpContainer = super.createSpContainer(z);
        ((EscherSpRecord) createSpContainer.getChildById(EscherSpRecord.RECORD_ID)).setOptions((short) ((ShapeType.FRAME.nativeId << 4) | 2));
        AbstractEscherOptRecord escherOptRecord = getEscherOptRecord();
        HSLFShape.setEscherProperty(escherOptRecord, 127, 8388736);
        HSLFShape.setEscherProperty(escherOptRecord, 16644, i2);
        return createSpContainer;
    }

    @Override // org.apache.poi.sl.usermodel.PictureShape
    public Insets getClipping() {
        AbstractEscherOptRecord escherOptRecord = getEscherOptRecord();
        double fractProp = getFractProp(escherOptRecord, 256);
        double fractProp2 = getFractProp(escherOptRecord, 257);
        double fractProp3 = getFractProp(escherOptRecord, 258);
        double fractProp4 = getFractProp(escherOptRecord, 259);
        if (fractProp == NumericFunction.LOG_10_TO_BASE_e && fractProp2 == NumericFunction.LOG_10_TO_BASE_e && fractProp3 == NumericFunction.LOG_10_TO_BASE_e && fractProp4 == NumericFunction.LOG_10_TO_BASE_e) {
            return null;
        }
        return new Insets((int) (fractProp * 100000.0d), (int) (fractProp3 * 100000.0d), (int) (fractProp2 * 100000.0d), (int) (fractProp4 * 100000.0d));
    }

    /* JADX WARN: Type inference failed for: r0v0, types: [org.apache.poi.hslf.usermodel.HSLFSheet] */
    /* JADX WARNING: Unknown variable types count: 1 */
    public EscherBSERecord getEscherBSERecord() {
        EscherContainerRecord escherContainerRecord = (EscherContainerRecord) HSLFShape.getEscherChild(getSheet().getSlideShow().getDocumentRecord().getPPDrawingGroup().getDggContainer(), -4095);
        if (escherContainerRecord == null) {
            LOG.log(1, "EscherContainerRecord.BSTORE_CONTAINER was not found ");
            return null;
        }
        List<EscherRecord> childRecords = escherContainerRecord.getChildRecords();
        int pictureIndex = getPictureIndex();
        if (pictureIndex != 0) {
            return (EscherBSERecord) childRecords.get(pictureIndex - 1);
        }
        LOG.log(1, "picture index was not found, returning ");
        return null;
    }

    public int getPictureIndex() {
        EscherSimpleProperty escherSimpleProperty = (EscherSimpleProperty) HSLFShape.getEscherProperty(getEscherOptRecord(), 260);
        if (escherSimpleProperty == null) {
            return 0;
        }
        return escherSimpleProperty.getPropertyValue();
    }

    public String getPictureName() {
        EscherComplexProperty escherComplexProperty = (EscherComplexProperty) HSLFShape.getEscherProperty(getEscherOptRecord(), 261);
        if (escherComplexProperty == null) {
            return null;
        }
        return StringUtil.getFromUnicodeLE(escherComplexProperty.getComplexData()).trim();
    }

    @Override // org.apache.poi.hslf.usermodel.HSLFShape, org.apache.poi.sl.usermodel.SimpleShape
    public ShapeType getShapeType() {
        return ShapeType.RECT;
    }

    public void setPictureName(String str) {
        AbstractEscherOptRecord escherOptRecord = getEscherOptRecord();
        escherOptRecord.addEscherProperty(new EscherComplexProperty(261, false, StringUtil.getToUnicodeLE(str + (char) 0)));
    }

    public HSLFPictureShape(HSLFPictureData hSLFPictureData, ShapeContainer<HSLFShape, HSLFTextParagraph> shapeContainer) {
        super(null, shapeContainer);
        createSpContainer(hSLFPictureData.getIndex(), shapeContainer instanceof HSLFGroupShape);
    }

    /* JADX WARN: Type inference failed for: r0v0, types: [org.apache.poi.hslf.usermodel.HSLFSheet] */
    /* JADX WARN: Type inference failed for: r0v1, types: [org.apache.poi.hslf.usermodel.HSLFSlideShow] */
    /* JADX WARNING: Unknown variable types count: 2 */
    @Override // org.apache.poi.sl.usermodel.PictureShape
    public HSLFPictureData getPictureData() {
        List<HSLFPictureData> pictureData = getSheet().getSlideShow().getPictureData();
        EscherBSERecord escherBSERecord = getEscherBSERecord();
        if (escherBSERecord == null) {
            LOG.log(7, "no reference to picture data found ");
            return null;
        }
        for (HSLFPictureData hSLFPictureData : pictureData) {
            if (hSLFPictureData.getOffset() == escherBSERecord.getOffset()) {
                return hSLFPictureData;
            }
        }
        POILogger pOILogger = LOG;
        StringBuilder b2 = a.b("no picture found for our BSE offset ");
        b2.append(escherBSERecord.getOffset());
        pOILogger.log(7, b2.toString());
        return null;
    }

    public HSLFPictureShape(EscherContainerRecord escherContainerRecord, ShapeContainer<HSLFShape, HSLFTextParagraph> shapeContainer) {
        super(escherContainerRecord, shapeContainer);
    }
}
