package org.apache.poi.hslf.usermodel;

import java.awt.Color;
import java.awt.Graphics2D;
import java.awt.geom.Rectangle2D;
import java.util.Iterator;
import java.util.List;
import org.apache.poi.ddf.AbstractEscherOptRecord;
import org.apache.poi.ddf.EscherChildAnchorRecord;
import org.apache.poi.ddf.EscherClientAnchorRecord;
import org.apache.poi.ddf.EscherClientDataRecord;
import org.apache.poi.ddf.EscherColorRef;
import org.apache.poi.ddf.EscherContainerRecord;
import org.apache.poi.ddf.EscherProperty;
import org.apache.poi.ddf.EscherRecord;
import org.apache.poi.ddf.EscherSimpleProperty;
import org.apache.poi.ddf.EscherSpRecord;
import org.apache.poi.hslf.record.HSLFEscherClientDataRecord;
import org.apache.poi.hslf.record.Record;
import org.apache.poi.hslf.record.RecordTypes;
import org.apache.poi.sl.draw.DrawFactory;
import org.apache.poi.sl.usermodel.FillStyle;
import org.apache.poi.sl.usermodel.PresetColor;
import org.apache.poi.sl.usermodel.Shape;
import org.apache.poi.sl.usermodel.ShapeContainer;
import org.apache.poi.sl.usermodel.ShapeType;
import org.apache.poi.sl.usermodel.Sheet;
import org.apache.poi.util.POILogFactory;
import org.apache.poi.util.POILogger;
import org.apache.poi.util.Units;

public abstract class HSLFShape implements Shape<HSLFShape, HSLFTextParagraph> {
    public static final POILogger LOG = POILogFactory.getLogger(HSLFShape.class);
    public EscherContainerRecord _escherContainer;
    public HSLFFill _fill;
    public ShapeContainer<HSLFShape, HSLFTextParagraph> _parent;
    public HSLFSheet _sheet;

    /* renamed from: org.apache.poi.hslf.usermodel.HSLFShape$1  reason: invalid class name */
    public static /* synthetic */ class AnonymousClass1 {
        public static final /* synthetic */ int[] $SwitchMap$org$apache$poi$ddf$EscherColorRef$SysIndexProcedure;
        public static final /* synthetic */ int[] $SwitchMap$org$apache$poi$ddf$EscherColorRef$SysIndexSource;

        /* JADX WARNING: Can't wrap try/catch for region: R(27:0|1|2|3|(2:5|6)|7|9|10|11|12|13|15|16|17|(2:19|20)|21|23|24|25|27|28|29|31|32|33|34|36) */
        /* JADX WARNING: Failed to process nested try/catch */
        /* JADX WARNING: Missing exception handler attribute for start block: B:11:0x0023 */
        /* JADX WARNING: Missing exception handler attribute for start block: B:33:0x004c */
        static {
            int[] iArr = new int[EscherColorRef.SysIndexProcedure.values().length];
            $SwitchMap$org$apache$poi$ddf$EscherColorRef$SysIndexProcedure = iArr;
            try {
                EscherColorRef.SysIndexProcedure sysIndexProcedure = EscherColorRef.SysIndexProcedure.DARKEN_COLOR;
                iArr[0] = 1;
            } catch (NoSuchFieldError unused) {
            }
            try {
                int[] iArr2 = $SwitchMap$org$apache$poi$ddf$EscherColorRef$SysIndexProcedure;
                EscherColorRef.SysIndexProcedure sysIndexProcedure2 = EscherColorRef.SysIndexProcedure.LIGHTEN_COLOR;
                iArr2[1] = 2;
            } catch (NoSuchFieldError unused2) {
            }
            int[] iArr3 = new int[EscherColorRef.SysIndexSource.values().length];
            $SwitchMap$org$apache$poi$ddf$EscherColorRef$SysIndexSource = iArr3;
            EscherColorRef.SysIndexSource sysIndexSource = EscherColorRef.SysIndexSource.FILL_COLOR;
            iArr3[0] = 1;
            int[] iArr4 = $SwitchMap$org$apache$poi$ddf$EscherColorRef$SysIndexSource;
            EscherColorRef.SysIndexSource sysIndexSource2 = EscherColorRef.SysIndexSource.LINE_OR_FILL_COLOR;
            iArr4[1] = 2;
            try {
                int[] iArr5 = $SwitchMap$org$apache$poi$ddf$EscherColorRef$SysIndexSource;
                EscherColorRef.SysIndexSource sysIndexSource3 = EscherColorRef.SysIndexSource.LINE_COLOR;
                iArr5[2] = 3;
            } catch (NoSuchFieldError unused3) {
            }
            try {
                int[] iArr6 = $SwitchMap$org$apache$poi$ddf$EscherColorRef$SysIndexSource;
                EscherColorRef.SysIndexSource sysIndexSource4 = EscherColorRef.SysIndexSource.SHADOW_COLOR;
                iArr6[3] = 4;
            } catch (NoSuchFieldError unused4) {
            }
            try {
                int[] iArr7 = $SwitchMap$org$apache$poi$ddf$EscherColorRef$SysIndexSource;
                EscherColorRef.SysIndexSource sysIndexSource5 = EscherColorRef.SysIndexSource.CURRENT_OR_LAST_COLOR;
                iArr7[4] = 5;
            } catch (NoSuchFieldError unused5) {
            }
            try {
                int[] iArr8 = $SwitchMap$org$apache$poi$ddf$EscherColorRef$SysIndexSource;
                EscherColorRef.SysIndexSource sysIndexSource6 = EscherColorRef.SysIndexSource.FILL_BACKGROUND_COLOR;
                iArr8[5] = 6;
            } catch (NoSuchFieldError unused6) {
            }
            int[] iArr9 = $SwitchMap$org$apache$poi$ddf$EscherColorRef$SysIndexSource;
            EscherColorRef.SysIndexSource sysIndexSource7 = EscherColorRef.SysIndexSource.LINE_BACKGROUND_COLOR;
            iArr9[6] = 7;
            try {
                int[] iArr10 = $SwitchMap$org$apache$poi$ddf$EscherColorRef$SysIndexSource;
                EscherColorRef.SysIndexSource sysIndexSource8 = EscherColorRef.SysIndexSource.FILL_OR_LINE_COLOR;
                iArr10[7] = 8;
            } catch (NoSuchFieldError unused7) {
            }
        }
    }

    public HSLFShape(EscherContainerRecord escherContainerRecord, ShapeContainer<HSLFShape, HSLFTextParagraph> shapeContainer) {
        this._escherContainer = escherContainerRecord;
        this._parent = shapeContainer;
    }

    private Color applySysIndexProcedure(EscherColorRef escherColorRef, Color color) {
        EscherColorRef.SysIndexProcedure sysIndexProcedure = escherColorRef.getSysIndexProcedure();
        if (color == null || sysIndexProcedure == null) {
            return color;
        }
        int ordinal = sysIndexProcedure.ordinal();
        if (ordinal == 0) {
            double d2 = ((double) escherColorRef.getRGB()[2]) / 255.0d;
            return new Color((int) Math.rint(((double) color.getRed()) * d2), (int) Math.rint(((double) color.getGreen()) * d2), (int) Math.rint(((double) color.getBlue()) * d2));
        } else if (ordinal != 1) {
            return color;
        } else {
            double d3 = ((double) (255 - escherColorRef.getRGB()[2])) / 255.0d;
            int red = color.getRed();
            int green = color.getGreen();
            int blue = color.getBlue();
            return new Color((int) (Math.rint(((double) (255 - red)) * d3) + ((double) red)), (int) (Math.rint(((double) (255 - green)) * d3) + ((double) green)), (int) (Math.rint(((double) (255 - blue)) * d3) + ((double) blue)));
        }
    }

    public static <T extends EscherRecord> T getEscherChild(EscherContainerRecord escherContainerRecord, int i2) {
        return (T) escherContainerRecord.getChildById((short) i2);
    }

    public static <T extends EscherProperty> T getEscherProperty(AbstractEscherOptRecord abstractEscherOptRecord, int i2) {
        if (abstractEscherOptRecord == null) {
            return null;
        }
        return (T) abstractEscherOptRecord.lookup(i2);
    }

    private Color getSysIndexColor(EscherColorRef escherColorRef) {
        EscherColorRef.SysIndexSource sysIndexSource = escherColorRef.getSysIndexSource();
        Color color = null;
        if (sysIndexSource == null) {
            PresetColor valueOfNativeId = PresetColor.valueOfNativeId(escherColorRef.getSysIndex());
            if (valueOfNativeId != null) {
                return valueOfNativeId.color;
            }
            return null;
        }
        int ordinal = sysIndexSource.ordinal();
        if (ordinal == 0) {
            return getFill().getForegroundColor();
        }
        if (ordinal != 1) {
            if (ordinal != 2) {
                if (ordinal != 3) {
                    if (ordinal == 5) {
                        return getFill().getBackgroundColor();
                    }
                    if (ordinal != 6) {
                        if (ordinal == 7) {
                            Color foregroundColor = getFill().getForegroundColor();
                            return (foregroundColor != null || !(this instanceof HSLFSimpleShape)) ? foregroundColor : ((HSLFSimpleShape) this).getLineColor();
                        }
                    } else if (this instanceof HSLFSimpleShape) {
                        return ((HSLFSimpleShape) this).getLineBackgroundColor();
                    }
                } else if (this instanceof HSLFSimpleShape) {
                    return ((HSLFSimpleShape) this).getShadowColor();
                }
            } else if (this instanceof HSLFSimpleShape) {
                return ((HSLFSimpleShape) this).getLineColor();
            }
            return null;
        }
        if (this instanceof HSLFSimpleShape) {
            color = ((HSLFSimpleShape) this).getLineColor();
        }
        return color == null ? getFill().getForegroundColor() : color;
    }

    public static void setEscherProperty(AbstractEscherOptRecord abstractEscherOptRecord, short s, int i2) {
        Iterator<EscherProperty> it = abstractEscherOptRecord.getEscherProperties().iterator();
        while (true) {
            if (it.hasNext()) {
                if (it.next().getPropertyNumber() == s) {
                    it.remove();
                    break;
                }
            } else {
                break;
            }
        }
        if (i2 != -1) {
            abstractEscherOptRecord.addEscherProperty(new EscherSimpleProperty(s, i2));
            abstractEscherOptRecord.sortProperties();
        }
    }

    public void afterInsert(HSLFSheet hSLFSheet) {
        HSLFFill hSLFFill = this._fill;
        if (hSLFFill != null) {
            hSLFFill.afterInsert(hSLFSheet);
        }
    }

    public EscherContainerRecord createSpContainer(boolean z) {
        if (this._escherContainer == null) {
            EscherContainerRecord escherContainerRecord = new EscherContainerRecord();
            this._escherContainer = escherContainerRecord;
            escherContainerRecord.setOptions(15);
        }
        return this._escherContainer;
    }

    @Override // org.apache.poi.sl.usermodel.Shape
    public void draw(Graphics2D graphics2D, Rectangle2D rectangle2D) {
        DrawFactory.getInstance(graphics2D).drawShape(graphics2D, this, rectangle2D);
    }

    public double getAlpha(short s) {
        int i2;
        EscherSimpleProperty escherSimpleProperty = (EscherSimpleProperty) getEscherProperty(getEscherOptRecord(), s);
        if (escherSimpleProperty == null) {
            i2 = 65536;
        } else {
            i2 = escherSimpleProperty.getPropertyValue();
        }
        return Units.fixedPointToDouble(i2);
    }

    @Override // org.apache.poi.sl.usermodel.Shape
    public Rectangle2D getAnchor() {
        int i2;
        int i3;
        int i4;
        int i5;
        int flags = ((EscherSpRecord) getEscherChild(-4086)).getFlags();
        EscherChildAnchorRecord escherChildAnchorRecord = (EscherChildAnchorRecord) getEscherChild(-4081);
        boolean z = (flags & 2) != 0;
        if (!z || escherChildAnchorRecord == null) {
            if (z) {
                LOG.log(5, "EscherSpRecord.FLAG_CHILD is set but EscherChildAnchorRecord was not found");
            }
            EscherClientAnchorRecord escherClientAnchorRecord = (EscherClientAnchorRecord) getEscherChild(-4080);
            short col1 = escherClientAnchorRecord.getCol1();
            i3 = escherClientAnchorRecord.getFlag();
            i2 = escherClientAnchorRecord.getDx1();
            i4 = escherClientAnchorRecord.getRow1();
            i5 = col1;
        } else {
            i5 = escherChildAnchorRecord.getDx1();
            i3 = escherChildAnchorRecord.getDy1();
            i2 = escherChildAnchorRecord.getDx2();
            i4 = escherChildAnchorRecord.getDy2();
        }
        return new Rectangle2D.Double(i5 == -1 ? -1.0d : Units.masterToPoints(i5), i3 == -1 ? -1.0d : Units.masterToPoints(i3), i2 == -1 ? -1.0d : Units.masterToPoints(i2 - i5), i4 == -1 ? -1.0d : Units.masterToPoints(i4 - i3));
    }

    public HSLFEscherClientDataRecord getClientData(boolean z) {
        HSLFEscherClientDataRecord hSLFEscherClientDataRecord = (HSLFEscherClientDataRecord) getEscherChild(-4079);
        if (hSLFEscherClientDataRecord != null || !z) {
            return hSLFEscherClientDataRecord;
        }
        HSLFEscherClientDataRecord hSLFEscherClientDataRecord2 = new HSLFEscherClientDataRecord();
        hSLFEscherClientDataRecord2.setOptions(15);
        hSLFEscherClientDataRecord2.setRecordId(EscherClientDataRecord.RECORD_ID);
        getSpContainer().addChildBefore(hSLFEscherClientDataRecord2, -4083);
        return hSLFEscherClientDataRecord2;
    }

    public <T extends Record> T getClientDataRecord(int i2) {
        List<? extends Record> clientRecords = getClientRecords();
        if (clientRecords == null) {
            return null;
        }
        for (Record record : clientRecords) {
            T t = (T) record;
            if (t.getRecordType() == ((long) i2)) {
                return t;
            }
        }
        return null;
    }

    public List<? extends Record> getClientRecords() {
        HSLFEscherClientDataRecord clientData = getClientData(false);
        if (clientData == null) {
            return null;
        }
        return clientData.getHSLFChildRecords();
    }

    public Color getColor(short s, short s2, int i2) {
        EscherSimpleProperty escherSimpleProperty = (EscherSimpleProperty) getEscherProperty(getEscherOptRecord(), s);
        if (escherSimpleProperty == null && i2 == -1) {
            return null;
        }
        if (escherSimpleProperty != null) {
            i2 = escherSimpleProperty.getPropertyValue();
        }
        Color color = getColor(new EscherColorRef(i2));
        if (color == null) {
            return null;
        }
        return new Color(color.getRed(), color.getGreen(), color.getBlue(), (int) (getAlpha(s2) * 255.0d));
    }

    public AbstractEscherOptRecord getEscherOptRecord() {
        AbstractEscherOptRecord abstractEscherOptRecord = (AbstractEscherOptRecord) getEscherChild(RecordTypes.EscherOPT);
        return abstractEscherOptRecord == null ? (AbstractEscherOptRecord) getEscherChild(RecordTypes.EscherUserDefined) : abstractEscherOptRecord;
    }

    public HSLFFill getFill() {
        if (this._fill == null) {
            this._fill = new HSLFFill(this);
        }
        return this._fill;
    }

    public FillStyle getFillStyle() {
        return getFill().getFillStyle();
    }

    public boolean getFlipHorizontal() {
        return (((EscherSpRecord) getEscherChild(-4086)).getFlags() & 64) != 0;
    }

    public boolean getFlipVertical() {
        return (((EscherSpRecord) getEscherChild(-4086)).getFlags() & 128) != 0;
    }

    @Override // org.apache.poi.sl.usermodel.Shape
    public ShapeContainer<HSLFShape, HSLFTextParagraph> getParent() {
        return this._parent;
    }

    public double getRotation() {
        return Units.fixedPointToDouble(getEscherProperty(4));
    }

    public int getShapeId() {
        EscherSpRecord escherSpRecord = (EscherSpRecord) getEscherChild(-4086);
        if (escherSpRecord == null) {
            return 0;
        }
        return escherSpRecord.getShapeId();
    }

    public String getShapeName() {
        return getShapeType().nativeName;
    }

    public ShapeType getShapeType() {
        return ShapeType.forId(((EscherSpRecord) getEscherChild(-4086)).getShapeType(), false);
    }

    public EscherContainerRecord getSpContainer() {
        return this._escherContainer;
    }

    public boolean isPlaceholder() {
        return false;
    }

    public final void moveTo(double d2, double d3) {
        Rectangle2D anchor = getAnchor();
        anchor.setRect(d2, d3, anchor.getWidth(), anchor.getHeight());
        setAnchor(anchor);
    }

    public void setAnchor(Rectangle2D rectangle2D) {
        int pointsToMaster = Units.pointsToMaster(rectangle2D.getX());
        int pointsToMaster2 = Units.pointsToMaster(rectangle2D.getY());
        int pointsToMaster3 = Units.pointsToMaster(rectangle2D.getWidth() + rectangle2D.getX());
        int pointsToMaster4 = Units.pointsToMaster(rectangle2D.getHeight() + rectangle2D.getY());
        if ((((EscherSpRecord) getEscherChild(-4086)).getFlags() & 2) != 0) {
            EscherChildAnchorRecord escherChildAnchorRecord = (EscherChildAnchorRecord) getEscherChild(-4081);
            escherChildAnchorRecord.setDx1(pointsToMaster);
            escherChildAnchorRecord.setDy1(pointsToMaster2);
            escherChildAnchorRecord.setDx2(pointsToMaster3);
            escherChildAnchorRecord.setDy2(pointsToMaster4);
            return;
        }
        EscherClientAnchorRecord escherClientAnchorRecord = (EscherClientAnchorRecord) getEscherChild(-4080);
        escherClientAnchorRecord.setCol1((short) pointsToMaster);
        escherClientAnchorRecord.setFlag((short) pointsToMaster2);
        escherClientAnchorRecord.setDx1((short) pointsToMaster3);
        escherClientAnchorRecord.setRow1((short) pointsToMaster4);
    }

    public void setFlipHorizontal(boolean z) {
        EscherSpRecord escherSpRecord = (EscherSpRecord) getEscherChild(-4086);
        escherSpRecord.setFlags(escherSpRecord.getFlags() | 64);
    }

    public void setFlipVertical(boolean z) {
        EscherSpRecord escherSpRecord = (EscherSpRecord) getEscherChild(-4086);
        escherSpRecord.setFlags(escherSpRecord.getFlags() | 128);
    }

    public void setRotation(double d2) {
        setEscherProperty(4, Units.doubleToFixedPoint(d2 % 360.0d));
    }

    public void setShapeId(int i2) {
        EscherSpRecord escherSpRecord = (EscherSpRecord) getEscherChild(-4086);
        if (escherSpRecord != null) {
            escherSpRecord.setShapeId(i2);
        }
    }

    public void setShapeType(ShapeType shapeType) {
        EscherSpRecord escherSpRecord = (EscherSpRecord) getEscherChild(-4086);
        escherSpRecord.setShapeType((short) shapeType.nativeId);
        escherSpRecord.setVersion(2);
    }

    public void setSheet(HSLFSheet hSLFSheet) {
        this._sheet = hSLFSheet;
    }

    /* JADX WARN: Type inference failed for: r6v4, types: [org.apache.poi.hslf.usermodel.HSLFSheet] */
    /* JADX WARNING: Unknown variable types count: 1 */
    public Color toRGB(int i2) {
        int i3 = (i2 >> 24) & 255;
        int i4 = (i2 >> 16) & 255;
        int i5 = (i2 >> 8) & 255;
        int i6 = (i2 >> 0) & 255;
        if (!(i3 == 254 || i3 == 255)) {
            int color = getSheet().getColorScheme().getColor(i3);
            i5 = (color >> 8) & 255;
            i4 = (color >> 16) & 255;
            i6 = (color >> 0) & 255;
        }
        return new Color(i6, i5, i4);
    }

    public static <T extends EscherRecord> T getEscherChild(EscherContainerRecord escherContainerRecord, RecordTypes recordTypes) {
        return (T) getEscherChild(escherContainerRecord, recordTypes.typeID);
    }

    public int getEscherProperty(short s) {
        EscherSimpleProperty escherSimpleProperty = (EscherSimpleProperty) getEscherProperty(getEscherOptRecord(), s);
        if (escherSimpleProperty == null) {
            return 0;
        }
        return escherSimpleProperty.getPropertyValue();
    }

    /* Return type fixed from 'org.apache.poi.hslf.usermodel.HSLFSheet' to match base method */
    @Override // org.apache.poi.sl.usermodel.Shape
    public Sheet<HSLFShape, HSLFTextParagraph> getSheet() {
        return this._sheet;
    }

    public <T extends EscherRecord> T getEscherChild(int i2) {
        return (T) this._escherContainer.getChildById((short) i2);
    }

    public <T extends EscherRecord> T getEscherChild(RecordTypes recordTypes) {
        return (T) getEscherChild(recordTypes.typeID);
    }

    public int getEscherProperty(short s, int i2) {
        EscherSimpleProperty escherSimpleProperty = (EscherSimpleProperty) getEscherProperty(getEscherOptRecord(), s);
        return escherSimpleProperty == null ? i2 : escherSimpleProperty.getPropertyValue();
    }

    public void setEscherProperty(short s, int i2) {
        setEscherProperty(getEscherOptRecord(), s, i2);
    }

    /* JADX WARN: Type inference failed for: r6v0, types: [org.apache.poi.hslf.usermodel.HSLFSheet] */
    /* JADX WARNING: Unknown variable types count: 1 */
    public Color getColor(EscherColorRef escherColorRef) {
        boolean hasPaletteIndexFlag = escherColorRef.hasPaletteIndexFlag();
        boolean hasPaletteRGBFlag = escherColorRef.hasPaletteRGBFlag();
        boolean hasSystemRGBFlag = escherColorRef.hasSystemRGBFlag();
        boolean hasSchemeIndexFlag = escherColorRef.hasSchemeIndexFlag();
        boolean hasSysIndexFlag = escherColorRef.hasSysIndexFlag();
        int[] rgb = escherColorRef.getRGB();
        ?? sheet = getSheet();
        if (hasSchemeIndexFlag && sheet != 0) {
            int color = sheet.getColorScheme().getColor(escherColorRef.getSchemeIndex());
            rgb[0] = (color >> 0) & 255;
            rgb[1] = (color >> 8) & 255;
            rgb[2] = (color >> 16) & 255;
        } else if (!hasPaletteIndexFlag && !hasPaletteRGBFlag && !hasSystemRGBFlag && hasSysIndexFlag) {
            return applySysIndexProcedure(escherColorRef, getSysIndexColor(escherColorRef));
        }
        return new Color(rgb[0], rgb[1], rgb[2]);
    }
}
