package org.apache.poi.hslf.usermodel;

import java.util.Iterator;
import org.apache.poi.ddf.AbstractEscherOptRecord;
import org.apache.poi.ddf.EscherClientDataRecord;
import org.apache.poi.ddf.EscherContainerRecord;
import org.apache.poi.ddf.EscherProperty;
import org.apache.poi.ddf.EscherPropertyFactory;
import org.apache.poi.ddf.EscherRecord;
import org.apache.poi.ddf.EscherSimpleProperty;
import org.apache.poi.ddf.EscherSpRecord;
import org.apache.poi.ddf.EscherTextboxRecord;
import org.apache.poi.hslf.model.MovieShape;
import org.apache.poi.hslf.model.OLEShape;
import org.apache.poi.hslf.record.ExObjRefAtom;
import org.apache.poi.hslf.record.HSLFEscherClientDataRecord;
import org.apache.poi.hslf.record.InteractiveInfo;
import org.apache.poi.hslf.record.Record;
import org.apache.poi.hslf.record.RecordTypes;
import org.apache.poi.sl.usermodel.ShapeContainer;
import org.apache.poi.sl.usermodel.ShapeType;
import org.apache.poi.util.POILogFactory;
import org.apache.poi.util.POILogger;

public final class HSLFShapeFactory {
    public static final POILogger logger = POILogFactory.getLogger(HSLFShapeFactory.class);

    /* renamed from: org.apache.poi.hslf.usermodel.HSLFShapeFactory$1  reason: invalid class name */
    public static /* synthetic */ class AnonymousClass1 {
        public static final /* synthetic */ int[] $SwitchMap$org$apache$poi$sl$usermodel$ShapeType;

        /* JADX WARNING: Can't wrap try/catch for region: R(12:0|1|2|3|4|5|6|7|8|9|10|12) */
        /* JADX WARNING: Code restructure failed: missing block: B:13:?, code lost:
            return;
         */
        /* JADX WARNING: Failed to process nested try/catch */
        /* JADX WARNING: Missing exception handler attribute for start block: B:3:0x0010 */
        /* JADX WARNING: Missing exception handler attribute for start block: B:5:0x0019 */
        /* JADX WARNING: Missing exception handler attribute for start block: B:7:0x0022 */
        /* JADX WARNING: Missing exception handler attribute for start block: B:9:0x0029 */
        static {
            int[] iArr = new int[ShapeType.values().length];
            $SwitchMap$org$apache$poi$sl$usermodel$ShapeType = iArr;
            ShapeType shapeType = ShapeType.TEXT_BOX;
            iArr[245] = 1;
            int[] iArr2 = $SwitchMap$org$apache$poi$sl$usermodel$ShapeType;
            ShapeType shapeType2 = ShapeType.HOST_CONTROL;
            iArr2[244] = 2;
            int[] iArr3 = $SwitchMap$org$apache$poi$sl$usermodel$ShapeType;
            ShapeType shapeType3 = ShapeType.FRAME;
            iArr3[85] = 3;
            int[] iArr4 = $SwitchMap$org$apache$poi$sl$usermodel$ShapeType;
            ShapeType shapeType4 = ShapeType.LINE;
            iArr4[1] = 4;
            int[] iArr5 = $SwitchMap$org$apache$poi$sl$usermodel$ShapeType;
            ShapeType shapeType5 = ShapeType.NOT_PRIMITIVE;
            iArr5[0] = 5;
        }
    }

    public static HSLFShape createFrame(EscherContainerRecord escherContainerRecord, ShapeContainer<HSLFShape, HSLFTextParagraph> shapeContainer) {
        InteractiveInfo interactiveInfo = (InteractiveInfo) getClientDataRecord(escherContainerRecord, RecordTypes.InteractiveInfo.typeID);
        if (!(interactiveInfo == null || interactiveInfo.getInteractiveInfoAtom() == null)) {
            byte action = interactiveInfo.getInteractiveInfoAtom().getAction();
            if (action == 5) {
                return new OLEShape(escherContainerRecord, shapeContainer);
            }
            if (action == 6) {
                return new MovieShape(escherContainerRecord, shapeContainer);
            }
        }
        return ((ExObjRefAtom) getClientDataRecord(escherContainerRecord, RecordTypes.ExObjRefAtom.typeID)) != null ? new OLEShape(escherContainerRecord, shapeContainer) : new HSLFPictureShape(escherContainerRecord, shapeContainer);
    }

    public static HSLFShape createNonPrimitive(EscherContainerRecord escherContainerRecord, ShapeContainer<HSLFShape, HSLFTextParagraph> shapeContainer) {
        if (HSLFShape.getEscherProperty((AbstractEscherOptRecord) HSLFShape.getEscherChild(escherContainerRecord, -4085), 325) != null) {
            return new HSLFFreeformShape(escherContainerRecord, shapeContainer);
        }
        logger.log(3, "Creating AutoShape for a NotPrimitive shape");
        return new HSLFAutoShape(escherContainerRecord, shapeContainer);
    }

    public static HSLFShape createShape(EscherContainerRecord escherContainerRecord, ShapeContainer<HSLFShape, HSLFTextParagraph> shapeContainer) {
        if (escherContainerRecord.getRecordId() == -4093) {
            return createShapeGroup(escherContainerRecord, shapeContainer);
        }
        return createSimpleShape(escherContainerRecord, shapeContainer);
    }

    public static HSLFGroupShape createShapeGroup(EscherContainerRecord escherContainerRecord, ShapeContainer<HSLFShape, HSLFTextParagraph> shapeContainer) {
        boolean z = false;
        EscherRecord escherChild = HSLFShape.getEscherChild((EscherContainerRecord) escherContainerRecord.getChild(0), RecordTypes.EscherUserDefined);
        if (escherChild != null) {
            Iterator<EscherProperty> it = new EscherPropertyFactory().createProperties(escherChild.serialize(), 8, escherChild.getInstance()).iterator();
            while (true) {
                if (!it.hasNext()) {
                    break;
                }
                EscherProperty next = it.next();
                if (next.getPropertyNumber() == 927 && (next instanceof EscherSimpleProperty) && (((EscherSimpleProperty) next).getPropertyValue() & 1) == 1) {
                    z = true;
                    break;
                }
            }
        }
        if (z) {
            return new HSLFTable(escherContainerRecord, shapeContainer);
        }
        return new HSLFGroupShape(escherContainerRecord, shapeContainer);
    }

    public static HSLFShape createSimpleShape(EscherContainerRecord escherContainerRecord, ShapeContainer<HSLFShape, HSLFTextParagraph> shapeContainer) {
        int ordinal = ShapeType.forId(((EscherSpRecord) escherContainerRecord.getChildById(EscherSpRecord.RECORD_ID)).getShapeType(), false).ordinal();
        if (ordinal == 0) {
            return createNonPrimitive(escherContainerRecord, shapeContainer);
        }
        if (ordinal == 1) {
            return new HSLFLine(escherContainerRecord, shapeContainer);
        }
        if (ordinal == 85 || ordinal == 244) {
            return createFrame(escherContainerRecord, shapeContainer);
        }
        if (ordinal == 245) {
            return new HSLFTextBox(escherContainerRecord, shapeContainer);
        }
        if (!(shapeContainer instanceof HSLFTable)) {
            return new HSLFAutoShape(escherContainerRecord, shapeContainer);
        }
        if (((EscherTextboxRecord) escherContainerRecord.getChildById(EscherTextboxRecord.RECORD_ID)) == null) {
            logger.log(5, "invalid ppt - add EscherTextboxRecord to cell");
            EscherTextboxRecord escherTextboxRecord = new EscherTextboxRecord();
            escherTextboxRecord.setRecordId(EscherTextboxRecord.RECORD_ID);
            escherTextboxRecord.setOptions(15);
            escherContainerRecord.addChildRecord(escherTextboxRecord);
        }
        return new HSLFTableCell(escherContainerRecord, (HSLFTable) shapeContainer);
    }

    public static <T extends Record> T getClientDataRecord(EscherContainerRecord escherContainerRecord, int i2) {
        HSLFEscherClientDataRecord hSLFEscherClientDataRecord = (HSLFEscherClientDataRecord) escherContainerRecord.getChildById(EscherClientDataRecord.RECORD_ID);
        if (hSLFEscherClientDataRecord == null) {
            return null;
        }
        for (Record record : hSLFEscherClientDataRecord.getHSLFChildRecords()) {
            T t = (T) record;
            if (t.getRecordType() == ((long) i2)) {
                return t;
            }
        }
        return null;
    }
}
