package org.apache.poi.hslf.usermodel;

import b.b.a.a.a;
import java.awt.Color;
import java.util.Iterator;
import java.util.List;
import org.apache.poi.ddf.AbstractEscherOptRecord;
import org.apache.poi.ddf.EscherChildAnchorRecord;
import org.apache.poi.ddf.EscherClientAnchorRecord;
import org.apache.poi.ddf.EscherContainerRecord;
import org.apache.poi.ddf.EscherOptRecord;
import org.apache.poi.ddf.EscherProperties;
import org.apache.poi.ddf.EscherSimpleProperty;
import org.apache.poi.ddf.EscherSpRecord;
import org.apache.poi.hslf.exceptions.HSLFException;
import org.apache.poi.hslf.record.HSLFEscherClientDataRecord;
import org.apache.poi.hslf.record.OEPlaceholderAtom;
import org.apache.poi.hslf.record.Record;
import org.apache.poi.hslf.record.RoundTripHFPlaceholder12;
import org.apache.poi.sl.draw.DrawPaint;
import org.apache.poi.sl.draw.geom.CustomGeometry;
import org.apache.poi.sl.draw.geom.Guide;
import org.apache.poi.sl.draw.geom.PresetGeometries;
import org.apache.poi.sl.usermodel.Hyperlink;
import org.apache.poi.sl.usermodel.LineDecoration;
import org.apache.poi.sl.usermodel.MasterSheet;
import org.apache.poi.sl.usermodel.PaintStyle;
import org.apache.poi.sl.usermodel.Placeholder;
import org.apache.poi.sl.usermodel.Shadow;
import org.apache.poi.sl.usermodel.ShapeContainer;
import org.apache.poi.sl.usermodel.ShapeType;
import org.apache.poi.sl.usermodel.Sheet;
import org.apache.poi.sl.usermodel.SimpleShape;
import org.apache.poi.sl.usermodel.StrokeStyle;
import org.apache.poi.ss.formula.functions.NumericFunction;
import org.apache.poi.util.LittleEndian;
import org.apache.poi.util.POILogFactory;
import org.apache.poi.util.POILogger;
import org.apache.poi.util.Units;

public abstract class HSLFSimpleShape extends HSLFShape implements SimpleShape<HSLFShape, HSLFTextParagraph> {
    public static final double DEFAULT_LINE_WIDTH = 0.75d;
    public static final POILogger LOG = POILogFactory.getLogger(HSLFSimpleShape.class);
    public HSLFHyperlink _hyperlink;

    /* renamed from: org.apache.poi.hslf.usermodel.HSLFSimpleShape$4  reason: invalid class name */
    public static /* synthetic */ class AnonymousClass4 {
        public static final /* synthetic */ int[] $SwitchMap$org$apache$poi$sl$usermodel$Placeholder;

        /* JADX WARNING: Failed to process nested try/catch */
        /* JADX WARNING: Missing exception handler attribute for start block: B:3:0x0010 */
        static {
            int[] iArr = new int[Placeholder.values().length];
            $SwitchMap$org$apache$poi$sl$usermodel$Placeholder = iArr;
            Placeholder placeholder = Placeholder.HEADER;
            iArr[8] = 1;
            try {
                int[] iArr2 = $SwitchMap$org$apache$poi$sl$usermodel$Placeholder;
                Placeholder placeholder2 = Placeholder.FOOTER;
                iArr2[7] = 2;
            } catch (NoSuchFieldError unused) {
            }
        }
    }

    public HSLFSimpleShape(EscherContainerRecord escherContainerRecord, ShapeContainer<HSLFShape, HSLFTextParagraph> shapeContainer) {
        super(escherContainerRecord, shapeContainer);
    }

    @Override // org.apache.poi.hslf.usermodel.HSLFShape
    public EscherContainerRecord createSpContainer(boolean z) {
        EscherChildAnchorRecord escherChildAnchorRecord;
        EscherContainerRecord createSpContainer = super.createSpContainer(z);
        createSpContainer.setRecordId(EscherContainerRecord.SP_CONTAINER);
        EscherSpRecord escherSpRecord = new EscherSpRecord();
        escherSpRecord.setFlags(z ? 2562 : 2560);
        createSpContainer.addChildRecord(escherSpRecord);
        EscherOptRecord escherOptRecord = new EscherOptRecord();
        escherOptRecord.setRecordId(EscherOptRecord.RECORD_ID);
        createSpContainer.addChildRecord(escherOptRecord);
        if (z) {
            escherChildAnchorRecord = new EscherChildAnchorRecord();
        } else {
            EscherClientAnchorRecord escherClientAnchorRecord = new EscherClientAnchorRecord();
            byte[] bArr = new byte[16];
            LittleEndian.putUShort(bArr, 0, 0);
            LittleEndian.putUShort(bArr, 2, 0);
            LittleEndian.putInt(bArr, 4, 8);
            escherClientAnchorRecord.fillFields(bArr, 0, null);
            escherChildAnchorRecord = escherClientAnchorRecord;
        }
        createSpContainer.addChildRecord(escherChildAnchorRecord);
        return createSpContainer;
    }

    @Override // org.apache.poi.sl.draw.geom.IAdjustableShape
    public Guide getAdjustValue(String str) {
        short s;
        if (str == null || !str.matches("adj([1-9]|10)?")) {
            LOG.log(3, a.b("Adjust value '", str, "' not supported. Using default value."));
            return null;
        }
        String replace = str.replace("adj", "");
        if ("".equals(replace)) {
            replace = "1";
        }
        switch (Integer.parseInt(replace)) {
            case 1:
                s = EscherProperties.GEOMETRY__ADJUSTVALUE;
                break;
            case 2:
                s = EscherProperties.GEOMETRY__ADJUST2VALUE;
                break;
            case 3:
                s = EscherProperties.GEOMETRY__ADJUST3VALUE;
                break;
            case 4:
                s = EscherProperties.GEOMETRY__ADJUST4VALUE;
                break;
            case 5:
                s = EscherProperties.GEOMETRY__ADJUST5VALUE;
                break;
            case 6:
                s = EscherProperties.GEOMETRY__ADJUST6VALUE;
                break;
            case 7:
                s = EscherProperties.GEOMETRY__ADJUST7VALUE;
                break;
            case 8:
                s = EscherProperties.GEOMETRY__ADJUST8VALUE;
                break;
            case 9:
                s = EscherProperties.GEOMETRY__ADJUST9VALUE;
                break;
            case 10:
                s = EscherProperties.GEOMETRY__ADJUST10VALUE;
                break;
            default:
                throw new HSLFException();
        }
        int escherProperty = getEscherProperty(s, -1);
        if (escherProperty == -1) {
            return null;
        }
        return new Guide(replace, a.c("val ", escherProperty));
    }

    @Override // org.apache.poi.sl.usermodel.SimpleShape
    public Color getFillColor() {
        return getFill().getForegroundColor();
    }

    @Override // org.apache.poi.sl.usermodel.SimpleShape
    public CustomGeometry getGeometry() {
        PresetGeometries instance = PresetGeometries.getInstance();
        ShapeType shapeType = getShapeType();
        String ooxmlName = shapeType != null ? shapeType.getOoxmlName() : null;
        CustomGeometry customGeometry = (CustomGeometry) instance.get(ooxmlName);
        if (customGeometry == null) {
            if (ooxmlName == null) {
                ooxmlName = shapeType != null ? shapeType.toString() : "<unknown>";
            }
            LOG.log(5, a.b("No preset shape definition for shapeType: ", ooxmlName));
        }
        return customGeometry;
    }

    public Color getLineBackgroundColor() {
        Color color;
        EscherSimpleProperty escherSimpleProperty = (EscherSimpleProperty) HSLFShape.getEscherProperty(getEscherOptRecord(), 511);
        if ((escherSimpleProperty == null || (escherSimpleProperty.getPropertyValue() & 8) != 0) && (color = getColor(EscherProperties.LINESTYLE__BACKCOLOR, 449, -1)) != null) {
            return color;
        }
        return null;
    }

    public StrokeStyle.LineCap getLineCap() {
        EscherSimpleProperty escherSimpleProperty = (EscherSimpleProperty) HSLFShape.getEscherProperty(getEscherOptRecord(), 471);
        return escherSimpleProperty == null ? StrokeStyle.LineCap.FLAT : StrokeStyle.LineCap.fromNativeId(escherSimpleProperty.getPropertyValue());
    }

    public Color getLineColor() {
        Color color;
        EscherSimpleProperty escherSimpleProperty = (EscherSimpleProperty) HSLFShape.getEscherProperty(getEscherOptRecord(), 511);
        if ((escherSimpleProperty == null || (escherSimpleProperty.getPropertyValue() & 8) != 0) && (color = getColor(EscherProperties.LINESTYLE__COLOR, 449, -1)) != null) {
            return color;
        }
        return null;
    }

    public StrokeStyle.LineCompound getLineCompound() {
        EscherSimpleProperty escherSimpleProperty = (EscherSimpleProperty) HSLFShape.getEscherProperty(getEscherOptRecord(), 461);
        return escherSimpleProperty == null ? StrokeStyle.LineCompound.SINGLE : StrokeStyle.LineCompound.fromNativeId(escherSimpleProperty.getPropertyValue());
    }

    public StrokeStyle.LineDash getLineDash() {
        EscherSimpleProperty escherSimpleProperty = (EscherSimpleProperty) HSLFShape.getEscherProperty(getEscherOptRecord(), 462);
        return escherSimpleProperty == null ? StrokeStyle.LineDash.SOLID : StrokeStyle.LineDash.fromNativeId(escherSimpleProperty.getPropertyValue());
    }

    @Override // org.apache.poi.sl.usermodel.SimpleShape
    public LineDecoration getLineDecoration() {
        return new LineDecoration() {
            /* class org.apache.poi.hslf.usermodel.HSLFSimpleShape.AnonymousClass3 */

            @Override // org.apache.poi.sl.usermodel.LineDecoration
            public LineDecoration.DecorationSize getHeadLength() {
                return HSLFSimpleShape.this.getLineHeadLength();
            }

            @Override // org.apache.poi.sl.usermodel.LineDecoration
            public LineDecoration.DecorationShape getHeadShape() {
                return HSLFSimpleShape.this.getLineHeadDecoration();
            }

            @Override // org.apache.poi.sl.usermodel.LineDecoration
            public LineDecoration.DecorationSize getHeadWidth() {
                return HSLFSimpleShape.this.getLineHeadWidth();
            }

            @Override // org.apache.poi.sl.usermodel.LineDecoration
            public LineDecoration.DecorationSize getTailLength() {
                return HSLFSimpleShape.this.getLineTailLength();
            }

            @Override // org.apache.poi.sl.usermodel.LineDecoration
            public LineDecoration.DecorationShape getTailShape() {
                return HSLFSimpleShape.this.getLineTailDecoration();
            }

            @Override // org.apache.poi.sl.usermodel.LineDecoration
            public LineDecoration.DecorationSize getTailWidth() {
                return HSLFSimpleShape.this.getLineTailWidth();
            }
        };
    }

    public LineDecoration.DecorationShape getLineHeadDecoration() {
        EscherSimpleProperty escherSimpleProperty = (EscherSimpleProperty) HSLFShape.getEscherProperty(getEscherOptRecord(), 464);
        if (escherSimpleProperty == null) {
            return null;
        }
        return LineDecoration.DecorationShape.fromNativeId(escherSimpleProperty.getPropertyValue());
    }

    public LineDecoration.DecorationSize getLineHeadLength() {
        EscherSimpleProperty escherSimpleProperty = (EscherSimpleProperty) HSLFShape.getEscherProperty(getEscherOptRecord(), 467);
        if (escherSimpleProperty == null) {
            return null;
        }
        return LineDecoration.DecorationSize.fromNativeId(escherSimpleProperty.getPropertyValue());
    }

    public LineDecoration.DecorationSize getLineHeadWidth() {
        EscherSimpleProperty escherSimpleProperty = (EscherSimpleProperty) HSLFShape.getEscherProperty(getEscherOptRecord(), 466);
        if (escherSimpleProperty == null) {
            return null;
        }
        return LineDecoration.DecorationSize.fromNativeId(escherSimpleProperty.getPropertyValue());
    }

    public LineDecoration.DecorationShape getLineTailDecoration() {
        EscherSimpleProperty escherSimpleProperty = (EscherSimpleProperty) HSLFShape.getEscherProperty(getEscherOptRecord(), 465);
        if (escherSimpleProperty == null) {
            return null;
        }
        return LineDecoration.DecorationShape.fromNativeId(escherSimpleProperty.getPropertyValue());
    }

    public LineDecoration.DecorationSize getLineTailLength() {
        EscherSimpleProperty escherSimpleProperty = (EscherSimpleProperty) HSLFShape.getEscherProperty(getEscherOptRecord(), 469);
        if (escherSimpleProperty == null) {
            return null;
        }
        return LineDecoration.DecorationSize.fromNativeId(escherSimpleProperty.getPropertyValue());
    }

    public LineDecoration.DecorationSize getLineTailWidth() {
        EscherSimpleProperty escherSimpleProperty = (EscherSimpleProperty) HSLFShape.getEscherProperty(getEscherOptRecord(), 468);
        if (escherSimpleProperty == null) {
            return null;
        }
        return LineDecoration.DecorationSize.fromNativeId(escherSimpleProperty.getPropertyValue());
    }

    public double getLineWidth() {
        EscherSimpleProperty escherSimpleProperty = (EscherSimpleProperty) HSLFShape.getEscherProperty(getEscherOptRecord(), 459);
        if (escherSimpleProperty == null) {
            return 0.75d;
        }
        return Units.toPoints((long) escherSimpleProperty.getPropertyValue());
    }

    @Override // org.apache.poi.sl.usermodel.SimpleShape
    public Placeholder getPlaceholder() {
        char c;
        int placeholderId;
        List<? extends Record> clientRecords = getClientRecords();
        if (clientRecords == null) {
            return null;
        }
        Sheet<HSLFShape, HSLFTextParagraph> sheet = getSheet();
        if (sheet instanceof HSLFSlideMaster) {
            c = 1;
        } else if (sheet instanceof HSLFNotes) {
            c = 2;
        } else {
            c = sheet instanceof MasterSheet ? (char) 3 : 0;
        }
        for (Record record : clientRecords) {
            if (record instanceof OEPlaceholderAtom) {
                placeholderId = ((OEPlaceholderAtom) record).getPlaceholderId();
            } else if (record instanceof RoundTripHFPlaceholder12) {
                placeholderId = ((RoundTripHFPlaceholder12) record).getPlaceholderId();
            }
            if (c == 0) {
                return Placeholder.lookupNativeSlide(placeholderId);
            }
            if (c == 2) {
                return Placeholder.lookupNativeNotes(placeholderId);
            }
            if (c != 3) {
                return Placeholder.lookupNativeSlideMaster(placeholderId);
            }
            return Placeholder.lookupNativeNotesMaster(placeholderId);
        }
        return null;
    }

    @Override // org.apache.poi.sl.usermodel.SimpleShape
    public Shadow<HSLFShape, HSLFTextParagraph> getShadow() {
        AbstractEscherOptRecord escherOptRecord = getEscherOptRecord();
        if (escherOptRecord == null || escherOptRecord.lookup(512) == null) {
            return null;
        }
        return new Shadow<HSLFShape, HSLFTextParagraph>() {
            /* class org.apache.poi.hslf.usermodel.HSLFSimpleShape.AnonymousClass2 */

            @Override // org.apache.poi.sl.usermodel.Shadow
            public double getAngle() {
                return HSLFSimpleShape.this.getShadowAngle();
            }

            @Override // org.apache.poi.sl.usermodel.Shadow
            public double getBlur() {
                return NumericFunction.LOG_10_TO_BASE_e;
            }

            @Override // org.apache.poi.sl.usermodel.Shadow
            public double getDistance() {
                return HSLFSimpleShape.this.getShadowDistance();
            }

            @Override // org.apache.poi.sl.usermodel.Shadow
            public PaintStyle.SolidPaint getFillStyle() {
                return DrawPaint.createSolidPaint(HSLFSimpleShape.this.getShadowColor());
            }

            @Override // org.apache.poi.sl.usermodel.Shadow
            public SimpleShape<HSLFShape, HSLFTextParagraph> getShadowParent() {
                return HSLFSimpleShape.this;
            }
        };
    }

    public double getShadowAngle() {
        int i2;
        AbstractEscherOptRecord escherOptRecord = getEscherOptRecord();
        EscherSimpleProperty escherSimpleProperty = (EscherSimpleProperty) HSLFShape.getEscherProperty(escherOptRecord, 517);
        int i3 = 0;
        if (escherSimpleProperty == null) {
            i2 = 0;
        } else {
            i2 = escherSimpleProperty.getPropertyValue();
        }
        EscherSimpleProperty escherSimpleProperty2 = (EscherSimpleProperty) HSLFShape.getEscherProperty(escherOptRecord, 518);
        if (escherSimpleProperty2 != null) {
            i3 = escherSimpleProperty2.getPropertyValue();
        }
        return Math.toDegrees(Math.atan2((double) i3, (double) i2));
    }

    public Color getShadowColor() {
        Color color = getColor(513, 516, -1);
        return color == null ? Color.black : color;
    }

    public double getShadowDistance() {
        int i2;
        AbstractEscherOptRecord escherOptRecord = getEscherOptRecord();
        EscherSimpleProperty escherSimpleProperty = (EscherSimpleProperty) HSLFShape.getEscherProperty(escherOptRecord, 517);
        int i3 = 0;
        if (escherSimpleProperty == null) {
            i2 = 0;
        } else {
            i2 = escherSimpleProperty.getPropertyValue();
        }
        EscherSimpleProperty escherSimpleProperty2 = (EscherSimpleProperty) HSLFShape.getEscherProperty(escherOptRecord, 518);
        if (escherSimpleProperty2 != null) {
            i3 = escherSimpleProperty2.getPropertyValue();
        }
        return Units.toPoints((long) Math.hypot((double) i2, (double) i3));
    }

    @Override // org.apache.poi.sl.usermodel.SimpleShape
    public StrokeStyle getStrokeStyle() {
        return new StrokeStyle() {
            /* class org.apache.poi.hslf.usermodel.HSLFSimpleShape.AnonymousClass1 */

            @Override // org.apache.poi.sl.usermodel.StrokeStyle
            public StrokeStyle.LineCap getLineCap() {
                return null;
            }

            @Override // org.apache.poi.sl.usermodel.StrokeStyle
            public StrokeStyle.LineCompound getLineCompound() {
                return HSLFSimpleShape.this.getLineCompound();
            }

            @Override // org.apache.poi.sl.usermodel.StrokeStyle
            public StrokeStyle.LineDash getLineDash() {
                return HSLFSimpleShape.this.getLineDash();
            }

            @Override // org.apache.poi.sl.usermodel.StrokeStyle
            public double getLineWidth() {
                return HSLFSimpleShape.this.getLineWidth();
            }

            @Override // org.apache.poi.sl.usermodel.StrokeStyle
            public PaintStyle getPaint() {
                return DrawPaint.createSolidPaint(HSLFSimpleShape.this.getLineColor());
            }
        };
    }

    @Override // org.apache.poi.sl.usermodel.SimpleShape
    public void setFillColor(Color color) {
        getFill().setForegroundColor(color);
    }

    public void setHyperlink(HSLFHyperlink hSLFHyperlink) {
        this._hyperlink = hSLFHyperlink;
    }

    public void setLineBackgroundColor(Color color) {
        AbstractEscherOptRecord escherOptRecord = getEscherOptRecord();
        if (color == null) {
            HSLFShape.setEscherProperty(escherOptRecord, EscherProperties.LINESTYLE__NOLINEDRAWDASH, 524288);
            escherOptRecord.removeEscherProperty(450);
            return;
        }
        HSLFShape.setEscherProperty(escherOptRecord, EscherProperties.LINESTYLE__BACKCOLOR, new Color(color.getBlue(), color.getGreen(), color.getRed(), 0).getRGB());
        HSLFShape.setEscherProperty(escherOptRecord, EscherProperties.LINESTYLE__NOLINEDRAWDASH, 1572888);
    }

    public void setLineCap(StrokeStyle.LineCap lineCap) {
        HSLFShape.setEscherProperty(getEscherOptRecord(), EscherProperties.LINESTYLE__LINEENDCAPSTYLE, lineCap == StrokeStyle.LineCap.FLAT ? -1 : lineCap.nativeId);
    }

    public void setLineColor(Color color) {
        AbstractEscherOptRecord escherOptRecord = getEscherOptRecord();
        if (color == null) {
            HSLFShape.setEscherProperty(escherOptRecord, EscherProperties.LINESTYLE__NOLINEDRAWDASH, 524288);
            return;
        }
        HSLFShape.setEscherProperty(escherOptRecord, EscherProperties.LINESTYLE__COLOR, new Color(color.getBlue(), color.getGreen(), color.getRed(), 0).getRGB());
        HSLFShape.setEscherProperty(escherOptRecord, EscherProperties.LINESTYLE__NOLINEDRAWDASH, 1572888);
    }

    public void setLineCompound(StrokeStyle.LineCompound lineCompound) {
        HSLFShape.setEscherProperty(getEscherOptRecord(), EscherProperties.LINESTYLE__LINESTYLE, lineCompound == StrokeStyle.LineCompound.SINGLE ? -1 : lineCompound.nativeId);
    }

    public void setLineDash(StrokeStyle.LineDash lineDash) {
        HSLFShape.setEscherProperty(getEscherOptRecord(), EscherProperties.LINESTYLE__LINEDASHING, lineDash == StrokeStyle.LineDash.SOLID ? -1 : lineDash.nativeId);
    }

    public void setLineHeadDecoration(LineDecoration.DecorationShape decorationShape) {
        int i2;
        AbstractEscherOptRecord escherOptRecord = getEscherOptRecord();
        if (decorationShape == null) {
            i2 = -1;
        } else {
            i2 = decorationShape.nativeId;
        }
        HSLFShape.setEscherProperty(escherOptRecord, EscherProperties.LINESTYLE__LINESTARTARROWHEAD, i2);
    }

    public void setLineHeadLength(LineDecoration.DecorationSize decorationSize) {
        int i2;
        AbstractEscherOptRecord escherOptRecord = getEscherOptRecord();
        if (decorationSize == null) {
            i2 = -1;
        } else {
            i2 = decorationSize.nativeId;
        }
        HSLFShape.setEscherProperty(escherOptRecord, EscherProperties.LINESTYLE__LINESTARTARROWLENGTH, i2);
    }

    public void setLineHeadWidth(LineDecoration.DecorationSize decorationSize) {
        int i2;
        AbstractEscherOptRecord escherOptRecord = getEscherOptRecord();
        if (decorationSize == null) {
            i2 = -1;
        } else {
            i2 = decorationSize.nativeId;
        }
        HSLFShape.setEscherProperty(escherOptRecord, EscherProperties.LINESTYLE__LINESTARTARROWWIDTH, i2);
    }

    public void setLineTailDecoration(LineDecoration.DecorationShape decorationShape) {
        int i2;
        AbstractEscherOptRecord escherOptRecord = getEscherOptRecord();
        if (decorationShape == null) {
            i2 = -1;
        } else {
            i2 = decorationShape.nativeId;
        }
        HSLFShape.setEscherProperty(escherOptRecord, EscherProperties.LINESTYLE__LINEENDARROWHEAD, i2);
    }

    public void setLineTailLength(LineDecoration.DecorationSize decorationSize) {
        int i2;
        AbstractEscherOptRecord escherOptRecord = getEscherOptRecord();
        if (decorationSize == null) {
            i2 = -1;
        } else {
            i2 = decorationSize.nativeId;
        }
        HSLFShape.setEscherProperty(escherOptRecord, EscherProperties.LINESTYLE__LINEENDARROWLENGTH, i2);
    }

    public void setLineTailWidth(LineDecoration.DecorationSize decorationSize) {
        int i2;
        AbstractEscherOptRecord escherOptRecord = getEscherOptRecord();
        if (decorationSize == null) {
            i2 = -1;
        } else {
            i2 = decorationSize.nativeId;
        }
        HSLFShape.setEscherProperty(escherOptRecord, EscherProperties.LINESTYLE__LINEENDARROWWIDTH, i2);
    }

    public void setLineWidth(double d2) {
        HSLFShape.setEscherProperty(getEscherOptRecord(), EscherProperties.LINESTYLE__LINEWIDTH, Units.toEMU(d2));
    }

    @Override // org.apache.poi.sl.usermodel.SimpleShape
    public void setPlaceholder(Placeholder placeholder) {
        OEPlaceholderAtom oEPlaceholderAtom;
        RoundTripHFPlaceholder12 roundTripHFPlaceholder12;
        int i2;
        EscherSpRecord escherSpRecord = (EscherSpRecord) getEscherChild(-4086);
        int flags = escherSpRecord.getFlags();
        escherSpRecord.setFlags(placeholder == null ? flags ^ 32 : flags | 544);
        setEscherProperty(127, placeholder == null ? -1 : 262144);
        HSLFEscherClientDataRecord clientData = getClientData(false);
        if (placeholder != null) {
            if (clientData == null) {
                clientData = getClientData(true);
            }
            Iterator<? extends Record> it = clientData.getHSLFChildRecords().iterator();
            while (true) {
                oEPlaceholderAtom = null;
                if (!it.hasNext()) {
                    roundTripHFPlaceholder12 = null;
                    break;
                }
                Record record = (Record) it.next();
                if (!(record instanceof OEPlaceholderAtom)) {
                    if (record instanceof RoundTripHFPlaceholder12) {
                        roundTripHFPlaceholder12 = (RoundTripHFPlaceholder12) record;
                        break;
                    }
                } else {
                    oEPlaceholderAtom = (OEPlaceholderAtom) record;
                    roundTripHFPlaceholder12 = null;
                    break;
                }
            }
            Sheet<HSLFShape, HSLFTextParagraph> sheet = getSheet();
            if (sheet instanceof HSLFSlideMaster) {
                i2 = placeholder.nativeSlideMasterId;
            } else if (sheet instanceof HSLFNotes) {
                i2 = placeholder.nativeNotesId;
            } else {
                i2 = placeholder.nativeSlideId;
            }
            byte b2 = (byte) i2;
            if (b2 != -2) {
                int ordinal = placeholder.ordinal();
                if (ordinal == 7 || ordinal == 8) {
                    if (roundTripHFPlaceholder12 == null) {
                        RoundTripHFPlaceholder12 roundTripHFPlaceholder122 = new RoundTripHFPlaceholder12();
                        roundTripHFPlaceholder122.setPlaceholderId(b2);
                        clientData.addChild(roundTripHFPlaceholder122);
                    }
                    if (oEPlaceholderAtom != null) {
                        clientData.removeChild(OEPlaceholderAtom.class);
                        return;
                    }
                    return;
                }
                if (roundTripHFPlaceholder12 != null) {
                    clientData.removeChild(RoundTripHFPlaceholder12.class);
                }
                if (oEPlaceholderAtom == null) {
                    OEPlaceholderAtom oEPlaceholderAtom2 = new OEPlaceholderAtom();
                    oEPlaceholderAtom2.setPlaceholderSize((byte) 0);
                    oEPlaceholderAtom2.setPlacementId(-1);
                    oEPlaceholderAtom2.setPlaceholderId(b2);
                    clientData.addChild(oEPlaceholderAtom2);
                    return;
                }
                return;
            }
            StringBuilder b3 = a.b("Placeholder ");
            b3.append(placeholder.name());
            b3.append(" not supported for this sheet type (");
            b3.append(sheet.getClass());
            b3.append(")");
            throw new HSLFException(b3.toString());
        } else if (clientData != null) {
            clientData.removeChild(OEPlaceholderAtom.class);
            clientData.removeChild(RoundTripHFPlaceholder12.class);
            if (clientData.getChildRecords().isEmpty()) {
                getSpContainer().removeChildRecord(clientData);
            }
        }
    }

    @Override // org.apache.poi.sl.usermodel.SimpleShape
    public void setStrokeStyle(Object... objArr) {
        if (objArr.length == 0) {
            setLineColor(null);
            return;
        }
        for (Object obj : objArr) {
            if (obj instanceof Number) {
                setLineWidth(((Number) obj).doubleValue());
            } else if (obj instanceof StrokeStyle.LineCap) {
                setLineCap((StrokeStyle.LineCap) obj);
            } else if (obj instanceof StrokeStyle.LineDash) {
                setLineDash((StrokeStyle.LineDash) obj);
            } else if (obj instanceof StrokeStyle.LineCompound) {
                setLineCompound((StrokeStyle.LineCompound) obj);
            } else if (obj instanceof Color) {
                setLineColor((Color) obj);
            }
        }
    }

    /* Return type fixed from 'org.apache.poi.hslf.usermodel.HSLFHyperlink' to match base method */
    @Override // org.apache.poi.sl.usermodel.SimpleShape
    public Hyperlink<HSLFShape, HSLFTextParagraph> createHyperlink() {
        if (this._hyperlink == null) {
            this._hyperlink = HSLFHyperlink.createHyperlink(this);
        }
        return this._hyperlink;
    }

    /* Return type fixed from 'org.apache.poi.hslf.usermodel.HSLFHyperlink' to match base method */
    @Override // org.apache.poi.sl.usermodel.SimpleShape
    public Hyperlink<HSLFShape, HSLFTextParagraph> getHyperlink() {
        return this._hyperlink;
    }
}
