package org.apache.poi.hslf.usermodel;

import java.awt.Graphics2D;
import java.awt.Rectangle;
import java.util.ArrayList;
import java.util.Iterator;
import java.util.List;
import org.apache.poi.ddf.EscherContainerRecord;
import org.apache.poi.ddf.EscherDgRecord;
import org.apache.poi.ddf.EscherDggRecord;
import org.apache.poi.ddf.EscherSpRecord;
import org.apache.poi.hslf.exceptions.HSLFException;
import org.apache.poi.hslf.model.Comment;
import org.apache.poi.hslf.model.HeadersFooters;
import org.apache.poi.hslf.record.ColorSchemeAtom;
import org.apache.poi.hslf.record.Comment2000;
import org.apache.poi.hslf.record.EscherTextboxWrapper;
import org.apache.poi.hslf.record.RecordContainer;
import org.apache.poi.hslf.record.RecordTypes;
import org.apache.poi.hslf.record.SSSlideInfoAtom;
import org.apache.poi.hslf.record.SlideAtom;
import org.apache.poi.hslf.record.SlideAtomLayout;
import org.apache.poi.hslf.record.SlideListWithText;
import org.apache.poi.hslf.record.StyleTextProp9Atom;
import org.apache.poi.sl.draw.DrawFactory;
import org.apache.poi.sl.usermodel.MasterSheet;
import org.apache.poi.sl.usermodel.Notes;
import org.apache.poi.sl.usermodel.Placeholder;
import org.apache.poi.sl.usermodel.ShapeType;
import org.apache.poi.sl.usermodel.Slide;

public final class HSLFSlide extends HSLFSheet implements Slide<HSLFShape, HSLFTextParagraph> {
    public SlideListWithText.SlideAtomsSet _atomSet;
    public HSLFNotes _notes;
    public final List<List<HSLFTextParagraph>> _paragraphs = new ArrayList();
    public int _slideNo;

    /* renamed from: org.apache.poi.hslf.usermodel.HSLFSlide$1  reason: invalid class name */
    public static /* synthetic */ class AnonymousClass1 {
        public static final /* synthetic */ int[] $SwitchMap$org$apache$poi$sl$usermodel$Placeholder;

        /* JADX WARNING: Can't wrap try/catch for region: R(8:0|1|2|3|4|5|6|(3:7|8|10)) */
        /* JADX WARNING: Failed to process nested try/catch */
        /* JADX WARNING: Missing exception handler attribute for start block: B:3:0x000f */
        /* JADX WARNING: Missing exception handler attribute for start block: B:5:0x0017 */
        /* JADX WARNING: Missing exception handler attribute for start block: B:7:0x0020 */
        static {
            int[] iArr = new int[Placeholder.values().length];
            $SwitchMap$org$apache$poi$sl$usermodel$Placeholder = iArr;
            Placeholder placeholder = Placeholder.DATETIME;
            iArr[5] = 1;
            int[] iArr2 = $SwitchMap$org$apache$poi$sl$usermodel$Placeholder;
            Placeholder placeholder2 = Placeholder.SLIDE_NUMBER;
            iArr2[6] = 2;
            int[] iArr3 = $SwitchMap$org$apache$poi$sl$usermodel$Placeholder;
            Placeholder placeholder3 = Placeholder.HEADER;
            iArr3[8] = 3;
            try {
                int[] iArr4 = $SwitchMap$org$apache$poi$sl$usermodel$Placeholder;
                Placeholder placeholder4 = Placeholder.FOOTER;
                iArr4[7] = 4;
            } catch (NoSuchFieldError unused) {
            }
        }
    }

    public HSLFSlide(org.apache.poi.hslf.record.Slide slide, HSLFNotes hSLFNotes, SlideListWithText.SlideAtomsSet slideAtomsSet, int i2, int i3) {
        super(slide, i2);
        this._notes = hSLFNotes;
        this._atomSet = slideAtomsSet;
        this._slideNo = i3;
        if (slideAtomsSet != null && slideAtomsSet.getSlideRecords().length > 0) {
            this._paragraphs.addAll(HSLFTextParagraph.findTextParagraphs(this._atomSet.getSlideRecords()));
            if (this._paragraphs.isEmpty()) {
                throw new HSLFException("No text records found for slide");
            }
        }
        for (List<HSLFTextParagraph> list : HSLFTextParagraph.findTextParagraphs(getPPDrawing(), this)) {
            if (!this._paragraphs.contains(list)) {
                this._paragraphs.add(list);
            }
        }
    }

    public HSLFTextBox addTitle() {
        HSLFPlaceholder hSLFPlaceholder = new HSLFPlaceholder();
        hSLFPlaceholder.setShapeType(ShapeType.RECT);
        hSLFPlaceholder.setPlaceholder(Placeholder.TITLE);
        hSLFPlaceholder.setRunType(0);
        hSLFPlaceholder.setText("Click to edit title");
        hSLFPlaceholder.setAnchor(new Rectangle(54, 48, 612, 90));
        addShape((HSLFShape) hSLFPlaceholder);
        return hSLFPlaceholder;
    }

    @Override // org.apache.poi.sl.usermodel.Sheet, org.apache.poi.hslf.usermodel.HSLFSheet
    public void draw(Graphics2D graphics2D) {
        DrawFactory.getInstance(graphics2D).getDrawable((Slide<?, ?>) this).draw(graphics2D);
    }

    @Override // org.apache.poi.hslf.usermodel.HSLFSheet
    public ColorSchemeAtom getColorScheme() {
        if (getFollowMasterScheme()) {
            return getMasterSheet().getColorScheme();
        }
        return super.getColorScheme();
    }

    public Comment[] getComments() {
        RecordContainer recordContainer;
        RecordContainer recordContainer2;
        RecordContainer recordContainer3 = (RecordContainer) getSheetContainer().findFirstOfType((long) RecordTypes.ProgTags.typeID);
        if (recordContainer3 == null || (recordContainer = (RecordContainer) recordContainer3.findFirstOfType((long) RecordTypes.ProgBinaryTag.typeID)) == null || (recordContainer2 = (RecordContainer) recordContainer.findFirstOfType((long) RecordTypes.BinaryTagData.typeID)) == null) {
            return new Comment[0];
        }
        int i2 = 0;
        for (int i3 = 0; i3 < recordContainer2.getChildRecords().length; i3++) {
            if (recordContainer2.getChildRecords()[i3] instanceof Comment2000) {
                i2++;
            }
        }
        Comment[] commentArr = new Comment[i2];
        for (int i4 = 0; i4 < recordContainer2.getChildRecords().length; i4++) {
            if (recordContainer2.getChildRecords()[i4] instanceof Comment2000) {
                commentArr[i4] = new Comment((Comment2000) recordContainer2.getChildRecords()[i4]);
            }
        }
        return commentArr;
    }

    @Override // org.apache.poi.sl.usermodel.Slide
    public boolean getDisplayPlaceholder(Placeholder placeholder) {
        HeadersFooters headersFooters = getHeadersFooters();
        SlideAtomLayout.SlideLayoutType geometryType = getSlideRecord().getSlideAtom().getSSlideLayoutAtom().getGeometryType();
        boolean z = geometryType == SlideAtomLayout.SlideLayoutType.TITLE_SLIDE || geometryType == SlideAtomLayout.SlideLayoutType.TITLE_ONLY || geometryType == SlideAtomLayout.SlideLayoutType.MASTER_TITLE;
        if (headersFooters != null) {
            int ordinal = placeholder.ordinal();
            if (ordinal != 5) {
                if (ordinal != 6) {
                    if (ordinal != 7) {
                        if (ordinal == 8 && headersFooters.isHeaderVisible() && !z) {
                            return true;
                        }
                        return false;
                    } else if (!headersFooters.isFooterVisible() || z) {
                        return false;
                    } else {
                        return true;
                    }
                } else if (!headersFooters.isSlideNumberVisible() || z) {
                    return false;
                } else {
                    return true;
                }
            } else if (!headersFooters.isDateTimeVisible() || z) {
                return false;
            } else {
                return true;
            }
        }
        return false;
    }

    @Override // org.apache.poi.sl.usermodel.Slide
    public boolean getFollowMasterBackground() {
        return getSlideRecord().getSlideAtom().getFollowMasterBackground();
    }

    @Override // org.apache.poi.sl.usermodel.Slide
    public boolean getFollowMasterColourScheme() {
        return false;
    }

    @Override // org.apache.poi.sl.usermodel.Sheet, org.apache.poi.hslf.usermodel.HSLFSheet
    public boolean getFollowMasterGraphics() {
        return getFollowMasterObjects();
    }

    @Override // org.apache.poi.sl.usermodel.Slide
    public boolean getFollowMasterObjects() {
        return getSlideRecord().getSlideAtom().getFollowMasterObjects();
    }

    public boolean getFollowMasterScheme() {
        return getSlideRecord().getSlideAtom().getFollowMasterScheme();
    }

    public HeadersFooters getHeadersFooters() {
        return new HeadersFooters((HSLFSheet) this, (short) 63);
    }

    public boolean getHidden() {
        SSSlideInfoAtom sSSlideInfoAtom = (SSSlideInfoAtom) getSlideRecord().findFirstOfType((long) RecordTypes.SSSlideInfoAtom.typeID);
        if (sSSlideInfoAtom == null) {
            return false;
        }
        return sSSlideInfoAtom.getEffectTransitionFlagByBit(4);
    }

    public StyleTextProp9Atom[] getNumberedListInfo() {
        return getPPDrawing().getNumberedListInfo();
    }

    public SlideListWithText.SlideAtomsSet getSlideAtomsSet() {
        return this._atomSet;
    }

    @Override // org.apache.poi.sl.usermodel.Slide
    public int getSlideNumber() {
        return this._slideNo;
    }

    public org.apache.poi.hslf.record.Slide getSlideRecord() {
        return (org.apache.poi.hslf.record.Slide) getSheetContainer();
    }

    @Override // org.apache.poi.hslf.usermodel.HSLFSheet
    public List<List<HSLFTextParagraph>> getTextParagraphs() {
        return this._paragraphs;
    }

    public EscherTextboxWrapper[] getTextboxWrappers() {
        return getPPDrawing().getTextboxWrappers();
    }

    @Override // org.apache.poi.sl.usermodel.Slide
    public String getTitle() {
        int runType;
        for (List<HSLFTextParagraph> list : getTextParagraphs()) {
            if (!list.isEmpty() && ((runType = list.get(0).getRunType()) == 0 || runType == 6)) {
                return HSLFTextParagraph.toExternalString(HSLFTextParagraph.getRawText(list), runType);
            }
        }
        return null;
    }

    /* JADX DEBUG: Multi-variable search result rejected for r0v0, resolved type: java.util.List<java.util.List<org.apache.poi.hslf.usermodel.HSLFTextParagraph>> */
    /* JADX WARN: Multi-variable type inference failed */
    @Override // org.apache.poi.hslf.usermodel.HSLFSheet
    public void onAddTextShape(HSLFTextShape hSLFTextShape) {
        this._paragraphs.add(hSLFTextShape.getTextParagraphs());
    }

    /* JADX WARN: Type inference failed for: r0v0, types: [org.apache.poi.hslf.usermodel.HSLFSlideShow] */
    /* JADX WARNING: Unknown variable types count: 1 */
    @Override // org.apache.poi.hslf.usermodel.HSLFSheet
    public void onCreate() {
        EscherDggRecord escherDggRecord = getSlideShow().getDocumentRecord().getPPDrawingGroup().getEscherDggRecord();
        EscherContainerRecord dgContainer = getSheetContainer().getPPDrawing().getDgContainer();
        EscherDgRecord escherDgRecord = (EscherDgRecord) HSLFShape.getEscherChild(dgContainer, -4088);
        escherDgRecord.setOptions((short) ((escherDggRecord.getMaxDrawingGroupId() + 1) << 4));
        escherDggRecord.setDrawingsSaved(escherDggRecord.getDrawingsSaved() + 1);
        for (EscherContainerRecord escherContainerRecord : dgContainer.getChildContainers()) {
            EscherSpRecord escherSpRecord = null;
            short recordId = escherContainerRecord.getRecordId();
            if (recordId == -4093) {
                escherSpRecord = (EscherSpRecord) ((EscherContainerRecord) escherContainerRecord.getChild(0)).getChildById(EscherSpRecord.RECORD_ID);
            } else if (recordId == -4092) {
                escherSpRecord = (EscherSpRecord) escherContainerRecord.getChildById(EscherSpRecord.RECORD_ID);
            }
            if (escherSpRecord != null) {
                escherSpRecord.setShapeId(allocateShapeId());
            }
        }
        escherDgRecord.setNumShapes(1);
    }

    @Override // org.apache.poi.sl.usermodel.Slide
    public void setFollowMasterBackground(boolean z) {
        getSlideRecord().getSlideAtom().setFollowMasterBackground(z);
    }

    @Override // org.apache.poi.sl.usermodel.Slide
    public void setFollowMasterColourScheme(boolean z) {
    }

    @Override // org.apache.poi.sl.usermodel.Slide
    public void setFollowMasterObjects(boolean z) {
        getSlideRecord().getSlideAtom().setFollowMasterObjects(z);
    }

    public void setFollowMasterScheme(boolean z) {
        getSlideRecord().getSlideAtom().setFollowMasterScheme(z);
    }

    public void setHidden(boolean z) {
        org.apache.poi.hslf.record.Slide slideRecord = getSlideRecord();
        SSSlideInfoAtom sSSlideInfoAtom = (SSSlideInfoAtom) slideRecord.findFirstOfType((long) RecordTypes.SSSlideInfoAtom.typeID);
        if (sSSlideInfoAtom == null) {
            sSSlideInfoAtom = new SSSlideInfoAtom();
            slideRecord.addChildAfter(sSSlideInfoAtom, slideRecord.findFirstOfType((long) RecordTypes.SlideAtom.typeID));
        }
        sSSlideInfoAtom.setEffectTransitionFlagByBit(4, z);
    }

    public void setMasterSheet(HSLFMasterSheet hSLFMasterSheet) {
        getSlideRecord().getSlideAtom().setMasterID(hSLFMasterSheet._getSheetNumber());
    }

    @Override // org.apache.poi.sl.usermodel.Slide
    public void setNotes(Notes<HSLFShape, HSLFTextParagraph> notes) {
        if (notes == null || (notes instanceof HSLFNotes)) {
            this._notes = (HSLFNotes) notes;
            SlideAtom slideAtom = getSlideRecord().getSlideAtom();
            HSLFNotes hSLFNotes = this._notes;
            if (hSLFNotes == null) {
                slideAtom.setNotesID(0);
            } else {
                slideAtom.setNotesID(hSLFNotes._getSheetNumber());
            }
        } else {
            throw new IllegalArgumentException("notes needs to be of type HSLFNotes");
        }
    }

    public void setSlideNumber(int i2) {
        this._slideNo = i2;
    }

    /* JADX WARN: Type inference failed for: r0v1, types: [org.apache.poi.hslf.usermodel.HSLFBackground] */
    /* JADX WARN: Type inference failed for: r0v3, types: [org.apache.poi.hslf.usermodel.HSLFBackground] */
    /* JADX WARNING: Unknown variable types count: 2 */
    @Override // org.apache.poi.sl.usermodel.Sheet, org.apache.poi.hslf.usermodel.HSLFSheet, org.apache.poi.hslf.usermodel.HSLFSheet
    public HSLFBackground getBackground() {
        if (getFollowMasterBackground()) {
            return getMasterSheet().getBackground();
        }
        return super.getBackground();
    }

    /* JADX WARN: Type inference failed for: r1v0, types: [org.apache.poi.hslf.usermodel.HSLFSlideShow] */
    /* JADX WARN: Type inference failed for: r1v3, types: [org.apache.poi.hslf.usermodel.HSLFSlideShow] */
    /* JADX WARNING: Unknown variable types count: 2 */
    @Override // org.apache.poi.sl.usermodel.Sheet, org.apache.poi.hslf.usermodel.HSLFSheet, org.apache.poi.hslf.usermodel.HSLFSheet
    public HSLFMasterSheet getMasterSheet() {
        int masterID = getSlideRecord().getSlideAtom().getMasterID();
        Iterator<? extends MasterSheet<HSLFShape, HSLFTextParagraph>> it = getSlideShow().getSlideMasters().iterator();
        while (it.hasNext()) {
            HSLFSlideMaster hSLFSlideMaster = (HSLFSlideMaster) it.next();
            if (masterID == hSLFSlideMaster._getSheetNumber()) {
                return hSLFSlideMaster;
            }
        }
        for (HSLFTitleMaster hSLFTitleMaster : getSlideShow().getTitleMasters()) {
            if (masterID == hSLFTitleMaster._getSheetNumber()) {
                return hSLFTitleMaster;
            }
        }
        return null;
    }

    /* Return type fixed from 'org.apache.poi.hslf.usermodel.HSLFNotes' to match base method */
    @Override // org.apache.poi.sl.usermodel.Slide
    public Notes<HSLFShape, HSLFTextParagraph> getNotes() {
        return this._notes;
    }

    public HSLFSlide(int i2, int i3, int i4) {
        super(new org.apache.poi.hslf.record.Slide(), i2);
        this._slideNo = i4;
        getSheetContainer().setSheetId(i3);
    }
}
