package org.apache.poi.hslf.usermodel;

import java.util.ArrayList;
import java.util.Iterator;
import java.util.List;
import org.apache.poi.hslf.exceptions.HSLFException;
import org.apache.poi.hslf.model.textproperties.TextProp;
import org.apache.poi.hslf.model.textproperties.TextPropCollection;
import org.apache.poi.hslf.record.MainMaster;
import org.apache.poi.hslf.record.TxMasterStyleAtom;
import org.apache.poi.util.Internal;

public final class HSLFSlideMaster extends HSLFMasterSheet {
    public static final /* synthetic */ boolean $assertionsDisabled = false;
    public final List<List<HSLFTextParagraph>> _paragraphs = new ArrayList();
    public TxMasterStyleAtom[] _txmaster;

    public HSLFSlideMaster(MainMaster mainMaster, int i2) {
        super(mainMaster, i2);
        for (List<HSLFTextParagraph> list : HSLFTextParagraph.findTextParagraphs(getPPDrawing(), this)) {
            if (!this._paragraphs.contains(list)) {
                this._paragraphs.add(list);
            }
        }
    }

    @Override // org.apache.poi.sl.usermodel.Sheet, org.apache.poi.hslf.usermodel.HSLFSheet, org.apache.poi.hslf.usermodel.HSLFSheet
    public HSLFMasterSheet getMasterSheet() {
        return null;
    }

    @Override // org.apache.poi.hslf.usermodel.HSLFMasterSheet
    public TextProp getStyleAttribute(int i2, int i3, String str, boolean z) {
        TxMasterStyleAtom[] txMasterStyleAtomArr = this._txmaster;
        if (txMasterStyleAtomArr.length <= i2) {
            return null;
        }
        TxMasterStyleAtom txMasterStyleAtom = txMasterStyleAtomArr[i2];
        List<TextPropCollection> characterStyles = z ? txMasterStyleAtom.getCharacterStyles() : txMasterStyleAtom.getParagraphStyles();
        int i4 = 1;
        int min = Math.min(i3, characterStyles.size() - 1);
        TextProp textProp = null;
        while (textProp == null && min >= 0) {
            textProp = characterStyles.get(min).findByName(str);
            min--;
        }
        if (textProp != null) {
            return textProp;
        }
        if (i2 != 5) {
            if (i2 == 6) {
                i4 = 0;
            } else if (!(i2 == 7 || i2 == 8)) {
                return null;
            }
        }
        return getStyleAttribute(i4, i3, str, z);
    }

    @Override // org.apache.poi.hslf.usermodel.HSLFSheet
    public List<List<HSLFTextParagraph>> getTextParagraphs() {
        return this._paragraphs;
    }

    public TxMasterStyleAtom[] getTxMasterStyleAtoms() {
        return this._txmaster;
    }

    @Override // org.apache.poi.hslf.usermodel.HSLFSheet
    public void onAddTextShape(HSLFTextShape hSLFTextShape) {
        this._paragraphs.add(hSLFTextShape.getTextParagraphs());
    }

    /* JADX WARN: Type inference failed for: r8v3, types: [org.apache.poi.hslf.usermodel.HSLFSlideShow] */
    /* JADX WARNING: Code restructure failed: missing block: B:33:0x00ce, code lost:
        throw new org.apache.poi.hslf.exceptions.HSLFException("Master styles not initialized");
     */
    /* JADX WARNING: Unknown variable types count: 1 */
    @Override // org.apache.poi.hslf.usermodel.HSLFSheet
    @Internal
    public void setSlideShow(HSLFSlideShow hSLFSlideShow) {
        super.setSlideShow(hSLFSlideShow);
        this._txmaster = new TxMasterStyleAtom[9];
        TxMasterStyleAtom txMasterStyleAtom = getSlideShow().getDocumentRecord().getEnvironment().getTxMasterStyleAtom();
        this._txmaster[txMasterStyleAtom.getTextType()] = txMasterStyleAtom;
        TxMasterStyleAtom[] txMasterStyleAtoms = ((MainMaster) getSheetContainer()).getTxMasterStyleAtoms();
        for (int i2 = 0; i2 < txMasterStyleAtoms.length; i2++) {
            int textType = txMasterStyleAtoms[i2].getTextType();
            TxMasterStyleAtom[] txMasterStyleAtomArr = this._txmaster;
            if (textType < txMasterStyleAtomArr.length && txMasterStyleAtomArr[textType] == null) {
                txMasterStyleAtomArr[textType] = txMasterStyleAtoms[i2];
            }
        }
        loop1:
        for (List<HSLFTextParagraph> list : getTextParagraphs()) {
            Iterator<HSLFTextParagraph> it = list.iterator();
            while (true) {
                if (it.hasNext()) {
                    HSLFTextParagraph next = it.next();
                    int runType = next.getRunType();
                    TxMasterStyleAtom[] txMasterStyleAtomArr2 = this._txmaster;
                    if (runType < txMasterStyleAtomArr2.length && txMasterStyleAtomArr2[runType] != null) {
                        int indentLevel = next.getIndentLevel();
                        List<TextPropCollection> characterStyles = this._txmaster[runType].getCharacterStyles();
                        List<TextPropCollection> paragraphStyles = this._txmaster[runType].getParagraphStyles();
                        if (characterStyles != null && paragraphStyles != null && characterStyles.size() > indentLevel && paragraphStyles.size() > indentLevel) {
                            next.setMasterStyleReference(paragraphStyles.get(indentLevel));
                            for (HSLFTextRun hSLFTextRun : next.getTextRuns()) {
                                hSLFTextRun.setMasterStyleReference(characterStyles.get(indentLevel));
                            }
                        }
                    }
                }
            }
            throw new HSLFException("Master styles not initialized");
        }
    }
}
