package org.apache.poi.hslf.usermodel;

import java.awt.Color;
import java.awt.geom.Rectangle2D;
import org.apache.poi.ddf.AbstractEscherOptRecord;
import org.apache.poi.ddf.EscherContainerRecord;
import org.apache.poi.ddf.EscherProperties;
import org.apache.poi.sl.draw.DrawPaint;
import org.apache.poi.sl.usermodel.PaintStyle;
import org.apache.poi.sl.usermodel.ShapeType;
import org.apache.poi.sl.usermodel.StrokeStyle;
import org.apache.poi.sl.usermodel.TableCell;

public final class HSLFTableCell extends HSLFTextBox implements TableCell<HSLFShape, HSLFTextParagraph> {
    public static final /* synthetic */ boolean $assertionsDisabled = false;
    public static final int DEFAULT_HEIGHT = 40;
    public static final int DEFAULT_WIDTH = 100;
    public HSLFLine borderBottom;
    public HSLFLine borderLeft;
    public HSLFLine borderRight;
    public HSLFLine borderTop;
    public int gridSpan = 1;
    public int rowSpan = 1;

    /* renamed from: org.apache.poi.hslf.usermodel.HSLFTableCell$2  reason: invalid class name */
    public static /* synthetic */ class AnonymousClass2 {
        public static final /* synthetic */ int[] $SwitchMap$org$apache$poi$sl$usermodel$TableCell$BorderEdge;

        /* JADX WARNING: Can't wrap try/catch for region: R(9:0|1|2|3|5|6|7|8|(3:9|10|12)) */
        /* JADX WARNING: Failed to process nested try/catch */
        /* JADX WARNING: Missing exception handler attribute for start block: B:7:0x0016 */
        /* JADX WARNING: Missing exception handler attribute for start block: B:9:0x001d */
        static {
            int[] iArr = new int[TableCell.BorderEdge.values().length];
            $SwitchMap$org$apache$poi$sl$usermodel$TableCell$BorderEdge = iArr;
            try {
                TableCell.BorderEdge borderEdge = TableCell.BorderEdge.top;
                iArr[2] = 1;
            } catch (NoSuchFieldError unused) {
            }
            int[] iArr2 = $SwitchMap$org$apache$poi$sl$usermodel$TableCell$BorderEdge;
            TableCell.BorderEdge borderEdge2 = TableCell.BorderEdge.right;
            iArr2[3] = 2;
            int[] iArr3 = $SwitchMap$org$apache$poi$sl$usermodel$TableCell$BorderEdge;
            TableCell.BorderEdge borderEdge3 = TableCell.BorderEdge.bottom;
            iArr3[0] = 3;
            try {
                int[] iArr4 = $SwitchMap$org$apache$poi$sl$usermodel$TableCell$BorderEdge;
                TableCell.BorderEdge borderEdge4 = TableCell.BorderEdge.left;
                iArr4[1] = 4;
            } catch (NoSuchFieldError unused2) {
            }
        }
    }

    public HSLFTableCell(EscherContainerRecord escherContainerRecord, HSLFTable hSLFTable) {
        super(escherContainerRecord, hSLFTable);
    }

    private void anchorBorder(TableCell.BorderEdge borderEdge, HSLFLine hSLFLine) {
        double x;
        double y;
        double width;
        double d2;
        double d3;
        double height;
        if (hSLFLine != null) {
            Rectangle2D anchor = getAnchor();
            int ordinal = borderEdge.ordinal();
            if (ordinal != 0) {
                if (ordinal == 1) {
                    x = anchor.getX();
                    y = anchor.getY();
                    height = anchor.getHeight();
                } else if (ordinal == 2) {
                    x = anchor.getX();
                    y = anchor.getY();
                    width = anchor.getWidth();
                } else if (ordinal == 3) {
                    x = anchor.getX() + anchor.getWidth();
                    y = anchor.getY();
                    height = anchor.getHeight();
                } else {
                    throw new IllegalArgumentException();
                }
                d2 = height;
                d3 = 0.0d;
                hSLFLine.setAnchor(new Rectangle2D.Double(x, y, d3, d2));
            }
            x = anchor.getX();
            y = anchor.getY() + anchor.getHeight();
            width = anchor.getWidth();
            d3 = width;
            d2 = 0.0d;
            hSLFLine.setAnchor(new Rectangle2D.Double(x, y, d3, d2));
        }
    }

    private HSLFLine createBorder(TableCell.BorderEdge borderEdge) {
        HSLFTable parent = getParent();
        HSLFLine hSLFLine = new HSLFLine(parent);
        parent.addShape((HSLFShape) hSLFLine);
        AbstractEscherOptRecord escherOptRecord = getEscherOptRecord();
        HSLFShape.setEscherProperty(escherOptRecord, EscherProperties.GEOMETRY__SHAPEPATH, -1);
        HSLFShape.setEscherProperty(escherOptRecord, EscherProperties.GEOMETRY__FILLOK, -1);
        HSLFShape.setEscherProperty(escherOptRecord, EscherProperties.SHADOWSTYLE__SHADOWOBSURED, 131072);
        HSLFShape.setEscherProperty(escherOptRecord, EscherProperties.THREED__LIGHTFACE, 524288);
        anchorBorder(borderEdge, hSLFLine);
        return hSLFLine;
    }

    public HSLFLine addLine(TableCell.BorderEdge borderEdge) {
        int ordinal = borderEdge.ordinal();
        if (ordinal == 0) {
            if (this.borderBottom == null) {
                this.borderBottom = createBorder(borderEdge);
                HSLFTableCell siblingCell = getSiblingCell(1, 0);
                if (siblingCell != null) {
                    siblingCell.borderTop = this.borderBottom;
                }
            }
            return this.borderBottom;
        } else if (ordinal == 1) {
            if (this.borderLeft == null) {
                this.borderLeft = createBorder(borderEdge);
                HSLFTableCell siblingCell2 = getSiblingCell(0, -1);
                if (siblingCell2 != null) {
                    siblingCell2.borderRight = this.borderLeft;
                }
            }
            return this.borderLeft;
        } else if (ordinal == 2) {
            if (this.borderTop == null) {
                this.borderTop = createBorder(borderEdge);
                HSLFTableCell siblingCell3 = getSiblingCell(-1, 0);
                if (siblingCell3 != null) {
                    siblingCell3.borderBottom = this.borderTop;
                }
            }
            return this.borderTop;
        } else if (ordinal == 3) {
            if (this.borderRight == null) {
                this.borderRight = createBorder(borderEdge);
                HSLFTableCell siblingCell4 = getSiblingCell(0, 1);
                if (siblingCell4 != null) {
                    siblingCell4.borderLeft = this.borderRight;
                }
            }
            return this.borderRight;
        } else {
            throw new IllegalArgumentException();
        }
    }

    public void applyLineProperties(TableCell.BorderEdge borderEdge, HSLFLine hSLFLine) {
        HSLFLine addLine = addLine(borderEdge);
        addLine.setLineWidth(hSLFLine.getLineWidth());
        addLine.setLineColor(hSLFLine.getLineColor());
    }

    @Override // org.apache.poi.hslf.usermodel.HSLFTextBox, org.apache.poi.hslf.usermodel.HSLFShape, org.apache.poi.hslf.usermodel.HSLFSimpleShape
    public EscherContainerRecord createSpContainer(boolean z) {
        EscherContainerRecord createSpContainer = super.createSpContainer(z);
        AbstractEscherOptRecord escherOptRecord = getEscherOptRecord();
        HSLFShape.setEscherProperty(escherOptRecord, 128, 0);
        HSLFShape.setEscherProperty(escherOptRecord, 191, 131072);
        HSLFShape.setEscherProperty(escherOptRecord, EscherProperties.FILL__NOFILLHITTEST, 1376257);
        HSLFShape.setEscherProperty(escherOptRecord, EscherProperties.SHADOWSTYLE__SHADOWOBSURED, 131072);
        HSLFShape.setEscherProperty(escherOptRecord, 127, 262144);
        return createSpContainer;
    }

    public Color getBorderColor(TableCell.BorderEdge borderEdge) {
        HSLFLine hSLFLine;
        int ordinal = borderEdge.ordinal();
        if (ordinal == 0) {
            hSLFLine = this.borderBottom;
        } else if (ordinal == 1) {
            hSLFLine = this.borderLeft;
        } else if (ordinal == 2) {
            hSLFLine = this.borderTop;
        } else if (ordinal == 3) {
            hSLFLine = this.borderRight;
        } else {
            throw new IllegalArgumentException();
        }
        if (hSLFLine == null) {
            return null;
        }
        return hSLFLine.getLineColor();
    }

    public StrokeStyle.LineCompound getBorderCompound(TableCell.BorderEdge borderEdge) {
        HSLFLine hSLFLine;
        int ordinal = borderEdge.ordinal();
        if (ordinal == 0) {
            hSLFLine = this.borderBottom;
        } else if (ordinal == 1) {
            hSLFLine = this.borderLeft;
        } else if (ordinal == 2) {
            hSLFLine = this.borderTop;
        } else if (ordinal == 3) {
            hSLFLine = this.borderRight;
        } else {
            throw new IllegalArgumentException();
        }
        if (hSLFLine == null) {
            return null;
        }
        return hSLFLine.getLineCompound();
    }

    public StrokeStyle.LineDash getBorderDash(TableCell.BorderEdge borderEdge) {
        HSLFLine hSLFLine;
        int ordinal = borderEdge.ordinal();
        if (ordinal == 0) {
            hSLFLine = this.borderBottom;
        } else if (ordinal == 1) {
            hSLFLine = this.borderLeft;
        } else if (ordinal == 2) {
            hSLFLine = this.borderTop;
        } else if (ordinal == 3) {
            hSLFLine = this.borderRight;
        } else {
            throw new IllegalArgumentException();
        }
        if (hSLFLine == null) {
            return null;
        }
        return hSLFLine.getLineDash();
    }

    @Override // org.apache.poi.sl.usermodel.TableCell
    public StrokeStyle getBorderStyle(final TableCell.BorderEdge borderEdge) {
        final Double borderWidth = getBorderWidth(borderEdge);
        if (borderWidth == null) {
            return null;
        }
        return new StrokeStyle() {
            /* class org.apache.poi.hslf.usermodel.HSLFTableCell.AnonymousClass1 */

            @Override // org.apache.poi.sl.usermodel.StrokeStyle
            public StrokeStyle.LineCap getLineCap() {
                return null;
            }

            @Override // org.apache.poi.sl.usermodel.StrokeStyle
            public StrokeStyle.LineCompound getLineCompound() {
                return HSLFTableCell.this.getBorderCompound(borderEdge);
            }

            @Override // org.apache.poi.sl.usermodel.StrokeStyle
            public StrokeStyle.LineDash getLineDash() {
                return HSLFTableCell.this.getBorderDash(borderEdge);
            }

            @Override // org.apache.poi.sl.usermodel.StrokeStyle
            public double getLineWidth() {
                return borderWidth.doubleValue();
            }

            @Override // org.apache.poi.sl.usermodel.StrokeStyle
            public PaintStyle getPaint() {
                return DrawPaint.createSolidPaint(HSLFTableCell.this.getBorderColor(borderEdge));
            }
        };
    }

    public Double getBorderWidth(TableCell.BorderEdge borderEdge) {
        HSLFLine hSLFLine;
        int ordinal = borderEdge.ordinal();
        if (ordinal == 0) {
            hSLFLine = this.borderBottom;
        } else if (ordinal == 1) {
            hSLFLine = this.borderLeft;
        } else if (ordinal == 2) {
            hSLFLine = this.borderTop;
        } else if (ordinal == 3) {
            hSLFLine = this.borderRight;
        } else {
            throw new IllegalArgumentException();
        }
        if (hSLFLine == null) {
            return null;
        }
        return Double.valueOf(hSLFLine.getLineWidth());
    }

    @Override // org.apache.poi.sl.usermodel.TableCell
    public int getGridSpan() {
        return this.gridSpan;
    }

    @Override // org.apache.poi.sl.usermodel.TableCell
    public int getRowSpan() {
        return this.rowSpan;
    }

    public HSLFTableCell getSiblingCell(int i2, int i3) {
        return getParent().getRelativeCell(this, i2, i3);
    }

    @Override // org.apache.poi.sl.usermodel.TableCell
    public boolean isMerged() {
        return false;
    }

    @Override // org.apache.poi.sl.usermodel.TableCell
    public void removeBorder(TableCell.BorderEdge borderEdge) {
        int ordinal = borderEdge.ordinal();
        if (ordinal != 0) {
            if (ordinal != 1) {
                if (ordinal != 2) {
                    if (ordinal != 3) {
                        throw new IllegalArgumentException();
                    } else if (this.borderRight != null) {
                        getParent().removeShape((HSLFShape) this.borderRight);
                        this.borderRight = null;
                        HSLFTableCell siblingCell = getSiblingCell(0, 1);
                        if (siblingCell != null) {
                            siblingCell.borderLeft = null;
                        }
                    }
                } else if (this.borderTop != null) {
                    getParent().removeShape((HSLFShape) this.borderTop);
                    this.borderTop = null;
                    HSLFTableCell siblingCell2 = getSiblingCell(-1, 0);
                    if (siblingCell2 != null) {
                        siblingCell2.borderBottom = null;
                    }
                }
            } else if (this.borderLeft != null) {
                getParent().removeShape((HSLFShape) this.borderLeft);
                this.borderLeft = null;
                HSLFTableCell siblingCell3 = getSiblingCell(0, -1);
                if (siblingCell3 != null) {
                    siblingCell3.borderRight = null;
                }
            }
        } else if (this.borderBottom != null) {
            getParent().removeShape((HSLFShape) this.borderBottom);
            this.borderBottom = null;
            HSLFTableCell siblingCell4 = getSiblingCell(1, 0);
            if (siblingCell4 != null) {
                siblingCell4.borderTop = null;
            }
        }
    }

    @Override // org.apache.poi.hslf.usermodel.HSLFShape, org.apache.poi.sl.usermodel.PlaceableShape
    public void setAnchor(Rectangle2D rectangle2D) {
        super.setAnchor(rectangle2D);
        anchorBorder(TableCell.BorderEdge.top, this.borderTop);
        anchorBorder(TableCell.BorderEdge.right, this.borderRight);
        anchorBorder(TableCell.BorderEdge.bottom, this.borderBottom);
        anchorBorder(TableCell.BorderEdge.left, this.borderLeft);
    }

    @Override // org.apache.poi.sl.usermodel.TableCell
    public void setBorderColor(TableCell.BorderEdge borderEdge, Color color) {
        if (borderEdge == null || color == null) {
            throw new IllegalArgumentException("BorderEdge and/or Color need to be specified.");
        }
        addLine(borderEdge).setLineColor(color);
    }

    @Override // org.apache.poi.sl.usermodel.TableCell
    public void setBorderCompound(TableCell.BorderEdge borderEdge, StrokeStyle.LineCompound lineCompound) {
        if (borderEdge == null || lineCompound == null) {
            throw new IllegalArgumentException("BorderEdge and/or LineCompound need to be specified.");
        }
        addLine(borderEdge).setLineCompound(lineCompound);
    }

    @Override // org.apache.poi.sl.usermodel.TableCell
    public void setBorderDash(TableCell.BorderEdge borderEdge, StrokeStyle.LineDash lineDash) {
        if (borderEdge == null || lineDash == null) {
            throw new IllegalArgumentException("BorderEdge and/or LineDash need to be specified.");
        }
        addLine(borderEdge).setLineDash(lineDash);
    }

    @Override // org.apache.poi.sl.usermodel.TableCell
    public void setBorderStyle(TableCell.BorderEdge borderEdge, StrokeStyle strokeStyle) {
        if (strokeStyle != null) {
            StrokeStyle.LineCompound lineCompound = strokeStyle.getLineCompound();
            if (lineCompound != null) {
                setBorderCompound(borderEdge, lineCompound);
            }
            StrokeStyle.LineDash lineDash = strokeStyle.getLineDash();
            if (lineDash != null) {
                setBorderDash(borderEdge, lineDash);
            }
            setBorderWidth(borderEdge, strokeStyle.getLineWidth());
            return;
        }
        throw new IllegalArgumentException("StrokeStyle needs to be specified.");
    }

    @Override // org.apache.poi.sl.usermodel.TableCell
    public void setBorderWidth(TableCell.BorderEdge borderEdge, double d2) {
        addLine(borderEdge).setLineWidth(d2);
    }

    public void setGridSpan(int i2) {
        this.gridSpan = i2;
    }

    public void setRowSpan(int i2) {
        this.rowSpan = i2;
    }

    @Override // org.apache.poi.sl.usermodel.Shape, org.apache.poi.hslf.usermodel.HSLFShape, org.apache.poi.sl.usermodel.PlaceableShape
    public HSLFTable getParent() {
        return (HSLFTable) super.getParent();
    }

    public HSLFTableCell(HSLFTable hSLFTable) {
        super(hSLFTable);
        setShapeType(ShapeType.RECT);
    }
}
