package org.apache.poi.hslf.usermodel;

import b.b.a.a.a;
import java.awt.Color;
import java.io.IOException;
import java.util.ArrayList;
import java.util.Iterator;
import java.util.List;
import org.apache.poi.common.usermodel.fonts.FontGroup;
import org.apache.poi.common.usermodel.fonts.FontInfo;
import org.apache.poi.hslf.exceptions.HSLFException;
import org.apache.poi.hslf.model.textproperties.BitMaskTextProp;
import org.apache.poi.hslf.model.textproperties.FontAlignmentProp;
import org.apache.poi.hslf.model.textproperties.IndentProp;
import org.apache.poi.hslf.model.textproperties.ParagraphFlagsTextProp;
import org.apache.poi.hslf.model.textproperties.TextPFException9;
import org.apache.poi.hslf.model.textproperties.TextProp;
import org.apache.poi.hslf.model.textproperties.TextPropCollection;
import org.apache.poi.hslf.record.EscherTextboxWrapper;
import org.apache.poi.hslf.record.InteractiveInfo;
import org.apache.poi.hslf.record.MasterTextPropAtom;
import org.apache.poi.hslf.record.OutlineTextRefAtom;
import org.apache.poi.hslf.record.PPDrawing;
import org.apache.poi.hslf.record.Record;
import org.apache.poi.hslf.record.RecordContainer;
import org.apache.poi.hslf.record.RecordTypes;
import org.apache.poi.hslf.record.SlideListWithText;
import org.apache.poi.hslf.record.SlidePersistAtom;
import org.apache.poi.hslf.record.StyleTextProp9Atom;
import org.apache.poi.hslf.record.StyleTextPropAtom;
import org.apache.poi.hslf.record.TextBytesAtom;
import org.apache.poi.hslf.record.TextCharsAtom;
import org.apache.poi.hslf.record.TextHeaderAtom;
import org.apache.poi.hslf.record.TextRulerAtom;
import org.apache.poi.hslf.record.TextSpecInfoAtom;
import org.apache.poi.hslf.record.TxInteractiveInfoAtom;
import org.apache.poi.sl.draw.DrawPaint;
import org.apache.poi.sl.usermodel.AutoNumberingScheme;
import org.apache.poi.sl.usermodel.MasterSheet;
import org.apache.poi.sl.usermodel.PaintStyle;
import org.apache.poi.sl.usermodel.Placeholder;
import org.apache.poi.sl.usermodel.TextParagraph;
import org.apache.poi.sl.usermodel.TextShape;
import org.apache.poi.ss.formula.FormulaParser;
import org.apache.poi.ss.formula.functions.NumericFunction;
import org.apache.poi.ss.util.CellUtil;
import org.apache.poi.util.Internal;
import org.apache.poi.util.POILogFactory;
import org.apache.poi.util.POILogger;
import org.apache.poi.util.StringUtil;
import org.apache.poi.util.Units;
import org.apache.poi.xssf.usermodel.XSSFDataValidationConstraint;

public final class HSLFTextParagraph implements TextParagraph<HSLFShape, HSLFTextParagraph, HSLFTextRun> {
    public static final /* synthetic */ boolean $assertionsDisabled = false;
    public static final int AlignCenter = 1;
    public static final int AlignJustify = 3;
    public static final int AlignLeft = 0;
    public static final int AlignRight = 2;
    public static final POILogger logger = POILogFactory.getLogger(HSLFTextParagraph.class);
    public TextBytesAtom _byteAtom;
    public TextCharsAtom _charAtom;
    public boolean _dirty = false;
    public final TextHeaderAtom _headerAtom;
    public TextPropCollection _masterStyle;
    public TextPropCollection _paragraphStyle = new TextPropCollection(1, TextPropCollection.TextPropType.paragraph);
    public HSLFTextShape _parentShape;
    public TextRulerAtom _ruler;
    public final List<HSLFTextRun> _runs = new ArrayList();
    public HSLFSheet _sheet;
    public final List<HSLFTextParagraph> parentList;
    public int shapeId;
    public StyleTextProp9Atom styleTextProp9Atom;

    /* renamed from: org.apache.poi.hslf.usermodel.HSLFTextParagraph$2  reason: invalid class name */
    public static /* synthetic */ class AnonymousClass2 {
        public static final /* synthetic */ int[] $SwitchMap$org$apache$poi$sl$usermodel$Placeholder;
        public static final /* synthetic */ int[] $SwitchMap$org$apache$poi$sl$usermodel$TextParagraph$TextAlign;

        /* JADX WARNING: Can't wrap try/catch for region: R(24:0|(2:1|2)|3|(2:5|6)|7|(2:9|10)|11|(2:13|14)|15|17|18|19|20|21|22|23|24|25|26|27|28|29|30|32) */
        /* JADX WARNING: Can't wrap try/catch for region: R(26:0|1|2|3|(2:5|6)|7|9|10|11|(2:13|14)|15|17|18|19|20|21|22|23|24|25|26|27|28|29|30|32) */
        /* JADX WARNING: Code restructure failed: missing block: B:33:?, code lost:
            return;
         */
        /* JADX WARNING: Failed to process nested try/catch */
        /* JADX WARNING: Missing exception handler attribute for start block: B:19:0x0036 */
        /* JADX WARNING: Missing exception handler attribute for start block: B:21:0x003c */
        /* JADX WARNING: Missing exception handler attribute for start block: B:23:0x0042 */
        /* JADX WARNING: Missing exception handler attribute for start block: B:25:0x0048 */
        /* JADX WARNING: Missing exception handler attribute for start block: B:27:0x004e */
        /* JADX WARNING: Missing exception handler attribute for start block: B:29:0x0054 */
        static {
            int[] iArr = new int[Placeholder.values().length];
            $SwitchMap$org$apache$poi$sl$usermodel$Placeholder = iArr;
            try {
                Placeholder placeholder = Placeholder.DATETIME;
                iArr[5] = 1;
            } catch (NoSuchFieldError unused) {
            }
            try {
                int[] iArr2 = $SwitchMap$org$apache$poi$sl$usermodel$Placeholder;
                Placeholder placeholder2 = Placeholder.SLIDE_NUMBER;
                iArr2[6] = 2;
            } catch (NoSuchFieldError unused2) {
            }
            try {
                int[] iArr3 = $SwitchMap$org$apache$poi$sl$usermodel$Placeholder;
                Placeholder placeholder3 = Placeholder.FOOTER;
                iArr3[7] = 3;
            } catch (NoSuchFieldError unused3) {
            }
            try {
                int[] iArr4 = $SwitchMap$org$apache$poi$sl$usermodel$Placeholder;
                Placeholder placeholder4 = Placeholder.HEADER;
                iArr4[8] = 4;
            } catch (NoSuchFieldError unused4) {
            }
            int[] iArr5 = new int[TextParagraph.TextAlign.values().length];
            $SwitchMap$org$apache$poi$sl$usermodel$TextParagraph$TextAlign = iArr5;
            TextParagraph.TextAlign textAlign = TextParagraph.TextAlign.LEFT;
            iArr5[0] = 1;
            int[] iArr6 = $SwitchMap$org$apache$poi$sl$usermodel$TextParagraph$TextAlign;
            TextParagraph.TextAlign textAlign2 = TextParagraph.TextAlign.CENTER;
            iArr6[1] = 2;
            int[] iArr7 = $SwitchMap$org$apache$poi$sl$usermodel$TextParagraph$TextAlign;
            TextParagraph.TextAlign textAlign3 = TextParagraph.TextAlign.RIGHT;
            iArr7[2] = 3;
            int[] iArr8 = $SwitchMap$org$apache$poi$sl$usermodel$TextParagraph$TextAlign;
            TextParagraph.TextAlign textAlign4 = TextParagraph.TextAlign.DIST;
            iArr8[5] = 4;
            int[] iArr9 = $SwitchMap$org$apache$poi$sl$usermodel$TextParagraph$TextAlign;
            TextParagraph.TextAlign textAlign5 = TextParagraph.TextAlign.JUSTIFY;
            iArr9[3] = 5;
            int[] iArr10 = $SwitchMap$org$apache$poi$sl$usermodel$TextParagraph$TextAlign;
            TextParagraph.TextAlign textAlign6 = TextParagraph.TextAlign.JUSTIFY_LOW;
            iArr10[4] = 6;
            int[] iArr11 = $SwitchMap$org$apache$poi$sl$usermodel$TextParagraph$TextAlign;
            TextParagraph.TextAlign textAlign7 = TextParagraph.TextAlign.THAI_DIST;
            iArr11[6] = 7;
        }
    }

    public HSLFTextParagraph(TextHeaderAtom textHeaderAtom, TextBytesAtom textBytesAtom, TextCharsAtom textCharsAtom, List<HSLFTextParagraph> list) {
        if (textHeaderAtom != null) {
            this._headerAtom = textHeaderAtom;
            this._byteAtom = textBytesAtom;
            this._charAtom = textCharsAtom;
            this.parentList = list;
            return;
        }
        throw new IllegalArgumentException("TextHeaderAtom must be set.");
    }

    /* JADX WARN: Type inference failed for: r13v5, types: [org.apache.poi.hslf.usermodel.HSLFTextShape] */
    /* JADX WARNING: Unknown variable types count: 1 */
    public static HSLFTextRun appendText(List<HSLFTextParagraph> list, String str, boolean z) {
        String internalString = toInternalString(str);
        HSLFTextParagraph hSLFTextParagraph = list.get(list.size() - 1);
        HSLFTextRun hSLFTextRun = hSLFTextParagraph.getTextRuns().get(hSLFTextParagraph.getTextRuns().size() - 1);
        String[] split = internalString.split("(?<=\r)");
        int length = split.length;
        int i2 = 0;
        while (i2 < length) {
            String str2 = split[i2];
            boolean z2 = hSLFTextRun.getLength() == 0;
            boolean z3 = z2 && hSLFTextParagraph.getTextRuns().size() == 1;
            if (z && !z3) {
                TextPropCollection paragraphStyle = hSLFTextParagraph.getParagraphStyle();
                HSLFTextParagraph hSLFTextParagraph2 = new HSLFTextParagraph(hSLFTextParagraph._headerAtom, hSLFTextParagraph._byteAtom, hSLFTextParagraph._charAtom, list);
                hSLFTextParagraph2.getParagraphStyle().copy(paragraphStyle);
                hSLFTextParagraph2.setParentShape(hSLFTextParagraph.getParentShape());
                hSLFTextParagraph2.setShapeId(hSLFTextParagraph.getShapeId());
                hSLFTextParagraph2.supplySheet(hSLFTextParagraph.getSheet());
                list.add(hSLFTextParagraph2);
                hSLFTextParagraph = hSLFTextParagraph2;
            }
            if (!z2) {
                TextPropCollection characterStyle = hSLFTextRun.getCharacterStyle();
                hSLFTextRun = new HSLFTextRun(hSLFTextParagraph);
                hSLFTextRun.getCharacterStyle().copy(characterStyle);
                hSLFTextParagraph.addTextRun(hSLFTextRun);
            }
            hSLFTextRun.setText(str2);
            i2++;
            z = true;
        }
        storeText(list);
        return hSLFTextRun;
    }

    public static void applyCharacterStyles(List<HSLFTextParagraph> list, List<TextPropCollection> list2) {
        int i2 = 0;
        int i3 = 0;
        for (int i4 = 0; i4 < list2.size(); i4++) {
            TextPropCollection textPropCollection = list2.get(i4);
            int charactersCovered = textPropCollection.getCharactersCovered();
            int i5 = 0;
            while (i5 < charactersCovered) {
                HSLFTextParagraph hSLFTextParagraph = list.get(i2);
                List<HSLFTextRun> textRuns = hSLFTextParagraph.getTextRuns();
                HSLFTextRun hSLFTextRun = textRuns.get(i3);
                int length = hSLFTextRun.getLength() + i5;
                if (length > charactersCovered) {
                    String rawText = hSLFTextRun.getRawText();
                    int i6 = charactersCovered - i5;
                    hSLFTextRun.setText(rawText.substring(0, i6));
                    HSLFTextRun hSLFTextRun2 = new HSLFTextRun(hSLFTextParagraph);
                    hSLFTextRun2.setText(rawText.substring(i6));
                    textRuns.add(i3 + 1, hSLFTextRun2);
                    length = i5 + i6;
                }
                hSLFTextRun.setCharacterStyle(textPropCollection);
                if (i2 == list.size() - 1 && i3 == textRuns.size() - 1) {
                    if (i4 < list2.size() - 1) {
                        HSLFTextRun hSLFTextRun3 = new HSLFTextRun(hSLFTextParagraph);
                        hSLFTextRun3.setText("");
                        textRuns.add(hSLFTextRun3);
                    } else {
                        hSLFTextRun.getCharacterStyle().updateTextSize(hSLFTextRun.getLength() + 1);
                    }
                    length++;
                }
                i5 = length;
                i3++;
                if (i3 == textRuns.size()) {
                    i2++;
                    i3 = 0;
                }
            }
        }
    }

    public static void applyHyperlinks(List<HSLFTextParagraph> list) {
        for (HSLFHyperlink hSLFHyperlink : HSLFHyperlink.find(list)) {
            int i2 = 0;
            for (HSLFTextParagraph hSLFTextParagraph : list) {
                if (i2 > hSLFHyperlink.getEndIndex()) {
                    break;
                }
                List<HSLFTextRun> textRuns = hSLFTextParagraph.getTextRuns();
                for (int i3 = 0; i3 < textRuns.size(); i3++) {
                    HSLFTextRun hSLFTextRun = textRuns.get(i3);
                    int length = hSLFTextRun.getLength();
                    if (i2 < hSLFHyperlink.getEndIndex() && hSLFHyperlink.getStartIndex() < i2 + length) {
                        String rawText = hSLFTextRun.getRawText();
                        int startIndex = hSLFHyperlink.getStartIndex() - i2;
                        if (startIndex > 0) {
                            HSLFTextRun hSLFTextRun2 = new HSLFTextRun(hSLFTextParagraph);
                            hSLFTextRun2.setCharacterStyle(hSLFTextRun.getCharacterStyle());
                            hSLFTextRun2.setText(rawText.substring(startIndex));
                            hSLFTextRun.setText(rawText.substring(0, startIndex));
                            textRuns.add(i3 + 1, hSLFTextRun2);
                            length = startIndex;
                        } else {
                            int min = Math.min(length, hSLFHyperlink.getEndIndex() - hSLFHyperlink.getStartIndex());
                            if (min < length) {
                                HSLFTextRun hSLFTextRun3 = new HSLFTextRun(hSLFTextParagraph);
                                hSLFTextRun3.setCharacterStyle(hSLFTextRun.getCharacterStyle());
                                hSLFTextRun3.setText(rawText.substring(0, min));
                                hSLFTextRun.setText(rawText.substring(min));
                                textRuns.add(i3, hSLFTextRun3);
                                hSLFTextRun = hSLFTextRun3;
                                length = min;
                            }
                            hSLFTextRun.setHyperlink(hSLFHyperlink);
                        }
                    }
                    i2 += length;
                }
            }
        }
    }

    public static void applyParagraphIndents(List<HSLFTextParagraph> list, List<IndentProp> list2) {
        int i2 = 0;
        for (IndentProp indentProp : list2) {
            int charactersCovered = indentProp.getCharactersCovered();
            int i3 = 0;
            while (true) {
                if (i3 < charactersCovered) {
                    if (i2 < list.size() && i3 < charactersCovered - 1) {
                        HSLFTextParagraph hSLFTextParagraph = list.get(i2);
                        int i4 = 0;
                        for (HSLFTextRun hSLFTextRun : hSLFTextParagraph.getTextRuns()) {
                            i4 += hSLFTextRun.getLength();
                        }
                        hSLFTextParagraph.setIndentLevel(indentProp.getIndentLevel());
                        i3 += i4 + 1;
                        i2++;
                    } else {
                        return;
                    }
                }
            }
        }
    }

    public static void applyParagraphStyles(List<HSLFTextParagraph> list, List<TextPropCollection> list2) {
        int i2 = 0;
        for (TextPropCollection textPropCollection : list2) {
            int charactersCovered = textPropCollection.getCharactersCovered();
            int i3 = 0;
            while (true) {
                if (i3 < charactersCovered) {
                    if (i2 < list.size()) {
                        HSLFTextParagraph hSLFTextParagraph = list.get(i2);
                        TextPropCollection textPropCollection2 = new TextPropCollection(0, TextPropCollection.TextPropType.paragraph);
                        textPropCollection2.copy(textPropCollection);
                        hSLFTextParagraph.setParagraphStyle(textPropCollection2);
                        int i4 = 0;
                        for (HSLFTextRun hSLFTextRun : hSLFTextParagraph.getTextRuns()) {
                            i4 += hSLFTextRun.getLength();
                        }
                        if (i2 == list.size() - 1) {
                            i4++;
                        }
                        textPropCollection2.updateTextSize(i4);
                        i3 += i4;
                        i2++;
                    } else {
                        return;
                    }
                }
            }
        }
    }

    public static StyleTextPropAtom findStyleAtomPresent(TextHeaderAtom textHeaderAtom, int i2) {
        Record[] childRecords = textHeaderAtom.getParentRecord().getChildRecords();
        int length = childRecords.length;
        StyleTextPropAtom styleTextPropAtom = null;
        int i3 = 0;
        boolean z = false;
        while (true) {
            boolean z2 = true;
            if (i3 >= length) {
                break;
            }
            Record record = childRecords[i3];
            long recordType = record.getRecordType();
            if (z && recordType == ((long) RecordTypes.TextHeaderAtom.typeID)) {
                break;
            }
            if (textHeaderAtom != record) {
                z2 = false;
            }
            z |= z2;
            if (z && recordType == ((long) RecordTypes.StyleTextPropAtom.typeID)) {
                styleTextPropAtom = (StyleTextPropAtom) record;
            }
            i3++;
        }
        if (styleTextPropAtom == null) {
            logger.log(3, "styles atom doesn't exist. Creating dummy record for later saving.");
            if (i2 < 0) {
                i2 = 1;
            }
            styleTextPropAtom = new StyleTextPropAtom(i2);
        } else if (i2 >= 0) {
            styleTextPropAtom.setParentTextSize(i2);
        }
        return styleTextPropAtom;
    }

    public static List<List<HSLFTextParagraph>> findTextParagraphs(PPDrawing pPDrawing, HSLFSheet hSLFSheet) {
        ArrayList arrayList = new ArrayList();
        for (EscherTextboxWrapper escherTextboxWrapper : pPDrawing.getTextboxWrappers()) {
            List<HSLFTextParagraph> findTextParagraphs = findTextParagraphs(escherTextboxWrapper, hSLFSheet);
            if (findTextParagraphs != null) {
                arrayList.add(findTextParagraphs);
            }
        }
        return arrayList;
    }

    public static void fixLineEndings(List<HSLFTextParagraph> list) {
        HSLFTextRun hSLFTextRun = null;
        for (HSLFTextParagraph hSLFTextParagraph : list) {
            if (hSLFTextRun != null && !hSLFTextRun.getRawText().endsWith("\r")) {
                hSLFTextRun.setText(hSLFTextRun.getRawText() + "\r");
            }
            List<HSLFTextRun> textRuns = hSLFTextParagraph.getTextRuns();
            if (!textRuns.isEmpty()) {
                hSLFTextRun = textRuns.get(textRuns.size() - 1);
            } else {
                throw new HSLFException("paragraph without textruns found");
            }
        }
    }

    public static Color getColorFromColorIndexStruct(int i2, HSLFSheet hSLFSheet) {
        Color color;
        int i3 = i2 >>> 24;
        if (i3 != 254) {
            switch (i3) {
                default:
                    return null;
                case 0:
                case 1:
                case 2:
                case 3:
                case 4:
                case 5:
                case 6:
                case 7:
                    if (hSLFSheet != null) {
                        color = new Color(hSLFSheet.getColorScheme().getColor(i3), true);
                        break;
                    } else {
                        return null;
                    }
            }
        } else {
            color = new Color(i2, true);
        }
        return new Color(color.getBlue(), color.getGreen(), color.getRed());
    }

    private boolean getFlag(int i2) {
        BitMaskTextProp bitMaskTextProp = (BitMaskTextProp) getPropVal(this._paragraphStyle, this._masterStyle, ParagraphFlagsTextProp.NAME);
        if (bitMaskTextProp == null) {
            return false;
        }
        return bitMaskTextProp.getSubValue(i2);
    }

    /* JADX WARN: Type inference failed for: r8v2, types: [org.apache.poi.hslf.usermodel.HSLFMasterSheet] */
    /* JADX WARNING: Unknown variable types count: 1 */
    private TextProp getMasterPropVal(TextPropCollection textPropCollection, TextPropCollection textPropCollection2, String str) {
        int i2 = 0;
        boolean z = textPropCollection.getTextPropType() == TextPropCollection.TextPropType.character;
        if (!z) {
            BitMaskTextProp bitMaskTextProp = (BitMaskTextProp) textPropCollection.findByName(ParagraphFlagsTextProp.NAME);
            if (bitMaskTextProp != null && bitMaskTextProp.getValue() == 0) {
                return null;
            }
        }
        String[] split = str.split(XSSFDataValidationConstraint.LIST_SEPARATOR);
        if (textPropCollection2 == null) {
            HSLFSheet sheet = getSheet();
            int runType = getRunType();
            ?? masterSheet = sheet.getMasterSheet();
            if (masterSheet == 0) {
                logger.log(5, "MasterSheet is not available");
                return null;
            }
            int length = split.length;
            while (i2 < length) {
                TextProp styleAttribute = masterSheet.getStyleAttribute(runType, getIndentLevel(), split[i2], z);
                if (isValidProp(styleAttribute)) {
                    return styleAttribute;
                }
                i2++;
            }
        } else {
            int length2 = split.length;
            while (i2 < length2) {
                TextProp findByName = textPropCollection2.findByName(split[i2]);
                if (isValidProp(findByName)) {
                    return findByName;
                }
                i2++;
            }
        }
        return null;
    }

    private Double getPctOrPoints(String str) {
        TextProp propVal = getPropVal(this._paragraphStyle, this._masterStyle, str);
        if (propVal == null) {
            return null;
        }
        int value = propVal.getValue();
        return Double.valueOf(value < 0 ? Units.masterToPoints(value) : (double) value);
    }

    public static String getRawText(List<HSLFTextParagraph> list) {
        StringBuilder sb = new StringBuilder();
        for (HSLFTextParagraph hSLFTextParagraph : list) {
            for (HSLFTextRun hSLFTextRun : hSLFTextParagraph.getTextRuns()) {
                sb.append(hSLFTextRun.getRawText());
            }
        }
        return sb.toString();
    }

    public static String getText(List<HSLFTextParagraph> list) {
        return toExternalString(getRawText(list), list.get(0).getRunType());
    }

    public static boolean isValidProp(TextProp textProp) {
        return textProp != null && (!textProp.getName().contains(CellUtil.FONT) || textProp.getValue() != -1);
    }

    public static void refreshRecords(List<HSLFTextParagraph> list) {
        RecordContainer parentRecord = list.get(0)._headerAtom.getParentRecord();
        if (parentRecord instanceof EscherTextboxWrapper) {
            try {
                ((EscherTextboxWrapper) parentRecord).writeOut(null);
            } catch (IOException e2) {
                throw new HSLFException("failed dummy write", e2);
            }
        }
    }

    private void setFlag(int i2, boolean z) {
        ((BitMaskTextProp) this._paragraphStyle.addWithName(ParagraphFlagsTextProp.NAME)).setSubValue(z, i2);
        setDirty();
    }

    private void setPctOrPoints(String str, Double d2) {
        Integer num;
        if (d2 != null) {
            num = Integer.valueOf(d2.doubleValue() < NumericFunction.LOG_10_TO_BASE_e ? Units.pointsToMaster(d2.doubleValue()) : d2.intValue());
        } else {
            num = null;
        }
        setParagraphTextPropVal(str, num);
    }

    public static HSLFTextRun setText(List<HSLFTextParagraph> list, String str) {
        Iterator<HSLFTextParagraph> it = list.iterator();
        HSLFTextParagraph next = it.next();
        while (it.hasNext()) {
            it.next();
            it.remove();
        }
        Iterator<HSLFTextRun> it2 = next.getTextRuns().iterator();
        if (it2.hasNext()) {
            it2.next().setText("");
            while (it2.hasNext()) {
                it2.next();
                it2.remove();
            }
        } else {
            next.addTextRun(new HSLFTextRun(next));
        }
        return appendText(list, str, false);
    }

    public static void storeText(List<HSLFTextParagraph> list) {
        fixLineEndings(list);
        updateTextAtom(list);
        updateStyles(list);
        updateHyperlinks(list);
        refreshRecords(list);
        for (HSLFTextParagraph hSLFTextParagraph : list) {
            hSLFTextParagraph._dirty = false;
        }
    }

    public static void supplySheet(List<HSLFTextParagraph> list, HSLFSheet hSLFSheet) {
        if (list != null) {
            for (HSLFTextParagraph hSLFTextParagraph : list) {
                hSLFTextParagraph.supplySheet(hSLFSheet);
            }
        }
    }

    public static String toExternalString(String str, int i2) {
        String replace = str.replace(FormulaParser.CR, '\n');
        if (i2 == -1 || i2 == 0 || i2 == 6) {
            return replace.replace((char) 11, '\n');
        }
        return replace.replace((char) 11, ' ');
    }

    public static String toInternalString(String str) {
        return str.replaceAll("\\r?\\n", "\r");
    }

    public static void updateHyperlinks(List<HSLFTextParagraph> list) {
        RecordContainer parentRecord = list.get(0)._headerAtom.getParentRecord();
        Record[] childRecords = parentRecord.getChildRecords();
        for (Record record : childRecords) {
            if ((record instanceof InteractiveInfo) || (record instanceof TxInteractiveInfoAtom)) {
                parentRecord.removeChild(record);
            }
        }
        HSLFHyperlink hSLFHyperlink = null;
        for (HSLFTextParagraph hSLFTextParagraph : list) {
            Iterator<HSLFTextRun> it = hSLFTextParagraph.iterator();
            while (it.hasNext()) {
                HSLFTextRun next = it.next();
                HSLFHyperlink hyperlink = next.getHyperlink();
                if (hyperlink != null && hyperlink == hSLFHyperlink) {
                    hyperlink.setEndIndex(next.getLength() + hyperlink.getEndIndex());
                } else if (hSLFHyperlink != null) {
                    InteractiveInfo info = hSLFHyperlink.getInfo();
                    TxInteractiveInfoAtom textRunInfo = hSLFHyperlink.getTextRunInfo();
                    parentRecord.appendChildRecord(info);
                    parentRecord.appendChildRecord(textRunInfo);
                }
                hSLFHyperlink = hyperlink;
            }
        }
        if (hSLFHyperlink != null) {
            InteractiveInfo info2 = hSLFHyperlink.getInfo();
            TxInteractiveInfoAtom textRunInfo2 = hSLFHyperlink.getTextRunInfo();
            parentRecord.appendChildRecord(info2);
            parentRecord.appendChildRecord(textRunInfo2);
        }
    }

    public static void updateStyles(List<HSLFTextParagraph> list) {
        String internalString = toInternalString(getRawText(list));
        StyleTextPropAtom findStyleAtomPresent = findStyleAtomPresent(list.get(0)._headerAtom, internalString.length());
        findStyleAtomPresent.clearStyles();
        TextPropCollection textPropCollection = null;
        TextPropCollection textPropCollection2 = null;
        TextPropCollection textPropCollection3 = null;
        TextPropCollection textPropCollection4 = null;
        for (HSLFTextParagraph hSLFTextParagraph : list) {
            TextPropCollection paragraphStyle = hSLFTextParagraph.getParagraphStyle();
            paragraphStyle.updateTextSize(0);
            if (!paragraphStyle.equals(textPropCollection)) {
                textPropCollection = findStyleAtomPresent.addParagraphTextPropCollection(0);
                textPropCollection.copy(paragraphStyle);
            }
            for (HSLFTextRun hSLFTextRun : hSLFTextParagraph.getTextRuns()) {
                TextPropCollection characterStyle = hSLFTextRun.getCharacterStyle();
                characterStyle.updateTextSize(0);
                if (!characterStyle.equals(textPropCollection2)) {
                    textPropCollection2 = findStyleAtomPresent.addCharacterTextPropCollection(0);
                    textPropCollection2.copy(characterStyle);
                }
                int length = hSLFTextRun.getLength();
                paragraphStyle.updateTextSize(paragraphStyle.getCharactersCovered() + length);
                characterStyle.updateTextSize(length);
                textPropCollection.updateTextSize(textPropCollection.getCharactersCovered() + length);
                textPropCollection2.updateTextSize(textPropCollection2.getCharactersCovered() + length);
                textPropCollection4 = characterStyle;
            }
            textPropCollection3 = paragraphStyle;
        }
        if (textPropCollection == null || textPropCollection2 == null || textPropCollection3 == null || textPropCollection4 == null) {
            throw new HSLFException("Not all TextPropCollection could be determined.");
        }
        textPropCollection3.updateTextSize(textPropCollection3.getCharactersCovered() + 1);
        textPropCollection4.updateTextSize(textPropCollection4.getCharactersCovered() + 1);
        textPropCollection.updateTextSize(textPropCollection.getCharactersCovered() + 1);
        textPropCollection2.updateTextSize(textPropCollection2.getCharactersCovered() + 1);
        Record[] records = list.get(0).getRecords();
        for (Record record : records) {
            if (record instanceof TextSpecInfoAtom) {
                ((TextSpecInfoAtom) record).setParentSize(internalString.length() + 1);
                return;
            }
        }
    }

    public static void updateTextAtom(List<HSLFTextParagraph> list) {
        TextCharsAtom textCharsAtom;
        TextCharsAtom textCharsAtom2;
        TextCharsAtom textCharsAtom3;
        String internalString = toInternalString(getRawText(list));
        boolean hasMultibyte = StringUtil.hasMultibyte(internalString);
        TextHeaderAtom textHeaderAtom = list.get(0)._headerAtom;
        TextBytesAtom textBytesAtom = list.get(0)._byteAtom;
        TextCharsAtom textCharsAtom4 = list.get(0)._charAtom;
        StyleTextPropAtom findStyleAtomPresent = findStyleAtomPresent(textHeaderAtom, internalString.length());
        if (hasMultibyte) {
            if (textBytesAtom != null || textCharsAtom4 == null) {
                textCharsAtom4 = new TextCharsAtom();
                textCharsAtom2 = textBytesAtom;
            } else {
                textCharsAtom2 = null;
            }
            textCharsAtom4.setText(internalString);
            textCharsAtom3 = textCharsAtom4;
            textCharsAtom = textCharsAtom4;
        } else {
            if (textCharsAtom4 != null || textBytesAtom == null) {
                textBytesAtom = new TextBytesAtom();
                textCharsAtom2 = textCharsAtom4;
            } else {
                textCharsAtom2 = null;
            }
            byte[] bArr = new byte[internalString.length()];
            StringUtil.putCompressedUnicode(internalString, bArr, 0);
            textBytesAtom.setText(bArr);
            textCharsAtom3 = textCharsAtom4;
            textCharsAtom = textBytesAtom;
        }
        RecordContainer parentRecord = textHeaderAtom.getParentRecord();
        Record[] childRecords = parentRecord.getChildRecords();
        int i2 = -1;
        int i3 = -1;
        for (int i4 = 0; i4 < childRecords.length; i4++) {
            Record record = childRecords[i4];
            if (record != textHeaderAtom) {
                if (record == textCharsAtom2 || record == textCharsAtom) {
                    i2 = i4;
                } else if (record == findStyleAtomPresent) {
                    i3 = i4;
                }
            }
        }
        if (i2 == -1) {
            parentRecord.addChildAfter(textCharsAtom, textHeaderAtom);
        } else {
            childRecords[i2] = textCharsAtom;
        }
        if (i3 == -1) {
            parentRecord.addChildAfter(findStyleAtomPresent, textCharsAtom);
        }
        for (HSLFTextParagraph hSLFTextParagraph : list) {
            if (textCharsAtom == textBytesAtom) {
                hSLFTextParagraph._byteAtom = textBytesAtom;
                hSLFTextParagraph._charAtom = null;
            } else {
                hSLFTextParagraph._byteAtom = null;
                hSLFTextParagraph._charAtom = textCharsAtom3;
            }
        }
    }

    public void addTextRun(HSLFTextRun hSLFTextRun) {
        this._runs.add(hSLFTextRun);
    }

    public TextRulerAtom createTextRuler() {
        TextRulerAtom textRuler = getTextRuler();
        this._ruler = textRuler;
        if (textRuler == null) {
            this._ruler = TextRulerAtom.getParagraphInstance();
            Record record = this._byteAtom;
            if (record == null) {
                record = this._charAtom;
            }
            if (record == null) {
                record = this._headerAtom;
            }
            this._headerAtom.getParentRecord().addChildAfter(this._ruler, record);
        }
        return this._ruler;
    }

    public AutoNumberingScheme getAutoNumberingScheme() {
        StyleTextProp9Atom styleTextProp9Atom2 = this.styleTextProp9Atom;
        if (styleTextProp9Atom2 == null) {
            return null;
        }
        TextPFException9[] autoNumberTypes = styleTextProp9Atom2.getAutoNumberTypes();
        int indentLevel = getIndentLevel();
        if (autoNumberTypes == null || indentLevel == -1 || indentLevel >= autoNumberTypes.length) {
            return null;
        }
        return autoNumberTypes[indentLevel].getAutoNumberScheme();
    }

    public Integer getAutoNumberingStartAt() {
        StyleTextProp9Atom styleTextProp9Atom2 = this.styleTextProp9Atom;
        if (styleTextProp9Atom2 == null) {
            return null;
        }
        TextPFException9[] autoNumberTypes = styleTextProp9Atom2.getAutoNumberTypes();
        int indentLevel = getIndentLevel();
        if (autoNumberTypes == null || indentLevel >= autoNumberTypes.length) {
            return null;
        }
        return Integer.valueOf(autoNumberTypes[indentLevel].getAutoNumberStartNumber().intValue());
    }

    public Character getBulletChar() {
        TextProp propVal = getPropVal(this._paragraphStyle, this._masterStyle, "bullet.char");
        if (propVal == null) {
            return null;
        }
        return Character.valueOf((char) propVal.getValue());
    }

    public Color getBulletColor() {
        PaintStyle.SolidPaint fontColor;
        TextProp propVal = getPropVal(this._paragraphStyle, this._masterStyle, "bullet.color");
        boolean flag = getFlag(2);
        if (propVal != null && flag) {
            return getColorFromColorIndexStruct(propVal.getValue(), this._sheet);
        }
        if (!this._runs.isEmpty() && (fontColor = this._runs.get(0).getFontColor()) != null) {
            return DrawPaint.applyColorTransform(fontColor.getSolidColor());
        }
        return null;
    }

    /* JADX WARN: Type inference failed for: r1v4, types: [org.apache.poi.hslf.usermodel.HSLFSlideShow] */
    /* JADX WARNING: Unknown variable types count: 1 */
    public String getBulletFont() {
        TextProp propVal = getPropVal(this._paragraphStyle, this._masterStyle, "bullet.font");
        boolean flag = getFlag(1);
        if (propVal == null || !flag) {
            return getDefaultFontFamily();
        }
        return getSheet().getSlideShow().getFont(propVal.getValue()).getTypeface();
    }

    public Double getBulletSize() {
        return getPctOrPoints("bullet.size");
    }

    @Override // org.apache.poi.sl.usermodel.TextParagraph
    public TextParagraph.BulletStyle getBulletStyle() {
        if (isBullet() || getAutoNumberingScheme() != null) {
            return new TextParagraph.BulletStyle() {
                /* class org.apache.poi.hslf.usermodel.HSLFTextParagraph.AnonymousClass1 */

                @Override // org.apache.poi.sl.usermodel.TextParagraph.BulletStyle
                public AutoNumberingScheme getAutoNumberingScheme() {
                    return HSLFTextParagraph.this.getAutoNumberingScheme();
                }

                @Override // org.apache.poi.sl.usermodel.TextParagraph.BulletStyle
                public Integer getAutoNumberingStartAt() {
                    return HSLFTextParagraph.this.getAutoNumberingStartAt();
                }

                @Override // org.apache.poi.sl.usermodel.TextParagraph.BulletStyle
                public String getBulletCharacter() {
                    Character bulletChar = HSLFTextParagraph.this.getBulletChar();
                    if (bulletChar == null || bulletChar.charValue() == 0) {
                        return "";
                    }
                    return "" + bulletChar;
                }

                @Override // org.apache.poi.sl.usermodel.TextParagraph.BulletStyle
                public String getBulletFont() {
                    return HSLFTextParagraph.this.getBulletFont();
                }

                @Override // org.apache.poi.sl.usermodel.TextParagraph.BulletStyle
                public PaintStyle getBulletFontColor() {
                    return DrawPaint.createSolidPaint(HSLFTextParagraph.this.getBulletColor());
                }

                @Override // org.apache.poi.sl.usermodel.TextParagraph.BulletStyle
                public Double getBulletFontSize() {
                    return HSLFTextParagraph.this.getBulletSize();
                }

                @Override // org.apache.poi.sl.usermodel.TextParagraph.BulletStyle
                public void setBulletFontColor(Color color) {
                    setBulletFontColor(DrawPaint.createSolidPaint(color));
                }

                @Override // org.apache.poi.sl.usermodel.TextParagraph.BulletStyle
                public void setBulletFontColor(PaintStyle paintStyle) {
                    if (paintStyle instanceof PaintStyle.SolidPaint) {
                        HSLFTextParagraph.this.setBulletColor(DrawPaint.applyColorTransform(((PaintStyle.SolidPaint) paintStyle).getSolidColor()));
                        return;
                    }
                    throw new IllegalArgumentException("HSLF only supports SolidPaint");
                }
            };
        }
        return null;
    }

    @Override // org.apache.poi.sl.usermodel.TextParagraph
    public String getDefaultFontFamily() {
        HSLFTextRun hSLFTextRun;
        FontInfo fontInfo = null;
        if (!this._runs.isEmpty() && (fontInfo = (hSLFTextRun = this._runs.get(0)).getFontInfo((FontGroup) null)) == null) {
            fontInfo = hSLFTextRun.getFontInfo(FontGroup.LATIN);
        }
        if (fontInfo == null) {
            fontInfo = HSLFFontInfoPredefined.ARIAL;
        }
        return fontInfo.getTypeface();
    }

    @Override // org.apache.poi.sl.usermodel.TextParagraph
    public Double getDefaultFontSize() {
        Double fontSize = !this._runs.isEmpty() ? this._runs.get(0).getFontSize() : null;
        return Double.valueOf(fontSize != null ? fontSize.doubleValue() : 12.0d);
    }

    @Override // org.apache.poi.sl.usermodel.TextParagraph
    public Double getDefaultTabSize() {
        return null;
    }

    @Override // org.apache.poi.sl.usermodel.TextParagraph
    public TextParagraph.FontAlign getFontAlign() {
        TextProp propVal = getPropVal(this._paragraphStyle, this._masterStyle, FontAlignmentProp.NAME);
        if (propVal == null) {
            return null;
        }
        int value = propVal.getValue();
        if (value == 0) {
            return TextParagraph.FontAlign.BASELINE;
        }
        if (value == 1) {
            return TextParagraph.FontAlign.TOP;
        }
        if (value == 2) {
            return TextParagraph.FontAlign.CENTER;
        }
        if (value != 3) {
            return TextParagraph.FontAlign.AUTO;
        }
        return TextParagraph.FontAlign.BOTTOM;
    }

    @Override // org.apache.poi.sl.usermodel.TextParagraph
    public Double getIndent() {
        TextProp propVal = getPropVal(this._paragraphStyle, this._masterStyle, "bullet.offset");
        if (propVal == null) {
            return null;
        }
        return Double.valueOf(Units.masterToPoints(propVal.getValue()));
    }

    @Override // org.apache.poi.sl.usermodel.TextParagraph
    public int getIndentLevel() {
        TextPropCollection textPropCollection = this._paragraphStyle;
        if (textPropCollection == null) {
            return 0;
        }
        return textPropCollection.getIndentLevel();
    }

    public int getIndex() {
        TextHeaderAtom textHeaderAtom = this._headerAtom;
        if (textHeaderAtom != null) {
            return textHeaderAtom.getIndex();
        }
        return -1;
    }

    @Override // org.apache.poi.sl.usermodel.TextParagraph
    public Double getLeftMargin() {
        TextProp propVal = getPropVal(this._paragraphStyle, this._masterStyle, "text.offset");
        if (propVal == null) {
            return null;
        }
        return Double.valueOf(Units.masterToPoints(propVal.getValue()));
    }

    @Override // org.apache.poi.sl.usermodel.TextParagraph
    public Double getLineSpacing() {
        return getPctOrPoints("linespacing");
    }

    public TextPropCollection getParagraphStyle() {
        return this._paragraphStyle;
    }

    public TextProp getPropVal(TextPropCollection textPropCollection, TextPropCollection textPropCollection2, String str) {
        for (String str2 : str.split(XSSFDataValidationConstraint.LIST_SEPARATOR)) {
            TextProp findByName = textPropCollection.findByName(str2);
            if (isValidProp(findByName)) {
                return findByName;
            }
        }
        return getMasterPropVal(textPropCollection, textPropCollection2, str);
    }

    public Record[] getRecords() {
        return getRecords(this._headerAtom.getParentRecord().getChildRecords(), new int[]{0}, this._headerAtom);
    }

    @Override // org.apache.poi.sl.usermodel.TextParagraph
    public Double getRightMargin() {
        return null;
    }

    public int getRunType() {
        TextHeaderAtom textHeaderAtom = this._headerAtom;
        if (textHeaderAtom != null) {
            return textHeaderAtom.getTextType();
        }
        return -1;
    }

    public int getShapeId() {
        return this.shapeId;
    }

    public HSLFSheet getSheet() {
        return this._sheet;
    }

    @Override // org.apache.poi.sl.usermodel.TextParagraph
    public Double getSpaceAfter() {
        return getPctOrPoints("spaceafter");
    }

    @Override // org.apache.poi.sl.usermodel.TextParagraph
    public Double getSpaceBefore() {
        return getPctOrPoints("spacebefore");
    }

    public int getStartIdxOfTextRun(HSLFTextRun hSLFTextRun) {
        int i2 = 0;
        for (HSLFTextParagraph hSLFTextParagraph : this.parentList) {
            Iterator<HSLFTextRun> it = hSLFTextParagraph.iterator();
            while (true) {
                if (it.hasNext()) {
                    HSLFTextRun next = it.next();
                    if (next == hSLFTextRun) {
                        return i2;
                    }
                    i2 += next.getLength();
                }
            }
        }
        return -1;
    }

    public StyleTextProp9Atom getStyleTextProp9Atom() {
        return this.styleTextProp9Atom;
    }

    @Override // org.apache.poi.sl.usermodel.TextParagraph
    public TextParagraph.TextAlign getTextAlign() {
        TextProp propVal = getPropVal(this._paragraphStyle, this._masterStyle, CellUtil.ALIGNMENT);
        if (propVal == null) {
            return null;
        }
        switch (propVal.getValue()) {
            case 1:
                return TextParagraph.TextAlign.CENTER;
            case 2:
                return TextParagraph.TextAlign.RIGHT;
            case 3:
                return TextParagraph.TextAlign.JUSTIFY;
            case 4:
                return TextParagraph.TextAlign.DIST;
            case 5:
                return TextParagraph.TextAlign.THAI_DIST;
            case 6:
                return TextParagraph.TextAlign.JUSTIFY_LOW;
            default:
                return TextParagraph.TextAlign.LEFT;
        }
    }

    public TextRulerAtom getTextRuler() {
        return this._ruler;
    }

    @Override // org.apache.poi.sl.usermodel.TextParagraph
    public List<HSLFTextRun> getTextRuns() {
        return this._runs;
    }

    public EscherTextboxWrapper getTextboxWrapper() {
        return (EscherTextboxWrapper) this._headerAtom.getParentRecord();
    }

    public boolean isBullet() {
        return getFlag(0);
    }

    public boolean isDirty() {
        return this._dirty;
    }

    public boolean isDrawingBased() {
        return getIndex() == -1;
    }

    /* JADX WARN: Type inference failed for: r0v0, types: [org.apache.poi.hslf.usermodel.HSLFSimpleShape, org.apache.poi.hslf.usermodel.HSLFTextShape] */
    /* JADX WARNING: Unknown variable types count: 1 */
    @Override // org.apache.poi.sl.usermodel.TextParagraph
    public boolean isHeaderOrFooter() {
        Placeholder placeholder;
        ?? parentShape = getParentShape();
        if (parentShape == 0 || (placeholder = parentShape.getPlaceholder()) == null) {
            return false;
        }
        int ordinal = placeholder.ordinal();
        if (ordinal == 5 || ordinal == 6 || ordinal == 7 || ordinal == 8) {
            return true;
        }
        return false;
    }

    @Override // java.lang.Iterable
    public Iterator<HSLFTextRun> iterator() {
        return this._runs.iterator();
    }

    public void setBullet(boolean z) {
        setFlag(0, z);
    }

    public void setBulletChar(Character ch) {
        setParagraphTextPropVal("bullet.char", ch == null ? null : Integer.valueOf(ch.charValue()));
    }

    public void setBulletColor(Color color) {
        setParagraphTextPropVal("bullet.color", color == null ? null : Integer.valueOf(new Color(color.getBlue(), color.getGreen(), color.getRed(), 254).getRGB()));
        setFlag(2, color != null);
    }

    /* JADX WARN: Type inference failed for: r5v2, types: [org.apache.poi.hslf.usermodel.HSLFSlideShow] */
    /* JADX WARNING: Unknown variable types count: 1 */
    public void setBulletFont(String str) {
        if (str == null) {
            setPropVal(this._paragraphStyle, this._masterStyle, "bullet.font", null);
            setFlag(1, false);
            return;
        }
        setParagraphTextPropVal("bullet.font", getSheet().getSlideShow().addFont(new HSLFFontInfo(str)).getIndex());
        setFlag(1, true);
    }

    public void setBulletSize(Double d2) {
        setPctOrPoints("bullet.size", d2);
    }

    @Override // org.apache.poi.sl.usermodel.TextParagraph
    public void setBulletStyle(Object... objArr) {
        if (objArr.length == 0) {
            setBullet(false);
            return;
        }
        setBullet(true);
        for (Object obj : objArr) {
            if (obj instanceof Number) {
                setBulletSize(Double.valueOf(((Number) obj).doubleValue()));
            } else if (obj instanceof Color) {
                setBulletColor((Color) obj);
            } else if (obj instanceof Character) {
                setBulletChar((Character) obj);
            } else if (obj instanceof String) {
                setBulletFont((String) obj);
            } else if (obj instanceof AutoNumberingScheme) {
                throw new HSLFException("setting bullet auto-numberin scheme for HSLF not supported ... yet");
            }
        }
    }

    public void setDirty() {
        this._dirty = true;
    }

    @Override // org.apache.poi.sl.usermodel.TextParagraph
    public void setIndent(Double d2) {
        setParagraphTextPropVal("bullet.offset", d2 == null ? null : Integer.valueOf(Units.pointsToMaster(d2.doubleValue())));
    }

    @Override // org.apache.poi.sl.usermodel.TextParagraph
    public void setIndentLevel(int i2) {
        TextPropCollection textPropCollection = this._paragraphStyle;
        if (textPropCollection != null) {
            textPropCollection.setIndentLevel((short) i2);
        }
    }

    public void setIndex(int i2) {
        TextHeaderAtom textHeaderAtom = this._headerAtom;
        if (textHeaderAtom != null) {
            textHeaderAtom.setIndex(i2);
        }
    }

    @Override // org.apache.poi.sl.usermodel.TextParagraph
    public void setLeftMargin(Double d2) {
        setParagraphTextPropVal("text.offset", d2 == null ? null : Integer.valueOf(Units.pointsToMaster(d2.doubleValue())));
    }

    @Override // org.apache.poi.sl.usermodel.TextParagraph
    public void setLineSpacing(Double d2) {
        setPctOrPoints("linespacing", d2);
    }

    @Internal
    public void setMasterStyleReference(TextPropCollection textPropCollection) {
        this._masterStyle = textPropCollection;
    }

    public void setParagraphStyle(TextPropCollection textPropCollection) {
        this._paragraphStyle.copy(textPropCollection);
    }

    public void setParagraphTextPropVal(String str, Integer num) {
        setPropVal(this._paragraphStyle, this._masterStyle, str, num);
        setDirty();
    }

    public void setParentShape(HSLFTextShape hSLFTextShape) {
        this._parentShape = hSLFTextShape;
    }

    public void setPropVal(TextPropCollection textPropCollection, TextPropCollection textPropCollection2, String str, Integer num) {
        if ((getSheet() instanceof MasterSheet) && textPropCollection2 != null) {
            textPropCollection = textPropCollection2;
        }
        if (num == null) {
            textPropCollection.removeByName(str);
        } else {
            textPropCollection.addWithName(str).setValue(num.intValue());
        }
    }

    @Override // org.apache.poi.sl.usermodel.TextParagraph
    public void setRightMargin(Double d2) {
    }

    public void setRunType(int i2) {
        TextHeaderAtom textHeaderAtom = this._headerAtom;
        if (textHeaderAtom != null) {
            textHeaderAtom.setTextType(i2);
        }
    }

    public void setShapeId(int i2) {
        this.shapeId = i2;
    }

    @Override // org.apache.poi.sl.usermodel.TextParagraph
    public void setSpaceAfter(Double d2) {
        setPctOrPoints("spaceafter", d2);
    }

    @Override // org.apache.poi.sl.usermodel.TextParagraph
    public void setSpaceBefore(Double d2) {
        setPctOrPoints("spacebefore", d2);
    }

    public void setStyleTextProp9Atom(StyleTextProp9Atom styleTextProp9Atom2) {
        this.styleTextProp9Atom = styleTextProp9Atom2;
    }

    @Override // org.apache.poi.sl.usermodel.TextParagraph
    public void setTextAlign(TextParagraph.TextAlign textAlign) {
        int i2;
        if (textAlign != null) {
            switch (textAlign.ordinal()) {
                case 1:
                    i2 = 1;
                    break;
                case 2:
                    i2 = 2;
                    break;
                case 3:
                    i2 = 3;
                    break;
                case 4:
                    i2 = 6;
                    break;
                case 5:
                    i2 = 4;
                    break;
                case 6:
                    i2 = 5;
                    break;
                default:
                    i2 = 0;
                    break;
            }
        } else {
            i2 = null;
        }
        setParagraphTextPropVal(CellUtil.ALIGNMENT, i2);
    }

    public String toString() {
        StringBuilder sb = new StringBuilder();
        for (HSLFTextRun hSLFTextRun : getTextRuns()) {
            sb.append(hSLFTextRun.getRawText());
        }
        return toExternalString(sb.toString(), getRunType());
    }

    /* Return type fixed from 'org.apache.poi.hslf.usermodel.HSLFTextShape' to match base method */
    @Override // org.apache.poi.sl.usermodel.TextParagraph
    public TextShape<HSLFShape, HSLFTextParagraph> getParentShape() {
        return this._parentShape;
    }

    public static Record[] getRecords(Record[] recordArr, int[] iArr, TextHeaderAtom textHeaderAtom) {
        int i2;
        if (recordArr != null) {
            while (true) {
                i2 = 1;
                if (iArr[0] >= recordArr.length) {
                    break;
                }
                Record record = recordArr[iArr[0]];
                if ((record instanceof TextHeaderAtom) && (textHeaderAtom == null || record == textHeaderAtom)) {
                    break;
                }
                iArr[0] = iArr[0] + 1;
            }
            if (iArr[0] >= recordArr.length) {
                logger.log(3, "header atom wasn't found - container might contain only an OutlineTextRefAtom");
                return new Record[0];
            }
            while (iArr[0] + i2 < recordArr.length) {
                Record record2 = recordArr[iArr[0] + i2];
                if ((record2 instanceof TextHeaderAtom) || (record2 instanceof SlidePersistAtom)) {
                    break;
                }
                i2++;
            }
            Record[] recordArr2 = new Record[i2];
            System.arraycopy(recordArr, iArr[0], recordArr2, 0, i2);
            iArr[0] = iArr[0] + i2;
            return recordArr2;
        }
        throw new NullPointerException("records need to be set.");
    }

    private void supplySheet(HSLFSheet hSLFSheet) {
        this._sheet = hSLFSheet;
        List<HSLFTextRun> list = this._runs;
        if (list != null) {
            for (HSLFTextRun hSLFTextRun : list) {
                hSLFTextRun.updateSheet();
            }
        }
    }

    public static List<HSLFTextParagraph> findTextParagraphs(EscherTextboxWrapper escherTextboxWrapper, HSLFSheet hSLFSheet) {
        List<List<HSLFTextParagraph>> findTextParagraphs;
        int size;
        RecordContainer.handleParentAwareRecords(escherTextboxWrapper);
        int shapeId2 = escherTextboxWrapper.getShapeId();
        OutlineTextRefAtom outlineTextRefAtom = (OutlineTextRefAtom) escherTextboxWrapper.findFirstOfType((long) RecordTypes.OutlineTextRefAtom.typeID);
        List<HSLFTextParagraph> list = null;
        if (outlineTextRefAtom == null) {
            if (hSLFSheet != null) {
                Iterator<List<HSLFTextParagraph>> it = hSLFSheet.getTextParagraphs().iterator();
                while (true) {
                    if (!it.hasNext()) {
                        break;
                    }
                    List<HSLFTextParagraph> next = it.next();
                    if (!next.isEmpty() && next.get(0)._headerAtom.getParentRecord() == escherTextboxWrapper) {
                        list = next;
                        break;
                    }
                }
            }
            if (list == null && (size = (findTextParagraphs = findTextParagraphs(escherTextboxWrapper.getChildRecords())).size()) != 0) {
                if (size == 1) {
                    list = findTextParagraphs.get(0);
                } else {
                    throw new HSLFException("TextBox contains more than one list of paragraphs.");
                }
            }
        } else if (hSLFSheet != null) {
            List<List<HSLFTextParagraph>> textParagraphs = hSLFSheet.getTextParagraphs();
            int textIndex = outlineTextRefAtom.getTextIndex();
            for (List<HSLFTextParagraph> list2 : textParagraphs) {
                if (!list2.isEmpty()) {
                    int index = list2.get(0).getIndex();
                    if (index > textIndex) {
                        break;
                    } else if (index == textIndex) {
                        if (list == null) {
                            list = list2;
                        } else {
                            ArrayList arrayList = new ArrayList(list);
                            arrayList.addAll(list2);
                            list = arrayList;
                        }
                    }
                }
            }
            if (list == null || list.isEmpty()) {
                logger.log(5, a.c("text run not found for OutlineTextRefAtom.TextIndex=", textIndex));
            }
        } else {
            throw new HSLFException("Outline atom reference can't be solved without a sheet record");
        }
        if (list != null) {
            StyleTextProp9Atom styleTextProp9Atom2 = escherTextboxWrapper.getStyleTextProp9Atom();
            for (HSLFTextParagraph hSLFTextParagraph : list) {
                hSLFTextParagraph.setShapeId(shapeId2);
                hSLFTextParagraph.setStyleTextProp9Atom(styleTextProp9Atom2);
            }
        }
        return list;
    }

    public HSLFTextParagraph(HSLFTextParagraph hSLFTextParagraph) {
        this._headerAtom = hSLFTextParagraph._headerAtom;
        this._byteAtom = hSLFTextParagraph._byteAtom;
        this._charAtom = hSLFTextParagraph._charAtom;
        this._parentShape = hSLFTextParagraph._parentShape;
        this._sheet = hSLFTextParagraph._sheet;
        this._ruler = hSLFTextParagraph._ruler;
        this.shapeId = hSLFTextParagraph.shapeId;
        this._paragraphStyle.copy(hSLFTextParagraph._paragraphStyle);
        this.parentList = hSLFTextParagraph.parentList;
    }

    public static List<List<HSLFTextParagraph>> findTextParagraphs(Record[] recordArr) {
        Record[] recordArr2 = recordArr;
        ArrayList arrayList = new ArrayList();
        char c = 0;
        int[] iArr = {0};
        int i2 = 0;
        while (iArr[c] < recordArr2.length) {
            TextHeaderAtom textHeaderAtom = null;
            Record[] records = getRecords(recordArr2, iArr, null);
            int length = records.length;
            TextBytesAtom textBytesAtom = null;
            TextCharsAtom textCharsAtom = null;
            TextRulerAtom textRulerAtom = null;
            MasterTextPropAtom masterTextPropAtom = null;
            int i3 = 0;
            while (i3 < length) {
                Record record = records[i3];
                long recordType = record.getRecordType();
                if (((long) RecordTypes.TextHeaderAtom.typeID) == recordType) {
                    textHeaderAtom = (TextHeaderAtom) record;
                } else if (((long) RecordTypes.TextBytesAtom.typeID) == recordType) {
                    textBytesAtom = (TextBytesAtom) record;
                } else if (((long) RecordTypes.TextCharsAtom.typeID) == recordType) {
                    textCharsAtom = (TextCharsAtom) record;
                } else if (((long) RecordTypes.TextRulerAtom.typeID) == recordType) {
                    textRulerAtom = (TextRulerAtom) record;
                } else if (((long) RecordTypes.MasterTextPropAtom.typeID) == recordType) {
                    masterTextPropAtom = (MasterTextPropAtom) record;
                }
                i3++;
                iArr = iArr;
            }
            if (textHeaderAtom == null) {
                break;
            }
            if (textHeaderAtom.getParentRecord() instanceof SlideListWithText) {
                textHeaderAtom.setIndex(i2);
            }
            if (textBytesAtom == null && textCharsAtom == null) {
                textBytesAtom = new TextBytesAtom();
                logger.log(3, "bytes nor chars atom doesn't exist. Creating dummy record for later saving.");
            }
            String text = textCharsAtom != null ? textCharsAtom.getText() : textBytesAtom.getText();
            StyleTextPropAtom findStyleAtomPresent = findStyleAtomPresent(textHeaderAtom, text.length());
            ArrayList arrayList2 = new ArrayList();
            arrayList.add(arrayList2);
            String[] split = text.split("(?<=\r)");
            for (String str : split) {
                HSLFTextParagraph hSLFTextParagraph = new HSLFTextParagraph(textHeaderAtom, textBytesAtom, textCharsAtom, arrayList2);
                arrayList2.add(hSLFTextParagraph);
                hSLFTextParagraph._ruler = textRulerAtom;
                hSLFTextParagraph.getParagraphStyle().updateTextSize(str.length());
                HSLFTextRun hSLFTextRun = new HSLFTextRun(hSLFTextParagraph);
                hSLFTextParagraph.addTextRun(hSLFTextRun);
                hSLFTextRun.setText(str);
            }
            applyCharacterStyles(arrayList2, findStyleAtomPresent.getCharacterStyles());
            applyParagraphStyles(arrayList2, findStyleAtomPresent.getParagraphStyles());
            if (masterTextPropAtom != null) {
                applyParagraphIndents(arrayList2, masterTextPropAtom.getIndents());
            }
            i2++;
            c = 0;
            recordArr2 = recordArr;
            iArr = iArr;
        }
        if (arrayList.isEmpty()) {
            logger.log(1, "No text records found.");
        }
        return arrayList;
    }
}
