package org.apache.poi.hslf.usermodel;

import java.awt.Color;
import java.util.List;
import org.apache.poi.common.usermodel.fonts.FontGroup;
import org.apache.poi.common.usermodel.fonts.FontInfo;
import org.apache.poi.hslf.exceptions.HSLFException;
import org.apache.poi.hslf.model.textproperties.BitMaskTextProp;
import org.apache.poi.hslf.model.textproperties.CharFlagsTextProp;
import org.apache.poi.hslf.model.textproperties.TextProp;
import org.apache.poi.hslf.model.textproperties.TextPropCollection;
import org.apache.poi.hslf.usermodel.HSLFSlideShow;
import org.apache.poi.sl.draw.DrawPaint;
import org.apache.poi.sl.usermodel.MasterSheet;
import org.apache.poi.sl.usermodel.PaintStyle;
import org.apache.poi.sl.usermodel.Placeholder;
import org.apache.poi.sl.usermodel.TextParagraph;
import org.apache.poi.sl.usermodel.TextRun;
import org.apache.poi.sl.usermodel.TextShape;
import org.apache.poi.util.Internal;
import org.apache.poi.util.POILogFactory;
import org.apache.poi.util.POILogger;

public final class HSLFTextRun implements TextRun {
    public String _runText = "";
    public HSLFFontInfo[] cachedFontInfo;
    public TextPropCollection characterStyle = new TextPropCollection(1, TextPropCollection.TextPropType.character);
    public HSLFHyperlink link;
    public POILogger logger = POILogFactory.getLogger(HSLFTextRun.class);
    public TextPropCollection masterStyle;
    public HSLFTextParagraph parentParagraph;

    /* renamed from: org.apache.poi.hslf.usermodel.HSLFTextRun$1  reason: invalid class name */
    public static /* synthetic */ class AnonymousClass1 {
        public static final /* synthetic */ int[] $SwitchMap$org$apache$poi$common$usermodel$fonts$FontGroup;
        public static final /* synthetic */ int[] $SwitchMap$org$apache$poi$sl$usermodel$Placeholder;

        /* JADX WARNING: Can't wrap try/catch for region: R(14:0|(2:1|2)|3|(2:5|6)|7|(2:9|10)|11|13|14|15|16|17|18|20) */
        /* JADX WARNING: Code restructure failed: missing block: B:21:?, code lost:
            return;
         */
        /* JADX WARNING: Failed to process nested try/catch */
        /* JADX WARNING: Missing exception handler attribute for start block: B:15:0x002c */
        /* JADX WARNING: Missing exception handler attribute for start block: B:17:0x0032 */
        static {
            int[] iArr = new int[Placeholder.values().length];
            $SwitchMap$org$apache$poi$sl$usermodel$Placeholder = iArr;
            try {
                Placeholder placeholder = Placeholder.SLIDE_NUMBER;
                iArr[6] = 1;
            } catch (NoSuchFieldError unused) {
            }
            try {
                int[] iArr2 = $SwitchMap$org$apache$poi$sl$usermodel$Placeholder;
                Placeholder placeholder2 = Placeholder.DATETIME;
                iArr2[5] = 2;
            } catch (NoSuchFieldError unused2) {
            }
            int[] iArr3 = new int[FontGroup.values().length];
            $SwitchMap$org$apache$poi$common$usermodel$fonts$FontGroup = iArr3;
            try {
                FontGroup fontGroup = FontGroup.LATIN;
                iArr3[0] = 1;
            } catch (NoSuchFieldError unused3) {
            }
            int[] iArr4 = $SwitchMap$org$apache$poi$common$usermodel$fonts$FontGroup;
            FontGroup fontGroup2 = FontGroup.COMPLEX_SCRIPT;
            iArr4[3] = 2;
            int[] iArr5 = $SwitchMap$org$apache$poi$common$usermodel$fonts$FontGroup;
            FontGroup fontGroup3 = FontGroup.EAST_ASIAN;
            iArr5[1] = 3;
            int[] iArr6 = $SwitchMap$org$apache$poi$common$usermodel$fonts$FontGroup;
            FontGroup fontGroup4 = FontGroup.SYMBOL;
            iArr6[2] = 4;
        }
    }

    public HSLFTextRun(HSLFTextParagraph hSLFTextParagraph) {
        this.parentParagraph = hSLFTextParagraph;
    }

    private boolean isCharFlagsTextPropVal(int i2) {
        return getFlag(i2);
    }

    private FontGroup safeFontGroup(FontGroup fontGroup) {
        return fontGroup != null ? fontGroup : FontGroup.getFontGroupFirst(getRawText());
    }

    private void setCharFlagsTextPropVal(int i2, boolean z) {
        if (getFlag(i2) != z) {
            setFlag(i2, z);
            this.parentParagraph.setDirty();
        }
    }

    public TextPropCollection getCharacterStyle() {
        return this.characterStyle;
    }

    /* JADX WARN: Type inference failed for: r0v1, types: [org.apache.poi.hslf.usermodel.HSLFShape, org.apache.poi.hslf.usermodel.HSLFSimpleShape, org.apache.poi.hslf.usermodel.HSLFTextShape] */
    /* JADX WARNING: Unknown variable types count: 1 */
    @Override // org.apache.poi.sl.usermodel.TextRun
    public TextRun.FieldType getFieldType() {
        TextShape<?, ? extends TextParagraph<?, ?, ? extends TextRun>> metroShape;
        ?? parentShape = getTextParagraph().getParentShape();
        Placeholder placeholder = parentShape.getPlaceholder();
        if (placeholder != null) {
            int ordinal = placeholder.ordinal();
            if (ordinal == 5) {
                return TextRun.FieldType.DATE_TIME;
            }
            if (ordinal == 6) {
                return TextRun.FieldType.SLIDE_NUMBER;
            }
        }
        if (!(parentShape.getSheet() instanceof MasterSheet) || (metroShape = parentShape.getMetroShape()) == null || metroShape.getTextParagraphs().isEmpty()) {
            return null;
        }
        List textRuns = ((TextParagraph) metroShape.getTextParagraphs().get(0)).getTextRuns();
        if (textRuns.isEmpty()) {
            return null;
        }
        return ((TextRun) textRuns.get(0)).getFieldType();
    }

    /* JADX WARN: Type inference failed for: r4v3, types: [org.apache.poi.hslf.usermodel.HSLFMasterSheet] */
    /* JADX WARNING: Unknown variable types count: 1 */
    public boolean getFlag(int i2) {
        TextPropCollection textPropCollection = this.characterStyle;
        if (textPropCollection == null) {
            return false;
        }
        BitMaskTextProp bitMaskTextProp = (BitMaskTextProp) textPropCollection.findByName(CharFlagsTextProp.NAME);
        if (bitMaskTextProp == null || !bitMaskTextProp.getSubPropMatches()[i2]) {
            int runType = this.parentParagraph.getRunType();
            HSLFSheet sheet = this.parentParagraph.getSheet();
            if (sheet != null) {
                ?? masterSheet = sheet.getMasterSheet();
                if (masterSheet != 0) {
                    bitMaskTextProp = (BitMaskTextProp) masterSheet.getStyleAttribute(runType, this.parentParagraph.getIndentLevel(), CharFlagsTextProp.NAME, true);
                }
            } else {
                this.logger.log(5, "MasterSheet is not available");
            }
        }
        if (bitMaskTextProp == null) {
            return false;
        }
        return bitMaskTextProp.getSubValue(i2);
    }

    @Override // org.apache.poi.sl.usermodel.TextRun
    public String getFontFamily() {
        return getFontFamily(null);
    }

    public int getFontIndex() {
        TextProp propVal = getTextParagraph().getPropVal(this.characterStyle, this.masterStyle, "font.index");
        if (propVal == null) {
            return -1;
        }
        return propVal.getValue();
    }

    @Override // org.apache.poi.sl.usermodel.TextRun
    public Double getFontSize() {
        TextProp propVal = getTextParagraph().getPropVal(this.characterStyle, this.masterStyle, "font.size");
        if (propVal == null) {
            return null;
        }
        return Double.valueOf((double) propVal.getValue());
    }

    public int getLength() {
        return this._runText.length();
    }

    @Override // org.apache.poi.sl.usermodel.TextRun
    public byte getPitchAndFamily() {
        return 0;
    }

    @Override // org.apache.poi.sl.usermodel.TextRun
    public String getRawText() {
        return this._runText;
    }

    public int getSuperscript() {
        TextProp propVal = getTextParagraph().getPropVal(this.characterStyle, this.masterStyle, "superscript");
        if (propVal == null) {
            return 0;
        }
        return propVal.getValue();
    }

    @Override // org.apache.poi.sl.usermodel.TextRun
    public TextRun.TextCap getTextCap() {
        return TextRun.TextCap.NONE;
    }

    public HSLFTextParagraph getTextParagraph() {
        return this.parentParagraph;
    }

    @Override // org.apache.poi.sl.usermodel.TextRun
    public boolean isBold() {
        return isCharFlagsTextPropVal(0);
    }

    public boolean isEmbossed() {
        return isCharFlagsTextPropVal(9);
    }

    @Override // org.apache.poi.sl.usermodel.TextRun
    public boolean isItalic() {
        return isCharFlagsTextPropVal(1);
    }

    public boolean isShadowed() {
        return isCharFlagsTextPropVal(4);
    }

    @Override // org.apache.poi.sl.usermodel.TextRun
    public boolean isStrikethrough() {
        return isCharFlagsTextPropVal(8);
    }

    @Override // org.apache.poi.sl.usermodel.TextRun
    public boolean isSubscript() {
        return getSuperscript() < 0;
    }

    @Override // org.apache.poi.sl.usermodel.TextRun
    public boolean isSuperscript() {
        return getSuperscript() > 0;
    }

    @Override // org.apache.poi.sl.usermodel.TextRun
    public boolean isUnderlined() {
        return isCharFlagsTextPropVal(2);
    }

    @Override // org.apache.poi.sl.usermodel.TextRun
    public void setBold(boolean z) {
        setCharFlagsTextPropVal(0, z);
    }

    public void setCharTextPropVal(String str, Integer num) {
        getTextParagraph().setPropVal(this.characterStyle, this.masterStyle, str, num);
        getTextParagraph().setDirty();
    }

    public void setCharacterStyle(TextPropCollection textPropCollection) {
        this.characterStyle.copy(textPropCollection);
        this.characterStyle.updateTextSize(this._runText.length());
    }

    public void setEmbossed(boolean z) {
        setCharFlagsTextPropVal(9, z);
    }

    public void setFlag(int i2, boolean z) {
        ((BitMaskTextProp) this.characterStyle.addWithName(CharFlagsTextProp.NAME)).setSubValue(z, i2);
    }

    public void setFontColor(int i2) {
        setCharTextPropVal("font.color", Integer.valueOf(i2));
    }

    @Override // org.apache.poi.sl.usermodel.TextRun
    public void setFontFamily(String str) {
        setFontInfo(new HSLFFontInfo(str), FontGroup.LATIN);
    }

    public void setFontIndex(int i2) {
        setCharTextPropVal("font.index", Integer.valueOf(i2));
    }

    /* JADX DEBUG: Multi-variable search result rejected for r2v0, resolved type: org.apache.poi.hslf.usermodel.HSLFSlideShow */
    /* JADX DEBUG: Multi-variable search result rejected for r2v2, resolved type: org.apache.poi.hslf.usermodel.HSLFSlideShow */
    /* JADX DEBUG: Multi-variable search result rejected for r2v3, resolved type: org.apache.poi.hslf.usermodel.HSLFSlideShow */
    /* JADX WARN: Multi-variable type inference failed */
    /* JADX WARNING: Removed duplicated region for block: B:16:0x0030  */
    @Override // org.apache.poi.sl.usermodel.TextRun
    public void setFontInfo(FontInfo fontInfo, FontGroup fontGroup) {
        HSLFSlideShow hSLFSlideShow;
        String str;
        FontGroup safeFontGroup = safeFontGroup(fontGroup);
        HSLFSheet sheet = this.parentParagraph.getSheet();
        HSLFFontInfo hSLFFontInfo = null;
        Integer num = null;
        if (sheet == null) {
            hSLFSlideShow = 0;
        } else {
            hSLFSlideShow = sheet.getSlideShow();
        }
        if (sheet == null || hSLFSlideShow == 0) {
            if (this.cachedFontInfo == null) {
                this.cachedFontInfo = new HSLFFontInfo[FontGroup.values().length];
            }
            HSLFFontInfo[] hSLFFontInfoArr = this.cachedFontInfo;
            int ordinal = safeFontGroup.ordinal();
            if (fontInfo != null) {
                hSLFFontInfo = new HSLFFontInfo(fontInfo);
            }
            hSLFFontInfoArr[ordinal] = hSLFFontInfo;
            return;
        }
        int ordinal2 = safeFontGroup.ordinal();
        if (ordinal2 != 1) {
            if (ordinal2 == 2) {
                str = "symbol.font.index";
            } else if (ordinal2 != 3) {
                str = "font.index";
            }
            if (fontInfo != null) {
                num = hSLFSlideShow.addFont(fontInfo).getIndex();
            }
            setCharTextPropVal(str, num);
        }
        str = "asian.font.index";
        if (fontInfo != null) {
        }
        setCharTextPropVal(str, num);
    }

    @Override // org.apache.poi.sl.usermodel.TextRun
    public void setFontSize(Double d2) {
        setCharTextPropVal("font.size", d2 == null ? null : Integer.valueOf(d2.intValue()));
    }

    public void setHyperlink(HSLFHyperlink hSLFHyperlink) {
        this.link = hSLFHyperlink;
    }

    @Override // org.apache.poi.sl.usermodel.TextRun
    public void setItalic(boolean z) {
        setCharFlagsTextPropVal(1, z);
    }

    @Internal
    public void setMasterStyleReference(TextPropCollection textPropCollection) {
        this.masterStyle = textPropCollection;
    }

    public void setShadowed(boolean z) {
        setCharFlagsTextPropVal(4, z);
    }

    @Override // org.apache.poi.sl.usermodel.TextRun
    public void setStrikethrough(boolean z) {
        setCharFlagsTextPropVal(8, z);
    }

    public void setSuperscript(int i2) {
        setCharTextPropVal("superscript", Integer.valueOf(i2));
    }

    @Override // org.apache.poi.sl.usermodel.TextRun
    public void setText(String str) {
        if (str != null) {
            String internalString = HSLFTextParagraph.toInternalString(str);
            if (!internalString.equals(this._runText)) {
                this._runText = internalString;
                if (HSLFSlideShow.getLoadSavePhase() == HSLFSlideShow.LoadSavePhase.LOADED) {
                    this.parentParagraph.setDirty();
                    return;
                }
                return;
            }
            return;
        }
        throw new HSLFException("text must not be null");
    }

    @Override // org.apache.poi.sl.usermodel.TextRun
    public void setUnderlined(boolean z) {
        setCharFlagsTextPropVal(2, z);
    }

    public void updateSheet() {
        if (this.cachedFontInfo != null) {
            FontGroup[] values = FontGroup.values();
            for (FontGroup fontGroup : values) {
                setFontInfo(this.cachedFontInfo[fontGroup.ordinal()], fontGroup);
            }
            this.cachedFontInfo = null;
        }
    }

    @Override // org.apache.poi.sl.usermodel.TextRun
    public HSLFHyperlink createHyperlink() {
        if (this.link == null) {
            this.link = HSLFHyperlink.createHyperlink(this);
            this.parentParagraph.setDirty();
        }
        return this.link;
    }

    @Override // org.apache.poi.sl.usermodel.TextRun
    public PaintStyle.SolidPaint getFontColor() {
        TextProp propVal = getTextParagraph().getPropVal(this.characterStyle, this.masterStyle, "font.color");
        if (propVal == null) {
            return null;
        }
        return DrawPaint.createSolidPaint(HSLFTextParagraph.getColorFromColorIndexStruct(propVal.getValue(), this.parentParagraph.getSheet()));
    }

    @Override // org.apache.poi.sl.usermodel.TextRun
    public String getFontFamily(FontGroup fontGroup) {
        HSLFFontInfo fontInfo = getFontInfo(fontGroup);
        if (fontInfo != null) {
            return fontInfo.getTypeface();
        }
        return null;
    }

    /* JADX DEBUG: Multi-variable search result rejected for r2v0, resolved type: org.apache.poi.hslf.usermodel.HSLFSlideShow */
    /* JADX DEBUG: Multi-variable search result rejected for r2v2, resolved type: org.apache.poi.hslf.usermodel.HSLFSlideShow */
    /* JADX DEBUG: Multi-variable search result rejected for r2v3, resolved type: org.apache.poi.hslf.usermodel.HSLFSlideShow */
    /* JADX WARN: Multi-variable type inference failed */
    /* JADX WARNING: Removed duplicated region for block: B:17:0x003c  */
    /* JADX WARNING: Removed duplicated region for block: B:22:? A[RETURN, SYNTHETIC] */
    @Override // org.apache.poi.sl.usermodel.TextRun
    public HSLFFontInfo getFontInfo(FontGroup fontGroup) {
        HSLFSlideShow hSLFSlideShow;
        String str;
        TextProp propVal;
        FontGroup safeFontGroup = safeFontGroup(fontGroup);
        HSLFSheet sheet = this.parentParagraph.getSheet();
        if (sheet == null) {
            hSLFSlideShow = 0;
        } else {
            hSLFSlideShow = sheet.getSlideShow();
        }
        if (sheet == null || hSLFSlideShow == 0) {
            HSLFFontInfo[] hSLFFontInfoArr = this.cachedFontInfo;
            if (hSLFFontInfoArr != null) {
                return hSLFFontInfoArr[safeFontGroup.ordinal()];
            }
            return null;
        }
        int ordinal = safeFontGroup.ordinal();
        if (ordinal != 1) {
            if (ordinal == 2) {
                str = "symbol.font.index";
            } else if (ordinal != 3) {
                str = "font.index,ansi.font.index";
            }
            propVal = getTextParagraph().getPropVal(this.characterStyle, this.masterStyle, str);
            if (propVal == null) {
                return hSLFSlideShow.getFont(propVal.getValue());
            }
            return null;
        }
        str = "asian.font.index";
        propVal = getTextParagraph().getPropVal(this.characterStyle, this.masterStyle, str);
        if (propVal == null) {
        }
    }

    @Override // org.apache.poi.sl.usermodel.TextRun
    public HSLFHyperlink getHyperlink() {
        return this.link;
    }

    @Override // org.apache.poi.sl.usermodel.TextRun
    public void setFontColor(Color color) {
        setFontColor(DrawPaint.createSolidPaint(color));
    }

    @Override // org.apache.poi.sl.usermodel.TextRun
    public void setFontFamily(String str, FontGroup fontGroup) {
        setFontInfo(new HSLFFontInfo(str), fontGroup);
    }

    @Override // org.apache.poi.sl.usermodel.TextRun
    public void setFontColor(PaintStyle paintStyle) {
        if (paintStyle instanceof PaintStyle.SolidPaint) {
            Color applyColorTransform = DrawPaint.applyColorTransform(((PaintStyle.SolidPaint) paintStyle).getSolidColor());
            setFontColor(new Color(applyColorTransform.getBlue(), applyColorTransform.getGreen(), applyColorTransform.getRed(), 254).getRGB());
            return;
        }
        throw new IllegalArgumentException("HSLF only supports solid paint");
    }
}
