package org.apache.poi.hslf.usermodel;

import java.awt.Graphics2D;
import java.awt.geom.Rectangle2D;
import java.io.IOException;
import java.util.ArrayList;
import java.util.Iterator;
import java.util.List;
import org.apache.poi.ddf.AbstractEscherOptRecord;
import org.apache.poi.ddf.EscherContainerRecord;
import org.apache.poi.ddf.EscherSimpleProperty;
import org.apache.poi.ddf.EscherTextboxRecord;
import org.apache.poi.hslf.exceptions.HSLFException;
import org.apache.poi.hslf.model.HSLFMetroShape;
import org.apache.poi.hslf.model.textproperties.TextPropCollection;
import org.apache.poi.hslf.record.EscherTextboxWrapper;
import org.apache.poi.hslf.record.OEPlaceholderAtom;
import org.apache.poi.hslf.record.PPDrawing;
import org.apache.poi.hslf.record.RecordTypes;
import org.apache.poi.hslf.record.RoundTripHFPlaceholder12;
import org.apache.poi.hslf.record.StyleTextPropAtom;
import org.apache.poi.hslf.record.TextBytesAtom;
import org.apache.poi.hslf.record.TextCharsAtom;
import org.apache.poi.hslf.record.TextHeaderAtom;
import org.apache.poi.sl.draw.DrawFactory;
import org.apache.poi.sl.usermodel.Insets2D;
import org.apache.poi.sl.usermodel.Placeholder;
import org.apache.poi.sl.usermodel.ShapeContainer;
import org.apache.poi.sl.usermodel.TextParagraph;
import org.apache.poi.sl.usermodel.TextRun;
import org.apache.poi.sl.usermodel.TextShape;
import org.apache.poi.sl.usermodel.VerticalAlignment;
import org.apache.poi.ss.formula.functions.NumericFunction;
import org.apache.poi.util.POILogFactory;
import org.apache.poi.util.POILogger;
import org.apache.poi.util.Units;

public abstract class HSLFTextShape extends HSLFSimpleShape implements TextShape<HSLFShape, HSLFTextParagraph> {
    public static final /* synthetic */ boolean $assertionsDisabled = false;
    public static final POILogger LOG = POILogFactory.getLogger(HSLFTextShape.class);
    public static final int WrapByPoints = 1;
    public static final int WrapNone = 2;
    public static final int WrapSquare = 0;
    public static final int WrapThrough = 4;
    public static final int WrapTopBottom = 3;
    public List<HSLFTextParagraph> _paragraphs;
    public EscherTextboxWrapper _txtbox;

    /* renamed from: org.apache.poi.hslf.usermodel.HSLFTextShape$1  reason: invalid class name */
    public static /* synthetic */ class AnonymousClass1 {
        public static final /* synthetic */ int[] $SwitchMap$org$apache$poi$sl$usermodel$TextShape$TextDirection;
        public static final /* synthetic */ int[] $SwitchMap$org$apache$poi$sl$usermodel$TextShape$TextPlaceholder;

        /* JADX WARNING: Can't wrap try/catch for region: R(28:0|(2:1|2)|3|(2:5|6)|7|(2:9|10)|11|13|14|15|(2:17|18)|19|(2:21|22)|23|25|26|27|28|29|31|32|33|34|35|36|37|38|40) */
        /* JADX WARNING: Can't wrap try/catch for region: R(29:0|(2:1|2)|3|(2:5|6)|7|(2:9|10)|11|13|14|15|(2:17|18)|19|21|22|23|25|26|27|28|29|31|32|33|34|35|36|37|38|40) */
        /* JADX WARNING: Can't wrap try/catch for region: R(30:0|1|2|3|(2:5|6)|7|(2:9|10)|11|13|14|15|(2:17|18)|19|21|22|23|25|26|27|28|29|31|32|33|34|35|36|37|38|40) */
        /* JADX WARNING: Can't wrap try/catch for region: R(32:0|1|2|3|(2:5|6)|7|9|10|11|13|14|15|17|18|19|21|22|23|25|26|27|28|29|31|32|33|34|35|36|37|38|40) */
        /* JADX WARNING: Code restructure failed: missing block: B:41:?, code lost:
            return;
         */
        /* JADX WARNING: Failed to process nested try/catch */
        /* JADX WARNING: Missing exception handler attribute for start block: B:27:0x0039 */
        /* JADX WARNING: Missing exception handler attribute for start block: B:33:0x004e */
        /* JADX WARNING: Missing exception handler attribute for start block: B:35:0x0054 */
        /* JADX WARNING: Missing exception handler attribute for start block: B:37:0x005a */
        static {
            int[] iArr = new int[TextShape.TextPlaceholder.values().length];
            $SwitchMap$org$apache$poi$sl$usermodel$TextShape$TextPlaceholder = iArr;
            try {
                TextShape.TextPlaceholder textPlaceholder = TextShape.TextPlaceholder.BODY;
                iArr[1] = 1;
            } catch (NoSuchFieldError unused) {
            }
            try {
                int[] iArr2 = $SwitchMap$org$apache$poi$sl$usermodel$TextShape$TextPlaceholder;
                TextShape.TextPlaceholder textPlaceholder2 = TextShape.TextPlaceholder.TITLE;
                iArr2[0] = 2;
            } catch (NoSuchFieldError unused2) {
            }
            try {
                int[] iArr3 = $SwitchMap$org$apache$poi$sl$usermodel$TextShape$TextPlaceholder;
                TextShape.TextPlaceholder textPlaceholder3 = TextShape.TextPlaceholder.CENTER_BODY;
                iArr3[3] = 3;
            } catch (NoSuchFieldError unused3) {
            }
            try {
                int[] iArr4 = $SwitchMap$org$apache$poi$sl$usermodel$TextShape$TextPlaceholder;
                TextShape.TextPlaceholder textPlaceholder4 = TextShape.TextPlaceholder.CENTER_TITLE;
                iArr4[2] = 4;
            } catch (NoSuchFieldError unused4) {
            }
            try {
                int[] iArr5 = $SwitchMap$org$apache$poi$sl$usermodel$TextShape$TextPlaceholder;
                TextShape.TextPlaceholder textPlaceholder5 = TextShape.TextPlaceholder.HALF_BODY;
                iArr5[4] = 5;
            } catch (NoSuchFieldError unused5) {
            }
            try {
                int[] iArr6 = $SwitchMap$org$apache$poi$sl$usermodel$TextShape$TextPlaceholder;
                TextShape.TextPlaceholder textPlaceholder6 = TextShape.TextPlaceholder.QUARTER_BODY;
                iArr6[5] = 6;
            } catch (NoSuchFieldError unused6) {
            }
            int[] iArr7 = $SwitchMap$org$apache$poi$sl$usermodel$TextShape$TextPlaceholder;
            TextShape.TextPlaceholder textPlaceholder7 = TextShape.TextPlaceholder.NOTES;
            iArr7[6] = 7;
            int[] iArr8 = $SwitchMap$org$apache$poi$sl$usermodel$TextShape$TextPlaceholder;
            TextShape.TextPlaceholder textPlaceholder8 = TextShape.TextPlaceholder.OTHER;
            iArr8[7] = 8;
            int[] iArr9 = new int[TextShape.TextDirection.values().length];
            $SwitchMap$org$apache$poi$sl$usermodel$TextShape$TextDirection = iArr9;
            TextShape.TextDirection textDirection = TextShape.TextDirection.STACKED;
            iArr9[3] = 1;
            int[] iArr10 = $SwitchMap$org$apache$poi$sl$usermodel$TextShape$TextDirection;
            TextShape.TextDirection textDirection2 = TextShape.TextDirection.HORIZONTAL;
            iArr10[0] = 2;
            int[] iArr11 = $SwitchMap$org$apache$poi$sl$usermodel$TextShape$TextDirection;
            TextShape.TextDirection textDirection3 = TextShape.TextDirection.VERTICAL;
            iArr11[1] = 3;
            int[] iArr12 = $SwitchMap$org$apache$poi$sl$usermodel$TextShape$TextDirection;
            TextShape.TextDirection textDirection4 = TextShape.TextDirection.VERTICAL_270;
            iArr12[2] = 4;
        }
    }

    public enum HSLFTextAnchor {
        TOP(0, VerticalAlignment.TOP, false, false),
        MIDDLE(1, VerticalAlignment.MIDDLE, false, false),
        BOTTOM(2, VerticalAlignment.BOTTOM, false, false),
        TOP_CENTER(3, VerticalAlignment.TOP, true, false),
        MIDDLE_CENTER(4, VerticalAlignment.MIDDLE, true, false),
        BOTTOM_CENTER(5, VerticalAlignment.BOTTOM, true, false),
        TOP_BASELINE(6, VerticalAlignment.TOP, false, true),
        BOTTOM_BASELINE(7, VerticalAlignment.BOTTOM, false, true),
        TOP_CENTER_BASELINE(8, VerticalAlignment.TOP, true, true),
        BOTTOM_CENTER_BASELINE(9, VerticalAlignment.BOTTOM, true, true);
        
        public final Boolean baseline;
        public final boolean centered;
        public final int nativeId;
        public final VerticalAlignment vAlign;

        /* access modifiers changed from: public */
        HSLFTextAnchor(int i2, VerticalAlignment verticalAlignment, boolean z, Boolean bool) {
            this.nativeId = i2;
            this.vAlign = verticalAlignment;
            this.centered = z;
            this.baseline = bool;
        }

        public static HSLFTextAnchor fromNativeId(int i2) {
            HSLFTextAnchor[] values = values();
            for (HSLFTextAnchor hSLFTextAnchor : values) {
                if (hSLFTextAnchor.nativeId == i2) {
                    return hSLFTextAnchor;
                }
            }
            return null;
        }
    }

    public HSLFTextShape(EscherContainerRecord escherContainerRecord, ShapeContainer<HSLFShape, HSLFTextParagraph> shapeContainer) {
        super(escherContainerRecord, shapeContainer);
        this._paragraphs = new ArrayList();
    }

    private void createEmptyParagraph() {
        TextPropCollection textPropCollection;
        TextPropCollection textPropCollection2;
        TextHeaderAtom textHeaderAtom = (TextHeaderAtom) this._txtbox.findFirstOfType(TextHeaderAtom._type);
        if (textHeaderAtom == null) {
            textHeaderAtom = new TextHeaderAtom();
            textHeaderAtom.setParentRecord(this._txtbox);
            this._txtbox.appendChildRecord(textHeaderAtom);
        }
        TextBytesAtom textBytesAtom = (TextBytesAtom) this._txtbox.findFirstOfType(TextBytesAtom._type);
        TextCharsAtom textCharsAtom = (TextCharsAtom) this._txtbox.findFirstOfType(TextCharsAtom._type);
        if (textBytesAtom == null && textCharsAtom == null) {
            textBytesAtom = new TextBytesAtom();
            textBytesAtom.setText(new byte[0]);
            this._txtbox.appendChildRecord(textBytesAtom);
        }
        String text = textBytesAtom != null ? textBytesAtom.getText() : textCharsAtom.getText();
        StyleTextPropAtom styleTextPropAtom = (StyleTextPropAtom) this._txtbox.findFirstOfType(StyleTextPropAtom._type);
        if (styleTextPropAtom == null) {
            int length = text.length() + 1;
            StyleTextPropAtom styleTextPropAtom2 = new StyleTextPropAtom(length);
            if (this._paragraphs.isEmpty()) {
                textPropCollection2 = styleTextPropAtom2.addParagraphTextPropCollection(length);
                textPropCollection = styleTextPropAtom2.addCharacterTextPropCollection(length);
            } else {
                TextPropCollection textPropCollection3 = null;
                TextPropCollection textPropCollection4 = null;
                for (HSLFTextParagraph hSLFTextParagraph : this._paragraphs) {
                    int i2 = 0;
                    for (HSLFTextRun hSLFTextRun : hSLFTextParagraph.getTextRuns()) {
                        i2 += hSLFTextRun.getLength();
                        TextPropCollection addCharacterTextPropCollection = styleTextPropAtom2.addCharacterTextPropCollection(hSLFTextRun.getLength());
                        hSLFTextRun.setCharacterStyle(addCharacterTextPropCollection);
                        textPropCollection4 = addCharacterTextPropCollection;
                    }
                    TextPropCollection addParagraphTextPropCollection = styleTextPropAtom2.addParagraphTextPropCollection(i2);
                    hSLFTextParagraph.setParagraphStyle(addParagraphTextPropCollection);
                    textPropCollection3 = addParagraphTextPropCollection;
                }
                textPropCollection2 = textPropCollection3;
                textPropCollection = textPropCollection4;
            }
            this._txtbox.appendChildRecord(styleTextPropAtom2);
        } else {
            textPropCollection = styleTextPropAtom.getCharacterStyles().get(0);
            textPropCollection2 = styleTextPropAtom.getParagraphStyles().get(0);
        }
        if (this._paragraphs.isEmpty()) {
            HSLFTextParagraph hSLFTextParagraph2 = new HSLFTextParagraph(textHeaderAtom, textBytesAtom, textCharsAtom, this._paragraphs);
            hSLFTextParagraph2.setParagraphStyle(textPropCollection2);
            hSLFTextParagraph2.setParentShape(this);
            this._paragraphs.add(hSLFTextParagraph2);
            HSLFTextRun hSLFTextRun2 = new HSLFTextRun(hSLFTextParagraph2);
            hSLFTextRun2.setCharacterStyle(textPropCollection);
            hSLFTextRun2.setText(text);
            hSLFTextParagraph2.addTextRun(hSLFTextRun2);
        }
    }

    private double getInset(short s, double d2) {
        EscherSimpleProperty escherSimpleProperty = (EscherSimpleProperty) HSLFShape.getEscherProperty(getEscherOptRecord(), s);
        return Units.toPoints((long) (escherSimpleProperty == null ? (int) (((double) Units.toEMU(72.0d)) * d2) : escherSimpleProperty.getPropertyValue()));
    }

    private void setInset(short s, double d2) {
        setEscherProperty(s, Units.toEMU(d2));
    }

    @Override // org.apache.poi.hslf.usermodel.HSLFShape
    public void afterInsert(HSLFSheet hSLFSheet) {
        super.afterInsert(hSLFSheet);
        storeText();
        EscherTextboxWrapper escherTextboxWrapper = getEscherTextboxWrapper();
        if (escherTextboxWrapper != null) {
            getSpContainer().addChildRecord(escherTextboxWrapper.getEscherRecord());
            hSLFSheet.getPPDrawing().addTextboxWrapper(escherTextboxWrapper);
            try {
                escherTextboxWrapper.writeOut(null);
                boolean equals = getAnchor().equals(new Rectangle2D.Double());
                boolean z = !"".equals(getText());
                if (equals && z) {
                    resizeToFitText();
                }
            } catch (IOException e2) {
                throw new HSLFException(e2);
            }
        }
        for (HSLFTextParagraph hSLFTextParagraph : this._paragraphs) {
            hSLFTextParagraph.setShapeId(getShapeId());
        }
        hSLFSheet.onAddTextShape(this);
    }

    /* JADX WARN: Multi-variable type inference failed */
    /* JADX WARN: Type inference failed for: r1v2, types: [org.apache.poi.hslf.usermodel.HSLFSheet] */
    /* JADX WARN: Type inference failed for: r1v7, types: [org.apache.poi.hslf.usermodel.HSLFMasterSheet] */
    /* JADX WARNING: Unknown variable types count: 2 */
    public HSLFTextAnchor getAlignment() {
        HSLFTextAnchor hSLFTextAnchor;
        EscherSimpleProperty escherSimpleProperty = (EscherSimpleProperty) HSLFShape.getEscherProperty(getEscherOptRecord(), 135);
        HSLFTextAnchor hSLFTextAnchor2 = HSLFTextAnchor.TOP;
        if (escherSimpleProperty == null) {
            int runType = getRunType();
            ?? sheet = getSheet();
            HSLFTextShape hSLFTextShape = null;
            HSLFSheet masterSheet = sheet != 0 ? sheet.getMasterSheet() : null;
            if (masterSheet != null) {
                hSLFTextShape = masterSheet.getPlaceholderByTextType(runType);
            }
            if (hSLFTextShape != null && runType != 4) {
                hSLFTextAnchor = hSLFTextShape.getAlignment();
            } else if (runType == 0 || runType == 6) {
                hSLFTextAnchor = HSLFTextAnchor.MIDDLE;
            } else {
                hSLFTextAnchor = HSLFTextAnchor.TOP;
            }
        } else {
            hSLFTextAnchor = HSLFTextAnchor.fromNativeId(escherSimpleProperty.getPropertyValue());
        }
        return hSLFTextAnchor == null ? HSLFTextAnchor.TOP : hSLFTextAnchor;
    }

    public double getBottomInset() {
        return getInset(132, 0.05d);
    }

    /* JADX WARN: Type inference failed for: r1v0, types: [org.apache.poi.hslf.usermodel.HSLFSheet] */
    /* JADX WARNING: Unknown variable types count: 1 */
    public EscherTextboxWrapper getEscherTextboxWrapper() {
        PPDrawing pPDrawing;
        EscherTextboxWrapper[] textboxWrappers;
        EscherTextboxWrapper escherTextboxWrapper = this._txtbox;
        if (escherTextboxWrapper != null) {
            return escherTextboxWrapper;
        }
        EscherTextboxRecord escherTextboxRecord = (EscherTextboxRecord) getEscherChild(-4083);
        if (escherTextboxRecord == null) {
            return null;
        }
        ?? sheet = getSheet();
        if (!(sheet == 0 || (pPDrawing = sheet.getPPDrawing()) == null || (textboxWrappers = pPDrawing.getTextboxWrappers()) == null)) {
            for (EscherTextboxWrapper escherTextboxWrapper2 : textboxWrappers) {
                if (escherTextboxRecord == escherTextboxWrapper2.getEscherRecord()) {
                    this._txtbox = escherTextboxWrapper2;
                    return escherTextboxWrapper2;
                }
            }
        }
        EscherTextboxWrapper escherTextboxWrapper3 = new EscherTextboxWrapper(escherTextboxRecord);
        this._txtbox = escherTextboxWrapper3;
        return escherTextboxWrapper3;
    }

    public RoundTripHFPlaceholder12 getHFPlaceholderAtom() {
        return (RoundTripHFPlaceholder12) getClientDataRecord(RecordTypes.RoundTripHFPlaceholder12.typeID);
    }

    public List<HSLFHyperlink> getHyperlinks() {
        return HSLFHyperlink.find(this);
    }

    @Override // org.apache.poi.sl.usermodel.TextShape
    public Insets2D getInsets() {
        return new Insets2D(getTopInset(), getLeftInset(), getBottomInset(), getRightInset());
    }

    public double getLeftInset() {
        return getInset(129, 0.1d);
    }

    public TextShape<?, ? extends TextParagraph<?, ?, ? extends TextRun>> getMetroShape() {
        return (TextShape) new HSLFMetroShape(this).getShape();
    }

    public OEPlaceholderAtom getPlaceholderAtom() {
        return (OEPlaceholderAtom) getClientDataRecord(RecordTypes.OEPlaceholderAtom.typeID);
    }

    public String getRawText() {
        return HSLFTextParagraph.getRawText(getTextParagraphs());
    }

    public double getRightInset() {
        return getInset(131, 0.1d);
    }

    /* JADX WARN: Type inference failed for: r2v0, types: [org.apache.poi.hslf.usermodel.HSLFSheet] */
    /* JADX WARNING: Unknown variable types count: 1 */
    public int getRunType() {
        getEscherTextboxWrapper();
        EscherTextboxWrapper escherTextboxWrapper = this._txtbox;
        if (escherTextboxWrapper == null) {
            return -1;
        }
        List<HSLFTextParagraph> findTextParagraphs = HSLFTextParagraph.findTextParagraphs(escherTextboxWrapper, (HSLFSheet) getSheet());
        if (findTextParagraphs.isEmpty()) {
            return -1;
        }
        return findTextParagraphs.get(0).getRunType();
    }

    @Override // org.apache.poi.sl.usermodel.TextShape
    public String getText() {
        return HSLFTextParagraph.toExternalString(getRawText(), getRunType());
    }

    @Override // org.apache.poi.sl.usermodel.TextShape
    public TextShape.TextDirection getTextDirection() {
        int i2;
        EscherSimpleProperty escherSimpleProperty = (EscherSimpleProperty) HSLFShape.getEscherProperty(getEscherOptRecord(), 136);
        if (escherSimpleProperty == null) {
            i2 = 0;
        } else {
            i2 = escherSimpleProperty.getPropertyValue();
        }
        if (i2 != 1) {
            if (i2 == 2) {
                return TextShape.TextDirection.VERTICAL_270;
            }
            if (!(i2 == 3 || i2 == 5)) {
                return TextShape.TextDirection.HORIZONTAL;
            }
        }
        return TextShape.TextDirection.VERTICAL;
    }

    @Override // org.apache.poi.sl.usermodel.TextShape
    public double getTextHeight() {
        return getTextHeight(null);
    }

    public int getTextId() {
        EscherSimpleProperty escherSimpleProperty = (EscherSimpleProperty) HSLFShape.getEscherProperty(getEscherOptRecord(), 128);
        if (escherSimpleProperty == null) {
            return 0;
        }
        return escherSimpleProperty.getPropertyValue();
    }

    /* Return type fixed from 'java.util.List<org.apache.poi.hslf.usermodel.HSLFTextParagraph>' to match base method */
    /* JADX WARN: Type inference failed for: r1v3, types: [org.apache.poi.hslf.usermodel.HSLFSheet] */
    /* JADX WARNING: Unknown variable types count: 1 */
    @Override // org.apache.poi.sl.usermodel.TextShape
    public List<? extends TextParagraph<HSLFShape, HSLFTextParagraph, ?>> getTextParagraphs() {
        if (!this._paragraphs.isEmpty()) {
            return this._paragraphs;
        }
        EscherTextboxWrapper escherTextboxWrapper = getEscherTextboxWrapper();
        this._txtbox = escherTextboxWrapper;
        if (escherTextboxWrapper == null) {
            this._txtbox = new EscherTextboxWrapper();
            createEmptyParagraph();
        } else {
            List<HSLFTextParagraph> findTextParagraphs = HSLFTextParagraph.findTextParagraphs(escherTextboxWrapper, (HSLFSheet) getSheet());
            if (findTextParagraphs == null) {
                createEmptyParagraph();
            } else {
                this._paragraphs = findTextParagraphs;
            }
            if (this._paragraphs.isEmpty()) {
                LOG.log(5, "TextRecord didn't contained any text lines");
            }
        }
        for (HSLFTextParagraph hSLFTextParagraph : this._paragraphs) {
            hSLFTextParagraph.setParentShape(this);
        }
        return this._paragraphs;
    }

    @Override // org.apache.poi.sl.usermodel.TextShape
    public TextShape.TextPlaceholder getTextPlaceholder() {
        int runType = getRunType();
        if (runType == 0) {
            return TextShape.TextPlaceholder.TITLE;
        }
        if (runType == 2) {
            return TextShape.TextPlaceholder.NOTES;
        }
        switch (runType) {
            case 4:
                return TextShape.TextPlaceholder.OTHER;
            case 5:
                return TextShape.TextPlaceholder.CENTER_BODY;
            case 6:
                return TextShape.TextPlaceholder.CENTER_TITLE;
            case 7:
                return TextShape.TextPlaceholder.HALF_BODY;
            case 8:
                return TextShape.TextPlaceholder.QUARTER_BODY;
            default:
                return TextShape.TextPlaceholder.BODY;
        }
    }

    @Override // org.apache.poi.sl.usermodel.TextShape
    public Double getTextRotation() {
        EscherSimpleProperty escherSimpleProperty = (EscherSimpleProperty) HSLFShape.getEscherProperty(getEscherOptRecord(), 137);
        if (escherSimpleProperty == null) {
            return null;
        }
        return Double.valueOf(((double) escherSimpleProperty.getPropertyValue()) * 90.0d);
    }

    public double getTopInset() {
        return getInset(130, 0.05d);
    }

    @Override // org.apache.poi.sl.usermodel.TextShape
    public VerticalAlignment getVerticalAlignment() {
        return getAlignment().vAlign;
    }

    @Override // org.apache.poi.sl.usermodel.TextShape
    public boolean getWordWrap() {
        return getWordWrapEx() != 2;
    }

    public int getWordWrapEx() {
        EscherSimpleProperty escherSimpleProperty = (EscherSimpleProperty) HSLFShape.getEscherProperty(getEscherOptRecord(), 133);
        if (escherSimpleProperty == null) {
            return 0;
        }
        return escherSimpleProperty.getPropertyValue();
    }

    public boolean isAlignToBaseline() {
        return getAlignment().baseline.booleanValue();
    }

    @Override // org.apache.poi.sl.usermodel.TextShape
    public boolean isHorizontalCentered() {
        return getAlignment().centered;
    }

    @Override // org.apache.poi.hslf.usermodel.HSLFShape
    public boolean isPlaceholder() {
        if (getPlaceholderAtom() == null && getHFPlaceholderAtom() == null) {
            return false;
        }
        return true;
    }

    @Override // java.lang.Iterable
    public Iterator<HSLFTextParagraph> iterator() {
        return this._paragraphs.iterator();
    }

    @Override // org.apache.poi.sl.usermodel.TextShape
    public Rectangle2D resizeToFitText() {
        return resizeToFitText(null);
    }

    public void setAlignToBaseline(boolean z) {
        setAlignment(Boolean.valueOf(isHorizontalCentered()), getVerticalAlignment(), z);
    }

    public void setAlignment(Boolean bool, VerticalAlignment verticalAlignment, boolean z) {
        Boolean bool2;
        HSLFTextAnchor[] values = HSLFTextAnchor.values();
        for (HSLFTextAnchor hSLFTextAnchor : values) {
            if (hSLFTextAnchor.centered == (bool != null && bool.booleanValue()) && hSLFTextAnchor.vAlign == verticalAlignment && ((bool2 = hSLFTextAnchor.baseline) == null || bool2.booleanValue() == z)) {
                setEscherProperty(135, hSLFTextAnchor.nativeId);
                return;
            }
        }
    }

    public void setBottomInset(double d2) {
        setInset(132, d2);
    }

    public void setDefaultTextProperties(HSLFTextParagraph hSLFTextParagraph) {
    }

    @Override // org.apache.poi.sl.usermodel.TextShape
    public void setHorizontalCentered(Boolean bool) {
        setAlignment(bool, getVerticalAlignment(), getAlignment().baseline.booleanValue());
    }

    @Override // org.apache.poi.sl.usermodel.TextShape
    public void setInsets(Insets2D insets2D) {
        setTopInset(insets2D.top);
        setLeftInset(insets2D.left);
        setBottomInset(insets2D.bottom);
        setRightInset(insets2D.right);
    }

    public void setLeftInset(double d2) {
        setInset(129, d2);
    }

    public void setRightInset(double d2) {
        setInset(131, d2);
    }

    /* JADX WARN: Type inference failed for: r1v0, types: [org.apache.poi.hslf.usermodel.HSLFSheet] */
    /* JADX WARNING: Unknown variable types count: 1 */
    public void setRunType(int i2) {
        getEscherTextboxWrapper();
        EscherTextboxWrapper escherTextboxWrapper = this._txtbox;
        if (escherTextboxWrapper != null) {
            List<HSLFTextParagraph> findTextParagraphs = HSLFTextParagraph.findTextParagraphs(escherTextboxWrapper, (HSLFSheet) getSheet());
            if (!findTextParagraphs.isEmpty()) {
                findTextParagraphs.get(0).setRunType(i2);
            }
        }
    }

    @Override // org.apache.poi.hslf.usermodel.HSLFShape
    public void setSheet(HSLFSheet hSLFSheet) {
        super.setSheet(hSLFSheet);
        HSLFTextParagraph.supplySheet(getTextParagraphs(), hSLFSheet);
    }

    @Override // org.apache.poi.sl.usermodel.TextShape
    public void setTextDirection(TextShape.TextDirection textDirection) {
        AbstractEscherOptRecord escherOptRecord = getEscherOptRecord();
        int i2 = -1;
        if (textDirection != null) {
            int ordinal = textDirection.ordinal();
            if (ordinal == 0) {
                i2 = 0;
            } else if (ordinal == 1) {
                i2 = 1;
            } else if (ordinal == 2) {
                i2 = 2;
            }
        }
        HSLFShape.setEscherProperty(escherOptRecord, 136, i2);
    }

    public void setTextId(int i2) {
        setEscherProperty(128, i2);
    }

    @Override // org.apache.poi.sl.usermodel.TextShape
    public void setTextPlaceholder(TextShape.TextPlaceholder textPlaceholder) {
        int i2;
        int ordinal = textPlaceholder.ordinal();
        Placeholder placeholder = null;
        if (ordinal != 0) {
            switch (ordinal) {
                case 2:
                    i2 = 6;
                    placeholder = Placeholder.TITLE;
                    break;
                case 3:
                    i2 = 5;
                    placeholder = Placeholder.BODY;
                    break;
                case 4:
                    i2 = 7;
                    placeholder = Placeholder.BODY;
                    break;
                case 5:
                    i2 = 8;
                    placeholder = Placeholder.BODY;
                    break;
                case 6:
                    i2 = 2;
                    break;
                case 7:
                    i2 = 4;
                    break;
                default:
                    i2 = 1;
                    placeholder = Placeholder.BODY;
                    break;
            }
        } else {
            i2 = 0;
            placeholder = Placeholder.TITLE;
        }
        setRunType(i2);
        if (placeholder != null) {
            setPlaceholder(placeholder);
        }
    }

    @Override // org.apache.poi.sl.usermodel.TextShape
    public void setTextRotation(Double d2) {
        AbstractEscherOptRecord escherOptRecord = getEscherOptRecord();
        if (d2 == null) {
            escherOptRecord.removeEscherProperty(137);
        } else {
            setEscherProperty(137, (int) (Math.round(d2.doubleValue() / 90.0d) % 4));
        }
    }

    public void setTopInset(double d2) {
        setInset(130, d2);
    }

    @Override // org.apache.poi.sl.usermodel.TextShape
    public void setVerticalAlignment(VerticalAlignment verticalAlignment) {
        setAlignment(Boolean.valueOf(isHorizontalCentered()), verticalAlignment, getAlignment().baseline.booleanValue());
    }

    @Override // org.apache.poi.sl.usermodel.TextShape
    public void setWordWrap(boolean z) {
        setWordWrapEx(z ? 0 : 2);
    }

    public void setWordWrapEx(int i2) {
        setEscherProperty(133, i2);
    }

    public void storeText() {
        HSLFTextParagraph.storeText(getTextParagraphs());
    }

    @Override // org.apache.poi.sl.usermodel.TextShape
    public HSLFTextRun appendText(String str, boolean z) {
        HSLFTextRun appendText = HSLFTextParagraph.appendText(getTextParagraphs(), str, z);
        setTextId(getRawText().hashCode());
        return appendText;
    }

    @Override // org.apache.poi.sl.usermodel.TextShape
    public double getTextHeight(Graphics2D graphics2D) {
        return DrawFactory.getInstance(graphics2D).getDrawable((TextShape<?, ?>) this).getTextHeight(graphics2D);
    }

    @Override // org.apache.poi.sl.usermodel.TextShape
    public Rectangle2D resizeToFitText(Graphics2D graphics2D) {
        Rectangle2D anchor = getAnchor();
        if (anchor.getWidth() == NumericFunction.LOG_10_TO_BASE_e) {
            LOG.log(5, "Width of shape wasn't set. Defaulting to 200px");
            anchor.setRect(anchor.getX(), anchor.getY(), 200.0d, anchor.getHeight());
            setAnchor(anchor);
        }
        Insets2D insets = getInsets();
        anchor.setRect(anchor.getX(), anchor.getY(), anchor.getWidth(), insets.bottom + getTextHeight(graphics2D) + 1.0d + insets.top);
        setAnchor(anchor);
        return anchor;
    }

    @Override // org.apache.poi.sl.usermodel.TextShape
    public HSLFTextRun setText(String str) {
        HSLFTextRun text = HSLFTextParagraph.setText(getTextParagraphs(), str);
        setTextId(getRawText().hashCode());
        return text;
    }

    public HSLFTextShape(ShapeContainer<HSLFShape, HSLFTextParagraph> shapeContainer) {
        super(null, shapeContainer);
        this._paragraphs = new ArrayList();
        createSpContainer(shapeContainer instanceof HSLFGroupShape);
    }

    public HSLFTextShape() {
        this(null);
    }
}
