package org.apache.poi.hsmf.parsers;

import b.b.a.a.a;
import java.io.IOException;
import java.util.ArrayList;
import java.util.Iterator;
import org.apache.poi.hsmf.datatypes.AttachmentChunks;
import org.apache.poi.hsmf.datatypes.ByteChunk;
import org.apache.poi.hsmf.datatypes.Chunk;
import org.apache.poi.hsmf.datatypes.ChunkGroup;
import org.apache.poi.hsmf.datatypes.Chunks;
import org.apache.poi.hsmf.datatypes.DirectoryChunk;
import org.apache.poi.hsmf.datatypes.MAPIProperty;
import org.apache.poi.hsmf.datatypes.MessagePropertiesChunk;
import org.apache.poi.hsmf.datatypes.MessageSubmissionChunk;
import org.apache.poi.hsmf.datatypes.NameIdChunks;
import org.apache.poi.hsmf.datatypes.PropertiesChunk;
import org.apache.poi.hsmf.datatypes.RecipientChunks;
import org.apache.poi.hsmf.datatypes.StoragePropertiesChunk;
import org.apache.poi.hsmf.datatypes.StringChunk;
import org.apache.poi.hsmf.datatypes.Types;
import org.apache.poi.poifs.filesystem.DirectoryNode;
import org.apache.poi.poifs.filesystem.DocumentInputStream;
import org.apache.poi.poifs.filesystem.DocumentNode;
import org.apache.poi.poifs.filesystem.Entry;
import org.apache.poi.poifs.filesystem.NPOIFSFileSystem;
import org.apache.poi.util.POILogFactory;
import org.apache.poi.util.POILogger;

public final class POIFSChunkParser {
    public static final POILogger logger = POILogFactory.getLogger(POIFSChunkParser.class);

    public static ChunkGroup[] parse(NPOIFSFileSystem nPOIFSFileSystem) {
        return parse(nPOIFSFileSystem.getRoot());
    }

    /* JADX WARNING: Removed duplicated region for block: B:57:0x00fb  */
    /* JADX WARNING: Removed duplicated region for block: B:60:0x0102  */
    /* JADX WARNING: Removed duplicated region for block: B:70:? A[RETURN, SYNTHETIC] */
    public static void process(Entry entry, ChunkGroup chunkGroup) {
        Chunk chunk;
        Throwable th;
        IOException e2;
        String name = entry.getName();
        DocumentInputStream documentInputStream = null;
        if (name.equals(PropertiesChunk.NAME)) {
            if (chunkGroup instanceof Chunks) {
                chunk = new MessagePropertiesChunk(chunkGroup);
            } else {
                chunk = new StoragePropertiesChunk(chunkGroup);
            }
        } else if (name.length() >= 9 && name.contains("_")) {
            int lastIndexOf = name.lastIndexOf(95);
            int i2 = lastIndexOf + 1;
            String substring = name.substring(0, i2);
            String substring2 = name.substring(i2);
            if (!substring.equals("Olk10SideProps") && !substring.equals("Olk10SideProps_")) {
                if (lastIndexOf <= name.length() - 8) {
                    try {
                        int parseInt = Integer.parseInt(substring2.substring(0, 4), 16);
                        int parseInt2 = Integer.parseInt(substring2.substring(4, 8), 16);
                        Types.MAPIType byId = Types.getById(parseInt2);
                        if (byId == null) {
                            byId = Types.createCustom(parseInt2);
                        }
                        if (parseInt == MAPIProperty.MESSAGE_SUBMISSION_ID.id) {
                            chunk = new MessageSubmissionChunk(substring, parseInt, byId);
                        } else if (byId == Types.BINARY) {
                            chunk = new ByteChunk(substring, parseInt, byId);
                        } else {
                            if (byId != Types.DIRECTORY) {
                                if (byId != Types.ASCII_STRING) {
                                    if (byId == Types.UNICODE_STRING) {
                                    }
                                }
                                chunk = new StringChunk(substring, parseInt, byId);
                            } else if (entry instanceof DirectoryNode) {
                                chunk = new DirectoryChunk((DirectoryNode) entry, substring, parseInt, byId);
                            }
                            chunk = null;
                        }
                    } catch (NumberFormatException unused) {
                        return;
                    }
                } else {
                    throw new IllegalArgumentException(a.b("Invalid chunk name ", name));
                }
            } else {
                return;
            }
        } else {
            return;
        }
        if (chunk == null) {
            return;
        }
        if (entry instanceof DocumentNode) {
            try {
                DocumentInputStream documentInputStream2 = new DocumentInputStream((DocumentNode) entry);
                try {
                    chunk.readValue(documentInputStream2);
                    chunkGroup.record(chunk);
                    documentInputStream2.close();
                } catch (IOException e3) {
                    e2 = e3;
                    documentInputStream = documentInputStream2;
                    try {
                        logger.log(7, "Error reading from part " + entry.getName() + " - " + e2);
                        if (documentInputStream == null) {
                            documentInputStream.close();
                        }
                    } catch (Throwable th2) {
                        th = th2;
                        documentInputStream2 = documentInputStream;
                        if (documentInputStream2 != null) {
                        }
                        throw th;
                    }
                } catch (Throwable th3) {
                    th = th3;
                    if (documentInputStream2 != null) {
                        documentInputStream2.close();
                    }
                    throw th;
                }
            } catch (IOException e4) {
                e2 = e4;
                logger.log(7, "Error reading from part " + entry.getName() + " - " + e2);
                if (documentInputStream == null) {
                }
            }
        } else {
            chunkGroup.record(chunk);
        }
    }

    public static void processChunks(DirectoryNode directoryNode, ChunkGroup chunkGroup) {
        Iterator<Entry> it = directoryNode.iterator();
        while (it.hasNext()) {
            Entry next = it.next();
            if (next instanceof DocumentNode) {
                process(next, chunkGroup);
            } else if ((next instanceof DirectoryNode) && next.getName().endsWith(Types.DIRECTORY.asFileEnding())) {
                process(next, chunkGroup);
            }
        }
    }

    public static ChunkGroup[] parse(DirectoryNode directoryNode) {
        Chunks chunks = new Chunks();
        ArrayList arrayList = new ArrayList();
        arrayList.add(chunks);
        Iterator<Entry> it = directoryNode.iterator();
        while (it.hasNext()) {
            Entry next = it.next();
            if (next instanceof DirectoryNode) {
                DirectoryNode directoryNode2 = (DirectoryNode) next;
                ChunkGroup chunkGroup = null;
                if (directoryNode2.getName().startsWith(AttachmentChunks.PREFIX)) {
                    chunkGroup = new AttachmentChunks(directoryNode2.getName());
                }
                if (directoryNode2.getName().startsWith(NameIdChunks.NAME)) {
                    chunkGroup = new NameIdChunks();
                }
                if (directoryNode2.getName().startsWith(RecipientChunks.PREFIX)) {
                    chunkGroup = new RecipientChunks(directoryNode2.getName());
                }
                if (chunkGroup != null) {
                    processChunks(directoryNode2, chunkGroup);
                    arrayList.add(chunkGroup);
                }
            }
        }
        processChunks(directoryNode, chunks);
        Iterator it2 = arrayList.iterator();
        while (it2.hasNext()) {
            ((ChunkGroup) it2.next()).chunksComplete();
        }
        return (ChunkGroup[]) arrayList.toArray(new ChunkGroup[arrayList.size()]);
    }
}
