package org.apache.poi.hssf.converter;

import org.apache.poi.hssf.usermodel.HSSFCell;
import org.apache.poi.hssf.usermodel.HSSFCellStyle;
import org.apache.poi.hssf.usermodel.HSSFDataFormatter;
import org.apache.poi.hssf.usermodel.HSSFRichTextString;
import org.apache.poi.hssf.usermodel.HSSFRow;
import org.apache.poi.hssf.usermodel.HSSFSheet;
import org.apache.poi.hwpf.converter.DefaultFontReplacer;
import org.apache.poi.hwpf.converter.FontReplacer;
import org.apache.poi.hwpf.converter.NumberFormatter;
import org.apache.poi.ss.formula.eval.ErrorEval;
import org.apache.poi.ss.usermodel.CellType;
import org.w3c.dom.Document;

public abstract class AbstractExcelConverter {
    public final HSSFDataFormatter _formatter = new HSSFDataFormatter();
    public FontReplacer fontReplacer = new DefaultFontReplacer();
    public boolean outputColumnHeaders = true;
    public boolean outputHiddenColumns = false;
    public boolean outputHiddenRows = false;
    public boolean outputLeadingSpacesAsNonBreaking = true;
    public boolean outputRowNumbers = true;

    /* renamed from: org.apache.poi.hssf.converter.AbstractExcelConverter$1  reason: invalid class name */
    public static /* synthetic */ class AnonymousClass1 {
        public static final /* synthetic */ int[] $SwitchMap$org$apache$poi$ss$usermodel$CellType;

        /* JADX WARNING: Can't wrap try/catch for region: R(16:0|1|2|3|4|5|7|8|9|11|12|13|14|15|16|18) */
        /* JADX WARNING: Code restructure failed: missing block: B:19:?, code lost:
            return;
         */
        /* JADX WARNING: Failed to process nested try/catch */
        /* JADX WARNING: Missing exception handler attribute for start block: B:13:0x0025 */
        /* JADX WARNING: Missing exception handler attribute for start block: B:15:0x002b */
        /* JADX WARNING: Missing exception handler attribute for start block: B:3:0x000f */
        static {
            int[] iArr = new int[CellType.values().length];
            $SwitchMap$org$apache$poi$ss$usermodel$CellType = iArr;
            CellType cellType = CellType.STRING;
            iArr[2] = 1;
            try {
                int[] iArr2 = $SwitchMap$org$apache$poi$ss$usermodel$CellType;
                CellType cellType2 = CellType.NUMERIC;
                iArr2[1] = 2;
            } catch (NoSuchFieldError unused) {
            }
            try {
                int[] iArr3 = $SwitchMap$org$apache$poi$ss$usermodel$CellType;
                CellType cellType3 = CellType.BOOLEAN;
                iArr3[5] = 3;
            } catch (NoSuchFieldError unused2) {
            }
            int[] iArr4 = $SwitchMap$org$apache$poi$ss$usermodel$CellType;
            CellType cellType4 = CellType.ERROR;
            iArr4[6] = 4;
            int[] iArr5 = $SwitchMap$org$apache$poi$ss$usermodel$CellType;
            CellType cellType5 = CellType.FORMULA;
            iArr5[3] = 5;
            int[] iArr6 = $SwitchMap$org$apache$poi$ss$usermodel$CellType;
            CellType cellType6 = CellType.BLANK;
            iArr6[4] = 6;
        }
    }

    public static int getColumnWidth(HSSFSheet hSSFSheet, int i2) {
        return AbstractExcelUtils.getColumnWidthInPx(hSSFSheet.getColumnWidth(i2));
    }

    public static int getDefaultColumnWidth(HSSFSheet hSSFSheet) {
        return AbstractExcelUtils.getColumnWidthInPx(hSSFSheet.getDefaultColumnWidth());
    }

    public String getColumnName(int i2) {
        return NumberFormatter.getNumber(i2 + 1, 3);
    }

    public abstract Document getDocument();

    public FontReplacer getFontReplacer() {
        return this.fontReplacer;
    }

    public String getRowName(HSSFRow hSSFRow) {
        return String.valueOf(hSSFRow.getRowNum() + 1);
    }

    public boolean isOutputColumnHeaders() {
        return this.outputColumnHeaders;
    }

    public boolean isOutputHiddenColumns() {
        return this.outputHiddenColumns;
    }

    public boolean isOutputHiddenRows() {
        return this.outputHiddenRows;
    }

    public boolean isOutputLeadingSpacesAsNonBreaking() {
        return this.outputLeadingSpacesAsNonBreaking;
    }

    public boolean isOutputRowNumbers() {
        return this.outputRowNumbers;
    }

    public boolean isTextEmpty(HSSFCell hSSFCell) {
        String str;
        String str2 = "";
        switch (hSSFCell.getCellTypeEnum().ordinal()) {
            case 1:
                str2 = this._formatter.formatCellValue(hSSFCell);
                break;
            case 2:
                str2 = hSSFCell.getRichStringCellValue().getString();
                break;
            case 3:
                int ordinal = hSSFCell.getCachedFormulaResultTypeEnum().ordinal();
                if (ordinal == 1) {
                    HSSFCellStyle cellStyle = hSSFCell.getCellStyle();
                    str = this._formatter.formatRawCellContents(hSSFCell.getNumericCellValue(), cellStyle.getDataFormat(), cellStyle.getDataFormatString());
                } else if (ordinal == 2) {
                    HSSFRichTextString richStringCellValue = hSSFCell.getRichStringCellValue();
                    if (richStringCellValue == null || richStringCellValue.length() <= 0) {
                        return false;
                    }
                    str = richStringCellValue.toString();
                } else if (ordinal == 5) {
                    str = String.valueOf(hSSFCell.getBooleanCellValue());
                } else if (ordinal == 6) {
                    str = ErrorEval.getText(hSSFCell.getErrorCellValue());
                }
                str2 = str;
                break;
            case 4:
                break;
            case 5:
                str2 = String.valueOf(hSSFCell.getBooleanCellValue());
                break;
            case 6:
                str2 = ErrorEval.getText(hSSFCell.getErrorCellValue());
                break;
            default:
                return true;
        }
        return AbstractExcelUtils.isEmpty(str2);
    }

    public void setFontReplacer(FontReplacer fontReplacer2) {
        this.fontReplacer = fontReplacer2;
    }

    public void setOutputColumnHeaders(boolean z) {
        this.outputColumnHeaders = z;
    }

    public void setOutputHiddenColumns(boolean z) {
        this.outputHiddenColumns = z;
    }

    public void setOutputHiddenRows(boolean z) {
        this.outputHiddenRows = z;
    }

    public void setOutputLeadingSpacesAsNonBreaking(boolean z) {
        this.outputLeadingSpacesAsNonBreaking = z;
    }

    public void setOutputRowNumbers(boolean z) {
        this.outputRowNumbers = z;
    }
}
