package org.apache.poi.hssf.converter;

import b.b.a.a.a;
import java.io.File;
import java.io.PrintStream;
import java.util.ArrayList;
import java.util.Iterator;
import javax.xml.transform.OutputKeys;
import javax.xml.transform.Transformer;
import javax.xml.transform.TransformerFactory;
import javax.xml.transform.dom.DOMSource;
import javax.xml.transform.stream.StreamResult;
import org.apache.poi.hpsf.SummaryInformation;
import org.apache.poi.hssf.usermodel.HSSFCell;
import org.apache.poi.hssf.usermodel.HSSFCellStyle;
import org.apache.poi.hssf.usermodel.HSSFFont;
import org.apache.poi.hssf.usermodel.HSSFRichTextString;
import org.apache.poi.hssf.usermodel.HSSFRow;
import org.apache.poi.hssf.usermodel.HSSFSheet;
import org.apache.poi.hssf.usermodel.HSSFWorkbook;
import org.apache.poi.hssf.util.HSSFColor;
import org.apache.poi.hwpf.converter.AbstractWordConverter;
import org.apache.poi.hwpf.converter.FoDocumentFacade;
import org.apache.poi.hwpf.converter.FontReplacer;
import org.apache.poi.ss.formula.eval.ErrorEval;
import org.apache.poi.ss.usermodel.BorderStyle;
import org.apache.poi.ss.usermodel.CellStyle;
import org.apache.poi.ss.usermodel.CellType;
import org.apache.poi.ss.util.CellRangeAddress;
import org.apache.poi.ss.util.CellUtil;
import org.apache.poi.util.POILogFactory;
import org.apache.poi.util.POILogger;
import org.apache.poi.util.XMLHelper;
import org.apache.xerces.impl.xs.SchemaSymbols;
import org.w3c.dom.Document;
import org.w3c.dom.Element;
import org.w3c.dom.Node;
import org.w3c.dom.Text;

public class ExcelToFoConverter extends AbstractExcelConverter {
    public static final float CM_PER_INCH = 2.54f;
    public static final float DPI = 72.0f;
    public static final float PAPER_A4_HEIGHT_INCHES = 11.574803f;
    public static final float PAPER_A4_WIDTH_INCHES = 8.267716f;
    public static final POILogger logger = POILogFactory.getLogger(ExcelToFoConverter.class);
    public final FoDocumentFacade foDocumentFacade;
    public float pageMarginInches = 0.4f;

    /* renamed from: org.apache.poi.hssf.converter.ExcelToFoConverter$1  reason: invalid class name */
    public static /* synthetic */ class AnonymousClass1 {
        public static final /* synthetic */ int[] $SwitchMap$org$apache$poi$ss$usermodel$CellType;

        /* JADX WARNING: Can't wrap try/catch for region: R(16:0|1|2|3|4|5|7|8|9|11|12|13|14|15|16|18) */
        /* JADX WARNING: Code restructure failed: missing block: B:19:?, code lost:
            return;
         */
        /* JADX WARNING: Failed to process nested try/catch */
        /* JADX WARNING: Missing exception handler attribute for start block: B:13:0x0025 */
        /* JADX WARNING: Missing exception handler attribute for start block: B:15:0x002b */
        /* JADX WARNING: Missing exception handler attribute for start block: B:3:0x000f */
        static {
            int[] iArr = new int[CellType.values().length];
            $SwitchMap$org$apache$poi$ss$usermodel$CellType = iArr;
            CellType cellType = CellType.STRING;
            iArr[2] = 1;
            try {
                int[] iArr2 = $SwitchMap$org$apache$poi$ss$usermodel$CellType;
                CellType cellType2 = CellType.NUMERIC;
                iArr2[1] = 2;
            } catch (NoSuchFieldError unused) {
            }
            try {
                int[] iArr3 = $SwitchMap$org$apache$poi$ss$usermodel$CellType;
                CellType cellType3 = CellType.BOOLEAN;
                iArr3[5] = 3;
            } catch (NoSuchFieldError unused2) {
            }
            int[] iArr4 = $SwitchMap$org$apache$poi$ss$usermodel$CellType;
            CellType cellType4 = CellType.ERROR;
            iArr4[6] = 4;
            int[] iArr5 = $SwitchMap$org$apache$poi$ss$usermodel$CellType;
            CellType cellType5 = CellType.FORMULA;
            iArr5[3] = 5;
            int[] iArr6 = $SwitchMap$org$apache$poi$ss$usermodel$CellType;
            CellType cellType6 = CellType.BLANK;
            iArr6[4] = 6;
        }
    }

    public ExcelToFoConverter(Document document) {
        this.foDocumentFacade = new FoDocumentFacade(document);
    }

    public static void main(String[] strArr) {
        if (strArr.length < 2) {
            System.err.println("Usage: ExcelToFoConverter <inputFile.xls> <saveTo.xml>");
            return;
        }
        PrintStream printStream = System.out;
        StringBuilder b2 = a.b("Converting ");
        b2.append(strArr[0]);
        printStream.println(b2.toString());
        PrintStream printStream2 = System.out;
        StringBuilder b3 = a.b("Saving output to ");
        b3.append(strArr[1]);
        printStream2.println(b3.toString());
        DOMSource dOMSource = new DOMSource(ExcelToHtmlConverter.process(new File(strArr[0])));
        StreamResult streamResult = new StreamResult(new File(strArr[1]));
        Transformer newTransformer = TransformerFactory.newInstance().newTransformer();
        newTransformer.setOutputProperty(OutputKeys.ENCODING, "UTF-8");
        newTransformer.setOutputProperty(OutputKeys.INDENT, "no");
        newTransformer.setOutputProperty("method", "xml");
        newTransformer.transform(dOMSource, streamResult);
    }

    public static Document process(File file) {
        HSSFWorkbook loadXls = AbstractExcelUtils.loadXls(file);
        try {
            ExcelToFoConverter excelToFoConverter = new ExcelToFoConverter(XMLHelper.getDocumentBuilderFactory().newDocumentBuilder().newDocument());
            excelToFoConverter.processWorkbook(loadXls);
            return excelToFoConverter.getDocument();
        } finally {
            loadXls.close();
        }
    }

    private void setBlockProperties(Element element, FontReplacer.Triplet triplet) {
        if (triplet.bold) {
            element.setAttribute("font-weight", "bold");
        }
        if (triplet.italic) {
            element.setAttribute("font-style", "italic");
        }
        if (AbstractExcelUtils.isNotEmpty(triplet.fontName)) {
            element.setAttribute("font-family", triplet.fontName);
        }
    }

    public String createPageMaster(float f2, String str) {
        float f3;
        float pageMarginInches2 = (getPageMarginInches() * 2.0f) + f2;
        float f4 = 8.267716f;
        if (pageMarginInches2 < 8.267716f) {
            f3 = 11.574803f;
        } else {
            f3 = 0.7142857f * pageMarginInches2;
            f4 = pageMarginInches2;
        }
        float pageMarginInches3 = getPageMarginInches();
        float pageMarginInches4 = getPageMarginInches();
        float pageMarginInches5 = getPageMarginInches();
        float pageMarginInches6 = getPageMarginInches();
        Element addSimplePageMaster = this.foDocumentFacade.addSimplePageMaster(str);
        addSimplePageMaster.setAttribute("page-height", f3 + "in");
        addSimplePageMaster.setAttribute("page-width", f4 + "in");
        Element addRegionBody = this.foDocumentFacade.addRegionBody(addSimplePageMaster);
        addRegionBody.setAttribute("margin", pageMarginInches5 + "in " + pageMarginInches4 + "in " + pageMarginInches6 + "in " + pageMarginInches3 + "in");
        return str;
    }

    @Override // org.apache.poi.hssf.converter.AbstractExcelConverter
    public Document getDocument() {
        return this.foDocumentFacade.getDocument();
    }

    public float getPageMarginInches() {
        return this.pageMarginInches;
    }

    public boolean isEmptyStyle(CellStyle cellStyle) {
        return cellStyle == null || (cellStyle.getFillPattern() == 0 && cellStyle.getBorderTopEnum() == BorderStyle.NONE && cellStyle.getBorderRightEnum() == BorderStyle.NONE && cellStyle.getBorderBottomEnum() == BorderStyle.NONE && cellStyle.getBorderLeftEnum() == BorderStyle.NONE);
    }

    public boolean processCell(HSSFWorkbook hSSFWorkbook, HSSFCell hSSFCell, Element element, int i2, int i3, float f2) {
        String str;
        HSSFCellStyle cellStyle = hSSFCell.getCellStyle();
        String str2 = "";
        switch (hSSFCell.getCellTypeEnum().ordinal()) {
            case 1:
                str2 = this._formatter.formatCellValue(hSSFCell);
                break;
            case 2:
                str2 = hSSFCell.getRichStringCellValue().getString();
                break;
            case 3:
                int ordinal = hSSFCell.getCachedFormulaResultTypeEnum().ordinal();
                if (ordinal == 1) {
                    str = this._formatter.formatRawCellContents(hSSFCell.getNumericCellValue(), cellStyle.getDataFormat(), cellStyle.getDataFormatString());
                } else if (ordinal == 2) {
                    HSSFRichTextString richStringCellValue = hSSFCell.getRichStringCellValue();
                    if (richStringCellValue != null && richStringCellValue.length() > 0) {
                        str = richStringCellValue.toString();
                    }
                } else if (ordinal == 5) {
                    str = Boolean.toString(hSSFCell.getBooleanCellValue());
                } else if (ordinal != 6) {
                    POILogger pOILogger = logger;
                    StringBuilder b2 = a.b("Unexpected cell cachedFormulaResultType (");
                    b2.append(hSSFCell.getCachedFormulaResultTypeEnum());
                    b2.append(")");
                    pOILogger.log(5, b2.toString());
                    break;
                } else {
                    str = ErrorEval.getText(hSSFCell.getErrorCellValue());
                }
                str2 = str;
                break;
            case 4:
                break;
            case 5:
                str2 = Boolean.toString(hSSFCell.getBooleanCellValue());
                break;
            case 6:
                str2 = ErrorEval.getText(hSSFCell.getErrorCellValue());
                break;
            default:
                POILogger pOILogger2 = logger;
                StringBuilder b3 = a.b("Unexpected cell type (");
                b3.append(hSSFCell.getCellTypeEnum());
                b3.append(")");
                pOILogger2.log(5, b3.toString());
                return true;
        }
        boolean isEmpty = AbstractExcelUtils.isEmpty(str2);
        boolean z = !isEmpty && !cellStyle.getWrapText();
        boolean isEmptyStyle = isEmptyStyle(cellStyle);
        if (!isEmptyStyle && isEmpty) {
            str2 = " ";
        }
        if (isOutputLeadingSpacesAsNonBreaking() && str2.startsWith(" ")) {
            StringBuilder sb = new StringBuilder();
            int i4 = 0;
            while (i4 < str2.length() && str2.charAt(i4) == ' ') {
                sb.append(AbstractWordConverter.UNICODECHAR_NO_BREAK_SPACE);
                i4++;
            }
            if (str2.length() != sb.length()) {
                sb.append(str2.substring(sb.length()));
            }
            str2 = sb.toString();
        }
        Text createText = this.foDocumentFacade.createText(str2);
        Element createBlock = this.foDocumentFacade.createBlock();
        if (z) {
            createBlock.setAttribute("absolute-position", "fixed");
            createBlock.setAttribute("left", "0px");
            createBlock.setAttribute("top", "0px");
            createBlock.setAttribute("bottom", "0px");
            createBlock.setAttribute("min-width", i2 + "px");
            if (i3 != Integer.MAX_VALUE) {
                createBlock.setAttribute("max-width", i3 + "px");
            }
            createBlock.setAttribute("overflow", CellUtil.HIDDEN);
            createBlock.setAttribute("height", f2 + "pt");
            createBlock.setAttribute("keep-together.within-line", "always");
            createBlock.setAttribute("wrap-option", "no-wrap");
        }
        processCellStyle(hSSFWorkbook, hSSFCell.getCellStyle(), element, createBlock);
        createBlock.appendChild(createText);
        element.appendChild(createBlock);
        if (!AbstractExcelUtils.isEmpty(str2) || !isEmptyStyle) {
            return false;
        }
        return true;
    }

    public void processCellStyle(HSSFWorkbook hSSFWorkbook, HSSFCellStyle hSSFCellStyle, Element element, Element element2) {
        element2.setAttribute("white-space-collapse", SchemaSymbols.ATTVAL_FALSE);
        String align = AbstractExcelUtils.getAlign(hSSFCellStyle.getAlignment());
        if (AbstractExcelUtils.isNotEmpty(align)) {
            element2.setAttribute("text-align", align);
        }
        if (hSSFCellStyle.getFillPattern() != 0) {
            if (hSSFCellStyle.getFillPattern() == 1) {
                HSSFColor fillForegroundColorColor = hSSFCellStyle.getFillForegroundColorColor();
                if (fillForegroundColorColor != null) {
                    element.setAttribute("background-color", AbstractExcelUtils.getColor(fillForegroundColorColor));
                }
            } else {
                HSSFColor fillBackgroundColorColor = hSSFCellStyle.getFillBackgroundColorColor();
                if (fillBackgroundColorColor != null) {
                    element.setAttribute("background-color", AbstractExcelUtils.getColor(fillBackgroundColorColor));
                }
            }
        }
        processCellStyleBorder(hSSFWorkbook, element, "top", hSSFCellStyle.getBorderTopEnum(), hSSFCellStyle.getTopBorderColor());
        processCellStyleBorder(hSSFWorkbook, element, "right", hSSFCellStyle.getBorderRightEnum(), hSSFCellStyle.getRightBorderColor());
        processCellStyleBorder(hSSFWorkbook, element, "bottom", hSSFCellStyle.getBorderBottomEnum(), hSSFCellStyle.getBottomBorderColor());
        processCellStyleBorder(hSSFWorkbook, element, "left", hSSFCellStyle.getBorderLeftEnum(), hSSFCellStyle.getLeftBorderColor());
        processCellStyleFont(hSSFWorkbook, element2, hSSFCellStyle.getFont(hSSFWorkbook));
    }

    public void processCellStyleBorder(HSSFWorkbook hSSFWorkbook, Element element, String str, BorderStyle borderStyle, short s) {
        if (borderStyle != BorderStyle.NONE) {
            StringBuilder sb = new StringBuilder();
            sb.append(AbstractExcelUtils.getBorderWidth(borderStyle));
            HSSFColor color = hSSFWorkbook.getCustomPalette().getColor(s);
            if (color != null) {
                sb.append(' ');
                sb.append(AbstractExcelUtils.getColor(color));
                sb.append(' ');
                sb.append(AbstractExcelUtils.getBorderStyle(borderStyle));
            }
            element.setAttribute(a.b("border-", str), sb.toString());
        }
    }

    public void processCellStyleFont(HSSFWorkbook hSSFWorkbook, Element element, HSSFFont hSSFFont) {
        FontReplacer.Triplet triplet = new FontReplacer.Triplet();
        triplet.fontName = hSSFFont.getFontName();
        triplet.bold = hSSFFont.getBold();
        triplet.italic = hSSFFont.getItalic();
        getFontReplacer().update(triplet);
        setBlockProperties(element, triplet);
        HSSFColor color = hSSFWorkbook.getCustomPalette().getColor(hSSFFont.getColor());
        if (color != null) {
            element.setAttribute("color", AbstractExcelUtils.getColor(color));
        }
        if (hSSFFont.getFontHeightInPoints() != 0) {
            element.setAttribute("font-size", ((int) hSSFFont.getFontHeightInPoints()) + "pt");
        }
    }

    public void processColumnHeaders(HSSFSheet hSSFSheet, int i2, Element element) {
        Node createTableHeader = this.foDocumentFacade.createTableHeader();
        Node createTableRow = this.foDocumentFacade.createTableRow();
        if (isOutputRowNumbers()) {
            Node createTableCell = this.foDocumentFacade.createTableCell();
            createTableCell.appendChild(this.foDocumentFacade.createBlock());
            createTableRow.appendChild(createTableCell);
        }
        for (int i3 = 0; i3 < i2; i3++) {
            if (isOutputHiddenColumns() || !hSSFSheet.isColumnHidden(i3)) {
                Node createTableCell2 = this.foDocumentFacade.createTableCell();
                Element createBlock = this.foDocumentFacade.createBlock();
                createBlock.setAttribute("text-align", "center");
                createBlock.setAttribute("font-weight", "bold");
                createBlock.appendChild(this.foDocumentFacade.createText(getColumnName(i3)));
                createTableCell2.appendChild(createBlock);
                createTableRow.appendChild(createTableCell2);
            }
        }
        createTableHeader.appendChild(createTableRow);
        element.appendChild(createTableHeader);
    }

    public float processColumnWidths(HSSFSheet hSSFSheet, int i2, Element element) {
        float f2 = 0.0f;
        if (isOutputRowNumbers()) {
            float defaultColumnWidth = ((float) AbstractExcelConverter.getDefaultColumnWidth(hSSFSheet)) / 72.0f;
            Element createTableColumn = this.foDocumentFacade.createTableColumn();
            createTableColumn.setAttribute("column-width", defaultColumnWidth + "in");
            element.appendChild(createTableColumn);
            f2 = 0.0f + defaultColumnWidth;
        }
        for (int i3 = 0; i3 < i2; i3++) {
            if (isOutputHiddenColumns() || !hSSFSheet.isColumnHidden(i3)) {
                float columnWidth = ((float) AbstractExcelConverter.getColumnWidth(hSSFSheet, i3)) / 72.0f;
                Element createTableColumn2 = this.foDocumentFacade.createTableColumn();
                createTableColumn2.setAttribute("column-width", columnWidth + "in");
                element.appendChild(createTableColumn2);
                f2 += columnWidth;
            }
        }
        element.setAttribute("width", f2 + "in");
        return f2;
    }

    public void processDocumentInformation(SummaryInformation summaryInformation) {
        if (AbstractExcelUtils.isNotEmpty(summaryInformation.getTitle())) {
            this.foDocumentFacade.setTitle(summaryInformation.getTitle());
        }
        if (AbstractExcelUtils.isNotEmpty(summaryInformation.getAuthor())) {
            this.foDocumentFacade.setCreator(summaryInformation.getAuthor());
        }
        if (AbstractExcelUtils.isNotEmpty(summaryInformation.getKeywords())) {
            this.foDocumentFacade.setKeywords(summaryInformation.getKeywords());
        }
        if (AbstractExcelUtils.isNotEmpty(summaryInformation.getComments())) {
            this.foDocumentFacade.setDescription(summaryInformation.getComments());
        }
    }

    public int processRow(HSSFWorkbook hSSFWorkbook, CellRangeAddress[][] cellRangeAddressArr, HSSFRow hSSFRow, Element element) {
        CellRangeAddress mergedRange;
        boolean z;
        Element element2;
        HSSFRow hSSFRow2 = hSSFRow;
        HSSFSheet sheet = hSSFRow.getSheet();
        short lastCellNum = hSSFRow.getLastCellNum();
        if (lastCellNum <= 0) {
            return 0;
        }
        ArrayList arrayList = new ArrayList(lastCellNum);
        if (isOutputRowNumbers()) {
            arrayList.add(processRowNumber(hSSFRow2));
        }
        int i2 = 0;
        int i3 = 0;
        while (true) {
            boolean z2 = true;
            if (i2 >= lastCellNum) {
                return i3 + 1;
            }
            if ((isOutputHiddenColumns() || !sheet.isColumnHidden(i2)) && ((mergedRange = AbstractExcelUtils.getMergedRange(cellRangeAddressArr, hSSFRow.getRowNum(), i2)) == null || (mergedRange.getFirstColumn() == i2 && mergedRange.getFirstRow() == hSSFRow.getRowNum()))) {
                HSSFCell cell = hSSFRow2.getCell(i2);
                int columnWidth = AbstractExcelConverter.getColumnWidth(sheet, i2);
                int i4 = i2 + 1;
                while (true) {
                    if (i4 >= lastCellNum) {
                        z = false;
                        break;
                    }
                    if (isOutputHiddenColumns() || !sheet.isColumnHidden(i4)) {
                        if (hSSFRow2.getCell(i4) != null && !isTextEmpty(hSSFRow2.getCell(i4))) {
                            z = true;
                            break;
                        }
                        columnWidth = AbstractExcelConverter.getColumnWidth(sheet, i4) + columnWidth;
                    }
                    i4++;
                }
                int i5 = !z ? Integer.MAX_VALUE : columnWidth;
                Element createTableCell = this.foDocumentFacade.createTableCell();
                if (mergedRange != null) {
                    if (mergedRange.getFirstColumn() != mergedRange.getLastColumn()) {
                        createTableCell.setAttribute("number-columns-spanned", String.valueOf((mergedRange.getLastColumn() - mergedRange.getFirstColumn()) + 1));
                    }
                    if (mergedRange.getFirstRow() != mergedRange.getLastRow()) {
                        createTableCell.setAttribute("number-rows-spanned", String.valueOf((mergedRange.getLastRow() - mergedRange.getFirstRow()) + 1));
                    }
                }
                if (cell != null) {
                    element2 = createTableCell;
                    z2 = processCell(hSSFWorkbook, cell, createTableCell, AbstractExcelConverter.getColumnWidth(sheet, i2), i5, ((float) hSSFRow.getHeight()) / 20.0f);
                } else {
                    element2 = createTableCell;
                    element2.appendChild(this.foDocumentFacade.createBlock());
                }
                if (z2) {
                    arrayList.add(element2);
                } else {
                    Iterator it = arrayList.iterator();
                    while (it.hasNext()) {
                        element.appendChild((Element) it.next());
                    }
                    arrayList.clear();
                    element.appendChild(element2);
                    i3 = i2;
                }
            }
            i2++;
            hSSFRow2 = hSSFRow;
        }
    }

    public Element processRowNumber(HSSFRow hSSFRow) {
        Element createTableCell = this.foDocumentFacade.createTableCell();
        Element createBlock = this.foDocumentFacade.createBlock();
        createBlock.setAttribute("text-align", "right");
        createBlock.setAttribute("font-weight", "bold");
        createBlock.appendChild(this.foDocumentFacade.createText(getRowName(hSSFRow)));
        createTableCell.appendChild(createBlock);
        return createTableCell;
    }

    public float processSheet(HSSFWorkbook hSSFWorkbook, HSSFSheet hSSFSheet, Element element) {
        int physicalNumberOfRows = hSSFSheet.getPhysicalNumberOfRows();
        if (physicalNumberOfRows <= 0) {
            return 0.0f;
        }
        processSheetName(hSSFSheet, element);
        Element createTable = this.foDocumentFacade.createTable();
        createTable.setAttribute("table-layout", "fixed");
        Node createTableBody = this.foDocumentFacade.createTableBody();
        CellRangeAddress[][] buildMergedRangesMap = ExcelToHtmlUtils.buildMergedRangesMap(hSSFSheet);
        ArrayList arrayList = new ArrayList(physicalNumberOfRows);
        int i2 = 1;
        for (int firstRowNum = hSSFSheet.getFirstRowNum(); firstRowNum <= hSSFSheet.getLastRowNum(); firstRowNum++) {
            HSSFRow row = hSSFSheet.getRow(firstRowNum);
            if (row != null && (isOutputHiddenRows() || !row.getZeroHeight())) {
                Element createTableRow = this.foDocumentFacade.createTableRow();
                createTableRow.setAttribute("height", (((float) row.getHeight()) / 20.0f) + "pt");
                int processRow = processRow(hSSFWorkbook, buildMergedRangesMap, row, createTableRow);
                if (createTableRow.getChildNodes().getLength() == 0) {
                    Node createTableCell = this.foDocumentFacade.createTableCell();
                    createTableCell.appendChild(this.foDocumentFacade.createBlock());
                    createTableRow.appendChild(createTableCell);
                }
                if (processRow == 0) {
                    arrayList.add(createTableRow);
                } else {
                    if (!arrayList.isEmpty()) {
                        Iterator it = arrayList.iterator();
                        while (it.hasNext()) {
                            createTableBody.appendChild((Element) it.next());
                        }
                        arrayList.clear();
                    }
                    createTableBody.appendChild(createTableRow);
                }
                i2 = Math.max(i2, processRow);
            }
        }
        float processColumnWidths = processColumnWidths(hSSFSheet, i2, createTable);
        if (isOutputColumnHeaders()) {
            processColumnHeaders(hSSFSheet, i2, createTable);
        }
        createTable.appendChild(createTableBody);
        element.appendChild(createTable);
        return processColumnWidths;
    }

    public void processSheetName(HSSFSheet hSSFSheet, Element element) {
        Element createBlock = this.foDocumentFacade.createBlock();
        FontReplacer.Triplet triplet = new FontReplacer.Triplet();
        triplet.bold = true;
        triplet.italic = false;
        triplet.fontName = HSSFFont.FONT_ARIAL;
        getFontReplacer().update(triplet);
        setBlockProperties(createBlock, triplet);
        createBlock.setAttribute("font-size", "200%");
        Element createInline = this.foDocumentFacade.createInline();
        createInline.appendChild(this.foDocumentFacade.createText(hSSFSheet.getSheetName()));
        createBlock.appendChild(createInline);
        element.appendChild(createBlock);
        Element createBlock2 = this.foDocumentFacade.createBlock();
        createBlock2.appendChild(this.foDocumentFacade.createInline());
        element.appendChild(createBlock2);
    }

    public void processWorkbook(HSSFWorkbook hSSFWorkbook) {
        SummaryInformation summaryInformation = hSSFWorkbook.getSummaryInformation();
        if (summaryInformation != null) {
            processDocumentInformation(summaryInformation);
        }
        for (int i2 = 0; i2 < hSSFWorkbook.getNumberOfSheets(); i2++) {
            processSheet(hSSFWorkbook, i2);
        }
    }

    public void setPageMarginInches(float f2) {
        this.pageMarginInches = f2;
    }

    public ExcelToFoConverter(FoDocumentFacade foDocumentFacade2) {
        this.foDocumentFacade = foDocumentFacade2;
    }

    public boolean processSheet(HSSFWorkbook hSSFWorkbook, int i2) {
        String c = a.c("sheet-", i2);
        Element createPageSequence = this.foDocumentFacade.createPageSequence(c);
        float processSheet = processSheet(hSSFWorkbook, hSSFWorkbook.getSheetAt(i2), this.foDocumentFacade.addFlowToPageSequence(createPageSequence, "xsl-region-body"));
        if (processSheet == 0.0f) {
            return false;
        }
        createPageMaster(processSheet, c);
        this.foDocumentFacade.addPageSequence(createPageSequence);
        return true;
    }
}
