package org.apache.poi.hssf.dev;

import b.b.a.a.a;
import java.io.File;
import java.io.InputStream;
import java.io.PrintStream;
import org.apache.poi.hssf.record.Record;
import org.apache.poi.hssf.record.RecordFactory;
import org.apache.poi.hssf.record.RecordInputStream;
import org.apache.poi.poifs.filesystem.NPOIFSFileSystem;
import org.apache.poi.ss.util.SheetUtil;

public class RecordLister {
    public String file;

    /* JADX DEBUG: Failed to insert an additional move for type inference into block B:0:0x0000 */
    /* JADX WARN: Multi-variable type inference failed */
    /* JADX WARN: Type inference failed for: r2v0, types: [byte, int] */
    /* JADX WARN: Type inference failed for: r2v1 */
    /* JADX WARN: Type inference failed for: r2v4, types: [int] */
    public static String byteToHex(byte b2) {
        if (b2 < 0) {
            b2 += 256;
        }
        String hexString = Integer.toHexString(b2 == true ? 1 : 0);
        return b2 < 16 ? a.b("0", hexString) : hexString;
    }

    public static String formatData(byte[] bArr) {
        if (bArr == null || bArr.length == 0) {
            return "";
        }
        StringBuffer stringBuffer = new StringBuffer();
        if (bArr.length > 9) {
            stringBuffer.append(byteToHex(bArr[0]));
            stringBuffer.append(' ');
            stringBuffer.append(byteToHex(bArr[1]));
            stringBuffer.append(' ');
            stringBuffer.append(byteToHex(bArr[2]));
            stringBuffer.append(' ');
            stringBuffer.append(byteToHex(bArr[3]));
            stringBuffer.append(' ');
            stringBuffer.append(" .... ");
            stringBuffer.append(' ');
            stringBuffer.append(byteToHex(bArr[bArr.length - 4]));
            stringBuffer.append(' ');
            stringBuffer.append(byteToHex(bArr[bArr.length - 3]));
            stringBuffer.append(' ');
            stringBuffer.append(byteToHex(bArr[bArr.length - 2]));
            stringBuffer.append(' ');
            stringBuffer.append(byteToHex(bArr[bArr.length - 1]));
        } else {
            for (byte b2 : bArr) {
                stringBuffer.append(byteToHex(b2));
                stringBuffer.append(' ');
            }
        }
        return stringBuffer.toString();
    }

    public static String formatSID(int i2) {
        String hexString = Integer.toHexString(i2);
        String num = Integer.toString(i2);
        StringBuffer a = a.a("0x");
        for (int length = hexString.length(); length < 4; length++) {
            a.append(SheetUtil.defaultChar);
        }
        a.append(hexString);
        a.append(" (");
        for (int length2 = num.length(); length2 < 4; length2++) {
            a.append(SheetUtil.defaultChar);
        }
        return a.a(a, num, ")");
    }

    public static String formatSize(int i2) {
        String hexString = Integer.toHexString(i2);
        String num = Integer.toString(i2);
        StringBuffer stringBuffer = new StringBuffer();
        for (int length = hexString.length(); length < 3; length++) {
            stringBuffer.append(SheetUtil.defaultChar);
        }
        stringBuffer.append(hexString);
        stringBuffer.append(" (");
        for (int length2 = num.length(); length2 < 3; length2++) {
            stringBuffer.append(SheetUtil.defaultChar);
        }
        return a.a(stringBuffer, num, ")");
    }

    public static void main(String[] strArr) {
        if (strArr.length != 1 || strArr[0].equals("--help")) {
            System.out.println("RecordLister");
            System.out.println("Outputs the summary of the records in file order");
            System.out.println("usage: java org.apache.poi.hssf.dev.RecordLister filename");
            return;
        }
        RecordLister recordLister = new RecordLister();
        recordLister.setFile(strArr[0]);
        recordLister.run();
    }

    /* JADX INFO: finally extract failed */
    public void run() {
        NPOIFSFileSystem nPOIFSFileSystem = new NPOIFSFileSystem(new File(this.file), true);
        try {
            InputStream pOIFSInputStream = BiffViewer.getPOIFSInputStream(nPOIFSFileSystem);
            try {
                RecordInputStream recordInputStream = new RecordInputStream(pOIFSInputStream);
                while (recordInputStream.hasNextRecord()) {
                    int nextSid = recordInputStream.getNextSid();
                    recordInputStream.nextRecord();
                    int available = recordInputStream.available();
                    Class<? extends Record> recordClass = RecordFactory.getRecordClass(nextSid);
                    PrintStream printStream = System.out;
                    printStream.print(formatSID(nextSid) + " - " + formatSize(available) + " bytes");
                    if (recordClass != null) {
                        System.out.print("  \t");
                        System.out.print(recordClass.getName().replace("org.apache.poi.hssf.record.", ""));
                    }
                    System.out.println();
                    byte[] readRemainder = recordInputStream.readRemainder();
                    if (readRemainder.length > 0) {
                        System.out.print("   ");
                        System.out.println(formatData(readRemainder));
                    }
                }
                pOIFSInputStream.close();
            } catch (Throwable th) {
                pOIFSInputStream.close();
                throw th;
            }
        } finally {
            nPOIFSFileSystem.close();
        }
    }

    public void setFile(String str) {
        this.file = str;
    }
}
