package org.apache.poi.hssf.eventusermodel;

import org.apache.poi.hssf.eventusermodel.dummyrecord.LastCellOfRowDummyRecord;
import org.apache.poi.hssf.eventusermodel.dummyrecord.MissingCellDummyRecord;
import org.apache.poi.hssf.eventusermodel.dummyrecord.MissingRowDummyRecord;
import org.apache.poi.hssf.record.BOFRecord;
import org.apache.poi.hssf.record.CellValueRecordInterface;
import org.apache.poi.hssf.record.MulBlankRecord;
import org.apache.poi.hssf.record.MulRKRecord;
import org.apache.poi.hssf.record.NoteRecord;
import org.apache.poi.hssf.record.NumberRecord;
import org.apache.poi.hssf.record.Record;
import org.apache.poi.hssf.record.RecordFactory;
import org.apache.poi.hssf.record.RowRecord;
import org.apache.poi.hssf.record.StringRecord;

public final class MissingRecordAwareHSSFListener implements HSSFListener {
    public HSSFListener childListener;
    public int lastCellColumn;
    public int lastCellRow;
    public int lastRowRow;

    public MissingRecordAwareHSSFListener(HSSFListener hSSFListener) {
        resetCounts();
        this.childListener = hSSFListener;
    }

    private void resetCounts() {
        this.lastRowRow = -1;
        this.lastCellRow = -1;
        this.lastCellColumn = -1;
    }

    /* JADX DEBUG: Multi-variable search result rejected for r2v4, resolved type: org.apache.poi.hssf.record.BlankRecord[] */
    /* JADX WARN: Multi-variable type inference failed */
    @Override // org.apache.poi.hssf.eventusermodel.HSSFListener
    public void processRecord(Record record) {
        int i2;
        short s;
        int i3;
        NumberRecord[] numberRecordArr = null;
        numberRecordArr = null;
        r2 = null;
        r2 = null;
        r2 = null;
        NumberRecord[] numberRecordArr2 = null;
        if (record instanceof CellValueRecordInterface) {
            CellValueRecordInterface cellValueRecordInterface = (CellValueRecordInterface) record;
            i2 = cellValueRecordInterface.getRow();
            s = cellValueRecordInterface.getColumn();
        } else if (record instanceof StringRecord) {
            this.childListener.processRecord(record);
            return;
        } else {
            short sid = record.getSid();
            if (sid != 28) {
                if (sid == 520) {
                    RowRecord rowRecord = (RowRecord) record;
                    if (this.lastRowRow + 1 < rowRecord.getRowNumber()) {
                        int i4 = this.lastRowRow;
                        while (true) {
                            i4++;
                            if (i4 >= rowRecord.getRowNumber()) {
                                break;
                            }
                            this.childListener.processRecord(new MissingRowDummyRecord(i4));
                        }
                    }
                    this.lastRowRow = rowRecord.getRowNumber();
                    this.lastCellColumn = -1;
                } else if (sid == 1212) {
                    this.childListener.processRecord(record);
                    return;
                } else if (sid == 2057) {
                    BOFRecord bOFRecord = (BOFRecord) record;
                    if (bOFRecord.getType() == 5 || bOFRecord.getType() == 16) {
                        resetCounts();
                    }
                } else if (sid == 189) {
                    numberRecordArr2 = RecordFactory.convertRKRecords((MulRKRecord) record);
                } else if (sid == 190) {
                    numberRecordArr2 = RecordFactory.convertBlankRecords((MulBlankRecord) record);
                }
                s = -1;
                i2 = -1;
                numberRecordArr = numberRecordArr2;
            } else {
                NoteRecord noteRecord = (NoteRecord) record;
                i2 = noteRecord.getRow();
                s = noteRecord.getColumn();
            }
        }
        if (numberRecordArr != null && numberRecordArr.length > 0) {
            i2 = numberRecordArr[0].getRow();
            s = numberRecordArr[0].getColumn();
        }
        int i5 = this.lastCellRow;
        if (i2 != i5 && i2 > 0) {
            if (i5 == -1) {
                this.lastCellRow = 0;
            }
            int i6 = this.lastCellRow;
            while (i6 < i2) {
                this.childListener.processRecord(new LastCellOfRowDummyRecord(i6, i6 == this.lastCellRow ? this.lastCellColumn : -1));
                i6++;
            }
        }
        int i7 = this.lastCellRow;
        if (!(i7 == -1 || (i3 = this.lastCellColumn) == -1 || i2 != -1)) {
            this.childListener.processRecord(new LastCellOfRowDummyRecord(i7, i3));
            this.lastCellRow = -1;
            this.lastCellColumn = -1;
        }
        if (i2 != this.lastCellRow) {
            this.lastCellColumn = -1;
        }
        int i8 = this.lastCellColumn;
        if (i8 != s - 1) {
            while (true) {
                i8++;
                if (i8 >= s) {
                    break;
                }
                this.childListener.processRecord(new MissingCellDummyRecord(i2, i8));
            }
        }
        if (numberRecordArr != null && numberRecordArr.length > 0) {
            s = numberRecordArr[numberRecordArr.length - 1].getColumn();
        }
        if (s != -1) {
            this.lastCellColumn = s;
            this.lastCellRow = i2;
        }
        if (numberRecordArr == null || numberRecordArr.length <= 0) {
            this.childListener.processRecord(record);
            return;
        }
        for (NumberRecord numberRecord : numberRecordArr) {
            this.childListener.processRecord(numberRecord);
        }
    }
}
