package org.apache.poi.hssf.model;

import java.util.List;
import org.apache.poi.hssf.record.Record;

public final class RecordStream {
    public int _countRead;
    public final int _endIx;
    public final List<Record> _list;
    public int _nextIndex;

    public RecordStream(List<Record> list, int i2, int i3) {
        this._list = list;
        this._nextIndex = i2;
        this._endIx = i3;
        this._countRead = 0;
    }

    public int getCountRead() {
        return this._countRead;
    }

    public Record getNext() {
        if (hasNext()) {
            this._countRead++;
            List<Record> list = this._list;
            int i2 = this._nextIndex;
            this._nextIndex = i2 + 1;
            return list.get(i2);
        }
        throw new RuntimeException("Attempt to read past end of record stream");
    }

    public boolean hasNext() {
        return this._nextIndex < this._endIx;
    }

    /* JADX DEBUG: Type inference failed for r0v4. Raw type applied. Possible types: java.lang.Class<?>, java.lang.Class<? extends org.apache.poi.hssf.record.Record> */
    public Class<? extends Record> peekNextClass() {
        if (!hasNext()) {
            return null;
        }
        return this._list.get(this._nextIndex).getClass();
    }

    public int peekNextSid() {
        if (!hasNext()) {
            return -1;
        }
        return this._list.get(this._nextIndex).getSid();
    }

    public RecordStream(List<Record> list, int i2) {
        this(list, i2, list.size());
    }
}
