package org.apache.poi.hssf.record;

import b.b.a.a.a;
import java.io.ByteArrayOutputStream;
import java.io.IOException;
import org.apache.poi.EncryptedDocumentException;
import org.apache.poi.poifs.crypt.EncryptionInfo;
import org.apache.poi.poifs.crypt.EncryptionMode;
import org.apache.poi.poifs.crypt.binaryrc4.BinaryRC4EncryptionHeader;
import org.apache.poi.poifs.crypt.binaryrc4.BinaryRC4EncryptionVerifier;
import org.apache.poi.poifs.crypt.cryptoapi.CryptoAPIEncryptionHeader;
import org.apache.poi.poifs.crypt.cryptoapi.CryptoAPIEncryptionVerifier;
import org.apache.poi.poifs.crypt.xor.XOREncryptionHeader;
import org.apache.poi.poifs.crypt.xor.XOREncryptionVerifier;
import org.apache.poi.util.HexDump;
import org.apache.poi.util.LittleEndianByteArrayOutputStream;
import org.apache.poi.util.LittleEndianOutput;
import org.apache.poi.util.LittleEndianOutputStream;

public final class FilePassRecord extends StandardRecord implements Cloneable {
    public static final int ENCRYPTION_OTHER = 1;
    public static final int ENCRYPTION_XOR = 0;
    public static final short sid = 47;
    public EncryptionInfo encryptionInfo;
    public final int encryptionType;

    /* renamed from: org.apache.poi.hssf.record.FilePassRecord$1  reason: invalid class name */
    public static /* synthetic */ class AnonymousClass1 {
        public static final /* synthetic */ int[] $SwitchMap$org$apache$poi$poifs$crypt$EncryptionMode;

        /* JADX WARNING: Can't wrap try/catch for region: R(8:0|1|2|3|4|5|6|8) */
        /* JADX WARNING: Code restructure failed: missing block: B:9:?, code lost:
            return;
         */
        /* JADX WARNING: Failed to process nested try/catch */
        /* JADX WARNING: Missing exception handler attribute for start block: B:3:0x000f */
        /* JADX WARNING: Missing exception handler attribute for start block: B:5:0x0017 */
        static {
            int[] iArr = new int[EncryptionMode.values().length];
            $SwitchMap$org$apache$poi$poifs$crypt$EncryptionMode = iArr;
            EncryptionMode encryptionMode = EncryptionMode.xor;
            iArr[4] = 1;
            int[] iArr2 = $SwitchMap$org$apache$poi$poifs$crypt$EncryptionMode;
            EncryptionMode encryptionMode2 = EncryptionMode.binaryRC4;
            iArr2[0] = 2;
            int[] iArr3 = $SwitchMap$org$apache$poi$poifs$crypt$EncryptionMode;
            EncryptionMode encryptionMode3 = EncryptionMode.cryptoAPI;
            iArr3[1] = 3;
        }
    }

    public FilePassRecord(FilePassRecord filePassRecord) {
        this.encryptionType = filePassRecord.encryptionType;
        try {
            this.encryptionInfo = filePassRecord.encryptionInfo.clone();
        } catch (CloneNotSupportedException e2) {
            throw new EncryptedDocumentException(e2);
        }
    }

    @Override // org.apache.poi.hssf.record.StandardRecord
    public int getDataSize() {
        ByteArrayOutputStream byteArrayOutputStream = new ByteArrayOutputStream();
        serialize(new LittleEndianOutputStream(byteArrayOutputStream));
        return byteArrayOutputStream.size();
    }

    public EncryptionInfo getEncryptionInfo() {
        return this.encryptionInfo;
    }

    @Override // org.apache.poi.hssf.record.Record
    public short getSid() {
        return 47;
    }

    @Override // org.apache.poi.hssf.record.StandardRecord
    public void serialize(LittleEndianOutput littleEndianOutput) {
        littleEndianOutput.writeShort(this.encryptionType);
        byte[] bArr = new byte[1024];
        LittleEndianByteArrayOutputStream littleEndianByteArrayOutputStream = new LittleEndianByteArrayOutputStream(bArr, 0);
        int ordinal = this.encryptionInfo.getEncryptionMode().ordinal();
        if (ordinal == 0) {
            littleEndianOutput.writeShort(this.encryptionInfo.getVersionMajor());
            littleEndianOutput.writeShort(this.encryptionInfo.getVersionMinor());
            ((BinaryRC4EncryptionHeader) this.encryptionInfo.getHeader()).write(littleEndianByteArrayOutputStream);
            ((BinaryRC4EncryptionVerifier) this.encryptionInfo.getVerifier()).write(littleEndianByteArrayOutputStream);
        } else if (ordinal == 1) {
            littleEndianOutput.writeShort(this.encryptionInfo.getVersionMajor());
            littleEndianOutput.writeShort(this.encryptionInfo.getVersionMinor());
            littleEndianOutput.writeInt(this.encryptionInfo.getEncryptionFlags());
            ((CryptoAPIEncryptionHeader) this.encryptionInfo.getHeader()).write(littleEndianByteArrayOutputStream);
            ((CryptoAPIEncryptionVerifier) this.encryptionInfo.getVerifier()).write(littleEndianByteArrayOutputStream);
        } else if (ordinal == 4) {
            ((XOREncryptionHeader) this.encryptionInfo.getHeader()).write(littleEndianByteArrayOutputStream);
            ((XOREncryptionVerifier) this.encryptionInfo.getVerifier()).write(littleEndianByteArrayOutputStream);
        } else {
            throw new EncryptedDocumentException("not supported");
        }
        littleEndianOutput.write(bArr, 0, littleEndianByteArrayOutputStream.getWriteIndex());
    }

    @Override // org.apache.poi.hssf.record.Record
    public String toString() {
        StringBuilder d2 = a.d("[FILEPASS]\n", "    .type = ");
        d2.append(HexDump.shortToHex(this.encryptionType));
        d2.append('\n');
        String str = "     ." + this.encryptionInfo.getEncryptionMode();
        d2.append(str + ".info = ");
        d2.append(HexDump.shortToHex(this.encryptionInfo.getVersionMajor()));
        d2.append('\n');
        d2.append(str + ".ver  = ");
        d2.append(HexDump.shortToHex(this.encryptionInfo.getVersionMinor()));
        d2.append('\n');
        d2.append(str + ".salt = ");
        d2.append(HexDump.toHex(this.encryptionInfo.getVerifier().getSalt()));
        d2.append('\n');
        d2.append(str + ".verifier = ");
        d2.append(HexDump.toHex(this.encryptionInfo.getVerifier().getEncryptedVerifier()));
        d2.append('\n');
        d2.append(str + ".verifierHash = ");
        d2.append(HexDump.toHex(this.encryptionInfo.getVerifier().getEncryptedVerifierHash()));
        d2.append('\n');
        d2.append("[/FILEPASS]\n");
        return d2.toString();
    }

    @Override // org.apache.poi.hssf.record.Record, java.lang.Object
    public FilePassRecord clone() {
        return new FilePassRecord(this);
    }

    public FilePassRecord(EncryptionMode encryptionMode) {
        this.encryptionType = encryptionMode == EncryptionMode.xor ? 0 : 1;
        this.encryptionInfo = new EncryptionInfo(encryptionMode);
    }

    public FilePassRecord(RecordInputStream recordInputStream) {
        EncryptionMode encryptionMode;
        int readUShort = recordInputStream.readUShort();
        this.encryptionType = readUShort;
        if (readUShort == 0) {
            encryptionMode = EncryptionMode.xor;
        } else if (readUShort == 1) {
            encryptionMode = EncryptionMode.cryptoAPI;
        } else {
            throw new EncryptedDocumentException("invalid encryption type");
        }
        try {
            this.encryptionInfo = new EncryptionInfo(recordInputStream, encryptionMode);
        } catch (IOException e2) {
            throw new EncryptedDocumentException(e2);
        }
    }
}
