package org.apache.poi.hssf.record;

import b.b.a.a.a;
import java.io.ByteArrayOutputStream;
import java.io.InputStream;
import java.util.Locale;
import org.apache.poi.hssf.record.crypto.Biff8DecryptingStream;
import org.apache.poi.poifs.crypt.EncryptionInfo;
import org.apache.poi.util.Internal;
import org.apache.poi.util.LittleEndianInput;
import org.apache.poi.util.LittleEndianInputStream;
import org.apache.poi.util.RecordFormatException;

public final class RecordInputStream implements LittleEndianInput {
    public static final /* synthetic */ boolean $assertionsDisabled = false;
    public static final int DATA_LEN_NEEDS_TO_BE_READ = -1;
    public static final byte[] EMPTY_BYTE_ARRAY = new byte[0];
    public static final int INVALID_SID_VALUE = -1;
    public static final short MAX_RECORD_DATA_SIZE = 8224;
    public final BiffHeaderInput _bhi;
    public int _currentDataLength;
    public int _currentDataOffset;
    public int _currentSid;
    public final LittleEndianInput _dataInput;
    public int _markedDataOffset;
    public int _nextSid;

    public static final class LeftoverDataException extends RuntimeException {
        /* JADX WARNING: Illegal instructions before constructor call */
        public LeftoverDataException(int i2, int i3) {
            super(a.a(r0, i3, " bytes remaining still to be read."));
            StringBuilder b2 = a.b("Initialisation of record 0x");
            b2.append(Integer.toHexString(i2).toUpperCase(Locale.ROOT));
            b2.append("(");
            b2.append(getRecordName(i2));
            b2.append(") left ");
        }

        public static String getRecordName(int i2) {
            Class<? extends Record> recordClass = RecordFactory.getRecordClass(i2);
            if (recordClass == null) {
                return null;
            }
            return recordClass.getSimpleName();
        }
    }

    public static final class SimpleHeaderInput implements BiffHeaderInput {
        public final LittleEndianInput _lei;

        public SimpleHeaderInput(InputStream inputStream) {
            this._lei = RecordInputStream.getLEI(inputStream);
        }

        @Override // org.apache.poi.hssf.record.BiffHeaderInput
        public int available() {
            return this._lei.available();
        }

        @Override // org.apache.poi.hssf.record.BiffHeaderInput
        public int readDataSize() {
            return this._lei.readUShort();
        }

        @Override // org.apache.poi.hssf.record.BiffHeaderInput
        public int readRecordSID() {
            return this._lei.readUShort();
        }
    }

    public RecordInputStream(InputStream inputStream) {
        this(inputStream, null, 0);
    }

    private void checkRecordPosition(int i2) {
        int remaining = remaining();
        if (remaining < i2) {
            if (remaining != 0 || !isContinueNext()) {
                throw new RecordFormatException(a.b("Not enough data (", remaining, ") to read requested (", i2, ") bytes"));
            }
            nextRecord();
        }
    }

    public static LittleEndianInput getLEI(InputStream inputStream) {
        if (inputStream instanceof LittleEndianInput) {
            return (LittleEndianInput) inputStream;
        }
        return new LittleEndianInputStream(inputStream);
    }

    private boolean isContinueNext() {
        int i2 = this._currentDataLength;
        if (i2 != -1 && this._currentDataOffset != i2) {
            throw new IllegalStateException("Should never be called before end of current record");
        } else if (hasNextRecord() && this._nextSid == 60) {
            return true;
        } else {
            return false;
        }
    }

    private int readNextSid() {
        if (this._bhi.available() < 4) {
            return -1;
        }
        int readRecordSID = this._bhi.readRecordSID();
        if (readRecordSID != -1) {
            this._currentDataLength = -1;
            return readRecordSID;
        }
        throw new RecordFormatException(a.b("Found invalid sid (", readRecordSID, ")"));
    }

    private String readStringCommon(int i2, boolean z) {
        int i3;
        int i4;
        if (i2 < 0 || i2 > 1048576) {
            throw new IllegalArgumentException(a.b("Bad requested string length (", i2, ")"));
        }
        char[] cArr = new char[i2];
        int i5 = 0;
        while (true) {
            int remaining = remaining();
            if (!z) {
                remaining /= 2;
            }
            if (i2 - i5 <= remaining) {
                while (i5 < i2) {
                    if (z) {
                        i3 = readUByte();
                    } else {
                        i3 = readShort();
                    }
                    cArr[i5] = (char) i3;
                    i5++;
                }
                return new String(cArr);
            }
            while (remaining > 0) {
                if (z) {
                    i4 = readUByte();
                } else {
                    i4 = readShort();
                }
                cArr[i5] = (char) i4;
                i5++;
                remaining--;
            }
            if (!isContinueNext()) {
                StringBuilder b2 = a.b("Expected to find a ContinueRecord in order to read remaining ");
                b2.append(i2 - i5);
                b2.append(" of ");
                b2.append(i2);
                b2.append(" chars");
                throw new RecordFormatException(b2.toString());
            } else if (remaining() == 0) {
                nextRecord();
                z = readByte() == 0;
            } else {
                StringBuilder b3 = a.b("Odd number of bytes(");
                b3.append(remaining());
                b3.append(") left behind");
                throw new RecordFormatException(b3.toString());
            }
        }
    }

    @Override // org.apache.poi.util.LittleEndianInput
    public int available() {
        return remaining();
    }

    public int getNextSid() {
        return this._nextSid;
    }

    public short getSid() {
        return (short) this._currentSid;
    }

    public boolean hasNextRecord() {
        int i2 = this._currentDataLength;
        if (i2 == -1 || i2 == this._currentDataOffset) {
            if (this._currentDataLength != -1) {
                this._nextSid = readNextSid();
            }
            return this._nextSid != -1;
        }
        throw new LeftoverDataException(this._currentSid, remaining());
    }

    @Internal
    public void mark(int i2) {
        ((InputStream) this._dataInput).mark(i2);
        this._markedDataOffset = this._currentDataOffset;
    }

    public void nextRecord() {
        int i2 = this._nextSid;
        if (i2 == -1) {
            throw new IllegalStateException("EOF - next record not available");
        } else if (this._currentDataLength == -1) {
            this._currentSid = i2;
            this._currentDataOffset = 0;
            int readDataSize = this._bhi.readDataSize();
            this._currentDataLength = readDataSize;
            if (readDataSize > 8224) {
                throw new RecordFormatException("The content of an excel record cannot exceed 8224 bytes");
            }
        } else {
            throw new IllegalStateException("Cannot call nextRecord() without checking hasNextRecord() first");
        }
    }

    public int read(byte[] bArr, int i2, int i3) {
        int min = Math.min(i3, remaining());
        if (min == 0) {
            return 0;
        }
        readFully(bArr, i2, min);
        return min;
    }

    @Deprecated
    public byte[] readAllContinuedRemainder() {
        ByteArrayOutputStream byteArrayOutputStream = new ByteArrayOutputStream(16448);
        while (true) {
            byte[] readRemainder = readRemainder();
            byteArrayOutputStream.write(readRemainder, 0, readRemainder.length);
            if (!isContinueNext()) {
                return byteArrayOutputStream.toByteArray();
            }
            nextRecord();
        }
    }

    @Override // org.apache.poi.util.LittleEndianInput
    public byte readByte() {
        checkRecordPosition(1);
        this._currentDataOffset++;
        return this._dataInput.readByte();
    }

    public String readCompressedUnicode(int i2) {
        return readStringCommon(i2, true);
    }

    @Override // org.apache.poi.util.LittleEndianInput
    public double readDouble() {
        double longBitsToDouble = Double.longBitsToDouble(readLong());
        Double.isNaN(longBitsToDouble);
        return longBitsToDouble;
    }

    @Override // org.apache.poi.util.LittleEndianInput
    public void readFully(byte[] bArr) {
        readFully(bArr, 0, bArr.length, false);
    }

    @Override // org.apache.poi.util.LittleEndianInput
    public int readInt() {
        checkRecordPosition(4);
        this._currentDataOffset += 4;
        return this._dataInput.readInt();
    }

    @Override // org.apache.poi.util.LittleEndianInput
    public long readLong() {
        checkRecordPosition(8);
        this._currentDataOffset += 8;
        return this._dataInput.readLong();
    }

    @Override // org.apache.poi.util.LittleEndianInput
    public void readPlain(byte[] bArr, int i2, int i3) {
        readFully(bArr, 0, bArr.length, true);
    }

    public byte[] readRemainder() {
        int remaining = remaining();
        if (remaining == 0) {
            return EMPTY_BYTE_ARRAY;
        }
        byte[] bArr = new byte[remaining];
        readFully(bArr);
        return bArr;
    }

    @Override // org.apache.poi.util.LittleEndianInput
    public short readShort() {
        checkRecordPosition(2);
        this._currentDataOffset += 2;
        return this._dataInput.readShort();
    }

    public String readString() {
        return readStringCommon(readUShort(), readByte() == 0);
    }

    @Override // org.apache.poi.util.LittleEndianInput
    public int readUByte() {
        return readByte() & 255;
    }

    @Override // org.apache.poi.util.LittleEndianInput
    public int readUShort() {
        checkRecordPosition(2);
        this._currentDataOffset += 2;
        return this._dataInput.readUShort();
    }

    public String readUnicodeLEString(int i2) {
        return readStringCommon(i2, false);
    }

    public int remaining() {
        int i2 = this._currentDataLength;
        if (i2 == -1) {
            return 0;
        }
        return i2 - this._currentDataOffset;
    }

    @Internal
    public void reset() {
        ((InputStream) this._dataInput).reset();
        this._currentDataOffset = this._markedDataOffset;
    }

    public RecordInputStream(InputStream inputStream, EncryptionInfo encryptionInfo, int i2) {
        if (encryptionInfo == null) {
            this._dataInput = getLEI(inputStream);
            this._bhi = new SimpleHeaderInput(inputStream);
        } else {
            Biff8DecryptingStream biff8DecryptingStream = new Biff8DecryptingStream(inputStream, i2, encryptionInfo);
            this._dataInput = biff8DecryptingStream;
            this._bhi = biff8DecryptingStream;
        }
        this._nextSid = readNextSid();
    }

    @Override // org.apache.poi.util.LittleEndianInput
    public void readFully(byte[] bArr, int i2, int i3) {
        readFully(bArr, i2, i3, false);
    }

    public void readFully(byte[] bArr, int i2, int i3, boolean z) {
        if (bArr == null) {
            throw null;
        } else if (i2 < 0 || i3 < 0 || i3 > bArr.length - i2) {
            throw new IndexOutOfBoundsException();
        } else {
            int i4 = i3;
            while (i4 > 0) {
                int min = Math.min(available(), i4);
                if (min == 0) {
                    if (hasNextRecord()) {
                        nextRecord();
                        min = Math.min(available(), i4);
                    } else {
                        throw new RecordFormatException(a.b("Can't read the remaining ", i4, " bytes of the requested ", i3, " bytes. No further record exists."));
                    }
                }
                checkRecordPosition(min);
                if (z) {
                    this._dataInput.readPlain(bArr, i2, min);
                } else {
                    this._dataInput.readFully(bArr, i2, min);
                }
                this._currentDataOffset += min;
                i2 += min;
                i4 -= min;
            }
        }
    }
}
