package org.apache.poi.hssf.usermodel;

import b.b.a.a.a;
import java.text.SimpleDateFormat;
import java.util.Calendar;
import java.util.Date;
import java.util.Iterator;
import java.util.List;
import org.apache.poi.common.usermodel.HyperlinkType;
import org.apache.poi.hssf.model.HSSFFormulaParser;
import org.apache.poi.hssf.model.InternalWorkbook;
import org.apache.poi.hssf.record.BlankRecord;
import org.apache.poi.hssf.record.BoolErrRecord;
import org.apache.poi.hssf.record.CellValueRecordInterface;
import org.apache.poi.hssf.record.ExtendedFormatRecord;
import org.apache.poi.hssf.record.FormulaRecord;
import org.apache.poi.hssf.record.HyperlinkRecord;
import org.apache.poi.hssf.record.LabelSSTRecord;
import org.apache.poi.hssf.record.NumberRecord;
import org.apache.poi.hssf.record.Record;
import org.apache.poi.hssf.record.RecordBase;
import org.apache.poi.hssf.record.aggregates.FormulaRecordAggregate;
import org.apache.poi.hssf.record.common.UnicodeString;
import org.apache.poi.ss.SpreadsheetVersion;
import org.apache.poi.ss.formula.FormulaType;
import org.apache.poi.ss.formula.eval.ErrorEval;
import org.apache.poi.ss.formula.functions.NumericFunction;
import org.apache.poi.ss.formula.ptg.ExpPtg;
import org.apache.poi.ss.formula.ptg.Ptg;
import org.apache.poi.ss.usermodel.Cell;
import org.apache.poi.ss.usermodel.CellStyle;
import org.apache.poi.ss.usermodel.CellType;
import org.apache.poi.ss.usermodel.Comment;
import org.apache.poi.ss.usermodel.DateUtil;
import org.apache.poi.ss.usermodel.FormulaError;
import org.apache.poi.ss.usermodel.Hyperlink;
import org.apache.poi.ss.usermodel.RichTextString;
import org.apache.poi.ss.util.CellAddress;
import org.apache.poi.ss.util.CellRangeAddress;
import org.apache.poi.ss.util.CellReference;
import org.apache.poi.ss.util.NumberToTextConverter;
import org.apache.poi.util.LocaleUtil;
import org.apache.poi.xssf.usermodel.XSSFCell;

public class HSSFCell implements Cell {
    public static final short ENCODING_COMPRESSED_UNICODE = 0;
    public static final short ENCODING_UNCHANGED = -1;
    public static final short ENCODING_UTF_16 = 1;
    public static final String FILE_FORMAT_NAME = "BIFF8";
    public static final String LAST_COLUMN_NAME = SpreadsheetVersion.EXCEL97.getLastColumnName();
    public static final int LAST_COLUMN_NUMBER = SpreadsheetVersion.EXCEL97.getLastColumnIndex();
    public final HSSFWorkbook _book;
    public CellType _cellType;
    public HSSFComment _comment;
    public CellValueRecordInterface _record;
    public final HSSFSheet _sheet;
    public HSSFRichTextString _stringValue;

    /* renamed from: org.apache.poi.hssf.usermodel.HSSFCell$1  reason: invalid class name */
    public static /* synthetic */ class AnonymousClass1 {
        public static final /* synthetic */ int[] $SwitchMap$org$apache$poi$common$usermodel$HyperlinkType;
        public static final /* synthetic */ int[] $SwitchMap$org$apache$poi$ss$usermodel$CellType;

        /* JADX WARNING: Can't wrap try/catch for region: R(23:0|(2:1|2)|3|(2:5|6)|7|9|10|11|12|13|15|16|17|18|19|20|21|22|23|24|25|26|28) */
        /* JADX WARNING: Can't wrap try/catch for region: R(24:0|1|2|3|(2:5|6)|7|9|10|11|12|13|15|16|17|18|19|20|21|22|23|24|25|26|28) */
        /* JADX WARNING: Can't wrap try/catch for region: R(25:0|1|2|3|5|6|7|9|10|11|12|13|15|16|17|18|19|20|21|22|23|24|25|26|28) */
        /* JADX WARNING: Code restructure failed: missing block: B:29:?, code lost:
            return;
         */
        /* JADX WARNING: Failed to process nested try/catch */
        /* JADX WARNING: Missing exception handler attribute for start block: B:11:0x001d */
        /* JADX WARNING: Missing exception handler attribute for start block: B:17:0x0030 */
        /* JADX WARNING: Missing exception handler attribute for start block: B:19:0x0036 */
        /* JADX WARNING: Missing exception handler attribute for start block: B:21:0x003c */
        /* JADX WARNING: Missing exception handler attribute for start block: B:23:0x0042 */
        /* JADX WARNING: Missing exception handler attribute for start block: B:25:0x0049 */
        static {
            int[] iArr = new int[HyperlinkType.values().length];
            $SwitchMap$org$apache$poi$common$usermodel$HyperlinkType = iArr;
            try {
                HyperlinkType hyperlinkType = HyperlinkType.EMAIL;
                iArr[3] = 1;
            } catch (NoSuchFieldError unused) {
            }
            try {
                int[] iArr2 = $SwitchMap$org$apache$poi$common$usermodel$HyperlinkType;
                HyperlinkType hyperlinkType2 = HyperlinkType.URL;
                iArr2[1] = 2;
            } catch (NoSuchFieldError unused2) {
            }
            int[] iArr3 = $SwitchMap$org$apache$poi$common$usermodel$HyperlinkType;
            HyperlinkType hyperlinkType3 = HyperlinkType.FILE;
            iArr3[4] = 3;
            try {
                int[] iArr4 = $SwitchMap$org$apache$poi$common$usermodel$HyperlinkType;
                HyperlinkType hyperlinkType4 = HyperlinkType.DOCUMENT;
                iArr4[2] = 4;
            } catch (NoSuchFieldError unused3) {
            }
            int[] iArr5 = new int[CellType.values().length];
            $SwitchMap$org$apache$poi$ss$usermodel$CellType = iArr5;
            CellType cellType = CellType.STRING;
            iArr5[2] = 1;
            int[] iArr6 = $SwitchMap$org$apache$poi$ss$usermodel$CellType;
            CellType cellType2 = CellType.BLANK;
            iArr6[4] = 2;
            int[] iArr7 = $SwitchMap$org$apache$poi$ss$usermodel$CellType;
            CellType cellType3 = CellType.FORMULA;
            iArr7[3] = 3;
            int[] iArr8 = $SwitchMap$org$apache$poi$ss$usermodel$CellType;
            CellType cellType4 = CellType.NUMERIC;
            iArr8[1] = 4;
            int[] iArr9 = $SwitchMap$org$apache$poi$ss$usermodel$CellType;
            CellType cellType5 = CellType.BOOLEAN;
            iArr9[5] = 5;
            int[] iArr10 = $SwitchMap$org$apache$poi$ss$usermodel$CellType;
            CellType cellType6 = CellType.ERROR;
            iArr10[6] = 6;
        }
    }

    public HSSFCell(HSSFWorkbook hSSFWorkbook, HSSFSheet hSSFSheet, int i2, short s) {
        checkBounds(s);
        this._stringValue = null;
        this._book = hSSFWorkbook;
        this._sheet = hSSFSheet;
        setCellType(CellType.BLANK, false, i2, s, hSSFSheet.getSheet().getXFIndexForColAt(s));
    }

    private short applyUserCellStyle(HSSFCellStyle hSSFCellStyle) {
        if (hSSFCellStyle.getUserStyleName() != null) {
            InternalWorkbook workbook = this._book.getWorkbook();
            int numExFormats = workbook.getNumExFormats();
            short s = 0;
            while (true) {
                if (s >= numExFormats) {
                    s = -1;
                    break;
                }
                ExtendedFormatRecord exFormatAt = workbook.getExFormatAt(s);
                if (exFormatAt.getXFType() == 0 && exFormatAt.getParentIndex() == hSSFCellStyle.getIndex()) {
                    break;
                }
                s = (short) (s + 1);
            }
            if (s != -1) {
                return s;
            }
            ExtendedFormatRecord createCellXF = workbook.createCellXF();
            createCellXF.cloneStyleFrom(workbook.getExFormatAt(hSSFCellStyle.getIndex()));
            createCellXF.setIndentionOptions(0);
            createCellXF.setXFType(0);
            createCellXF.setParentIndex(hSSFCellStyle.getIndex());
            return (short) numExFormats;
        }
        throw new IllegalArgumentException("Expected user-defined style");
    }

    public static void checkBounds(int i2) {
        if (i2 < 0 || i2 > LAST_COLUMN_NUMBER) {
            StringBuilder sb = new StringBuilder();
            sb.append("Invalid column index (");
            sb.append(i2);
            sb.append(").  Allowable column range for ");
            sb.append(FILE_FORMAT_NAME);
            sb.append(" is (0..");
            sb.append(LAST_COLUMN_NUMBER);
            sb.append(") or ('A'..'");
            throw new IllegalArgumentException(a.a(sb, LAST_COLUMN_NAME, "')"));
        }
    }

    public static void checkFormulaCachedValueType(CellType cellType, FormulaRecord formulaRecord) {
        CellType forInt = CellType.forInt(formulaRecord.getCachedResultType());
        if (forInt != cellType) {
            throw typeMismatch(cellType, forInt, true);
        }
    }

    private boolean convertCellValueToBoolean() {
        switch (this._cellType.ordinal()) {
            case 1:
                if (((NumberRecord) this._record).getValue() != NumericFunction.LOG_10_TO_BASE_e) {
                    return true;
                }
                return false;
            case 2:
                return Boolean.valueOf(this._book.getWorkbook().getSSTString(((LabelSSTRecord) this._record).getSSTIndex()).getString()).booleanValue();
            case 3:
                FormulaRecord formulaRecord = ((FormulaRecordAggregate) this._record).getFormulaRecord();
                checkFormulaCachedValueType(CellType.BOOLEAN, formulaRecord);
                return formulaRecord.getCachedBooleanValue();
            case 4:
            case 6:
                return false;
            case 5:
                return ((BoolErrRecord) this._record).getBooleanValue();
            default:
                StringBuilder b2 = a.b("Unexpected cell type (");
                b2.append(this._cellType);
                b2.append(")");
                throw new RuntimeException(b2.toString());
        }
    }

    private String convertCellValueToString() {
        switch (this._cellType.ordinal()) {
            case 1:
                return NumberToTextConverter.toText(((NumberRecord) this._record).getValue());
            case 2:
                return this._book.getWorkbook().getSSTString(((LabelSSTRecord) this._record).getSSTIndex()).getString();
            case 3:
                FormulaRecordAggregate formulaRecordAggregate = (FormulaRecordAggregate) this._record;
                FormulaRecord formulaRecord = formulaRecordAggregate.getFormulaRecord();
                int ordinal = CellType.forInt(formulaRecord.getCachedResultType()).ordinal();
                if (ordinal == 1) {
                    return NumberToTextConverter.toText(formulaRecord.getValue());
                }
                if (ordinal == 2) {
                    return formulaRecordAggregate.getStringValue();
                }
                if (ordinal == 5) {
                    return formulaRecord.getCachedBooleanValue() ? XSSFCell.TRUE : XSSFCell.FALSE;
                }
                if (ordinal == 6) {
                    return FormulaError.forInt(formulaRecord.getCachedErrorValue()).getString();
                }
                StringBuilder b2 = a.b("Unexpected formula result type (");
                b2.append(this._cellType);
                b2.append(")");
                throw new IllegalStateException(b2.toString());
            case 4:
                return "";
            case 5:
                return ((BoolErrRecord) this._record).getBooleanValue() ? XSSFCell.TRUE : XSSFCell.FALSE;
            case 6:
                return FormulaError.forInt(((BoolErrRecord) this._record).getErrorValue()).getString();
            default:
                StringBuilder b3 = a.b("Unexpected cell type (");
                b3.append(this._cellType);
                b3.append(")");
                throw new IllegalStateException(b3.toString());
        }
    }

    public static CellType determineType(CellValueRecordInterface cellValueRecordInterface) {
        if (cellValueRecordInterface instanceof FormulaRecordAggregate) {
            return CellType.FORMULA;
        }
        Record record = (Record) cellValueRecordInterface;
        short sid = record.getSid();
        if (sid == 253) {
            return CellType.STRING;
        }
        if (sid == 513) {
            return CellType.BLANK;
        }
        if (sid == 515) {
            return CellType.NUMERIC;
        }
        if (sid == 517) {
            return ((BoolErrRecord) record).isBoolean() ? CellType.BOOLEAN : CellType.ERROR;
        }
        StringBuilder b2 = a.b("Bad cell value rec (");
        b2.append(cellValueRecordInterface.getClass().getName());
        b2.append(")");
        throw new RuntimeException(b2.toString());
    }

    private void notifyFormulaChanging() {
        CellValueRecordInterface cellValueRecordInterface = this._record;
        if (cellValueRecordInterface instanceof FormulaRecordAggregate) {
            ((FormulaRecordAggregate) cellValueRecordInterface).notifyFormulaChanging();
        }
    }

    public static RuntimeException typeMismatch(CellType cellType, CellType cellType2, boolean z) {
        StringBuilder sb = new StringBuilder();
        sb.append("Cannot get a ");
        sb.append(cellType);
        sb.append(" value from a ");
        sb.append(cellType2);
        sb.append(" ");
        return new IllegalStateException(a.a(sb, z ? "formula " : "", "cell"));
    }

    @Override // org.apache.poi.ss.usermodel.Cell
    public CellAddress getAddress() {
        return new CellAddress(this);
    }

    @Override // org.apache.poi.ss.usermodel.Cell
    public CellRangeAddress getArrayFormulaRange() {
        if (this._cellType == CellType.FORMULA) {
            return ((FormulaRecordAggregate) this._record).getArrayFormulaRange();
        }
        throw new IllegalStateException(a.b("Cell ", new CellReference(this).formatAsString(), " is not part of an array formula."));
    }

    @Override // org.apache.poi.ss.usermodel.Cell
    public boolean getBooleanCellValue() {
        int ordinal = this._cellType.ordinal();
        if (ordinal == 3) {
            FormulaRecord formulaRecord = ((FormulaRecordAggregate) this._record).getFormulaRecord();
            checkFormulaCachedValueType(CellType.BOOLEAN, formulaRecord);
            return formulaRecord.getCachedBooleanValue();
        } else if (ordinal == 4) {
            return false;
        } else {
            if (ordinal == 5) {
                return ((BoolErrRecord) this._record).getBooleanValue();
            }
            throw typeMismatch(CellType.BOOLEAN, this._cellType, false);
        }
    }

    public InternalWorkbook getBoundWorkbook() {
        return this._book.getWorkbook();
    }

    @Override // org.apache.poi.ss.usermodel.Cell
    public int getCachedFormulaResultType() {
        return getCachedFormulaResultTypeEnum().getCode();
    }

    @Override // org.apache.poi.ss.usermodel.Cell
    public CellType getCachedFormulaResultTypeEnum() {
        if (this._cellType == CellType.FORMULA) {
            return CellType.forInt(((FormulaRecordAggregate) this._record).getFormulaRecord().getCachedResultType());
        }
        throw new IllegalStateException("Only formula cells have cached results");
    }

    @Override // org.apache.poi.ss.usermodel.Cell
    public String getCellFormula() {
        CellValueRecordInterface cellValueRecordInterface = this._record;
        if (cellValueRecordInterface instanceof FormulaRecordAggregate) {
            return HSSFFormulaParser.toFormulaString(this._book, ((FormulaRecordAggregate) cellValueRecordInterface).getFormulaTokens());
        }
        throw typeMismatch(CellType.FORMULA, this._cellType, true);
    }

    @Override // org.apache.poi.ss.usermodel.Cell
    public int getCellType() {
        return getCellTypeEnum().getCode();
    }

    @Override // org.apache.poi.ss.usermodel.Cell
    public CellType getCellTypeEnum() {
        return this._cellType;
    }

    public CellValueRecordInterface getCellValueRecord() {
        return this._record;
    }

    @Override // org.apache.poi.ss.usermodel.Cell
    public int getColumnIndex() {
        return this._record.getColumn() & 65535;
    }

    @Override // org.apache.poi.ss.usermodel.Cell
    public Date getDateCellValue() {
        if (this._cellType == CellType.BLANK) {
            return null;
        }
        double numericCellValue = getNumericCellValue();
        if (this._book.getWorkbook().isUsing1904DateWindowing()) {
            return DateUtil.getJavaDate(numericCellValue, true);
        }
        return DateUtil.getJavaDate(numericCellValue, false);
    }

    @Override // org.apache.poi.ss.usermodel.Cell
    public byte getErrorCellValue() {
        int ordinal = this._cellType.ordinal();
        if (ordinal == 3) {
            FormulaRecord formulaRecord = ((FormulaRecordAggregate) this._record).getFormulaRecord();
            checkFormulaCachedValueType(CellType.ERROR, formulaRecord);
            return (byte) formulaRecord.getCachedErrorValue();
        } else if (ordinal == 6) {
            return ((BoolErrRecord) this._record).getErrorValue();
        } else {
            throw typeMismatch(CellType.ERROR, this._cellType, false);
        }
    }

    @Override // org.apache.poi.ss.usermodel.Cell
    public double getNumericCellValue() {
        int ordinal = this._cellType.ordinal();
        if (ordinal == 1) {
            return ((NumberRecord) this._record).getValue();
        }
        if (ordinal == 3) {
            FormulaRecord formulaRecord = ((FormulaRecordAggregate) this._record).getFormulaRecord();
            checkFormulaCachedValueType(CellType.NUMERIC, formulaRecord);
            return formulaRecord.getValue();
        } else if (ordinal == 4) {
            return NumericFunction.LOG_10_TO_BASE_e;
        } else {
            throw typeMismatch(CellType.NUMERIC, this._cellType, false);
        }
    }

    @Override // org.apache.poi.ss.usermodel.Cell
    public int getRowIndex() {
        return this._record.getRow();
    }

    @Override // org.apache.poi.ss.usermodel.Cell
    public String getStringCellValue() {
        return getRichStringCellValue().getString();
    }

    @Override // org.apache.poi.ss.usermodel.Cell
    public boolean isPartOfArrayFormulaGroup() {
        if (this._cellType != CellType.FORMULA) {
            return false;
        }
        return ((FormulaRecordAggregate) this._record).isPartOfArrayFormula();
    }

    public void notifyArrayFormulaChanging(String str) {
        if (getArrayFormulaRange().getNumberOfCells() <= 1) {
            getRow().getSheet().removeArrayFormula(this);
            return;
        }
        throw new IllegalStateException(str);
    }

    @Override // org.apache.poi.ss.usermodel.Cell
    public void removeCellComment() {
        HSSFComment findCellComment = this._sheet.findCellComment(this._record.getRow(), this._record.getColumn());
        this._comment = null;
        if (findCellComment != null) {
            this._sheet.getDrawingPatriarch().removeShape(findCellComment);
        }
    }

    @Override // org.apache.poi.ss.usermodel.Cell
    public void removeHyperlink() {
        Iterator<RecordBase> it = this._sheet.getSheet().getRecords().iterator();
        while (it.hasNext()) {
            RecordBase next = it.next();
            if (next instanceof HyperlinkRecord) {
                HyperlinkRecord hyperlinkRecord = (HyperlinkRecord) next;
                if (hyperlinkRecord.getFirstColumn() == this._record.getColumn() && hyperlinkRecord.getFirstRow() == this._record.getRow()) {
                    it.remove();
                    return;
                }
            }
        }
    }

    @Override // org.apache.poi.ss.usermodel.Cell
    public void setAsActiveCell() {
        int row = this._record.getRow();
        short column = this._record.getColumn();
        this._sheet.getSheet().setActiveCellRow(row);
        this._sheet.getSheet().setActiveCellCol(column);
    }

    public void setCellArrayFormula(CellRangeAddress cellRangeAddress) {
        setCellType(CellType.FORMULA, false, this._record.getRow(), this._record.getColumn(), this._record.getXFIndex());
        ((FormulaRecordAggregate) this._record).setParsedExpression(new Ptg[]{new ExpPtg(cellRangeAddress.getFirstRow(), cellRangeAddress.getFirstColumn())});
    }

    @Override // org.apache.poi.ss.usermodel.Cell
    public void setCellComment(Comment comment) {
        if (comment == null) {
            removeCellComment();
            return;
        }
        comment.setRow(this._record.getRow());
        comment.setColumn(this._record.getColumn());
        this._comment = (HSSFComment) comment;
    }

    @Override // org.apache.poi.ss.usermodel.Cell
    public void setCellErrorValue(byte b2) {
        setCellErrorValue(FormulaError.forInt(b2));
    }

    @Override // org.apache.poi.ss.usermodel.Cell
    public void setCellFormula(String str) {
        if (isPartOfArrayFormulaGroup()) {
            notifyArrayFormulaChanging();
        }
        int row = this._record.getRow();
        short column = this._record.getColumn();
        short xFIndex = this._record.getXFIndex();
        if (str == null) {
            notifyFormulaChanging();
            setCellType(CellType.BLANK, false, row, column, xFIndex);
            return;
        }
        Ptg[] parse = HSSFFormulaParser.parse(str, this._book, FormulaType.CELL, this._book.getSheetIndex(this._sheet));
        setCellType(CellType.FORMULA, false, row, column, xFIndex);
        FormulaRecordAggregate formulaRecordAggregate = (FormulaRecordAggregate) this._record;
        FormulaRecord formulaRecord = formulaRecordAggregate.getFormulaRecord();
        formulaRecord.setOptions(2);
        formulaRecord.setValue(NumericFunction.LOG_10_TO_BASE_e);
        if (formulaRecordAggregate.getXFIndex() == 0) {
            formulaRecordAggregate.setXFIndex(15);
        }
        formulaRecordAggregate.setParsedExpression(parse);
    }

    @Override // org.apache.poi.ss.usermodel.Cell
    public void setCellStyle(CellStyle cellStyle) {
        setCellStyle((HSSFCellStyle) cellStyle);
    }

    @Override // org.apache.poi.ss.usermodel.Cell
    public void setCellType(int i2) {
        setCellType(CellType.forInt(i2));
    }

    @Override // org.apache.poi.ss.usermodel.Cell
    public void setCellValue(double d2) {
        if (Double.isInfinite(d2)) {
            setCellErrorValue(FormulaError.DIV0.getCode());
        } else if (Double.isNaN(d2)) {
            setCellErrorValue(FormulaError.NUM.getCode());
        } else {
            int row = this._record.getRow();
            short column = this._record.getColumn();
            short xFIndex = this._record.getXFIndex();
            int ordinal = this._cellType.ordinal();
            if (ordinal != 1) {
                if (ordinal != 3) {
                    setCellType(CellType.NUMERIC, false, row, column, xFIndex);
                } else {
                    ((FormulaRecordAggregate) this._record).setCachedDoubleResult(d2);
                    return;
                }
            }
            ((NumberRecord) this._record).setValue(d2);
        }
    }

    @Override // org.apache.poi.ss.usermodel.Cell
    public void setHyperlink(Hyperlink hyperlink) {
        if (hyperlink == null) {
            removeHyperlink();
            return;
        }
        HSSFHyperlink hSSFHyperlink = (HSSFHyperlink) hyperlink;
        hSSFHyperlink.setFirstRow(this._record.getRow());
        hSSFHyperlink.setLastRow(this._record.getRow());
        hSSFHyperlink.setFirstColumn(this._record.getColumn());
        hSSFHyperlink.setLastColumn(this._record.getColumn());
        int ordinal = hSSFHyperlink.getTypeEnum().ordinal();
        if (ordinal != 1) {
            if (ordinal == 2) {
                hSSFHyperlink.setLabel("place");
            } else if (ordinal != 3) {
                if (ordinal == 4) {
                    hSSFHyperlink.setLabel("file");
                }
            }
            List<RecordBase> records = this._sheet.getSheet().getRecords();
            records.add(records.size() - 1, hSSFHyperlink.record);
        }
        hSSFHyperlink.setLabel("url");
        List<RecordBase> records2 = this._sheet.getSheet().getRecords();
        records2.add(records2.size() - 1, hSSFHyperlink.record);
    }

    public String toString() {
        switch (getCellTypeEnum().ordinal()) {
            case 1:
                if (!DateUtil.isCellDateFormatted(this)) {
                    return String.valueOf(getNumericCellValue());
                }
                SimpleDateFormat simpleDateFormat = new SimpleDateFormat("dd-MMM-yyyy", LocaleUtil.getUserLocale());
                simpleDateFormat.setTimeZone(LocaleUtil.getUserTimeZone());
                return simpleDateFormat.format(getDateCellValue());
            case 2:
                return getStringCellValue();
            case 3:
                return getCellFormula();
            case 4:
                return "";
            case 5:
                return getBooleanCellValue() ? XSSFCell.TRUE : XSSFCell.FALSE;
            case 6:
                return ErrorEval.getText(((BoolErrRecord) this._record).getErrorValue());
            default:
                StringBuilder b2 = a.b("Unknown Cell Type: ");
                b2.append(getCellTypeEnum());
                return b2.toString();
        }
    }

    public void updateCellNum(short s) {
        this._record.setColumn(s);
    }

    @Override // org.apache.poi.ss.usermodel.Cell
    public HSSFComment getCellComment() {
        if (this._comment == null) {
            this._comment = this._sheet.findCellComment(this._record.getRow(), this._record.getColumn());
        }
        return this._comment;
    }

    @Override // org.apache.poi.ss.usermodel.Cell
    public HSSFCellStyle getCellStyle() {
        short xFIndex = this._record.getXFIndex();
        return new HSSFCellStyle(xFIndex, this._book.getWorkbook().getExFormatAt(xFIndex), this._book);
    }

    @Override // org.apache.poi.ss.usermodel.Cell
    public HSSFHyperlink getHyperlink() {
        return this._sheet.getHyperlink(this._record.getRow(), (int) this._record.getColumn());
    }

    @Override // org.apache.poi.ss.usermodel.Cell
    public HSSFRichTextString getRichStringCellValue() {
        int ordinal = this._cellType.ordinal();
        if (ordinal == 2) {
            return this._stringValue;
        }
        String str = "";
        if (ordinal == 3) {
            FormulaRecordAggregate formulaRecordAggregate = (FormulaRecordAggregate) this._record;
            checkFormulaCachedValueType(CellType.STRING, formulaRecordAggregate.getFormulaRecord());
            String stringValue = formulaRecordAggregate.getStringValue();
            if (stringValue != null) {
                str = stringValue;
            }
            return new HSSFRichTextString(str);
        } else if (ordinal == 4) {
            return new HSSFRichTextString(str);
        } else {
            throw typeMismatch(CellType.STRING, this._cellType, false);
        }
    }

    @Override // org.apache.poi.ss.usermodel.Cell
    public HSSFRow getRow() {
        return this._sheet.getRow(getRowIndex());
    }

    @Override // org.apache.poi.ss.usermodel.Cell
    public HSSFSheet getSheet() {
        return this._sheet;
    }

    public void setCellStyle(HSSFCellStyle hSSFCellStyle) {
        short s;
        if (hSSFCellStyle == null) {
            this._record.setXFIndex(15);
            return;
        }
        hSSFCellStyle.verifyBelongsToWorkbook(this._book);
        if (hSSFCellStyle.getUserStyleName() != null) {
            s = applyUserCellStyle(hSSFCellStyle);
        } else {
            s = hSSFCellStyle.getIndex();
        }
        this._record.setXFIndex(s);
    }

    @Override // org.apache.poi.ss.usermodel.Cell
    public void setCellType(CellType cellType) {
        notifyFormulaChanging();
        if (isPartOfArrayFormulaGroup()) {
            notifyArrayFormulaChanging();
        }
        setCellType(cellType, true, this._record.getRow(), this._record.getColumn(), this._record.getXFIndex());
    }

    public void setCellErrorValue(FormulaError formulaError) {
        int row = this._record.getRow();
        short column = this._record.getColumn();
        short xFIndex = this._record.getXFIndex();
        int ordinal = this._cellType.ordinal();
        if (ordinal != 3) {
            if (ordinal != 6) {
                setCellType(CellType.ERROR, false, row, column, xFIndex);
            }
            ((BoolErrRecord) this._record).setValue(formulaError);
            return;
        }
        ((FormulaRecordAggregate) this._record).setCachedErrorResult(formulaError.getCode());
    }

    public void notifyArrayFormulaChanging() {
        CellReference cellReference = new CellReference(this);
        StringBuilder b2 = a.b("Cell ");
        b2.append(cellReference.formatAsString());
        b2.append(" is part of a multi-cell array formula. ");
        b2.append("You cannot change part of an array.");
        notifyArrayFormulaChanging(b2.toString());
    }

    public HSSFCell(HSSFWorkbook hSSFWorkbook, HSSFSheet hSSFSheet, int i2, short s, CellType cellType) {
        checkBounds(s);
        this._cellType = CellType._NONE;
        this._stringValue = null;
        this._book = hSSFWorkbook;
        this._sheet = hSSFSheet;
        setCellType(cellType, false, i2, s, hSSFSheet.getSheet().getXFIndexForColAt(s));
    }

    private void setCellType(CellType cellType, boolean z, int i2, short s, short s2) {
        LabelSSTRecord labelSSTRecord;
        BlankRecord blankRecord;
        FormulaRecordAggregate formulaRecordAggregate;
        NumberRecord numberRecord;
        BoolErrRecord boolErrRecord;
        BoolErrRecord boolErrRecord2;
        switch (cellType.ordinal()) {
            case 1:
                if (cellType != this._cellType) {
                    numberRecord = new NumberRecord();
                } else {
                    numberRecord = (NumberRecord) this._record;
                }
                numberRecord.setColumn(s);
                if (z) {
                    numberRecord.setValue(getNumericCellValue());
                }
                numberRecord.setXFIndex(s2);
                numberRecord.setRow(i2);
                this._record = numberRecord;
                break;
            case 2:
                if (cellType == this._cellType) {
                    labelSSTRecord = (LabelSSTRecord) this._record;
                } else {
                    labelSSTRecord = new LabelSSTRecord();
                    labelSSTRecord.setColumn(s);
                    labelSSTRecord.setRow(i2);
                    labelSSTRecord.setXFIndex(s2);
                }
                if (z) {
                    String convertCellValueToString = convertCellValueToString();
                    if (convertCellValueToString == null) {
                        setCellType(CellType.BLANK, false, i2, s, s2);
                        return;
                    }
                    int addSSTString = this._book.getWorkbook().addSSTString(new UnicodeString(convertCellValueToString));
                    labelSSTRecord.setSSTIndex(addSSTString);
                    UnicodeString sSTString = this._book.getWorkbook().getSSTString(addSSTString);
                    HSSFRichTextString hSSFRichTextString = new HSSFRichTextString();
                    this._stringValue = hSSFRichTextString;
                    hSSFRichTextString.setUnicodeString(sSTString);
                }
                this._record = labelSSTRecord;
                break;
            case 3:
                if (cellType != this._cellType) {
                    formulaRecordAggregate = this._sheet.getSheet().getRowsAggregate().createFormula(i2, s);
                } else {
                    FormulaRecordAggregate formulaRecordAggregate2 = (FormulaRecordAggregate) this._record;
                    formulaRecordAggregate2.setRow(i2);
                    formulaRecordAggregate2.setColumn(s);
                    formulaRecordAggregate = formulaRecordAggregate2;
                }
                if (z) {
                    formulaRecordAggregate.getFormulaRecord().setValue(getNumericCellValue());
                }
                formulaRecordAggregate.setXFIndex(s2);
                this._record = formulaRecordAggregate;
                break;
            case 4:
                if (cellType != this._cellType) {
                    blankRecord = new BlankRecord();
                } else {
                    blankRecord = (BlankRecord) this._record;
                }
                blankRecord.setColumn(s);
                blankRecord.setXFIndex(s2);
                blankRecord.setRow(i2);
                this._record = blankRecord;
                break;
            case 5:
                if (cellType != this._cellType) {
                    boolErrRecord = new BoolErrRecord();
                } else {
                    boolErrRecord = (BoolErrRecord) this._record;
                }
                boolErrRecord.setColumn(s);
                if (z) {
                    boolErrRecord.setValue(convertCellValueToBoolean());
                }
                boolErrRecord.setXFIndex(s2);
                boolErrRecord.setRow(i2);
                this._record = boolErrRecord;
                break;
            case 6:
                if (cellType != this._cellType) {
                    boolErrRecord2 = new BoolErrRecord();
                } else {
                    boolErrRecord2 = (BoolErrRecord) this._record;
                }
                boolErrRecord2.setColumn(s);
                if (z) {
                    boolErrRecord2.setValue(FormulaError.VALUE.getCode());
                }
                boolErrRecord2.setXFIndex(s2);
                boolErrRecord2.setRow(i2);
                this._record = boolErrRecord2;
                break;
            default:
                throw new IllegalStateException("Invalid cell type: " + cellType);
        }
        CellType cellType2 = this._cellType;
        if (!(cellType == cellType2 || cellType2 == CellType._NONE)) {
            this._sheet.getSheet().replaceValueRecord(this._record);
        }
        this._cellType = cellType;
    }

    @Override // org.apache.poi.ss.usermodel.Cell
    public void setCellValue(Date date) {
        setCellValue(DateUtil.getExcelDate(date, this._book.getWorkbook().isUsing1904DateWindowing()));
    }

    @Override // org.apache.poi.ss.usermodel.Cell
    public void setCellValue(Calendar calendar) {
        setCellValue(DateUtil.getExcelDate(calendar, this._book.getWorkbook().isUsing1904DateWindowing()));
    }

    @Override // org.apache.poi.ss.usermodel.Cell
    public void setCellValue(String str) {
        setCellValue(str == null ? null : new HSSFRichTextString(str));
    }

    public HSSFCell(HSSFWorkbook hSSFWorkbook, HSSFSheet hSSFSheet, CellValueRecordInterface cellValueRecordInterface) {
        this._record = cellValueRecordInterface;
        CellType determineType = determineType(cellValueRecordInterface);
        this._cellType = determineType;
        this._stringValue = null;
        this._book = hSSFWorkbook;
        this._sheet = hSSFSheet;
        int ordinal = determineType.ordinal();
        if (ordinal == 2) {
            this._stringValue = new HSSFRichTextString(hSSFWorkbook.getWorkbook(), (LabelSSTRecord) cellValueRecordInterface);
        } else if (ordinal == 3) {
            this._stringValue = new HSSFRichTextString(((FormulaRecordAggregate) cellValueRecordInterface).getStringValue());
        }
    }

    @Override // org.apache.poi.ss.usermodel.Cell
    public void setCellValue(RichTextString richTextString) {
        int row = this._record.getRow();
        short column = this._record.getColumn();
        short xFIndex = this._record.getXFIndex();
        if (richTextString == null) {
            notifyFormulaChanging();
            setCellType(CellType.BLANK, false, row, column, xFIndex);
        } else if (richTextString.length() <= SpreadsheetVersion.EXCEL97.getMaxTextLength()) {
            CellType cellType = this._cellType;
            if (cellType == CellType.FORMULA) {
                ((FormulaRecordAggregate) this._record).setCachedStringResult(richTextString.getString());
                this._stringValue = new HSSFRichTextString(richTextString.getString());
                return;
            }
            CellType cellType2 = CellType.STRING;
            if (cellType != cellType2) {
                setCellType(cellType2, false, row, column, xFIndex);
            }
            HSSFRichTextString hSSFRichTextString = (HSSFRichTextString) richTextString;
            int addSSTString = this._book.getWorkbook().addSSTString(hSSFRichTextString.getUnicodeString());
            ((LabelSSTRecord) this._record).setSSTIndex(addSSTString);
            this._stringValue = hSSFRichTextString;
            hSSFRichTextString.setWorkbookReferences(this._book.getWorkbook(), (LabelSSTRecord) this._record);
            this._stringValue.setUnicodeString(this._book.getWorkbook().getSSTString(addSSTString));
        } else {
            throw new IllegalArgumentException("The maximum length of cell contents (text) is 32,767 characters");
        }
    }

    @Override // org.apache.poi.ss.usermodel.Cell
    public void setCellValue(boolean z) {
        int row = this._record.getRow();
        short column = this._record.getColumn();
        short xFIndex = this._record.getXFIndex();
        int ordinal = this._cellType.ordinal();
        if (ordinal != 3) {
            if (ordinal != 5) {
                setCellType(CellType.BOOLEAN, false, row, column, xFIndex);
            }
            ((BoolErrRecord) this._record).setValue(z);
            return;
        }
        ((FormulaRecordAggregate) this._record).setCachedBooleanResult(z);
    }
}
