package org.apache.poi.hssf.usermodel;

import org.apache.poi.common.usermodel.HyperlinkType;
import org.apache.poi.hssf.record.HyperlinkRecord;
import org.apache.poi.ss.usermodel.Hyperlink;
import org.apache.poi.util.Internal;

public class HSSFHyperlink implements Hyperlink {
    public final HyperlinkType link_type;
    public final HyperlinkRecord record;

    /* renamed from: org.apache.poi.hssf.usermodel.HSSFHyperlink$1  reason: invalid class name */
    public static /* synthetic */ class AnonymousClass1 {
        public static final /* synthetic */ int[] $SwitchMap$org$apache$poi$common$usermodel$HyperlinkType;

        /* JADX WARNING: Failed to process nested try/catch */
        /* JADX WARNING: Missing exception handler attribute for start block: B:11:0x001d */
        static {
            int[] iArr = new int[HyperlinkType.values().length];
            $SwitchMap$org$apache$poi$common$usermodel$HyperlinkType = iArr;
            try {
                HyperlinkType hyperlinkType = HyperlinkType.URL;
                iArr[1] = 1;
            } catch (NoSuchFieldError unused) {
            }
            try {
                int[] iArr2 = $SwitchMap$org$apache$poi$common$usermodel$HyperlinkType;
                HyperlinkType hyperlinkType2 = HyperlinkType.EMAIL;
                iArr2[3] = 2;
            } catch (NoSuchFieldError unused2) {
            }
            int[] iArr3 = $SwitchMap$org$apache$poi$common$usermodel$HyperlinkType;
            HyperlinkType hyperlinkType3 = HyperlinkType.FILE;
            iArr3[4] = 3;
            try {
                int[] iArr4 = $SwitchMap$org$apache$poi$common$usermodel$HyperlinkType;
                HyperlinkType hyperlinkType4 = HyperlinkType.DOCUMENT;
                iArr4[2] = 4;
            } catch (NoSuchFieldError unused3) {
            }
        }
    }

    @Internal(since = "3.15 beta 3")
    public HSSFHyperlink(HyperlinkType hyperlinkType) {
        this.link_type = hyperlinkType;
        this.record = new HyperlinkRecord();
        int ordinal = hyperlinkType.ordinal();
        if (ordinal != 1) {
            if (ordinal == 2) {
                this.record.newDocumentLink();
                return;
            } else if (ordinal != 3) {
                if (ordinal == 4) {
                    this.record.newFileLink();
                    return;
                }
                throw new IllegalArgumentException("Invalid type: " + hyperlinkType);
            }
        }
        this.record.newUrlLink();
    }

    public static HyperlinkType getType(HyperlinkRecord hyperlinkRecord) {
        if (hyperlinkRecord.isFileLink()) {
            return HyperlinkType.FILE;
        }
        if (hyperlinkRecord.isDocumentLink()) {
            return HyperlinkType.DOCUMENT;
        }
        if (hyperlinkRecord.getAddress() == null || !hyperlinkRecord.getAddress().startsWith("mailto:")) {
            return HyperlinkType.URL;
        }
        return HyperlinkType.EMAIL;
    }

    public boolean equals(Object obj) {
        if (this == obj) {
            return true;
        }
        if ((obj instanceof HSSFHyperlink) && this.record == ((HSSFHyperlink) obj).record) {
            return true;
        }
        return false;
    }

    @Override // org.apache.poi.common.usermodel.Hyperlink
    public String getAddress() {
        return this.record.getAddress();
    }

    @Override // org.apache.poi.ss.usermodel.Hyperlink
    public int getFirstColumn() {
        return this.record.getFirstColumn();
    }

    @Override // org.apache.poi.ss.usermodel.Hyperlink
    public int getFirstRow() {
        return this.record.getFirstRow();
    }

    @Override // org.apache.poi.common.usermodel.Hyperlink
    public String getLabel() {
        return this.record.getLabel();
    }

    @Override // org.apache.poi.ss.usermodel.Hyperlink
    public int getLastColumn() {
        return this.record.getLastColumn();
    }

    @Override // org.apache.poi.ss.usermodel.Hyperlink
    public int getLastRow() {
        return this.record.getLastRow();
    }

    public String getShortFilename() {
        return this.record.getShortFilename();
    }

    public String getTextMark() {
        return this.record.getTextMark();
    }

    @Override // org.apache.poi.common.usermodel.Hyperlink
    public HyperlinkType getTypeEnum() {
        return this.link_type;
    }

    public int hashCode() {
        return this.record.hashCode();
    }

    @Override // org.apache.poi.common.usermodel.Hyperlink
    public void setAddress(String str) {
        this.record.setAddress(str);
    }

    @Override // org.apache.poi.ss.usermodel.Hyperlink
    public void setFirstColumn(int i2) {
        this.record.setFirstColumn((short) i2);
    }

    @Override // org.apache.poi.ss.usermodel.Hyperlink
    public void setFirstRow(int i2) {
        this.record.setFirstRow(i2);
    }

    @Override // org.apache.poi.common.usermodel.Hyperlink
    public void setLabel(String str) {
        this.record.setLabel(str);
    }

    @Override // org.apache.poi.ss.usermodel.Hyperlink
    public void setLastColumn(int i2) {
        this.record.setLastColumn((short) i2);
    }

    @Override // org.apache.poi.ss.usermodel.Hyperlink
    public void setLastRow(int i2) {
        this.record.setLastRow(i2);
    }

    public void setShortFilename(String str) {
        this.record.setShortFilename(str);
    }

    public void setTextMark(String str) {
        this.record.setTextMark(str);
    }

    @Override // org.apache.poi.common.usermodel.Hyperlink
    public int getType() {
        return this.link_type.getCode();
    }

    public HSSFHyperlink(HyperlinkRecord hyperlinkRecord) {
        this.record = hyperlinkRecord;
        this.link_type = getType(hyperlinkRecord);
    }

    public HSSFHyperlink(Hyperlink hyperlink) {
        if (hyperlink instanceof HSSFHyperlink) {
            HyperlinkRecord clone = ((HSSFHyperlink) hyperlink).record.clone();
            this.record = clone;
            this.link_type = getType(clone);
            return;
        }
        this.link_type = hyperlink.getTypeEnum();
        this.record = new HyperlinkRecord();
        setFirstRow(hyperlink.getFirstRow());
        setFirstColumn(hyperlink.getFirstColumn());
        setLastRow(hyperlink.getLastRow());
        setLastColumn(hyperlink.getLastColumn());
    }
}
