package org.apache.poi.hssf.usermodel;

import b.b.a.a.a;
import java.util.Iterator;
import java.util.NoSuchElementException;
import org.apache.poi.hssf.record.CellValueRecordInterface;
import org.apache.poi.hssf.record.RowRecord;
import org.apache.poi.ss.SpreadsheetVersion;
import org.apache.poi.ss.usermodel.Cell;
import org.apache.poi.ss.usermodel.CellStyle;
import org.apache.poi.ss.usermodel.CellType;
import org.apache.poi.ss.usermodel.Font;
import org.apache.poi.ss.usermodel.Row;
import org.apache.poi.util.Configurator;

public final class HSSFRow implements Row, Comparable<HSSFRow> {
    public static final int INITIAL_CAPACITY = Configurator.getIntValue("HSSFRow.ColInitialCapacity", 5);
    public final HSSFWorkbook book;
    public HSSFCell[] cells;
    public final RowRecord row;
    public int rowNum;
    public final HSSFSheet sheet;

    /* renamed from: org.apache.poi.hssf.usermodel.HSSFRow$1  reason: invalid class name */
    public static /* synthetic */ class AnonymousClass1 {
        public static final /* synthetic */ int[] $SwitchMap$org$apache$poi$ss$usermodel$Row$MissingCellPolicy;

        /* JADX WARNING: Can't wrap try/catch for region: R(8:0|(2:1|2)|3|5|6|7|8|10) */
        /* JADX WARNING: Code restructure failed: missing block: B:11:?, code lost:
            return;
         */
        /* JADX WARNING: Failed to process nested try/catch */
        /* JADX WARNING: Missing exception handler attribute for start block: B:7:0x0016 */
        static {
            int[] iArr = new int[Row.MissingCellPolicy.values().length];
            $SwitchMap$org$apache$poi$ss$usermodel$Row$MissingCellPolicy = iArr;
            try {
                Row.MissingCellPolicy missingCellPolicy = Row.MissingCellPolicy.RETURN_NULL_AND_BLANK;
                iArr[0] = 1;
            } catch (NoSuchFieldError unused) {
            }
            int[] iArr2 = $SwitchMap$org$apache$poi$ss$usermodel$Row$MissingCellPolicy;
            Row.MissingCellPolicy missingCellPolicy2 = Row.MissingCellPolicy.RETURN_BLANK_AS_NULL;
            iArr2[1] = 2;
            int[] iArr3 = $SwitchMap$org$apache$poi$ss$usermodel$Row$MissingCellPolicy;
            Row.MissingCellPolicy missingCellPolicy3 = Row.MissingCellPolicy.CREATE_NULL_AS_BLANK;
            iArr3[2] = 3;
        }
    }

    public class CellIterator implements Iterator<Cell> {
        public int nextId = -1;
        public int thisId = -1;

        public CellIterator() {
            findNext();
        }

        private void findNext() {
            int i2 = this.nextId;
            do {
                i2++;
                if (i2 >= HSSFRow.this.cells.length) {
                    break;
                }
            } while (HSSFRow.this.cells[i2] == null);
            this.nextId = i2;
        }

        public boolean hasNext() {
            return this.nextId < HSSFRow.this.cells.length;
        }

        public void remove() {
            if (this.thisId != -1) {
                HSSFRow.this.cells[this.thisId] = null;
                return;
            }
            throw new IllegalStateException("remove() called before next()");
        }

        @Override // java.util.Iterator
        public Cell next() {
            if (hasNext()) {
                HSSFCell[] hSSFCellArr = HSSFRow.this.cells;
                int i2 = this.nextId;
                HSSFCell hSSFCell = hSSFCellArr[i2];
                this.thisId = i2;
                findNext();
                return hSSFCell;
            }
            throw new NoSuchElementException("At last element");
        }
    }

    public HSSFRow(HSSFWorkbook hSSFWorkbook, HSSFSheet hSSFSheet, int i2) {
        this(hSSFWorkbook, hSSFSheet, new RowRecord(i2));
    }

    private void addCell(HSSFCell hSSFCell) {
        int columnIndex = hSSFCell.getColumnIndex();
        HSSFCell[] hSSFCellArr = this.cells;
        if (columnIndex >= hSSFCellArr.length) {
            int length = ((hSSFCellArr.length * 3) / 2) + 1;
            if (length < columnIndex + 1) {
                length = INITIAL_CAPACITY + columnIndex;
            }
            HSSFCell[] hSSFCellArr2 = new HSSFCell[length];
            this.cells = hSSFCellArr2;
            System.arraycopy(hSSFCellArr, 0, hSSFCellArr2, 0, hSSFCellArr.length);
        }
        this.cells[columnIndex] = hSSFCell;
        if (this.row.isEmpty() || columnIndex < this.row.getFirstCol()) {
            this.row.setFirstCol((short) columnIndex);
        }
        if (this.row.isEmpty() || columnIndex >= this.row.getLastCol()) {
            this.row.setLastCol((short) (columnIndex + 1));
        }
    }

    private int calculateNewFirstCell(int i2) {
        int i3 = i2 + 1;
        HSSFCell retrieveCell = retrieveCell(i3);
        while (retrieveCell == null) {
            if (i3 <= this.cells.length) {
                return 0;
            }
            i3++;
            retrieveCell = retrieveCell(i3);
        }
        return i3;
    }

    private int calculateNewLastCellPlusOne(int i2) {
        int i3 = i2 - 1;
        HSSFCell retrieveCell = retrieveCell(i3);
        while (retrieveCell == null) {
            if (i3 < 0) {
                return 0;
            }
            i3--;
            retrieveCell = retrieveCell(i3);
        }
        return i3 + 1;
    }

    private HSSFCell retrieveCell(int i2) {
        if (i2 < 0) {
            return null;
        }
        HSSFCell[] hSSFCellArr = this.cells;
        if (i2 >= hSSFCellArr.length) {
            return null;
        }
        return hSSFCellArr[i2];
    }

    @Override // org.apache.poi.ss.usermodel.Row
    public Iterator<Cell> cellIterator() {
        return new CellIterator();
    }

    public HSSFCell createCellFromRecord(CellValueRecordInterface cellValueRecordInterface) {
        HSSFCell hSSFCell = new HSSFCell(this.book, this.sheet, cellValueRecordInterface);
        addCell(hSSFCell);
        short column = cellValueRecordInterface.getColumn();
        if (this.row.isEmpty()) {
            this.row.setFirstCol(column);
            this.row.setLastCol(column + 1);
        } else if (column < this.row.getFirstCol()) {
            this.row.setFirstCol(column);
        } else if (column > this.row.getLastCol()) {
            this.row.setLastCol(column + 1);
        }
        return hSSFCell;
    }

    public boolean equals(Object obj) {
        if (!(obj instanceof HSSFRow)) {
            return false;
        }
        HSSFRow hSSFRow = (HSSFRow) obj;
        if (getRowNum() == hSSFRow.getRowNum() && getSheet() == hSSFRow.getSheet()) {
            return true;
        }
        return false;
    }

    @Override // org.apache.poi.ss.usermodel.Row
    public short getFirstCellNum() {
        if (this.row.isEmpty()) {
            return -1;
        }
        return (short) this.row.getFirstCol();
    }

    @Override // org.apache.poi.ss.usermodel.Row
    public short getHeight() {
        short height = this.row.getHeight();
        return (32768 & height) != 0 ? this.sheet.getSheet().getDefaultRowHeight() : (short) (height & Font.COLOR_NORMAL);
    }

    @Override // org.apache.poi.ss.usermodel.Row
    public float getHeightInPoints() {
        return ((float) getHeight()) / 20.0f;
    }

    @Override // org.apache.poi.ss.usermodel.Row
    public short getLastCellNum() {
        if (this.row.isEmpty()) {
            return -1;
        }
        return (short) this.row.getLastCol();
    }

    @Override // org.apache.poi.ss.usermodel.Row
    public int getOutlineLevel() {
        return this.row.getOutlineLevel();
    }

    @Override // org.apache.poi.ss.usermodel.Row
    public int getPhysicalNumberOfCells() {
        int i2 = 0;
        for (HSSFCell hSSFCell : this.cells) {
            if (hSSFCell != null) {
                i2++;
            }
        }
        return i2;
    }

    @Override // org.apache.poi.ss.usermodel.Row
    public int getRowNum() {
        return this.rowNum;
    }

    public RowRecord getRowRecord() {
        return this.row;
    }

    @Override // org.apache.poi.ss.usermodel.Row
    public boolean getZeroHeight() {
        return this.row.getZeroHeight();
    }

    public int hashCode() {
        return this.row.hashCode();
    }

    @Override // org.apache.poi.ss.usermodel.Row
    public boolean isFormatted() {
        return this.row.getFormatted();
    }

    @Override // java.lang.Iterable
    public Iterator<Cell> iterator() {
        return cellIterator();
    }

    public void moveCell(HSSFCell hSSFCell, short s) {
        HSSFCell[] hSSFCellArr = this.cells;
        if (hSSFCellArr.length > s && hSSFCellArr[s] != null) {
            throw new IllegalArgumentException(a.b("Asked to move cell to column ", s, " but there's already a cell there"));
        } else if (this.cells[hSSFCell.getColumnIndex()].equals(hSSFCell)) {
            removeCell(hSSFCell, false);
            hSSFCell.updateCellNum(s);
            addCell(hSSFCell);
        } else {
            throw new IllegalArgumentException("Asked to move a cell, but it didn't belong to our row");
        }
    }

    public void removeAllCells() {
        HSSFCell[] hSSFCellArr = this.cells;
        for (HSSFCell hSSFCell : hSSFCellArr) {
            if (hSSFCell != null) {
                removeCell(hSSFCell, true);
            }
        }
        this.cells = new HSSFCell[INITIAL_CAPACITY];
    }

    @Override // org.apache.poi.ss.usermodel.Row
    public void removeCell(Cell cell) {
        if (cell != null) {
            removeCell((HSSFCell) cell, true);
            return;
        }
        throw new IllegalArgumentException("cell must not be null");
    }

    @Override // org.apache.poi.ss.usermodel.Row
    public void setHeight(short s) {
        if (s == -1) {
            this.row.setHeight(-32513);
            this.row.setBadFontHeight(false);
            return;
        }
        this.row.setBadFontHeight(true);
        this.row.setHeight(s);
    }

    @Override // org.apache.poi.ss.usermodel.Row
    public void setHeightInPoints(float f2) {
        if (f2 == -1.0f) {
            this.row.setHeight(-32513);
            this.row.setBadFontHeight(false);
            return;
        }
        this.row.setBadFontHeight(true);
        this.row.setHeight((short) ((int) (f2 * 20.0f)));
    }

    @Override // org.apache.poi.ss.usermodel.Row
    public void setRowNum(int i2) {
        int lastRowIndex = SpreadsheetVersion.EXCEL97.getLastRowIndex();
        if (i2 < 0 || i2 > lastRowIndex) {
            throw new IllegalArgumentException(a.b("Invalid row number (", i2, ") outside allowable range (0..", lastRowIndex, ")"));
        }
        this.rowNum = i2;
        RowRecord rowRecord = this.row;
        if (rowRecord != null) {
            rowRecord.setRowNumber(i2);
        }
    }

    public void setRowStyle(HSSFCellStyle hSSFCellStyle) {
        this.row.setFormatted(true);
        this.row.setXFIndex(hSSFCellStyle.getIndex());
    }

    @Override // org.apache.poi.ss.usermodel.Row
    public void setZeroHeight(boolean z) {
        this.row.setZeroHeight(z);
    }

    public HSSFRow(HSSFWorkbook hSSFWorkbook, HSSFSheet hSSFSheet, RowRecord rowRecord) {
        this.book = hSSFWorkbook;
        this.sheet = hSSFSheet;
        this.row = rowRecord;
        setRowNum(rowRecord.getRowNumber());
        this.cells = new HSSFCell[(rowRecord.getLastCol() + INITIAL_CAPACITY)];
        rowRecord.setEmpty();
    }

    public int compareTo(HSSFRow hSSFRow) {
        if (getSheet() == hSSFRow.getSheet()) {
            return Integer.valueOf(getRowNum()).compareTo(Integer.valueOf(hSSFRow.getRowNum()));
        }
        throw new IllegalArgumentException("The compared rows must belong to the same sheet");
    }

    @Override // org.apache.poi.ss.usermodel.Row
    public HSSFCellStyle getRowStyle() {
        if (!isFormatted()) {
            return null;
        }
        short xFIndex = this.row.getXFIndex();
        return new HSSFCellStyle(xFIndex, this.book.getWorkbook().getExFormatAt(xFIndex), this.book);
    }

    @Override // org.apache.poi.ss.usermodel.Row
    public HSSFSheet getSheet() {
        return this.sheet;
    }

    private void removeCell(HSSFCell hSSFCell, boolean z) {
        int columnIndex = hSSFCell.getColumnIndex();
        if (columnIndex >= 0) {
            HSSFCell[] hSSFCellArr = this.cells;
            if (columnIndex >= hSSFCellArr.length || hSSFCell != hSSFCellArr[columnIndex]) {
                throw new RuntimeException("Specified cell is not from this row");
            }
            if (hSSFCell.isPartOfArrayFormulaGroup()) {
                hSSFCell.notifyArrayFormulaChanging();
            }
            this.cells[columnIndex] = null;
            if (z) {
                this.sheet.getSheet().removeValueRecord(getRowNum(), hSSFCell.getCellValueRecord());
            }
            if (hSSFCell.getColumnIndex() + 1 == this.row.getLastCol()) {
                RowRecord rowRecord = this.row;
                rowRecord.setLastCol(calculateNewLastCellPlusOne(rowRecord.getLastCol()));
            }
            if (hSSFCell.getColumnIndex() == this.row.getFirstCol()) {
                RowRecord rowRecord2 = this.row;
                rowRecord2.setFirstCol(calculateNewFirstCell(rowRecord2.getFirstCol()));
                return;
            }
            return;
        }
        throw new RuntimeException("Negative cell indexes not allowed");
    }

    @Override // org.apache.poi.ss.usermodel.Row
    public HSSFCell getCell(int i2) {
        return getCell(i2, this.book.getMissingCellPolicy());
    }

    @Override // org.apache.poi.ss.usermodel.Row
    public void setRowStyle(CellStyle cellStyle) {
        setRowStyle((HSSFCellStyle) cellStyle);
    }

    @Override // org.apache.poi.ss.usermodel.Row
    public HSSFCell createCell(int i2) {
        return createCell(i2, CellType.BLANK);
    }

    @Override // org.apache.poi.ss.usermodel.Row
    public HSSFCell getCell(int i2, Row.MissingCellPolicy missingCellPolicy) {
        HSSFCell retrieveCell = retrieveCell(i2);
        int ordinal = missingCellPolicy.ordinal();
        if (ordinal == 0) {
            return retrieveCell;
        }
        boolean z = true;
        if (ordinal == 1) {
            if (retrieveCell == null || retrieveCell.getCellTypeEnum() != CellType.BLANK) {
                z = false;
            }
            if (z) {
                return null;
            }
            return retrieveCell;
        } else if (ordinal == 2) {
            return retrieveCell == null ? createCell(i2, CellType.BLANK) : retrieveCell;
        } else {
            throw new IllegalArgumentException("Illegal policy " + missingCellPolicy);
        }
    }

    @Override // org.apache.poi.ss.usermodel.Row
    public HSSFCell createCell(int i2, int i3) {
        return createCell(i2, CellType.forInt(i3));
    }

    @Override // org.apache.poi.ss.usermodel.Row
    public HSSFCell createCell(int i2, CellType cellType) {
        short s = (short) i2;
        if (i2 > 32767) {
            s = (short) (65535 - i2);
        }
        HSSFCell hSSFCell = new HSSFCell(this.book, this.sheet, getRowNum(), s, cellType);
        addCell(hSSFCell);
        this.sheet.getSheet().addValueRecord(getRowNum(), hSSFCell.getCellValueRecord());
        return hSSFCell;
    }
}
