package org.apache.poi.hssf.usermodel;

import java.awt.Font;
import java.io.File;
import java.io.FileInputStream;
import java.io.IOException;
import java.io.InputStream;
import java.util.HashMap;
import java.util.Map;
import java.util.Properties;
import org.apache.poi.util.POILogFactory;
import org.apache.poi.util.POILogger;

public final class StaticFontMetrics {
    public static final POILogger LOGGER = POILogFactory.getLogger(StaticFontMetrics.class);
    public static final Map<String, FontDetails> fontDetailsMap = new HashMap();
    public static Properties fontMetricsProps;

    public static synchronized FontDetails getFontDetails(Font font) {
        FontDetails fontDetails;
        synchronized (StaticFontMetrics.class) {
            if (fontMetricsProps == null) {
                try {
                    fontMetricsProps = loadMetrics();
                } catch (IOException e2) {
                    throw new RuntimeException("Could not load font metrics", e2);
                }
            }
            String name = font.getName();
            String str = "";
            if (font.isPlain()) {
                str = "plain";
            }
            if (font.isBold()) {
                str = str + "bold";
            }
            if (font.isItalic()) {
                str = str + "italic";
            }
            String buildFontHeightProperty = FontDetails.buildFontHeightProperty(name);
            String buildFontHeightProperty2 = FontDetails.buildFontHeightProperty(name + "." + str);
            if (fontMetricsProps.get(buildFontHeightProperty) == null && fontMetricsProps.get(buildFontHeightProperty2) != null) {
                name = name + "." + str;
            }
            fontDetails = fontDetailsMap.get(name);
            if (fontDetails == null) {
                fontDetails = FontDetails.create(name, fontMetricsProps);
                fontDetailsMap.put(name, fontDetails);
            }
        }
        return fontDetails;
    }

    /* JADX WARNING: Removed duplicated region for block: B:15:0x004c A[SYNTHETIC, Splitter:B:15:0x004c] */
    /* JADX WARNING: Removed duplicated region for block: B:17:0x0053 A[Catch:{ all -> 0x0071 }] */
    public static Properties loadMetrics() {
        File file;
        InputStream inputStream;
        SecurityException e2;
        InputStream inputStream2 = null;
        try {
            String property = System.getProperty("font.metrics.filename");
            if (property != null) {
                file = new File(property);
                try {
                    if (!file.exists()) {
                        LOGGER.log(5, "font_metrics.properties not found at path " + file.getAbsolutePath());
                    }
                } catch (SecurityException e3) {
                    e2 = e3;
                    LOGGER.log(5, "Can't access font.metrics.filename system property", e2);
                    if (file == null) {
                    }
                    Properties properties = new Properties();
                    properties.load(inputStream);
                    inputStream.close();
                    return properties;
                }
                if (file == null) {
                    try {
                        inputStream = new FileInputStream(file);
                    } catch (Throwable th) {
                        if (0 != 0) {
                            inputStream2.close();
                        }
                        throw th;
                    }
                } else {
                    inputStream = FontDetails.class.getResourceAsStream("/font_metrics.properties");
                    if (inputStream == null) {
                        throw new IOException("font_metrics.properties not found in classpath");
                    }
                }
                Properties properties2 = new Properties();
                properties2.load(inputStream);
                inputStream.close();
                return properties2;
            }
            file = null;
        } catch (SecurityException e4) {
            e2 = e4;
            file = null;
            LOGGER.log(5, "Can't access font.metrics.filename system property", e2);
            if (file == null) {
            }
            Properties properties22 = new Properties();
            properties22.load(inputStream);
            inputStream.close();
            return properties22;
        }
        if (file == null) {
        }
        Properties properties222 = new Properties();
        properties222.load(inputStream);
        inputStream.close();
        return properties222;
    }
}
