package org.apache.poi.hwpf.sprm;

import org.apache.poi.hwpf.usermodel.BorderCode;
import org.apache.poi.hwpf.usermodel.TableCellDescriptor;
import org.apache.poi.hwpf.usermodel.TableProperties;
import org.apache.poi.util.Internal;
import org.apache.poi.util.LittleEndian;
import org.apache.poi.util.POILogFactory;
import org.apache.poi.util.POILogger;

@Internal
public final class TableSprmUncompressor extends SprmUncompressor {
    public static final POILogger logger = POILogFactory.getLogger(TableSprmUncompressor.class);

    /* JADX DEBUG: Multi-variable search result rejected for r5v2, resolved type: int */
    /* JADX WARN: Multi-variable type inference failed */
    public static void unCompressTAPOperation(TableProperties tableProperties, SprmOperation sprmOperation) {
        int i2;
        int operation = sprmOperation.getOperation();
        if (operation != 0) {
            int i3 = 0;
            if (operation == 1) {
                short[] rgdxaCenter = tableProperties.getRgdxaCenter();
                short itcMac = tableProperties.getItcMac();
                int operand = sprmOperation.getOperand() - (tableProperties.getDxaGapHalf() + rgdxaCenter[0]);
                while (i3 < itcMac) {
                    rgdxaCenter[i3] = (short) (rgdxaCenter[i3] + operand);
                    i3++;
                }
            } else if (operation == 2) {
                short[] rgdxaCenter2 = tableProperties.getRgdxaCenter();
                if (rgdxaCenter2 != null) {
                    rgdxaCenter2[0] = (short) (rgdxaCenter2[0] + (tableProperties.getDxaGapHalf() - sprmOperation.getOperand()));
                }
                tableProperties.setDxaGapHalf(sprmOperation.getOperand());
            } else if (operation == 3) {
                tableProperties.setFCantSplit(SprmUncompressor.getFlag(sprmOperation.getOperand()));
            } else if (operation == 4) {
                tableProperties.setFTableHeader(SprmUncompressor.getFlag(sprmOperation.getOperand()));
            } else if (operation == 5) {
                byte[] grpprl = sprmOperation.getGrpprl();
                int grpprlOffset = sprmOperation.getGrpprlOffset();
                tableProperties.setBrcTop(new BorderCode(grpprl, grpprlOffset));
                int i4 = grpprlOffset + 4;
                tableProperties.setBrcLeft(new BorderCode(grpprl, i4));
                int i5 = i4 + 4;
                tableProperties.setBrcBottom(new BorderCode(grpprl, i5));
                int i6 = i5 + 4;
                tableProperties.setBrcRight(new BorderCode(grpprl, i6));
                int i7 = i6 + 4;
                tableProperties.setBrcHorizontal(new BorderCode(grpprl, i7));
                tableProperties.setBrcVertical(new BorderCode(grpprl, i7 + 4));
            } else if (operation == 7) {
                tableProperties.setDyaRowHeight(sprmOperation.getOperand());
            } else if (operation == 8) {
                byte[] grpprl2 = sprmOperation.getGrpprl();
                int grpprlOffset2 = sprmOperation.getGrpprlOffset();
                int i8 = (short) grpprl2[grpprlOffset2];
                int i9 = i8 + 1;
                short[] sArr = new short[i9];
                TableCellDescriptor[] tableCellDescriptorArr = new TableCellDescriptor[i8];
                tableProperties.setItcMac(i8);
                tableProperties.setRgdxaCenter(sArr);
                tableProperties.setRgtc(tableCellDescriptorArr);
                for (int i10 = 0; i10 < i8; i10++) {
                    sArr[i10] = LittleEndian.getShort(grpprl2, (i10 * 2) + 1 + grpprlOffset2);
                }
                int i11 = (i9 * 2) + 1;
                boolean z = grpprlOffset2 + i11 < (sprmOperation.size() + grpprlOffset2) + -6;
                while (i3 < i8) {
                    if (!z || (i2 = (i3 * 20) + i11 + grpprlOffset2) >= grpprl2.length) {
                        tableCellDescriptorArr[i3] = new TableCellDescriptor();
                    } else {
                        tableCellDescriptorArr[i3] = TableCellDescriptor.convertBytesToTC(grpprl2, i2);
                    }
                    i3++;
                }
                sArr[i8] = LittleEndian.getShort(grpprl2, (i8 * 2) + 1 + grpprlOffset2);
            } else if (operation == 33) {
                int operand2 = sprmOperation.getOperand();
                int i12 = (-16777216 & operand2) >> 24;
                int i13 = (16711680 & operand2) >> 16;
                int i14 = operand2 & 65535;
                short itcMac2 = tableProperties.getItcMac();
                int i15 = itcMac2 + i13;
                short[] sArr2 = new short[(i15 + 1)];
                TableCellDescriptor[] tableCellDescriptorArr2 = new TableCellDescriptor[i15];
                if (i12 >= itcMac2) {
                    System.arraycopy(tableProperties.getRgdxaCenter(), 0, sArr2, 0, itcMac2 + 1);
                    System.arraycopy(tableProperties.getRgtc(), 0, tableCellDescriptorArr2, 0, itcMac2);
                    i12 = itcMac2;
                } else {
                    int i16 = i12 + 1;
                    System.arraycopy(tableProperties.getRgdxaCenter(), 0, sArr2, 0, i16);
                    int i17 = i12 + i13;
                    int i18 = itcMac2 - i12;
                    System.arraycopy(tableProperties.getRgdxaCenter(), i16, sArr2, i17, i18);
                    System.arraycopy(tableProperties.getRgtc(), 0, tableCellDescriptorArr2, 0, i12);
                    System.arraycopy(tableProperties.getRgtc(), i12, tableCellDescriptorArr2, i17, i18);
                }
                int i19 = i12;
                while (true) {
                    int i20 = i12 + i13;
                    if (i19 < i20) {
                        tableCellDescriptorArr2[i19] = new TableCellDescriptor();
                        sArr2[i19] = (short) (sArr2[i19 - 1] + i14);
                        i19++;
                    } else {
                        sArr2[i20] = (short) (sArr2[i20 - 1] + i14);
                        return;
                    }
                }
            } else if (operation == 52) {
                byte b2 = sprmOperation.getGrpprl()[sprmOperation.getGrpprlOffset()];
                byte b3 = sprmOperation.getGrpprl()[sprmOperation.getGrpprlOffset() + 1];
                byte b4 = sprmOperation.getGrpprl()[sprmOperation.getGrpprlOffset() + 2];
                byte b5 = sprmOperation.getGrpprl()[sprmOperation.getGrpprlOffset() + 3];
                short s = LittleEndian.getShort(sprmOperation.getGrpprl(), sprmOperation.getGrpprlOffset() + 4);
                byte b6 = b2;
                while (b6 < b3) {
                    TableCellDescriptor tableCellDescriptor = tableProperties.getRgtc()[b6 == 1 ? 1 : 0];
                    if ((b4 & 1) != 0) {
                        tableCellDescriptor.setFtsCellPaddingTop(b5);
                        tableCellDescriptor.setWCellPaddingTop(s);
                    }
                    if ((b4 & 2) != 0) {
                        tableCellDescriptor.setFtsCellPaddingLeft(b5);
                        tableCellDescriptor.setWCellPaddingLeft(s);
                    }
                    if ((b4 & 4) != 0) {
                        tableCellDescriptor.setFtsCellPaddingBottom(b5);
                        tableCellDescriptor.setWCellPaddingBottom(s);
                    }
                    if ((b4 & 8) != 0) {
                        tableCellDescriptor.setFtsCellPaddingRight(b5);
                        tableCellDescriptor.setWCellPaddingRight(s);
                    }
                    b6 = (b6 == 1 ? 1 : 0) + 1;
                }
            }
        } else {
            tableProperties.setJc((short) sprmOperation.getOperand());
        }
    }

    public static TableProperties uncompressTAP(SprmBuffer sprmBuffer) {
        TableProperties tableProperties;
        SprmOperation findSprm = sprmBuffer.findSprm(SprmOperation.SPRM_LONG_TABLE);
        if (findSprm != null) {
            tableProperties = new TableProperties((short) findSprm.getGrpprl()[findSprm.getGrpprlOffset()]);
        } else {
            logger.log(5, "Some table rows didn't specify number of columns in SPRMs");
            tableProperties = new TableProperties(1);
        }
        SprmIterator it = sprmBuffer.iterator();
        while (it.hasNext()) {
            SprmOperation next = it.next();
            if (next.getType() == 5) {
                try {
                    unCompressTAPOperation(tableProperties, next);
                } catch (ArrayIndexOutOfBoundsException e2) {
                    logger.log(7, "Unable to apply ", next, ": ", e2, e2);
                }
            }
        }
        return tableProperties;
    }
}
