package org.apache.poi.hwpf.usermodel;

import b.b.a.a.a;
import java.io.ByteArrayInputStream;
import java.io.ByteArrayOutputStream;
import java.io.IOException;
import java.io.OutputStream;
import java.util.Collections;
import java.util.List;
import java.util.zip.InflaterInputStream;
import org.apache.lucene.codecs.lucene3x.Lucene3xFields;
import org.apache.poi.ddf.EscherBSERecord;
import org.apache.poi.ddf.EscherBlipRecord;
import org.apache.poi.ddf.EscherComplexProperty;
import org.apache.poi.ddf.EscherOptRecord;
import org.apache.poi.ddf.EscherProperty;
import org.apache.poi.ddf.EscherRecord;
import org.apache.poi.hwpf.model.PICF;
import org.apache.poi.hwpf.model.PICFAndOfficeArtData;
import org.apache.poi.hwpf.model.types.CHPAbstractType;
import org.apache.poi.util.POILogFactory;
import org.apache.poi.util.POILogger;
import org.apache.poi.util.PngUtils;
import org.apache.poi.util.StringUtil;

public final class Picture {
    public static final byte[] COMPRESSED1 = {-2, 120, -38};
    public static final byte[] COMPRESSED2 = {-2, 120, -100};
    public static final byte[] IHDR = {73, 72, 68, 82};
    @Deprecated
    public static final byte[] PNG = {-119, 80, 78, 71, 13, 10, CHPAbstractType.KUL_DOT_DOT_DASH_HEAVY, 10};
    public static final POILogger log = POILogFactory.getLogger(Picture.class);
    public final List<? extends EscherRecord> _blipRecords;
    public PICF _picf;
    public PICFAndOfficeArtData _picfAndOfficeArtData;
    public byte[] content;
    public int dataBlockStartOfsset;
    public int height = -1;
    public int width = -1;

    /* renamed from: org.apache.poi.hwpf.usermodel.Picture$1  reason: invalid class name */
    public static /* synthetic */ class AnonymousClass1 {
        public static final /* synthetic */ int[] $SwitchMap$org$apache$poi$hwpf$usermodel$PictureType;

        /* JADX WARNING: Failed to process nested try/catch */
        /* JADX WARNING: Missing exception handler attribute for start block: B:3:0x000f */
        static {
            int[] iArr = new int[PictureType.values().length];
            $SwitchMap$org$apache$poi$hwpf$usermodel$PictureType = iArr;
            PictureType pictureType = PictureType.JPEG;
            iArr[3] = 1;
            try {
                int[] iArr2 = $SwitchMap$org$apache$poi$hwpf$usermodel$PictureType;
                PictureType pictureType2 = PictureType.PNG;
                iArr2[5] = 2;
            } catch (NoSuchFieldError unused) {
            }
        }
    }

    public Picture(EscherBlipRecord escherBlipRecord) {
        this._blipRecords = Collections.singletonList(escherBlipRecord);
    }

    private void fillImageContent() {
        byte[] bArr = this.content;
        if (bArr == null || bArr.length <= 0) {
            byte[] rawContent = getRawContent();
            if (matchSignature(rawContent, COMPRESSED1, 32) || matchSignature(rawContent, COMPRESSED2, 32)) {
                try {
                    InflaterInputStream inflaterInputStream = new InflaterInputStream(new ByteArrayInputStream(rawContent, 33, rawContent.length - 33));
                    ByteArrayOutputStream byteArrayOutputStream = new ByteArrayOutputStream();
                    byte[] bArr2 = new byte[4096];
                    while (true) {
                        int read = inflaterInputStream.read(bArr2);
                        if (read > 0) {
                            byteArrayOutputStream.write(bArr2, 0, read);
                        } else {
                            this.content = byteArrayOutputStream.toByteArray();
                            return;
                        }
                    }
                } catch (IOException e2) {
                    log.log(3, "Possibly corrupt compression or non-compressed data", e2);
                }
            } else {
                this.content = rawContent;
                if (PngUtils.matchesPngHeader(rawContent, 16)) {
                    byte[] bArr3 = this.content;
                    int length = bArr3.length - 16;
                    byte[] bArr4 = new byte[length];
                    System.arraycopy(bArr3, 16, bArr4, 0, length);
                    this.content = bArr4;
                }
            }
        }
    }

    private void fillJPGWidthHeight() {
        byte b2;
        byte b3;
        byte[] content2 = getContent();
        byte b4 = content2[2];
        byte b5 = content2[3];
        int length = content2.length;
        int i2 = 2;
        while (true) {
            int i3 = length - 1;
            if (i2 < i3) {
                do {
                    b2 = content2[i2];
                    b3 = content2[i2 + 1];
                    i2 += 2;
                    if (b2 == -1) {
                        break;
                    }
                } while (i2 < i3);
                if (b2 != -1 || i2 >= i3) {
                    i2++;
                } else if (b3 != -39 && b3 != -38) {
                    if ((b3 & Lucene3xFields.PreTermsEnum.UTF8_NON_BMP_LEAD) != 192 || b3 == -60 || b3 == -56 || b3 == -52) {
                        int i4 = i2 + 1 + 1;
                        i2 = i4 + getBigEndianShort(content2, i4);
                    } else {
                        int i5 = i2 + 5;
                        this.height = getBigEndianShort(content2, i5);
                        this.width = getBigEndianShort(content2, i5 + 2);
                        return;
                    }
                } else {
                    return;
                }
            } else {
                return;
            }
        }
    }

    private void fillWidthHeight() {
        int ordinal = suggestPictureType().ordinal();
        if (ordinal == 3) {
            fillJPGWidthHeight();
        } else if (ordinal == 5) {
            fillPNGWidthHeight();
        }
    }

    public static int getBigEndianInt(byte[] bArr, int i2) {
        return ((bArr[i2] & 255) << 24) + ((bArr[i2 + 1] & 255) << 16) + ((bArr[i2 + 2] & 255) << 8) + (bArr[i2 + 3] & 255);
    }

    public static int getBigEndianShort(byte[] bArr, int i2) {
        return ((bArr[i2] & 255) << 8) + (bArr[i2 + 1] & 255);
    }

    public static boolean matchSignature(byte[] bArr, byte[] bArr2, int i2) {
        boolean z = i2 < bArr.length;
        int i3 = 0;
        while (true) {
            int i4 = i3 + i2;
            if (i4 < bArr.length && i3 < bArr2.length) {
                if (bArr[i4] != bArr2[i3]) {
                    return false;
                }
                i3++;
            }
        }
        return z;
    }

    public void fillPNGWidthHeight() {
        byte[] content2 = getContent();
        int length = PNG.length + 4;
        if (matchSignature(content2, IHDR, length)) {
            int i2 = length + 4;
            this.width = getBigEndianInt(content2, i2);
            this.height = getBigEndianInt(content2, i2 + 4);
        }
    }

    public byte[] getContent() {
        fillImageContent();
        return this.content;
    }

    public String getDescription() {
        for (EscherRecord escherRecord : this._picfAndOfficeArtData.getShape().getChildRecords()) {
            if (escherRecord instanceof EscherOptRecord) {
                for (EscherProperty escherProperty : ((EscherOptRecord) escherRecord).getEscherProperties()) {
                    if (897 == escherProperty.getPropertyNumber()) {
                        byte[] complexData = ((EscherComplexProperty) escherProperty).getComplexData();
                        return StringUtil.getFromUnicodeLE(complexData, 0, (complexData.length / 2) - 1);
                    }
                }
                continue;
            }
        }
        return null;
    }

    @Deprecated
    public int getDxaCropLeft() {
        return this._picf.getDxaReserved1();
    }

    @Deprecated
    public int getDxaCropRight() {
        return this._picf.getDxaReserved2();
    }

    public int getDxaGoal() {
        return this._picf.getDxaGoal();
    }

    @Deprecated
    public int getDyaCropBottom() {
        return this._picf.getDyaReserved2();
    }

    @Deprecated
    public int getDyaCropTop() {
        return this._picf.getDyaReserved1();
    }

    public int getDyaGoal() {
        return this._picf.getDyaGoal();
    }

    public int getHeight() {
        if (this.height == -1) {
            fillWidthHeight();
        }
        return this.height;
    }

    public int getHorizontalScalingFactor() {
        return this._picf.getMx();
    }

    public String getMimeType() {
        return suggestPictureType().getMime();
    }

    public byte[] getRawContent() {
        EscherBlipRecord blipRecord;
        List<? extends EscherRecord> list = this._blipRecords;
        if (list == null || list.size() != 1) {
            return new byte[0];
        }
        EscherRecord escherRecord = (EscherRecord) this._blipRecords.get(0);
        if (escherRecord instanceof EscherBlipRecord) {
            return ((EscherBlipRecord) escherRecord).getPicturedata();
        }
        return (!(escherRecord instanceof EscherBSERecord) || (blipRecord = ((EscherBSERecord) escherRecord).getBlipRecord()) == null) ? new byte[0] : blipRecord.getPicturedata();
    }

    public int getSize() {
        return getContent().length;
    }

    public int getStartOffset() {
        return this.dataBlockStartOfsset;
    }

    public int getVerticalScalingFactor() {
        return this._picf.getMy();
    }

    public int getWidth() {
        if (this.width == -1) {
            fillWidthHeight();
        }
        return this.width;
    }

    public String suggestFileExtension() {
        return suggestPictureType().getExtension();
    }

    public String suggestFullFileName() {
        String suggestFileExtension = suggestFileExtension();
        StringBuilder sb = new StringBuilder();
        sb.append(Integer.toHexString(this.dataBlockStartOfsset));
        sb.append(suggestFileExtension.length() > 0 ? a.b(".", suggestFileExtension) : "");
        return sb.toString();
    }

    public PictureType suggestPictureType() {
        List<? extends EscherRecord> list = this._blipRecords;
        if (list == null || list.size() != 1) {
            return PictureType.UNKNOWN;
        }
        EscherRecord escherRecord = (EscherRecord) this._blipRecords.get(0);
        short recordId = escherRecord.getRecordId();
        if (recordId == -4089) {
            byte blipTypeWin32 = ((EscherBSERecord) escherRecord).getBlipTypeWin32();
            if (blipTypeWin32 == 17) {
                return PictureType.TIFF;
            }
            if (blipTypeWin32 == 18) {
                return PictureType.JPEG;
            }
            switch (blipTypeWin32) {
                case 0:
                    return PictureType.UNKNOWN;
                case 1:
                    return PictureType.UNKNOWN;
                case 2:
                    return PictureType.EMF;
                case 3:
                    return PictureType.WMF;
                case 4:
                    return PictureType.PICT;
                case 5:
                    return PictureType.JPEG;
                case 6:
                    return PictureType.PNG;
                case 7:
                    return PictureType.BMP;
                default:
                    return PictureType.UNKNOWN;
            }
        } else if (recordId == -4055) {
            return PictureType.TIFF;
        } else {
            if (recordId == -4054) {
                return PictureType.JPEG;
            }
            switch (recordId) {
                case -4070:
                    return PictureType.EMF;
                case -4069:
                    return PictureType.WMF;
                case -4068:
                    return PictureType.PICT;
                case -4067:
                    return PictureType.JPEG;
                case -4066:
                    return PictureType.PNG;
                case -4065:
                    return PictureType.BMP;
                default:
                    return PictureType.UNKNOWN;
            }
        }
    }

    public void writeImageContent(OutputStream outputStream) {
        byte[] content2 = getContent();
        if (content2 != null && content2.length > 0) {
            outputStream.write(content2, 0, content2.length);
        }
    }

    public Picture(int i2, byte[] bArr, boolean z) {
        PICFAndOfficeArtData pICFAndOfficeArtData = new PICFAndOfficeArtData(bArr, i2);
        this._picfAndOfficeArtData = pICFAndOfficeArtData;
        this._picf = pICFAndOfficeArtData.getPicf();
        this.dataBlockStartOfsset = i2;
        if (this._picfAndOfficeArtData.getBlipRecords() != null) {
            this._blipRecords = this._picfAndOfficeArtData.getBlipRecords();
        } else {
            this._blipRecords = Collections.emptyList();
        }
        if (z) {
            fillImageContent();
        }
    }
}
