package org.apache.poi.openxml4j.opc.internal;

import b.b.a.a.a;
import java.io.File;
import java.io.FileInputStream;
import java.io.FileNotFoundException;
import java.io.IOException;
import java.io.InputStream;
import java.io.PushbackInputStream;
import java.net.URI;
import java.net.URISyntaxException;
import java.util.Enumeration;
import java.util.zip.ZipEntry;
import java.util.zip.ZipFile;
import java.util.zip.ZipInputStream;
import org.apache.poi.openxml4j.exceptions.NotOfficeXmlFileException;
import org.apache.poi.openxml4j.exceptions.OLE2NotOfficeXmlFileException;
import org.apache.poi.openxml4j.opc.PackageRelationship;
import org.apache.poi.openxml4j.opc.PackageRelationshipTypes;
import org.apache.poi.openxml4j.opc.ZipPackage;
import org.apache.poi.openxml4j.util.ZipSecureFile;
import org.apache.poi.poifs.common.POIFSConstants;
import org.apache.poi.poifs.storage.HeaderBlockConstants;
import org.apache.poi.util.IOUtils;
import org.apache.poi.util.LittleEndian;
import org.apache.poi.util.Removal;

public final class ZipHelper {
    public static final String FORWARD_SLASH = "/";
    @Removal(version = "3.18")
    @Deprecated
    public static final int READ_WRITE_FILE_BUFFER_SIZE = 8192;

    public static ZipEntry getContentTypeZipEntry(ZipPackage zipPackage) {
        Enumeration<? extends ZipEntry> entries = zipPackage.getZipArchive().getEntries();
        while (entries.hasMoreElements()) {
            ZipEntry zipEntry = (ZipEntry) entries.nextElement();
            if (zipEntry.getName().equals(ContentTypeManager.CONTENT_TYPES_PART_NAME)) {
                return zipEntry;
            }
        }
        return null;
    }

    public static ZipEntry getCorePropertiesZipEntry(ZipPackage zipPackage) {
        PackageRelationship relationship = zipPackage.getRelationshipsByType(PackageRelationshipTypes.CORE_PROPERTIES).getRelationship(0);
        if (relationship == null) {
            return null;
        }
        return new ZipEntry(relationship.getTargetURI().getPath());
    }

    public static String getOPCNameFromZipItemName(String str) {
        if (str == null) {
            throw new IllegalArgumentException("zipItemName cannot be null");
        } else if (str.startsWith(FORWARD_SLASH)) {
            return str;
        } else {
            return a.b(FORWARD_SLASH, str);
        }
    }

    public static String getZipItemNameFromOPCName(String str) {
        if (str != null) {
            while (str.startsWith(FORWARD_SLASH)) {
                str = str.substring(1);
            }
            return str;
        }
        throw new IllegalArgumentException("opcItemName cannot be null");
    }

    public static URI getZipURIFromOPCName(String str) {
        if (str != null) {
            while (str.startsWith(FORWARD_SLASH)) {
                str = str.substring(1);
            }
            try {
                return new URI(str);
            } catch (URISyntaxException unused) {
                return null;
            }
        } else {
            throw new IllegalArgumentException("opcItemName");
        }
    }

    /* JADX INFO: finally extract failed */
    public static ZipFile openZipFile(File file) {
        if (!file.exists()) {
            throw new FileNotFoundException("File does not exist");
        } else if (!file.isDirectory()) {
            FileInputStream fileInputStream = new FileInputStream(file);
            try {
                verifyZipHeader(fileInputStream);
                fileInputStream.close();
                return new ZipSecureFile(file);
            } catch (Throwable th) {
                fileInputStream.close();
                throw th;
            }
        } else {
            throw new IOException("File is a directory");
        }
    }

    public static ZipSecureFile.ThresholdInputStream openZipStream(InputStream inputStream) {
        InputStream prepareToCheckHeader = prepareToCheckHeader(inputStream);
        verifyZipHeader(prepareToCheckHeader);
        return ZipSecureFile.addThreshold(new ZipInputStream(prepareToCheckHeader));
    }

    public static InputStream prepareToCheckHeader(InputStream inputStream) {
        if (inputStream instanceof PushbackInputStream) {
            return inputStream;
        }
        if (!inputStream.markSupported()) {
            return new PushbackInputStream(inputStream, 8);
        }
        inputStream.mark(8);
        return inputStream;
    }

    public static void verifyZipHeader(InputStream inputStream) {
        byte[] bArr = new byte[8];
        IOUtils.readFully(inputStream, bArr);
        if (LittleEndian.getLong(bArr) != HeaderBlockConstants._signature) {
            byte[] bArr2 = POIFSConstants.RAW_XML_FILE_HEADER;
            if (bArr[0] == bArr2[0] && bArr[1] == bArr2[1] && bArr[2] == bArr2[2] && bArr[3] == bArr2[3] && bArr[4] == bArr2[4]) {
                throw new NotOfficeXmlFileException("The supplied data appears to be a raw XML file. Formats such as Office 2003 XML are not supported");
            } else if (inputStream instanceof PushbackInputStream) {
                ((PushbackInputStream) inputStream).unread(bArr);
            } else if (inputStream.markSupported()) {
                inputStream.reset();
            } else {
                boolean z = inputStream instanceof FileInputStream;
            }
        } else {
            throw new OLE2NotOfficeXmlFileException("The supplied data appears to be in the OLE2 Format. You are calling the part of POI that deals with OOXML (Office Open XML) Documents. You need to call a different part of POI to process this data (eg HSSF instead of XSSF)");
        }
    }

    public static ZipFile openZipFile(String str) {
        return openZipFile(new File(str));
    }
}
