package org.apache.poi.poifs.filesystem;

import java.io.FileNotFoundException;
import java.io.IOException;
import java.util.HashMap;
import java.util.Iterator;
import java.util.List;
import org.apache.poi.util.Internal;

@Internal
public class EntryUtils {
    public static boolean areDirectoriesIdentical(DirectoryEntry directoryEntry, DirectoryEntry directoryEntry2) {
        boolean z;
        int i2;
        if (!directoryEntry.getName().equals(directoryEntry2.getName()) || directoryEntry.getEntryCount() != directoryEntry2.getEntryCount()) {
            return false;
        }
        HashMap hashMap = new HashMap();
        Iterator it = directoryEntry.iterator();
        while (it.hasNext()) {
            Entry entry = (Entry) it.next();
            String name = entry.getName();
            if (entry.isDirectoryEntry()) {
                hashMap.put(name, -12345);
            } else {
                hashMap.put(name, Integer.valueOf(((DocumentNode) entry).getSize()));
            }
        }
        Iterator it2 = directoryEntry2.iterator();
        while (it2.hasNext()) {
            Entry entry2 = (Entry) it2.next();
            String name2 = entry2.getName();
            if (!hashMap.containsKey(name2)) {
                return false;
            }
            if (entry2.isDirectoryEntry()) {
                i2 = -12345;
            } else {
                i2 = ((DocumentNode) entry2).getSize();
            }
            if (i2 != ((Integer) hashMap.get(name2)).intValue()) {
                return false;
            }
            hashMap.remove(name2);
        }
        if (!hashMap.isEmpty()) {
            return false;
        }
        Iterator it3 = directoryEntry.iterator();
        while (it3.hasNext()) {
            Entry entry3 = (Entry) it3.next();
            try {
                Entry entry4 = directoryEntry2.getEntry(entry3.getName());
                if (entry3.isDirectoryEntry()) {
                    z = areDirectoriesIdentical((DirectoryEntry) entry3, (DirectoryEntry) entry4);
                    continue;
                } else {
                    z = areDocumentsIdentical((DocumentEntry) entry3, (DocumentEntry) entry4);
                    continue;
                }
                if (!z) {
                    return false;
                }
            } catch (FileNotFoundException | IOException unused) {
            }
        }
        return true;
    }

    /* JADX WARNING: Code restructure failed: missing block: B:17:0x0037, code lost:
        r1 = true;
     */
    /* JADX WARNING: Removed duplicated region for block: B:27:0x0049  */
    /* JADX WARNING: Removed duplicated region for block: B:29:0x004e  */
    public static boolean areDocumentsIdentical(DocumentEntry documentEntry, DocumentEntry documentEntry2) {
        Throwable th;
        DocumentInputStream documentInputStream;
        boolean z = false;
        if (!documentEntry.getName().equals(documentEntry2.getName()) || documentEntry.getSize() != documentEntry2.getSize()) {
            return false;
        }
        DocumentInputStream documentInputStream2 = null;
        try {
            DocumentInputStream documentInputStream3 = new DocumentInputStream(documentEntry);
            try {
                documentInputStream = new DocumentInputStream(documentEntry2);
                while (true) {
                    try {
                        int read = documentInputStream3.read();
                        int read2 = documentInputStream.read();
                        if (read == read2) {
                            if (read != -1) {
                                if (read2 == -1) {
                                    break;
                                }
                            } else {
                                break;
                            }
                        } else {
                            break;
                        }
                    } catch (Throwable th2) {
                        th = th2;
                        documentInputStream2 = documentInputStream3;
                        if (documentInputStream2 != null) {
                        }
                        if (documentInputStream != null) {
                        }
                        throw th;
                    }
                }
                documentInputStream3.close();
                documentInputStream.close();
                return z;
            } catch (Throwable th3) {
                th = th3;
                documentInputStream = null;
                documentInputStream2 = documentInputStream3;
                if (documentInputStream2 != null) {
                    documentInputStream2.close();
                }
                if (documentInputStream != null) {
                    documentInputStream.close();
                }
                throw th;
            }
        } catch (Throwable th4) {
            th = th4;
            documentInputStream = null;
            if (documentInputStream2 != null) {
            }
            if (documentInputStream != null) {
            }
            throw th;
        }
    }

    @Internal
    public static void copyNodeRecursively(Entry entry, DirectoryEntry directoryEntry) {
        if (entry.isDirectoryEntry()) {
            DirectoryEntry directoryEntry2 = (DirectoryEntry) entry;
            DirectoryEntry createDirectory = directoryEntry.createDirectory(entry.getName());
            createDirectory.setStorageClsid(directoryEntry2.getStorageClsid());
            Iterator<Entry> entries = directoryEntry2.getEntries();
            while (entries.hasNext()) {
                copyNodeRecursively(entries.next(), createDirectory);
            }
            return;
        }
        DocumentEntry documentEntry = (DocumentEntry) entry;
        DocumentInputStream documentInputStream = new DocumentInputStream(documentEntry);
        directoryEntry.createDocument(documentEntry.getName(), documentInputStream);
        documentInputStream.close();
    }

    public static void copyNodes(DirectoryEntry directoryEntry, DirectoryEntry directoryEntry2) {
        Iterator it = directoryEntry.iterator();
        while (it.hasNext()) {
            copyNodeRecursively((Entry) it.next(), directoryEntry2);
        }
    }

    public static void copyNodes(FilteringDirectoryNode filteringDirectoryNode, FilteringDirectoryNode filteringDirectoryNode2) {
        copyNodes((DirectoryEntry) filteringDirectoryNode, (DirectoryEntry) filteringDirectoryNode2);
    }

    public static void copyNodes(OPOIFSFileSystem oPOIFSFileSystem, OPOIFSFileSystem oPOIFSFileSystem2) {
        copyNodes(oPOIFSFileSystem.getRoot(), oPOIFSFileSystem2.getRoot());
    }

    public static void copyNodes(NPOIFSFileSystem nPOIFSFileSystem, NPOIFSFileSystem nPOIFSFileSystem2) {
        copyNodes(nPOIFSFileSystem.getRoot(), nPOIFSFileSystem2.getRoot());
    }

    public static void copyNodes(OPOIFSFileSystem oPOIFSFileSystem, OPOIFSFileSystem oPOIFSFileSystem2, List<String> list) {
        copyNodes(new FilteringDirectoryNode(oPOIFSFileSystem.getRoot(), list), new FilteringDirectoryNode(oPOIFSFileSystem2.getRoot(), list));
    }

    public static void copyNodes(NPOIFSFileSystem nPOIFSFileSystem, NPOIFSFileSystem nPOIFSFileSystem2, List<String> list) {
        copyNodes(new FilteringDirectoryNode(nPOIFSFileSystem.getRoot(), list), new FilteringDirectoryNode(nPOIFSFileSystem2.getRoot(), list));
    }
}
