package org.apache.poi.poifs.filesystem;

import java.io.BufferedInputStream;
import java.io.IOException;
import java.io.InputStream;
import java.lang.reflect.Array;
import org.apache.poi.poifs.common.POIFSConstants;
import org.apache.poi.poifs.storage.HeaderBlockConstants;
import org.apache.poi.util.IOUtils;
import org.apache.poi.util.LittleEndian;
import org.apache.poi.util.LocaleUtil;

public enum FileMagic {
    OLE2((long) HeaderBlockConstants._signature),
    OOXML(POIFSConstants.OOXML_FILE_HEADER),
    XML(POIFSConstants.RAW_XML_FILE_HEADER),
    BIFF2(new byte[]{9, 0, 4, 0, 0, 0, 112, 0}),
    BIFF3(new byte[]{9, 2, 6, 0, 0, 0, 112, 0}),
    BIFF4(new byte[]{9, 4, 6, 0, 0, 0, 112, 0}, new byte[]{9, 4, 6, 0, 0, 0, 0, 1}),
    MSWRITE(new byte[]{49, -66, 0, 0}, new byte[]{50, -66, 0, 0}),
    RTF("{\\rtf"),
    PDF("%PDF"),
    UNKNOWN(new byte[0]);
    
    public final byte[][] magic;

    /* access modifiers changed from: public */
    FileMagic(long j) {
        byte[][] bArr = (byte[][]) Array.newInstance(byte.class, 1, 8);
        this.magic = bArr;
        LittleEndian.putLong(bArr[0], 0, j);
    }

    public static InputStream prepareToCheckMagic(InputStream inputStream) {
        if (inputStream.markSupported()) {
            return inputStream;
        }
        return new BufferedInputStream(inputStream);
    }

    /* JADX WARNING: Code restructure failed: missing block: B:16:0x0031, code lost:
        r9 = r14;
        r7 = false;
     */
    public static FileMagic valueOf(byte[] bArr) {
        FileMagic[] values = values();
        for (FileMagic fileMagic : values) {
            byte[][] bArr2 = fileMagic.magic;
            boolean z = true;
            int i2 = 0;
            for (byte[] bArr3 : bArr2) {
                int length = bArr3.length;
                int i3 = 0;
                while (true) {
                    if (i3 >= length) {
                        break;
                    }
                    byte b2 = bArr3[i3];
                    int i4 = i2 + 1;
                    byte b3 = bArr[i2];
                    if (b3 == b2 || (b2 == 112 && (b3 == 16 || b3 == 32 || b3 == 64))) {
                        i3++;
                        i2 = i4;
                    }
                }
                if (z) {
                    return fileMagic;
                }
            }
        }
        return UNKNOWN;
    }

    /* access modifiers changed from: public */
    FileMagic(byte[]... bArr) {
        this.magic = bArr;
    }

    /* access modifiers changed from: public */
    FileMagic(String str) {
        this(str.getBytes(LocaleUtil.CHARSET_1252));
    }

    public static FileMagic valueOf(InputStream inputStream) {
        if (inputStream.markSupported()) {
            return valueOf(IOUtils.peekFirst8Bytes(inputStream));
        }
        throw new IOException("getFileMagic() only operates on streams which support mark(int)");
    }
}
