package org.apache.poi.poifs.filesystem;

import b.b.a.a.a;
import java.io.ByteArrayInputStream;
import java.io.Closeable;
import java.io.File;
import java.io.FileInputStream;
import java.io.FileOutputStream;
import java.io.IOException;
import java.io.InputStream;
import java.io.OutputStream;
import java.nio.ByteBuffer;
import java.nio.channels.Channels;
import java.nio.channels.FileChannel;
import java.nio.channels.ReadableByteChannel;
import java.util.ArrayList;
import java.util.Collections;
import java.util.Iterator;
import java.util.List;
import org.apache.poi.EmptyFileException;
import org.apache.poi.poifs.common.POIFSBigBlockSize;
import org.apache.poi.poifs.common.POIFSConstants;
import org.apache.poi.poifs.dev.POIFSViewable;
import org.apache.poi.poifs.filesystem.BlockStore;
import org.apache.poi.poifs.nio.ByteArrayBackedDataSource;
import org.apache.poi.poifs.nio.DataSource;
import org.apache.poi.poifs.nio.FileBackedDataSource;
import org.apache.poi.poifs.property.DirectoryProperty;
import org.apache.poi.poifs.property.DocumentProperty;
import org.apache.poi.poifs.property.NPropertyTable;
import org.apache.poi.poifs.storage.BATBlock;
import org.apache.poi.poifs.storage.BlockAllocationTableReader;
import org.apache.poi.poifs.storage.BlockAllocationTableWriter;
import org.apache.poi.poifs.storage.HeaderBlock;
import org.apache.poi.poifs.storage.HeaderBlockWriter;
import org.apache.poi.util.CloseIgnoringInputStream;
import org.apache.poi.util.IOUtils;
import org.apache.poi.util.Internal;
import org.apache.poi.util.POILogFactory;
import org.apache.poi.util.POILogger;
import org.apache.poi.util.Removal;

public class NPOIFSFileSystem extends BlockStore implements POIFSViewable, Closeable {
    public static final POILogger LOG = POILogFactory.getLogger(NPOIFSFileSystem.class);
    public List<BATBlock> _bat_blocks;
    public DataSource _data;
    public HeaderBlock _header;
    public NPOIFSMiniStore _mini_store;
    public NPropertyTable _property_table;
    public DirectoryNode _root;
    public List<BATBlock> _xbat_blocks;
    public POIFSBigBlockSize bigBlockSize;

    public NPOIFSFileSystem(boolean z) {
        POIFSBigBlockSize pOIFSBigBlockSize = POIFSConstants.SMALLER_BIG_BLOCK_SIZE_DETAILS;
        this.bigBlockSize = pOIFSBigBlockSize;
        this._header = new HeaderBlock(pOIFSBigBlockSize);
        NPropertyTable nPropertyTable = new NPropertyTable(this._header);
        this._property_table = nPropertyTable;
        this._mini_store = new NPOIFSMiniStore(this, nPropertyTable.getRoot(), new ArrayList(), this._header);
        this._xbat_blocks = new ArrayList();
        this._bat_blocks = new ArrayList();
        this._root = null;
        if (z) {
            this._data = new ByteArrayBackedDataSource(new byte[(this.bigBlockSize.getBigBlockSize() * 3)]);
        }
    }

    private void closeInputStream(InputStream inputStream, boolean z) {
        try {
            inputStream.close();
        } catch (IOException e2) {
            if (!z) {
                LOG.log(7, "can't close input stream", e2);
                return;
            }
            throw new RuntimeException(e2);
        }
    }

    private BATBlock createBAT(int i2, boolean z) {
        BATBlock createEmptyBATBlock = BATBlock.createEmptyBATBlock(this.bigBlockSize, !z);
        createEmptyBATBlock.setOurBlockIndex(i2);
        this._data.write(ByteBuffer.allocate(this.bigBlockSize.getBigBlockSize()), (long) (this.bigBlockSize.getBigBlockSize() * (i2 + 1)));
        return createEmptyBATBlock;
    }

    public static InputStream createNonClosingInputStream(InputStream inputStream) {
        return new CloseIgnoringInputStream(inputStream);
    }

    @Removal(version = "4.0")
    @Deprecated
    public static boolean hasPOIFSHeader(InputStream inputStream) {
        return FileMagic.valueOf(inputStream) == FileMagic.OLE2;
    }

    /* JADX INFO: finally extract failed */
    public static void main(String[] strArr) {
        if (strArr.length != 2) {
            System.err.println("two arguments required: input filename and output filename");
            System.exit(1);
        }
        FileInputStream fileInputStream = new FileInputStream(strArr[0]);
        try {
            FileOutputStream fileOutputStream = new FileOutputStream(strArr[1]);
            try {
                NPOIFSFileSystem nPOIFSFileSystem = new NPOIFSFileSystem(fileInputStream);
                try {
                    nPOIFSFileSystem.writeFilesystem(fileOutputStream);
                    nPOIFSFileSystem.close();
                    fileOutputStream.close();
                } catch (Throwable th) {
                    nPOIFSFileSystem.close();
                    throw th;
                }
            } catch (Throwable th2) {
                fileOutputStream.close();
                throw th2;
            }
        } finally {
            fileInputStream.close();
        }
    }

    private void readBAT(int i2, BlockStore.ChainLoopDetector chainLoopDetector) {
        chainLoopDetector.claim(i2);
        BATBlock createBATBlock = BATBlock.createBATBlock(this.bigBlockSize, getBlockAt(i2));
        createBATBlock.setOurBlockIndex(i2);
        this._bat_blocks.add(createBATBlock);
    }

    private void readCoreContents() {
        this.bigBlockSize = this._header.getBigBlockSize();
        BlockStore.ChainLoopDetector chainLoopDetector = getChainLoopDetector();
        for (int i2 : this._header.getBATArray()) {
            readBAT(i2, chainLoopDetector);
        }
        int bATCount = this._header.getBATCount() - this._header.getBATArray().length;
        int xBATIndex = this._header.getXBATIndex();
        for (int i3 = 0; i3 < this._header.getXBATCount(); i3++) {
            chainLoopDetector.claim(xBATIndex);
            BATBlock createBATBlock = BATBlock.createBATBlock(this.bigBlockSize, getBlockAt(xBATIndex));
            createBATBlock.setOurBlockIndex(xBATIndex);
            xBATIndex = createBATBlock.getValueAt(this.bigBlockSize.getXBATEntriesPerBlock());
            this._xbat_blocks.add(createBATBlock);
            int min = Math.min(bATCount, this.bigBlockSize.getXBATEntriesPerBlock());
            for (int i4 = 0; i4 < min; i4++) {
                int valueAt = createBATBlock.getValueAt(i4);
                if (valueAt == -1 || valueAt == -2) {
                    break;
                }
                readBAT(valueAt, chainLoopDetector);
            }
            bATCount -= min;
        }
        this._property_table = new NPropertyTable(this._header, this);
        ArrayList arrayList = new ArrayList();
        this._mini_store = new NPOIFSMiniStore(this, this._property_table.getRoot(), arrayList, this._header);
        int sBATStart = this._header.getSBATStart();
        for (int i5 = 0; i5 < this._header.getSBATCount() && sBATStart != -2; i5++) {
            chainLoopDetector.claim(sBATStart);
            BATBlock createBATBlock2 = BATBlock.createBATBlock(this.bigBlockSize, getBlockAt(sBATStart));
            createBATBlock2.setOurBlockIndex(sBATStart);
            arrayList.add(createBATBlock2);
            sBATStart = getNextBlock(sBATStart);
        }
    }

    private void syncWithDataSource() {
        this._mini_store.syncWithDataSource();
        NPOIFSStream nPOIFSStream = new NPOIFSStream(this, this._header.getPropertyStart());
        this._property_table.preWrite();
        this._property_table.write(nPOIFSStream);
        new HeaderBlockWriter(this._header).writeBlock(getBlockAt(-1));
        for (BATBlock bATBlock : this._bat_blocks) {
            BlockAllocationTableWriter.writeBlock(bATBlock, getBlockAt(bATBlock.getOurBlockIndex()));
        }
        for (BATBlock bATBlock2 : this._xbat_blocks) {
            BlockAllocationTableWriter.writeBlock(bATBlock2, getBlockAt(bATBlock2.getOurBlockIndex()));
        }
    }

    public NPropertyTable _get_property_table() {
        return this._property_table;
    }

    public void addDirectory(DirectoryProperty directoryProperty) {
        this._property_table.addProperty(directoryProperty);
    }

    public void addDocument(NPOIFSDocument nPOIFSDocument) {
        this._property_table.addProperty(nPOIFSDocument.getDocumentProperty());
    }

    @Override // java.io.Closeable, java.lang.AutoCloseable
    public void close() {
        this._data.close();
    }

    @Override // org.apache.poi.poifs.filesystem.BlockStore
    public ByteBuffer createBlockIfNeeded(int i2) {
        try {
            return getBlockAt(i2);
        } catch (IndexOutOfBoundsException unused) {
            long bigBlockSize2 = (((long) i2) + 1) * ((long) this.bigBlockSize.getBigBlockSize());
            this._data.write(ByteBuffer.allocate(getBigBlockSize()), bigBlockSize2);
            return getBlockAt(i2);
        }
    }

    public DirectoryEntry createDirectory(String str) {
        return getRoot().createDirectory(str);
    }

    public DocumentEntry createDocument(InputStream inputStream, String str) {
        return getRoot().createDocument(str, inputStream);
    }

    public DocumentInputStream createDocumentInputStream(String str) {
        return getRoot().createDocumentInputStream(str);
    }

    public DocumentEntry createOrUpdateDocument(InputStream inputStream, String str) {
        return getRoot().createOrUpdateDocument(str, inputStream);
    }

    @Override // org.apache.poi.poifs.filesystem.BlockStore
    public BATBlock.BATBlockAndIndex getBATBlockAndIndex(int i2) {
        return BATBlock.getBATBlockAndIndex(i2, this._header, this._bat_blocks);
    }

    public int getBigBlockSize() {
        return this.bigBlockSize.getBigBlockSize();
    }

    public POIFSBigBlockSize getBigBlockSizeDetails() {
        return this.bigBlockSize;
    }

    @Override // org.apache.poi.poifs.filesystem.BlockStore
    public ByteBuffer getBlockAt(int i2) {
        try {
            return this._data.read(this.bigBlockSize.getBigBlockSize(), (((long) i2) + 1) * ((long) this.bigBlockSize.getBigBlockSize()));
        } catch (IndexOutOfBoundsException e2) {
            IndexOutOfBoundsException indexOutOfBoundsException = new IndexOutOfBoundsException(a.b("Block ", i2, " not found"));
            indexOutOfBoundsException.initCause(e2);
            throw indexOutOfBoundsException;
        }
    }

    @Override // org.apache.poi.poifs.filesystem.BlockStore
    public int getBlockStoreBlockSize() {
        return getBigBlockSize();
    }

    @Override // org.apache.poi.poifs.filesystem.BlockStore
    public BlockStore.ChainLoopDetector getChainLoopDetector() {
        return new BlockStore.ChainLoopDetector(this._data.size());
    }

    @Override // org.apache.poi.poifs.filesystem.BlockStore
    public int getFreeBlock() {
        int bATEntriesPerBlock = this.bigBlockSize.getBATEntriesPerBlock();
        int i2 = 0;
        int i3 = 0;
        for (BATBlock bATBlock : this._bat_blocks) {
            if (bATBlock.hasFreeSectors()) {
                for (int i4 = 0; i4 < bATEntriesPerBlock; i4++) {
                    if (bATBlock.getValueAt(i4) == -1) {
                        return i3 + i4;
                    }
                }
                continue;
            }
            i3 += bATEntriesPerBlock;
        }
        BATBlock createBAT = createBAT(i3, true);
        createBAT.setValueAt(0, -3);
        this._bat_blocks.add(createBAT);
        if (this._header.getBATCount() >= 109) {
            BATBlock bATBlock2 = null;
            Iterator<BATBlock> it = this._xbat_blocks.iterator();
            while (true) {
                if (!it.hasNext()) {
                    break;
                }
                BATBlock next = it.next();
                if (next.hasFreeSectors()) {
                    bATBlock2 = next;
                    break;
                }
            }
            if (bATBlock2 == null) {
                int i5 = i3 + 1;
                BATBlock createBAT2 = createBAT(i5, false);
                createBAT2.setValueAt(0, i3);
                createBAT.setValueAt(1, -4);
                if (this._xbat_blocks.size() == 0) {
                    this._header.setXBATStart(i5);
                } else {
                    List<BATBlock> list = this._xbat_blocks;
                    list.get(list.size() - 1).setValueAt(this.bigBlockSize.getXBATEntriesPerBlock(), i5);
                }
                this._xbat_blocks.add(createBAT2);
                this._header.setXBATCount(this._xbat_blocks.size());
                i3 = i5;
            } else {
                while (true) {
                    if (i2 >= this.bigBlockSize.getXBATEntriesPerBlock()) {
                        break;
                    } else if (bATBlock2.getValueAt(i2) == -1) {
                        bATBlock2.setValueAt(i2, i3);
                        break;
                    } else {
                        i2++;
                    }
                }
            }
        } else {
            int bATCount = this._header.getBATCount() + 1;
            int[] iArr = new int[bATCount];
            int i6 = bATCount - 1;
            System.arraycopy(this._header.getBATArray(), 0, iArr, 0, i6);
            iArr[i6] = i3;
            this._header.setBATArray(iArr);
        }
        this._header.setBATCount(this._bat_blocks.size());
        return i3 + 1;
    }

    @Internal
    public HeaderBlock getHeaderBlock() {
        return this._header;
    }

    public NPOIFSMiniStore getMiniStore() {
        return this._mini_store;
    }

    @Override // org.apache.poi.poifs.filesystem.BlockStore
    public int getNextBlock(int i2) {
        BATBlock.BATBlockAndIndex bATBlockAndIndex = getBATBlockAndIndex(i2);
        return bATBlockAndIndex.getBlock().getValueAt(bATBlockAndIndex.getIndex());
    }

    @Internal
    public NPropertyTable getPropertyTable() {
        return this._property_table;
    }

    public DirectoryNode getRoot() {
        if (this._root == null) {
            this._root = new DirectoryNode(this._property_table.getRoot(), this, (DirectoryNode) null);
        }
        return this._root;
    }

    @Override // org.apache.poi.poifs.dev.POIFSViewable
    public String getShortDescription() {
        return "POIFS FileSystem";
    }

    @Override // org.apache.poi.poifs.dev.POIFSViewable
    public Object[] getViewableArray() {
        return preferArray() ? getRoot().getViewableArray() : new Object[0];
    }

    @Override // org.apache.poi.poifs.dev.POIFSViewable
    public Iterator<Object> getViewableIterator() {
        if (!preferArray()) {
            return getRoot().getViewableIterator();
        }
        return Collections.emptyList().iterator();
    }

    public boolean isInPlaceWriteable() {
        DataSource dataSource = this._data;
        return (dataSource instanceof FileBackedDataSource) && ((FileBackedDataSource) dataSource).isWriteable();
    }

    @Override // org.apache.poi.poifs.dev.POIFSViewable
    public boolean preferArray() {
        return getRoot().preferArray();
    }

    public void remove(EntryNode entryNode) {
        if (entryNode instanceof DocumentEntry) {
            new NPOIFSDocument((DocumentProperty) entryNode.getProperty(), this).free();
        }
        this._property_table.removeProperty(entryNode.getProperty());
    }

    @Override // org.apache.poi.poifs.filesystem.BlockStore
    public void setNextBlock(int i2, int i3) {
        BATBlock.BATBlockAndIndex bATBlockAndIndex = getBATBlockAndIndex(i2);
        bATBlockAndIndex.getBlock().setValueAt(bATBlockAndIndex.getIndex(), i3);
    }

    public long size() {
        return this._data.size();
    }

    public void writeFilesystem() {
        DataSource dataSource = this._data;
        if (!(dataSource instanceof FileBackedDataSource)) {
            throw new IllegalArgumentException("POIFS opened from an inputstream, so writeFilesystem() may not be called. Use writeFilesystem(OutputStream) instead");
        } else if (((FileBackedDataSource) dataSource).isWriteable()) {
            syncWithDataSource();
        } else {
            throw new IllegalArgumentException("POIFS opened in read only mode, so writeFilesystem() may not be called. Open the FileSystem in read-write mode first");
        }
    }

    @Removal(version = "4.0")
    @Deprecated
    public static boolean hasPOIFSHeader(byte[] bArr) {
        try {
            return hasPOIFSHeader(new ByteArrayInputStream(bArr));
        } catch (IOException e2) {
            throw new RuntimeException("invalid header check", e2);
        }
    }

    public DocumentEntry createDocument(String str, int i2, POIFSWriterListener pOIFSWriterListener) {
        return getRoot().createDocument(str, i2, pOIFSWriterListener);
    }

    public void writeFilesystem(OutputStream outputStream) {
        syncWithDataSource();
        this._data.copyTo(outputStream);
    }

    public NPOIFSFileSystem() {
        this(true);
        this._header.setBATCount(1);
        this._header.setBATArray(new int[]{1});
        BATBlock createEmptyBATBlock = BATBlock.createEmptyBATBlock(this.bigBlockSize, false);
        createEmptyBATBlock.setOurBlockIndex(1);
        this._bat_blocks.add(createEmptyBATBlock);
        setNextBlock(0, -2);
        setNextBlock(1, -3);
        this._property_table.setStartBlock(0);
    }

    public NPOIFSFileSystem(File file) {
        this(file, true);
    }

    public NPOIFSFileSystem(File file, boolean z) {
        this(null, file, z, true);
    }

    public NPOIFSFileSystem(FileChannel fileChannel) {
        this(fileChannel, true);
    }

    public NPOIFSFileSystem(FileChannel fileChannel, boolean z) {
        this(fileChannel, null, z, false);
    }

    public NPOIFSFileSystem(FileChannel fileChannel, File file, boolean z, boolean z2) {
        this(false);
        if (file != null) {
            try {
                if (file.length() != 0) {
                    FileBackedDataSource fileBackedDataSource = new FileBackedDataSource(file, z);
                    fileChannel = fileBackedDataSource.getChannel();
                    this._data = fileBackedDataSource;
                } else {
                    throw new EmptyFileException();
                }
            } catch (IOException e2) {
                if (z2 && fileChannel != null) {
                    fileChannel.close();
                }
                throw e2;
            } catch (RuntimeException e3) {
                if (z2 && fileChannel != null) {
                    fileChannel.close();
                }
                throw e3;
            }
        } else {
            this._data = new FileBackedDataSource(fileChannel, z);
        }
        ByteBuffer allocate = ByteBuffer.allocate(512);
        IOUtils.readFully(fileChannel, allocate);
        this._header = new HeaderBlock(allocate);
        readCoreContents();
    }

    /* JADX WARNING: Removed duplicated region for block: B:18:0x006b  */
    public NPOIFSFileSystem(InputStream inputStream) {
        this(false);
        Throwable th;
        ReadableByteChannel readableByteChannel;
        try {
            readableByteChannel = Channels.newChannel(inputStream);
            try {
                ByteBuffer allocate = ByteBuffer.allocate(512);
                IOUtils.readFully(readableByteChannel, allocate);
                HeaderBlock headerBlock = new HeaderBlock(allocate);
                this._header = headerBlock;
                BlockAllocationTableReader.sanityCheckBlockCount(headerBlock.getBATCount());
                long calculateMaximumSize = BATBlock.calculateMaximumSize(this._header);
                if (calculateMaximumSize <= 2147483647L) {
                    ByteBuffer allocate2 = ByteBuffer.allocate((int) calculateMaximumSize);
                    allocate.position(0);
                    allocate2.put(allocate);
                    allocate2.position(allocate.capacity());
                    IOUtils.readFully(readableByteChannel, allocate2);
                    this._data = new ByteArrayBackedDataSource(allocate2.array(), allocate2.position());
                    if (readableByteChannel != null) {
                        readableByteChannel.close();
                    }
                    closeInputStream(inputStream, true);
                    readCoreContents();
                    return;
                }
                throw new IllegalArgumentException("Unable read a >2gb file via an InputStream");
            } catch (Throwable th2) {
                th = th2;
                if (readableByteChannel != null) {
                    readableByteChannel.close();
                }
                closeInputStream(inputStream, false);
                throw th;
            }
        } catch (Throwable th3) {
            th = th3;
            readableByteChannel = null;
            if (readableByteChannel != null) {
            }
            closeInputStream(inputStream, false);
            throw th;
        }
    }
}
