package org.apache.poi.poifs.storage;

import java.io.InputStream;
import java.io.OutputStream;
import java.util.Arrays;
import org.apache.poi.poifs.common.POIFSBigBlockSize;
import org.apache.poi.poifs.common.POIFSConstants;
import org.apache.poi.util.IOUtils;

public final class DocumentBlock extends BigBlock {
    public static final byte _default_value = -1;
    public int _bytes_read;
    public byte[] _data;

    /* JADX INFO: super call moved to the top of the method (can break code semantics) */
    public DocumentBlock(RawDataBlock rawDataBlock) {
        super(rawDataBlock.getBigBlockSize() == 512 ? POIFSConstants.SMALLER_BIG_BLOCK_SIZE_DETAILS : POIFSConstants.LARGER_BIG_BLOCK_SIZE_DETAILS);
        byte[] data = rawDataBlock.getData();
        this._data = data;
        this._bytes_read = data.length;
    }

    public static DocumentBlock[] convert(POIFSBigBlockSize pOIFSBigBlockSize, byte[] bArr, int i2) {
        int bigBlockSize = ((pOIFSBigBlockSize.getBigBlockSize() + i2) - 1) / pOIFSBigBlockSize.getBigBlockSize();
        DocumentBlock[] documentBlockArr = new DocumentBlock[bigBlockSize];
        int i3 = 0;
        for (int i4 = 0; i4 < bigBlockSize; i4++) {
            documentBlockArr[i4] = new DocumentBlock(pOIFSBigBlockSize);
            if (i3 < bArr.length) {
                int min = Math.min(pOIFSBigBlockSize.getBigBlockSize(), bArr.length - i3);
                System.arraycopy(bArr, i3, documentBlockArr[i4]._data, 0, min);
                if (min != pOIFSBigBlockSize.getBigBlockSize()) {
                    Arrays.fill(documentBlockArr[i4]._data, min, pOIFSBigBlockSize.getBigBlockSize(), (byte) -1);
                }
            } else {
                Arrays.fill(documentBlockArr[i4]._data, (byte) -1);
            }
            i3 += pOIFSBigBlockSize.getBigBlockSize();
        }
        return documentBlockArr;
    }

    public static DataInputBlock getDataInputBlock(DocumentBlock[] documentBlockArr, int i2) {
        if (documentBlockArr == null || documentBlockArr.length == 0) {
            return null;
        }
        POIFSBigBlockSize pOIFSBigBlockSize = documentBlockArr[0].bigBlockSize;
        return new DataInputBlock(documentBlockArr[i2 >> pOIFSBigBlockSize.getHeaderValue()]._data, i2 & (pOIFSBigBlockSize.getBigBlockSize() - 1));
    }

    public static byte getFillByte() {
        return -1;
    }

    public boolean partiallyRead() {
        return this._bytes_read != this.bigBlockSize.getBigBlockSize();
    }

    public int size() {
        return this._bytes_read;
    }

    @Override // org.apache.poi.poifs.storage.BigBlock, org.apache.poi.poifs.storage.BlockWritable
    public /* bridge */ /* synthetic */ void writeBlocks(OutputStream outputStream) {
        super.writeBlocks(outputStream);
    }

    @Override // org.apache.poi.poifs.storage.BigBlock
    public void writeData(OutputStream outputStream) {
        doWriteData(outputStream, this._data);
    }

    public DocumentBlock(InputStream inputStream, POIFSBigBlockSize pOIFSBigBlockSize) {
        this(pOIFSBigBlockSize);
        int readFully = IOUtils.readFully(inputStream, this._data);
        this._bytes_read = readFully == -1 ? 0 : readFully;
    }

    public DocumentBlock(POIFSBigBlockSize pOIFSBigBlockSize) {
        super(pOIFSBigBlockSize);
        byte[] bArr = new byte[pOIFSBigBlockSize.getBigBlockSize()];
        this._data = bArr;
        Arrays.fill(bArr, (byte) -1);
    }
}
