package org.apache.poi.poifs.storage;

import b.b.a.a.a;
import java.io.IOException;
import java.io.InputStream;
import java.io.OutputStream;
import java.nio.ByteBuffer;
import java.util.Arrays;
import org.apache.lucene.codecs.lucene3x.Lucene3xNormsProducer;
import org.apache.poi.hssf.OldExcelFormatException;
import org.apache.poi.poifs.common.POIFSBigBlockSize;
import org.apache.poi.poifs.common.POIFSConstants;
import org.apache.poi.poifs.filesystem.FileMagic;
import org.apache.poi.poifs.filesystem.NotOLE2FileException;
import org.apache.poi.poifs.filesystem.OfficeXmlFileException;
import org.apache.poi.util.HexDump;
import org.apache.poi.util.IOUtils;
import org.apache.poi.util.IntegerField;
import org.apache.poi.util.LittleEndian;
import org.apache.poi.util.LongField;
import org.apache.poi.util.ShortField;

public final class HeaderBlock implements HeaderBlockConstants {
    public static final byte _default_value = -1;
    public int _bat_count;
    public final byte[] _data;
    public int _property_start;
    public int _sbat_count;
    public int _sbat_start;
    public int _xbat_count;
    public int _xbat_start;
    public final POIFSBigBlockSize bigBlockSize;

    /* renamed from: org.apache.poi.poifs.storage.HeaderBlock$1  reason: invalid class name */
    public static /* synthetic */ class AnonymousClass1 {
        public static final /* synthetic */ int[] $SwitchMap$org$apache$poi$poifs$filesystem$FileMagic;

        /* JADX WARNING: Can't wrap try/catch for region: R(18:0|(2:1|2)|3|(2:5|6)|7|9|10|11|13|14|15|17|18|19|20|21|22|24) */
        /* JADX WARNING: Code restructure failed: missing block: B:25:?, code lost:
            return;
         */
        /* JADX WARNING: Failed to process nested try/catch */
        /* JADX WARNING: Missing exception handler attribute for start block: B:19:0x002c */
        /* JADX WARNING: Missing exception handler attribute for start block: B:21:0x0032 */
        static {
            int[] iArr = new int[FileMagic.values().length];
            $SwitchMap$org$apache$poi$poifs$filesystem$FileMagic = iArr;
            try {
                FileMagic fileMagic = FileMagic.OLE2;
                iArr[0] = 1;
            } catch (NoSuchFieldError unused) {
            }
            try {
                int[] iArr2 = $SwitchMap$org$apache$poi$poifs$filesystem$FileMagic;
                FileMagic fileMagic2 = FileMagic.OOXML;
                iArr2[1] = 2;
            } catch (NoSuchFieldError unused2) {
            }
            try {
                int[] iArr3 = $SwitchMap$org$apache$poi$poifs$filesystem$FileMagic;
                FileMagic fileMagic3 = FileMagic.XML;
                iArr3[2] = 3;
            } catch (NoSuchFieldError unused3) {
            }
            try {
                int[] iArr4 = $SwitchMap$org$apache$poi$poifs$filesystem$FileMagic;
                FileMagic fileMagic4 = FileMagic.MSWRITE;
                iArr4[6] = 4;
            } catch (NoSuchFieldError unused4) {
            }
            int[] iArr5 = $SwitchMap$org$apache$poi$poifs$filesystem$FileMagic;
            FileMagic fileMagic5 = FileMagic.BIFF2;
            iArr5[3] = 5;
            int[] iArr6 = $SwitchMap$org$apache$poi$poifs$filesystem$FileMagic;
            FileMagic fileMagic6 = FileMagic.BIFF3;
            iArr6[4] = 6;
            int[] iArr7 = $SwitchMap$org$apache$poi$poifs$filesystem$FileMagic;
            FileMagic fileMagic7 = FileMagic.BIFF4;
            iArr7[5] = 7;
        }
    }

    public HeaderBlock(InputStream inputStream) {
        this(readFirst512(inputStream));
        if (this.bigBlockSize.getBigBlockSize() != 512) {
            IOUtils.readFully(inputStream, new byte[(this.bigBlockSize.getBigBlockSize() - 512)]);
        }
    }

    public static IOException alertShortRead(int i2, int i3) {
        if (i2 < 0) {
            i2 = 0;
        }
        StringBuilder b2 = a.b(" byte");
        b2.append(i2 == 1 ? "" : Lucene3xNormsProducer.SEPARATE_NORMS_EXTENSION);
        String sb = b2.toString();
        return new IOException("Unable to read entire header; " + i2 + sb + " read; expected " + i3 + " bytes");
    }

    public static byte[] readFirst512(InputStream inputStream) {
        byte[] bArr = new byte[512];
        int readFully = IOUtils.readFully(inputStream, bArr);
        if (readFully == 512) {
            return bArr;
        }
        throw alertShortRead(readFully, 512);
    }

    public int[] getBATArray() {
        int min = Math.min(this._bat_count, 109);
        int[] iArr = new int[min];
        int i2 = 76;
        for (int i3 = 0; i3 < min; i3++) {
            iArr[i3] = LittleEndian.getInt(this._data, i2);
            i2 += 4;
        }
        return iArr;
    }

    public int getBATCount() {
        return this._bat_count;
    }

    public POIFSBigBlockSize getBigBlockSize() {
        return this.bigBlockSize;
    }

    public int getPropertyStart() {
        return this._property_start;
    }

    public int getSBATCount() {
        return this._sbat_count;
    }

    public int getSBATStart() {
        return this._sbat_start;
    }

    public int getXBATCount() {
        return this._xbat_count;
    }

    public int getXBATIndex() {
        return this._xbat_start;
    }

    public void setBATArray(int[] iArr) {
        int min = Math.min(iArr.length, 109);
        int i2 = 109 - min;
        int i3 = 76;
        for (int i4 = 0; i4 < min; i4++) {
            LittleEndian.putInt(this._data, i3, iArr[i4]);
            i3 += 4;
        }
        for (int i5 = 0; i5 < i2; i5++) {
            LittleEndian.putInt(this._data, i3, -1);
            i3 += 4;
        }
    }

    public void setBATCount(int i2) {
        this._bat_count = i2;
    }

    public void setPropertyStart(int i2) {
        this._property_start = i2;
    }

    public void setSBATBlockCount(int i2) {
        this._sbat_count = i2;
    }

    public void setSBATStart(int i2) {
        this._sbat_start = i2;
    }

    public void setXBATCount(int i2) {
        this._xbat_count = i2;
    }

    public void setXBATStart(int i2) {
        this._xbat_start = i2;
    }

    public void writeData(OutputStream outputStream) {
        new IntegerField(44, this._bat_count, this._data);
        new IntegerField(48, this._property_start, this._data);
        new IntegerField(60, this._sbat_start, this._data);
        new IntegerField(64, this._sbat_count, this._data);
        new IntegerField(68, this._xbat_start, this._data);
        new IntegerField(72, this._xbat_count, this._data);
        outputStream.write(this._data, 0, 512);
        for (int i2 = 512; i2 < this.bigBlockSize.getBigBlockSize(); i2++) {
            outputStream.write(0);
        }
    }

    public HeaderBlock(ByteBuffer byteBuffer) {
        this(IOUtils.toByteArray(byteBuffer, 512));
    }

    public HeaderBlock(byte[] bArr) {
        this._data = (byte[]) bArr.clone();
        FileMagic valueOf = FileMagic.valueOf(bArr);
        switch (valueOf.ordinal()) {
            case 0:
                byte[] bArr2 = this._data;
                if (bArr2[30] == 12) {
                    this.bigBlockSize = POIFSConstants.LARGER_BIG_BLOCK_SIZE_DETAILS;
                } else if (bArr2[30] == 9) {
                    this.bigBlockSize = POIFSConstants.SMALLER_BIG_BLOCK_SIZE_DETAILS;
                } else {
                    throw new IOException(a.a(a.b("Unsupported blocksize  (2^"), this._data[30], "). Expected 2^9 or 2^12."));
                }
                this._bat_count = new IntegerField(44, bArr).get();
                this._property_start = new IntegerField(48, this._data).get();
                this._sbat_start = new IntegerField(60, this._data).get();
                this._sbat_count = new IntegerField(64, this._data).get();
                this._xbat_start = new IntegerField(68, this._data).get();
                this._xbat_count = new IntegerField(72, this._data).get();
                return;
            case 1:
                throw new OfficeXmlFileException("The supplied data appears to be in the Office 2007+ XML. You are calling the part of POI that deals with OLE2 Office Documents. You need to call a different part of POI to process this data (eg XSSF instead of HSSF)");
            case 2:
                throw new NotOLE2FileException("The supplied data appears to be a raw XML file. Formats such as Office 2003 XML are not supported");
            case 3:
            case 4:
            case 5:
                throw new OldExcelFormatException("The supplied data appears to be in " + valueOf + " format. " + "HSSF only supports the BIFF8 format, try OldExcelExtractor");
            case 6:
                throw new NotOLE2FileException("The supplied data appears to be in the old MS Write format. Apache POI doesn't currently support this format");
            default:
                throw new NotOLE2FileException(a.b("Invalid header signature; read ", HexDump.longToHex(LittleEndian.getLong(bArr, 0)), ", expected ", HexDump.longToHex(HeaderBlockConstants._signature), " - Your file appears not to be a valid OLE2 document"));
        }
    }

    public HeaderBlock(POIFSBigBlockSize pOIFSBigBlockSize) {
        this.bigBlockSize = pOIFSBigBlockSize;
        byte[] bArr = new byte[512];
        this._data = bArr;
        Arrays.fill(bArr, (byte) -1);
        new LongField(0, HeaderBlockConstants._signature, this._data);
        new IntegerField(8, 0, this._data);
        new IntegerField(12, 0, this._data);
        new IntegerField(16, 0, this._data);
        new IntegerField(20, 0, this._data);
        new ShortField(24, 59, this._data);
        new ShortField(26, 3, this._data);
        new ShortField(28, -2, this._data);
        new ShortField(30, pOIFSBigBlockSize.getHeaderValue(), this._data);
        new IntegerField(32, 6, this._data);
        new IntegerField(36, 0, this._data);
        new IntegerField(40, 0, this._data);
        new IntegerField(52, 0, this._data);
        new IntegerField(56, 4096, this._data);
        this._bat_count = 0;
        this._sbat_count = 0;
        this._xbat_count = 0;
        this._property_start = -2;
        this._sbat_start = -2;
        this._xbat_start = -2;
    }
}
