package org.apache.poi.sl.draw;

import java.awt.Color;
import java.awt.Dimension;
import java.awt.Graphics2D;
import java.awt.LinearGradientPaint;
import java.awt.Paint;
import java.awt.RadialGradientPaint;
import java.awt.TexturePaint;
import java.awt.geom.AffineTransform;
import java.awt.geom.Point2D;
import java.awt.geom.Rectangle2D;
import java.awt.image.BufferedImage;
import java.io.IOException;
import java.io.InputStream;
import org.apache.poi.sl.usermodel.ColorStyle;
import org.apache.poi.sl.usermodel.PaintStyle;
import org.apache.poi.sl.usermodel.PlaceableShape;
import org.apache.poi.ss.formula.functions.NumericFunction;
import org.apache.poi.util.POILogFactory;
import org.apache.poi.util.POILogger;
import org.apache.xerces.util.SecurityManager;

public class DrawPaint {
    public static final /* synthetic */ boolean $assertionsDisabled = false;
    public static final POILogger LOG = POILogFactory.getLogger(DrawPaint.class);
    public static final Color TRANSPARENT = new Color(1.0f, 1.0f, 1.0f, 0.0f);
    public PlaceableShape<?, ?> shape;

    /* renamed from: org.apache.poi.sl.draw.DrawPaint$2  reason: invalid class name */
    public static /* synthetic */ class AnonymousClass2 {
        public static final /* synthetic */ int[] $SwitchMap$org$apache$poi$sl$usermodel$PaintStyle$GradientPaint$GradientType;
        public static final /* synthetic */ int[] $SwitchMap$org$apache$poi$sl$usermodel$PaintStyle$PaintModifier;

        /* JADX WARNING: Can't wrap try/catch for region: R(17:0|(2:1|2)|3|(2:5|6)|7|9|10|11|13|14|15|16|17|18|19|20|22) */
        /* JADX WARNING: Can't wrap try/catch for region: R(19:0|1|2|3|5|6|7|9|10|11|13|14|15|16|17|18|19|20|22) */
        /* JADX WARNING: Code restructure failed: missing block: B:23:?, code lost:
            return;
         */
        /* JADX WARNING: Failed to process nested try/catch */
        /* JADX WARNING: Missing exception handler attribute for start block: B:15:0x002b */
        /* JADX WARNING: Missing exception handler attribute for start block: B:17:0x0032 */
        /* JADX WARNING: Missing exception handler attribute for start block: B:19:0x0038 */
        static {
            int[] iArr = new int[PaintStyle.GradientPaint.GradientType.values().length];
            $SwitchMap$org$apache$poi$sl$usermodel$PaintStyle$GradientPaint$GradientType = iArr;
            try {
                PaintStyle.GradientPaint.GradientType gradientType = PaintStyle.GradientPaint.GradientType.linear;
                iArr[0] = 1;
            } catch (NoSuchFieldError unused) {
            }
            try {
                int[] iArr2 = $SwitchMap$org$apache$poi$sl$usermodel$PaintStyle$GradientPaint$GradientType;
                PaintStyle.GradientPaint.GradientType gradientType2 = PaintStyle.GradientPaint.GradientType.circular;
                iArr2[1] = 2;
            } catch (NoSuchFieldError unused2) {
            }
            try {
                int[] iArr3 = $SwitchMap$org$apache$poi$sl$usermodel$PaintStyle$GradientPaint$GradientType;
                PaintStyle.GradientPaint.GradientType gradientType3 = PaintStyle.GradientPaint.GradientType.shape;
                iArr3[2] = 3;
            } catch (NoSuchFieldError unused3) {
            }
            int[] iArr4 = new int[PaintStyle.PaintModifier.values().length];
            $SwitchMap$org$apache$poi$sl$usermodel$PaintStyle$PaintModifier = iArr4;
            PaintStyle.PaintModifier paintModifier = PaintStyle.PaintModifier.DARKEN;
            iArr4[4] = 1;
            int[] iArr5 = $SwitchMap$org$apache$poi$sl$usermodel$PaintStyle$PaintModifier;
            PaintStyle.PaintModifier paintModifier2 = PaintStyle.PaintModifier.DARKEN_LESS;
            iArr5[5] = 2;
            int[] iArr6 = $SwitchMap$org$apache$poi$sl$usermodel$PaintStyle$PaintModifier;
            PaintStyle.PaintModifier paintModifier3 = PaintStyle.PaintModifier.LIGHTEN;
            iArr6[2] = 3;
            int[] iArr7 = $SwitchMap$org$apache$poi$sl$usermodel$PaintStyle$PaintModifier;
            PaintStyle.PaintModifier paintModifier4 = PaintStyle.PaintModifier.LIGHTEN_LESS;
            iArr7[3] = 4;
        }
    }

    public DrawPaint(PlaceableShape<?, ?> placeableShape) {
        this.shape = placeableShape;
    }

    public static Color HSL2RGB(double d2, double d3, double d4, double d5) {
        double max = Math.max((double) NumericFunction.LOG_10_TO_BASE_e, Math.min(100.0d, d3));
        double max2 = Math.max((double) NumericFunction.LOG_10_TO_BASE_e, Math.min(100.0d, d4));
        if (d5 < NumericFunction.LOG_10_TO_BASE_e || d5 > 1.0d) {
            throw new IllegalArgumentException("Color parameter outside of expected range - Alpha: " + d5);
        }
        double d6 = (d2 % 360.0d) / 360.0d;
        double d7 = max / 100.0d;
        double d8 = max2 / 100.0d;
        double d9 = d8 < 0.5d ? (d7 + 1.0d) * d8 : (d8 + d7) - (d7 * d8);
        double d10 = (d8 * 2.0d) - d9;
        return new Color((float) Math.min(Math.max((double) NumericFunction.LOG_10_TO_BASE_e, HUE2RGB(d10, d9, d6 + 0.3333333333333333d)), 1.0d), (float) Math.min(Math.max((double) NumericFunction.LOG_10_TO_BASE_e, HUE2RGB(d10, d9, d6)), 1.0d), (float) Math.min(Math.max((double) NumericFunction.LOG_10_TO_BASE_e, HUE2RGB(d10, d9, d6 - 0.3333333333333333d)), 1.0d), (float) d5);
    }

    public static double HUE2RGB(double d2, double d3, double d4) {
        if (d4 < NumericFunction.LOG_10_TO_BASE_e) {
            d4 += 1.0d;
        }
        if (d4 > 1.0d) {
            d4 -= 1.0d;
        }
        if (d4 * 6.0d < 1.0d) {
            return ((d3 - d2) * 6.0d * d4) + d2;
        }
        if (d4 * 2.0d < 1.0d) {
            return d3;
        }
        if (3.0d * d4 >= 2.0d) {
            return d2;
        }
        return ((0.6666666666666666d - d4) * (d3 - d2) * 6.0d) + d2;
    }

    /* JADX WARNING: Removed duplicated region for block: B:14:0x0064  */
    public static double[] RGB2HSL(Color color) {
        double d2;
        float[] rGBColorComponents = color.getRGBColorComponents((float[]) null);
        double d3 = (double) rGBColorComponents[0];
        double d4 = (double) rGBColorComponents[1];
        double d5 = (double) rGBColorComponents[2];
        double min = Math.min(d3, Math.min(d4, d5));
        double max = Math.max(d3, Math.max(d4, d5));
        double d6 = NumericFunction.LOG_10_TO_BASE_e;
        int i2 = (max > min ? 1 : (max == min ? 0 : -1));
        if (i2 != 0) {
            if (max == d3) {
                d2 = ((((d4 - d5) * 60.0d) / (max - min)) + 360.0d) % 360.0d;
            } else if (max == d4) {
                d2 = (((d5 - d3) * 60.0d) / (max - min)) + 120.0d;
            } else if (max == d5) {
                d2 = 240.0d + (((d3 - d4) * 60.0d) / (max - min));
            }
            double d7 = max + min;
            double d8 = d7 / 2.0d;
            if (i2 != 0) {
                d6 = d8 <= 0.5d ? (max - min) / d7 : (max - min) / ((2.0d - max) - min);
            }
            return new double[]{d2, d6 * 100.0d, d8 * 100.0d};
        }
        d2 = 0.0d;
        double d72 = max + min;
        double d82 = d72 / 2.0d;
        if (i2 != 0) {
        }
        return new double[]{d2, d6 * 100.0d, d82 * 100.0d};
    }

    public static Color applyColorTransform(ColorStyle colorStyle) {
        if (colorStyle == null || colorStyle.getColor() == null) {
            return TRANSPARENT;
        }
        Color color = colorStyle.getColor();
        double alpha = getAlpha(color, colorStyle);
        double[] RGB2HSL = RGB2HSL(color);
        applyHslModOff(RGB2HSL, 0, colorStyle.getHueMod(), colorStyle.getHueOff());
        applyHslModOff(RGB2HSL, 1, colorStyle.getSatMod(), colorStyle.getSatOff());
        applyHslModOff(RGB2HSL, 2, colorStyle.getLumMod(), colorStyle.getLumOff());
        applyShade(RGB2HSL, colorStyle);
        applyTint(RGB2HSL, colorStyle);
        return HSL2RGB(RGB2HSL[0], RGB2HSL[1], RGB2HSL[2], alpha);
    }

    public static void applyHslModOff(double[] dArr, int i2, int i3, int i4) {
        if (i3 == -1) {
            i3 = SecurityManager.DEFAULT_ENTITY_EXPANSION_LIMIT;
        }
        if (i4 == -1) {
            i4 = 0;
        }
        if (i3 != 100000 || i4 != 0) {
            dArr[i2] = (dArr[i2] * (((double) i3) / 100000.0d)) + (((double) i4) / 1000.0d);
        }
    }

    public static void applyShade(double[] dArr, ColorStyle colorStyle) {
        int shade = colorStyle.getShade();
        if (shade != -1) {
            dArr[2] = (1.0d - (((double) shade) / 100000.0d)) * dArr[2];
        }
    }

    public static void applyTint(double[] dArr, ColorStyle colorStyle) {
        int tint = colorStyle.getTint();
        if (tint != -1) {
            double d2 = 1.0d - (((double) tint) / 100000.0d);
            dArr[2] = (100.0d - (d2 * 100.0d)) + (dArr[2] * d2);
        }
    }

    public static PaintStyle.SolidPaint createSolidPaint(Color color) {
        if (color == null) {
            return null;
        }
        return new SimpleSolidPaint(color);
    }

    public static double getAlpha(Color color, ColorStyle colorStyle) {
        double alpha = ((double) color.getAlpha()) / 255.0d;
        int alpha2 = colorStyle.getAlpha();
        if (alpha2 != -1) {
            alpha *= ((double) alpha2) / 100000.0d;
        }
        return Math.min(1.0d, Math.max((double) NumericFunction.LOG_10_TO_BASE_e, alpha));
    }

    public static float lin2srgb(int i2) {
        double d2 = (double) i2;
        return (float) (d2 <= 0.0031308d ? (d2 / 100000.0d) * 12.92d : (Math.pow(d2 / 100000.0d, 0.4166666666666667d) * 1.055d) - 0.055d);
    }

    public static int srgb2lin(float f2) {
        double rint;
        double d2 = (double) f2;
        if (d2 <= 0.04045d) {
            rint = Math.rint((d2 * 100000.0d) / 12.92d);
        } else {
            rint = Math.rint(Math.pow((d2 + 0.055d) / 1.055d, 2.4d) * 100000.0d);
        }
        return (int) rint;
    }

    public Paint createLinearGradientPaint(PaintStyle.GradientPaint gradientPaint, Graphics2D graphics2D) {
        double gradientAngle = gradientPaint.getGradientAngle();
        if (!gradientPaint.isRotatedWithShape()) {
            gradientAngle -= this.shape.getRotation();
        }
        Rectangle2D anchor = DrawShape.getAnchor(graphics2D, this.shape);
        double height = anchor.getHeight();
        double width = anchor.getWidth();
        double x = anchor.getX();
        double y = anchor.getY();
        AffineTransform rotateInstance = AffineTransform.getRotateInstance(Math.toRadians(gradientAngle), anchor.getCenterX(), anchor.getCenterY());
        double d2 = (height / 2.0d) + y;
        Point2D transform = rotateInstance.transform(new Point2D.Double(((width / 2.0d) + x) - (Math.sqrt((width * width) + (height * height)) / 2.0d), d2), (Point2D) null);
        Point2D transform2 = rotateInstance.transform(new Point2D.Double(x + width, d2), (Point2D) null);
        if (transform.equals(transform2)) {
            return null;
        }
        float[] gradientFractions = gradientPaint.getGradientFractions();
        Color[] colorArr = new Color[gradientFractions.length];
        ColorStyle[] gradientColors = gradientPaint.getGradientColors();
        int length = gradientColors.length;
        int i2 = 0;
        int i3 = 0;
        while (i2 < length) {
            ColorStyle colorStyle = gradientColors[i2];
            int i4 = i3 + 1;
            colorArr[i3] = colorStyle == null ? TRANSPARENT : applyColorTransform(colorStyle);
            i2++;
            i3 = i4;
        }
        return new LinearGradientPaint(transform, transform2, gradientFractions, colorArr);
    }

    public Paint createPathGradientPaint(PaintStyle.GradientPaint gradientPaint, Graphics2D graphics2D) {
        float[] gradientFractions = gradientPaint.getGradientFractions();
        Color[] colorArr = new Color[gradientFractions.length];
        ColorStyle[] gradientColors = gradientPaint.getGradientColors();
        int length = gradientColors.length;
        int i2 = 0;
        int i3 = 0;
        while (i2 < length) {
            colorArr[i3] = applyColorTransform(gradientColors[i2]);
            i2++;
            i3++;
        }
        return new PathGradientPaint(colorArr, gradientFractions);
    }

    public Paint createRadialGradientPaint(PaintStyle.GradientPaint gradientPaint, Graphics2D graphics2D) {
        Rectangle2D anchor = DrawShape.getAnchor(graphics2D, this.shape);
        Point2D.Double r0 = new Point2D.Double((anchor.getWidth() / 2.0d) + anchor.getX(), (anchor.getHeight() / 2.0d) + anchor.getY());
        float max = (float) Math.max(anchor.getWidth(), anchor.getHeight());
        float[] gradientFractions = gradientPaint.getGradientFractions();
        Color[] colorArr = new Color[gradientFractions.length];
        ColorStyle[] gradientColors = gradientPaint.getGradientColors();
        int length = gradientColors.length;
        int i2 = 0;
        int i3 = 0;
        while (i2 < length) {
            colorArr[i3] = applyColorTransform(gradientColors[i2]);
            i2++;
            i3++;
        }
        return new RadialGradientPaint(r0, max, gradientFractions, colorArr);
    }

    public Paint getGradientPaint(PaintStyle.GradientPaint gradientPaint, Graphics2D graphics2D) {
        int ordinal = gradientPaint.getGradientType().ordinal();
        if (ordinal == 0) {
            return createLinearGradientPaint(gradientPaint, graphics2D);
        }
        if (ordinal == 1) {
            return createRadialGradientPaint(gradientPaint, graphics2D);
        }
        if (ordinal == 2) {
            return createPathGradientPaint(gradientPaint, graphics2D);
        }
        throw new UnsupportedOperationException("gradient fill of type " + gradientPaint + " not supported.");
    }

    public Paint getPaint(Graphics2D graphics2D, PaintStyle paintStyle) {
        return getPaint(graphics2D, paintStyle, PaintStyle.PaintModifier.NORM);
    }

    public Paint getSolidPaint(PaintStyle.SolidPaint solidPaint, Graphics2D graphics2D, final PaintStyle.PaintModifier paintModifier) {
        final ColorStyle solidColor = solidPaint.getSolidColor();
        return applyColorTransform(new ColorStyle() {
            /* class org.apache.poi.sl.draw.DrawPaint.AnonymousClass1 */

            @Override // org.apache.poi.sl.usermodel.ColorStyle
            public int getAlpha() {
                return solidColor.getAlpha();
            }

            @Override // org.apache.poi.sl.usermodel.ColorStyle
            public Color getColor() {
                return solidColor.getColor();
            }

            @Override // org.apache.poi.sl.usermodel.ColorStyle
            public int getHueMod() {
                return solidColor.getHueMod();
            }

            @Override // org.apache.poi.sl.usermodel.ColorStyle
            public int getHueOff() {
                return solidColor.getHueOff();
            }

            @Override // org.apache.poi.sl.usermodel.ColorStyle
            public int getLumMod() {
                return solidColor.getLumMod();
            }

            @Override // org.apache.poi.sl.usermodel.ColorStyle
            public int getLumOff() {
                return solidColor.getLumOff();
            }

            @Override // org.apache.poi.sl.usermodel.ColorStyle
            public int getSatMod() {
                return solidColor.getSatMod();
            }

            @Override // org.apache.poi.sl.usermodel.ColorStyle
            public int getSatOff() {
                return solidColor.getSatOff();
            }

            @Override // org.apache.poi.sl.usermodel.ColorStyle
            public int getShade() {
                int shade = solidColor.getShade();
                int ordinal = paintModifier.ordinal();
                if (ordinal == 4) {
                    return Math.min((int) SecurityManager.DEFAULT_ENTITY_EXPANSION_LIMIT, Math.max(0, shade) + 40000);
                }
                if (ordinal != 5) {
                    return shade;
                }
                return Math.min((int) SecurityManager.DEFAULT_ENTITY_EXPANSION_LIMIT, Math.max(0, shade) + 20000);
            }

            @Override // org.apache.poi.sl.usermodel.ColorStyle
            public int getTint() {
                int tint = solidColor.getTint();
                int ordinal = paintModifier.ordinal();
                if (ordinal == 2) {
                    return Math.min((int) SecurityManager.DEFAULT_ENTITY_EXPANSION_LIMIT, Math.max(0, tint) + 40000);
                }
                if (ordinal != 3) {
                    return tint;
                }
                return Math.min((int) SecurityManager.DEFAULT_ENTITY_EXPANSION_LIMIT, Math.max(0, tint) + 20000);
            }
        });
    }

    public Paint getTexturePaint(PaintStyle.TexturePaint texturePaint, Graphics2D graphics2D) {
        BufferedImage bufferedImage;
        InputStream imageData = texturePaint.getImageData();
        if (imageData == null) {
            return null;
        }
        ImageRenderer imageRenderer = DrawPictureShape.getImageRenderer(graphics2D, texturePaint.getContentType());
        try {
            imageRenderer.loadImage(imageData, texturePaint.getContentType());
            try {
                int alpha = texturePaint.getAlpha();
                if (alpha >= 0 && alpha < 100000) {
                    imageRenderer.setAlpha((double) (((float) alpha) / 100000.0f));
                }
                Rectangle2D anchor = this.shape.getAnchor();
                if ("image/x-wmf".equals(texturePaint.getContentType())) {
                    bufferedImage = imageRenderer.getImage(new Dimension((int) anchor.getWidth(), (int) anchor.getHeight()));
                } else {
                    bufferedImage = imageRenderer.getImage();
                }
                if (bufferedImage != null) {
                    return new TexturePaint(bufferedImage, anchor);
                }
                LOG.log(7, "Can't load image data");
                return null;
            } catch (IOException e2) {
                LOG.log(7, "Can't load image data - using transparent color", e2);
                return null;
            }
        } finally {
            imageData.close();
        }
    }

    public void snapToAnchor(Point2D point2D, Rectangle2D rectangle2D) {
        if (point2D.getX() < rectangle2D.getX()) {
            point2D.setLocation(rectangle2D.getX(), point2D.getY());
        } else if (point2D.getX() > rectangle2D.getX() + rectangle2D.getWidth()) {
            point2D.setLocation(rectangle2D.getX() + rectangle2D.getWidth(), point2D.getY());
        }
        if (point2D.getY() < rectangle2D.getY()) {
            point2D.setLocation(point2D.getX(), rectangle2D.getY());
        } else if (point2D.getY() > rectangle2D.getY() + rectangle2D.getHeight()) {
            point2D.setLocation(point2D.getX(), rectangle2D.getY() + rectangle2D.getHeight());
        }
    }

    public static PaintStyle.SolidPaint createSolidPaint(ColorStyle colorStyle) {
        if (colorStyle == null) {
            return null;
        }
        return new SimpleSolidPaint(colorStyle);
    }

    public Paint getPaint(Graphics2D graphics2D, PaintStyle paintStyle, PaintStyle.PaintModifier paintModifier) {
        if (paintModifier == PaintStyle.PaintModifier.NONE) {
            return null;
        }
        if (paintStyle instanceof PaintStyle.SolidPaint) {
            return getSolidPaint((PaintStyle.SolidPaint) paintStyle, graphics2D, paintModifier);
        }
        if (paintStyle instanceof PaintStyle.GradientPaint) {
            return getGradientPaint((PaintStyle.GradientPaint) paintStyle, graphics2D);
        }
        if (paintStyle instanceof PaintStyle.TexturePaint) {
            return getTexturePaint((PaintStyle.TexturePaint) paintStyle, graphics2D);
        }
        return null;
    }

    public static class SimpleSolidPaint implements PaintStyle.SolidPaint {
        public final ColorStyle solidColor;

        public SimpleSolidPaint(final Color color) {
            if (color != null) {
                this.solidColor = new ColorStyle() {
                    /* class org.apache.poi.sl.draw.DrawPaint.SimpleSolidPaint.AnonymousClass1 */

                    @Override // org.apache.poi.sl.usermodel.ColorStyle
                    public int getAlpha() {
                        return (int) Math.round((((double) color.getAlpha()) * 100000.0d) / 255.0d);
                    }

                    @Override // org.apache.poi.sl.usermodel.ColorStyle
                    public Color getColor() {
                        return new Color(color.getRed(), color.getGreen(), color.getBlue());
                    }

                    @Override // org.apache.poi.sl.usermodel.ColorStyle
                    public int getHueMod() {
                        return -1;
                    }

                    @Override // org.apache.poi.sl.usermodel.ColorStyle
                    public int getHueOff() {
                        return -1;
                    }

                    @Override // org.apache.poi.sl.usermodel.ColorStyle
                    public int getLumMod() {
                        return -1;
                    }

                    @Override // org.apache.poi.sl.usermodel.ColorStyle
                    public int getLumOff() {
                        return -1;
                    }

                    @Override // org.apache.poi.sl.usermodel.ColorStyle
                    public int getSatMod() {
                        return -1;
                    }

                    @Override // org.apache.poi.sl.usermodel.ColorStyle
                    public int getSatOff() {
                        return -1;
                    }

                    @Override // org.apache.poi.sl.usermodel.ColorStyle
                    public int getShade() {
                        return -1;
                    }

                    @Override // org.apache.poi.sl.usermodel.ColorStyle
                    public int getTint() {
                        return -1;
                    }
                };
                return;
            }
            throw new NullPointerException("Color needs to be specified");
        }

        @Override // org.apache.poi.sl.usermodel.PaintStyle.SolidPaint
        public ColorStyle getSolidColor() {
            return this.solidColor;
        }

        public SimpleSolidPaint(ColorStyle colorStyle) {
            if (colorStyle != null) {
                this.solidColor = colorStyle;
                return;
            }
            throw new NullPointerException("Color needs to be specified");
        }
    }
}
