package org.apache.poi.sl.draw;

import java.awt.Dimension;
import java.awt.Graphics2D;
import java.awt.Insets;
import java.awt.geom.Rectangle2D;
import java.io.IOException;
import org.apache.poi.sl.usermodel.PictureData;
import org.apache.poi.sl.usermodel.PictureShape;
import org.apache.poi.sl.usermodel.RectAlign;
import org.apache.poi.ss.formula.functions.NumericFunction;
import org.apache.poi.util.POILogFactory;
import org.apache.poi.util.POILogger;

public class DrawPictureShape extends DrawSimpleShape {
    public static final POILogger LOG = POILogFactory.getLogger(DrawPictureShape.class);
    public static final String WMF_IMAGE_RENDERER = "org.apache.poi.hwmf.draw.HwmfSLImageRenderer";

    /* renamed from: org.apache.poi.sl.draw.DrawPictureShape$1  reason: invalid class name */
    public static /* synthetic */ class AnonymousClass1 {
        public static final /* synthetic */ int[] $SwitchMap$org$apache$poi$sl$usermodel$RectAlign;

        /* JADX WARNING: Can't wrap try/catch for region: R(21:0|1|2|3|4|5|7|8|9|11|12|13|15|16|17|18|19|20|21|22|24) */
        /* JADX WARNING: Code restructure failed: missing block: B:25:?, code lost:
            return;
         */
        /* JADX WARNING: Failed to process nested try/catch */
        /* JADX WARNING: Missing exception handler attribute for start block: B:17:0x002d */
        /* JADX WARNING: Missing exception handler attribute for start block: B:19:0x0034 */
        /* JADX WARNING: Missing exception handler attribute for start block: B:21:0x003a */
        /* JADX WARNING: Missing exception handler attribute for start block: B:3:0x000e */
        static {
            int[] iArr = new int[RectAlign.values().length];
            $SwitchMap$org$apache$poi$sl$usermodel$RectAlign = iArr;
            RectAlign rectAlign = RectAlign.TOP;
            iArr[1] = 1;
            try {
                int[] iArr2 = $SwitchMap$org$apache$poi$sl$usermodel$RectAlign;
                RectAlign rectAlign2 = RectAlign.TOP_RIGHT;
                iArr2[2] = 2;
            } catch (NoSuchFieldError unused) {
            }
            try {
                int[] iArr3 = $SwitchMap$org$apache$poi$sl$usermodel$RectAlign;
                RectAlign rectAlign3 = RectAlign.RIGHT;
                iArr3[5] = 3;
            } catch (NoSuchFieldError unused2) {
            }
            try {
                int[] iArr4 = $SwitchMap$org$apache$poi$sl$usermodel$RectAlign;
                RectAlign rectAlign4 = RectAlign.BOTTOM_RIGHT;
                iArr4[8] = 4;
            } catch (NoSuchFieldError unused3) {
            }
            int[] iArr5 = $SwitchMap$org$apache$poi$sl$usermodel$RectAlign;
            RectAlign rectAlign5 = RectAlign.BOTTOM;
            iArr5[7] = 5;
            int[] iArr6 = $SwitchMap$org$apache$poi$sl$usermodel$RectAlign;
            RectAlign rectAlign6 = RectAlign.BOTTOM_LEFT;
            iArr6[6] = 6;
            int[] iArr7 = $SwitchMap$org$apache$poi$sl$usermodel$RectAlign;
            RectAlign rectAlign7 = RectAlign.LEFT;
            iArr7[3] = 7;
            int[] iArr8 = $SwitchMap$org$apache$poi$sl$usermodel$RectAlign;
            RectAlign rectAlign8 = RectAlign.TOP_LEFT;
            iArr8[0] = 8;
        }
    }

    public DrawPictureShape(PictureShape<?, ?> pictureShape) {
        super(pictureShape);
    }

    public static ImageRenderer getImageRenderer(Graphics2D graphics2D, String str) {
        ImageRenderer imageRenderer = (ImageRenderer) graphics2D.getRenderingHint(Drawable.IMAGE_RENDERER);
        if (imageRenderer != null) {
            return imageRenderer;
        }
        if (PictureData.PictureType.WMF.contentType.equals(str)) {
            try {
                return (ImageRenderer) Thread.currentThread().getContextClassLoader().loadClass(WMF_IMAGE_RENDERER).newInstance();
            } catch (Exception e2) {
                LOG.log(7, "WMF image renderer is not on the classpath - include poi-scratchpad jar!", e2);
            }
        }
        return new BitmapImageRenderer();
    }

    @Override // org.apache.poi.sl.draw.DrawShape, org.apache.poi.sl.draw.Drawable
    public void drawContent(Graphics2D graphics2D) {
        PictureData pictureData = getShape().getPictureData();
        if (pictureData != null) {
            Rectangle2D anchor = DrawShape.getAnchor(graphics2D, getShape());
            Insets clipping = getShape().getClipping();
            try {
                ImageRenderer imageRenderer = getImageRenderer(graphics2D, pictureData.getContentType());
                imageRenderer.loadImage(pictureData.getData(), pictureData.getContentType());
                imageRenderer.drawImage(graphics2D, anchor, clipping);
            } catch (IOException e2) {
                LOG.log(7, "image can't be loaded/rendered.", e2);
            }
        }
    }

    public void resize() {
        PictureShape<?, ?> shape = getShape();
        Dimension imageDimension = shape.getPictureData().getImageDimension();
        Rectangle2D anchor = shape.getAnchor();
        shape.setAnchor(new Rectangle2D.Double(anchor.getX(), anchor.getY(), imageDimension.getWidth(), imageDimension.getHeight()));
    }

    @Override // org.apache.poi.sl.draw.DrawShape, org.apache.poi.sl.draw.DrawSimpleShape, org.apache.poi.sl.draw.DrawSimpleShape
    public PictureShape<?, ?> getShape() {
        return (PictureShape) this.shape;
    }

    public void resize(Rectangle2D rectangle2D) {
        resize(rectangle2D, RectAlign.CENTER);
    }

    /* JADX INFO: Can't fix incorrect switch cases order, some code will duplicate */
    public void resize(Rectangle2D rectangle2D, RectAlign rectAlign) {
        double d2;
        double d3;
        double d4;
        double d5;
        double d6;
        double d7;
        PictureShape<?, ?> shape = getShape();
        Dimension imageDimension = shape.getPictureData().getImageDimension();
        if (imageDimension.width <= 0 || imageDimension.height <= 0) {
            shape.setAnchor(rectangle2D);
            return;
        }
        double width = rectangle2D.getWidth();
        double height = rectangle2D.getHeight();
        double d8 = width / ((double) imageDimension.width);
        double d9 = height / ((double) imageDimension.height);
        double d10 = NumericFunction.LOG_10_TO_BASE_e;
        if (d8 > d9) {
            double d11 = d9 * ((double) imageDimension.width);
            d3 = d11;
            d2 = height;
            d4 = 0.0d;
            d10 = rectangle2D.getWidth() - d11;
        } else if (d9 > d8) {
            double d12 = ((double) imageDimension.height) * d8;
            d4 = rectangle2D.getHeight() - d12;
            d3 = width;
            d2 = d12;
        } else {
            shape.setAnchor(rectangle2D);
            return;
        }
        double x = rectangle2D.getX();
        double y = rectangle2D.getY();
        switch (rectAlign.ordinal()) {
            case 0:
                d6 = x;
                d5 = y;
                break;
            case 1:
                d7 = (d10 / 2.0d) + x;
                d5 = y;
                d6 = d7;
                break;
            case 2:
                x += d10;
                d6 = x;
                d5 = y;
                break;
            case 3:
                d6 = x;
                d5 = (d4 / 2.0d) + y;
                break;
            case 4:
            default:
                d7 = (d10 / 2.0d) + x;
                d5 = (d4 / 2.0d) + y;
                d6 = d7;
                break;
            case 5:
                x += d10;
                d6 = x;
                d5 = (d4 / 2.0d) + y;
                break;
            case 6:
                y += d4;
                d6 = x;
                d5 = y;
                break;
            case 7:
                d7 = (d10 / 2.0d) + x;
                y += d4;
                d5 = y;
                d6 = d7;
                break;
            case 8:
                x += d10;
                y += d4;
                d6 = x;
                d5 = y;
                break;
        }
        shape.setAnchor(new Rectangle2D.Double(d6, d5, d3, d2));
    }
}
