package org.apache.poi.sl.draw;

import java.awt.BasicStroke;
import java.awt.Color;
import java.awt.Graphics2D;
import java.awt.Paint;
import java.awt.Shape;
import java.awt.geom.AffineTransform;
import java.awt.geom.Ellipse2D;
import java.awt.geom.Path2D;
import java.awt.geom.Rectangle2D;
import java.io.InputStream;
import java.util.ArrayList;
import java.util.Collection;
import java.util.HashMap;
import java.util.Iterator;
import java.util.Map;
import javax.xml.bind.JAXBContext;
import javax.xml.bind.Unmarshaller;
import javax.xml.stream.EventFilter;
import javax.xml.stream.XMLEventReader;
import javax.xml.stream.XMLInputFactory;
import javax.xml.stream.events.StartElement;
import javax.xml.stream.events.XMLEvent;
import org.apache.poi.sl.draw.binding.CTCustomGeometry2D;
import org.apache.poi.sl.draw.geom.Context;
import org.apache.poi.sl.draw.geom.CustomGeometry;
import org.apache.poi.sl.draw.geom.Outline;
import org.apache.poi.sl.draw.geom.Path;
import org.apache.poi.sl.draw.geom.PresetGeometries;
import org.apache.poi.sl.usermodel.LineDecoration;
import org.apache.poi.sl.usermodel.Shadow;
import org.apache.poi.sl.usermodel.SimpleShape;
import org.apache.poi.ss.formula.functions.NumericFunction;
import org.apache.poi.util.IOUtils;
import org.apache.poi.util.StaxHelper;
import org.apache.poi.util.Units;

public class DrawSimpleShape extends DrawShape {
    public static final double DECO_SIZE_POW = 1.5d;

    /* renamed from: org.apache.poi.sl.draw.DrawSimpleShape$2  reason: invalid class name */
    public static /* synthetic */ class AnonymousClass2 {
        public static final /* synthetic */ int[] $SwitchMap$org$apache$poi$sl$usermodel$LineDecoration$DecorationShape;

        /* JADX WARNING: Can't wrap try/catch for region: R(8:0|1|2|3|4|5|6|(3:7|8|10)) */
        /* JADX WARNING: Failed to process nested try/catch */
        /* JADX WARNING: Missing exception handler attribute for start block: B:3:0x000f */
        /* JADX WARNING: Missing exception handler attribute for start block: B:5:0x0016 */
        /* JADX WARNING: Missing exception handler attribute for start block: B:7:0x001e */
        static {
            int[] iArr = new int[LineDecoration.DecorationShape.values().length];
            $SwitchMap$org$apache$poi$sl$usermodel$LineDecoration$DecorationShape = iArr;
            LineDecoration.DecorationShape decorationShape = LineDecoration.DecorationShape.OVAL;
            iArr[4] = 1;
            int[] iArr2 = $SwitchMap$org$apache$poi$sl$usermodel$LineDecoration$DecorationShape;
            LineDecoration.DecorationShape decorationShape2 = LineDecoration.DecorationShape.STEALTH;
            iArr2[2] = 2;
            int[] iArr3 = $SwitchMap$org$apache$poi$sl$usermodel$LineDecoration$DecorationShape;
            LineDecoration.DecorationShape decorationShape3 = LineDecoration.DecorationShape.ARROW;
            iArr3[5] = 3;
            try {
                int[] iArr4 = $SwitchMap$org$apache$poi$sl$usermodel$LineDecoration$DecorationShape;
                LineDecoration.DecorationShape decorationShape4 = LineDecoration.DecorationShape.TRIANGLE;
                iArr4[1] = 4;
            } catch (NoSuchFieldError unused) {
            }
        }
    }

    public DrawSimpleShape(SimpleShape<?, ?> simpleShape) {
        super(simpleShape);
    }

    public static CustomGeometry getCustomGeometry(String str) {
        return getCustomGeometry(str, null);
    }

    public Collection<Outline> computeOutlines(Graphics2D graphics2D) {
        double d2;
        double d3;
        SimpleShape<?, ?> shape = getShape();
        ArrayList arrayList = new ArrayList();
        CustomGeometry geometry = shape.getGeometry();
        if (geometry == null) {
            return arrayList;
        }
        Rectangle2D anchor = DrawShape.getAnchor(graphics2D, shape);
        Iterator<Path> it = geometry.iterator();
        while (it.hasNext()) {
            Path next = it.next();
            double w = (double) next.getW();
            double h2 = (double) next.getH();
            double points = Units.toPoints(1);
            if (w == -1.0d) {
                d2 = (double) Units.toEMU(anchor.getWidth());
                d3 = points;
            } else {
                d3 = anchor.getWidth() / w;
                d2 = w;
            }
            if (h2 == -1.0d) {
                h2 = (double) Units.toEMU(anchor.getHeight());
            } else {
                points = anchor.getHeight() / h2;
            }
            Path2D.Double path = next.getPath(new Context(geometry, new Rectangle2D.Double((double) NumericFunction.LOG_10_TO_BASE_e, (double) NumericFunction.LOG_10_TO_BASE_e, d2, h2), shape));
            AffineTransform affineTransform = new AffineTransform();
            affineTransform.translate(anchor.getX(), anchor.getY());
            affineTransform.scale(d3, points);
            arrayList.add(new Outline(affineTransform.createTransformedShape(path), next));
        }
        return arrayList;
    }

    @Override // org.apache.poi.sl.draw.DrawShape, org.apache.poi.sl.draw.Drawable
    public void draw(Graphics2D graphics2D) {
        Paint paint;
        DrawPaint paint2 = DrawFactory.getInstance(graphics2D).getPaint(getShape());
        Paint paint3 = paint2.getPaint(graphics2D, getShape().getFillStyle().getPaint());
        Paint paint4 = paint2.getPaint(graphics2D, getShape().getStrokeStyle().getPaint());
        BasicStroke stroke = getStroke();
        graphics2D.setStroke(stroke);
        Collection<Outline> computeOutlines = computeOutlines(graphics2D);
        drawShadow(graphics2D, computeOutlines, paint3, paint4);
        if (paint3 != null) {
            for (Outline outline : computeOutlines) {
                if (outline.getPath().isFilled() && (paint = paint2.getPaint(graphics2D, getShape().getFillStyle().getPaint(), outline.getPath().getFill())) != null) {
                    graphics2D.setPaint(paint);
                    Shape outline2 = outline.getOutline();
                    graphics2D.setRenderingHint(Drawable.GRADIENT_SHAPE, outline2);
                    graphics2D.fill(outline2);
                }
            }
        }
        drawContent(graphics2D);
        if (paint4 != null) {
            graphics2D.setPaint(paint4);
            graphics2D.setStroke(stroke);
            for (Outline outline3 : computeOutlines) {
                if (outline3.getPath().isStroked()) {
                    Shape outline4 = outline3.getOutline();
                    graphics2D.setRenderingHint(Drawable.GRADIENT_SHAPE, outline4);
                    graphics2D.draw(outline4);
                }
            }
        }
        drawDecoration(graphics2D, paint4, stroke);
    }

    public void drawDecoration(Graphics2D graphics2D, Paint paint, BasicStroke basicStroke) {
        if (paint != null) {
            graphics2D.setPaint(paint);
            ArrayList arrayList = new ArrayList();
            LineDecoration lineDecoration = getShape().getLineDecoration();
            Outline headDecoration = getHeadDecoration(graphics2D, lineDecoration, basicStroke);
            if (headDecoration != null) {
                arrayList.add(headDecoration);
            }
            Outline tailDecoration = getTailDecoration(graphics2D, lineDecoration, basicStroke);
            if (tailDecoration != null) {
                arrayList.add(tailDecoration);
            }
            Iterator it = arrayList.iterator();
            while (it.hasNext()) {
                Outline outline = (Outline) it.next();
                Shape outline2 = outline.getOutline();
                Path path = outline.getPath();
                graphics2D.setRenderingHint(Drawable.GRADIENT_SHAPE, outline2);
                if (path.isFilled()) {
                    graphics2D.fill(outline2);
                }
                if (path.isStroked()) {
                    graphics2D.draw(outline2);
                }
            }
        }
    }

    public void drawShadow(Graphics2D graphics2D, Collection<Outline> collection, Paint paint, Paint paint2) {
        Shadow<?, ?> shadow = getShape().getShadow();
        if (shadow == null) {
            return;
        }
        if (!(paint == null && paint2 == null)) {
            Color applyColorTransform = DrawPaint.applyColorTransform(shadow.getFillStyle().getSolidColor());
            double rotation = getShape().getRotation();
            if (getShape().getFlipVertical()) {
                rotation += 180.0d;
            }
            double angle = shadow.getAngle() - rotation;
            double distance = shadow.getDistance();
            double cos = Math.cos(Math.toRadians(angle)) * distance;
            double sin = Math.sin(Math.toRadians(angle)) * distance;
            graphics2D.translate(cos, sin);
            for (Outline outline : collection) {
                Shape outline2 = outline.getOutline();
                Path path = outline.getPath();
                graphics2D.setRenderingHint(Drawable.GRADIENT_SHAPE, outline2);
                graphics2D.setPaint(applyColorTransform);
                if (paint != null && path.isFilled()) {
                    graphics2D.fill(outline2);
                } else if (paint2 != null && path.isStroked()) {
                    graphics2D.draw(outline2);
                }
            }
            graphics2D.translate(-cos, -sin);
        }
    }

    public Outline getHeadDecoration(Graphics2D graphics2D, LineDecoration lineDecoration, BasicStroke basicStroke) {
        Shape shape;
        Path path;
        if (lineDecoration == null || basicStroke == null) {
            return null;
        }
        LineDecoration.DecorationSize headLength = lineDecoration.getHeadLength();
        if (headLength == null) {
            headLength = LineDecoration.DecorationSize.MEDIUM;
        }
        LineDecoration.DecorationSize headWidth = lineDecoration.getHeadWidth();
        if (headWidth == null) {
            headWidth = LineDecoration.DecorationSize.MEDIUM;
        }
        double max = Math.max(2.5d, (double) basicStroke.getLineWidth());
        Rectangle2D anchor = DrawShape.getAnchor(graphics2D, getShape());
        double x = anchor.getX();
        double y = anchor.getY();
        double atan = Math.atan(anchor.getHeight() / anchor.getWidth());
        AffineTransform affineTransform = new AffineTransform();
        double pow = Math.pow(1.5d, ((double) headWidth.ordinal()) + 1.0d);
        double pow2 = Math.pow(1.5d, ((double) headLength.ordinal()) + 1.0d);
        LineDecoration.DecorationShape headShape = lineDecoration.getHeadShape();
        if (headShape == null) {
            return null;
        }
        int ordinal = headShape.ordinal();
        if (ordinal != 1) {
            if (ordinal != 2) {
                if (ordinal == 4) {
                    path = new Path();
                    Shape shape2 = new Ellipse2D.Double((double) NumericFunction.LOG_10_TO_BASE_e, (double) NumericFunction.LOG_10_TO_BASE_e, max * pow2, max * pow);
                    Rectangle2D bounds2D = shape2.getBounds2D();
                    affineTransform.translate(x - (bounds2D.getWidth() / 2.0d), y - (bounds2D.getHeight() / 2.0d));
                    affineTransform.rotate(atan, (bounds2D.getWidth() / 2.0d) + bounds2D.getX(), (bounds2D.getHeight() / 2.0d) + bounds2D.getY());
                    shape = shape2;
                } else if (ordinal != 5) {
                    path = null;
                    shape = null;
                }
            }
            path = new Path(false, true);
            shape = new Path2D.Double();
            double d2 = pow2 * max;
            shape.moveTo(d2, ((-max) * pow) / 2.0d);
            shape.lineTo((double) NumericFunction.LOG_10_TO_BASE_e, (double) NumericFunction.LOG_10_TO_BASE_e);
            shape.lineTo(d2, (max * pow) / 2.0d);
            affineTransform.translate(x, y);
            affineTransform.rotate(atan);
        } else {
            path = new Path();
            shape = new Path2D.Double();
            double d3 = pow2 * max;
            shape.moveTo(d3, ((-max) * pow) / 2.0d);
            shape.lineTo((double) NumericFunction.LOG_10_TO_BASE_e, (double) NumericFunction.LOG_10_TO_BASE_e);
            shape.lineTo(d3, (max * pow) / 2.0d);
            shape.closePath();
            affineTransform.translate(x, y);
            affineTransform.rotate(atan);
        }
        if (shape != null) {
            shape = affineTransform.createTransformedShape(shape);
        }
        if (shape == null) {
            return null;
        }
        return new Outline(shape, path);
    }

    public BasicStroke getStroke() {
        return DrawShape.getStroke(getShape().getStrokeStyle());
    }

    public Outline getTailDecoration(Graphics2D graphics2D, LineDecoration lineDecoration, BasicStroke basicStroke) {
        Shape shape;
        Path path;
        if (lineDecoration == null || basicStroke == null) {
            return null;
        }
        LineDecoration.DecorationSize tailLength = lineDecoration.getTailLength();
        if (tailLength == null) {
            tailLength = LineDecoration.DecorationSize.MEDIUM;
        }
        LineDecoration.DecorationSize tailWidth = lineDecoration.getTailWidth();
        if (tailWidth == null) {
            tailWidth = LineDecoration.DecorationSize.MEDIUM;
        }
        double max = Math.max(2.5d, (double) basicStroke.getLineWidth());
        Rectangle2D anchor = DrawShape.getAnchor(graphics2D, getShape());
        double x = anchor.getX() + anchor.getWidth();
        double y = anchor.getY() + anchor.getHeight();
        double atan = Math.atan(anchor.getHeight() / anchor.getWidth());
        AffineTransform affineTransform = new AffineTransform();
        double pow = Math.pow(1.5d, ((double) tailWidth.ordinal()) + 1.0d);
        double pow2 = Math.pow(1.5d, ((double) tailLength.ordinal()) + 1.0d);
        LineDecoration.DecorationShape tailShape = lineDecoration.getTailShape();
        if (tailShape == null) {
            return null;
        }
        int ordinal = tailShape.ordinal();
        if (ordinal != 1) {
            if (ordinal != 2) {
                if (ordinal == 4) {
                    path = new Path();
                    Shape shape2 = new Ellipse2D.Double((double) NumericFunction.LOG_10_TO_BASE_e, (double) NumericFunction.LOG_10_TO_BASE_e, max * pow2, max * pow);
                    Rectangle2D bounds2D = shape2.getBounds2D();
                    affineTransform.translate(x - (bounds2D.getWidth() / 2.0d), y - (bounds2D.getHeight() / 2.0d));
                    affineTransform.rotate(atan, (bounds2D.getWidth() / 2.0d) + bounds2D.getX(), (bounds2D.getHeight() / 2.0d) + bounds2D.getY());
                    shape = shape2;
                } else if (ordinal != 5) {
                    path = null;
                    shape = null;
                }
            }
            path = new Path(false, true);
            shape = new Path2D.Double();
            double d2 = -max;
            double d3 = pow2 * d2;
            shape.moveTo(d3, (d2 * pow) / 2.0d);
            shape.lineTo((double) NumericFunction.LOG_10_TO_BASE_e, (double) NumericFunction.LOG_10_TO_BASE_e);
            shape.lineTo(d3, (max * pow) / 2.0d);
            affineTransform.translate(x, y);
            affineTransform.rotate(atan);
        } else {
            path = new Path();
            shape = new Path2D.Double();
            double d4 = -max;
            double d5 = pow2 * d4;
            shape.moveTo(d5, (d4 * pow) / 2.0d);
            shape.lineTo((double) NumericFunction.LOG_10_TO_BASE_e, (double) NumericFunction.LOG_10_TO_BASE_e);
            shape.lineTo(d5, (max * pow) / 2.0d);
            shape.closePath();
            affineTransform.translate(x, y);
            affineTransform.rotate(atan);
        }
        if (shape != null) {
            shape = affineTransform.createTransformedShape(shape);
        }
        if (shape == null) {
            return null;
        }
        return new Outline(shape, path);
    }

    /* JADX DEBUG: Failed to insert an additional move for type inference into block B:3:0x000c */
    /* JADX WARN: Multi-variable type inference failed */
    /* JADX WARN: Type inference failed for: r0v6, types: [java.util.Map] */
    /* JADX WARNING: Unknown variable types count: 1 */
    public static CustomGeometry getCustomGeometry(String str, Graphics2D graphics2D) {
        HashMap hashMap = graphics2D == null ? null : (Map) graphics2D.getRenderingHint(Drawable.PRESET_GEOMETRY_CACHE);
        if (hashMap == null) {
            hashMap = new HashMap();
            if (graphics2D != null) {
                graphics2D.setRenderingHint(Drawable.PRESET_GEOMETRY_CACHE, hashMap);
            }
            InputStream resourceAsStream = Drawable.class.getResourceAsStream("presetShapeDefinitions.xml");
            AnonymousClass1 r2 = new EventFilter() {
                /* class org.apache.poi.sl.draw.DrawSimpleShape.AnonymousClass1 */

                @Override // javax.xml.stream.EventFilter
                public boolean accept(XMLEvent xMLEvent) {
                    return xMLEvent.isStartElement();
                }
            };
            try {
                XMLInputFactory newXMLInputFactory = StaxHelper.newXMLInputFactory();
                XMLEventReader createXMLEventReader = newXMLInputFactory.createXMLEventReader(resourceAsStream);
                XMLEventReader createFilteredReader = newXMLInputFactory.createFilteredReader(createXMLEventReader, r2);
                createFilteredReader.nextEvent();
                Unmarshaller createUnmarshaller = JAXBContext.newInstance(PresetGeometries.BINDING_PACKAGE).createUnmarshaller();
                while (createFilteredReader.peek() != null) {
                    hashMap.put(((StartElement) createFilteredReader.peek()).getName().getLocalPart(), new CustomGeometry((CTCustomGeometry2D) createUnmarshaller.unmarshal(createXMLEventReader, CTCustomGeometry2D.class).getValue()));
                }
                createFilteredReader.close();
                createXMLEventReader.close();
                IOUtils.closeQuietly(resourceAsStream);
            } catch (Exception e2) {
                throw new RuntimeException("Unable to load preset geometries.", e2);
            } catch (Throwable th) {
                IOUtils.closeQuietly(resourceAsStream);
                throw th;
            }
        }
        return (CustomGeometry) hashMap.get(str);
    }

    @Override // org.apache.poi.sl.draw.DrawShape
    public SimpleShape<?, ?> getShape() {
        return (SimpleShape) this.shape;
    }
}
