package org.apache.poi.sl.draw;

import java.awt.Dimension;
import java.awt.Font;
import java.awt.Graphics2D;
import java.awt.Paint;
import java.awt.font.FontRenderContext;
import java.awt.font.LineBreakMeasurer;
import java.awt.font.TextAttribute;
import java.awt.font.TextLayout;
import java.awt.geom.AffineTransform;
import java.awt.geom.Rectangle2D;
import java.io.InvalidObjectException;
import java.text.AttributedCharacterIterator;
import java.text.AttributedString;
import java.util.ArrayList;
import java.util.Iterator;
import java.util.List;
import java.util.Locale;
import org.apache.poi.common.usermodel.fonts.FontGroup;
import org.apache.poi.common.usermodel.fonts.FontInfo;
import org.apache.poi.sl.usermodel.AutoNumberingScheme;
import org.apache.poi.sl.usermodel.Hyperlink;
import org.apache.poi.sl.usermodel.Insets2D;
import org.apache.poi.sl.usermodel.PaintStyle;
import org.apache.poi.sl.usermodel.PlaceableShape;
import org.apache.poi.sl.usermodel.ShapeContainer;
import org.apache.poi.sl.usermodel.Sheet;
import org.apache.poi.sl.usermodel.Slide;
import org.apache.poi.sl.usermodel.TextParagraph;
import org.apache.poi.sl.usermodel.TextRun;
import org.apache.poi.sl.usermodel.TextShape;
import org.apache.poi.ss.formula.functions.NumericFunction;
import org.apache.poi.util.POILogFactory;
import org.apache.poi.util.POILogger;
import org.apache.poi.util.Units;
import org.apache.xmlbeans.impl.schema.SoapEncSchemaTypeSystem;

public class DrawTextParagraph implements Drawable {
    public static final /* synthetic */ boolean $assertionsDisabled = false;
    public static final XlinkAttribute HYPERLINK_HREF = new XlinkAttribute(SoapEncSchemaTypeSystem.ATTR_HREF);
    public static final XlinkAttribute HYPERLINK_LABEL = new XlinkAttribute("label");
    public static final POILogger LOG = POILogFactory.getLogger(DrawTextParagraph.class);
    public int autoNbrIdx;
    public DrawTextFragment bullet;
    public List<DrawTextFragment> lines = new ArrayList();
    public double maxLineHeight;
    public TextParagraph<?, ?, ?> paragraph;
    public String rawText;
    public double x;
    public double y;

    /* renamed from: org.apache.poi.sl.draw.DrawTextParagraph$2  reason: invalid class name */
    public static /* synthetic */ class AnonymousClass2 {
        public static final /* synthetic */ int[] $SwitchMap$org$apache$poi$sl$usermodel$TextParagraph$TextAlign;
        public static final /* synthetic */ int[] $SwitchMap$org$apache$poi$sl$usermodel$TextRun$TextCap;
        public static final /* synthetic */ int[] $SwitchMap$org$apache$poi$sl$usermodel$TextShape$TextDirection;

        /* JADX WARNING: Can't wrap try/catch for region: R(18:0|(2:1|2)|3|5|6|7|9|10|11|12|13|14|15|17|18|19|20|22) */
        /* JADX WARNING: Can't wrap try/catch for region: R(19:0|1|2|3|5|6|7|9|10|11|12|13|14|15|17|18|19|20|22) */
        /* JADX WARNING: Failed to process nested try/catch */
        /* JADX WARNING: Missing exception handler attribute for start block: B:11:0x0022 */
        /* JADX WARNING: Missing exception handler attribute for start block: B:13:0x0028 */
        /* JADX WARNING: Missing exception handler attribute for start block: B:19:0x003d */
        static {
            int[] iArr = new int[TextShape.TextDirection.values().length];
            $SwitchMap$org$apache$poi$sl$usermodel$TextShape$TextDirection = iArr;
            try {
                TextShape.TextDirection textDirection = TextShape.TextDirection.VERTICAL;
                iArr[1] = 1;
            } catch (NoSuchFieldError unused) {
            }
            try {
                int[] iArr2 = $SwitchMap$org$apache$poi$sl$usermodel$TextShape$TextDirection;
                TextShape.TextDirection textDirection2 = TextShape.TextDirection.VERTICAL_270;
                iArr2[2] = 2;
            } catch (NoSuchFieldError unused2) {
            }
            int[] iArr3 = new int[TextRun.TextCap.values().length];
            $SwitchMap$org$apache$poi$sl$usermodel$TextRun$TextCap = iArr3;
            TextRun.TextCap textCap = TextRun.TextCap.ALL;
            iArr3[2] = 1;
            int[] iArr4 = $SwitchMap$org$apache$poi$sl$usermodel$TextRun$TextCap;
            TextRun.TextCap textCap2 = TextRun.TextCap.SMALL;
            iArr4[1] = 2;
            int[] iArr5 = $SwitchMap$org$apache$poi$sl$usermodel$TextRun$TextCap;
            TextRun.TextCap textCap3 = TextRun.TextCap.NONE;
            iArr5[0] = 3;
            int[] iArr6 = new int[TextParagraph.TextAlign.values().length];
            $SwitchMap$org$apache$poi$sl$usermodel$TextParagraph$TextAlign = iArr6;
            TextParagraph.TextAlign textAlign = TextParagraph.TextAlign.CENTER;
            iArr6[1] = 1;
            try {
                int[] iArr7 = $SwitchMap$org$apache$poi$sl$usermodel$TextParagraph$TextAlign;
                TextParagraph.TextAlign textAlign2 = TextParagraph.TextAlign.RIGHT;
                iArr7[2] = 2;
            } catch (NoSuchFieldError unused3) {
            }
        }
    }

    public static class AttributedStringData {
        public AttributedCharacterIterator.Attribute attribute;
        public int beginIndex;
        public int endIndex;
        public Object value;

        public AttributedStringData(AttributedCharacterIterator.Attribute attribute2, Object obj, int i2, int i3) {
            this.attribute = attribute2;
            this.value = obj;
            this.beginIndex = i2;
            this.endIndex = i3;
        }
    }

    public static class XlinkAttribute extends AttributedCharacterIterator.Attribute {
        public XlinkAttribute(String str) {
            super(str);
        }

        @Override // java.text.AttributedCharacterIterator.Attribute
        public Object readResolve() {
            if (DrawTextParagraph.HYPERLINK_HREF.getName().equals(getName())) {
                return DrawTextParagraph.HYPERLINK_HREF;
            }
            if (DrawTextParagraph.HYPERLINK_LABEL.getName().equals(getName())) {
                return DrawTextParagraph.HYPERLINK_LABEL;
            }
            throw new InvalidObjectException("unknown attribute name");
        }
    }

    public DrawTextParagraph(TextParagraph<?, ?, ?> textParagraph) {
        this.paragraph = textParagraph;
    }

    private PlaceableShape<?, ?> getParagraphShape() {
        return new PlaceableShape() {
            /* class org.apache.poi.sl.draw.DrawTextParagraph.AnonymousClass1 */

            @Override // org.apache.poi.sl.usermodel.PlaceableShape
            public Rectangle2D getAnchor() {
                return DrawTextParagraph.this.paragraph.getParentShape().getAnchor();
            }

            @Override // org.apache.poi.sl.usermodel.PlaceableShape
            public boolean getFlipHorizontal() {
                return false;
            }

            @Override // org.apache.poi.sl.usermodel.PlaceableShape
            public boolean getFlipVertical() {
                return false;
            }

            @Override // org.apache.poi.sl.usermodel.PlaceableShape
            public ShapeContainer<?, ?> getParent() {
                return null;
            }

            @Override // org.apache.poi.sl.usermodel.PlaceableShape
            public double getRotation() {
                return NumericFunction.LOG_10_TO_BASE_e;
            }

            @Override // org.apache.poi.sl.usermodel.PlaceableShape
            public Sheet<?, ?> getSheet() {
                return DrawTextParagraph.this.paragraph.getParentShape().getSheet();
            }

            @Override // org.apache.poi.sl.usermodel.PlaceableShape
            public void setAnchor(Rectangle2D rectangle2D) {
            }

            @Override // org.apache.poi.sl.usermodel.PlaceableShape
            public void setFlipHorizontal(boolean z) {
            }

            @Override // org.apache.poi.sl.usermodel.PlaceableShape
            public void setFlipVertical(boolean z) {
            }

            @Override // org.apache.poi.sl.usermodel.PlaceableShape
            public void setRotation(double d2) {
            }
        };
    }

    public static int nextPart(Font font, String str, int i2, int i3, boolean z) {
        while (i2 < i3) {
            int codePointAt = str.codePointAt(i2);
            if (font.canDisplay(codePointAt) != z) {
                break;
            }
            i2 += Character.charCount(codePointAt);
        }
        return i2;
    }

    private void processGlyphs(Graphics2D graphics2D, DrawFontManager drawFontManager, List<AttributedStringData> list, int i2, TextRun textRun, String str) {
        int i3;
        int i4;
        Graphics2D graphics2D2 = graphics2D;
        DrawFontManager drawFontManager2 = drawFontManager;
        int i5 = 0;
        for (FontGroup.FontGroupRange fontGroupRange : FontGroup.getFontGroupRanges(str)) {
            FontInfo fontInfo = textRun.getFontInfo(fontGroupRange.getFontGroup());
            if (fontInfo == null) {
                fontInfo = textRun.getFontInfo(FontGroup.LATIN);
            }
            FontInfo mappedFont = drawFontManager2.getMappedFont(graphics2D2, fontInfo);
            FontInfo fallbackFont = drawFontManager2.getFallbackFont(graphics2D2, fontInfo);
            if (mappedFont == null) {
                mappedFont = drawFontManager2.getMappedFont(graphics2D2, new DrawFontInfo(this.paragraph.getDefaultFontFamily()));
            }
            Font createAWTFont = drawFontManager.createAWTFont(graphics2D, mappedFont == null ? fallbackFont : mappedFont, 10.0d, textRun.isBold(), textRun.isItalic());
            Font createAWTFont2 = drawFontManager.createAWTFont(graphics2D, fallbackFont, 10.0d, textRun.isBold(), textRun.isItalic());
            int length = fontGroupRange.getLength();
            int i6 = i5;
            while (true) {
                i3 = i5 + length;
                if (i6 >= i3) {
                    break;
                }
                int nextPart = nextPart(createAWTFont, str, i6, i3, true);
                if (i6 < nextPart) {
                    i4 = length;
                    int i7 = i2 + i6;
                    int i8 = i2 + nextPart;
                    list.add(new AttributedStringData(TextAttribute.FAMILY, createAWTFont.getFontName(Locale.ROOT), i7, i8));
                    if (LOG.check(1)) {
                        LOG.log(1, "mapped: ", createAWTFont.getFontName(Locale.ROOT), " ", Integer.valueOf(i7), " ", Integer.valueOf(i8), " - ", str.substring(i7, i8));
                    }
                } else {
                    i4 = length;
                }
                i6 = nextPart(createAWTFont, str, nextPart, i3, false);
                if (nextPart < i6) {
                    int i9 = i2 + nextPart;
                    int i10 = i2 + i6;
                    list.add(new AttributedStringData(TextAttribute.FAMILY, createAWTFont2.getFontName(Locale.ROOT), i9, i10));
                    if (LOG.check(1)) {
                        LOG.log(1, "fallback: ", createAWTFont2.getFontName(Locale.ROOT), " ", Integer.valueOf(i9), " ", Integer.valueOf(i10), " - ", str.substring(i9, i10));
                        length = i4;
                    }
                }
                length = i4;
            }
            graphics2D2 = graphics2D;
            drawFontManager2 = drawFontManager;
            i5 = i3;
        }
    }

    private String tab2space(TextRun textRun) {
        AttributedString attributedString = new AttributedString(" ");
        String fontFamily = textRun.getFontFamily();
        if (fontFamily == null) {
            fontFamily = "Lucida Sans";
        }
        attributedString.addAttribute(TextAttribute.FAMILY, fontFamily);
        Double fontSize = textRun.getFontSize();
        if (fontSize == null) {
            fontSize = Double.valueOf(12.0d);
        }
        attributedString.addAttribute(TextAttribute.SIZE, Float.valueOf(fontSize.floatValue()));
        double advance = (double) new TextLayout(attributedString.getIterator(), new FontRenderContext((AffineTransform) null, true, true)).getAdvance();
        Double defaultTabSize = this.paragraph.getDefaultTabSize();
        if (defaultTabSize == null) {
            defaultTabSize = Double.valueOf(4.0d * advance);
        }
        int ceil = (int) Math.ceil(defaultTabSize.doubleValue() / advance);
        StringBuilder sb = new StringBuilder();
        for (int i2 = 0; i2 < ceil; i2++) {
            sb.append(' ');
        }
        return sb.toString();
    }

    @Override // org.apache.poi.sl.draw.Drawable
    public void applyTransform(Graphics2D graphics2D) {
    }

    public void breakText(Graphics2D graphics2D) {
        int position;
        AttributedString attributedString;
        this.lines.clear();
        DrawFactory instance = DrawFactory.getInstance(graphics2D);
        instance.fixFonts(graphics2D);
        StringBuilder sb = new StringBuilder();
        AttributedString attributedString2 = getAttributedString(graphics2D, sb);
        boolean equals = "".equals(sb.toString().trim());
        AttributedCharacterIterator iterator = attributedString2.getIterator();
        LineBreakMeasurer lineBreakMeasurer = new LineBreakMeasurer(iterator, graphics2D.getFontRenderContext());
        do {
            int position2 = lineBreakMeasurer.getPosition();
            double d2 = 1.0d;
            double wrappingWidth = getWrappingWidth(this.lines.isEmpty(), graphics2D) + 1.0d;
            if (wrappingWidth >= NumericFunction.LOG_10_TO_BASE_e) {
                d2 = wrappingWidth;
            }
            int indexOf = sb.indexOf("\n", position2 + 1);
            if (indexOf == -1) {
                indexOf = iterator.getEndIndex();
            }
            float f2 = (float) d2;
            TextLayout nextLayout = lineBreakMeasurer.nextLayout(f2, indexOf, true);
            if (nextLayout == null) {
                nextLayout = lineBreakMeasurer.nextLayout(f2, indexOf, false);
            }
            if (nextLayout == null) {
                break;
            }
            position = lineBreakMeasurer.getPosition();
            if (position < iterator.getEndIndex() && sb.charAt(position) == '\n') {
                lineBreakMeasurer.setPosition(position + 1);
            }
            TextParagraph.TextAlign textAlign = this.paragraph.getTextAlign();
            if (textAlign == TextParagraph.TextAlign.JUSTIFY || textAlign == TextParagraph.TextAlign.JUSTIFY_LOW) {
                nextLayout = nextLayout.getJustifiedLayout(f2);
            }
            if (equals) {
                attributedString = null;
            } else {
                attributedString = new AttributedString(iterator, position2, position);
            }
            DrawTextFragment textFragment = instance.getTextFragment(nextLayout, attributedString);
            this.lines.add(textFragment);
            this.maxLineHeight = Math.max(this.maxLineHeight, (double) textFragment.getHeight());
        } while (position != iterator.getEndIndex());
        this.rawText = sb.toString();
    }

    /* JADX WARNING: Removed duplicated region for block: B:31:0x00f8  */
    /* JADX WARNING: Removed duplicated region for block: B:34:0x0103  */
    /* JADX WARNING: Removed duplicated region for block: B:38:0x011e  */
    /* JADX WARNING: Removed duplicated region for block: B:42:0x014a  */
    /* JADX WARNING: Removed duplicated region for block: B:43:0x015f  */
    @Override // org.apache.poi.sl.draw.Drawable
    public void draw(Graphics2D graphics2D) {
        double d2;
        double d3;
        TextParagraph.TextAlign textAlign;
        int ordinal;
        Double d4;
        double d5;
        double d6;
        double d7;
        double d8;
        double d9;
        DrawTextParagraph drawTextParagraph = this;
        Graphics2D graphics2D2 = graphics2D;
        if (!drawTextParagraph.lines.isEmpty()) {
            double d10 = drawTextParagraph.y;
            int indentLevel = drawTextParagraph.paragraph.getIndentLevel();
            Double leftMargin = drawTextParagraph.paragraph.getLeftMargin();
            if (leftMargin == null) {
                leftMargin = Double.valueOf(Units.toPoints(((long) indentLevel) * 347663));
            }
            Double indent = drawTextParagraph.paragraph.getIndent();
            if (indent == null) {
                indent = Double.valueOf(Units.toPoints(((long) indentLevel) * 347663));
            }
            if (isHSLF()) {
                indent = Double.valueOf(indent.doubleValue() - leftMargin.doubleValue());
            }
            Double lineSpacing = drawTextParagraph.paragraph.getLineSpacing();
            if (lineSpacing == null) {
                lineSpacing = Double.valueOf(100.0d);
            }
            Iterator<DrawTextFragment> it = drawTextParagraph.lines.iterator();
            boolean z = true;
            while (it.hasNext()) {
                DrawTextFragment next = it.next();
                if (z) {
                    if (!isEmptyParagraph()) {
                        drawTextParagraph.bullet = drawTextParagraph.getBullet(graphics2D2, next.getAttributedString().getIterator());
                    }
                    DrawTextFragment drawTextFragment = drawTextParagraph.bullet;
                    if (drawTextFragment != null) {
                        drawTextFragment.setPosition(indent.doubleValue() + leftMargin.doubleValue() + drawTextParagraph.x, d10);
                        drawTextParagraph.bullet.draw(graphics2D2);
                        d2 = d10;
                        d3 = Math.max(leftMargin.doubleValue(), indent.doubleValue() + leftMargin.doubleValue() + ((double) (drawTextParagraph.bullet.getLayout().getAdvance() + 1.0f))) + drawTextParagraph.x;
                        Rectangle2D anchor = DrawShape.getAnchor(graphics2D2, drawTextParagraph.paragraph.getParentShape());
                        Insets2D insets = drawTextParagraph.paragraph.getParentShape().getInsets();
                        double d11 = insets.left;
                        double d12 = insets.right;
                        textAlign = drawTextParagraph.paragraph.getTextAlign();
                        if (textAlign == null) {
                            textAlign = TextParagraph.TextAlign.LEFT;
                        }
                        ordinal = textAlign.ordinal();
                        if (ordinal != 1) {
                            d4 = indent;
                            d7 = d2;
                            d3 += ((((anchor.getWidth() - ((double) next.getWidth())) - d11) - d12) - leftMargin.doubleValue()) / 2.0d;
                        } else if (ordinal != 2) {
                            d4 = indent;
                            d5 = d2;
                            next.setPosition(d3, d5);
                            next.draw(graphics2D);
                            if (lineSpacing.doubleValue() > NumericFunction.LOG_10_TO_BASE_e) {
                                d6 = (lineSpacing.doubleValue() * 0.01d * ((double) next.getHeight())) + d5;
                            } else {
                                d6 = d5 + (-lineSpacing.doubleValue());
                            }
                            z = false;
                            indent = d4;
                            it = it;
                            drawTextParagraph = this;
                            graphics2D2 = graphics2D;
                            d10 = d6;
                        } else {
                            d4 = indent;
                            d7 = d2;
                            d3 = (((anchor.getWidth() - ((double) next.getWidth())) - d11) - d12) + d3;
                        }
                        d5 = d7;
                        next.setPosition(d3, d5);
                        next.draw(graphics2D);
                        if (lineSpacing.doubleValue() > NumericFunction.LOG_10_TO_BASE_e) {
                        }
                        z = false;
                        indent = d4;
                        it = it;
                        drawTextParagraph = this;
                        graphics2D2 = graphics2D;
                        d10 = d6;
                    } else {
                        d2 = d10;
                        d9 = drawTextParagraph.x;
                        d8 = leftMargin.doubleValue();
                    }
                } else {
                    d2 = d10;
                    d9 = drawTextParagraph.x;
                    d8 = leftMargin.doubleValue();
                }
                d3 = d9 + d8;
                Rectangle2D anchor2 = DrawShape.getAnchor(graphics2D2, drawTextParagraph.paragraph.getParentShape());
                Insets2D insets2 = drawTextParagraph.paragraph.getParentShape().getInsets();
                double d112 = insets2.left;
                double d122 = insets2.right;
                textAlign = drawTextParagraph.paragraph.getTextAlign();
                if (textAlign == null) {
                }
                ordinal = textAlign.ordinal();
                if (ordinal != 1) {
                }
                d5 = d7;
                next.setPosition(d3, d5);
                next.draw(graphics2D);
                if (lineSpacing.doubleValue() > NumericFunction.LOG_10_TO_BASE_e) {
                }
                z = false;
                indent = d4;
                it = it;
                drawTextParagraph = this;
                graphics2D2 = graphics2D;
                d10 = d6;
            }
            drawTextParagraph.y = d10 - drawTextParagraph.y;
        }
    }

    @Override // org.apache.poi.sl.draw.Drawable
    public void drawContent(Graphics2D graphics2D) {
    }

    public AttributedString getAttributedString(Graphics2D graphics2D, StringBuilder sb) {
        ArrayList arrayList = new ArrayList();
        if (sb == null) {
            sb = new StringBuilder();
        }
        PlaceableShape<?, ?> paragraphShape = getParagraphShape();
        DrawFontManager fontManager = DrawFactory.getInstance(graphics2D).getFontManager(graphics2D);
        for (TextRun textRun : this.paragraph) {
            String renderableText = getRenderableText(graphics2D, textRun);
            if (!renderableText.isEmpty()) {
                String mapFontCharset = fontManager.mapFontCharset(graphics2D, textRun.getFontInfo(null), renderableText);
                int length = sb.length();
                sb.append(mapFontCharset);
                int length2 = sb.length();
                arrayList.add(new AttributedStringData(TextAttribute.FOREGROUND, new DrawPaint(paragraphShape).getPaint(graphics2D, textRun.getFontColor()), length, length2));
                Double fontSize = textRun.getFontSize();
                if (fontSize == null) {
                    fontSize = this.paragraph.getDefaultFontSize();
                }
                arrayList.add(new AttributedStringData(TextAttribute.SIZE, Float.valueOf(fontSize.floatValue()), length, length2));
                if (textRun.isBold()) {
                    arrayList.add(new AttributedStringData(TextAttribute.WEIGHT, TextAttribute.WEIGHT_BOLD, length, length2));
                }
                if (textRun.isItalic()) {
                    arrayList.add(new AttributedStringData(TextAttribute.POSTURE, TextAttribute.POSTURE_OBLIQUE, length, length2));
                }
                if (textRun.isUnderlined()) {
                    arrayList.add(new AttributedStringData(TextAttribute.UNDERLINE, TextAttribute.UNDERLINE_ON, length, length2));
                    arrayList.add(new AttributedStringData(TextAttribute.INPUT_METHOD_UNDERLINE, TextAttribute.UNDERLINE_LOW_TWO_PIXEL, length, length2));
                }
                if (textRun.isStrikethrough()) {
                    arrayList.add(new AttributedStringData(TextAttribute.STRIKETHROUGH, TextAttribute.STRIKETHROUGH_ON, length, length2));
                }
                if (textRun.isSubscript()) {
                    arrayList.add(new AttributedStringData(TextAttribute.SUPERSCRIPT, TextAttribute.SUPERSCRIPT_SUB, length, length2));
                }
                if (textRun.isSuperscript()) {
                    arrayList.add(new AttributedStringData(TextAttribute.SUPERSCRIPT, TextAttribute.SUPERSCRIPT_SUPER, length, length2));
                }
                Hyperlink<?, ?> hyperlink = textRun.getHyperlink();
                if (hyperlink != null) {
                    arrayList.add(new AttributedStringData(HYPERLINK_HREF, hyperlink.getAddress(), length, length2));
                    arrayList.add(new AttributedStringData(HYPERLINK_LABEL, hyperlink.getLabel(), length, length2));
                }
                processGlyphs(graphics2D, fontManager, arrayList, length, textRun, mapFontCharset);
            }
        }
        if (sb.length() == 0) {
            Double defaultFontSize = this.paragraph.getDefaultFontSize();
            sb.append(" ");
            arrayList.add(new AttributedStringData(TextAttribute.SIZE, Float.valueOf(defaultFontSize.floatValue()), 0, 1));
        }
        AttributedString attributedString = new AttributedString(sb.toString());
        Iterator it = arrayList.iterator();
        while (it.hasNext()) {
            AttributedStringData attributedStringData = (AttributedStringData) it.next();
            attributedString.addAttribute(attributedStringData.attribute, attributedStringData.value, attributedStringData.beginIndex, attributedStringData.endIndex);
        }
        return attributedString;
    }

    public DrawTextFragment getBullet(Graphics2D graphics2D, AttributedCharacterIterator attributedCharacterIterator) {
        String str;
        Paint paint;
        float f2;
        TextParagraph.BulletStyle bulletStyle = this.paragraph.getBulletStyle();
        if (bulletStyle == null) {
            return null;
        }
        AutoNumberingScheme autoNumberingScheme = bulletStyle.getAutoNumberingScheme();
        if (autoNumberingScheme != null) {
            str = autoNumberingScheme.format(this.autoNbrIdx);
        } else {
            str = bulletStyle.getBulletCharacter();
        }
        if (str == null) {
            return null;
        }
        PlaceableShape<?, ?> paragraphShape = getParagraphShape();
        PaintStyle bulletFontColor = bulletStyle.getBulletFontColor();
        if (bulletFontColor == null) {
            paint = (Paint) attributedCharacterIterator.getAttribute(TextAttribute.FOREGROUND);
        } else {
            paint = new DrawPaint(paragraphShape).getPaint(graphics2D, bulletFontColor);
        }
        float floatValue = ((Float) attributedCharacterIterator.getAttribute(TextAttribute.SIZE)).floatValue();
        Double bulletFontSize = bulletStyle.getBulletFontSize();
        if (bulletFontSize == null) {
            bulletFontSize = Double.valueOf(100.0d);
        }
        if (bulletFontSize.doubleValue() > NumericFunction.LOG_10_TO_BASE_e) {
            f2 = (float) (bulletFontSize.doubleValue() * 0.01d * ((double) floatValue));
        } else {
            f2 = (float) (-bulletFontSize.doubleValue());
        }
        String bulletFont = bulletStyle.getBulletFont();
        if (bulletFont == null) {
            bulletFont = this.paragraph.getDefaultFontFamily();
        }
        DrawFontInfo drawFontInfo = new DrawFontInfo(bulletFont);
        DrawFontManager fontManager = DrawFactory.getInstance(graphics2D).getFontManager(graphics2D);
        FontInfo mappedFont = fontManager.getMappedFont(graphics2D, drawFontInfo);
        AttributedString attributedString = new AttributedString(fontManager.mapFontCharset(graphics2D, mappedFont, str));
        attributedString.addAttribute(TextAttribute.FOREGROUND, paint);
        attributedString.addAttribute(TextAttribute.FAMILY, mappedFont.getTypeface());
        attributedString.addAttribute(TextAttribute.SIZE, Float.valueOf(f2));
        return DrawFactory.getInstance(graphics2D).getTextFragment(new TextLayout(attributedString.getIterator(), graphics2D.getFontRenderContext()), attributedString);
    }

    public float getFirstLineHeight() {
        if (this.lines.isEmpty()) {
            return 0.0f;
        }
        return this.lines.get(0).getHeight();
    }

    public float getFirstLineLeading() {
        if (this.lines.isEmpty()) {
            return 0.0f;
        }
        return this.lines.get(0).getLeading();
    }

    public float getLastLineHeight() {
        if (this.lines.isEmpty()) {
            return 0.0f;
        }
        List<DrawTextFragment> list = this.lines;
        return list.get(list.size() - 1).getHeight();
    }

    public String getRenderableText(Graphics2D graphics2D, TextRun textRun) {
        if (textRun.getFieldType() == TextRun.FieldType.SLIDE_NUMBER) {
            Slide slide = (Slide) graphics2D.getRenderingHint(Drawable.CURRENT_SLIDE);
            if (slide == null) {
                return "";
            }
            return Integer.toString(slide.getSlideNumber());
        }
        StringBuilder sb = new StringBuilder();
        TextRun.TextCap textCap = textRun.getTextCap();
        String str = null;
        char[] charArray = textRun.getRawText().toCharArray();
        for (char c : charArray) {
            if (c == '\t') {
                if (str == null) {
                    str = tab2space(textRun);
                }
                sb.append(str);
            } else if (c != 11) {
                int ordinal = textCap.ordinal();
                if (ordinal == 1) {
                    c = Character.toLowerCase(c);
                } else if (ordinal == 2) {
                    c = Character.toUpperCase(c);
                }
                sb.append(c);
            } else {
                sb.append('\n');
            }
        }
        return sb.toString();
    }

    public double getWrappingWidth(boolean z, Graphics2D graphics2D) {
        double d2;
        double d3;
        double d4;
        double d5;
        TextShape<?, ?> parentShape = this.paragraph.getParentShape();
        Insets2D insets = parentShape.getInsets();
        double d6 = insets.left;
        double d7 = insets.right;
        int indentLevel = this.paragraph.getIndentLevel();
        if (indentLevel == -1) {
            indentLevel = 0;
        }
        Double leftMargin = this.paragraph.getLeftMargin();
        if (leftMargin == null) {
            leftMargin = Double.valueOf(Units.toPoints(((long) (indentLevel + 1)) * 347663));
        }
        Double indent = this.paragraph.getIndent();
        if (indent == null) {
            indent = Double.valueOf(Units.toPoints(((long) indentLevel) * 347663));
        }
        Double rightMargin = this.paragraph.getRightMargin();
        if (rightMargin == null) {
            rightMargin = Double.valueOf((double) NumericFunction.LOG_10_TO_BASE_e);
        }
        Rectangle2D anchor = DrawShape.getAnchor(graphics2D, parentShape);
        TextShape.TextDirection textDirection = parentShape.getTextDirection();
        if (!parentShape.getWordWrap()) {
            Dimension pageSize = parentShape.getSheet().getSlideShow().getPageSize();
            int ordinal = textDirection.ordinal();
            if (ordinal == 1) {
                d3 = pageSize.getHeight();
                d2 = anchor.getX();
            } else if (ordinal == 2) {
                return anchor.getX();
            } else {
                d3 = pageSize.getWidth();
                d2 = anchor.getX();
            }
        } else {
            int ordinal2 = textDirection.ordinal();
            if (ordinal2 == 1 || ordinal2 == 2) {
                d4 = ((anchor.getHeight() - d6) - d7) - leftMargin.doubleValue();
                d5 = rightMargin.doubleValue();
            } else {
                d4 = ((anchor.getWidth() - d6) - d7) - leftMargin.doubleValue();
                d5 = rightMargin.doubleValue();
            }
            d3 = d4 - d5;
            if (!z || isHSLF()) {
                return d3;
            }
            if (this.bullet != null) {
                if (indent.doubleValue() <= NumericFunction.LOG_10_TO_BASE_e) {
                    return d3;
                }
                d2 = indent.doubleValue();
            } else if (indent.doubleValue() <= NumericFunction.LOG_10_TO_BASE_e) {
                return indent.doubleValue() < NumericFunction.LOG_10_TO_BASE_e ? d3 + leftMargin.doubleValue() : d3;
            } else {
                d2 = indent.doubleValue();
            }
        }
        return d3 - d2;
    }

    public double getY() {
        return this.y;
    }

    public boolean isEmptyParagraph() {
        return this.lines.isEmpty() || this.rawText.trim().isEmpty();
    }

    public boolean isHSLF() {
        return DrawShape.isHSLF(this.paragraph.getParentShape());
    }

    public void setAutoNumberingIdx(int i2) {
        this.autoNbrIdx = i2;
    }

    public void setPosition(double d2, double d3) {
        this.x = d2;
        this.y = d3;
    }
}
