package org.apache.poi.sl.usermodel;

import java.io.File;
import java.io.FileNotFoundException;
import java.io.IOException;
import java.io.InputStream;
import java.lang.reflect.InvocationTargetException;
import org.apache.poi.EncryptedDocumentException;
import org.apache.poi.OldFileFormatException;
import org.apache.poi.hssf.record.crypto.Biff8EncryptionKey;
import org.apache.poi.poifs.filesystem.DocumentFactoryHelper;
import org.apache.poi.poifs.filesystem.FileMagic;
import org.apache.poi.poifs.filesystem.NPOIFSFileSystem;
import org.apache.poi.poifs.filesystem.OfficeXmlFileException;
import org.apache.poi.util.IOUtils;

public class SlideShowFactory {

    /* renamed from: org.apache.poi.sl.usermodel.SlideShowFactory$1  reason: invalid class name */
    public static /* synthetic */ class AnonymousClass1 {
        public static final /* synthetic */ int[] $SwitchMap$org$apache$poi$poifs$filesystem$FileMagic;

        /* JADX WARNING: Failed to process nested try/catch */
        /* JADX WARNING: Missing exception handler attribute for start block: B:3:0x000f */
        static {
            int[] iArr = new int[FileMagic.values().length];
            $SwitchMap$org$apache$poi$poifs$filesystem$FileMagic = iArr;
            FileMagic fileMagic = FileMagic.OLE2;
            iArr[0] = 1;
            try {
                int[] iArr2 = $SwitchMap$org$apache$poi$poifs$filesystem$FileMagic;
                FileMagic fileMagic2 = FileMagic.OOXML;
                iArr2[1] = 2;
            } catch (NoSuchFieldError unused) {
            }
        }
    }

    public static SlideShow<?, ?> create(NPOIFSFileSystem nPOIFSFileSystem) {
        return create(nPOIFSFileSystem, (String) null);
    }

    public static SlideShow<?, ?> createHSLFSlideShow(Object... objArr) {
        return createSlideShow("org.apache.poi.hslf.usermodel.HSLFSlideShowFactory", objArr);
    }

    public static SlideShow<?, ?> createSlideShow(String str, Object[] objArr) {
        try {
            Class<?> loadClass = Thread.currentThread().getContextClassLoader().loadClass(str);
            Class<?>[] clsArr = new Class[objArr.length];
            int length = objArr.length;
            int i2 = 0;
            int i3 = 0;
            while (i2 < length) {
                Class<?> cls = objArr[i2].getClass();
                if (Boolean.class.isAssignableFrom(cls)) {
                    cls = Boolean.TYPE;
                } else if (InputStream.class.isAssignableFrom(cls)) {
                    cls = InputStream.class;
                }
                clsArr[i3] = cls;
                i2++;
                i3++;
            }
            return (SlideShow) loadClass.getMethod("createSlideShow", clsArr).invoke(null, objArr);
        } catch (InvocationTargetException e2) {
            Throwable cause = e2.getCause();
            if (cause instanceof IOException) {
                throw ((IOException) cause);
            } else if (cause instanceof EncryptedDocumentException) {
                throw ((EncryptedDocumentException) cause);
            } else if (cause instanceof OldFileFormatException) {
                throw ((OldFileFormatException) cause);
            } else {
                throw new IOException(cause);
            }
        } catch (Exception e3) {
            throw new IOException(e3);
        }
    }

    public static SlideShow<?, ?> createXSLFSlideShow(Object... objArr) {
        return createSlideShow("org.apache.poi.xslf.usermodel.XSLFSlideShowFactory", objArr);
    }

    /* JADX DEBUG: Failed to insert an additional move for type inference into block B:2:0x000f */
    /* JADX WARN: Multi-variable type inference failed */
    /* JADX WARN: Type inference failed for: r2v0, types: [java.lang.String] */
    /* JADX WARN: Type inference failed for: r2v1, types: [java.io.Closeable] */
    /* JADX WARN: Type inference failed for: r2v2, types: [java.io.Closeable, java.io.InputStream] */
    /* JADX WARN: Type inference failed for: r4v4, types: [java.lang.Object[]] */
    /* JADX WARNING: Unknown variable types count: 2 */
    public static SlideShow<?, ?> create(NPOIFSFileSystem nPOIFSFileSystem, String str) {
        boolean z;
        ?? r2 = 0;
        if (nPOIFSFileSystem.getRoot().hasEntry("EncryptedPackage")) {
            try {
                r2 = DocumentFactoryHelper.getDecryptedStream(nPOIFSFileSystem, str);
                return createXSLFSlideShow(new Object[]{r2});
            } finally {
                IOUtils.closeQuietly(r2);
            }
        } else {
            if (str != null) {
                Biff8EncryptionKey.setCurrentUserPassword(str);
                z = true;
            } else {
                z = false;
            }
            try {
                return createHSLFSlideShow(nPOIFSFileSystem);
            } finally {
                if (z) {
                    Biff8EncryptionKey.setCurrentUserPassword(r2);
                }
            }
        }
    }

    public static SlideShow<?, ?> create(InputStream inputStream) {
        return create(inputStream, (String) null);
    }

    public static SlideShow<?, ?> create(InputStream inputStream, String str) {
        InputStream prepareToCheckMagic = FileMagic.prepareToCheckMagic(inputStream);
        int ordinal = FileMagic.valueOf(prepareToCheckMagic).ordinal();
        if (ordinal == 0) {
            return create(new NPOIFSFileSystem(prepareToCheckMagic), str);
        }
        if (ordinal == 1) {
            return createXSLFSlideShow(prepareToCheckMagic);
        }
        throw new IllegalArgumentException("Your InputStream was neither an OLE2 stream, nor an OOXML stream");
    }

    public static SlideShow<?, ?> create(File file) {
        return create(file, (String) null);
    }

    public static SlideShow<?, ?> create(File file, String str) {
        return create(file, str, false);
    }

    public static SlideShow<?, ?> create(File file, String str, boolean z) {
        RuntimeException e2;
        if (file.exists()) {
            NPOIFSFileSystem nPOIFSFileSystem = null;
            try {
                NPOIFSFileSystem nPOIFSFileSystem2 = new NPOIFSFileSystem(file, z);
                try {
                    return create(nPOIFSFileSystem2, str);
                } catch (OfficeXmlFileException unused) {
                    nPOIFSFileSystem = nPOIFSFileSystem2;
                    IOUtils.closeQuietly(nPOIFSFileSystem);
                    return createXSLFSlideShow(file, Boolean.valueOf(z));
                } catch (RuntimeException e3) {
                    e2 = e3;
                    nPOIFSFileSystem = nPOIFSFileSystem2;
                    IOUtils.closeQuietly(nPOIFSFileSystem);
                    throw e2;
                }
            } catch (OfficeXmlFileException unused2) {
                IOUtils.closeQuietly(nPOIFSFileSystem);
                return createXSLFSlideShow(file, Boolean.valueOf(z));
            } catch (RuntimeException e4) {
                e2 = e4;
                IOUtils.closeQuietly(nPOIFSFileSystem);
                throw e2;
            }
        } else {
            throw new FileNotFoundException(file.toString());
        }
    }
}
