package org.apache.poi.ss.format;

import b.b.a.a.a;
import java.awt.Color;
import java.util.ArrayList;
import java.util.Date;
import java.util.Locale;
import java.util.Map;
import java.util.WeakHashMap;
import java.util.logging.Level;
import java.util.logging.Logger;
import java.util.regex.Matcher;
import java.util.regex.Pattern;
import javax.swing.JLabel;
import org.apache.poi.ss.formula.functions.NumericFunction;
import org.apache.poi.ss.usermodel.Cell;
import org.apache.poi.ss.usermodel.CellType;
import org.apache.poi.ss.usermodel.DateUtil;
import org.apache.poi.util.LocaleUtil;
import org.apache.poi.util.Removal;

public class CellFormat {
    @Removal(version = "3.18")
    @Deprecated
    public static final CellFormat GENERAL_FORMAT = createGeneralFormat(LocaleUtil.getUserLocale());
    public static final String INVALID_VALUE_FOR_FORMAT = "###############################################################################################################################################################################################################################################################";
    public static final Pattern ONE_PART = Pattern.compile(CellFormatPart.FORMAT_PAT.pattern() + "(;|$)", 6);
    public static String QUOTE = "\"";
    public static final Map<Locale, Map<String, CellFormat>> formatCache = new WeakHashMap();
    public final String format;
    public final int formatPartCount;
    public final Locale locale;
    public final CellFormatPart negNumFmt;
    public final CellFormatPart posNumFmt;
    public final CellFormatPart textFmt;
    public final CellFormatPart zeroNumFmt;

    /* renamed from: org.apache.poi.ss.format.CellFormat$2  reason: invalid class name */
    public static /* synthetic */ class AnonymousClass2 {
        public static final /* synthetic */ int[] $SwitchMap$org$apache$poi$ss$usermodel$CellType;

        /* JADX WARNING: Can't wrap try/catch for region: R(8:0|(2:1|2)|3|5|6|7|8|(3:9|10|12)) */
        /* JADX WARNING: Failed to process nested try/catch */
        /* JADX WARNING: Missing exception handler attribute for start block: B:7:0x0017 */
        /* JADX WARNING: Missing exception handler attribute for start block: B:9:0x001e */
        static {
            int[] iArr = new int[CellType.values().length];
            $SwitchMap$org$apache$poi$ss$usermodel$CellType = iArr;
            try {
                CellType cellType = CellType.BLANK;
                iArr[4] = 1;
            } catch (NoSuchFieldError unused) {
            }
            int[] iArr2 = $SwitchMap$org$apache$poi$ss$usermodel$CellType;
            CellType cellType2 = CellType.BOOLEAN;
            iArr2[5] = 2;
            int[] iArr3 = $SwitchMap$org$apache$poi$ss$usermodel$CellType;
            CellType cellType3 = CellType.NUMERIC;
            iArr3[1] = 3;
            try {
                int[] iArr4 = $SwitchMap$org$apache$poi$ss$usermodel$CellType;
                CellType cellType4 = CellType.STRING;
                iArr4[2] = 4;
            } catch (NoSuchFieldError unused2) {
            }
        }
    }

    public static CellFormat createGeneralFormat(final Locale locale2) {
        return new CellFormat("General", locale2) {
            /* class org.apache.poi.ss.format.CellFormat.AnonymousClass1 */

            @Override // org.apache.poi.ss.format.CellFormat
            public CellFormatResult apply(Object obj) {
                return new CellFormatResult(true, new CellGeneralFormatter(locale2).format(obj), null);
            }
        };
    }

    private CellFormatPart getApplicableFormatPart(Object obj) {
        if (obj instanceof Number) {
            double doubleValue = ((Number) obj).doubleValue();
            int i2 = this.formatPartCount;
            if (i2 == 1) {
                if (!this.posNumFmt.hasCondition() || (this.posNumFmt.hasCondition() && this.posNumFmt.applies(Double.valueOf(doubleValue)))) {
                    return this.posNumFmt;
                }
                return new CellFormatPart(this.locale, "General");
            } else if (i2 == 2) {
                if ((!this.posNumFmt.hasCondition() && doubleValue >= NumericFunction.LOG_10_TO_BASE_e) || (this.posNumFmt.hasCondition() && this.posNumFmt.applies(Double.valueOf(doubleValue)))) {
                    return this.posNumFmt;
                }
                if (!this.negNumFmt.hasCondition() || (this.negNumFmt.hasCondition() && this.negNumFmt.applies(Double.valueOf(doubleValue)))) {
                    return this.negNumFmt;
                }
                return new CellFormatPart(QUOTE + INVALID_VALUE_FOR_FORMAT + QUOTE);
            } else if ((!this.posNumFmt.hasCondition() && doubleValue > NumericFunction.LOG_10_TO_BASE_e) || (this.posNumFmt.hasCondition() && this.posNumFmt.applies(Double.valueOf(doubleValue)))) {
                return this.posNumFmt;
            } else {
                if ((this.negNumFmt.hasCondition() || doubleValue >= NumericFunction.LOG_10_TO_BASE_e) && (!this.negNumFmt.hasCondition() || !this.negNumFmt.applies(Double.valueOf(doubleValue)))) {
                    return this.zeroNumFmt;
                }
                return this.negNumFmt;
            }
        } else {
            throw new IllegalArgumentException("value must be a Number");
        }
    }

    public static CellFormat getInstance(String str) {
        return getInstance(LocaleUtil.getUserLocale(), str);
    }

    public static int ultimateType(Cell cell) {
        return ultimateTypeEnum(cell).getCode();
    }

    public static CellType ultimateTypeEnum(Cell cell) {
        CellType cellTypeEnum = cell.getCellTypeEnum();
        return cellTypeEnum == CellType.FORMULA ? cell.getCachedFormulaResultTypeEnum() : cellTypeEnum;
    }

    public CellFormatResult apply(Object obj) {
        if (obj instanceof Number) {
            double doubleValue = ((Number) obj).doubleValue();
            if (doubleValue >= NumericFunction.LOG_10_TO_BASE_e || ((this.formatPartCount != 2 || this.posNumFmt.hasCondition() || this.negNumFmt.hasCondition()) && ((this.formatPartCount != 3 || this.negNumFmt.hasCondition()) && (this.formatPartCount != 4 || this.negNumFmt.hasCondition())))) {
                return getApplicableFormatPart(Double.valueOf(doubleValue)).apply(Double.valueOf(doubleValue));
            }
            return this.negNumFmt.apply(Double.valueOf(-doubleValue));
        } else if (!(obj instanceof Date)) {
            return this.textFmt.apply(obj);
        } else {
            Double valueOf = Double.valueOf(DateUtil.getExcelDate((Date) obj));
            if (DateUtil.isValidExcelDate(valueOf.doubleValue())) {
                return getApplicableFormatPart(valueOf).apply(obj);
            }
            throw new IllegalArgumentException("value " + valueOf + " of date " + obj + " is not a valid Excel date");
        }
    }

    public boolean equals(Object obj) {
        if (this == obj) {
            return true;
        }
        if (obj instanceof CellFormat) {
            return this.format.equals(((CellFormat) obj).format);
        }
        return false;
    }

    public int hashCode() {
        return this.format.hashCode();
    }

    public CellFormat(Locale locale2, String str) {
        this.locale = locale2;
        this.format = str;
        CellFormatPart cellFormatPart = new CellFormatPart(locale2, "@");
        Matcher matcher = ONE_PART.matcher(str);
        ArrayList arrayList = new ArrayList();
        while (matcher.find()) {
            try {
                String group = matcher.group();
                arrayList.add(new CellFormatPart(locale2, group.endsWith(";") ? group.substring(0, group.length() - 1) : group));
            } catch (RuntimeException e2) {
                Logger logger = CellFormatter.logger;
                Level level = Level.WARNING;
                StringBuilder b2 = a.b("Invalid format: ");
                b2.append(CellFormatter.quote(matcher.group()));
                logger.log(level, b2.toString(), (Throwable) e2);
                arrayList.add(null);
            }
        }
        int size = arrayList.size();
        this.formatPartCount = size;
        if (size == 1) {
            this.posNumFmt = (CellFormatPart) arrayList.get(0);
            this.negNumFmt = null;
            this.zeroNumFmt = null;
            this.textFmt = cellFormatPart;
        } else if (size == 2) {
            this.posNumFmt = (CellFormatPart) arrayList.get(0);
            this.negNumFmt = (CellFormatPart) arrayList.get(1);
            this.zeroNumFmt = null;
            this.textFmt = cellFormatPart;
        } else if (size != 3) {
            this.posNumFmt = (CellFormatPart) arrayList.get(0);
            this.negNumFmt = (CellFormatPart) arrayList.get(1);
            this.zeroNumFmt = (CellFormatPart) arrayList.get(2);
            this.textFmt = (CellFormatPart) arrayList.get(3);
        } else {
            this.posNumFmt = (CellFormatPart) arrayList.get(0);
            this.negNumFmt = (CellFormatPart) arrayList.get(1);
            this.zeroNumFmt = (CellFormatPart) arrayList.get(2);
            this.textFmt = cellFormatPart;
        }
    }

    public static synchronized CellFormat getInstance(Locale locale2, String str) {
        CellFormat cellFormat;
        synchronized (CellFormat.class) {
            Map<String, CellFormat> map = formatCache.get(locale2);
            if (map == null) {
                map = new WeakHashMap<>();
                formatCache.put(locale2, map);
            }
            cellFormat = map.get(str);
            if (cellFormat == null) {
                if (!str.equals("General")) {
                    if (!str.equals("@")) {
                        cellFormat = new CellFormat(locale2, str);
                        map.put(str, cellFormat);
                    }
                }
                cellFormat = createGeneralFormat(locale2);
                map.put(str, cellFormat);
            }
        }
        return cellFormat;
    }

    private CellFormatResult apply(Date date, double d2) {
        return getApplicableFormatPart(Double.valueOf(d2)).apply(date);
    }

    public CellFormatResult apply(Cell cell) {
        int ordinal = ultimateTypeEnum(cell).ordinal();
        if (ordinal == 1) {
            Double valueOf = Double.valueOf(cell.getNumericCellValue());
            if (getApplicableFormatPart(valueOf).getCellFormatType() != CellFormatType.DATE) {
                return apply(valueOf);
            }
            if (DateUtil.isValidExcelDate(valueOf.doubleValue())) {
                return apply(cell.getDateCellValue(), valueOf.doubleValue());
            }
            return apply(INVALID_VALUE_FOR_FORMAT);
        } else if (ordinal == 2) {
            return apply(cell.getStringCellValue());
        } else {
            if (ordinal == 4) {
                return apply("");
            }
            if (ordinal != 5) {
                return apply("?");
            }
            return apply(Boolean.valueOf(cell.getBooleanCellValue()));
        }
    }

    public CellFormatResult apply(JLabel jLabel, Object obj) {
        CellFormatResult apply = apply(obj);
        jLabel.setText(apply.text);
        Color color = apply.textColor;
        if (color != null) {
            jLabel.setForeground(color);
        }
        return apply;
    }

    private CellFormatResult apply(JLabel jLabel, Date date, double d2) {
        CellFormatResult apply = apply(date, d2);
        jLabel.setText(apply.text);
        Color color = apply.textColor;
        if (color != null) {
            jLabel.setForeground(color);
        }
        return apply;
    }

    public CellFormatResult apply(JLabel jLabel, Cell cell) {
        int ordinal = ultimateTypeEnum(cell).ordinal();
        if (ordinal == 1) {
            Double valueOf = Double.valueOf(cell.getNumericCellValue());
            if (getApplicableFormatPart(valueOf).getCellFormatType() != CellFormatType.DATE) {
                return apply(jLabel, valueOf);
            }
            if (DateUtil.isValidExcelDate(valueOf.doubleValue())) {
                return apply(jLabel, cell.getDateCellValue(), valueOf.doubleValue());
            }
            return apply(jLabel, INVALID_VALUE_FOR_FORMAT);
        } else if (ordinal == 2) {
            return apply(jLabel, cell.getStringCellValue());
        } else {
            if (ordinal == 4) {
                return apply(jLabel, "");
            }
            if (ordinal != 5) {
                return apply(jLabel, "?");
            }
            return apply(jLabel, Boolean.valueOf(cell.getBooleanCellValue()));
        }
    }
}
