package org.apache.poi.ss.format;

import java.util.LinkedList;
import java.util.List;
import java.util.ListIterator;
import java.util.regex.Matcher;
import org.apache.poi.ss.format.CellFormatPart;
import org.apache.poi.ss.format.CellNumberFormatter;
import org.apache.poi.util.Internal;
import org.apache.xmlbeans.impl.common.NameUtil;

@Internal
public class CellNumberPartHandler implements CellFormatPart.PartHandler {
    public CellNumberFormatter.Special decimalPoint;
    public CellNumberFormatter.Special exponent;
    public boolean improperFraction;
    public char insertSignForExponent;
    public CellNumberFormatter.Special numerator;
    public double scale = 1.0d;
    public CellNumberFormatter.Special slash;
    public final List<CellNumberFormatter.Special> specials = new LinkedList();

    public static CellNumberFormatter.Special firstDigit(List<CellNumberFormatter.Special> list) {
        for (CellNumberFormatter.Special special : list) {
            if (isDigitFmt(special)) {
                return special;
            }
        }
        return null;
    }

    public static boolean isDigitFmt(CellNumberFormatter.Special special) {
        char c = special.ch;
        return c == '0' || c == '?' || c == '#';
    }

    private CellNumberFormatter.Special previousNumber() {
        List<CellNumberFormatter.Special> list = this.specials;
        ListIterator<CellNumberFormatter.Special> listIterator = list.listIterator(list.size());
        while (listIterator.hasPrevious()) {
            CellNumberFormatter.Special previous = listIterator.previous();
            if (isDigitFmt(previous)) {
                while (listIterator.hasPrevious()) {
                    CellNumberFormatter.Special previous2 = listIterator.previous();
                    if (previous.pos - previous2.pos > 1 || !isDigitFmt(previous2)) {
                        break;
                    }
                    previous = previous2;
                }
                return previous;
            }
        }
        return null;
    }

    public CellNumberFormatter.Special getDecimalPoint() {
        return this.decimalPoint;
    }

    public CellNumberFormatter.Special getExponent() {
        return this.exponent;
    }

    public CellNumberFormatter.Special getNumerator() {
        return this.numerator;
    }

    public double getScale() {
        return this.scale;
    }

    public CellNumberFormatter.Special getSlash() {
        return this.slash;
    }

    public List<CellNumberFormatter.Special> getSpecials() {
        return this.specials;
    }

    /* JADX DEBUG: Multi-variable search result rejected for r7v11, resolved type: boolean */
    /* JADX WARN: Multi-variable type inference failed */
    @Override // org.apache.poi.ss.format.CellFormatPart.PartHandler
    public String handlePart(Matcher matcher, String str, CellFormatType cellFormatType, StringBuffer stringBuffer) {
        int length = stringBuffer.length();
        int i2 = 0;
        char charAt = str.charAt(0);
        if (charAt != '#') {
            if (charAt == '%') {
                this.scale *= 100.0d;
            } else if (charAt != '?') {
                if (charAt != 'E' && charAt != 'e') {
                    switch (charAt) {
                        case '.':
                            if (this.decimalPoint == null && this.specials.size() > 0) {
                                CellNumberFormatter.Special special = new CellNumberFormatter.Special(NameUtil.PERIOD, length);
                                this.decimalPoint = special;
                                this.specials.add(special);
                                break;
                            }
                        case '/':
                            if (this.slash == null && this.specials.size() > 0) {
                                CellNumberFormatter.Special previousNumber = previousNumber();
                                this.numerator = previousNumber;
                                boolean z = this.improperFraction;
                                if (previousNumber == firstDigit(this.specials)) {
                                    i2 = 1;
                                }
                                this.improperFraction = i2 | (z ? 1 : 0);
                                CellNumberFormatter.Special special2 = new CellNumberFormatter.Special(NameUtil.PERIOD, length);
                                this.slash = special2;
                                this.specials.add(special2);
                                break;
                            }
                        case '0':
                            break;
                        default:
                            return null;
                    }
                } else if (this.exponent == null && this.specials.size() > 0) {
                    CellNumberFormatter.Special special3 = new CellNumberFormatter.Special(NameUtil.PERIOD, length);
                    this.exponent = special3;
                    this.specials.add(special3);
                    this.insertSignForExponent = str.charAt(1);
                    return str.substring(0, 1);
                }
            }
            return str;
        }
        char c = this.insertSignForExponent;
        if (c != 0) {
            this.specials.add(new CellNumberFormatter.Special(c, length));
            stringBuffer.append(this.insertSignForExponent);
            this.insertSignForExponent = 0;
            length++;
        }
        while (i2 < str.length()) {
            this.specials.add(new CellNumberFormatter.Special(str.charAt(i2), length + i2));
            i2++;
        }
        return str;
    }

    public boolean isImproperFraction() {
        return this.improperFraction;
    }
}
