package org.apache.poi.ss.formula;

import java.util.ArrayList;
import java.util.Collections;
import java.util.HashMap;
import java.util.HashSet;
import java.util.LinkedHashSet;
import java.util.List;
import java.util.Map;
import java.util.Set;
import org.apache.poi.ss.formula.eval.BlankEval;
import org.apache.poi.ss.formula.eval.BoolEval;
import org.apache.poi.ss.formula.eval.ErrorEval;
import org.apache.poi.ss.formula.eval.NumberEval;
import org.apache.poi.ss.formula.eval.RefEval;
import org.apache.poi.ss.formula.eval.StringEval;
import org.apache.poi.ss.formula.eval.ValueEval;
import org.apache.poi.ss.formula.functions.AggregateFunction;
import org.apache.poi.ss.formula.functions.NumericFunction;
import org.apache.poi.ss.usermodel.Cell;
import org.apache.poi.ss.usermodel.CellType;
import org.apache.poi.ss.usermodel.ConditionFilterData;
import org.apache.poi.ss.usermodel.ConditionFilterType;
import org.apache.poi.ss.usermodel.ConditionType;
import org.apache.poi.ss.usermodel.ConditionalFormatting;
import org.apache.poi.ss.usermodel.ConditionalFormattingRule;
import org.apache.poi.ss.usermodel.ExcelNumberFormat;
import org.apache.poi.ss.usermodel.Row;
import org.apache.poi.ss.usermodel.Sheet;
import org.apache.poi.ss.util.CellRangeAddress;
import org.apache.poi.ss.util.CellReference;

public class EvaluationConditionalFormatRule implements Comparable<EvaluationConditionalFormatRule> {
    public final ConditionalFormatting formatting;
    public final int formattingIndex;
    public final String formula1;
    public final String formula2;
    public final Map<CellRangeAddress, Set<ValueAndFormat>> meaningfulRegionValues = new HashMap();
    public final ExcelNumberFormat numberFormat;
    public final OperatorEnum operator;
    public final int priority;
    public final CellRangeAddress[] regions;
    public final ConditionalFormattingRule rule;
    public final int ruleIndex;
    public final Sheet sheet;
    public final ConditionType type;
    public final WorkbookEvaluator workbookEvaluator;

    /* renamed from: org.apache.poi.ss.formula.EvaluationConditionalFormatRule$5  reason: invalid class name */
    public static /* synthetic */ class AnonymousClass5 {
        public static final /* synthetic */ int[] $SwitchMap$org$apache$poi$ss$usermodel$ConditionFilterType;

        /* JADX WARNING: Can't wrap try/catch for region: R(39:0|1|2|3|5|6|7|9|10|11|13|14|15|(2:17|18)|19|21|22|23|25|26|27|29|30|31|(2:33|34)|35|37|38|39|41|42|43|45|46|47|48|49|50|52) */
        /* JADX WARNING: Can't wrap try/catch for region: R(41:0|1|2|3|5|6|7|9|10|11|13|14|15|17|18|19|21|22|23|25|26|27|29|30|31|33|34|35|37|38|39|41|42|43|45|46|47|48|49|50|52) */
        /* JADX WARNING: Code restructure failed: missing block: B:53:?, code lost:
            return;
         */
        /* JADX WARNING: Failed to process nested try/catch */
        /* JADX WARNING: Missing exception handler attribute for start block: B:47:0x0063 */
        /* JADX WARNING: Missing exception handler attribute for start block: B:49:0x0069 */
        static {
            int[] iArr = new int[ConditionFilterType.values().length];
            $SwitchMap$org$apache$poi$ss$usermodel$ConditionFilterType = iArr;
            try {
                ConditionFilterType conditionFilterType = ConditionFilterType.FILTER;
                iArr[0] = 1;
            } catch (NoSuchFieldError unused) {
            }
            try {
                int[] iArr2 = $SwitchMap$org$apache$poi$ss$usermodel$ConditionFilterType;
                ConditionFilterType conditionFilterType2 = ConditionFilterType.TOP_10;
                iArr2[1] = 2;
            } catch (NoSuchFieldError unused2) {
            }
            try {
                int[] iArr3 = $SwitchMap$org$apache$poi$ss$usermodel$ConditionFilterType;
                ConditionFilterType conditionFilterType3 = ConditionFilterType.UNIQUE_VALUES;
                iArr3[2] = 3;
            } catch (NoSuchFieldError unused3) {
            }
            try {
                int[] iArr4 = $SwitchMap$org$apache$poi$ss$usermodel$ConditionFilterType;
                ConditionFilterType conditionFilterType4 = ConditionFilterType.DUPLICATE_VALUES;
                iArr4[3] = 4;
            } catch (NoSuchFieldError unused4) {
            }
            try {
                int[] iArr5 = $SwitchMap$org$apache$poi$ss$usermodel$ConditionFilterType;
                ConditionFilterType conditionFilterType5 = ConditionFilterType.ABOVE_AVERAGE;
                iArr5[13] = 5;
            } catch (NoSuchFieldError unused5) {
            }
            try {
                int[] iArr6 = $SwitchMap$org$apache$poi$ss$usermodel$ConditionFilterType;
                ConditionFilterType conditionFilterType6 = ConditionFilterType.CONTAINS_TEXT;
                iArr6[4] = 6;
            } catch (NoSuchFieldError unused6) {
            }
            try {
                int[] iArr7 = $SwitchMap$org$apache$poi$ss$usermodel$ConditionFilterType;
                ConditionFilterType conditionFilterType7 = ConditionFilterType.NOT_CONTAINS_TEXT;
                iArr7[5] = 7;
            } catch (NoSuchFieldError unused7) {
            }
            try {
                int[] iArr8 = $SwitchMap$org$apache$poi$ss$usermodel$ConditionFilterType;
                ConditionFilterType conditionFilterType8 = ConditionFilterType.BEGINS_WITH;
                iArr8[6] = 8;
            } catch (NoSuchFieldError unused8) {
            }
            try {
                int[] iArr9 = $SwitchMap$org$apache$poi$ss$usermodel$ConditionFilterType;
                ConditionFilterType conditionFilterType9 = ConditionFilterType.ENDS_WITH;
                iArr9[7] = 9;
            } catch (NoSuchFieldError unused9) {
            }
            try {
                int[] iArr10 = $SwitchMap$org$apache$poi$ss$usermodel$ConditionFilterType;
                ConditionFilterType conditionFilterType10 = ConditionFilterType.CONTAINS_BLANKS;
                iArr10[8] = 10;
            } catch (NoSuchFieldError unused10) {
            }
            try {
                int[] iArr11 = $SwitchMap$org$apache$poi$ss$usermodel$ConditionFilterType;
                ConditionFilterType conditionFilterType11 = ConditionFilterType.NOT_CONTAINS_BLANKS;
                iArr11[9] = 11;
            } catch (NoSuchFieldError unused11) {
            }
            int[] iArr12 = $SwitchMap$org$apache$poi$ss$usermodel$ConditionFilterType;
            ConditionFilterType conditionFilterType12 = ConditionFilterType.CONTAINS_ERRORS;
            iArr12[10] = 12;
            int[] iArr13 = $SwitchMap$org$apache$poi$ss$usermodel$ConditionFilterType;
            ConditionFilterType conditionFilterType13 = ConditionFilterType.NOT_CONTAINS_ERRORS;
            iArr13[11] = 13;
            int[] iArr14 = $SwitchMap$org$apache$poi$ss$usermodel$ConditionFilterType;
            ConditionFilterType conditionFilterType14 = ConditionFilterType.TIME_PERIOD;
            iArr14[12] = 14;
        }
    }

    public enum OperatorEnum {
        NO_COMPARISON {
            @Override // org.apache.poi.ss.formula.EvaluationConditionalFormatRule.OperatorEnum
            public <C extends Comparable<C>> boolean isValid(C c, C c2, C c3) {
                return false;
            }
        },
        BETWEEN {
            @Override // org.apache.poi.ss.formula.EvaluationConditionalFormatRule.OperatorEnum
            public <C extends Comparable<C>> boolean isValid(C c, C c2, C c3) {
                return c.compareTo(c2) >= 0 && c.compareTo(c3) <= 0;
            }
        },
        NOT_BETWEEN {
            @Override // org.apache.poi.ss.formula.EvaluationConditionalFormatRule.OperatorEnum
            public <C extends Comparable<C>> boolean isValid(C c, C c2, C c3) {
                return c.compareTo(c2) < 0 || c.compareTo(c3) > 0;
            }
        },
        EQUAL {
            @Override // org.apache.poi.ss.formula.EvaluationConditionalFormatRule.OperatorEnum
            public <C extends Comparable<C>> boolean isValid(C c, C c2, C c3) {
                if (c.getClass() == String.class) {
                    if (c.toString().compareToIgnoreCase(c2.toString()) == 0) {
                        return true;
                    }
                    return false;
                } else if (c.compareTo(c2) == 0) {
                    return true;
                } else {
                    return false;
                }
            }
        },
        NOT_EQUAL {
            @Override // org.apache.poi.ss.formula.EvaluationConditionalFormatRule.OperatorEnum
            public <C extends Comparable<C>> boolean isValid(C c, C c2, C c3) {
                if (c.getClass() == String.class) {
                    if (c.toString().compareToIgnoreCase(c2.toString()) == 0) {
                        return true;
                    }
                    return false;
                } else if (c.compareTo(c2) != 0) {
                    return true;
                } else {
                    return false;
                }
            }
        },
        GREATER_THAN {
            @Override // org.apache.poi.ss.formula.EvaluationConditionalFormatRule.OperatorEnum
            public <C extends Comparable<C>> boolean isValid(C c, C c2, C c3) {
                return c.compareTo(c2) > 0;
            }
        },
        LESS_THAN {
            @Override // org.apache.poi.ss.formula.EvaluationConditionalFormatRule.OperatorEnum
            public <C extends Comparable<C>> boolean isValid(C c, C c2, C c3) {
                return c.compareTo(c2) < 0;
            }
        },
        GREATER_OR_EQUAL {
            @Override // org.apache.poi.ss.formula.EvaluationConditionalFormatRule.OperatorEnum
            public <C extends Comparable<C>> boolean isValid(C c, C c2, C c3) {
                return c.compareTo(c2) >= 0;
            }
        },
        LESS_OR_EQUAL {
            @Override // org.apache.poi.ss.formula.EvaluationConditionalFormatRule.OperatorEnum
            public <C extends Comparable<C>> boolean isValid(C c, C c2, C c3) {
                return c.compareTo(c2) <= 0;
            }
        };

        public abstract <C extends Comparable<C>> boolean isValid(C c, C c2, C c3);
    }

    public static class ValueAndFormat implements Comparable<ValueAndFormat> {
        public final String format;
        public final String string;
        public final Double value;

        public ValueAndFormat(Double d2, String str) {
            this.value = d2;
            this.format = str;
            this.string = null;
        }

        public boolean equals(Object obj) {
            if (!(obj instanceof ValueAndFormat)) {
                return false;
            }
            ValueAndFormat valueAndFormat = (ValueAndFormat) obj;
            Double d2 = this.value;
            Double d3 = valueAndFormat.value;
            if (d2 != d3 && !d2.equals(d3)) {
                return false;
            }
            String str = this.format;
            String str2 = valueAndFormat.format;
            if (str != str2 && !str.equals(str2)) {
                return false;
            }
            String str3 = this.string;
            String str4 = valueAndFormat.string;
            if (str3 == str4 || str3.equals(str4)) {
                return true;
            }
            return false;
        }

        public String getString() {
            return this.string;
        }

        public Double getValue() {
            return this.value;
        }

        public int hashCode() {
            String str = this.string;
            int i2 = 0;
            int hashCode = (str == null ? 0 : str.hashCode()) * 37 * 37;
            Double d2 = this.value;
            int hashCode2 = ((d2 == null ? 0 : d2.hashCode()) * 37) + hashCode;
            String str2 = this.format;
            if (str2 != null) {
                i2 = str2.hashCode();
            }
            return hashCode2 + i2;
        }

        public boolean isNumber() {
            return this.value != null;
        }

        public int compareTo(ValueAndFormat valueAndFormat) {
            if (this.value == null && valueAndFormat.value != null) {
                return 1;
            }
            if (valueAndFormat.value == null && this.value != null) {
                return -1;
            }
            Double d2 = this.value;
            int compareTo = d2 == null ? 0 : d2.compareTo(valueAndFormat.value);
            if (compareTo != 0) {
                return compareTo;
            }
            if (this.string == null && valueAndFormat.string != null) {
                return 1;
            }
            if (valueAndFormat.string == null && this.string != null) {
                return -1;
            }
            String str = this.string;
            if (str == null) {
                return 0;
            }
            return str.compareTo(valueAndFormat.string);
        }

        public ValueAndFormat(String str, String str2) {
            this.value = null;
            this.format = str2;
            this.string = str;
        }
    }

    public interface ValueFunction {
        Set<ValueAndFormat> evaluate(List<ValueAndFormat> list);
    }

    public EvaluationConditionalFormatRule(WorkbookEvaluator workbookEvaluator2, Sheet sheet2, ConditionalFormatting conditionalFormatting, int i2, ConditionalFormattingRule conditionalFormattingRule, int i3, CellRangeAddress[] cellRangeAddressArr) {
        this.workbookEvaluator = workbookEvaluator2;
        this.sheet = sheet2;
        this.formatting = conditionalFormatting;
        this.rule = conditionalFormattingRule;
        this.formattingIndex = i2;
        this.ruleIndex = i3;
        this.priority = conditionalFormattingRule.getPriority();
        this.regions = cellRangeAddressArr;
        this.formula1 = conditionalFormattingRule.getFormula1();
        this.formula2 = conditionalFormattingRule.getFormula2();
        this.numberFormat = conditionalFormattingRule.getNumberFormat();
        this.operator = OperatorEnum.values()[conditionalFormattingRule.getComparisonOperation()];
        this.type = conditionalFormattingRule.getConditionType();
    }

    private boolean checkFilter(Cell cell, CellReference cellReference, CellRangeAddress cellRangeAddress) {
        OperatorEnum operatorEnum;
        ConditionFilterType conditionFilterType = this.rule.getConditionFilterType();
        if (conditionFilterType == null) {
            return false;
        }
        ValueAndFormat cellValue = getCellValue(cell);
        switch (conditionFilterType.ordinal()) {
            case 1:
                if (!cellValue.isNumber()) {
                    return false;
                }
                return getMeaningfulValues(cellRangeAddress, false, new ValueFunction() {
                    /* class org.apache.poi.ss.formula.EvaluationConditionalFormatRule.AnonymousClass1 */

                    @Override // org.apache.poi.ss.formula.EvaluationConditionalFormatRule.ValueFunction
                    public Set<ValueAndFormat> evaluate(List<ValueAndFormat> list) {
                        ConditionFilterData filterConfiguration = EvaluationConditionalFormatRule.this.rule.getFilterConfiguration();
                        if (!filterConfiguration.getBottom()) {
                            Collections.sort(list, Collections.reverseOrder());
                        } else {
                            Collections.sort(list);
                        }
                        int rank = (int) filterConfiguration.getRank();
                        if (filterConfiguration.getPercent()) {
                            rank = (list.size() * rank) / 100;
                        }
                        if (list.size() <= rank) {
                            return new HashSet(list);
                        }
                        return new HashSet(list.subList(0, rank));
                    }
                }).contains(cellValue);
            case 2:
                return getMeaningfulValues(cellRangeAddress, true, new ValueFunction() {
                    /* class org.apache.poi.ss.formula.EvaluationConditionalFormatRule.AnonymousClass2 */

                    @Override // org.apache.poi.ss.formula.EvaluationConditionalFormatRule.ValueFunction
                    public Set<ValueAndFormat> evaluate(List<ValueAndFormat> list) {
                        Collections.sort(list);
                        HashSet hashSet = new HashSet();
                        int i2 = 0;
                        while (i2 < list.size()) {
                            ValueAndFormat valueAndFormat = list.get(i2);
                            if ((i2 >= list.size() - 1 || !valueAndFormat.equals(list.get(i2 + 1))) && (i2 <= 0 || i2 != list.size() - 1 || !valueAndFormat.equals(list.get(i2 - 1)))) {
                                hashSet.add(valueAndFormat);
                            } else {
                                i2++;
                            }
                            i2++;
                        }
                        return hashSet;
                    }
                }).contains(cellValue);
            case 3:
                return getMeaningfulValues(cellRangeAddress, true, new ValueFunction() {
                    /* class org.apache.poi.ss.formula.EvaluationConditionalFormatRule.AnonymousClass3 */

                    @Override // org.apache.poi.ss.formula.EvaluationConditionalFormatRule.ValueFunction
                    public Set<ValueAndFormat> evaluate(List<ValueAndFormat> list) {
                        Collections.sort(list);
                        HashSet hashSet = new HashSet();
                        int i2 = 0;
                        while (i2 < list.size()) {
                            ValueAndFormat valueAndFormat = list.get(i2);
                            if ((i2 < list.size() - 1 && valueAndFormat.equals(list.get(i2 + 1))) || (i2 > 0 && i2 == list.size() - 1 && valueAndFormat.equals(list.get(i2 - 1)))) {
                                hashSet.add(valueAndFormat);
                                i2++;
                            }
                            i2++;
                        }
                        return hashSet;
                    }
                }).contains(cellValue);
            case 4:
                return checkFormula(cellReference, cellRangeAddress);
            case 5:
                return checkFormula(cellReference, cellRangeAddress);
            case 6:
                return checkFormula(cellReference, cellRangeAddress);
            case 7:
                return checkFormula(cellReference, cellRangeAddress);
            case 8:
                try {
                    String string = cellValue.getString();
                    if (string == null || string.trim().length() == 0) {
                        return true;
                    }
                    return false;
                } catch (Exception unused) {
                    return false;
                }
            case 9:
                try {
                    String string2 = cellValue.getString();
                    if (string2 == null || string2.trim().length() <= 0) {
                        return false;
                    }
                    return true;
                } catch (Exception unused2) {
                    return true;
                }
            case 10:
                if (cell == null || !DataValidationEvaluator.isType(cell, CellType.ERROR)) {
                    return false;
                }
                return true;
            case 11:
                if (cell == null || !DataValidationEvaluator.isType(cell, CellType.ERROR)) {
                    return true;
                }
                return false;
            case 12:
                return checkFormula(cellReference, cellRangeAddress);
            case 13:
                ConditionFilterData filterConfiguration = this.rule.getFilterConfiguration();
                ArrayList arrayList = new ArrayList(getMeaningfulValues(cellRangeAddress, false, new ValueFunction() {
                    /* class org.apache.poi.ss.formula.EvaluationConditionalFormatRule.AnonymousClass4 */

                    @Override // org.apache.poi.ss.formula.EvaluationConditionalFormatRule.ValueFunction
                    public Set<ValueAndFormat> evaluate(List<ValueAndFormat> list) {
                        ValueEval[] valueEvalArr = new ValueEval[list.size()];
                        double d2 = NumericFunction.LOG_10_TO_BASE_e;
                        double d3 = 0.0d;
                        for (int i2 = 0; i2 < list.size(); i2++) {
                            ValueAndFormat valueAndFormat = list.get(i2);
                            d3 += valueAndFormat.value.doubleValue();
                            valueEvalArr[i2] = new NumberEval(valueAndFormat.value.doubleValue());
                        }
                        LinkedHashSet linkedHashSet = new LinkedHashSet(1);
                        linkedHashSet.add(new ValueAndFormat(new Double(list.size() == 0 ? 0.0d : d3 / ((double) list.size())), (String) null));
                        if (list.size() > 1) {
                            d2 = ((NumberEval) AggregateFunction.STDEV.evaluate(valueEvalArr, 0, 0)).getNumberValue();
                        }
                        linkedHashSet.add(new ValueAndFormat(new Double(d2), (String) null));
                        return linkedHashSet;
                    }
                }));
                Double value = cellValue.isNumber() ? cellValue.getValue() : null;
                if (value == null) {
                    return false;
                }
                double doubleValue = ((ValueAndFormat) arrayList.get(0)).value.doubleValue();
                double doubleValue2 = ((ValueAndFormat) arrayList.get(1)).value.doubleValue();
                if (filterConfiguration.getStdDev() > 0) {
                    doubleValue += ((double) (filterConfiguration.getAboveAverage() ? 1 : -1)) * doubleValue2 * ((double) filterConfiguration.getStdDev());
                }
                Double d2 = new Double(doubleValue);
                if (filterConfiguration.getAboveAverage()) {
                    if (filterConfiguration.getEqualAverage()) {
                        operatorEnum = OperatorEnum.GREATER_OR_EQUAL;
                    } else {
                        operatorEnum = OperatorEnum.GREATER_THAN;
                    }
                } else if (filterConfiguration.getEqualAverage()) {
                    operatorEnum = OperatorEnum.LESS_OR_EQUAL;
                } else {
                    operatorEnum = OperatorEnum.LESS_THAN;
                }
                if (operatorEnum == null || !operatorEnum.isValid(value, d2, null)) {
                    return false;
                }
                return true;
            default:
                return false;
        }
    }

    private boolean checkFormula(CellReference cellReference, CellRangeAddress cellRangeAddress) {
        ValueEval unwrapEval = unwrapEval(this.workbookEvaluator.evaluate(this.rule.getFormula1(), cellReference, cellRangeAddress));
        if (unwrapEval instanceof BlankEval) {
            return true;
        }
        if (unwrapEval instanceof ErrorEval) {
            return false;
        }
        if (unwrapEval instanceof BoolEval) {
            return ((BoolEval) unwrapEval).getBooleanValue();
        }
        if (!(unwrapEval instanceof NumberEval) || ((NumberEval) unwrapEval).getNumberValue() == NumericFunction.LOG_10_TO_BASE_e) {
            return false;
        }
        return true;
    }

    private boolean checkValue(Cell cell, CellRangeAddress cellRangeAddress) {
        if (cell != null && !DataValidationEvaluator.isType(cell, CellType.BLANK) && !DataValidationEvaluator.isType(cell, CellType.ERROR) && (!DataValidationEvaluator.isType(cell, CellType.STRING) || (cell.getStringCellValue() != null && !cell.getStringCellValue().isEmpty()))) {
            ValueEval unwrapEval = unwrapEval(this.workbookEvaluator.evaluate(this.rule.getFormula1(), ConditionalFormattingEvaluator.getRef(cell), cellRangeAddress));
            String formula22 = this.rule.getFormula2();
            Object obj = null;
            ValueEval unwrapEval2 = (formula22 == null || formula22.length() <= 0) ? null : unwrapEval(this.workbookEvaluator.evaluate(formula22, ConditionalFormattingEvaluator.getRef(cell), cellRangeAddress));
            if (DataValidationEvaluator.isType(cell, CellType.BOOLEAN)) {
                if (!(unwrapEval instanceof BoolEval) || (unwrapEval2 != null && !(unwrapEval2 instanceof BoolEval))) {
                    return false;
                }
                OperatorEnum operatorEnum = this.operator;
                Boolean valueOf = Boolean.valueOf(cell.getBooleanCellValue());
                Boolean valueOf2 = Boolean.valueOf(((BoolEval) unwrapEval).getBooleanValue());
                if (unwrapEval2 != null) {
                    obj = Boolean.valueOf(((BoolEval) unwrapEval2).getBooleanValue());
                }
                return operatorEnum.isValid(valueOf, valueOf2, obj);
            } else if (DataValidationEvaluator.isType(cell, CellType.NUMERIC)) {
                if (!(unwrapEval instanceof NumberEval) || (unwrapEval2 != null && !(unwrapEval2 instanceof NumberEval))) {
                    return false;
                }
                OperatorEnum operatorEnum2 = this.operator;
                Double valueOf3 = Double.valueOf(cell.getNumericCellValue());
                Double valueOf4 = Double.valueOf(((NumberEval) unwrapEval).getNumberValue());
                if (unwrapEval2 != null) {
                    obj = Double.valueOf(((NumberEval) unwrapEval2).getNumberValue());
                }
                return operatorEnum2.isValid(valueOf3, valueOf4, obj);
            } else if (DataValidationEvaluator.isType(cell, CellType.STRING) && (unwrapEval instanceof StringEval) && (unwrapEval2 == null || (unwrapEval2 instanceof StringEval))) {
                OperatorEnum operatorEnum3 = this.operator;
                String stringCellValue = cell.getStringCellValue();
                String stringValue = ((StringEval) unwrapEval).getStringValue();
                if (unwrapEval2 != null) {
                    obj = ((StringEval) unwrapEval2).getStringValue();
                }
                return operatorEnum3.isValid(stringCellValue, stringValue, obj);
            }
        }
        return false;
    }

    private ValueAndFormat getCellValue(Cell cell) {
        if (cell != null) {
            CellType cellTypeEnum = cell.getCellTypeEnum();
            if (cellTypeEnum == CellType.NUMERIC || (cellTypeEnum == CellType.FORMULA && cell.getCachedFormulaResultTypeEnum() == CellType.NUMERIC)) {
                return new ValueAndFormat(new Double(cell.getNumericCellValue()), cell.getCellStyle().getDataFormatString());
            }
            if (cellTypeEnum == CellType.STRING || (cellTypeEnum == CellType.FORMULA && cell.getCachedFormulaResultTypeEnum() == CellType.STRING)) {
                return new ValueAndFormat(cell.getStringCellValue(), cell.getCellStyle().getDataFormatString());
            }
            if (cellTypeEnum == CellType.BOOLEAN || (cellTypeEnum == CellType.FORMULA && cell.getCachedFormulaResultTypeEnum() == CellType.BOOLEAN)) {
                return new ValueAndFormat(cell.getStringCellValue(), cell.getCellStyle().getDataFormatString());
            }
        }
        return new ValueAndFormat("", "");
    }

    private Set<ValueAndFormat> getMeaningfulValues(CellRangeAddress cellRangeAddress, boolean z, ValueFunction valueFunction) {
        Set<ValueAndFormat> set = this.meaningfulRegionValues.get(cellRangeAddress);
        if (set != null) {
            return set;
        }
        ArrayList arrayList = new ArrayList(((cellRangeAddress.getLastRow() - cellRangeAddress.getFirstRow()) + 1) * ((cellRangeAddress.getLastColumn() - cellRangeAddress.getFirstColumn()) + 1));
        for (int firstRow = cellRangeAddress.getFirstRow(); firstRow <= cellRangeAddress.getLastRow(); firstRow++) {
            Row row = this.sheet.getRow(firstRow);
            if (row != null) {
                for (int firstColumn = cellRangeAddress.getFirstColumn(); firstColumn <= cellRangeAddress.getLastColumn(); firstColumn++) {
                    ValueAndFormat cellValue = getCellValue(row.getCell(firstColumn));
                    if (cellValue != null && (z || cellValue.isNumber())) {
                        arrayList.add(cellValue);
                    }
                }
            }
        }
        Set<ValueAndFormat> evaluate = valueFunction.evaluate(arrayList);
        this.meaningfulRegionValues.put(cellRangeAddress, evaluate);
        return evaluate;
    }

    private ValueEval unwrapEval(ValueEval valueEval) {
        while (valueEval instanceof RefEval) {
            RefEval refEval = (RefEval) valueEval;
            valueEval = refEval.getInnerValueEval(refEval.getFirstSheetIndex());
        }
        return valueEval;
    }

    public boolean equals(Object obj) {
        if (obj == null || !obj.getClass().equals(EvaluationConditionalFormatRule.class)) {
            return false;
        }
        EvaluationConditionalFormatRule evaluationConditionalFormatRule = (EvaluationConditionalFormatRule) obj;
        if (getSheet().getSheetName().equalsIgnoreCase(evaluationConditionalFormatRule.getSheet().getSheetName()) && getFormattingIndex() == evaluationConditionalFormatRule.getFormattingIndex() && getRuleIndex() == evaluationConditionalFormatRule.getRuleIndex()) {
            return true;
        }
        return false;
    }

    public ConditionalFormatting getFormatting() {
        return this.formatting;
    }

    public int getFormattingIndex() {
        return this.formattingIndex;
    }

    public String getFormula1() {
        return this.formula1;
    }

    public String getFormula2() {
        return this.formula2;
    }

    public ExcelNumberFormat getNumberFormat() {
        return this.numberFormat;
    }

    public OperatorEnum getOperator() {
        return this.operator;
    }

    public int getPriority() {
        return this.priority;
    }

    public CellRangeAddress[] getRegions() {
        return this.regions;
    }

    public ConditionalFormattingRule getRule() {
        return this.rule;
    }

    public int getRuleIndex() {
        return this.ruleIndex;
    }

    public Sheet getSheet() {
        return this.sheet;
    }

    public ConditionType getType() {
        return this.type;
    }

    public int hashCode() {
        return (((this.sheet.getSheetName().hashCode() * 31) + this.formattingIndex) * 31) + this.ruleIndex;
    }

    public boolean matches(CellReference cellReference) {
        Cell cell;
        CellRangeAddress cellRangeAddress;
        CellRangeAddress[] cellRangeAddressArr = this.regions;
        int length = cellRangeAddressArr.length;
        int i2 = 0;
        while (true) {
            cell = null;
            if (i2 >= length) {
                cellRangeAddress = null;
                break;
            }
            cellRangeAddress = cellRangeAddressArr[i2];
            if (cellRangeAddress.isInRange(cellReference)) {
                break;
            }
            i2++;
        }
        if (cellRangeAddress == null) {
            return false;
        }
        ConditionType conditionType = getRule().getConditionType();
        if (conditionType.equals(ConditionType.COLOR_SCALE) || conditionType.equals(ConditionType.DATA_BAR) || conditionType.equals(ConditionType.ICON_SET)) {
            return true;
        }
        Row row = this.sheet.getRow(cellReference.getRow());
        if (row != null) {
            cell = row.getCell(cellReference.getCol());
        }
        if (conditionType.equals(ConditionType.CELL_VALUE_IS)) {
            if (cell == null) {
                return false;
            }
            return checkValue(cell, cellRangeAddress);
        } else if (conditionType.equals(ConditionType.FORMULA)) {
            return checkFormula(cellReference, cellRangeAddress);
        } else {
            if (conditionType.equals(ConditionType.FILTER)) {
                return checkFilter(cell, cellReference, cellRangeAddress);
            }
            return false;
        }
    }

    public int compareTo(EvaluationConditionalFormatRule evaluationConditionalFormatRule) {
        int compareToIgnoreCase = getSheet().getSheetName().compareToIgnoreCase(evaluationConditionalFormatRule.getSheet().getSheetName());
        if (compareToIgnoreCase != 0) {
            return compareToIgnoreCase;
        }
        int priority2 = getPriority();
        int priority3 = evaluationConditionalFormatRule.getPriority();
        int i2 = priority2 < priority3 ? -1 : priority2 == priority3 ? 0 : 1;
        if (i2 != 0) {
            return i2;
        }
        int compareTo = new Integer(getFormattingIndex()).compareTo(new Integer(evaluationConditionalFormatRule.getFormattingIndex()));
        if (compareTo != 0) {
            return compareTo;
        }
        return new Integer(getRuleIndex()).compareTo(new Integer(evaluationConditionalFormatRule.getRuleIndex()));
    }
}
