package org.apache.poi.ss.formula;

import b.b.a.a.a;
import java.util.ArrayList;
import java.util.Locale;
import java.util.regex.Pattern;
import org.apache.poi.ss.SpreadsheetVersion;
import org.apache.poi.ss.formula.constant.ErrorConstant;
import org.apache.poi.ss.formula.function.FunctionMetadata;
import org.apache.poi.ss.formula.function.FunctionMetadataRegistry;
import org.apache.poi.ss.formula.ptg.AbstractFunctionPtg;
import org.apache.poi.ss.formula.ptg.AddPtg;
import org.apache.poi.ss.formula.ptg.Area3DPxg;
import org.apache.poi.ss.formula.ptg.AreaPtg;
import org.apache.poi.ss.formula.ptg.ArrayPtg;
import org.apache.poi.ss.formula.ptg.AttrPtg;
import org.apache.poi.ss.formula.ptg.BoolPtg;
import org.apache.poi.ss.formula.ptg.ConcatPtg;
import org.apache.poi.ss.formula.ptg.DividePtg;
import org.apache.poi.ss.formula.ptg.EqualPtg;
import org.apache.poi.ss.formula.ptg.ErrPtg;
import org.apache.poi.ss.formula.ptg.FuncPtg;
import org.apache.poi.ss.formula.ptg.FuncVarPtg;
import org.apache.poi.ss.formula.ptg.GreaterEqualPtg;
import org.apache.poi.ss.formula.ptg.GreaterThanPtg;
import org.apache.poi.ss.formula.ptg.IntPtg;
import org.apache.poi.ss.formula.ptg.IntersectionPtg;
import org.apache.poi.ss.formula.ptg.LessEqualPtg;
import org.apache.poi.ss.formula.ptg.LessThanPtg;
import org.apache.poi.ss.formula.ptg.MemAreaPtg;
import org.apache.poi.ss.formula.ptg.MemFuncPtg;
import org.apache.poi.ss.formula.ptg.MultiplyPtg;
import org.apache.poi.ss.formula.ptg.NamePtg;
import org.apache.poi.ss.formula.ptg.NameXPtg;
import org.apache.poi.ss.formula.ptg.NameXPxg;
import org.apache.poi.ss.formula.ptg.NotEqualPtg;
import org.apache.poi.ss.formula.ptg.NumberPtg;
import org.apache.poi.ss.formula.ptg.OperandPtg;
import org.apache.poi.ss.formula.ptg.OperationPtg;
import org.apache.poi.ss.formula.ptg.ParenthesisPtg;
import org.apache.poi.ss.formula.ptg.PercentPtg;
import org.apache.poi.ss.formula.ptg.PowerPtg;
import org.apache.poi.ss.formula.ptg.Ptg;
import org.apache.poi.ss.formula.ptg.RangePtg;
import org.apache.poi.ss.formula.ptg.RefPtg;
import org.apache.poi.ss.formula.ptg.StringPtg;
import org.apache.poi.ss.formula.ptg.SubtractPtg;
import org.apache.poi.ss.formula.ptg.UnaryMinusPtg;
import org.apache.poi.ss.formula.ptg.UnaryPlusPtg;
import org.apache.poi.ss.formula.ptg.UnionPtg;
import org.apache.poi.ss.formula.ptg.ValueOperatorPtg;
import org.apache.poi.ss.usermodel.FormulaError;
import org.apache.poi.ss.usermodel.Name;
import org.apache.poi.ss.usermodel.Table;
import org.apache.poi.ss.util.AreaReference;
import org.apache.poi.ss.util.CellReference;
import org.apache.poi.util.Internal;
import org.apache.poi.util.POILogFactory;
import org.apache.poi.util.POILogger;
import org.apache.poi.xssf.usermodel.XSSFCell;
import org.apache.xmlbeans.impl.common.NameUtil;

@Internal
public final class FormulaParser {
    public static final Pattern CELL_REF_PATTERN = Pattern.compile("(\\$?[A-Za-z]+)?(\\$?[0-9]+)?");
    public static final char CR = '\r';
    public static final char LF = '\n';
    public static final char TAB = '\t';
    public static final POILogger log = POILogFactory.getLogger(FormulaParser.class);
    public static final String specAll = "All";
    public static final String specData = "Data";
    public static final String specHeaders = "Headers";
    public static final String specThisRow = "This Row";
    public static final String specTotals = "Totals";
    public final FormulaParsingWorkbook _book;
    public final int _formulaLength;
    public final String _formulaString;
    public boolean _inIntersection;
    public int _pointer = 0;
    public ParseNode _rootNode;
    public final int _rowIndex;
    public final int _sheetIndex;
    public final SpreadsheetVersion _ssVersion;
    public int look;

    /* renamed from: org.apache.poi.ss.formula.FormulaParser$1  reason: invalid class name */
    public static /* synthetic */ class AnonymousClass1 {
        public static final /* synthetic */ int[] $SwitchMap$org$apache$poi$ss$SpreadsheetVersion;

        /* JADX WARNING: Failed to process nested try/catch */
        /* JADX WARNING: Missing exception handler attribute for start block: B:3:0x000f */
        static {
            int[] iArr = new int[SpreadsheetVersion.values().length];
            $SwitchMap$org$apache$poi$ss$SpreadsheetVersion = iArr;
            SpreadsheetVersion spreadsheetVersion = SpreadsheetVersion.EXCEL97;
            iArr[0] = 1;
            try {
                int[] iArr2 = $SwitchMap$org$apache$poi$ss$SpreadsheetVersion;
                SpreadsheetVersion spreadsheetVersion2 = SpreadsheetVersion.EXCEL2007;
                iArr2[1] = 2;
            } catch (NoSuchFieldError unused) {
            }
        }
    }

    public static final class SimpleRangePart {
        public final String _rep;
        public final Type _type;

        public enum Type {
            CELL,
            ROW,
            COLUMN;

            public static Type get(boolean z, boolean z2) {
                if (z) {
                    return z2 ? CELL : COLUMN;
                }
                if (z2) {
                    return ROW;
                }
                throw new IllegalArgumentException("must have either letters or numbers");
            }
        }

        public SimpleRangePart(String str, boolean z, boolean z2) {
            this._rep = str;
            this._type = Type.get(z, z2);
        }

        public CellReference getCellReference() {
            if (this._type == Type.CELL) {
                return new CellReference(this._rep);
            }
            throw new IllegalStateException("Not applicable to this type");
        }

        public String getRep() {
            return this._rep;
        }

        public boolean isCell() {
            return this._type == Type.CELL;
        }

        public boolean isColumn() {
            return this._type == Type.COLUMN;
        }

        public boolean isCompatibleForArea(SimpleRangePart simpleRangePart) {
            return this._type == simpleRangePart._type;
        }

        public boolean isRow() {
            return this._type == Type.ROW;
        }

        public boolean isRowOrColumn() {
            return this._type != Type.CELL;
        }

        public String toString() {
            StringBuilder sb = new StringBuilder();
            sb.append(SimpleRangePart.class.getName());
            sb.append(" [");
            return a.a(sb, this._rep, "]");
        }
    }

    public FormulaParser(String str, FormulaParsingWorkbook formulaParsingWorkbook, int i2, int i3) {
        this._formulaString = str;
        this._book = formulaParsingWorkbook;
        this._ssVersion = formulaParsingWorkbook == null ? SpreadsheetVersion.EXCEL97 : formulaParsingWorkbook.getSpreadsheetVersion();
        this._formulaLength = this._formulaString.length();
        this._sheetIndex = i2;
        this._rowIndex = i3;
    }

    /* JADX WARNING: Code restructure failed: missing block: B:11:0x002d, code lost:
        if (r5.look != 41) goto L_0x0039;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:12:0x002f, code lost:
        r1 = new org.apache.poi.ss.formula.ParseNode[r0.size()];
        r0.toArray(r1);
     */
    /* JADX WARNING: Code restructure failed: missing block: B:13:0x0038, code lost:
        return r1;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:8:0x001f, code lost:
        if (r3 == false) goto L_0x002b;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:9:0x0021, code lost:
        r0.add(new org.apache.poi.ss.formula.ParseNode(org.apache.poi.ss.formula.ptg.MissingArgPtg.instance));
     */
    private ParseNode[] Arguments() {
        ArrayList arrayList = new ArrayList(2);
        SkipWhite();
        if (this.look == 41) {
            return ParseNode.EMPTY_ARRAY;
        }
        while (true) {
            boolean z = true;
            while (true) {
                SkipWhite();
                if (isArgumentDelimiter(this.look)) {
                    break;
                }
                arrayList.add(comparisonExpression());
                z = false;
                SkipWhite();
                if (!isArgumentDelimiter(this.look)) {
                    throw expected("',' or ')'");
                }
            }
            Match(44);
        }
    }

    private void GetChar() {
        if (!IsWhite(this.look)) {
            this._inIntersection = false;
        } else if (this.look == 32) {
            this._inIntersection = true;
        }
        int i2 = this._pointer;
        int i3 = this._formulaLength;
        if (i2 <= i3) {
            if (i2 < i3) {
                this.look = this._formulaString.codePointAt(i2);
            } else {
                this.look = 0;
                this._inIntersection = false;
            }
            this._pointer = Character.charCount(this.look) + this._pointer;
            return;
        }
        throw new RuntimeException("too far");
    }

    private String GetNum() {
        StringBuilder sb = new StringBuilder();
        while (IsDigit(this.look)) {
            sb.appendCodePoint(this.look);
            GetChar();
        }
        if (sb.length() == 0) {
            return null;
        }
        return sb.toString();
    }

    public static boolean IsAlpha(int i2) {
        return Character.isLetter(i2) || i2 == 36 || i2 == 95;
    }

    public static boolean IsDigit(int i2) {
        return Character.isDigit(i2);
    }

    public static boolean IsWhite(int i2) {
        return i2 == 32 || i2 == 9 || i2 == 13 || i2 == 10;
    }

    private void Match(int i2) {
        if (this.look == i2) {
            GetChar();
            return;
        }
        StringBuilder sb = new StringBuilder();
        sb.append("'");
        StringBuilder appendCodePoint = sb.appendCodePoint(i2);
        appendCodePoint.append("'");
        throw expected(appendCodePoint.toString());
    }

    private void SkipWhite() {
        while (IsWhite(this.look)) {
            GetChar();
        }
    }

    private ParseNode Term() {
        ValueOperatorPtg valueOperatorPtg;
        ParseNode powerFactor = powerFactor();
        while (true) {
            SkipWhite();
            int i2 = this.look;
            if (i2 == 42) {
                Match(42);
                valueOperatorPtg = MultiplyPtg.instance;
            } else if (i2 != 47) {
                return powerFactor;
            } else {
                Match(47);
                valueOperatorPtg = DividePtg.instance;
            }
            powerFactor = new ParseNode(valueOperatorPtg, powerFactor, powerFactor());
        }
    }

    private void addName(String str) {
        Name createName = this._book.createName();
        createName.setFunction(true);
        createName.setNameName(str);
        createName.setSheetIndex(this._sheetIndex);
    }

    private ParseNode additiveExpression() {
        ValueOperatorPtg valueOperatorPtg;
        ParseNode Term = Term();
        while (true) {
            SkipWhite();
            int i2 = this.look;
            if (i2 == 43) {
                Match(43);
                valueOperatorPtg = AddPtg.instance;
            } else if (i2 != 45) {
                return Term;
            } else {
                Match(45);
                valueOperatorPtg = SubtractPtg.instance;
            }
            Term = new ParseNode(valueOperatorPtg, Term, Term());
        }
    }

    public static ParseNode augmentWithMemPtg(ParseNode parseNode) {
        Ptg ptg;
        if (needsMemFunc(parseNode)) {
            ptg = new MemFuncPtg(parseNode.getEncodedSize());
        } else {
            ptg = new MemAreaPtg(parseNode.getEncodedSize());
        }
        return new ParseNode(ptg, parseNode);
    }

    private void checkRowLengths(Object[][] objArr, int i2) {
        for (int i3 = 0; i3 < objArr.length; i3++) {
            int length = objArr[i3].length;
            if (length != i2) {
                StringBuilder a = a.a("Array row ", i3, " has length ", length, " but row 0 has length ");
                a.append(i2);
                throw new FormulaParseException(a.toString());
            }
        }
    }

    public static void checkValidRangeOperand(String str, int i2, ParseNode parseNode) {
        if (!isValidRangeOperand(parseNode)) {
            throw new FormulaParseException("The " + str + " of the range operator ':' at position " + i2 + " is not a proper reference.");
        }
    }

    private ParseNode comparisonExpression() {
        ParseNode concatExpression = concatExpression();
        while (true) {
            SkipWhite();
            switch (this.look) {
                case 60:
                case 61:
                case 62:
                    concatExpression = new ParseNode(getComparisonToken(), concatExpression, concatExpression());
                default:
                    return concatExpression;
            }
        }
    }

    private ParseNode concatExpression() {
        ParseNode additiveExpression = additiveExpression();
        while (true) {
            SkipWhite();
            if (this.look != 38) {
                return additiveExpression;
            }
            Match(38);
            additiveExpression = new ParseNode(ConcatPtg.instance, additiveExpression, additiveExpression());
        }
    }

    public static Double convertArrayNumber(Ptg ptg, boolean z) {
        double d2;
        if (ptg instanceof IntPtg) {
            d2 = (double) ((IntPtg) ptg).getValue();
        } else if (ptg instanceof NumberPtg) {
            d2 = ((NumberPtg) ptg).getValue();
        } else {
            StringBuilder b2 = a.b("Unexpected ptg (");
            b2.append(ptg.getClass().getName());
            b2.append(")");
            throw new RuntimeException(b2.toString());
        }
        if (!z) {
            d2 = -d2;
        }
        return new Double(d2);
    }

    private AreaReference createAreaRef(SimpleRangePart simpleRangePart, SimpleRangePart simpleRangePart2) {
        if (!simpleRangePart.isCompatibleForArea(simpleRangePart2)) {
            StringBuilder b2 = a.b("has incompatible parts: '");
            b2.append(simpleRangePart.getRep());
            b2.append("' and '");
            b2.append(simpleRangePart2.getRep());
            b2.append("'.");
            throw new FormulaParseException(b2.toString());
        } else if (simpleRangePart.isRow()) {
            return AreaReference.getWholeRow(this._ssVersion, simpleRangePart.getRep(), simpleRangePart2.getRep());
        } else {
            if (simpleRangePart.isColumn()) {
                return AreaReference.getWholeColumn(this._ssVersion, simpleRangePart.getRep(), simpleRangePart2.getRep());
            }
            return new AreaReference(simpleRangePart.getCellReference(), simpleRangePart2.getCellReference(), this._ssVersion);
        }
    }

    private ParseNode createAreaRefParseNode(SheetIdentifier sheetIdentifier, SimpleRangePart simpleRangePart, SimpleRangePart simpleRangePart2) {
        Ptg ptg;
        if (simpleRangePart2 == null) {
            CellReference cellReference = simpleRangePart.getCellReference();
            if (sheetIdentifier == null) {
                ptg = new RefPtg(cellReference);
            } else {
                ptg = this._book.get3DReferencePtg(cellReference, sheetIdentifier);
            }
        } else {
            AreaReference createAreaRef = createAreaRef(simpleRangePart, simpleRangePart2);
            if (sheetIdentifier == null) {
                ptg = new AreaPtg(createAreaRef);
            } else {
                ptg = this._book.get3DReferencePtg(createAreaRef, sheetIdentifier);
            }
        }
        return new ParseNode(ptg);
    }

    private RuntimeException expected(String str) {
        String str2;
        if (this.look != 61 || this._formulaString.substring(0, this._pointer - 1).trim().length() >= 1) {
            StringBuilder sb = new StringBuilder("Parse error near char ");
            sb.append(this._pointer - 1);
            sb.append(" '");
            StringBuilder appendCodePoint = sb.appendCodePoint(this.look);
            appendCodePoint.append("'");
            appendCodePoint.append(" in specified formula '");
            appendCodePoint.append(this._formulaString);
            appendCodePoint.append("'. Expected ");
            appendCodePoint.append(str);
            str2 = appendCodePoint.toString();
        } else {
            str2 = a.a(a.b("The specified formula '"), this._formulaString, "' starts with an equals sign which is not allowed.");
        }
        return new FormulaParseException(str2);
    }

    private ParseNode function(String str) {
        Ptg ptg = null;
        if (!AbstractFunctionPtg.isBuiltInFunctionName(str)) {
            FormulaParsingWorkbook formulaParsingWorkbook = this._book;
            if (formulaParsingWorkbook != null) {
                EvaluationName name = formulaParsingWorkbook.getName(str, this._sheetIndex);
                if (name == null) {
                    ptg = this._book.getNameXPtg(str, null);
                    if (ptg == null) {
                        if (log.check(5)) {
                            log.log(5, a.b("FormulaParser.function: Name '", str, "' is completely unknown in the current workbook."));
                        }
                        int ordinal = this._book.getSpreadsheetVersion().ordinal();
                        if (ordinal == 0) {
                            addName(str);
                            ptg = this._book.getName(str, this._sheetIndex).createPtg();
                        } else if (ordinal == 1) {
                            ptg = new NameXPxg(str);
                        } else {
                            StringBuilder b2 = a.b("Unexpected spreadsheet version: ");
                            b2.append(this._book.getSpreadsheetVersion().name());
                            throw new IllegalStateException(b2.toString());
                        }
                    }
                } else if (name.isFunctionName()) {
                    ptg = name.createPtg();
                } else {
                    throw new FormulaParseException(a.b("Attempt to use name '", str, "' as a function, but defined name in workbook does not refer to a function"));
                }
            } else {
                throw new IllegalStateException(a.b("Need book to evaluate name '", str, "'"));
            }
        }
        Match(40);
        ParseNode[] Arguments = Arguments();
        Match(41);
        return getFunction(str, ptg, Arguments);
    }

    private String getBookName() {
        StringBuilder sb = new StringBuilder();
        GetChar();
        while (true) {
            int i2 = this.look;
            if (i2 != 93) {
                sb.appendCodePoint(i2);
                GetChar();
            } else {
                GetChar();
                return sb.toString();
            }
        }
    }

    private Ptg getComparisonToken() {
        int i2 = this.look;
        if (i2 == 61) {
            Match(i2);
            return EqualPtg.instance;
        }
        boolean z = i2 == 62;
        Match(this.look);
        if (!z) {
            int i3 = this.look;
            if (i3 == 61) {
                Match(61);
                return LessEqualPtg.instance;
            } else if (i3 != 62) {
                return LessThanPtg.instance;
            } else {
                Match(62);
                return NotEqualPtg.instance;
            }
        } else if (this.look != 61) {
            return GreaterThanPtg.instance;
        } else {
            Match(61);
            return GreaterEqualPtg.instance;
        }
    }

    private ParseNode getFunction(String str, Ptg ptg, ParseNode[] parseNodeArr) {
        Ptg ptg2;
        FunctionMetadata functionByName = FunctionMetadataRegistry.getFunctionByName(str.toUpperCase(Locale.ROOT));
        int length = parseNodeArr.length;
        if (functionByName == null) {
            if (ptg != null) {
                int i2 = length + 1;
                ParseNode[] parseNodeArr2 = new ParseNode[i2];
                parseNodeArr2[0] = new ParseNode(ptg);
                System.arraycopy(parseNodeArr, 0, parseNodeArr2, 1, length);
                return new ParseNode(FuncVarPtg.create(str, i2), parseNodeArr2);
            }
            throw new IllegalStateException("NamePtg must be supplied for external functions");
        } else if (ptg == null) {
            boolean z = !functionByName.hasFixedArgsLength();
            int index = functionByName.getIndex();
            if (index == 4 && parseNodeArr.length == 1) {
                return new ParseNode(AttrPtg.getSumSingle(), parseNodeArr);
            }
            validateNumArgs(parseNodeArr.length, functionByName);
            if (z) {
                ptg2 = FuncVarPtg.create(str, length);
            } else {
                ptg2 = FuncPtg.create(index);
            }
            return new ParseNode(ptg2, parseNodeArr);
        } else {
            throw new IllegalStateException("NamePtg no applicable to internal functions");
        }
    }

    public static Ptg getNumberPtgFromString(String str, String str2, String str3) {
        StringBuilder sb = new StringBuilder();
        if (str2 == null) {
            sb.append(str);
            if (str3 != null) {
                sb.append('E');
                sb.append(str3);
            }
            String sb2 = sb.toString();
            try {
                int parseInt = Integer.parseInt(sb2);
                if (IntPtg.isInRange(parseInt)) {
                    return new IntPtg(parseInt);
                }
                return new NumberPtg(sb2);
            } catch (NumberFormatException unused) {
                return new NumberPtg(sb2);
            }
        } else {
            if (str != null) {
                sb.append(str);
            }
            sb.append(NameUtil.PERIOD);
            sb.append(str2);
            if (str3 != null) {
                sb.append('E');
                sb.append(str3);
            }
            return new NumberPtg(sb.toString());
        }
    }

    private Ptg[] getRPNPtg(FormulaType formulaType) {
        new OperandClassTransformer(formulaType).transformFormula(this._rootNode);
        return ParseNode.toTokenArray(this._rootNode);
    }

    private ParseNode intersectionExpression() {
        ParseNode comparisonExpression = comparisonExpression();
        boolean z = false;
        while (true) {
            SkipWhite();
            if (!this._inIntersection) {
                break;
            }
            try {
                z = true;
                comparisonExpression = new ParseNode(IntersectionPtg.instance, comparisonExpression, comparisonExpression());
            } catch (FormulaParseException unused) {
                resetPointer(this._pointer);
            }
        }
        return z ? augmentWithMemPtg(comparisonExpression) : comparisonExpression;
    }

    public static boolean isArgumentDelimiter(int i2) {
        return i2 == 44 || i2 == 41;
    }

    public static boolean isUnquotedSheetNameChar(int i2) {
        return Character.isLetterOrDigit(i2) || i2 > 128 || i2 == 46 || i2 == 95;
    }

    private boolean isValidCellReference(String str) {
        boolean z = true;
        boolean z2 = CellReference.classifyCellReference(str, this._ssVersion) == CellReference.NameType.CELL;
        if (!z2) {
            return z2;
        }
        if (!(FunctionMetadataRegistry.getFunctionByName(str.toUpperCase(Locale.ROOT)) != null)) {
            return z2;
        }
        int i2 = this._pointer;
        resetPointer(str.length() + i2);
        SkipWhite();
        if (this.look == 40) {
            z = false;
        }
        resetPointer(i2);
        return z;
    }

    public static boolean isValidDefinedNameChar(int i2) {
        return Character.isLetterOrDigit(i2) || i2 > 128 || i2 == 46 || i2 == 63 || i2 == 92 || i2 == 95;
    }

    public static boolean isValidRangeOperand(ParseNode parseNode) {
        Ptg token = parseNode.getToken();
        if (token instanceof OperandPtg) {
            return true;
        }
        if (token instanceof AbstractFunctionPtg) {
            if (((AbstractFunctionPtg) token).getDefaultOperandClass() == 0) {
                return true;
            }
            return false;
        } else if (token instanceof ValueOperatorPtg) {
            return false;
        } else {
            if (token instanceof OperationPtg) {
                return true;
            }
            if (token instanceof ParenthesisPtg) {
                return isValidRangeOperand(parseNode.getChildren()[0]);
            }
            if (token == ErrPtg.REF_INVALID) {
                return true;
            }
            return false;
        }
    }

    public static boolean needsMemFunc(ParseNode parseNode) {
        Ptg token = parseNode.getToken();
        if ((token instanceof AbstractFunctionPtg) || (token instanceof ExternSheetReferenceToken) || (token instanceof NamePtg) || (token instanceof NameXPtg)) {
            return true;
        }
        boolean z = token instanceof OperationPtg;
        if (z || (token instanceof ParenthesisPtg)) {
            for (ParseNode parseNode2 : parseNode.getChildren()) {
                if (needsMemFunc(parseNode2)) {
                    return true;
                }
            }
            return false;
        } else if (!(token instanceof OperandPtg) && z) {
            return true;
        } else {
            return false;
        }
    }

    public static Ptg[] parse(String str, FormulaParsingWorkbook formulaParsingWorkbook, FormulaType formulaType, int i2, int i3) {
        FormulaParser formulaParser = new FormulaParser(str, formulaParsingWorkbook, i2, i3);
        formulaParser.parse();
        return formulaParser.getRPNPtg(formulaType);
    }

    private ParseNode parseArray() {
        ArrayList arrayList = new ArrayList();
        while (true) {
            arrayList.add(parseArrayRow());
            int i2 = this.look;
            if (i2 == 125) {
                Object[][] objArr = new Object[arrayList.size()][];
                arrayList.toArray(objArr);
                checkRowLengths(objArr, objArr[0].length);
                return new ParseNode(new ArrayPtg(objArr));
            } else if (i2 == 59) {
                Match(59);
            } else {
                throw expected("'}' or ';'");
            }
        }
    }

    private Object parseArrayItem() {
        SkipWhite();
        int i2 = this.look;
        if (i2 == 34) {
            return parseStringLiteral();
        }
        if (i2 == 35) {
            return ErrorConstant.valueOf(parseErrorLiteral());
        }
        if (i2 == 45) {
            Match(45);
            SkipWhite();
            return convertArrayNumber(parseNumber(), false);
        } else if (i2 == 70 || i2 == 84 || i2 == 102 || i2 == 116) {
            return parseBooleanLiteral();
        } else {
            return convertArrayNumber(parseNumber(), true);
        }
    }

    private Object[] parseArrayRow() {
        int i2;
        ArrayList arrayList = new ArrayList();
        while (true) {
            arrayList.add(parseArrayItem());
            SkipWhite();
            i2 = this.look;
            if (i2 != 44) {
                break;
            }
            Match(44);
        }
        if (i2 == 59 || i2 == 125) {
            Object[] objArr = new Object[arrayList.size()];
            arrayList.toArray(objArr);
            return objArr;
        }
        throw expected("'}' or ','");
    }

    private String parseAsColumnQuantifier() {
        if (this.look != 91) {
            return null;
        }
        GetChar();
        int i2 = this.look;
        if (i2 == 35) {
            return null;
        }
        if (i2 == 64) {
            GetChar();
        }
        StringBuilder sb = new StringBuilder();
        while (true) {
            int i3 = this.look;
            if (i3 != 93) {
                sb.appendCodePoint(i3);
                GetChar();
            } else {
                Match(93);
                return sb.toString();
            }
        }
    }

    private String parseAsName() {
        int i2;
        StringBuilder sb = new StringBuilder();
        if (Character.isLetter(this.look) || (i2 = this.look) == 95 || i2 == 92) {
            while (isValidDefinedNameChar(this.look)) {
                sb.appendCodePoint(this.look);
                GetChar();
            }
            SkipWhite();
            return sb.toString();
        }
        throw expected("number, string, defined name, or data table");
    }

    private String parseAsSpecialQuantifier() {
        if (this.look != 91) {
            return null;
        }
        GetChar();
        if (this.look != 35) {
            return null;
        }
        GetChar();
        String parseAsName = parseAsName();
        if (parseAsName.equals("This")) {
            parseAsName = parseAsName + ' ' + parseAsName();
        }
        Match(93);
        return parseAsName;
    }

    private Boolean parseBooleanLiteral() {
        String parseUnquotedIdentifier = parseUnquotedIdentifier();
        if (XSSFCell.TRUE.equalsIgnoreCase(parseUnquotedIdentifier)) {
            return Boolean.TRUE;
        }
        if (XSSFCell.FALSE.equalsIgnoreCase(parseUnquotedIdentifier)) {
            return Boolean.FALSE;
        }
        throw expected("'TRUE' or 'FALSE'");
    }

    private int parseErrorLiteral() {
        Match(35);
        String upperCase = parseUnquotedIdentifier().toUpperCase(Locale.ROOT);
        if (upperCase != null) {
            char charAt = upperCase.charAt(0);
            if (charAt == 'D') {
                FormulaError formulaError = FormulaError.DIV0;
                if (upperCase.equals("DIV")) {
                    Match(47);
                    Match(48);
                    Match(33);
                    return formulaError.getCode();
                }
                throw expected(formulaError.getString());
            } else if (charAt == 'N') {
                FormulaError formulaError2 = FormulaError.NAME;
                if (upperCase.equals("NAME")) {
                    Match(63);
                    return formulaError2.getCode();
                }
                FormulaError formulaError3 = FormulaError.NUM;
                if (upperCase.equals("NUM")) {
                    Match(33);
                    return formulaError3.getCode();
                }
                FormulaError formulaError4 = FormulaError.NULL;
                if (upperCase.equals("NULL")) {
                    Match(33);
                    return formulaError4.getCode();
                }
                FormulaError formulaError5 = FormulaError.NA;
                if (upperCase.equals("N")) {
                    Match(47);
                    int i2 = this.look;
                    if (i2 == 65 || i2 == 97) {
                        Match(this.look);
                        return formulaError5.getCode();
                    }
                    throw expected(formulaError5.getString());
                }
                throw expected("#NAME?, #NUM!, #NULL! or #N/A");
            } else if (charAt == 'R') {
                FormulaError formulaError6 = FormulaError.REF;
                if (upperCase.equals("REF")) {
                    Match(33);
                    return formulaError6.getCode();
                }
                throw expected(formulaError6.getString());
            } else if (charAt == 'V') {
                FormulaError formulaError7 = FormulaError.VALUE;
                if (upperCase.equals("VALUE")) {
                    Match(33);
                    return formulaError7.getCode();
                }
                throw expected(formulaError7.getString());
            } else {
                throw expected("#VALUE!, #REF!, #DIV/0!, #NAME?, #NUM!, #NULL! or #N/A");
            }
        } else {
            throw expected("remainder of error constant literal");
        }
    }

    private ParseNode parseNonRange(int i2) {
        resetPointer(i2);
        if (Character.isDigit(this.look)) {
            return new ParseNode(parseNumber());
        }
        if (this.look == 34) {
            return new ParseNode(new StringPtg(parseStringLiteral()));
        }
        String parseAsName = parseAsName();
        int i3 = this.look;
        if (i3 == 40) {
            return function(parseAsName);
        }
        if (i3 == 91) {
            return parseStructuredReference(parseAsName);
        }
        if (parseAsName.equalsIgnoreCase(XSSFCell.TRUE) || parseAsName.equalsIgnoreCase(XSSFCell.FALSE)) {
            return new ParseNode(BoolPtg.valueOf(parseAsName.equalsIgnoreCase(XSSFCell.TRUE)));
        }
        FormulaParsingWorkbook formulaParsingWorkbook = this._book;
        if (formulaParsingWorkbook != null) {
            EvaluationName name = formulaParsingWorkbook.getName(parseAsName, this._sheetIndex);
            if (name == null) {
                throw new FormulaParseException(a.b("Specified named range '", parseAsName, "' does not exist in the current workbook."));
            } else if (name.isRange()) {
                return new ParseNode(name.createPtg());
            } else {
                throw new FormulaParseException(a.b("Specified name '", parseAsName, "' is not a range as expected."));
            }
        } else {
            throw new IllegalStateException(a.b("Need book to evaluate name '", parseAsName, "'"));
        }
    }

    /* JADX WARNING: Removed duplicated region for block: B:15:0x003b  */
    /* JADX WARNING: Removed duplicated region for block: B:16:0x0040  */
    private Ptg parseNumber() {
        String str;
        String str2;
        String GetNum;
        String GetNum2 = GetNum();
        String str3 = null;
        if (this.look == 46) {
            GetChar();
            str = GetNum();
        } else {
            str = null;
        }
        if (this.look == 69) {
            GetChar();
            int i2 = this.look;
            if (i2 == 43) {
                GetChar();
            } else if (i2 == 45) {
                GetChar();
                str2 = UnaryMinusPtg.MINUS;
                GetNum = GetNum();
                if (GetNum == null) {
                    str3 = a.b(str2, GetNum);
                } else {
                    throw expected("Integer");
                }
            }
            str2 = "";
            GetNum = GetNum();
            if (GetNum == null) {
            }
        }
        if (GetNum2 != null || str != null) {
            return getNumberPtgFromString(GetNum2, str, str3);
        }
        throw expected("Integer");
    }

    private ParseNode parseRangeExpression() {
        ParseNode parseRangeable = parseRangeable();
        boolean z = false;
        while (this.look == 58) {
            int i2 = this._pointer;
            GetChar();
            ParseNode parseRangeable2 = parseRangeable();
            checkValidRangeOperand("LHS", i2, parseRangeable);
            checkValidRangeOperand("RHS", i2, parseRangeable2);
            parseRangeable = new ParseNode(RangePtg.instance, new ParseNode[]{parseRangeable, parseRangeable2});
            z = true;
        }
        return z ? augmentWithMemPtg(parseRangeable) : parseRangeable;
    }

    private ParseNode parseRangeable() {
        int i2;
        String str;
        SkipWhite();
        int i3 = this._pointer;
        SheetIdentifier parseSheetName = parseSheetName();
        if (parseSheetName == null) {
            resetPointer(i3);
        } else {
            SkipWhite();
            i3 = this._pointer;
        }
        SimpleRangePart parseSimpleRangePart = parseSimpleRangePart();
        if (parseSimpleRangePart != null) {
            boolean IsWhite = IsWhite(this.look);
            if (IsWhite) {
                SkipWhite();
            }
            int i4 = this.look;
            SimpleRangePart simpleRangePart = null;
            if (i4 == 58) {
                int i5 = this._pointer;
                GetChar();
                SkipWhite();
                SimpleRangePart parseSimpleRangePart2 = parseSimpleRangePart();
                if (parseSimpleRangePart2 == null || parseSimpleRangePart.isCompatibleForArea(parseSimpleRangePart2)) {
                    simpleRangePart = parseSimpleRangePart2;
                }
                if (simpleRangePart == null) {
                    resetPointer(i5);
                    if (!parseSimpleRangePart.isCell()) {
                        if (parseSheetName != null) {
                            StringBuilder b2 = a.b("'");
                            b2.append(parseSheetName.getSheetIdentifier().getName());
                            b2.append('!');
                            str = b2.toString();
                        } else {
                            str = "";
                        }
                        StringBuilder b3 = a.b(str);
                        b3.append(parseSimpleRangePart.getRep());
                        b3.append("' is not a proper reference.");
                        throw new FormulaParseException(b3.toString());
                    }
                }
                return createAreaRefParseNode(parseSheetName, parseSimpleRangePart, simpleRangePart);
            } else if (i4 == 46) {
                GetChar();
                int i6 = 1;
                while (true) {
                    i2 = this.look;
                    if (i2 != 46) {
                        break;
                    }
                    i6++;
                    GetChar();
                }
                boolean IsWhite2 = IsWhite(i2);
                SkipWhite();
                SimpleRangePart parseSimpleRangePart3 = parseSimpleRangePart();
                String substring = this._formulaString.substring(i3 - 1, this._pointer - 1);
                if (parseSimpleRangePart3 == null) {
                    if (parseSheetName == null) {
                        return parseNonRange(i3);
                    }
                    throw new FormulaParseException(a.a(a.b("Complete area reference expected after sheet name at index "), this._pointer, "."));
                } else if (IsWhite || IsWhite2) {
                    if (!parseSimpleRangePart.isRowOrColumn() && !parseSimpleRangePart3.isRowOrColumn()) {
                        return createAreaRefParseNode(parseSheetName, parseSimpleRangePart, parseSimpleRangePart3);
                    }
                    throw new FormulaParseException(a.b("Dotted range (full row or column) expression '", substring, "' must not contain whitespace."));
                } else if (i6 == 1 && parseSimpleRangePart.isRow() && parseSimpleRangePart3.isRow()) {
                    return parseNonRange(i3);
                } else {
                    if ((!parseSimpleRangePart.isRowOrColumn() && !parseSimpleRangePart3.isRowOrColumn()) || i6 == 2) {
                        return createAreaRefParseNode(parseSheetName, parseSimpleRangePart, parseSimpleRangePart3);
                    }
                    throw new FormulaParseException(a.b("Dotted range (full row or column) expression '", substring, "' must have exactly 2 dots."));
                }
            } else if (parseSimpleRangePart.isCell() && isValidCellReference(parseSimpleRangePart.getRep())) {
                return createAreaRefParseNode(parseSheetName, parseSimpleRangePart, null);
            } else {
                if (parseSheetName == null) {
                    return parseNonRange(i3);
                }
                throw new FormulaParseException(a.a(a.b("Second part of cell reference expected after sheet name at index "), this._pointer, "."));
            }
        } else if (parseSheetName == null) {
            return parseNonRange(i3);
        } else {
            if (this.look == 35) {
                return new ParseNode(ErrPtg.valueOf(parseErrorLiteral()));
            }
            String parseAsName = parseAsName();
            if (parseAsName.length() != 0) {
                Ptg nameXPtg = this._book.getNameXPtg(parseAsName, parseSheetName);
                if (nameXPtg != null) {
                    return new ParseNode(nameXPtg);
                }
                StringBuilder d2 = a.d("Specified name '", parseAsName, "' for sheet ");
                d2.append(parseSheetName.asFormulaString());
                d2.append(" not found");
                throw new FormulaParseException(d2.toString());
            }
            throw new FormulaParseException(a.a(a.b("Cell reference or Named Range expected after sheet name at index "), this._pointer, "."));
        }
    }

    /* JADX WARNING: Code restructure failed: missing block: B:10:0x002b, code lost:
        if (r10.look == 39) goto L_0x002d;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:11:0x002d, code lost:
        r3 = true;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:12:0x002f, code lost:
        r3 = false;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:13:0x0030, code lost:
        if (r3 != false) goto L_0x0046;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:14:0x0032, code lost:
        r1.appendCodePoint(r10.look);
        GetChar();
     */
    /* JADX WARNING: Code restructure failed: missing block: B:15:0x003c, code lost:
        if (r10.look != 39) goto L_0x0030;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:16:0x003e, code lost:
        Match(39);
     */
    /* JADX WARNING: Code restructure failed: missing block: B:17:0x0043, code lost:
        if (r10.look == 39) goto L_0x002f;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:18:0x0046, code lost:
        r3 = new org.apache.poi.ss.formula.NameIdentifier(r1.toString(), true);
        SkipWhite();
        r1 = r10.look;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:19:0x0054, code lost:
        if (r1 != 33) goto L_0x005f;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:20:0x0056, code lost:
        GetChar();
     */
    /* JADX WARNING: Code restructure failed: missing block: B:21:0x005e, code lost:
        return new org.apache.poi.ss.formula.SheetIdentifier(r0, r3);
     */
    /* JADX WARNING: Code restructure failed: missing block: B:22:0x005f, code lost:
        if (r1 != 58) goto L_0x0066;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:24:0x0065, code lost:
        return parseSheetRange(r0, r3);
     */
    /* JADX WARNING: Code restructure failed: missing block: B:25:0x0066, code lost:
        return null;
     */
    private SheetIdentifier parseSheetName() {
        String bookName = this.look == 91 ? getBookName() : null;
        int i2 = this.look;
        if (i2 == 39) {
            Match(39);
            if (this.look == 91) {
                bookName = getBookName();
            }
            StringBuilder sb = new StringBuilder();
        } else if (i2 == 95 || Character.isLetter(i2)) {
            StringBuilder sb2 = new StringBuilder();
            while (isUnquotedSheetNameChar(this.look)) {
                sb2.appendCodePoint(this.look);
                GetChar();
            }
            NameIdentifier nameIdentifier = new NameIdentifier(sb2.toString(), false);
            SkipWhite();
            int i3 = this.look;
            if (i3 == 33) {
                GetChar();
                return new SheetIdentifier(bookName, nameIdentifier);
            } else if (i3 == 58) {
                return parseSheetRange(bookName, nameIdentifier);
            } else {
                return null;
            }
        } else if (this.look != 33 || bookName == null) {
            return null;
        } else {
            GetChar();
            return new SheetIdentifier(bookName, null);
        }
    }

    private SheetIdentifier parseSheetRange(String str, NameIdentifier nameIdentifier) {
        GetChar();
        SheetIdentifier parseSheetName = parseSheetName();
        if (parseSheetName != null) {
            return new SheetRangeIdentifier(str, nameIdentifier, parseSheetName.getSheetIdentifier());
        }
        return null;
    }

    private ParseNode parseSimpleFactor() {
        int i2;
        SkipWhite();
        int i3 = this.look;
        if (i3 == 34) {
            return new ParseNode(new StringPtg(parseStringLiteral()));
        }
        if (i3 == 35) {
            return new ParseNode(ErrPtg.valueOf(parseErrorLiteral()));
        }
        if (i3 == 40) {
            Match(40);
            ParseNode unionExpression = unionExpression();
            Match(41);
            return new ParseNode(ParenthesisPtg.instance, unionExpression);
        } else if (i3 == 43) {
            Match(43);
            return parseUnary(true);
        } else if (i3 == 45) {
            Match(45);
            return parseUnary(false);
        } else if (i3 == 123) {
            Match(123);
            ParseNode parseArray = parseArray();
            Match(125);
            return parseArray;
        } else if (IsAlpha(i3) || Character.isDigit(this.look) || (i2 = this.look) == 39 || i2 == 91 || i2 == 95 || i2 == 92) {
            return parseRangeExpression();
        } else {
            if (i2 == 46) {
                return new ParseNode(parseNumber());
            }
            throw expected("cell ref or constant literal");
        }
    }

    /* JADX WARNING: Code restructure failed: missing block: B:35:0x0077, code lost:
        if (r5 <= r8._ssVersion.getMaxRows()) goto L_0x007a;
     */
    private SimpleRangePart parseSimpleRangePart() {
        int i2 = this._pointer - 1;
        boolean z = false;
        boolean z2 = false;
        while (i2 < this._formulaLength) {
            char charAt = this._formulaString.charAt(i2);
            if (!Character.isDigit(charAt)) {
                if (!Character.isLetter(charAt)) {
                    if (!(charAt == '$' || charAt == '_')) {
                        break;
                    }
                } else {
                    z2 = true;
                }
            } else {
                z = true;
            }
            i2++;
        }
        int i3 = this._pointer;
        if (i2 <= i3 - 1) {
            return null;
        }
        String substring = this._formulaString.substring(i3 - 1, i2);
        if (!CELL_REF_PATTERN.matcher(substring).matches()) {
            return null;
        }
        if (!z2 || !z) {
            if (!z2) {
                if (z) {
                    try {
                        int parseInt = Integer.parseInt(substring.replace("$", ""));
                        if (parseInt >= 1) {
                        }
                    } catch (NumberFormatException unused) {
                    }
                }
                return null;
            } else if (!CellReference.isColumnWithinRange(substring.replace("$", ""), this._ssVersion)) {
                return null;
            }
        } else if (!isValidCellReference(substring)) {
            return null;
        }
        resetPointer(i2 + 1);
        return new SimpleRangePart(substring, z2, z);
    }

    private String parseStringLiteral() {
        Match(34);
        StringBuilder sb = new StringBuilder();
        while (true) {
            if (this.look == 34) {
                GetChar();
                if (this.look != 34) {
                    return sb.toString();
                }
            }
            sb.appendCodePoint(this.look);
            GetChar();
        }
    }

    public static Area3DPxg parseStructuredReference(String str, FormulaParsingWorkbook formulaParsingWorkbook, int i2) {
        Ptg[] parse = parse(str, formulaParsingWorkbook, FormulaType.CELL, -1, i2);
        if (parse.length == 1 && (parse[0] instanceof Area3DPxg)) {
            return (Area3DPxg) parse[0];
        }
        throw new IllegalStateException("Illegal structured reference");
    }

    private ParseNode parseUnary(boolean z) {
        boolean z2 = IsDigit(this.look) || this.look == 46;
        ParseNode powerFactor = powerFactor();
        if (z2) {
            Ptg token = powerFactor.getToken();
            if (token instanceof NumberPtg) {
                if (z) {
                    return powerFactor;
                }
                return new ParseNode(new NumberPtg(-((NumberPtg) token).getValue()));
            } else if (token instanceof IntPtg) {
                if (z) {
                    return powerFactor;
                }
                return new ParseNode(new NumberPtg((double) (-((IntPtg) token).getValue())));
            }
        }
        return new ParseNode(z ? UnaryPlusPtg.instance : UnaryMinusPtg.instance, powerFactor);
    }

    private String parseUnquotedIdentifier() {
        if (this.look != 39) {
            StringBuilder sb = new StringBuilder();
            while (true) {
                if (!Character.isLetterOrDigit(this.look) && this.look != 46) {
                    break;
                }
                sb.appendCodePoint(this.look);
                GetChar();
            }
            if (sb.length() < 1) {
                return null;
            }
            return sb.toString();
        }
        throw expected("unquoted identifier");
    }

    private ParseNode percentFactor() {
        ParseNode parseSimpleFactor = parseSimpleFactor();
        while (true) {
            SkipWhite();
            if (this.look != 37) {
                return parseSimpleFactor;
            }
            Match(37);
            parseSimpleFactor = new ParseNode(PercentPtg.instance, parseSimpleFactor);
        }
    }

    private ParseNode powerFactor() {
        ParseNode percentFactor = percentFactor();
        while (true) {
            SkipWhite();
            if (this.look != 94) {
                return percentFactor;
            }
            Match(94);
            percentFactor = new ParseNode(PowerPtg.instance, percentFactor, percentFactor());
        }
    }

    private void resetPointer(int i2) {
        this._pointer = i2;
        if (i2 <= this._formulaLength) {
            this.look = this._formulaString.codePointAt(i2 - Character.charCount(this.look));
        } else {
            this.look = 0;
        }
    }

    private ParseNode unionExpression() {
        ParseNode intersectionExpression = intersectionExpression();
        boolean z = false;
        while (true) {
            SkipWhite();
            if (this.look != 44) {
                break;
            }
            GetChar();
            z = true;
            intersectionExpression = new ParseNode(UnionPtg.instance, intersectionExpression, intersectionExpression());
        }
        return z ? augmentWithMemPtg(intersectionExpression) : intersectionExpression;
    }

    private void validateNumArgs(int i2, FunctionMetadata functionMetadata) {
        int i3;
        String str;
        String str2;
        if (i2 < functionMetadata.getMinParams()) {
            StringBuilder b2 = a.b("Too few arguments to function '");
            b2.append(functionMetadata.getName());
            b2.append("'. ");
            String sb = b2.toString();
            if (functionMetadata.hasFixedArgsLength()) {
                StringBuilder d2 = a.d(sb, "Expected ");
                d2.append(functionMetadata.getMinParams());
                str2 = d2.toString();
            } else {
                StringBuilder d3 = a.d(sb, "At least ");
                d3.append(functionMetadata.getMinParams());
                d3.append(" were expected");
                str2 = d3.toString();
            }
            throw new FormulaParseException(str2 + " but got " + i2 + ".");
        }
        if (functionMetadata.hasUnlimitedVarags()) {
            FormulaParsingWorkbook formulaParsingWorkbook = this._book;
            if (formulaParsingWorkbook != null) {
                i3 = formulaParsingWorkbook.getSpreadsheetVersion().getMaxFunctionArgs();
            } else {
                i3 = functionMetadata.getMaxParams();
            }
        } else {
            i3 = functionMetadata.getMaxParams();
        }
        if (i2 > i3) {
            StringBuilder b3 = a.b("Too many arguments to function '");
            b3.append(functionMetadata.getName());
            b3.append("'. ");
            String sb2 = b3.toString();
            if (functionMetadata.hasFixedArgsLength()) {
                str = sb2 + "Expected " + i3;
            } else {
                str = sb2 + "At most " + i3 + " were expected";
            }
            throw new FormulaParseException(str + " but got " + i2 + ".");
        }
    }

    public static Ptg[] parse(String str, FormulaParsingWorkbook formulaParsingWorkbook, FormulaType formulaType, int i2) {
        return parse(str, formulaParsingWorkbook, formulaType, i2, -1);
    }

    private void parse() {
        this._pointer = 0;
        GetChar();
        this._rootNode = unionExpression();
        if (this._pointer <= this._formulaLength) {
            StringBuilder b2 = a.b("Unused input [");
            b2.append(this._formulaString.substring(this._pointer - 1));
            b2.append("] after attempting to parse the formula [");
            throw new FormulaParseException(a.a(b2, this._formulaString, "]"));
        }
    }

    /* JADX WARNING: Code restructure failed: missing block: B:100:0x01a6, code lost:
        if (r2.getTotalsRowCount() > 0) goto L_0x0191;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:118:0x01db, code lost:
        if (r2.getTotalsRowCount() > 0) goto L_0x0191;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:91:0x018f, code lost:
        if (r2.getTotalsRowCount() > 0) goto L_0x0191;
     */
    /* JADX WARNING: Removed duplicated region for block: B:121:0x01e6  */
    /* JADX WARNING: Removed duplicated region for block: B:131:0x022a  */
    /* JADX WARNING: Removed duplicated region for block: B:147:0x028b  */
    /* JADX WARNING: Removed duplicated region for block: B:149:0x0293  */
    private ParseNode parseStructuredReference(String str) {
        boolean z;
        boolean z2;
        boolean z3;
        boolean z4;
        boolean z5;
        boolean z6;
        String str2;
        int i2;
        String str3;
        int i3;
        int i4;
        int i5;
        int i6;
        if (this._ssVersion.equals(SpreadsheetVersion.EXCEL2007)) {
            Table table = this._book.getTable(str);
            if (table != null) {
                String sheetName = table.getSheetName();
                int startColIndex = table.getStartColIndex();
                int endColIndex = table.getEndColIndex();
                int startRowIndex = table.getStartRowIndex();
                int endRowIndex = table.getEndRowIndex();
                int i7 = this._pointer;
                GetChar();
                int i8 = 0;
                boolean z7 = false;
                boolean z8 = false;
                boolean z9 = false;
                boolean z10 = false;
                boolean z11 = false;
                while (true) {
                    int i9 = this._pointer;
                    String parseAsSpecialQuantifier = parseAsSpecialQuantifier();
                    z = z7;
                    z2 = z8;
                    z3 = z9;
                    z4 = z10;
                    z5 = z11;
                    if (parseAsSpecialQuantifier != null) {
                        if (parseAsSpecialQuantifier.equals(specAll)) {
                            z3 = true;
                        } else if (parseAsSpecialQuantifier.equals("Data")) {
                            z4 = true;
                        } else if (parseAsSpecialQuantifier.equals(specHeaders)) {
                            z5 = true;
                        } else if (parseAsSpecialQuantifier.equals(specThisRow)) {
                            z2 = true;
                        } else if (parseAsSpecialQuantifier.equals(specTotals)) {
                            z = true;
                        } else {
                            throw new FormulaParseException(a.b("Unknown special quantifier ", parseAsSpecialQuantifier));
                        }
                        i8++;
                        if (this.look != 44) {
                            break;
                        }
                        GetChar();
                        endColIndex = endColIndex;
                        z7 = z;
                        z8 = z2;
                        z9 = z3;
                        z10 = z4;
                        z11 = z5;
                    } else {
                        resetPointer(i9);
                        break;
                    }
                }
                SkipWhite();
                if (this.look == 64) {
                    GetChar();
                    z6 = true;
                } else {
                    z6 = false;
                }
                int i10 = this._pointer;
                String parseAsColumnQuantifier = parseAsColumnQuantifier();
                if (parseAsColumnQuantifier == null) {
                    resetPointer(i10);
                    i2 = 0;
                    str2 = sheetName;
                } else {
                    int i11 = this.look;
                    str2 = sheetName;
                    if (i11 == 44) {
                        throw new FormulaParseException(a.a(a.b("The formula "), this._formulaString, "is illegal: you should not use ',' with column quantifiers"));
                    } else if (i11 == 58) {
                        GetChar();
                        str3 = parseAsColumnQuantifier();
                        if (str3 != null) {
                            i2 = 2;
                            if (i2 == 0 || i8 != 0) {
                                Match(93);
                            } else {
                                resetPointer(i7);
                                int i12 = this._pointer;
                                parseAsColumnQuantifier = parseAsColumnQuantifier();
                                if (parseAsColumnQuantifier != null) {
                                    i2++;
                                } else {
                                    resetPointer(i12);
                                    String parseAsSpecialQuantifier2 = parseAsSpecialQuantifier();
                                    if (parseAsSpecialQuantifier2 != null) {
                                        if (parseAsSpecialQuantifier2.equals(specAll)) {
                                            z3 = true;
                                        } else if (parseAsSpecialQuantifier2.equals("Data")) {
                                            z4 = true;
                                        } else if (parseAsSpecialQuantifier2.equals(specHeaders)) {
                                            z5 = true;
                                        } else if (parseAsSpecialQuantifier2.equals(specThisRow)) {
                                            z2 = true;
                                        } else if (parseAsSpecialQuantifier2.equals(specTotals)) {
                                            z = true;
                                        } else {
                                            throw new FormulaParseException(a.b("Unknown special quantifier ", parseAsSpecialQuantifier2));
                                        }
                                        i8++;
                                    } else {
                                        throw new FormulaParseException(a.a(a.b("The formula "), this._formulaString, " is illegal"));
                                    }
                                }
                            }
                            if (!z && table.getTotalsRowCount() == 0) {
                                return new ParseNode(ErrPtg.REF_INVALID);
                            }
                            if ((z6 && !z2) || ((i6 = this._rowIndex) >= startRowIndex && endRowIndex >= i6)) {
                                if (i8 > 0) {
                                    if (i8 != 1 || !z3) {
                                        if (!z4 || !z5) {
                                            if (!z4 || !z) {
                                                int i13 = 1;
                                                if (i8 == 1) {
                                                    if (z4) {
                                                        startRowIndex++;
                                                    } else {
                                                        i13 = 1;
                                                    }
                                                }
                                                if (i8 != i13 || !z5) {
                                                    if (i8 == i13 && z) {
                                                        startRowIndex = endRowIndex;
                                                    } else if ((i8 != i13 || !z2) && !z6) {
                                                        throw new FormulaParseException(a.a(a.b("The formula "), this._formulaString, " is illegal"));
                                                    } else {
                                                        i5 = this._rowIndex;
                                                        startRowIndex = i5;
                                                    }
                                                }
                                                endRowIndex = startRowIndex;
                                            } else {
                                                startRowIndex++;
                                            }
                                        }
                                    }
                                    if (i2 == 2) {
                                        if (parseAsColumnQuantifier == null || str3 == null) {
                                            throw new IllegalStateException("Fatal error");
                                        }
                                        int findColumnIndex = table.findColumnIndex(parseAsColumnQuantifier);
                                        int findColumnIndex2 = table.findColumnIndex(str3);
                                        if (findColumnIndex == -1 || findColumnIndex2 == -1) {
                                            throw new FormulaParseException("One of the columns " + parseAsColumnQuantifier + ", " + str3 + " doesn't exist in table " + table.getName());
                                        }
                                        i4 = startColIndex + findColumnIndex;
                                        i3 = startColIndex + findColumnIndex2;
                                    } else if (i2 != 1 || z6) {
                                        i3 = endColIndex;
                                        i4 = startColIndex;
                                    } else if (parseAsColumnQuantifier != null) {
                                        int findColumnIndex3 = table.findColumnIndex(parseAsColumnQuantifier);
                                        if (findColumnIndex3 != -1) {
                                            i4 = startColIndex + findColumnIndex3;
                                            i3 = i4;
                                        } else {
                                            StringBuilder d2 = a.d("The column ", parseAsColumnQuantifier, " doesn't exist in table ");
                                            d2.append(table.getName());
                                            throw new FormulaParseException(d2.toString());
                                        }
                                    } else {
                                        throw new IllegalStateException("Fatal error");
                                    }
                                    return new ParseNode(this._book.get3DReferencePtg(new AreaReference(new CellReference(startRowIndex, i4), new CellReference(endRowIndex, i3), this._ssVersion), new SheetIdentifier(null, new NameIdentifier(str2, true))));
                                } else if (z6) {
                                    i5 = this._rowIndex;
                                    startRowIndex = i5;
                                    endRowIndex = startRowIndex;
                                    if (i2 == 2) {
                                    }
                                    return new ParseNode(this._book.get3DReferencePtg(new AreaReference(new CellReference(startRowIndex, i4), new CellReference(endRowIndex, i3), this._ssVersion), new SheetIdentifier(null, new NameIdentifier(str2, true))));
                                } else {
                                    startRowIndex++;
                                }
                                endRowIndex--;
                                if (i2 == 2) {
                                }
                                return new ParseNode(this._book.get3DReferencePtg(new AreaReference(new CellReference(startRowIndex, i4), new CellReference(endRowIndex, i3), this._ssVersion), new SheetIdentifier(null, new NameIdentifier(str2, true))));
                            } else if (this._rowIndex < 0) {
                                return new ParseNode(ErrPtg.VALUE_INVALID);
                            } else {
                                throw new FormulaParseException("Formula contained [#This Row] or [@] structured reference but this row < 0. Row index must be specified for row-referencing structured references.");
                            }
                        } else {
                            throw new FormulaParseException(a.a(a.b("The formula "), this._formulaString, "is illegal: the string after ':' must be column quantifier"));
                        }
                    } else {
                        i2 = 1;
                    }
                }
                str3 = null;
                if (i2 == 0) {
                }
                Match(93);
                if (!z) {
                }
                if (z6) {
                }
                if (this._rowIndex < 0) {
                }
            } else {
                throw new FormulaParseException(a.b("Illegal table name: '", str, "'"));
            }
        } else {
            throw new FormulaParseException("Structured references work only on XSSF (Excel 2007+)!");
        }
    }
}
