package org.apache.poi.ss.formula;

import b.b.a.a.a;
import org.apache.poi.ss.SpreadsheetVersion;
import org.apache.poi.ss.formula.ptg.Area2DPtgBase;
import org.apache.poi.ss.formula.ptg.Area3DPtg;
import org.apache.poi.ss.formula.ptg.Area3DPxg;
import org.apache.poi.ss.formula.ptg.AreaErrPtg;
import org.apache.poi.ss.formula.ptg.AreaPtg;
import org.apache.poi.ss.formula.ptg.AreaPtgBase;
import org.apache.poi.ss.formula.ptg.Deleted3DPxg;
import org.apache.poi.ss.formula.ptg.DeletedArea3DPtg;
import org.apache.poi.ss.formula.ptg.DeletedRef3DPtg;
import org.apache.poi.ss.formula.ptg.Ptg;
import org.apache.poi.ss.formula.ptg.Ref3DPtg;
import org.apache.poi.ss.formula.ptg.Ref3DPxg;
import org.apache.poi.ss.formula.ptg.RefErrorPtg;
import org.apache.poi.ss.formula.ptg.RefPtg;
import org.apache.poi.ss.formula.ptg.RefPtgBase;

public final class FormulaShifter {
    public final int _amountToMove;
    public final int _dstSheetIndex;
    public final int _externSheetIndex;
    public final int _firstMovedIndex;
    public final int _lastMovedIndex;
    public final ShiftMode _mode;
    public final String _sheetName;
    public final int _srcSheetIndex;
    public final SpreadsheetVersion _version;

    /* renamed from: org.apache.poi.ss.formula.FormulaShifter$1  reason: invalid class name */
    public static /* synthetic */ class AnonymousClass1 {
        public static final /* synthetic */ int[] $SwitchMap$org$apache$poi$ss$formula$FormulaShifter$ShiftMode;

        /* JADX WARNING: Can't wrap try/catch for region: R(8:0|(2:1|2)|3|5|6|7|8|10) */
        /* JADX WARNING: Code restructure failed: missing block: B:11:?, code lost:
            return;
         */
        /* JADX WARNING: Failed to process nested try/catch */
        /* JADX WARNING: Missing exception handler attribute for start block: B:7:0x0016 */
        static {
            int[] iArr = new int[ShiftMode.values().length];
            $SwitchMap$org$apache$poi$ss$formula$FormulaShifter$ShiftMode = iArr;
            try {
                ShiftMode shiftMode = ShiftMode.RowMove;
                iArr[0] = 1;
            } catch (NoSuchFieldError unused) {
            }
            int[] iArr2 = $SwitchMap$org$apache$poi$ss$formula$FormulaShifter$ShiftMode;
            ShiftMode shiftMode2 = ShiftMode.RowCopy;
            iArr2[1] = 2;
            int[] iArr3 = $SwitchMap$org$apache$poi$ss$formula$FormulaShifter$ShiftMode;
            ShiftMode shiftMode3 = ShiftMode.SheetMove;
            iArr3[2] = 3;
        }
    }

    public enum ShiftMode {
        RowMove,
        RowCopy,
        SheetMove
    }

    public FormulaShifter(int i2, String str, int i3, int i4, int i5, ShiftMode shiftMode, SpreadsheetVersion spreadsheetVersion) {
        if (i5 == 0) {
            throw new IllegalArgumentException("amountToMove must not be zero");
        } else if (i3 <= i4) {
            this._externSheetIndex = i2;
            this._sheetName = str;
            this._firstMovedIndex = i3;
            this._lastMovedIndex = i4;
            this._amountToMove = i5;
            this._mode = shiftMode;
            this._version = spreadsheetVersion;
            this._dstSheetIndex = -1;
            this._srcSheetIndex = -1;
        } else {
            throw new IllegalArgumentException("firstMovedIndex, lastMovedIndex out of order");
        }
    }

    private Ptg adjustPtg(Ptg ptg, int i2) {
        int ordinal = this._mode.ordinal();
        if (ordinal == 0) {
            return adjustPtgDueToRowMove(ptg, i2);
        }
        if (ordinal == 1) {
            return adjustPtgDueToRowCopy(ptg);
        }
        if (ordinal == 2) {
            return adjustPtgDueToSheetMove(ptg);
        }
        StringBuilder b2 = a.b("Unsupported shift mode: ");
        b2.append(this._mode);
        throw new IllegalStateException(b2.toString());
    }

    private Ptg adjustPtgDueToRowCopy(Ptg ptg) {
        if (ptg instanceof RefPtg) {
            return rowCopyRefPtg((RefPtg) ptg);
        }
        if (ptg instanceof Ref3DPtg) {
            return rowCopyRefPtg((Ref3DPtg) ptg);
        }
        if (ptg instanceof Ref3DPxg) {
            return rowCopyRefPtg((Ref3DPxg) ptg);
        }
        if (ptg instanceof Area2DPtgBase) {
            return rowCopyAreaPtg((Area2DPtgBase) ptg);
        }
        if (ptg instanceof Area3DPtg) {
            return rowCopyAreaPtg((Area3DPtg) ptg);
        }
        if (ptg instanceof Area3DPxg) {
            return rowCopyAreaPtg((Area3DPxg) ptg);
        }
        return null;
    }

    private Ptg adjustPtgDueToRowMove(Ptg ptg, int i2) {
        if (ptg instanceof RefPtg) {
            if (i2 != this._externSheetIndex) {
                return null;
            }
            return rowMoveRefPtg((RefPtg) ptg);
        } else if (ptg instanceof Ref3DPtg) {
            Ref3DPtg ref3DPtg = (Ref3DPtg) ptg;
            if (this._externSheetIndex != ref3DPtg.getExternSheetIndex()) {
                return null;
            }
            return rowMoveRefPtg(ref3DPtg);
        } else if (ptg instanceof Ref3DPxg) {
            Ref3DPxg ref3DPxg = (Ref3DPxg) ptg;
            if (ref3DPxg.getExternalWorkbookNumber() > 0 || !this._sheetName.equals(ref3DPxg.getSheetName())) {
                return null;
            }
            return rowMoveRefPtg(ref3DPxg);
        } else if (ptg instanceof Area2DPtgBase) {
            if (i2 != this._externSheetIndex) {
                return ptg;
            }
            return rowMoveAreaPtg((Area2DPtgBase) ptg);
        } else if (ptg instanceof Area3DPtg) {
            Area3DPtg area3DPtg = (Area3DPtg) ptg;
            if (this._externSheetIndex != area3DPtg.getExternSheetIndex()) {
                return null;
            }
            return rowMoveAreaPtg(area3DPtg);
        } else {
            if (ptg instanceof Area3DPxg) {
                Area3DPxg area3DPxg = (Area3DPxg) ptg;
                if (area3DPxg.getExternalWorkbookNumber() <= 0 && this._sheetName.equals(area3DPxg.getSheetName())) {
                    return rowMoveAreaPtg(area3DPxg);
                }
            }
            return null;
        }
    }

    private Ptg adjustPtgDueToSheetMove(Ptg ptg) {
        Ref3DPtg ref3DPtg;
        int externSheetIndex;
        if (!(ptg instanceof Ref3DPtg) || ((externSheetIndex = (ref3DPtg = (Ref3DPtg) ptg).getExternSheetIndex()) < this._srcSheetIndex && externSheetIndex < this._dstSheetIndex)) {
            return null;
        }
        if (externSheetIndex > this._srcSheetIndex && externSheetIndex > this._dstSheetIndex) {
            return null;
        }
        int i2 = this._srcSheetIndex;
        if (externSheetIndex == i2) {
            ref3DPtg.setExternSheetIndex(this._dstSheetIndex);
            return ref3DPtg;
        }
        int i3 = this._dstSheetIndex;
        if (i3 < i2) {
            ref3DPtg.setExternSheetIndex(externSheetIndex + 1);
            return ref3DPtg;
        }
        if (i3 > i2) {
            ref3DPtg.setExternSheetIndex(externSheetIndex - 1);
            return ref3DPtg;
        }
        return null;
    }

    public static Ptg createDeletedRef(Ptg ptg) {
        if (ptg instanceof RefPtg) {
            return new RefErrorPtg();
        }
        if (ptg instanceof Ref3DPtg) {
            return new DeletedRef3DPtg(((Ref3DPtg) ptg).getExternSheetIndex());
        }
        if (ptg instanceof AreaPtg) {
            return new AreaErrPtg();
        }
        if (ptg instanceof Area3DPtg) {
            return new DeletedArea3DPtg(((Area3DPtg) ptg).getExternSheetIndex());
        }
        if (ptg instanceof Ref3DPxg) {
            Ref3DPxg ref3DPxg = (Ref3DPxg) ptg;
            return new Deleted3DPxg(ref3DPxg.getExternalWorkbookNumber(), ref3DPxg.getSheetName());
        } else if (ptg instanceof Area3DPxg) {
            Area3DPxg area3DPxg = (Area3DPxg) ptg;
            return new Deleted3DPxg(area3DPxg.getExternalWorkbookNumber(), area3DPxg.getSheetName());
        } else {
            StringBuilder b2 = a.b("Unexpected ref ptg class (");
            b2.append(ptg.getClass().getName());
            b2.append(")");
            throw new IllegalArgumentException(b2.toString());
        }
    }

    public static FormulaShifter createForRowCopy(int i2, String str, int i3, int i4, int i5, SpreadsheetVersion spreadsheetVersion) {
        return new FormulaShifter(i2, str, i3, i4, i5, ShiftMode.RowCopy, spreadsheetVersion);
    }

    public static FormulaShifter createForRowShift(int i2, String str, int i3, int i4, int i5, SpreadsheetVersion spreadsheetVersion) {
        return new FormulaShifter(i2, str, i3, i4, i5, ShiftMode.RowMove, spreadsheetVersion);
    }

    public static FormulaShifter createForSheetShift(int i2, int i3) {
        return new FormulaShifter(i2, i3);
    }

    private Ptg rowCopyAreaPtg(AreaPtgBase areaPtgBase) {
        boolean z;
        int firstRow = areaPtgBase.getFirstRow();
        int lastRow = areaPtgBase.getLastRow();
        boolean z2 = true;
        if (areaPtgBase.isFirstRowRelative()) {
            int i2 = firstRow + this._amountToMove;
            if (i2 < 0 || this._version.getLastRowIndex() < i2) {
                return createDeletedRef(areaPtgBase);
            }
            areaPtgBase.setFirstRow(i2);
            z = true;
        } else {
            z = false;
        }
        if (areaPtgBase.isLastRowRelative()) {
            int i3 = lastRow + this._amountToMove;
            if (i3 < 0 || this._version.getLastRowIndex() < i3) {
                return createDeletedRef(areaPtgBase);
            }
            areaPtgBase.setLastRow(i3);
        } else {
            z2 = z;
        }
        if (z2) {
            areaPtgBase.sortTopLeftToBottomRight();
        }
        if (z2) {
            return areaPtgBase;
        }
        return null;
    }

    private Ptg rowCopyRefPtg(RefPtgBase refPtgBase) {
        int row = refPtgBase.getRow();
        if (!refPtgBase.isRowRelative()) {
            return null;
        }
        int i2 = this._firstMovedIndex + this._amountToMove;
        if (i2 < 0 || this._version.getLastRowIndex() < i2) {
            return createDeletedRef(refPtgBase);
        }
        refPtgBase.setRow(row + this._amountToMove);
        return refPtgBase;
    }

    private Ptg rowMoveAreaPtg(AreaPtgBase areaPtgBase) {
        int i2;
        int firstRow = areaPtgBase.getFirstRow();
        int lastRow = areaPtgBase.getLastRow();
        if (this._firstMovedIndex > firstRow || lastRow > this._lastMovedIndex) {
            int i3 = this._firstMovedIndex;
            int i4 = this._amountToMove;
            int i5 = i3 + i4;
            int i6 = this._lastMovedIndex;
            int i7 = i4 + i6;
            if (firstRow >= i3 || i6 >= lastRow) {
                if (this._firstMovedIndex > firstRow || firstRow > (i2 = this._lastMovedIndex)) {
                    int i8 = this._firstMovedIndex;
                    if (i8 <= lastRow && lastRow <= this._lastMovedIndex) {
                        int i9 = this._amountToMove;
                        if (i9 > 0) {
                            areaPtgBase.setLastRow(lastRow + i9);
                            return areaPtgBase;
                        } else if (i7 < firstRow) {
                            return null;
                        } else {
                            int i10 = lastRow + i9;
                            if (i5 > firstRow) {
                                areaPtgBase.setLastRow(i10);
                                return areaPtgBase;
                            }
                            int i11 = i8 - 1;
                            if (i7 < i11) {
                                i10 = i11;
                            }
                            areaPtgBase.setFirstRow(Math.min(firstRow, i5));
                            areaPtgBase.setLastRow(i10);
                            return areaPtgBase;
                        }
                    } else if (i7 < firstRow || lastRow < i5) {
                        return null;
                    } else {
                        if (i5 <= firstRow && lastRow <= i7) {
                            return createDeletedRef(areaPtgBase);
                        }
                        if (firstRow <= i5 && i7 <= lastRow) {
                            return null;
                        }
                        if (i5 < firstRow && firstRow <= i7) {
                            areaPtgBase.setFirstRow(i7 + 1);
                            return areaPtgBase;
                        } else if (i5 > lastRow || lastRow >= i7) {
                            StringBuilder b2 = a.b("Situation not covered: (");
                            b2.append(this._firstMovedIndex);
                            b2.append(", ");
                            b2.append(this._lastMovedIndex);
                            b2.append(", ");
                            b2.append(this._amountToMove);
                            b2.append(", ");
                            b2.append(firstRow);
                            b2.append(", ");
                            throw new IllegalStateException(a.a(b2, lastRow, ")"));
                        } else {
                            areaPtgBase.setLastRow(i5 - 1);
                            return areaPtgBase;
                        }
                    }
                } else {
                    int i12 = this._amountToMove;
                    if (i12 < 0) {
                        areaPtgBase.setFirstRow(firstRow + i12);
                        return areaPtgBase;
                    } else if (i5 > lastRow) {
                        return null;
                    } else {
                        int i13 = firstRow + i12;
                        if (i7 < lastRow) {
                            areaPtgBase.setFirstRow(i13);
                            return areaPtgBase;
                        }
                        int i14 = i2 + 1;
                        if (i5 > i14) {
                            i13 = i14;
                        }
                        areaPtgBase.setFirstRow(i13);
                        areaPtgBase.setLastRow(Math.max(lastRow, i7));
                        return areaPtgBase;
                    }
                }
            } else if (i5 < firstRow && firstRow <= i7) {
                areaPtgBase.setFirstRow(i7 + 1);
                return areaPtgBase;
            } else if (i5 > lastRow || lastRow >= i7) {
                return null;
            } else {
                areaPtgBase.setLastRow(i5 - 1);
                return areaPtgBase;
            }
        } else {
            areaPtgBase.setFirstRow(firstRow + this._amountToMove);
            areaPtgBase.setLastRow(lastRow + this._amountToMove);
            return areaPtgBase;
        }
    }

    private Ptg rowMoveRefPtg(RefPtgBase refPtgBase) {
        int row = refPtgBase.getRow();
        if (this._firstMovedIndex > row || row > this._lastMovedIndex) {
            int i2 = this._firstMovedIndex;
            int i3 = this._amountToMove;
            int i4 = i2 + i3;
            int i5 = this._lastMovedIndex + i3;
            if (i5 < row || row < i4) {
                return null;
            }
            if (i4 <= row && row <= i5) {
                return createDeletedRef(refPtgBase);
            }
            StringBuilder b2 = a.b("Situation not covered: (");
            b2.append(this._firstMovedIndex);
            b2.append(", ");
            b2.append(this._lastMovedIndex);
            b2.append(", ");
            b2.append(this._amountToMove);
            b2.append(", ");
            b2.append(row);
            b2.append(", ");
            throw new IllegalStateException(a.a(b2, row, ")"));
        }
        refPtgBase.setRow(row + this._amountToMove);
        return refPtgBase;
    }

    public boolean adjustFormula(Ptg[] ptgArr, int i2) {
        boolean z = false;
        for (int i3 = 0; i3 < ptgArr.length; i3++) {
            Ptg adjustPtg = adjustPtg(ptgArr[i3], i2);
            if (adjustPtg != null) {
                ptgArr[i3] = adjustPtg;
                z = true;
            }
        }
        return z;
    }

    public String toString() {
        StringBuffer stringBuffer = new StringBuffer();
        a.a(FormulaShifter.class, stringBuffer, " [");
        stringBuffer.append(this._firstMovedIndex);
        stringBuffer.append(this._lastMovedIndex);
        stringBuffer.append(this._amountToMove);
        return stringBuffer.toString();
    }

    public FormulaShifter(int i2, int i3) {
        this._amountToMove = -1;
        this._lastMovedIndex = -1;
        this._firstMovedIndex = -1;
        this._externSheetIndex = -1;
        this._sheetName = null;
        this._version = null;
        this._srcSheetIndex = i2;
        this._dstSheetIndex = i3;
        this._mode = ShiftMode.SheetMove;
    }
}
