package org.apache.poi.ss.formula;

import b.b.a.a.a;
import org.apache.poi.ss.SpreadsheetVersion;
import org.apache.poi.ss.formula.CollaboratingWorkbooksEnvironment;
import org.apache.poi.ss.formula.EvaluationWorkbook;
import org.apache.poi.ss.formula.eval.ErrorEval;
import org.apache.poi.ss.formula.eval.ExternalNameEval;
import org.apache.poi.ss.formula.eval.FunctionNameEval;
import org.apache.poi.ss.formula.eval.ValueEval;
import org.apache.poi.ss.formula.functions.FreeRefFunction;
import org.apache.poi.ss.formula.ptg.Area3DPtg;
import org.apache.poi.ss.formula.ptg.Area3DPxg;
import org.apache.poi.ss.formula.ptg.NameXPtg;
import org.apache.poi.ss.formula.ptg.NameXPxg;
import org.apache.poi.ss.formula.ptg.Ptg;
import org.apache.poi.ss.formula.ptg.Ref3DPtg;
import org.apache.poi.ss.formula.ptg.Ref3DPxg;
import org.apache.poi.ss.util.CellReference;

public final class OperationEvaluationContext {
    public static final FreeRefFunction UDF = UserDefinedFunction.instance;
    public final WorkbookEvaluator _bookEvaluator;
    public final int _columnIndex;
    public final boolean _isSingleValue;
    public final int _rowIndex;
    public final int _sheetIndex;
    public final EvaluationTracker _tracker;
    public final EvaluationWorkbook _workbook;

    /* renamed from: org.apache.poi.ss.formula.OperationEvaluationContext$1  reason: invalid class name */
    public static /* synthetic */ class AnonymousClass1 {
        public static final /* synthetic */ int[] $SwitchMap$org$apache$poi$ss$util$CellReference$NameType;

        /* JADX WARNING: Can't wrap try/catch for region: R(12:0|(2:1|2)|3|(2:5|6)|7|9|10|11|12|13|14|16) */
        /* JADX WARNING: Code restructure failed: missing block: B:17:?, code lost:
            return;
         */
        /* JADX WARNING: Failed to process nested try/catch */
        /* JADX WARNING: Missing exception handler attribute for start block: B:11:0x001d */
        /* JADX WARNING: Missing exception handler attribute for start block: B:13:0x0023 */
        static {
            int[] iArr = new int[CellReference.NameType.values().length];
            $SwitchMap$org$apache$poi$ss$util$CellReference$NameType = iArr;
            try {
                CellReference.NameType nameType = CellReference.NameType.BAD_CELL_OR_NAMED_RANGE;
                iArr[4] = 1;
            } catch (NoSuchFieldError unused) {
            }
            try {
                int[] iArr2 = $SwitchMap$org$apache$poi$ss$util$CellReference$NameType;
                CellReference.NameType nameType2 = CellReference.NameType.NAMED_RANGE;
                iArr2[1] = 2;
            } catch (NoSuchFieldError unused2) {
            }
            int[] iArr3 = $SwitchMap$org$apache$poi$ss$util$CellReference$NameType;
            CellReference.NameType nameType3 = CellReference.NameType.COLUMN;
            iArr3[2] = 3;
            int[] iArr4 = $SwitchMap$org$apache$poi$ss$util$CellReference$NameType;
            CellReference.NameType nameType4 = CellReference.NameType.ROW;
            iArr4[3] = 4;
            int[] iArr5 = $SwitchMap$org$apache$poi$ss$util$CellReference$NameType;
            CellReference.NameType nameType5 = CellReference.NameType.CELL;
            iArr5[0] = 5;
        }
    }

    public OperationEvaluationContext(WorkbookEvaluator workbookEvaluator, EvaluationWorkbook evaluationWorkbook, int i2, int i3, int i4, EvaluationTracker evaluationTracker) {
        this(workbookEvaluator, evaluationWorkbook, i2, i3, i4, evaluationTracker, true);
    }

    public static CellReference.NameType classifyCellReference(String str, SpreadsheetVersion spreadsheetVersion) {
        if (str.length() < 1) {
            return CellReference.NameType.BAD_CELL_OR_NAMED_RANGE;
        }
        return CellReference.classifyCellReference(str, spreadsheetVersion);
    }

    private ValueEval getExternalNameXEval(EvaluationWorkbook.ExternalName externalName, String str) {
        try {
            WorkbookEvaluator otherWorkbookEvaluator = this._bookEvaluator.getOtherWorkbookEvaluator(str);
            EvaluationName name = otherWorkbookEvaluator.getName(externalName.getName(), externalName.getIx() - 1);
            if (name != null && name.hasFormula()) {
                if (name.getNameDefinition().length <= 1) {
                    OperationEvaluationContext operationEvaluationContext = new OperationEvaluationContext(otherWorkbookEvaluator, otherWorkbookEvaluator.getWorkbook(), -1, -1, -1, this._tracker);
                    Ptg ptg = name.getNameDefinition()[0];
                    if (ptg instanceof Ref3DPtg) {
                        return operationEvaluationContext.getRef3DEval((Ref3DPtg) ptg);
                    }
                    if (ptg instanceof Ref3DPxg) {
                        return operationEvaluationContext.getRef3DEval((Ref3DPxg) ptg);
                    }
                    if (ptg instanceof Area3DPtg) {
                        return operationEvaluationContext.getArea3DEval((Area3DPtg) ptg);
                    }
                    if (ptg instanceof Area3DPxg) {
                        return operationEvaluationContext.getArea3DEval((Area3DPxg) ptg);
                    }
                } else {
                    throw new RuntimeException("Complex name formulas not supported yet");
                }
            }
            return ErrorEval.REF_INVALID;
        } catch (CollaboratingWorkbooksEnvironment.WorkbookNotFoundException unused) {
            return ErrorEval.REF_INVALID;
        }
    }

    private ValueEval getLocalNameXEval(NameXPxg nameXPxg) {
        int sheetIndex = nameXPxg.getSheetName() != null ? this._workbook.getSheetIndex(nameXPxg.getSheetName()) : -1;
        String nameName = nameXPxg.getNameName();
        EvaluationName name = this._workbook.getName(nameName, sheetIndex);
        if (name != null) {
            return new ExternalNameEval(name);
        }
        return new FunctionNameEval(nameName);
    }

    public static int parseColRef(String str) {
        return Integer.parseInt(str) - 1;
    }

    public static int parseRowRef(String str) {
        return CellReference.convertColStringToIndex(str);
    }

    public SheetRangeEvaluator createExternSheetRefEvaluator(ExternSheetReferenceToken externSheetReferenceToken) {
        return createExternSheetRefEvaluator(externSheetReferenceToken.getExternSheetIndex());
    }

    public FreeRefFunction findUserDefinedFunction(String str) {
        return this._bookEvaluator.findUserDefinedFunction(str);
    }

    public ValueEval getArea3DEval(Area3DPtg area3DPtg) {
        return new LazyAreaEval(area3DPtg.getFirstRow(), area3DPtg.getFirstColumn(), area3DPtg.getLastRow(), area3DPtg.getLastColumn(), createExternSheetRefEvaluator(area3DPtg.getExternSheetIndex()));
    }

    public ValueEval getAreaEval(int i2, int i3, int i4, int i5) {
        return new LazyAreaEval(i2, i3, i4, i5, getRefEvaluatorForCurrentSheet());
    }

    public int getColumnIndex() {
        return this._columnIndex;
    }

    public ValueEval getDynamicReference(String str, String str2, String str3, String str4, boolean z) {
        short s;
        int i2;
        short s2;
        int i3;
        int i4;
        int i5;
        int i6;
        int i7;
        int i8;
        int i9;
        if (z) {
            SheetRefEvaluator createExternSheetRefEvaluator = createExternSheetRefEvaluator(str, str2);
            if (createExternSheetRefEvaluator == null) {
                return ErrorEval.REF_INVALID;
            }
            SheetRangeEvaluator sheetRangeEvaluator = new SheetRangeEvaluator(this._sheetIndex, createExternSheetRefEvaluator);
            SpreadsheetVersion spreadsheetVersion = ((FormulaParsingWorkbook) this._workbook).getSpreadsheetVersion();
            CellReference.NameType classifyCellReference = classifyCellReference(str3, spreadsheetVersion);
            int ordinal = classifyCellReference.ordinal();
            if (ordinal == 1) {
                EvaluationName name = ((FormulaParsingWorkbook) this._workbook).getName(str3, this._sheetIndex);
                if (name.isRange()) {
                    return this._bookEvaluator.evaluateNameFormula(name.getNameDefinition(), this);
                }
                throw new RuntimeException(a.b("Specified name '", str3, "' is not a range as expected."));
            } else if (ordinal == 4) {
                return ErrorEval.REF_INVALID;
            } else {
                if (str4 == null) {
                    int ordinal2 = classifyCellReference.ordinal();
                    if (ordinal2 == 0) {
                        CellReference cellReference = new CellReference(str3);
                        return new LazyRefEval(cellReference.getRow(), cellReference.getCol(), sheetRangeEvaluator);
                    } else if (ordinal2 == 2 || ordinal2 == 3) {
                        return ErrorEval.REF_INVALID;
                    } else {
                        throw new IllegalStateException(a.b("Unexpected reference classification of '", str3, "'."));
                    }
                } else {
                    CellReference.NameType classifyCellReference2 = classifyCellReference(str3, spreadsheetVersion);
                    int ordinal3 = classifyCellReference2.ordinal();
                    if (ordinal3 == 1) {
                        throw new RuntimeException(a.b("Cannot evaluate '", str3, "'. Indirect evaluation of defined names not supported yet"));
                    } else if (ordinal3 == 4) {
                        return ErrorEval.REF_INVALID;
                    } else {
                        if (classifyCellReference2 != classifyCellReference) {
                            return ErrorEval.REF_INVALID;
                        }
                        int ordinal4 = classifyCellReference.ordinal();
                        if (ordinal4 == 0) {
                            CellReference cellReference2 = new CellReference(str3);
                            int row = cellReference2.getRow();
                            short col = cellReference2.getCol();
                            CellReference cellReference3 = new CellReference(str4);
                            int row2 = cellReference3.getRow();
                            s2 = col;
                            i3 = row;
                            s = cellReference3.getCol();
                            i2 = row2;
                        } else if (ordinal4 == 2) {
                            if (classifyCellReference2.equals(CellReference.NameType.COLUMN)) {
                                i6 = spreadsheetVersion.getLastRowIndex();
                                i5 = parseRowRef(str3);
                                i4 = parseRowRef(str4);
                            } else {
                                i6 = spreadsheetVersion.getLastRowIndex();
                                i5 = parseColRef(str3);
                                i4 = parseColRef(str4);
                            }
                            i2 = i6;
                            s2 = i5;
                            s = i4;
                            i3 = 0;
                        } else if (ordinal4 == 3) {
                            if (classifyCellReference2.equals(CellReference.NameType.ROW)) {
                                i8 = parseColRef(str3);
                                i7 = parseColRef(str4);
                                i9 = spreadsheetVersion.getLastColumnIndex();
                            } else {
                                i9 = spreadsheetVersion.getLastColumnIndex();
                                i8 = parseRowRef(str3);
                                i7 = parseRowRef(str4);
                            }
                            s = i9;
                            i3 = i8;
                            i2 = i7;
                            s2 = 0;
                        } else {
                            throw new IllegalStateException(a.b("Unexpected reference classification of '", str3, "'."));
                        }
                        return new LazyAreaEval(i3, s2, i2, s, sheetRangeEvaluator);
                    }
                }
            }
        } else {
            throw new RuntimeException("R1C1 style not supported yet");
        }
    }

    public ValueEval getNameXEval(NameXPtg nameXPtg) {
        EvaluationWorkbook.ExternalSheet externalSheet = this._workbook.getExternalSheet(nameXPtg.getSheetRefIndex());
        if (externalSheet == null || externalSheet.getWorkbookName() == null) {
            return getLocalNameXEval(nameXPtg);
        }
        return getExternalNameXEval(this._workbook.getExternalName(nameXPtg.getSheetRefIndex(), nameXPtg.getNameIndex()), externalSheet.getWorkbookName());
    }

    public ValueEval getRef3DEval(Ref3DPtg ref3DPtg) {
        return new LazyRefEval(ref3DPtg.getRow(), ref3DPtg.getColumn(), createExternSheetRefEvaluator(ref3DPtg.getExternSheetIndex()));
    }

    public ValueEval getRefEval(int i2, int i3) {
        return new LazyRefEval(i2, i3, getRefEvaluatorForCurrentSheet());
    }

    public SheetRangeEvaluator getRefEvaluatorForCurrentSheet() {
        return new SheetRangeEvaluator(this._sheetIndex, new SheetRefEvaluator(this._bookEvaluator, this._tracker, this._sheetIndex));
    }

    public int getRowIndex() {
        return this._rowIndex;
    }

    public int getSheetIndex() {
        return this._sheetIndex;
    }

    public EvaluationWorkbook getWorkbook() {
        return this._workbook;
    }

    public boolean isSingleValue() {
        return this._isSingleValue;
    }

    public OperationEvaluationContext(WorkbookEvaluator workbookEvaluator, EvaluationWorkbook evaluationWorkbook, int i2, int i3, int i4, EvaluationTracker evaluationTracker, boolean z) {
        this._bookEvaluator = workbookEvaluator;
        this._workbook = evaluationWorkbook;
        this._sheetIndex = i2;
        this._rowIndex = i3;
        this._columnIndex = i4;
        this._tracker = evaluationTracker;
        this._isSingleValue = z;
    }

    public SheetRangeEvaluator createExternSheetRefEvaluator(String str, String str2, int i2) {
        return createExternSheetRefEvaluator(this._workbook.getExternalSheet(str, str2, i2));
    }

    public ValueEval getArea3DEval(Area3DPxg area3DPxg) {
        return new LazyAreaEval(area3DPxg.getFirstRow(), area3DPxg.getFirstColumn(), area3DPxg.getLastRow(), area3DPxg.getLastColumn(), createExternSheetRefEvaluator(area3DPxg.getSheetName(), area3DPxg.getLastSheetName(), area3DPxg.getExternalWorkbookNumber()));
    }

    public ValueEval getRef3DEval(Ref3DPxg ref3DPxg) {
        return new LazyRefEval(ref3DPxg.getRow(), ref3DPxg.getColumn(), createExternSheetRefEvaluator(ref3DPxg.getSheetName(), ref3DPxg.getLastSheetName(), ref3DPxg.getExternalWorkbookNumber()));
    }

    public SheetRangeEvaluator createExternSheetRefEvaluator(int i2) {
        return createExternSheetRefEvaluator(this._workbook.getExternalSheet(i2));
    }

    public SheetRangeEvaluator createExternSheetRefEvaluator(EvaluationWorkbook.ExternalSheet externalSheet) {
        int i2;
        int i3;
        WorkbookEvaluator workbookEvaluator;
        if (externalSheet == null || externalSheet.getWorkbookName() == null) {
            workbookEvaluator = this._bookEvaluator;
            if (externalSheet == null) {
                i3 = 0;
            } else {
                i3 = this._workbook.getSheetIndex(externalSheet.getSheetName());
            }
            i2 = externalSheet instanceof EvaluationWorkbook.ExternalSheetRange ? this._workbook.getSheetIndex(((EvaluationWorkbook.ExternalSheetRange) externalSheet).getLastSheetName()) : -1;
        } else {
            String workbookName = externalSheet.getWorkbookName();
            try {
                workbookEvaluator = this._bookEvaluator.getOtherWorkbookEvaluator(workbookName);
                i3 = workbookEvaluator.getSheetIndex(externalSheet.getSheetName());
                i2 = externalSheet instanceof EvaluationWorkbook.ExternalSheetRange ? workbookEvaluator.getSheetIndex(((EvaluationWorkbook.ExternalSheetRange) externalSheet).getLastSheetName()) : -1;
                if (i3 < 0) {
                    StringBuilder b2 = a.b("Invalid sheet name '");
                    b2.append(externalSheet.getSheetName());
                    b2.append("' in bool '");
                    b2.append(workbookName);
                    b2.append("'.");
                    throw new RuntimeException(b2.toString());
                }
            } catch (CollaboratingWorkbooksEnvironment.WorkbookNotFoundException e2) {
                throw new RuntimeException(e2.getMessage(), e2);
            }
        }
        if (i2 == -1) {
            i2 = i3;
        }
        int i4 = (i2 - i3) + 1;
        SheetRefEvaluator[] sheetRefEvaluatorArr = new SheetRefEvaluator[i4];
        for (int i5 = 0; i5 < i4; i5++) {
            sheetRefEvaluatorArr[i5] = new SheetRefEvaluator(workbookEvaluator, this._tracker, i5 + i3);
        }
        return new SheetRangeEvaluator(i3, i2, sheetRefEvaluatorArr);
    }

    private ValueEval getLocalNameXEval(NameXPtg nameXPtg) {
        EvaluationName evaluationName;
        String resolveNameXText = this._workbook.resolveNameXText(nameXPtg);
        int indexOf = resolveNameXText.indexOf(33);
        if (indexOf > -1) {
            String substring = resolveNameXText.substring(0, indexOf);
            String substring2 = resolveNameXText.substring(indexOf + 1);
            EvaluationWorkbook evaluationWorkbook = this._workbook;
            evaluationName = evaluationWorkbook.getName(substring2, evaluationWorkbook.getSheetIndex(substring));
        } else {
            evaluationName = this._workbook.getName(resolveNameXText, -1);
        }
        if (evaluationName != null) {
            return new ExternalNameEval(evaluationName);
        }
        return new FunctionNameEval(resolveNameXText);
    }

    public ValueEval getNameXEval(NameXPxg nameXPxg) {
        EvaluationWorkbook.ExternalSheet externalSheet = this._workbook.getExternalSheet(nameXPxg.getSheetName(), null, nameXPxg.getExternalWorkbookNumber());
        if (externalSheet == null || externalSheet.getWorkbookName() == null) {
            return getLocalNameXEval(nameXPxg);
        }
        return getExternalNameXEval(this._workbook.getExternalName(nameXPxg.getNameName(), nameXPxg.getSheetName(), nameXPxg.getExternalWorkbookNumber()), externalSheet.getWorkbookName());
    }

    private SheetRefEvaluator createExternSheetRefEvaluator(String str, String str2) {
        WorkbookEvaluator workbookEvaluator;
        if (str == null) {
            workbookEvaluator = this._bookEvaluator;
        } else if (str2 != null) {
            try {
                workbookEvaluator = this._bookEvaluator.getOtherWorkbookEvaluator(str);
            } catch (CollaboratingWorkbooksEnvironment.WorkbookNotFoundException unused) {
                return null;
            }
        } else {
            throw new IllegalArgumentException("sheetName must not be null if workbookName is provided");
        }
        int sheetIndex = str2 == null ? this._sheetIndex : workbookEvaluator.getSheetIndex(str2);
        if (sheetIndex < 0) {
            return null;
        }
        return new SheetRefEvaluator(workbookEvaluator, this._tracker, sheetIndex);
    }
}
