package org.apache.poi.ss.formula.functions;

import org.apache.poi.ss.formula.OperationEvaluationContext;
import org.apache.poi.ss.formula.eval.AreaEval;
import org.apache.poi.ss.formula.eval.ErrorEval;
import org.apache.poi.ss.formula.eval.EvaluationException;
import org.apache.poi.ss.formula.eval.NumberEval;
import org.apache.poi.ss.formula.eval.RefEval;
import org.apache.poi.ss.formula.eval.ValueEval;
import org.apache.poi.ss.formula.functions.CountUtils;
import org.apache.poi.ss.formula.functions.Countif;

public abstract class Baseifs implements FreeRefFunction {
    public static double accumulate(AreaEval areaEval, int i2, int i3) {
        if (areaEval == null) {
            return 1.0d;
        }
        ValueEval relativeValue = areaEval.getRelativeValue(i2, i3);
        return relativeValue instanceof NumberEval ? ((NumberEval) relativeValue).getNumberValue() : NumericFunction.LOG_10_TO_BASE_e;
    }

    public static double aggregateMatchingCells(AreaEval areaEval, AreaEval[] areaEvalArr, CountUtils.I_MatchPredicate[] i_MatchPredicateArr) {
        boolean z;
        int height = areaEvalArr[0].getHeight();
        int width = areaEvalArr[0].getWidth();
        double d2 = NumericFunction.LOG_10_TO_BASE_e;
        for (int i2 = 0; i2 < height; i2++) {
            for (int i3 = 0; i3 < width; i3++) {
                int i4 = 0;
                while (true) {
                    if (i4 >= areaEvalArr.length) {
                        z = true;
                        break;
                    }
                    AreaEval areaEval2 = areaEvalArr[i4];
                    CountUtils.I_MatchPredicate i_MatchPredicate = i_MatchPredicateArr[i4];
                    if (i_MatchPredicate == null || !i_MatchPredicate.matches(areaEval2.getRelativeValue(i2, i3))) {
                        z = false;
                    } else {
                        i4++;
                    }
                }
                z = false;
                if (z) {
                    d2 += accumulate(areaEval, i2, i3);
                }
            }
        }
        return d2;
    }

    public static AreaEval convertRangeArg(ValueEval valueEval) {
        if (valueEval instanceof AreaEval) {
            return (AreaEval) valueEval;
        }
        if (valueEval instanceof RefEval) {
            return ((RefEval) valueEval).offset(0, 0, 0, 0);
        }
        throw new EvaluationException(ErrorEval.VALUE_INVALID);
    }

    public static void validateCriteria(CountUtils.I_MatchPredicate[] i_MatchPredicateArr) {
        for (CountUtils.I_MatchPredicate i_MatchPredicate : i_MatchPredicateArr) {
            if (i_MatchPredicate instanceof Countif.ErrorMatcher) {
                throw new EvaluationException(ErrorEval.valueOf(((Countif.ErrorMatcher) i_MatchPredicate).getValue()));
            }
        }
    }

    public static void validateCriteriaRanges(AreaEval areaEval, AreaEval[] areaEvalArr) {
        int height = areaEvalArr[0].getHeight();
        int width = areaEvalArr[0].getWidth();
        if (areaEval == null || (areaEval.getHeight() == height && areaEval.getWidth() == width)) {
            for (AreaEval areaEval2 : areaEvalArr) {
                if (areaEval2.getHeight() != height || areaEval2.getWidth() != width) {
                    throw EvaluationException.invalidValue();
                }
            }
            return;
        }
        throw EvaluationException.invalidValue();
    }

    /* JADX WARN: Type inference failed for: r0v0, types: [boolean, int] */
    /* JADX WARNING: Unknown variable types count: 1 */
    @Override // org.apache.poi.ss.formula.functions.FreeRefFunction
    public ValueEval evaluate(ValueEval[] valueEvalArr, OperationEvaluationContext operationEvaluationContext) {
        ?? hasInitialRange = hasInitialRange();
        if (valueEvalArr.length < hasInitialRange + 2 || valueEvalArr.length % 2 != hasInitialRange) {
            return ErrorEval.VALUE_INVALID;
        }
        AreaEval areaEval = null;
        int i2 = 0;
        if (hasInitialRange != 0) {
            try {
                areaEval = convertRangeArg(valueEvalArr[0]);
            } catch (EvaluationException e2) {
                return e2.getErrorEval();
            }
        }
        int length = (valueEvalArr.length - hasInitialRange) / 2;
        AreaEval[] areaEvalArr = new AreaEval[length];
        CountUtils.I_MatchPredicate[] i_MatchPredicateArr = new CountUtils.I_MatchPredicate[length];
        int i3 = hasInitialRange;
        while (i3 < valueEvalArr.length) {
            areaEvalArr[i2] = convertRangeArg(valueEvalArr[i3 == 1 ? 1 : 0]);
            i_MatchPredicateArr[i2] = Countif.createCriteriaPredicate(valueEvalArr[(i3 == 1 ? 1 : 0) + 1], operationEvaluationContext.getRowIndex(), operationEvaluationContext.getColumnIndex());
            i2++;
            i3 += 2;
        }
        validateCriteriaRanges(areaEval, areaEvalArr);
        validateCriteria(i_MatchPredicateArr);
        return new NumberEval(aggregateMatchingCells(areaEval, areaEvalArr, i_MatchPredicateArr));
    }

    public abstract boolean hasInitialRange();
}
