package org.apache.poi.ss.formula.functions;

import java.math.BigDecimal;
import java.math.RoundingMode;
import java.text.DecimalFormat;
import java.text.NumberFormat;
import java.util.Locale;
import org.apache.poi.ss.formula.eval.BoolEval;
import org.apache.poi.ss.formula.eval.ErrorEval;
import org.apache.poi.ss.formula.eval.EvaluationException;
import org.apache.poi.ss.formula.eval.NumberEval;
import org.apache.poi.ss.formula.eval.OperandResolver;
import org.apache.poi.ss.formula.eval.StringEval;
import org.apache.poi.ss.formula.eval.ValueEval;

public final class Fixed implements Function1Arg, Function2Arg, Function3Arg {
    /* JADX WARNING: Removed duplicated region for block: B:10:0x003d A[Catch:{ EvaluationException -> 0x0058 }] */
    /* JADX WARNING: Removed duplicated region for block: B:11:0x003f A[Catch:{ EvaluationException -> 0x0058 }] */
    /* JADX WARNING: Removed duplicated region for block: B:14:0x0045 A[Catch:{ EvaluationException -> 0x0058 }] */
    /* JADX WARNING: Removed duplicated region for block: B:15:0x0046 A[Catch:{ EvaluationException -> 0x0058 }] */
    private ValueEval fixed(ValueEval valueEval, ValueEval valueEval2, ValueEval valueEval3, int i2, int i3) {
        boolean z;
        try {
            BigDecimal bigDecimal = new BigDecimal(OperandResolver.coerceValueToDouble(OperandResolver.getSingleValue(valueEval, i2, i3)));
            int coerceValueToInt = OperandResolver.coerceValueToInt(OperandResolver.getSingleValue(valueEval2, i2, i3));
            Boolean coerceValueToBoolean = OperandResolver.coerceValueToBoolean(OperandResolver.getSingleValue(valueEval3, i2, i3), false);
            BigDecimal scale = bigDecimal.setScale(coerceValueToInt, RoundingMode.HALF_UP);
            DecimalFormat decimalFormat = (DecimalFormat) NumberFormat.getNumberInstance(Locale.US);
            if (coerceValueToBoolean != null) {
                if (coerceValueToBoolean.booleanValue()) {
                    z = false;
                    decimalFormat.setGroupingUsed(z);
                    decimalFormat.setMinimumFractionDigits(coerceValueToInt < 0 ? coerceValueToInt : 0);
                    if (coerceValueToInt >= 0) {
                        coerceValueToInt = 0;
                    }
                    decimalFormat.setMaximumFractionDigits(coerceValueToInt);
                    return new StringEval(decimalFormat.format(scale.doubleValue()));
                }
            }
            z = true;
            decimalFormat.setGroupingUsed(z);
            decimalFormat.setMinimumFractionDigits(coerceValueToInt < 0 ? coerceValueToInt : 0);
            if (coerceValueToInt >= 0) {
            }
            decimalFormat.setMaximumFractionDigits(coerceValueToInt);
            return new StringEval(decimalFormat.format(scale.doubleValue()));
        } catch (EvaluationException e2) {
            return e2.getErrorEval();
        }
    }

    @Override // org.apache.poi.ss.formula.functions.Function3Arg
    public ValueEval evaluate(int i2, int i3, ValueEval valueEval, ValueEval valueEval2, ValueEval valueEval3) {
        return fixed(valueEval, valueEval2, valueEval3, i2, i3);
    }

    @Override // org.apache.poi.ss.formula.functions.Function2Arg
    public ValueEval evaluate(int i2, int i3, ValueEval valueEval, ValueEval valueEval2) {
        return fixed(valueEval, valueEval2, BoolEval.FALSE, i2, i3);
    }

    @Override // org.apache.poi.ss.formula.functions.Function1Arg
    public ValueEval evaluate(int i2, int i3, ValueEval valueEval) {
        return fixed(valueEval, new NumberEval(2.0d), BoolEval.FALSE, i2, i3);
    }

    @Override // org.apache.poi.ss.formula.functions.Function
    public ValueEval evaluate(ValueEval[] valueEvalArr, int i2, int i3) {
        int length = valueEvalArr.length;
        if (length == 1) {
            return fixed(valueEvalArr[0], new NumberEval(2.0d), BoolEval.FALSE, i2, i3);
        }
        if (length == 2) {
            return fixed(valueEvalArr[0], valueEvalArr[1], BoolEval.FALSE, i2, i3);
        }
        if (length != 3) {
            return ErrorEval.VALUE_INVALID;
        }
        return fixed(valueEvalArr[0], valueEvalArr[1], valueEvalArr[2], i2, i3);
    }
}
