package org.apache.poi.ss.formula.functions;

import b.b.a.a.a;
import org.apache.poi.ss.formula.eval.AreaEval;
import org.apache.poi.ss.formula.eval.ErrorEval;
import org.apache.poi.ss.formula.eval.EvaluationException;
import org.apache.poi.ss.formula.eval.MissingArgEval;
import org.apache.poi.ss.formula.eval.OperandResolver;
import org.apache.poi.ss.formula.eval.RefEval;
import org.apache.poi.ss.formula.eval.ValueEval;
import org.apache.poi.ss.formula.function.FunctionMetadataReader;

public final class Offset implements Function {
    public static final int LAST_VALID_COLUMN_INDEX = 255;
    public static final int LAST_VALID_ROW_INDEX = 65535;

    public static final class LinearOffsetRange {
        public final int _length;
        public final int _offset;

        public LinearOffsetRange(int i2, int i3) {
            if (i3 != 0) {
                this._offset = i2;
                this._length = i3;
                return;
            }
            throw new RuntimeException("length may not be zero");
        }

        public short getFirstIndex() {
            return (short) this._offset;
        }

        public short getLastIndex() {
            return (short) ((this._offset + this._length) - 1);
        }

        public boolean isOutOfBounds(int i2, int i3) {
            if (this._offset >= i2 && getLastIndex() <= i3) {
                return false;
            }
            return true;
        }

        public LinearOffsetRange normaliseAndTranslate(int i2) {
            int i3 = this._length;
            if (i3 <= 0) {
                return new LinearOffsetRange(i2 + this._offset + i3 + 1, -i3);
            }
            if (i2 == 0) {
                return this;
            }
            return new LinearOffsetRange(i2 + this._offset, i3);
        }

        public String toString() {
            StringBuffer stringBuffer = new StringBuffer(64);
            a.a(LinearOffsetRange.class, stringBuffer, " [");
            stringBuffer.append(this._offset);
            stringBuffer.append(FunctionMetadataReader.ELLIPSIS);
            stringBuffer.append((int) getLastIndex());
            stringBuffer.append("]");
            return stringBuffer.toString();
        }
    }

    public static AreaEval createOffset(BaseRef baseRef, LinearOffsetRange linearOffsetRange, LinearOffsetRange linearOffsetRange2) {
        LinearOffsetRange normaliseAndTranslate = linearOffsetRange.normaliseAndTranslate(baseRef.getFirstRowIndex());
        LinearOffsetRange normaliseAndTranslate2 = linearOffsetRange2.normaliseAndTranslate(baseRef.getFirstColumnIndex());
        if (normaliseAndTranslate.isOutOfBounds(0, 65535)) {
            throw new EvaluationException(ErrorEval.REF_INVALID);
        } else if (!normaliseAndTranslate2.isOutOfBounds(0, 255)) {
            return baseRef.offset(linearOffsetRange.getFirstIndex(), linearOffsetRange.getLastIndex(), linearOffsetRange2.getFirstIndex(), linearOffsetRange2.getLastIndex());
        } else {
            throw new EvaluationException(ErrorEval.REF_INVALID);
        }
    }

    public static BaseRef evaluateBaseRef(ValueEval valueEval) {
        if (valueEval instanceof RefEval) {
            return new BaseRef((RefEval) valueEval);
        }
        if (valueEval instanceof AreaEval) {
            return new BaseRef((AreaEval) valueEval);
        }
        if (valueEval instanceof ErrorEval) {
            throw new EvaluationException((ErrorEval) valueEval);
        }
        throw new EvaluationException(ErrorEval.VALUE_INVALID);
    }

    public static int evaluateIntArg(ValueEval valueEval, int i2, int i3) {
        return OperandResolver.coerceValueToInt(OperandResolver.getSingleValue(valueEval, i2, i3));
    }

    /* JADX WARNING: Removed duplicated region for block: B:17:0x0048 A[Catch:{ EvaluationException -> 0x005d }] */
    @Override // org.apache.poi.ss.formula.functions.Function
    public ValueEval evaluate(ValueEval[] valueEvalArr, int i2, int i3) {
        if (valueEvalArr.length < 3 || valueEvalArr.length > 5) {
            return ErrorEval.VALUE_INVALID;
        }
        try {
            BaseRef evaluateBaseRef = evaluateBaseRef(valueEvalArr[0]);
            int evaluateIntArg = evaluateIntArg(valueEvalArr[1], i2, i3);
            int evaluateIntArg2 = evaluateIntArg(valueEvalArr[2], i2, i3);
            int height = evaluateBaseRef.getHeight();
            int width = evaluateBaseRef.getWidth();
            int length = valueEvalArr.length;
            if (length != 4) {
                if (length != 5) {
                    if (height != 0) {
                        if (width != 0) {
                            return createOffset(evaluateBaseRef, new LinearOffsetRange(evaluateIntArg, height), new LinearOffsetRange(evaluateIntArg2, width));
                        }
                    }
                    return ErrorEval.REF_INVALID;
                } else if (!(valueEvalArr[4] instanceof MissingArgEval)) {
                    width = evaluateIntArg(valueEvalArr[4], i2, i3);
                }
            }
            if (!(valueEvalArr[3] instanceof MissingArgEval)) {
                height = evaluateIntArg(valueEvalArr[3], i2, i3);
            }
            if (height != 0) {
            }
            return ErrorEval.REF_INVALID;
        } catch (EvaluationException e2) {
            return e2.getErrorEval();
        }
    }

    public static final class BaseRef {
        public final AreaEval _areaEval;
        public final int _firstColumnIndex;
        public final int _firstRowIndex;
        public final int _height;
        public final RefEval _refEval;
        public final int _width;

        public BaseRef(RefEval refEval) {
            this._refEval = refEval;
            this._areaEval = null;
            this._firstRowIndex = refEval.getRow();
            this._firstColumnIndex = refEval.getColumn();
            this._height = 1;
            this._width = 1;
        }

        public int getFirstColumnIndex() {
            return this._firstColumnIndex;
        }

        public int getFirstRowIndex() {
            return this._firstRowIndex;
        }

        public int getHeight() {
            return this._height;
        }

        public int getWidth() {
            return this._width;
        }

        public AreaEval offset(int i2, int i3, int i4, int i5) {
            RefEval refEval = this._refEval;
            if (refEval == null) {
                return this._areaEval.offset(i2, i3, i4, i5);
            }
            return refEval.offset(i2, i3, i4, i5);
        }

        public BaseRef(AreaEval areaEval) {
            this._refEval = null;
            this._areaEval = areaEval;
            this._firstRowIndex = areaEval.getFirstRow();
            this._firstColumnIndex = areaEval.getFirstColumn();
            this._height = (areaEval.getLastRow() - areaEval.getFirstRow()) + 1;
            this._width = (areaEval.getLastColumn() - areaEval.getFirstColumn()) + 1;
        }
    }
}
