package org.apache.poi.ss.usermodel;

import b.b.a.a.a;
import java.math.BigDecimal;
import java.math.RoundingMode;
import java.text.DateFormat;
import java.text.DateFormatSymbols;
import java.text.DecimalFormat;
import java.text.DecimalFormatSymbols;
import java.text.FieldPosition;
import java.text.Format;
import java.text.ParsePosition;
import java.text.SimpleDateFormat;
import java.util.ArrayList;
import java.util.Date;
import java.util.HashMap;
import java.util.Iterator;
import java.util.Locale;
import java.util.Map;
import java.util.Observable;
import java.util.Observer;
import java.util.regex.Matcher;
import java.util.regex.Pattern;
import org.apache.poi.openxml4j.opc.internal.ZipHelper;
import org.apache.poi.ss.format.CellFormat;
import org.apache.poi.ss.format.CellFormatResult;
import org.apache.poi.ss.formula.ConditionalFormattingEvaluator;
import org.apache.poi.ss.formula.functions.NumericFunction;
import org.apache.poi.ss.formula.ptg.UnaryMinusPtg;
import org.apache.poi.ss.util.NumberToTextConverter;
import org.apache.poi.util.LocaleUtil;
import org.apache.poi.util.POILogFactory;
import org.apache.poi.util.POILogger;
import org.apache.poi.xssf.usermodel.XSSFCell;
import org.apache.poi.xssf.usermodel.XSSFDataValidationConstraint;
import org.apache.xmlbeans.impl.common.NameUtil;

public class DataFormatter implements Observer {
    public static final Pattern alternateGrouping = Pattern.compile("([#0]([^.#0])[#0]{3})");
    public static final Pattern amPmPattern = Pattern.compile("((A|P)[M/P]*)", 2);
    public static final Pattern colorPattern = Pattern.compile("(\\[BLACK\\])|(\\[BLUE\\])|(\\[CYAN\\])|(\\[GREEN\\])|(\\[MAGENTA\\])|(\\[RED\\])|(\\[WHITE\\])|(\\[YELLOW\\])|(\\[COLOR\\s*\\d\\])|(\\[COLOR\\s*[0-5]\\d\\])", 2);
    public static final Pattern daysAsText = Pattern.compile("([d]{3,})", 2);
    public static final String defaultFractionFractionPartFormat = "#/##";
    public static final String defaultFractionWholePartFormat = "#";
    public static final Pattern fractionPattern = Pattern.compile("(?:([#\\d]+)\\s+)?(#+)\\s*\\/\\s*([#\\d]+)");
    public static final Pattern fractionStripper = Pattern.compile("(\"[^\"]*\")|([^ \\?#\\d\\/]+)");
    public static final String invalidDateTimeString;
    public static final Pattern localePatternGroup = Pattern.compile("(\\[\\$[^-\\]]*-[0-9A-Z]+\\])");
    public static POILogger logger = POILogFactory.getLogger(DataFormatter.class);
    public static final Pattern numPattern = Pattern.compile("[0#]+");
    public static final Pattern rangeConditionalPattern = Pattern.compile(".*\\[\\s*(>|>=|<|<=|=)\\s*[0-9]*\\.*[0-9].*");
    public DateFormatSymbols dateSymbols;
    public DecimalFormatSymbols decimalSymbols;
    public DateFormat defaultDateformat;
    public Format defaultNumFormat;
    public final boolean emulateCSV;
    public final Map<String, Format> formats;
    public Format generalNumberFormat;
    public Locale locale;
    public final LocaleChangeObservable localeChangedObservable;
    public boolean localeIsAdapting;

    /* renamed from: org.apache.poi.ss.usermodel.DataFormatter$1  reason: invalid class name */
    public static /* synthetic */ class AnonymousClass1 {
        public static final /* synthetic */ int[] $SwitchMap$org$apache$poi$ss$usermodel$CellType;

        /* JADX WARNING: Can't wrap try/catch for region: R(13:0|1|2|3|4|5|7|8|9|10|11|12|14) */
        /* JADX WARNING: Code restructure failed: missing block: B:15:?, code lost:
            return;
         */
        /* JADX WARNING: Failed to process nested try/catch */
        /* JADX WARNING: Missing exception handler attribute for start block: B:11:0x0024 */
        /* JADX WARNING: Missing exception handler attribute for start block: B:3:0x000e */
        /* JADX WARNING: Missing exception handler attribute for start block: B:9:0x001d */
        static {
            int[] iArr = new int[CellType.values().length];
            $SwitchMap$org$apache$poi$ss$usermodel$CellType = iArr;
            CellType cellType = CellType.NUMERIC;
            iArr[1] = 1;
            try {
                int[] iArr2 = $SwitchMap$org$apache$poi$ss$usermodel$CellType;
                CellType cellType2 = CellType.STRING;
                iArr2[2] = 2;
            } catch (NoSuchFieldError unused) {
            }
            int[] iArr3 = $SwitchMap$org$apache$poi$ss$usermodel$CellType;
            CellType cellType3 = CellType.BOOLEAN;
            iArr3[5] = 3;
            int[] iArr4 = $SwitchMap$org$apache$poi$ss$usermodel$CellType;
            CellType cellType4 = CellType.BLANK;
            iArr4[4] = 4;
            int[] iArr5 = $SwitchMap$org$apache$poi$ss$usermodel$CellType;
            CellType cellType5 = CellType.ERROR;
            iArr5[6] = 5;
        }
    }

    public final class CellFormatResultWrapper extends Format {
        public final CellFormatResult result;

        public /* synthetic */ CellFormatResultWrapper(DataFormatter dataFormatter, CellFormatResult cellFormatResult, AnonymousClass1 r3) {
            this(cellFormatResult);
        }

        public StringBuffer format(Object obj, StringBuffer stringBuffer, FieldPosition fieldPosition) {
            if (DataFormatter.this.emulateCSV) {
                stringBuffer.append(this.result.text);
                return stringBuffer;
            }
            stringBuffer.append(this.result.text.trim());
            return stringBuffer;
        }

        public Object parseObject(String str, ParsePosition parsePosition) {
            return null;
        }

        public CellFormatResultWrapper(CellFormatResult cellFormatResult) {
            this.result = cellFormatResult;
        }
    }

    public static final class ConstantStringFormat extends Format {
        public static final DecimalFormat df = DataFormatter.createIntegerOnlyFormat("##########");
        public final String str;

        public ConstantStringFormat(String str2) {
            this.str = str2;
        }

        public StringBuffer format(Object obj, StringBuffer stringBuffer, FieldPosition fieldPosition) {
            stringBuffer.append(this.str);
            return stringBuffer;
        }

        public Object parseObject(String str2, ParsePosition parsePosition) {
            return df.parseObject(str2, parsePosition);
        }
    }

    public static class InternalDecimalFormatWithScale extends Format {
        public static final BigDecimal ONE_THOUSAND = new BigDecimal(1000);
        public static final Pattern endsWithCommas = Pattern.compile("(,+)$");
        public final DecimalFormat df;
        public BigDecimal divider;

        public InternalDecimalFormatWithScale(String str, DecimalFormatSymbols decimalFormatSymbols) {
            DecimalFormat decimalFormat = new DecimalFormat(trimTrailingCommas(str), decimalFormatSymbols);
            this.df = decimalFormat;
            DataFormatter.setExcelStyleRoundingMode(decimalFormat);
            Matcher matcher = endsWithCommas.matcher(str);
            if (matcher.find()) {
                String group = matcher.group(1);
                BigDecimal bigDecimal = BigDecimal.ONE;
                for (int i2 = 0; i2 < group.length(); i2++) {
                    bigDecimal = bigDecimal.multiply(ONE_THOUSAND);
                }
                this.divider = bigDecimal;
                return;
            }
            this.divider = null;
        }

        private Object scaleInput(Object obj) {
            BigDecimal bigDecimal = this.divider;
            if (bigDecimal == null) {
                return obj;
            }
            if (obj instanceof BigDecimal) {
                return ((BigDecimal) obj).divide(bigDecimal, RoundingMode.HALF_UP);
            }
            if (obj instanceof Double) {
                return Double.valueOf(((Double) obj).doubleValue() / this.divider.doubleValue());
            }
            throw new UnsupportedOperationException();
        }

        public static final String trimTrailingCommas(String str) {
            return str.replaceAll(",+$", "");
        }

        public StringBuffer format(Object obj, StringBuffer stringBuffer, FieldPosition fieldPosition) {
            return this.df.format(scaleInput(obj), stringBuffer, fieldPosition);
        }

        public Object parseObject(String str, ParsePosition parsePosition) {
            throw new UnsupportedOperationException();
        }
    }

    public class LocaleChangeObservable extends Observable {
        public LocaleChangeObservable() {
        }

        public void checkForLocaleChange() {
            checkForLocaleChange(LocaleUtil.getUserLocale());
        }

        public /* synthetic */ LocaleChangeObservable(DataFormatter dataFormatter, AnonymousClass1 r2) {
            this();
        }

        public void checkForLocaleChange(Locale locale) {
            if (DataFormatter.this.localeIsAdapting && !locale.equals(DataFormatter.this.locale)) {
                super.setChanged();
                notifyObservers(locale);
            }
        }
    }

    static {
        StringBuilder sb = new StringBuilder();
        for (int i2 = 0; i2 < 255; i2++) {
            sb.append('#');
        }
        invalidDateTimeString = sb.toString();
    }

    public DataFormatter() {
        this(false);
    }

    private String cleanFormatForNumber(String str) {
        StringBuilder sb = new StringBuilder(str);
        int i2 = 0;
        if (this.emulateCSV) {
            int i3 = 0;
            while (i3 < sb.length()) {
                char charAt = sb.charAt(i3);
                if ((charAt == '_' || charAt == '*' || charAt == '?') && (i3 <= 0 || sb.charAt(i3 - 1) != '\\')) {
                    if (charAt == '?') {
                        sb.setCharAt(i3, ' ');
                    } else if (i3 < sb.length() - 1) {
                        if (charAt == '_') {
                            sb.setCharAt(i3 + 1, ' ');
                        } else {
                            sb.deleteCharAt(i3 + 1);
                        }
                        sb.deleteCharAt(i3);
                        i3--;
                    }
                }
                i3++;
            }
        } else {
            int i4 = 0;
            while (i4 < sb.length()) {
                char charAt2 = sb.charAt(i4);
                if ((charAt2 == '_' || charAt2 == '*') && (i4 <= 0 || sb.charAt(i4 - 1) != '\\')) {
                    if (i4 < sb.length() - 1) {
                        sb.deleteCharAt(i4 + 1);
                    }
                    sb.deleteCharAt(i4);
                    i4--;
                }
                i4++;
            }
        }
        while (i2 < sb.length()) {
            char charAt3 = sb.charAt(i2);
            if (charAt3 == '\\' || charAt3 == '\"') {
                sb.deleteCharAt(i2);
            } else {
                if (charAt3 == '+' && i2 > 0 && sb.charAt(i2 - 1) == 'E') {
                    sb.deleteCharAt(i2);
                }
                i2++;
            }
            i2--;
            i2++;
        }
        return sb.toString();
    }

    private Format createDateFormat(String str, double d2) {
        char c;
        String replaceAll = str.replaceAll("\\\\-", UnaryMinusPtg.MINUS).replaceAll("\\\\,", XSSFDataValidationConstraint.LIST_SEPARATOR).replaceAll("\\\\\\.", ".").replaceAll("\\\\ ", " ").replaceAll("\\\\/", ZipHelper.FORWARD_SLASH).replaceAll(";@", "").replaceAll("\"/\"", ZipHelper.FORWARD_SLASH).replace("\"\"", "'").replaceAll("\\\\T", "'T'");
        Matcher matcher = amPmPattern.matcher(replaceAll);
        boolean z = false;
        while (matcher.find()) {
            replaceAll = matcher.replaceAll("@");
            matcher = amPmPattern.matcher(replaceAll);
            z = true;
        }
        String replaceAll2 = replaceAll.replaceAll("@", "a");
        Matcher matcher2 = daysAsText.matcher(replaceAll2);
        if (matcher2.find()) {
            replaceAll2 = matcher2.replaceAll(matcher2.group(0).toUpperCase(Locale.ROOT).replaceAll("D", "E"));
        }
        StringBuilder sb = new StringBuilder();
        char[] charArray = replaceAll2.toCharArray();
        ArrayList arrayList = new ArrayList();
        int i2 = 0;
        boolean z2 = false;
        boolean z3 = true;
        while (i2 < charArray.length) {
            char c2 = charArray[i2];
            if (c2 == '\'') {
                sb.append(c2);
                do {
                    i2++;
                    if (i2 >= charArray.length) {
                        break;
                    }
                    c = charArray[i2];
                    sb.append(c);
                } while (c != '\'');
            } else {
                if (c2 == '[' && !z2) {
                    sb.append(c2);
                    z2 = true;
                } else if (c2 == ']' && z2) {
                    sb.append(c2);
                    z2 = false;
                } else if (z2) {
                    if (c2 == 'h' || c2 == 'H') {
                        sb.append('H');
                    } else if (c2 == 'm' || c2 == 'M') {
                        sb.append('m');
                    } else if (c2 == 's' || c2 == 'S') {
                        sb.append('s');
                    } else {
                        sb.append(c2);
                    }
                } else if (c2 == 'h' || c2 == 'H') {
                    if (z) {
                        sb.append('h');
                    } else {
                        sb.append('H');
                    }
                } else if (c2 != 'm' && c2 != 'M') {
                    if (c2 == 's' || c2 == 'S') {
                        sb.append('s');
                        Iterator it = arrayList.iterator();
                        while (it.hasNext()) {
                            int intValue = ((Integer) it.next()).intValue();
                            if (sb.charAt(intValue) == 'M') {
                                sb.replace(intValue, intValue + 1, "m");
                            }
                        }
                        arrayList.clear();
                    } else if (Character.isLetter(c2)) {
                        arrayList.clear();
                        if (c2 == 'y' || c2 == 'Y') {
                            sb.append('y');
                        } else if (c2 == 'd' || c2 == 'D') {
                            sb.append('d');
                        } else {
                            sb.append(c2);
                        }
                    } else {
                        if (Character.isWhitespace(c2)) {
                            arrayList.clear();
                        }
                        sb.append(c2);
                    }
                    z3 = true;
                } else if (z3) {
                    sb.append('M');
                    arrayList.add(Integer.valueOf(sb.length() - 1));
                } else {
                    sb.append('m');
                }
                z3 = false;
            }
            i2++;
        }
        String sb2 = sb.toString();
        try {
            return new ExcelStyleDateFormatter(sb2, this.dateSymbols);
        } catch (IllegalArgumentException e2) {
            logger.log(1, a.b("Formatting failed for format ", sb2, ", falling back"), e2);
            return getDefaultFormat(d2);
        }
    }

    public static DecimalFormat createIntegerOnlyFormat(String str) {
        DecimalFormat decimalFormat = new DecimalFormat(str, DecimalFormatSymbols.getInstance(Locale.ROOT));
        decimalFormat.setParseIntegerOnly(true);
        return decimalFormat;
    }

    private Format createNumberFormat(String str, double d2) {
        char charAt;
        String cleanFormatForNumber = cleanFormatForNumber(str);
        DecimalFormatSymbols decimalFormatSymbols = this.decimalSymbols;
        Matcher matcher = alternateGrouping.matcher(cleanFormatForNumber);
        if (matcher.find() && (charAt = matcher.group(2).charAt(0)) != ',') {
            decimalFormatSymbols = DecimalFormatSymbols.getInstance(this.locale);
            decimalFormatSymbols.setGroupingSeparator(charAt);
            String group = matcher.group(1);
            cleanFormatForNumber = cleanFormatForNumber.replace(group, group.replace(charAt, ','));
        }
        try {
            return new InternalDecimalFormatWithScale(cleanFormatForNumber, decimalFormatSymbols);
        } catch (IllegalArgumentException e2) {
            logger.log(1, a.b("Formatting failed for format ", str, ", falling back"), e2);
            return getDefaultFormat(d2);
        }
    }

    private Format getFormat(Cell cell, ConditionalFormattingEvaluator conditionalFormattingEvaluator) {
        ExcelNumberFormat from;
        if (cell == null || (from = ExcelNumberFormat.from(cell, conditionalFormattingEvaluator)) == null) {
            return null;
        }
        int idx = from.getIdx();
        String format = from.getFormat();
        if (format == null || format.trim().length() == 0) {
            return null;
        }
        return getFormat(cell.getNumericCellValue(), idx, format);
    }

    private String getFormattedDateString(Cell cell, ConditionalFormattingEvaluator conditionalFormattingEvaluator) {
        Format format = getFormat(cell, conditionalFormattingEvaluator);
        if (format instanceof ExcelStyleDateFormatter) {
            ((ExcelStyleDateFormatter) format).setDateToBeFormatted(cell.getNumericCellValue());
        }
        return performDateFormatting(cell.getDateCellValue(), format);
    }

    private String getFormattedNumberString(Cell cell, ConditionalFormattingEvaluator conditionalFormattingEvaluator) {
        Format format = getFormat(cell, conditionalFormattingEvaluator);
        double numericCellValue = cell.getNumericCellValue();
        if (format == null) {
            return String.valueOf(numericCellValue);
        }
        return format.format(new Double(numericCellValue)).replaceFirst("E(\\d)", "E+$1");
    }

    private String performDateFormatting(Date date, Format format) {
        if (format == null) {
            format = this.defaultDateformat;
        }
        return format.format(date);
    }

    public static void setExcelStyleRoundingMode(DecimalFormat decimalFormat) {
        setExcelStyleRoundingMode(decimalFormat, RoundingMode.HALF_UP);
    }

    public void addFormat(String str, Format format) {
        this.formats.put(str, format);
    }

    public Format createFormat(Cell cell) {
        return createFormat(cell.getNumericCellValue(), cell.getCellStyle().getDataFormat(), cell.getCellStyle().getDataFormatString());
    }

    public String formatCellValue(Cell cell) {
        return formatCellValue(cell, null);
    }

    public String formatRawCellContents(double d2, int i2, String str) {
        return formatRawCellContents(d2, i2, str, false);
    }

    public Format getDefaultFormat(Cell cell) {
        return getDefaultFormat(cell.getNumericCellValue());
    }

    public Observable getLocaleChangedObservable() {
        return this.localeChangedObservable;
    }

    public void setDefaultNumberFormat(Format format) {
        for (Map.Entry<String, Format> entry : this.formats.entrySet()) {
            if (entry.getValue() == this.generalNumberFormat) {
                entry.setValue(format);
            }
        }
        this.defaultNumFormat = format;
    }

    public void update(Observable observable, Object obj) {
        if (obj instanceof Locale) {
            Locale locale2 = (Locale) obj;
            if (this.localeIsAdapting && !locale2.equals(this.locale)) {
                this.locale = locale2;
                this.dateSymbols = DateFormatSymbols.getInstance(locale2);
                this.decimalSymbols = DecimalFormatSymbols.getInstance(this.locale);
                this.generalNumberFormat = new ExcelGeneralNumberFormat(this.locale);
                SimpleDateFormat simpleDateFormat = new SimpleDateFormat("EEE MMM dd HH:mm:ss zzz yyyy", this.dateSymbols);
                this.defaultDateformat = simpleDateFormat;
                simpleDateFormat.setTimeZone(LocaleUtil.getUserTimeZone());
                this.formats.clear();
                Format format = ZipPlusFourFormat.instance;
                addFormat("00000\\-0000", format);
                addFormat("00000-0000", format);
                Format format2 = PhoneFormat.instance;
                addFormat("[<=9999999]###\\-####;\\(###\\)\\ ###\\-####", format2);
                addFormat("[<=9999999]###-####;(###) ###-####", format2);
                addFormat("###\\-####;\\(###\\)\\ ###\\-####", format2);
                addFormat("###-####;(###) ###-####", format2);
                Format format3 = SSNFormat.instance;
                addFormat("000\\-00\\-0000", format3);
                addFormat("000-00-0000", format3);
            }
        }
    }

    public static final class SSNFormat extends Format {
        public static final DecimalFormat df = DataFormatter.createIntegerOnlyFormat("000000000");
        public static final Format instance = new SSNFormat();

        public static String format(Number number) {
            String format = df.format(number);
            return format.substring(0, 3) + NameUtil.HYPHEN + format.substring(3, 5) + NameUtil.HYPHEN + format.substring(5, 9);
        }

        public Object parseObject(String str, ParsePosition parsePosition) {
            return df.parseObject(str, parsePosition);
        }

        public StringBuffer format(Object obj, StringBuffer stringBuffer, FieldPosition fieldPosition) {
            stringBuffer.append(format((Number) obj));
            return stringBuffer;
        }
    }

    public static final class ZipPlusFourFormat extends Format {
        public static final DecimalFormat df = DataFormatter.createIntegerOnlyFormat("000000000");
        public static final Format instance = new ZipPlusFourFormat();

        public static String format(Number number) {
            String format = df.format(number);
            return format.substring(0, 5) + NameUtil.HYPHEN + format.substring(5, 9);
        }

        public Object parseObject(String str, ParsePosition parsePosition) {
            return df.parseObject(str, parsePosition);
        }

        public StringBuffer format(Object obj, StringBuffer stringBuffer, FieldPosition fieldPosition) {
            stringBuffer.append(format((Number) obj));
            return stringBuffer;
        }
    }

    public DataFormatter(boolean z) {
        this(LocaleUtil.getUserLocale(), true, z);
    }

    private Format getDefaultFormat(double d2) {
        this.localeChangedObservable.checkForLocaleChange();
        Format format = this.defaultNumFormat;
        if (format != null) {
            return format;
        }
        return this.generalNumberFormat;
    }

    public static void setExcelStyleRoundingMode(DecimalFormat decimalFormat, RoundingMode roundingMode) {
        decimalFormat.setRoundingMode(roundingMode);
    }

    public String formatCellValue(Cell cell, FormulaEvaluator formulaEvaluator) {
        return formatCellValue(cell, formulaEvaluator, null);
    }

    public String formatRawCellContents(double d2, int i2, String str, boolean z) {
        String str2;
        this.localeChangedObservable.checkForLocaleChange();
        if (DateUtil.isADateFormat(i2, str)) {
            if (DateUtil.isValidExcelDate(d2)) {
                Format format = getFormat(d2, i2, str);
                if (format instanceof ExcelStyleDateFormatter) {
                    ((ExcelStyleDateFormatter) format).setDateToBeFormatted(d2);
                }
                return performDateFormatting(DateUtil.getJavaDate(d2, z), format);
            } else if (this.emulateCSV) {
                return invalidDateTimeString;
            }
        }
        Format format2 = getFormat(d2, i2, str);
        if (format2 == null) {
            return String.valueOf(d2);
        }
        String text = NumberToTextConverter.toText(d2);
        if (text.indexOf(69) > -1) {
            str2 = format2.format(new Double(d2));
        } else {
            str2 = format2.format(new BigDecimal(text));
        }
        return (str2.indexOf(69) <= -1 || str2.contains("E-")) ? str2 : str2.replaceFirst("E", "E+");
    }

    public DataFormatter(Locale locale2) {
        this(locale2, false);
    }

    public String formatCellValue(Cell cell, FormulaEvaluator formulaEvaluator, ConditionalFormattingEvaluator conditionalFormattingEvaluator) {
        this.localeChangedObservable.checkForLocaleChange();
        if (cell == null) {
            return "";
        }
        CellType cellTypeEnum = cell.getCellTypeEnum();
        if (cellTypeEnum == CellType.FORMULA) {
            if (formulaEvaluator == null) {
                return cell.getCellFormula();
            }
            cellTypeEnum = formulaEvaluator.evaluateFormulaCellEnum(cell);
        }
        int ordinal = cellTypeEnum.ordinal();
        if (ordinal != 1) {
            if (ordinal == 2) {
                return cell.getRichStringCellValue().getString();
            }
            if (ordinal == 4) {
                return "";
            }
            if (ordinal == 5) {
                return cell.getBooleanCellValue() ? XSSFCell.TRUE : XSSFCell.FALSE;
            }
            if (ordinal == 6) {
                return FormulaError.forInt(cell.getErrorCellValue()).getString();
            }
            throw new RuntimeException("Unexpected celltype (" + cellTypeEnum + ")");
        } else if (DateUtil.isCellDateFormatted(cell, conditionalFormattingEvaluator)) {
            return getFormattedDateString(cell, conditionalFormattingEvaluator);
        } else {
            return getFormattedNumberString(cell, conditionalFormattingEvaluator);
        }
    }

    public DataFormatter(Locale locale2, boolean z) {
        this(locale2, false, z);
    }

    private Format createFormat(double d2, int i2, String str) {
        int i3;
        String group;
        int indexOf;
        this.localeChangedObservable.checkForLocaleChange();
        Matcher matcher = colorPattern.matcher(str);
        while (true) {
            i3 = 0;
            if (!matcher.find() || (indexOf = str.indexOf((group = matcher.group()))) == -1) {
                break;
            }
            String str2 = str.substring(0, indexOf) + str.substring(group.length() + indexOf);
            if (str2.equals(str)) {
                break;
            }
            matcher = colorPattern.matcher(str2);
            str = str2;
        }
        Matcher matcher2 = localePatternGroup.matcher(str);
        while (matcher2.find()) {
            String group2 = matcher2.group();
            String substring = group2.substring(group2.indexOf(36) + 1, group2.indexOf(45));
            if (substring.indexOf(36) > -1) {
                substring = substring.substring(0, substring.indexOf(36)) + '\\' + substring.substring(substring.indexOf(36), substring.length());
            }
            str = matcher2.replaceAll(substring);
            matcher2 = localePatternGroup.matcher(str);
        }
        if (str == null || str.trim().length() == 0) {
            return getDefaultFormat(d2);
        }
        if ("General".equalsIgnoreCase(str) || "@".equals(str)) {
            return this.generalNumberFormat;
        }
        if (DateUtil.isADateFormat(i2, str) && DateUtil.isValidExcelDate(d2)) {
            return createDateFormat(str, d2);
        }
        if (str.contains("#/") || str.contains("?/")) {
            String[] split = str.split(";");
            int length = split.length;
            while (true) {
                String str3 = defaultFractionWholePartFormat;
                if (i3 >= length) {
                    return new FractionFormat(str3, defaultFractionFractionPartFormat);
                }
                Matcher matcher3 = fractionPattern.matcher(fractionStripper.matcher(split[i3].replaceAll("\\?", str3)).replaceAll(" ").replaceAll(" +", " "));
                if (matcher3.find()) {
                    if (matcher3.group(1) == null) {
                        str3 = "";
                    }
                    return new FractionFormat(str3, matcher3.group(3));
                }
                i3++;
            }
        } else if (numPattern.matcher(str).find()) {
            return createNumberFormat(str, d2);
        } else {
            if (this.emulateCSV) {
                return new ConstantStringFormat(cleanFormatForNumber(str));
            }
            return null;
        }
    }

    public DataFormatter(Locale locale2, boolean z, boolean z2) {
        this.formats = new HashMap();
        LocaleChangeObservable localeChangeObservable = new LocaleChangeObservable(this, null);
        this.localeChangedObservable = localeChangeObservable;
        this.localeIsAdapting = true;
        localeChangeObservable.addObserver(this);
        this.localeChangedObservable.checkForLocaleChange(locale2);
        this.localeIsAdapting = z;
        this.emulateCSV = z2;
    }

    private Format getFormat(double d2, int i2, String str) {
        this.localeChangedObservable.checkForLocaleChange();
        if (str.contains(";") && (str.indexOf(59) != str.lastIndexOf(59) || rangeConditionalPattern.matcher(str).matches())) {
            try {
                CellFormat instance = CellFormat.getInstance(this.locale, str);
                Double valueOf = Double.valueOf(d2);
                Date date = valueOf;
                if (DateUtil.isADateFormat(i2, str)) {
                    int i3 = (valueOf.doubleValue() > NumericFunction.LOG_10_TO_BASE_e ? 1 : (valueOf.doubleValue() == NumericFunction.LOG_10_TO_BASE_e ? 0 : -1));
                    date = valueOf;
                    if (i3 != 0) {
                        date = DateUtil.getJavaDate(d2);
                    }
                }
                return new CellFormatResultWrapper(this, instance.apply(date), null);
            } catch (Exception e2) {
                logger.log(5, a.b("Formatting failed for format ", str, ", falling back"), e2);
            }
        }
        if (this.emulateCSV && d2 == NumericFunction.LOG_10_TO_BASE_e && str.contains(defaultFractionWholePartFormat) && !str.contains("0")) {
            str = str.replaceAll(defaultFractionWholePartFormat, "");
        }
        Format format = this.formats.get(str);
        if (format != null) {
            return format;
        }
        if ("General".equalsIgnoreCase(str) || "@".equals(str)) {
            return this.generalNumberFormat;
        }
        Format createFormat = createFormat(d2, i2, str);
        this.formats.put(str, createFormat);
        return createFormat;
    }

    public static final class PhoneFormat extends Format {
        public static final DecimalFormat df = DataFormatter.createIntegerOnlyFormat("##########");
        public static final Format instance = new PhoneFormat();

        public static String format(Number number) {
            String format = df.format(number);
            StringBuilder sb = new StringBuilder();
            int length = format.length();
            if (length <= 4) {
                return format;
            }
            int i2 = length - 4;
            String substring = format.substring(i2, length);
            int i3 = length - 7;
            String substring2 = format.substring(Math.max(0, i3), i2);
            String substring3 = format.substring(Math.max(0, length - 10), Math.max(0, i3));
            if (substring3.trim().length() > 0) {
                sb.append('(');
                sb.append(substring3);
                sb.append(") ");
            }
            if (substring2.trim().length() > 0) {
                sb.append(substring2);
                sb.append(NameUtil.HYPHEN);
            }
            sb.append(substring);
            return sb.toString();
        }

        public Object parseObject(String str, ParsePosition parsePosition) {
            return df.parseObject(str, parsePosition);
        }

        public StringBuffer format(Object obj, StringBuffer stringBuffer, FieldPosition fieldPosition) {
            stringBuffer.append(format((Number) obj));
            return stringBuffer;
        }
    }
}
