package org.apache.poi.ss.util;

import java.awt.Dimension;
import java.awt.image.BufferedImage;
import java.io.ByteArrayInputStream;
import java.io.IOException;
import java.io.InputStream;
import javax.imageio.ImageIO;
import javax.imageio.ImageReader;
import javax.imageio.stream.ImageInputStream;
import org.apache.poi.hssf.usermodel.HSSFClientAnchor;
import org.apache.poi.ss.usermodel.ClientAnchor;
import org.apache.poi.ss.usermodel.Picture;
import org.apache.poi.ss.usermodel.PictureData;
import org.apache.poi.ss.usermodel.Row;
import org.apache.poi.ss.usermodel.Sheet;
import org.apache.poi.util.POILogFactory;
import org.apache.poi.util.POILogger;
import org.apache.poi.util.Units;
import org.w3c.dom.Element;
import org.w3c.dom.NodeList;

public class ImageUtils {
    public static final int PIXEL_DPI = 96;
    public static final POILogger logger = POILogFactory.getLogger(ImageUtils.class);

    public static Dimension getDimensionFromAnchor(Picture picture) {
        double d2;
        double d3;
        double d4;
        double d5;
        double d6;
        ClientAnchor clientAnchor = picture.getClientAnchor();
        boolean z = clientAnchor instanceof HSSFClientAnchor;
        Sheet sheet = picture.getSheet();
        short col1 = clientAnchor.getCol1();
        int i2 = col1 + 1;
        double columnWidthInPixels = (double) sheet.getColumnWidthInPixels(col1);
        if (z) {
            d2 = (1.0d - (((double) clientAnchor.getDx1()) / 1024.0d)) * columnWidthInPixels;
        } else {
            d2 = columnWidthInPixels - (((double) clientAnchor.getDx1()) / 9525.0d);
        }
        while (i2 < clientAnchor.getCol2()) {
            d2 += (double) sheet.getColumnWidthInPixels(i2);
            i2++;
        }
        if (z) {
            d3 = ((double) (sheet.getColumnWidthInPixels(i2) * ((float) clientAnchor.getDx2()))) / 1024.0d;
        } else {
            d3 = ((double) clientAnchor.getDx2()) / 9525.0d;
        }
        double d7 = d3 + d2;
        int row1 = clientAnchor.getRow1();
        int i3 = row1 + 1;
        double rowHeightInPixels = getRowHeightInPixels(sheet, row1);
        if (z) {
            d4 = (1.0d - (((double) clientAnchor.getDy1()) / 256.0d)) * rowHeightInPixels;
        } else {
            d4 = rowHeightInPixels - (((double) clientAnchor.getDy1()) / 9525.0d);
        }
        while (i3 < clientAnchor.getRow2()) {
            d4 += getRowHeightInPixels(sheet, i3);
            i3++;
        }
        if (z) {
            d6 = ((getRowHeightInPixels(sheet, i3) * ((double) clientAnchor.getDy2())) / 256.0d) + d4;
            d5 = 9525.0d;
        } else {
            d5 = 9525.0d;
            d6 = (((double) clientAnchor.getDy2()) / 9525.0d) + d4;
        }
        return new Dimension((int) Math.rint(d7 * d5), (int) Math.rint(d6 * d5));
    }

    /* JADX INFO: finally extract failed */
    public static Dimension getImageDimension(InputStream inputStream, int i2) {
        Dimension dimension = new Dimension();
        if (i2 == 5 || i2 == 6 || i2 == 7) {
            try {
                ImageInputStream createImageInputStream = ImageIO.createImageInputStream(inputStream);
                try {
                    ImageReader imageReader = (ImageReader) ImageIO.getImageReaders(createImageInputStream).next();
                    try {
                        imageReader.setInput(createImageInputStream);
                        BufferedImage read = imageReader.read(0);
                        int[] resolution = getResolution(imageReader);
                        if (resolution[0] == 0) {
                            resolution[0] = 96;
                        }
                        if (resolution[1] == 0) {
                            resolution[1] = 96;
                        }
                        dimension.width = (read.getWidth() * 96) / resolution[0];
                        dimension.height = (read.getHeight() * 96) / resolution[1];
                        imageReader.dispose();
                    } catch (Throwable th) {
                        imageReader.dispose();
                        throw th;
                    }
                } finally {
                    createImageInputStream.close();
                }
            } catch (IOException e2) {
                logger.log(5, e2);
            }
        } else {
            logger.log(5, "Only JPEG, PNG and DIB pictures can be automatically sized");
        }
        return dimension;
    }

    public static int[] getResolution(ImageReader imageReader) {
        Element element = (Element) imageReader.getImageMetadata(0).getAsTree("javax_imageio_1.0");
        NodeList elementsByTagName = element.getElementsByTagName("HorizontalPixelSize");
        int i2 = 96;
        int parseFloat = (elementsByTagName == null || elementsByTagName.getLength() != 1) ? 96 : (int) (25.4d / ((double) Float.parseFloat(((Element) elementsByTagName.item(0)).getAttribute("value"))));
        NodeList elementsByTagName2 = element.getElementsByTagName("VerticalPixelSize");
        if (elementsByTagName2 != null && elementsByTagName2.getLength() == 1) {
            i2 = (int) (25.4d / ((double) Float.parseFloat(((Element) elementsByTagName2.item(0)).getAttribute("value"))));
        }
        return new int[]{parseFloat, i2};
    }

    public static double getRowHeightInPixels(Sheet sheet, int i2) {
        Row row = sheet.getRow(i2);
        return ((double) Units.toEMU((double) (row == null ? sheet.getDefaultRowHeightInPoints() : row.getHeightInPoints()))) / 9525.0d;
    }

    /* JADX WARNING: Code restructure failed: missing block: B:21:0x00a3, code lost:
        if (r7 < 0) goto L_0x00a5;
     */
    public static Dimension setPreferredSize(Picture picture, double d2, double d3) {
        double d4;
        int i2;
        double d5;
        Sheet sheet;
        double d6;
        int i3;
        int i4;
        ClientAnchor clientAnchor = picture.getClientAnchor();
        boolean z = clientAnchor instanceof HSSFClientAnchor;
        PictureData pictureData = picture.getPictureData();
        Sheet sheet2 = picture.getSheet();
        Dimension imageDimension = getImageDimension(new ByteArrayInputStream(pictureData.getData()), pictureData.getPictureType());
        Dimension dimensionFromAnchor = getDimensionFromAnchor(picture);
        double width = d2 == Double.MAX_VALUE ? imageDimension.getWidth() : (dimensionFromAnchor.getWidth() / 9525.0d) * d2;
        double height = d3 == Double.MAX_VALUE ? imageDimension.getHeight() : (dimensionFromAnchor.getHeight() / 9525.0d) * d3;
        short col1 = clientAnchor.getCol1();
        int i5 = col1 + 1;
        double columnWidthInPixels = (double) sheet2.getColumnWidthInPixels(col1);
        if (z) {
            d4 = (1.0d - (((double) clientAnchor.getDx1()) / 1024.0d)) * columnWidthInPixels;
        } else {
            d4 = columnWidthInPixels - (((double) clientAnchor.getDx1()) / 9525.0d);
        }
        while (d4 < width) {
            d4 += (double) sheet2.getColumnWidthInPixels(i5);
            i5++;
        }
        if (d4 > width) {
            i5--;
            double columnWidthInPixels2 = (double) sheet2.getColumnWidthInPixels(i5);
            double d7 = d4 - width;
            i2 = z ? (int) (((columnWidthInPixels2 - d7) / columnWidthInPixels2) * 1024.0d) : (int) ((columnWidthInPixels2 - d7) * 9525.0d);
        }
        i2 = 0;
        clientAnchor.setCol2(i5);
        clientAnchor.setDx2(i2);
        int row1 = clientAnchor.getRow1();
        int i6 = row1 + 1;
        double rowHeightInPixels = getRowHeightInPixels(sheet2, row1);
        if (z) {
            sheet = sheet2;
            d5 = (1.0d - (((double) clientAnchor.getDy1()) / 256.0d)) * rowHeightInPixels;
        } else {
            sheet = sheet2;
            d5 = rowHeightInPixels - (((double) clientAnchor.getDy1()) / 9525.0d);
        }
        while (d5 < height) {
            d5 += getRowHeightInPixels(sheet, i6);
            i6++;
        }
        if (d5 > height) {
            i6--;
            double rowHeightInPixels2 = getRowHeightInPixels(sheet, i6);
            double d8 = d5 - height;
            if (z) {
                i4 = (int) (((rowHeightInPixels2 - d8) / rowHeightInPixels2) * 256.0d);
                d6 = 9525.0d;
            } else {
                d6 = 9525.0d;
                i4 = (int) ((rowHeightInPixels2 - d8) * 9525.0d);
            }
            if (i4 >= 0) {
                i3 = i4;
                clientAnchor.setRow2(i6);
                clientAnchor.setDy2(i3);
                return new Dimension((int) Math.round(width * d6), (int) Math.round(height * d6));
            }
        } else {
            d6 = 9525.0d;
        }
        i3 = 0;
        clientAnchor.setRow2(i6);
        clientAnchor.setDy2(i3);
        return new Dimension((int) Math.round(width * d6), (int) Math.round(height * d6));
    }
}
