package org.apache.poi.util;

import java.io.FilterInputStream;
import java.io.InputStream;
import java.nio.charset.Charset;
import java.util.Arrays;

@Internal
public class ReplacingInputStream extends FilterInputStream {
    public static final Charset UTF8 = Charset.forName("UTF-8");
    public final int[] buf;
    public int matchedIndex;
    public final byte[] pattern;
    public int replacedIndex;
    public final byte[] replacement;
    public State state;
    public int unbufferIndex;

    /* renamed from: org.apache.poi.util.ReplacingInputStream$1  reason: invalid class name */
    public static /* synthetic */ class AnonymousClass1 {
        public static final /* synthetic */ int[] $SwitchMap$org$apache$poi$util$ReplacingInputStream$State;

        /* JADX WARNING: Failed to process nested try/catch */
        /* JADX WARNING: Missing exception handler attribute for start block: B:11:0x001d */
        static {
            int[] iArr = new int[State.values().length];
            $SwitchMap$org$apache$poi$util$ReplacingInputStream$State = iArr;
            try {
                State state = State.NOT_MATCHED;
                iArr[0] = 1;
            } catch (NoSuchFieldError unused) {
            }
            try {
                int[] iArr2 = $SwitchMap$org$apache$poi$util$ReplacingInputStream$State;
                State state2 = State.MATCHING;
                iArr2[1] = 2;
            } catch (NoSuchFieldError unused2) {
            }
            int[] iArr3 = $SwitchMap$org$apache$poi$util$ReplacingInputStream$State;
            State state3 = State.REPLACING;
            iArr3[2] = 3;
            try {
                int[] iArr4 = $SwitchMap$org$apache$poi$util$ReplacingInputStream$State;
                State state4 = State.UNBUFFER;
                iArr4[3] = 4;
            } catch (NoSuchFieldError unused3) {
            }
        }
    }

    public enum State {
        NOT_MATCHED,
        MATCHING,
        REPLACING,
        UNBUFFER
    }

    /* JADX INFO: this call moved to the top of the method (can break code semantics) */
    public ReplacingInputStream(InputStream inputStream, String str, String str2) {
        this(inputStream, str.getBytes(UTF8), str2 == null ? null : str2.getBytes(UTF8));
    }

    @Override // java.io.FilterInputStream, java.io.InputStream
    public int read(byte[] bArr, int i2, int i3) {
        if (bArr == null) {
            throw null;
        } else if (i2 < 0 || i3 < 0 || i3 > bArr.length - i2) {
            throw new IndexOutOfBoundsException();
        } else if (i3 == 0) {
            return 0;
        } else {
            int read = read();
            if (read == -1) {
                return -1;
            }
            bArr[i2] = (byte) read;
            int i4 = 1;
            while (i4 < i3) {
                int read2 = read();
                if (read2 == -1) {
                    break;
                }
                bArr[i2 + i4] = (byte) read2;
                i4++;
            }
            return i4;
        }
    }

    public String toString() {
        return this.state.name() + " " + this.matchedIndex + " " + this.replacedIndex + " " + this.unbufferIndex;
    }

    public ReplacingInputStream(InputStream inputStream, byte[] bArr, byte[] bArr2) {
        super(inputStream);
        this.matchedIndex = 0;
        this.unbufferIndex = 0;
        this.replacedIndex = 0;
        this.state = State.NOT_MATCHED;
        if (bArr == null || bArr.length == 0) {
            throw new IllegalArgumentException("pattern length should be > 0");
        }
        this.pattern = bArr;
        this.replacement = bArr2;
        this.buf = new int[bArr.length];
    }

    @Override // java.io.FilterInputStream, java.io.InputStream
    public int read(byte[] bArr) {
        return read(bArr, 0, bArr.length);
    }

    @Override // java.io.FilterInputStream, java.io.InputStream
    public int read() {
        int ordinal = this.state.ordinal();
        if (ordinal == 1) {
            int read = super.read();
            byte[] bArr = this.pattern;
            int i2 = this.matchedIndex;
            if (bArr[i2] == read) {
                int[] iArr = this.buf;
                int i3 = i2 + 1;
                this.matchedIndex = i3;
                iArr[i2] = read;
                if (i3 == bArr.length) {
                    byte[] bArr2 = this.replacement;
                    if (bArr2 == null || bArr2.length == 0) {
                        this.state = State.NOT_MATCHED;
                        this.matchedIndex = 0;
                    } else {
                        this.state = State.REPLACING;
                        this.replacedIndex = 0;
                    }
                }
            } else {
                int[] iArr2 = this.buf;
                this.matchedIndex = i2 + 1;
                iArr2[i2] = read;
                this.state = State.UNBUFFER;
                this.unbufferIndex = 0;
            }
            return read();
        } else if (ordinal == 2) {
            byte[] bArr3 = this.replacement;
            int i4 = this.replacedIndex;
            int i5 = i4 + 1;
            this.replacedIndex = i5;
            byte b2 = bArr3[i4];
            if (i5 == bArr3.length) {
                this.state = State.NOT_MATCHED;
                this.replacedIndex = 0;
            }
            return b2;
        } else if (ordinal != 3) {
            int read2 = super.read();
            if (this.pattern[0] != read2) {
                return read2;
            }
            Arrays.fill(this.buf, 0);
            this.matchedIndex = 0;
            int[] iArr3 = this.buf;
            this.matchedIndex = 0 + 1;
            iArr3[0] = read2;
            if (this.pattern.length == 1) {
                this.state = State.REPLACING;
                this.replacedIndex = 0;
            } else {
                this.state = State.MATCHING;
            }
            return read();
        } else {
            int[] iArr4 = this.buf;
            int i6 = this.unbufferIndex;
            int i7 = i6 + 1;
            this.unbufferIndex = i7;
            int i8 = iArr4[i6];
            if (i7 == this.matchedIndex) {
                this.state = State.NOT_MATCHED;
                this.matchedIndex = 0;
            }
            return i8;
        }
    }
}
