package org.apache.poi.xdgf.usermodel.section.geometry;

import b.e.a.a.c.a.a.a;
import b.e.a.a.c.a.a.p;
import com.graphbuilder.curve.ControlPath;
import com.graphbuilder.curve.ValueVector;
import com.graphbuilder.geom.PointFactory;
import java.awt.geom.Path2D;
import java.awt.geom.Point2D;
import org.apache.poi.POIXMLException;
import org.apache.poi.xdgf.geom.SplineRenderer;
import org.apache.poi.xdgf.usermodel.XDGFCell;
import org.apache.poi.xdgf.usermodel.XDGFShape;
import org.apache.poi.xssf.usermodel.XSSFDataValidationConstraint;

public class NURBSTo implements GeometryRow {
    public NURBSTo _master = null;
    public Double a = null;

    /* renamed from: b  reason: collision with root package name */
    public Double f1943b = null;
    public Double c = null;

    /* renamed from: d  reason: collision with root package name */
    public Double f1944d = null;
    public Boolean deleted = null;

    /* renamed from: e  reason: collision with root package name */
    public String f1945e = null;
    public Double x = null;
    public Double y = null;

    public NURBSTo(p pVar) {
        if (pVar.isSetDel()) {
            this.deleted = Boolean.valueOf(pVar.getDel());
        }
        a[] a2 = pVar.a();
        for (a aVar : a2) {
            String n = aVar.getN();
            if (n.equals("X")) {
                this.x = XDGFCell.parseDoubleValue(aVar);
            } else if (n.equals("Y")) {
                this.y = XDGFCell.parseDoubleValue(aVar);
            } else if (n.equals("A")) {
                this.a = XDGFCell.parseDoubleValue(aVar);
            } else if (n.equals("B")) {
                this.f1943b = XDGFCell.parseDoubleValue(aVar);
            } else if (n.equals("C")) {
                this.c = XDGFCell.parseDoubleValue(aVar);
            } else if (n.equals("D")) {
                this.f1944d = XDGFCell.parseDoubleValue(aVar);
            } else if (n.equals("E")) {
                this.f1945e = aVar.getV();
            } else {
                throw new POIXMLException(b.b.a.a.a.b("Invalid cell '", n, "' in NURBS row"));
            }
        }
    }

    @Override // org.apache.poi.xdgf.usermodel.section.geometry.GeometryRow
    public void addToPath(Path2D.Double r32, XDGFShape xDGFShape) {
        if (!getDel()) {
            Point2D currentPoint = r32.getCurrentPoint();
            String trim = getE().trim();
            if (!trim.startsWith("NURBS(") || !trim.endsWith(")")) {
                throw new POIXMLException(b.b.a.a.a.b("Invalid NURBS formula: ", trim));
            }
            String[] split = trim.substring(6, trim.length() - 1).split(XSSFDataValidationConstraint.LIST_SEPARATOR);
            if (split.length < 8) {
                throw new POIXMLException("Invalid NURBS formula (not enough arguments)");
            } else if ((split.length - 4) % 4 == 0) {
                double doubleValue = getX().doubleValue();
                double doubleValue2 = getY().doubleValue();
                double doubleValue3 = getA().doubleValue();
                double doubleValue4 = getB().doubleValue();
                double doubleValue5 = getC().doubleValue();
                double doubleValue6 = getD().doubleValue();
                double parseDouble = Double.parseDouble(split[0].trim());
                int parseInt = Integer.parseInt(split[1].trim());
                int parseInt2 = Integer.parseInt(split[2].trim());
                int parseInt3 = Integer.parseInt(split[3].trim());
                double d2 = 1.0d;
                double doubleValue7 = parseInt2 == 0 ? xDGFShape.getWidth().doubleValue() : 1.0d;
                if (parseInt3 == 0) {
                    d2 = xDGFShape.getHeight().doubleValue();
                }
                ControlPath controlPath = new ControlPath();
                ValueVector valueVector = new ValueVector();
                ValueVector valueVector2 = new ValueVector();
                valueVector.add(doubleValue5);
                valueVector2.add(doubleValue6);
                controlPath.addPoint(PointFactory.create(currentPoint.getX(), currentPoint.getY()));
                int length = (split.length - 4) / 4;
                int i2 = 0;
                while (i2 < length) {
                    int i3 = (i2 * 4) + 4;
                    double parseDouble2 = Double.parseDouble(split[i3 + 0].trim());
                    double parseDouble3 = Double.parseDouble(split[i3 + 1].trim());
                    double parseDouble4 = Double.parseDouble(split[i3 + 2].trim());
                    double parseDouble5 = Double.parseDouble(split[i3 + 3].trim());
                    controlPath.addPoint(PointFactory.create(parseDouble2 * doubleValue7, parseDouble3 * d2));
                    valueVector.add(parseDouble4);
                    valueVector2.add(parseDouble5);
                    i2++;
                    length = length;
                    split = split;
                    doubleValue4 = doubleValue4;
                    parseDouble = parseDouble;
                }
                valueVector.add(doubleValue3);
                valueVector.add(parseDouble);
                valueVector2.add(doubleValue4);
                controlPath.addPoint(PointFactory.create(doubleValue, doubleValue2));
                r32.append(SplineRenderer.createNurbsSpline(controlPath, valueVector, valueVector2, parseInt), true);
            } else {
                StringBuilder b2 = b.b.a.a.a.b("Invalid NURBS formula -- need 4 + n*4 arguments, got ");
                b2.append(split.length);
                throw new POIXMLException(b2.toString());
            }
        }
    }

    public Double getA() {
        Double d2 = this.a;
        return d2 == null ? this._master.a : d2;
    }

    public Double getB() {
        Double d2 = this.f1943b;
        return d2 == null ? this._master.f1943b : d2;
    }

    public Double getC() {
        Double d2 = this.c;
        return d2 == null ? this._master.c : d2;
    }

    public Double getD() {
        Double d2 = this.f1944d;
        return d2 == null ? this._master.f1944d : d2;
    }

    public boolean getDel() {
        Boolean bool = this.deleted;
        if (bool != null) {
            return bool.booleanValue();
        }
        NURBSTo nURBSTo = this._master;
        if (nURBSTo != null) {
            return nURBSTo.getDel();
        }
        return false;
    }

    public String getE() {
        String str = this.f1945e;
        return str == null ? this._master.f1945e : str;
    }

    public Double getX() {
        Double d2 = this.x;
        return d2 == null ? this._master.x : d2;
    }

    public Double getY() {
        Double d2 = this.y;
        return d2 == null ? this._master.y : d2;
    }

    @Override // org.apache.poi.xdgf.usermodel.section.geometry.GeometryRow
    public void setupMaster(GeometryRow geometryRow) {
        this._master = (NURBSTo) geometryRow;
    }
}
