package org.apache.poi.xslf.usermodel;

import java.awt.geom.Rectangle2D;
import org.apache.poi.POIXMLException;
import org.apache.poi.javax.xml.namespace.QName;
import org.apache.poi.openxml4j.exceptions.InvalidFormatException;
import org.apache.poi.openxml4j.opc.PackageRelationship;
import org.apache.poi.openxml4j.opc.PackageRelationshipTypes;
import org.apache.poi.sl.usermodel.GraphicalFrame;
import org.apache.poi.sl.usermodel.PictureShape;
import org.apache.poi.sl.usermodel.ShapeType;
import org.apache.poi.ss.formula.functions.NumericFunction;
import org.apache.poi.util.POILogFactory;
import org.apache.poi.util.POILogger;
import org.apache.poi.util.Units;
import org.apache.xmlbeans.XmlCursor;
import org.apache.xmlbeans.XmlException;
import org.apache.xmlbeans.XmlObject;
import org.openxmlformats.schemas.drawingml.x2006.main.CTGraphicalObjectData;
import org.openxmlformats.schemas.drawingml.x2006.main.CTPoint2D;
import org.openxmlformats.schemas.drawingml.x2006.main.CTPositiveSize2D;
import org.openxmlformats.schemas.drawingml.x2006.main.CTTransform2D;
import org.openxmlformats.schemas.presentationml.x2006.main.CTGraphicalObjectFrame;
import org.openxmlformats.schemas.presentationml.x2006.main.CTGroupShape;

public class XSLFGraphicFrame extends XSLFShape implements GraphicalFrame<XSLFShape, XSLFTextParagraph> {
    public static final POILogger LOG = POILogFactory.getLogger(XSLFGraphicFrame.class);

    public XSLFGraphicFrame(CTGraphicalObjectFrame cTGraphicalObjectFrame, XSLFSheet xSLFSheet) {
        super(cTGraphicalObjectFrame, xSLFSheet);
    }

    /* JADX WARN: Type inference failed for: r6v1, types: [org.apache.poi.POIXMLDocumentPart, org.apache.poi.xslf.usermodel.XSLFSheet] */
    /* JADX WARN: Type inference failed for: r3v0, types: [org.apache.poi.xslf.usermodel.XSLFSheet] */
    /* JADX WARN: Type inference failed for: r3v1, types: [org.apache.poi.xslf.usermodel.XSLFSheet] */
    /* JADX WARN: Type inference failed for: r3v2, types: [org.apache.poi.xslf.usermodel.XSLFSheet] */
    /* JADX WARN: Type inference failed for: r1v14, types: [org.apache.poi.xslf.usermodel.XSLFSheet] */
    /* JADX WARNING: Unknown variable types count: 5 */
    private void copyDiagram(CTGraphicalObjectData cTGraphicalObjectData, XSLFGraphicFrame xSLFGraphicFrame) {
        XmlObject[] selectPath = cTGraphicalObjectData.selectPath("declare namespace dgm='http://schemas.openxmlformats.org/drawingml/2006/diagram' $this//dgm:relIds");
        if (selectPath != null && selectPath.length == 1) {
            XmlCursor newCursor = selectPath[0].newCursor();
            ?? sheet = xSLFGraphicFrame.getSheet();
            try {
                PackageRelationship relationship = sheet.getPackagePart().getRelationship(newCursor.getAttributeText(new QName(PackageRelationshipTypes.CORE_PROPERTIES_ECMA376_NS, "dm")));
                getSheet().importPart(relationship, sheet.getPackagePart().getRelatedPart(relationship));
                PackageRelationship relationship2 = sheet.getPackagePart().getRelationship(newCursor.getAttributeText(new QName(PackageRelationshipTypes.CORE_PROPERTIES_ECMA376_NS, "lo")));
                getSheet().importPart(relationship2, sheet.getPackagePart().getRelatedPart(relationship2));
                PackageRelationship relationship3 = sheet.getPackagePart().getRelationship(newCursor.getAttributeText(new QName(PackageRelationshipTypes.CORE_PROPERTIES_ECMA376_NS, "qs")));
                getSheet().importPart(relationship3, sheet.getPackagePart().getRelatedPart(relationship3));
                PackageRelationship relationship4 = sheet.getPackagePart().getRelationship(newCursor.getAttributeText(new QName(PackageRelationshipTypes.CORE_PROPERTIES_ECMA376_NS, "cs")));
                getSheet().importPart(relationship4, sheet.getPackagePart().getRelatedPart(relationship4));
                newCursor.dispose();
            } catch (InvalidFormatException e2) {
                throw new POIXMLException(e2);
            }
        }
    }

    public static XSLFGraphicFrame create(CTGraphicalObjectFrame cTGraphicalObjectFrame, XSLFSheet xSLFSheet) {
        if (XSLFTable.TABLE_URI.equals(cTGraphicalObjectFrame.getGraphic().getGraphicData().getUri())) {
            return new XSLFTable(cTGraphicalObjectFrame, xSLFSheet);
        }
        return new XSLFGraphicFrame(cTGraphicalObjectFrame, xSLFSheet);
    }

    @Override // org.apache.poi.xslf.usermodel.XSLFShape
    public void copy(XSLFShape xSLFShape) {
        super.copy(xSLFShape);
        CTGraphicalObjectData graphicData = ((CTGraphicalObjectFrame) getXmlObject()).getGraphic().getGraphicData();
        if (graphicData.getUri().equals("http://schemas.openxmlformats.org/drawingml/2006/diagram")) {
            copyDiagram(graphicData, (XSLFGraphicFrame) xSLFShape);
        }
    }

    @Override // org.apache.poi.sl.usermodel.Shape, org.apache.poi.sl.usermodel.PlaceableShape
    public Rectangle2D getAnchor() {
        CTTransform2D xfrm = ((CTGraphicalObjectFrame) getXmlObject()).getXfrm();
        CTPoint2D off = xfrm.getOff();
        double points = Units.toPoints(off.getX());
        double points2 = Units.toPoints(off.getY());
        CTPositiveSize2D ext = xfrm.getExt();
        return new Rectangle2D.Double(points, points2, Units.toPoints(ext.getCx()), Units.toPoints(ext.getCy()));
    }

    @Override // org.apache.poi.sl.usermodel.PlaceableShape
    public boolean getFlipHorizontal() {
        return false;
    }

    @Override // org.apache.poi.sl.usermodel.PlaceableShape
    public boolean getFlipVertical() {
        return false;
    }

    @Override // org.apache.poi.sl.usermodel.PlaceableShape
    public double getRotation() {
        return NumericFunction.LOG_10_TO_BASE_e;
    }

    public ShapeType getShapeType() {
        throw new UnsupportedOperationException();
    }

    @Override // org.apache.poi.sl.usermodel.PlaceableShape
    public void setAnchor(Rectangle2D rectangle2D) {
        CTTransform2D xfrm = ((CTGraphicalObjectFrame) getXmlObject()).getXfrm();
        CTPoint2D off = xfrm.isSetOff() ? xfrm.getOff() : xfrm.addNewOff();
        off.setX((long) Units.toEMU(rectangle2D.getX()));
        off.setY((long) Units.toEMU(rectangle2D.getY()));
        CTPositiveSize2D ext = xfrm.isSetExt() ? xfrm.getExt() : xfrm.addNewExt();
        ext.setCx((long) Units.toEMU(rectangle2D.getWidth()));
        ext.setCy((long) Units.toEMU(rectangle2D.getHeight()));
    }

    @Override // org.apache.poi.sl.usermodel.PlaceableShape
    public void setFlipHorizontal(boolean z) {
        throw new IllegalArgumentException("Operation not supported");
    }

    @Override // org.apache.poi.sl.usermodel.PlaceableShape
    public void setFlipVertical(boolean z) {
        throw new IllegalArgumentException("Operation not supported");
    }

    @Override // org.apache.poi.sl.usermodel.PlaceableShape
    public void setRotation(double d2) {
        throw new IllegalArgumentException("Operation not supported");
    }

    /* Return type fixed from 'org.apache.poi.xslf.usermodel.XSLFPictureShape' to match base method */
    /* JADX WARN: Type inference failed for: r2v2, types: [org.apache.poi.xslf.usermodel.XSLFSheet] */
    /* JADX WARNING: Unknown variable types count: 1 */
    @Override // org.apache.poi.sl.usermodel.GraphicalFrame
    public PictureShape<XSLFShape, XSLFTextParagraph> getFallbackPicture() {
        XmlObject selectProperty = selectProperty(XmlObject.class, "declare namespace p='http://schemas.openxmlformats.org/presentationml/2006/main'; declare namespace mc='http://schemas.openxmlformats.org/markup-compatibility/2006' .//mc:Fallback/*/p:pic");
        if (selectProperty == null) {
            return null;
        }
        try {
            CTGroupShape parse = CTGroupShape.Factory.parse(selectProperty.newDomNode());
            if (parse.sizeOfPicArray() == 0) {
                return null;
            }
            return new XSLFPictureShape(parse.getPicArray(0), getSheet());
        } catch (XmlException e2) {
            LOG.log(5, "Can't parse fallback picture stream of graphical frame", e2);
            return null;
        }
    }
}
