package org.apache.poi.xslf.usermodel;

import java.awt.geom.Rectangle2D;
import org.apache.poi.java.awt.Color;
import org.apache.poi.sl.draw.DrawPaint;
import org.apache.poi.sl.usermodel.PaintStyle;
import org.apache.poi.sl.usermodel.Shadow;
import org.apache.poi.sl.usermodel.SimpleShape;
import org.apache.poi.ss.formula.functions.NumericFunction;
import org.apache.poi.util.Units;
import org.openxmlformats.schemas.drawingml.x2006.main.CTOuterShadowEffect;

public class XSLFShadow extends XSLFShape implements Shadow<XSLFShape, XSLFTextParagraph> {
    public XSLFSimpleShape _parent;

    /* JADX WARN: Type inference failed for: r0v0, types: [org.apache.poi.xslf.usermodel.XSLFSheet] */
    /* JADX WARNING: Unknown variable types count: 1 */
    public XSLFShadow(CTOuterShadowEffect cTOuterShadowEffect, XSLFSimpleShape xSLFSimpleShape) {
        super(cTOuterShadowEffect, xSLFSimpleShape.getSheet());
        this._parent = xSLFSimpleShape;
    }

    @Override // org.apache.poi.sl.usermodel.Shape
    public Rectangle2D getAnchor() {
        return this._parent.getAnchor();
    }

    @Override // org.apache.poi.sl.usermodel.Shadow
    public double getAngle() {
        CTOuterShadowEffect cTOuterShadowEffect = (CTOuterShadowEffect) getXmlObject();
        return cTOuterShadowEffect.isSetDir() ? ((double) cTOuterShadowEffect.getDir()) / 60000.0d : NumericFunction.LOG_10_TO_BASE_e;
    }

    @Override // org.apache.poi.sl.usermodel.Shadow
    public double getBlur() {
        CTOuterShadowEffect cTOuterShadowEffect = (CTOuterShadowEffect) getXmlObject();
        return cTOuterShadowEffect.isSetBlurRad() ? Units.toPoints(cTOuterShadowEffect.getBlurRad()) : NumericFunction.LOG_10_TO_BASE_e;
    }

    @Override // org.apache.poi.sl.usermodel.Shadow
    public double getDistance() {
        CTOuterShadowEffect cTOuterShadowEffect = (CTOuterShadowEffect) getXmlObject();
        return cTOuterShadowEffect.isSetDist() ? Units.toPoints(cTOuterShadowEffect.getDist()) : NumericFunction.LOG_10_TO_BASE_e;
    }

    public Color getFillColor() {
        PaintStyle.SolidPaint fillStyle = getFillStyle();
        if (fillStyle == null) {
            return null;
        }
        return DrawPaint.applyColorTransform(fillStyle.getSolidColor());
    }

    /* JADX WARN: Type inference failed for: r0v0, types: [org.apache.poi.xslf.usermodel.XSLFSheet] */
    /* JADX WARNING: Unknown variable types count: 1 */
    @Override // org.apache.poi.sl.usermodel.Shadow
    public PaintStyle.SolidPaint getFillStyle() {
        XSLFTheme theme = getSheet().getTheme();
        CTOuterShadowEffect cTOuterShadowEffect = (CTOuterShadowEffect) getXmlObject();
        if (cTOuterShadowEffect == null) {
            return null;
        }
        return DrawPaint.createSolidPaint(new XSLFColor(cTOuterShadowEffect, theme, cTOuterShadowEffect.getSchemeClr()).getColorStyle());
    }

    public void setAnchor(Rectangle2D rectangle2D) {
        throw new IllegalStateException("You can't set anchor of a shadow");
    }

    /* Return type fixed from 'org.apache.poi.xslf.usermodel.XSLFSimpleShape' to match base method */
    @Override // org.apache.poi.sl.usermodel.Shadow
    public SimpleShape<XSLFShape, XSLFTextParagraph> getShadowParent() {
        return this._parent;
    }
}
