package org.apache.poi.xslf.usermodel;

import b.b.a.a.a;
import java.awt.geom.Rectangle2D;
import org.apache.poi.java.awt.Color;
import org.apache.poi.javax.xml.stream.XMLStreamException;
import org.apache.poi.javax.xml.stream.XMLStreamReader;
import org.apache.poi.openxml4j.opc.PackagePart;
import org.apache.poi.sl.draw.DrawPaint;
import org.apache.poi.sl.draw.geom.CustomGeometry;
import org.apache.poi.sl.draw.geom.Guide;
import org.apache.poi.sl.draw.geom.PresetGeometries;
import org.apache.poi.sl.usermodel.FillStyle;
import org.apache.poi.sl.usermodel.Hyperlink;
import org.apache.poi.sl.usermodel.LineDecoration;
import org.apache.poi.sl.usermodel.PaintStyle;
import org.apache.poi.sl.usermodel.Placeholder;
import org.apache.poi.sl.usermodel.Shadow;
import org.apache.poi.sl.usermodel.ShapeType;
import org.apache.poi.sl.usermodel.SimpleShape;
import org.apache.poi.sl.usermodel.StrokeStyle;
import org.apache.poi.ss.formula.functions.NumericFunction;
import org.apache.poi.util.POILogFactory;
import org.apache.poi.util.POILogger;
import org.apache.poi.util.Units;
import org.apache.poi.xslf.model.PropertyFetcher;
import org.apache.poi.xslf.usermodel.XSLFPropertiesDelegate;
import org.apache.xmlbeans.XmlObject;
import org.openxmlformats.schemas.drawingml.x2006.main.CTBaseStyles;
import org.openxmlformats.schemas.drawingml.x2006.main.CTBlip;
import org.openxmlformats.schemas.drawingml.x2006.main.CTGeomGuide;
import org.openxmlformats.schemas.drawingml.x2006.main.CTLineEndProperties;
import org.openxmlformats.schemas.drawingml.x2006.main.CTLineProperties;
import org.openxmlformats.schemas.drawingml.x2006.main.CTLineStyleList;
import org.openxmlformats.schemas.drawingml.x2006.main.CTNonVisualDrawingProps;
import org.openxmlformats.schemas.drawingml.x2006.main.CTOuterShadowEffect;
import org.openxmlformats.schemas.drawingml.x2006.main.CTPoint2D;
import org.openxmlformats.schemas.drawingml.x2006.main.CTPositiveSize2D;
import org.openxmlformats.schemas.drawingml.x2006.main.CTSchemeColor;
import org.openxmlformats.schemas.drawingml.x2006.main.CTShapeProperties;
import org.openxmlformats.schemas.drawingml.x2006.main.CTShapeStyle;
import org.openxmlformats.schemas.drawingml.x2006.main.CTSolidColorFillProperties;
import org.openxmlformats.schemas.drawingml.x2006.main.CTStyleMatrix;
import org.openxmlformats.schemas.drawingml.x2006.main.CTStyleMatrixReference;
import org.openxmlformats.schemas.drawingml.x2006.main.CTTransform2D;
import org.openxmlformats.schemas.drawingml.x2006.main.STCompoundLine;
import org.openxmlformats.schemas.drawingml.x2006.main.STLineCap;
import org.openxmlformats.schemas.drawingml.x2006.main.STLineEndLength;
import org.openxmlformats.schemas.drawingml.x2006.main.STLineEndType;
import org.openxmlformats.schemas.drawingml.x2006.main.STLineEndWidth;
import org.openxmlformats.schemas.drawingml.x2006.main.STPresetLineDashVal;
import org.openxmlformats.schemas.drawingml.x2006.main.STShapeType;

public abstract class XSLFSimpleShape extends XSLFShape implements SimpleShape<XSLFShape, XSLFTextParagraph> {
    public static final POILogger LOG = POILogFactory.getLogger(XSLFSimpleShape.class);
    public static CTOuterShadowEffect NO_SHADOW = CTOuterShadowEffect.Factory.newInstance();

    /* renamed from: org.apache.poi.xslf.usermodel.XSLFSimpleShape$11  reason: invalid class name */
    public static /* synthetic */ class AnonymousClass11 {
        public static final /* synthetic */ int[] $SwitchMap$org$apache$poi$sl$usermodel$StrokeStyle$LineCompound;

        /* JADX WARNING: Can't wrap try/catch for region: R(13:0|(2:1|2)|3|(2:5|6)|7|9|10|11|13|14|15|16|18) */
        /* JADX WARNING: Code restructure failed: missing block: B:19:?, code lost:
            return;
         */
        /* JADX WARNING: Failed to process nested try/catch */
        /* JADX WARNING: Missing exception handler attribute for start block: B:15:0x0024 */
        static {
            int[] iArr = new int[StrokeStyle.LineCompound.values().length];
            $SwitchMap$org$apache$poi$sl$usermodel$StrokeStyle$LineCompound = iArr;
            try {
                StrokeStyle.LineCompound lineCompound = StrokeStyle.LineCompound.SINGLE;
                iArr[0] = 1;
            } catch (NoSuchFieldError unused) {
            }
            try {
                int[] iArr2 = $SwitchMap$org$apache$poi$sl$usermodel$StrokeStyle$LineCompound;
                StrokeStyle.LineCompound lineCompound2 = StrokeStyle.LineCompound.DOUBLE;
                iArr2[1] = 2;
            } catch (NoSuchFieldError unused2) {
            }
            try {
                int[] iArr3 = $SwitchMap$org$apache$poi$sl$usermodel$StrokeStyle$LineCompound;
                StrokeStyle.LineCompound lineCompound3 = StrokeStyle.LineCompound.THICK_THIN;
                iArr3[2] = 3;
            } catch (NoSuchFieldError unused3) {
            }
            int[] iArr4 = $SwitchMap$org$apache$poi$sl$usermodel$StrokeStyle$LineCompound;
            StrokeStyle.LineCompound lineCompound4 = StrokeStyle.LineCompound.THIN_THICK;
            iArr4[3] = 4;
            int[] iArr5 = $SwitchMap$org$apache$poi$sl$usermodel$StrokeStyle$LineCompound;
            StrokeStyle.LineCompound lineCompound5 = StrokeStyle.LineCompound.TRIPLE;
            iArr5[4] = 5;
        }
    }

    public XSLFSimpleShape(XmlObject xmlObject, XSLFSheet xSLFSheet) {
        super(xmlObject, xSLFSheet);
    }

    public static CTLineProperties getLn(XSLFShape xSLFShape, boolean z) {
        XmlObject shapeProperties = xSLFShape.getShapeProperties();
        if (!(shapeProperties instanceof CTShapeProperties)) {
            POILogger pOILogger = LOG;
            pOILogger.log(5, xSLFShape.getClass() + " doesn't have line properties");
            return null;
        }
        CTShapeProperties cTShapeProperties = (CTShapeProperties) shapeProperties;
        return (cTShapeProperties.isSetLn() || !z) ? cTShapeProperties.getLn() : cTShapeProperties.addNewLn();
    }

    /* JADX WARN: Type inference failed for: r2v1, types: [org.apache.poi.xslf.usermodel.XSLFSheet] */
    /* JADX WARN: Type inference failed for: r3v0, types: [org.apache.poi.POIXMLDocumentPart, org.apache.poi.xslf.usermodel.XSLFSheet] */
    /* JADX WARNING: Unknown variable types count: 2 */
    @Override // org.apache.poi.xslf.usermodel.XSLFShape
    public void copy(XSLFShape xSLFShape) {
        super.copy(xSLFShape);
        XSLFSimpleShape xSLFSimpleShape = (XSLFSimpleShape) xSLFShape;
        Color fillColor = xSLFSimpleShape.getFillColor();
        Color fillColor2 = getFillColor();
        if (fillColor != null && !fillColor.equals(fillColor2)) {
            setFillColor(fillColor);
        }
        XSLFPropertiesDelegate.XSLFFillProperties fillDelegate = XSLFPropertiesDelegate.getFillDelegate(getShapeProperties());
        if (fillDelegate != null && fillDelegate.isSetBlipFill()) {
            CTBlip blip = fillDelegate.getBlipFill().getBlip();
            blip.setEmbed(getSheet().importBlip(blip.getEmbed(), xSLFSimpleShape.getSheet().getPackagePart()));
        }
        Color lineColor = xSLFSimpleShape.getLineColor();
        Color lineColor2 = getLineColor();
        if (lineColor != null && !lineColor.equals(lineColor2)) {
            setLineColor(lineColor);
        }
        double lineWidth = xSLFSimpleShape.getLineWidth();
        if (lineWidth != getLineWidth()) {
            setLineWidth(lineWidth);
        }
        StrokeStyle.LineDash lineDash = xSLFSimpleShape.getLineDash();
        StrokeStyle.LineDash lineDash2 = getLineDash();
        if (!(lineDash == null || lineDash == lineDash2)) {
            setLineDash(lineDash);
        }
        StrokeStyle.LineCap lineCap = xSLFSimpleShape.getLineCap();
        StrokeStyle.LineCap lineCap2 = getLineCap();
        if (lineCap != null && lineCap != lineCap2) {
            setLineCap(lineCap);
        }
    }

    @Override // org.apache.poi.sl.draw.geom.IAdjustableShape
    public Guide getAdjustValue(String str) {
        XSLFPropertiesDelegate.XSLFGeometryProperties geometryDelegate = XSLFPropertiesDelegate.getGeometryDelegate(getShapeProperties());
        if (geometryDelegate == null || !geometryDelegate.isSetPrstGeom() || !geometryDelegate.getPrstGeom().isSetAvLst()) {
            return null;
        }
        CTGeomGuide[] gdArray = geometryDelegate.getPrstGeom().getAvLst().getGdArray();
        for (CTGeomGuide cTGeomGuide : gdArray) {
            if (cTGeomGuide.getName().equals(str)) {
                return new Guide(cTGeomGuide.getName(), cTGeomGuide.getFmla());
            }
        }
        return null;
    }

    @Override // org.apache.poi.sl.usermodel.Shape, org.apache.poi.sl.usermodel.PlaceableShape
    public Rectangle2D getAnchor() {
        CTTransform2D xfrm = getXfrm(false);
        if (xfrm == null) {
            return null;
        }
        CTPoint2D off = xfrm.getOff();
        double points = Units.toPoints(off.getX());
        double points2 = Units.toPoints(off.getY());
        CTPositiveSize2D ext = xfrm.getExt();
        return new Rectangle2D.Double(points, points2, Units.toPoints(ext.getCx()), Units.toPoints(ext.getCy()));
    }

    /* JADX WARN: Type inference failed for: r2v1, types: [org.apache.poi.xslf.usermodel.XSLFSheet] */
    /* JADX WARNING: Unknown variable types count: 1 */
    public CTLineProperties getDefaultLineProperties() {
        CTStyleMatrixReference lnRef;
        CTBaseStyles themeElements;
        CTStyleMatrix fmtScheme;
        CTLineStyleList lnStyleLst;
        CTShapeStyle spStyle = getSpStyle();
        if (spStyle == null || (lnRef = spStyle.getLnRef()) == null) {
            return null;
        }
        int idx = (int) lnRef.getIdx();
        XSLFTheme theme = getSheet().getTheme();
        if (theme == null || (themeElements = theme.getXmlObject().getThemeElements()) == null || (fmtScheme = themeElements.getFmtScheme()) == null || (lnStyleLst = fmtScheme.getLnStyleLst()) == null || lnStyleLst.sizeOfLnArray() < idx) {
            return null;
        }
        return lnStyleLst.getLnArray(idx - 1);
    }

    @Override // org.apache.poi.sl.usermodel.SimpleShape
    public Color getFillColor() {
        PaintStyle fillPaint = getFillPaint();
        if (fillPaint instanceof PaintStyle.SolidPaint) {
            return DrawPaint.applyColorTransform(((PaintStyle.SolidPaint) fillPaint).getSolidColor());
        }
        return null;
    }

    @Override // org.apache.poi.sl.usermodel.SimpleShape
    public FillStyle getFillStyle() {
        return new FillStyle() {
            /* class org.apache.poi.xslf.usermodel.XSLFSimpleShape.AnonymousClass9 */

            @Override // org.apache.poi.sl.usermodel.FillStyle
            public PaintStyle getPaint() {
                return XSLFSimpleShape.this.getFillPaint();
            }
        };
    }

    @Override // org.apache.poi.sl.usermodel.PlaceableShape
    public boolean getFlipHorizontal() {
        CTTransform2D xfrm = getXfrm(false);
        if (xfrm == null || !xfrm.isSetFlipH()) {
            return false;
        }
        return xfrm.getFlipH();
    }

    @Override // org.apache.poi.sl.usermodel.PlaceableShape
    public boolean getFlipVertical() {
        CTTransform2D xfrm = getXfrm(false);
        if (xfrm == null || !xfrm.isSetFlipV()) {
            return false;
        }
        return xfrm.getFlipV();
    }

    @Override // org.apache.poi.sl.usermodel.SimpleShape
    public CustomGeometry getGeometry() {
        XSLFPropertiesDelegate.XSLFGeometryProperties geometryDelegate = XSLFPropertiesDelegate.getGeometryDelegate(getShapeProperties());
        if (geometryDelegate == null) {
            return null;
        }
        PresetGeometries instance = PresetGeometries.getInstance();
        if (geometryDelegate.isSetPrstGeom()) {
            String stringEnumAbstractBase = geometryDelegate.getPrstGeom().getPrst().toString();
            CustomGeometry customGeometry = (CustomGeometry) instance.get(stringEnumAbstractBase);
            if (customGeometry != null) {
                return customGeometry;
            }
            StringBuilder d2 = a.d("Unknown shape geometry: ", stringEnumAbstractBase, ", available geometries are: ");
            d2.append(instance.keySet());
            throw new IllegalStateException(d2.toString());
        } else if (!geometryDelegate.isSetCustGeom()) {
            return (CustomGeometry) instance.get("rect");
        } else {
            XMLStreamReader newXMLStreamReader = geometryDelegate.getCustGeom().newXMLStreamReader();
            CustomGeometry convertCustomGeometry = PresetGeometries.convertCustomGeometry(newXMLStreamReader);
            try {
                newXMLStreamReader.close();
                return convertCustomGeometry;
            } catch (XMLStreamException e2) {
                POILogger pOILogger = LOG;
                StringBuilder b2 = a.b("An error occurred while closing a Custom Geometry XML Stream Reader: ");
                b2.append(e2.getMessage());
                pOILogger.log(5, b2.toString());
                return convertCustomGeometry;
            }
        }
    }

    public StrokeStyle.LineCap getLineCap() {
        CTLineProperties defaultLineProperties;
        AnonymousClass6 r0 = new PropertyFetcher<StrokeStyle.LineCap>() {
            /* class org.apache.poi.xslf.usermodel.XSLFSimpleShape.AnonymousClass6 */

            @Override // org.apache.poi.xslf.model.PropertyFetcher
            public boolean fetch(XSLFShape xSLFShape) {
                CTLineProperties ln = XSLFSimpleShape.getLn(xSLFShape, false);
                if (ln == null || !ln.isSetCap()) {
                    return false;
                }
                setValue(StrokeStyle.LineCap.fromOoxmlId(ln.getCap().intValue()));
                return true;
            }
        };
        fetchShapeProperty(r0);
        StrokeStyle.LineCap lineCap = (StrokeStyle.LineCap) r0.getValue();
        return (lineCap != null || (defaultLineProperties = getDefaultLineProperties()) == null || !defaultLineProperties.isSetCap()) ? lineCap : StrokeStyle.LineCap.fromOoxmlId(defaultLineProperties.getCap().intValue());
    }

    public Color getLineColor() {
        PaintStyle linePaint = getLinePaint();
        if (linePaint instanceof PaintStyle.SolidPaint) {
            return ((PaintStyle.SolidPaint) linePaint).getSolidColor().getColor();
        }
        return null;
    }

    public StrokeStyle.LineCompound getLineCompound() {
        CTLineProperties defaultLineProperties;
        AnonymousClass4 r0 = new PropertyFetcher<Integer>() {
            /* class org.apache.poi.xslf.usermodel.XSLFSimpleShape.AnonymousClass4 */

            @Override // org.apache.poi.xslf.model.PropertyFetcher
            public boolean fetch(XSLFShape xSLFShape) {
                STCompoundLine.Enum cmpd;
                CTLineProperties ln = XSLFSimpleShape.getLn(xSLFShape, false);
                if (ln == null || (cmpd = ln.getCmpd()) == null) {
                    return false;
                }
                setValue(Integer.valueOf(cmpd.intValue()));
                return true;
            }
        };
        fetchShapeProperty(r0);
        if (((Integer) r0.getValue()) != null || (defaultLineProperties = getDefaultLineProperties()) == null || !defaultLineProperties.isSetCmpd()) {
            return null;
        }
        int intValue = defaultLineProperties.getCmpd().intValue();
        if (intValue == 2) {
            return StrokeStyle.LineCompound.DOUBLE;
        }
        if (intValue == 3) {
            return StrokeStyle.LineCompound.THICK_THIN;
        }
        if (intValue == 4) {
            return StrokeStyle.LineCompound.THIN_THICK;
        }
        if (intValue != 5) {
            return StrokeStyle.LineCompound.SINGLE;
        }
        return StrokeStyle.LineCompound.TRIPLE;
    }

    public StrokeStyle.LineDash getLineDash() {
        CTLineProperties defaultLineProperties;
        AnonymousClass5 r0 = new PropertyFetcher<StrokeStyle.LineDash>() {
            /* class org.apache.poi.xslf.usermodel.XSLFSimpleShape.AnonymousClass5 */

            @Override // org.apache.poi.xslf.model.PropertyFetcher
            public boolean fetch(XSLFShape xSLFShape) {
                CTLineProperties ln = XSLFSimpleShape.getLn(xSLFShape, false);
                if (ln == null || !ln.isSetPrstDash()) {
                    return false;
                }
                setValue(StrokeStyle.LineDash.fromOoxmlId(ln.getPrstDash().getVal().intValue()));
                return true;
            }
        };
        fetchShapeProperty(r0);
        StrokeStyle.LineDash lineDash = (StrokeStyle.LineDash) r0.getValue();
        return (lineDash != null || (defaultLineProperties = getDefaultLineProperties()) == null || !defaultLineProperties.isSetPrstDash()) ? lineDash : StrokeStyle.LineDash.fromOoxmlId(defaultLineProperties.getPrstDash().getVal().intValue());
    }

    @Override // org.apache.poi.sl.usermodel.SimpleShape
    public LineDecoration getLineDecoration() {
        return new LineDecoration() {
            /* class org.apache.poi.xslf.usermodel.XSLFSimpleShape.AnonymousClass8 */

            @Override // org.apache.poi.sl.usermodel.LineDecoration
            public LineDecoration.DecorationSize getHeadLength() {
                return XSLFSimpleShape.this.getLineHeadLength();
            }

            @Override // org.apache.poi.sl.usermodel.LineDecoration
            public LineDecoration.DecorationShape getHeadShape() {
                return XSLFSimpleShape.this.getLineHeadDecoration();
            }

            @Override // org.apache.poi.sl.usermodel.LineDecoration
            public LineDecoration.DecorationSize getHeadWidth() {
                return XSLFSimpleShape.this.getLineHeadWidth();
            }

            @Override // org.apache.poi.sl.usermodel.LineDecoration
            public LineDecoration.DecorationSize getTailLength() {
                return XSLFSimpleShape.this.getLineTailLength();
            }

            @Override // org.apache.poi.sl.usermodel.LineDecoration
            public LineDecoration.DecorationShape getTailShape() {
                return XSLFSimpleShape.this.getLineTailDecoration();
            }

            @Override // org.apache.poi.sl.usermodel.LineDecoration
            public LineDecoration.DecorationSize getTailWidth() {
                return XSLFSimpleShape.this.getLineTailWidth();
            }
        };
    }

    public LineDecoration.DecorationShape getLineHeadDecoration() {
        CTLineProperties ln = getLn(this, false);
        LineDecoration.DecorationShape decorationShape = LineDecoration.DecorationShape.NONE;
        return (ln == null || !ln.isSetHeadEnd() || !ln.getHeadEnd().isSetType()) ? decorationShape : LineDecoration.DecorationShape.fromOoxmlId(ln.getHeadEnd().getType().intValue());
    }

    public LineDecoration.DecorationSize getLineHeadLength() {
        CTLineProperties ln = getLn(this, false);
        LineDecoration.DecorationSize decorationSize = LineDecoration.DecorationSize.MEDIUM;
        return (ln == null || !ln.isSetHeadEnd() || !ln.getHeadEnd().isSetLen()) ? decorationSize : LineDecoration.DecorationSize.fromOoxmlId(ln.getHeadEnd().getLen().intValue());
    }

    public LineDecoration.DecorationSize getLineHeadWidth() {
        CTLineProperties ln = getLn(this, false);
        LineDecoration.DecorationSize decorationSize = LineDecoration.DecorationSize.MEDIUM;
        return (ln == null || !ln.isSetHeadEnd() || !ln.getHeadEnd().isSetW()) ? decorationSize : LineDecoration.DecorationSize.fromOoxmlId(ln.getHeadEnd().getW().intValue());
    }

    /* JADX WARN: Type inference failed for: r0v0, types: [org.apache.poi.xslf.usermodel.XSLFSheet] */
    /* JADX WARNING: Unknown variable types count: 1 */
    public PaintStyle getLinePaint() {
        final XSLFTheme theme = getSheet().getTheme();
        final boolean z = getPlaceholder() != null;
        AnonymousClass2 r2 = new PropertyFetcher<PaintStyle>() {
            /* class org.apache.poi.xslf.usermodel.XSLFSimpleShape.AnonymousClass2 */

            /* JADX WARN: Type inference failed for: r4v0, types: [org.apache.poi.POIXMLDocumentPart, org.apache.poi.xslf.usermodel.XSLFSheet] */
            /* JADX WARNING: Unknown variable types count: 1 */
            @Override // org.apache.poi.xslf.model.PropertyFetcher
            public boolean fetch(XSLFShape xSLFShape) {
                XSLFPropertiesDelegate.XSLFFillProperties fillDelegate = XSLFPropertiesDelegate.getFillDelegate(XSLFSimpleShape.getLn(xSLFShape, false));
                if (fillDelegate == null || !fillDelegate.isSetNoFill()) {
                    PackagePart packagePart = xSLFShape.getSheet().getPackagePart();
                    PaintStyle selectPaint = XSLFShape.selectPaint(fillDelegate, null, packagePart, theme, z);
                    if (selectPaint != null) {
                        setValue(selectPaint);
                        return true;
                    }
                    CTShapeStyle spStyle = xSLFShape.getSpStyle();
                    if (spStyle != null && (selectPaint = XSLFShape.selectPaint(XSLFPropertiesDelegate.getFillDelegate(spStyle.getLnRef()), null, packagePart, theme, z)) == null) {
                        selectPaint = getThemePaint(spStyle, packagePart);
                    }
                    if (selectPaint == null) {
                        return false;
                    }
                    setValue(selectPaint);
                    return true;
                }
                setValue(null);
                return true;
            }

            public PaintStyle getThemePaint(CTShapeStyle cTShapeStyle, PackagePart packagePart) {
                CTStyleMatrixReference lnRef = cTShapeStyle.getLnRef();
                if (lnRef == null) {
                    return null;
                }
                int idx = (int) lnRef.getIdx();
                CTSchemeColor schemeClr = lnRef.getSchemeClr();
                if (idx <= 0) {
                    return null;
                }
                return XSLFShape.selectPaint(XSLFPropertiesDelegate.getFillDelegate(theme.getXmlObject().getThemeElements().getFmtScheme().getLnStyleLst().getLnArray(idx - 1)), schemeClr, packagePart, theme, z);
            }
        };
        fetchShapeProperty(r2);
        return (PaintStyle) r2.getValue();
    }

    public LineDecoration.DecorationShape getLineTailDecoration() {
        CTLineProperties ln = getLn(this, false);
        LineDecoration.DecorationShape decorationShape = LineDecoration.DecorationShape.NONE;
        return (ln == null || !ln.isSetTailEnd() || !ln.getTailEnd().isSetType()) ? decorationShape : LineDecoration.DecorationShape.fromOoxmlId(ln.getTailEnd().getType().intValue());
    }

    public LineDecoration.DecorationSize getLineTailLength() {
        CTLineProperties ln = getLn(this, false);
        LineDecoration.DecorationSize decorationSize = LineDecoration.DecorationSize.MEDIUM;
        return (ln == null || !ln.isSetTailEnd() || !ln.getTailEnd().isSetLen()) ? decorationSize : LineDecoration.DecorationSize.fromOoxmlId(ln.getTailEnd().getLen().intValue());
    }

    public LineDecoration.DecorationSize getLineTailWidth() {
        CTLineProperties ln = getLn(this, false);
        LineDecoration.DecorationSize decorationSize = LineDecoration.DecorationSize.MEDIUM;
        return (ln == null || !ln.isSetTailEnd() || !ln.getTailEnd().isSetW()) ? decorationSize : LineDecoration.DecorationSize.fromOoxmlId(ln.getTailEnd().getW().intValue());
    }

    public double getLineWidth() {
        AnonymousClass3 r0 = new PropertyFetcher<Double>() {
            /* class org.apache.poi.xslf.usermodel.XSLFSimpleShape.AnonymousClass3 */

            @Override // org.apache.poi.xslf.model.PropertyFetcher
            public boolean fetch(XSLFShape xSLFShape) {
                CTLineProperties ln = XSLFSimpleShape.getLn(xSLFShape, false);
                if (ln != null) {
                    if (ln.isSetNoFill()) {
                        setValue(Double.valueOf((double) NumericFunction.LOG_10_TO_BASE_e));
                        return true;
                    } else if (ln.isSetW()) {
                        setValue(Double.valueOf(Units.toPoints((long) ln.getW())));
                        return true;
                    }
                }
                return false;
            }
        };
        fetchShapeProperty(r0);
        if (r0.getValue() != null) {
            return ((Double) r0.getValue()).doubleValue();
        }
        CTLineProperties defaultLineProperties = getDefaultLineProperties();
        return (defaultLineProperties == null || !defaultLineProperties.isSetW()) ? NumericFunction.LOG_10_TO_BASE_e : Units.toPoints((long) defaultLineProperties.getW());
    }

    @Override // org.apache.poi.sl.usermodel.PlaceableShape
    public double getRotation() {
        CTTransform2D xfrm = getXfrm(false);
        return (xfrm == null || !xfrm.isSetRot()) ? NumericFunction.LOG_10_TO_BASE_e : ((double) xfrm.getRot()) / 60000.0d;
    }

    @Override // org.apache.poi.sl.usermodel.SimpleShape
    public ShapeType getShapeType() {
        STShapeType.Enum prst;
        XSLFPropertiesDelegate.XSLFGeometryProperties geometryDelegate = XSLFPropertiesDelegate.getGeometryDelegate(getShapeProperties());
        if (geometryDelegate == null || !geometryDelegate.isSetPrstGeom() || (prst = geometryDelegate.getPrstGeom().getPrst()) == null) {
            return null;
        }
        return ShapeType.forId(prst.intValue(), true);
    }

    @Override // org.apache.poi.sl.usermodel.SimpleShape
    public StrokeStyle getStrokeStyle() {
        return new StrokeStyle() {
            /* class org.apache.poi.xslf.usermodel.XSLFSimpleShape.AnonymousClass10 */

            @Override // org.apache.poi.sl.usermodel.StrokeStyle
            public StrokeStyle.LineCap getLineCap() {
                return XSLFSimpleShape.this.getLineCap();
            }

            @Override // org.apache.poi.sl.usermodel.StrokeStyle
            public StrokeStyle.LineCompound getLineCompound() {
                return XSLFSimpleShape.this.getLineCompound();
            }

            @Override // org.apache.poi.sl.usermodel.StrokeStyle
            public StrokeStyle.LineDash getLineDash() {
                return XSLFSimpleShape.this.getLineDash();
            }

            @Override // org.apache.poi.sl.usermodel.StrokeStyle
            public double getLineWidth() {
                return XSLFSimpleShape.this.getLineWidth();
            }

            @Override // org.apache.poi.sl.usermodel.StrokeStyle
            public PaintStyle getPaint() {
                return XSLFSimpleShape.this.getLinePaint();
            }
        };
    }

    public CTTransform2D getXfrm(boolean z) {
        AnonymousClass1 r0 = new PropertyFetcher<CTTransform2D>() {
            /* class org.apache.poi.xslf.usermodel.XSLFSimpleShape.AnonymousClass1 */

            @Override // org.apache.poi.xslf.model.PropertyFetcher
            public boolean fetch(XSLFShape xSLFShape) {
                XmlObject shapeProperties = xSLFShape.getShapeProperties();
                if (!(shapeProperties instanceof CTShapeProperties)) {
                    return false;
                }
                CTShapeProperties cTShapeProperties = (CTShapeProperties) shapeProperties;
                if (!cTShapeProperties.isSetXfrm()) {
                    return false;
                }
                setValue(cTShapeProperties.getXfrm());
                return true;
            }
        };
        fetchShapeProperty(r0);
        CTTransform2D cTTransform2D = (CTTransform2D) r0.getValue();
        if (!z || cTTransform2D != null) {
            return cTTransform2D;
        }
        XmlObject shapeProperties = getShapeProperties();
        if (shapeProperties instanceof CTShapeProperties) {
            return ((CTShapeProperties) shapeProperties).addNewXfrm();
        }
        POILogger pOILogger = LOG;
        pOILogger.log(5, getClass() + " doesn't have xfrm element.");
        return null;
    }

    public boolean isPlaceholder() {
        return getCTPlaceholder() != null;
    }

    @Override // org.apache.poi.sl.usermodel.PlaceableShape
    public void setAnchor(Rectangle2D rectangle2D) {
        CTTransform2D xfrm = getXfrm(true);
        if (xfrm != null) {
            CTPoint2D off = xfrm.isSetOff() ? xfrm.getOff() : xfrm.addNewOff();
            off.setX((long) Units.toEMU(rectangle2D.getX()));
            off.setY((long) Units.toEMU(rectangle2D.getY()));
            CTPositiveSize2D ext = xfrm.isSetExt() ? xfrm.getExt() : xfrm.addNewExt();
            ext.setCx((long) Units.toEMU(rectangle2D.getWidth()));
            ext.setCy((long) Units.toEMU(rectangle2D.getHeight()));
        }
    }

    /* JADX WARN: Type inference failed for: r2v0, types: [org.apache.poi.xslf.usermodel.XSLFSheet] */
    /* JADX WARNING: Unknown variable types count: 1 */
    public void setFillColor(Color color) {
        XSLFPropertiesDelegate.XSLFFillProperties fillDelegate = XSLFPropertiesDelegate.getFillDelegate(getShapeProperties());
        if (fillDelegate != null) {
            if (color == null) {
                if (fillDelegate.isSetSolidFill()) {
                    fillDelegate.unsetSolidFill();
                }
                if (fillDelegate.isSetGradFill()) {
                    fillDelegate.unsetGradFill();
                }
                if (fillDelegate.isSetPattFill()) {
                    fillDelegate.unsetGradFill();
                }
                if (fillDelegate.isSetBlipFill()) {
                    fillDelegate.unsetBlipFill();
                }
                if (!fillDelegate.isSetNoFill()) {
                    fillDelegate.addNewNoFill();
                    return;
                }
                return;
            }
            if (fillDelegate.isSetNoFill()) {
                fillDelegate.unsetNoFill();
            }
            CTSolidColorFillProperties solidFill = fillDelegate.isSetSolidFill() ? fillDelegate.getSolidFill() : fillDelegate.addNewSolidFill();
            new XSLFColor(solidFill, getSheet().getTheme(), solidFill.getSchemeClr()).setColor(color);
        }
    }

    @Override // org.apache.poi.sl.usermodel.PlaceableShape
    public void setFlipHorizontal(boolean z) {
        CTTransform2D xfrm = getXfrm(true);
        if (xfrm != null) {
            xfrm.setFlipH(z);
        }
    }

    @Override // org.apache.poi.sl.usermodel.PlaceableShape
    public void setFlipVertical(boolean z) {
        CTTransform2D xfrm = getXfrm(true);
        if (xfrm != null) {
            xfrm.setFlipV(z);
        }
    }

    public void setLineCap(StrokeStyle.LineCap lineCap) {
        CTLineProperties ln = getLn(this, true);
        if (ln != null) {
            if (lineCap != null) {
                ln.setCap(STLineCap.Enum.forInt(lineCap.ooxmlId));
            } else if (ln.isSetCap()) {
                ln.unsetCap();
            }
        }
    }

    /* JADX WARN: Type inference failed for: r2v0, types: [org.apache.poi.xslf.usermodel.XSLFSheet] */
    /* JADX WARNING: Unknown variable types count: 1 */
    public void setLineColor(Color color) {
        CTLineProperties ln = getLn(this, true);
        if (ln != null) {
            if (ln.isSetSolidFill()) {
                ln.unsetSolidFill();
            }
            if (ln.isSetGradFill()) {
                ln.unsetGradFill();
            }
            if (ln.isSetPattFill()) {
                ln.unsetPattFill();
            }
            if (ln.isSetNoFill()) {
                ln.unsetNoFill();
            }
            if (color == null) {
                ln.addNewNoFill();
                return;
            }
            CTSolidColorFillProperties addNewSolidFill = ln.addNewSolidFill();
            new XSLFColor(addNewSolidFill, getSheet().getTheme(), addNewSolidFill.getSchemeClr()).setColor(color);
        }
    }

    public void setLineCompound(StrokeStyle.LineCompound lineCompound) {
        STCompoundLine.Enum r3;
        CTLineProperties ln = getLn(this, true);
        if (ln != null) {
            if (lineCompound != null) {
                int ordinal = lineCompound.ordinal();
                if (ordinal == 1) {
                    r3 = STCompoundLine.DBL;
                } else if (ordinal == 2) {
                    r3 = STCompoundLine.THICK_THIN;
                } else if (ordinal == 3) {
                    r3 = STCompoundLine.THIN_THICK;
                } else if (ordinal != 4) {
                    r3 = STCompoundLine.SNG;
                } else {
                    r3 = STCompoundLine.TRI;
                }
                ln.setCmpd(r3);
            } else if (ln.isSetCmpd()) {
                ln.unsetCmpd();
            }
        }
    }

    public void setLineDash(StrokeStyle.LineDash lineDash) {
        CTLineProperties ln = getLn(this, true);
        if (ln != null) {
            if (lineDash != null) {
                (ln.isSetPrstDash() ? ln.getPrstDash() : ln.addNewPrstDash()).setVal(STPresetLineDashVal.Enum.forInt(lineDash.ooxmlId));
            } else if (ln.isSetPrstDash()) {
                ln.unsetPrstDash();
            }
        }
    }

    public void setLineHeadDecoration(LineDecoration.DecorationShape decorationShape) {
        CTLineProperties ln = getLn(this, true);
        if (ln != null) {
            CTLineEndProperties headEnd = ln.isSetHeadEnd() ? ln.getHeadEnd() : ln.addNewHeadEnd();
            if (decorationShape != null) {
                headEnd.setType(STLineEndType.Enum.forInt(decorationShape.ooxmlId));
            } else if (headEnd.isSetType()) {
                headEnd.unsetType();
            }
        }
    }

    public void setLineHeadLength(LineDecoration.DecorationSize decorationSize) {
        CTLineProperties ln = getLn(this, true);
        if (ln != null) {
            CTLineEndProperties headEnd = ln.isSetHeadEnd() ? ln.getHeadEnd() : ln.addNewHeadEnd();
            if (decorationSize != null) {
                headEnd.setLen(STLineEndLength.Enum.forInt(decorationSize.ooxmlId));
            } else if (headEnd.isSetLen()) {
                headEnd.unsetLen();
            }
        }
    }

    public void setLineHeadWidth(LineDecoration.DecorationSize decorationSize) {
        CTLineProperties ln = getLn(this, true);
        if (ln != null) {
            CTLineEndProperties headEnd = ln.isSetHeadEnd() ? ln.getHeadEnd() : ln.addNewHeadEnd();
            if (decorationSize != null) {
                headEnd.setW(STLineEndWidth.Enum.forInt(decorationSize.ooxmlId));
            } else if (headEnd.isSetW()) {
                headEnd.unsetW();
            }
        }
    }

    public void setLineTailDecoration(LineDecoration.DecorationShape decorationShape) {
        CTLineProperties ln = getLn(this, true);
        if (ln != null) {
            CTLineEndProperties tailEnd = ln.isSetTailEnd() ? ln.getTailEnd() : ln.addNewTailEnd();
            if (decorationShape != null) {
                tailEnd.setType(STLineEndType.Enum.forInt(decorationShape.ooxmlId));
            } else if (tailEnd.isSetType()) {
                tailEnd.unsetType();
            }
        }
    }

    public void setLineTailLength(LineDecoration.DecorationSize decorationSize) {
        CTLineProperties ln = getLn(this, true);
        if (ln != null) {
            CTLineEndProperties tailEnd = ln.isSetTailEnd() ? ln.getTailEnd() : ln.addNewTailEnd();
            if (decorationSize != null) {
                tailEnd.setLen(STLineEndLength.Enum.forInt(decorationSize.ooxmlId));
            } else if (tailEnd.isSetLen()) {
                tailEnd.unsetLen();
            }
        }
    }

    public void setLineTailWidth(LineDecoration.DecorationSize decorationSize) {
        CTLineProperties ln = getLn(this, true);
        if (ln != null) {
            CTLineEndProperties tailEnd = ln.isSetTailEnd() ? ln.getTailEnd() : ln.addNewTailEnd();
            if (decorationSize != null) {
                tailEnd.setW(STLineEndWidth.Enum.forInt(decorationSize.ooxmlId));
            } else if (tailEnd.isSetW()) {
                tailEnd.unsetW();
            }
        }
    }

    public void setLineWidth(double d2) {
        CTLineProperties ln = getLn(this, true);
        if (ln != null) {
            if (d2 == NumericFunction.LOG_10_TO_BASE_e) {
                if (ln.isSetW()) {
                    ln.unsetW();
                }
                if (!ln.isSetNoFill()) {
                    ln.addNewNoFill();
                }
                if (ln.isSetSolidFill()) {
                    ln.unsetSolidFill();
                }
                if (ln.isSetGradFill()) {
                    ln.unsetGradFill();
                }
                if (ln.isSetPattFill()) {
                    ln.unsetPattFill();
                    return;
                }
                return;
            }
            if (ln.isSetNoFill()) {
                ln.unsetNoFill();
            }
            ln.setW(Units.toEMU(d2));
        }
    }

    @Override // org.apache.poi.xslf.usermodel.XSLFShape, org.apache.poi.sl.usermodel.SimpleShape
    public void setPlaceholder(Placeholder placeholder) {
        super.setPlaceholder(placeholder);
    }

    @Override // org.apache.poi.sl.usermodel.PlaceableShape
    public void setRotation(double d2) {
        CTTransform2D xfrm = getXfrm(true);
        if (xfrm != null) {
            xfrm.setRot((int) (d2 * 60000.0d));
        }
    }

    @Override // org.apache.poi.sl.usermodel.SimpleShape
    public void setShapeType(ShapeType shapeType) {
        XSLFPropertiesDelegate.XSLFGeometryProperties geometryDelegate = XSLFPropertiesDelegate.getGeometryDelegate(getShapeProperties());
        if (geometryDelegate != null) {
            if (geometryDelegate.isSetCustGeom()) {
                geometryDelegate.unsetCustGeom();
            }
            (geometryDelegate.isSetPrstGeom() ? geometryDelegate.getPrstGeom() : geometryDelegate.addNewPrstGeom()).setPrst(STShapeType.Enum.forInt(shapeType.ooxmlId));
        }
    }

    @Override // org.apache.poi.sl.usermodel.SimpleShape
    public void setStrokeStyle(Object... objArr) {
        if (objArr.length == 0) {
            setLineColor(null);
            return;
        }
        for (Object obj : objArr) {
            if (obj instanceof Number) {
                setLineWidth(((Number) obj).doubleValue());
            } else if (obj instanceof StrokeStyle.LineCap) {
                setLineCap((StrokeStyle.LineCap) obj);
            } else if (obj instanceof StrokeStyle.LineDash) {
                setLineDash((StrokeStyle.LineDash) obj);
            } else if (obj instanceof StrokeStyle.LineCompound) {
                setLineCompound((StrokeStyle.LineCompound) obj);
            } else if (obj instanceof Color) {
                setLineColor((Color) obj);
            }
        }
    }

    /* Return type fixed from 'org.apache.poi.xslf.usermodel.XSLFHyperlink' to match base method */
    /* JADX WARN: Type inference failed for: r0v0, types: [org.apache.poi.xslf.usermodel.XSLFHyperlink] */
    /* JADX WARN: Type inference failed for: r2v0, types: [org.apache.poi.xslf.usermodel.XSLFSheet] */
    /* JADX WARNING: Unknown variable types count: 2 */
    @Override // org.apache.poi.sl.usermodel.SimpleShape
    public Hyperlink<XSLFShape, XSLFTextParagraph> createHyperlink() {
        ?? hyperlink = getHyperlink();
        return hyperlink == 0 ? new XSLFHyperlink(getCNvPr().addNewHlinkClick(), getSheet()) : hyperlink;
    }

    /* Return type fixed from 'org.apache.poi.xslf.usermodel.XSLFHyperlink' to match base method */
    /* JADX WARN: Type inference failed for: r2v0, types: [org.apache.poi.xslf.usermodel.XSLFSheet] */
    /* JADX WARNING: Unknown variable types count: 1 */
    @Override // org.apache.poi.sl.usermodel.SimpleShape
    public Hyperlink<XSLFShape, XSLFTextParagraph> getHyperlink() {
        CTNonVisualDrawingProps cNvPr = getCNvPr();
        if (!cNvPr.isSetHlinkClick()) {
            return null;
        }
        return new XSLFHyperlink(cNvPr.getHlinkClick(), getSheet());
    }

    /* Return type fixed from 'org.apache.poi.xslf.usermodel.XSLFShadow' to match base method */
    /* JADX WARN: Type inference failed for: r0v4, types: [org.apache.poi.xslf.usermodel.XSLFSheet] */
    /* JADX WARNING: Unknown variable types count: 1 */
    @Override // org.apache.poi.sl.usermodel.SimpleShape
    public Shadow<XSLFShape, XSLFTextParagraph> getShadow() {
        CTShapeStyle spStyle;
        int idx;
        AnonymousClass7 r0 = new PropertyFetcher<CTOuterShadowEffect>() {
            /* class org.apache.poi.xslf.usermodel.XSLFSimpleShape.AnonymousClass7 */

            @Override // org.apache.poi.xslf.model.PropertyFetcher
            public boolean fetch(XSLFShape xSLFShape) {
                XSLFPropertiesDelegate.XSLFEffectProperties effectDelegate = XSLFPropertiesDelegate.getEffectDelegate(xSLFShape.getShapeProperties());
                if (effectDelegate == null || !effectDelegate.isSetEffectLst()) {
                    return false;
                }
                CTOuterShadowEffect outerShdw = effectDelegate.getEffectLst().getOuterShdw();
                if (outerShdw == null) {
                    outerShdw = XSLFSimpleShape.NO_SHADOW;
                }
                setValue(outerShdw);
                return true;
            }
        };
        fetchShapeProperty(r0);
        CTOuterShadowEffect cTOuterShadowEffect = (CTOuterShadowEffect) r0.getValue();
        if (!(cTOuterShadowEffect != null || (spStyle = getSpStyle()) == null || spStyle.getEffectRef() == null || (idx = (int) spStyle.getEffectRef().getIdx()) == 0)) {
            cTOuterShadowEffect = getSheet().getTheme().getXmlObject().getThemeElements().getFmtScheme().getEffectStyleLst().getEffectStyleArray(idx - 1).getEffectLst().getOuterShdw();
        }
        if (cTOuterShadowEffect == null || cTOuterShadowEffect == NO_SHADOW) {
            return null;
        }
        return new XSLFShadow(cTOuterShadowEffect, this);
    }
}
