package org.apache.poi.xslf.usermodel;

import b.b.a.a.a;
import java.util.ArrayList;
import java.util.Iterator;
import java.util.List;
import org.apache.poi.hssf.usermodel.HSSFFont;
import org.apache.poi.java.awt.Color;
import org.apache.poi.sl.draw.DrawPaint;
import org.apache.poi.sl.usermodel.AutoNumberingScheme;
import org.apache.poi.sl.usermodel.PaintStyle;
import org.apache.poi.sl.usermodel.TextParagraph;
import org.apache.poi.sl.usermodel.TextShape;
import org.apache.poi.ss.formula.functions.NumericFunction;
import org.apache.poi.util.Internal;
import org.apache.poi.util.Units;
import org.apache.poi.xslf.model.ParagraphPropertyFetcher;
import org.apache.xmlbeans.XmlCursor;
import org.apache.xmlbeans.XmlObject;
import org.openxmlformats.schemas.drawingml.x2006.main.CTColor;
import org.openxmlformats.schemas.drawingml.x2006.main.CTRegularTextRun;
import org.openxmlformats.schemas.drawingml.x2006.main.CTTextAutonumberBullet;
import org.openxmlformats.schemas.drawingml.x2006.main.CTTextCharacterProperties;
import org.openxmlformats.schemas.drawingml.x2006.main.CTTextField;
import org.openxmlformats.schemas.drawingml.x2006.main.CTTextLineBreak;
import org.openxmlformats.schemas.drawingml.x2006.main.CTTextNormalAutofit;
import org.openxmlformats.schemas.drawingml.x2006.main.CTTextParagraph;
import org.openxmlformats.schemas.drawingml.x2006.main.CTTextParagraphProperties;
import org.openxmlformats.schemas.drawingml.x2006.main.CTTextSpacing;
import org.openxmlformats.schemas.drawingml.x2006.main.CTTextTabStopList;
import org.openxmlformats.schemas.drawingml.x2006.main.STTextAlignType;
import org.openxmlformats.schemas.drawingml.x2006.main.STTextAutonumberScheme;
import org.openxmlformats.schemas.drawingml.x2006.main.STTextFontAlignType;
import org.openxmlformats.schemas.presentationml.x2006.main.CTPlaceholder;

public class XSLFTextParagraph implements TextParagraph<XSLFShape, XSLFTextParagraph, XSLFTextRun> {
    public final CTTextParagraph _p;
    public final List<XSLFTextRun> _runs = new ArrayList();
    public final XSLFTextShape _shape;

    public XSLFTextParagraph(CTTextParagraph cTTextParagraph, XSLFTextShape xSLFTextShape) {
        this._p = cTTextParagraph;
        this._shape = xSLFTextShape;
        XmlCursor newCursor = this._p.newCursor();
        try {
            if (newCursor.toFirstChild()) {
                do {
                    XmlObject object = newCursor.getObject();
                    if (object instanceof CTTextLineBreak) {
                        this._runs.add(new XSLFLineBreak((CTTextLineBreak) object, this));
                    } else if ((object instanceof CTRegularTextRun) || (object instanceof CTTextField)) {
                        this._runs.add(new XSLFTextRun(object, this));
                    }
                } while (newCursor.toNextSibling());
            }
        } finally {
            newCursor.dispose();
        }
    }

    public static boolean doubleEquals(Double d2, Double d3) {
        return d2 == d3 || (d2 != null && d2.equals(d3));
    }

    /* JADX WARN: Type inference failed for: r0v0, types: [org.apache.poi.xslf.usermodel.XSLFShape, org.apache.poi.xslf.usermodel.XSLFTextShape] */
    /* JADX WARN: Type inference failed for: r1v0, types: [org.apache.poi.xslf.usermodel.XSLFSheet] */
    /* JADX WARN: Type inference failed for: r0v3, types: [org.apache.poi.xslf.usermodel.XMLSlideShow] */
    /* JADX WARNING: Unknown variable types count: 3 */
    private <T> boolean fetchParagraphProperty(ParagraphPropertyFetcher<T> paragraphPropertyFetcher) {
        boolean fetchShapeProperty;
        CTTextParagraphProperties defaultParagraphStyle;
        ?? parentShape = getParentShape();
        ?? sheet = parentShape.getSheet();
        if ((this._p.isSetPPr() ? paragraphPropertyFetcher.fetch(this._p.getPPr()) : false) || (fetchShapeProperty = parentShape.fetchShapeProperty(paragraphPropertyFetcher))) {
            return true;
        }
        if (parentShape.getCTPlaceholder() == null && (defaultParagraphStyle = sheet.getSlideShow().getDefaultParagraphStyle(getIndentLevel())) != null) {
            fetchShapeProperty = paragraphPropertyFetcher.fetch(defaultParagraphStyle);
        }
        if (fetchShapeProperty) {
            return true;
        }
        CTTextParagraphProperties defaultMasterStyle = getDefaultMasterStyle();
        if (defaultMasterStyle != null) {
            fetchShapeProperty = paragraphPropertyFetcher.fetch(defaultMasterStyle);
        }
        return fetchShapeProperty;
    }

    public XSLFTextRun addLineBreak() {
        XSLFLineBreak xSLFLineBreak = new XSLFLineBreak(this._p.addNewBr(), this);
        CTTextCharacterProperties rPr = xSLFLineBreak.getRPr(true);
        if (this._runs.size() > 0) {
            List<XSLFTextRun> list = this._runs;
            rPr.set(list.get(list.size() - 1).getRPr(true));
        }
        this._runs.add(xSLFLineBreak);
        return xSLFLineBreak;
    }

    public XSLFTextRun addNewTextRun() {
        CTRegularTextRun addNewR = this._p.addNewR();
        addNewR.addNewRPr().setLang("en-US");
        XSLFTextRun newTextRun = newTextRun(addNewR);
        this._runs.add(newTextRun);
        return newTextRun;
    }

    public void addTabStop(double d2) {
        CTTextParagraphProperties pPr = this._p.isSetPPr() ? this._p.getPPr() : this._p.addNewPPr();
        (pPr.isSetTabLst() ? pPr.getTabLst() : pPr.addNewTabLst()).addNewTab().setPos(Units.toEMU(d2));
    }

    public void clearButKeepProperties() {
        CTTextParagraph xmlObject = getXmlObject();
        for (int sizeOfBrArray = xmlObject.sizeOfBrArray(); sizeOfBrArray > 0; sizeOfBrArray--) {
            xmlObject.removeBr(sizeOfBrArray - 1);
        }
        for (int sizeOfFldArray = xmlObject.sizeOfFldArray(); sizeOfFldArray > 0; sizeOfFldArray--) {
            xmlObject.removeFld(sizeOfFldArray - 1);
        }
        if (!this._runs.isEmpty()) {
            int size = this._runs.size();
            CTTextCharacterProperties rPr = this._runs.get(size - 1).getRPr(false);
            if (rPr != null) {
                if (xmlObject.isSetEndParaRPr()) {
                    xmlObject.unsetEndParaRPr();
                }
                xmlObject.addNewEndParaRPr().set(rPr);
            }
            while (size > 0) {
                xmlObject.removeR(size - 1);
                size--;
            }
            this._runs.clear();
        }
    }

    public void copy(XSLFTextParagraph xSLFTextParagraph) {
        if (xSLFTextParagraph != this) {
            CTTextParagraph xmlObject = getXmlObject();
            CTTextParagraph xmlObject2 = xSLFTextParagraph.getXmlObject();
            if (xmlObject.isSetPPr()) {
                xmlObject.unsetPPr();
            }
            if (xmlObject.isSetEndParaRPr()) {
                xmlObject.unsetEndParaRPr();
            }
            this._runs.clear();
            for (int sizeOfBrArray = xmlObject.sizeOfBrArray(); sizeOfBrArray > 0; sizeOfBrArray--) {
                xmlObject.removeBr(sizeOfBrArray - 1);
            }
            for (int sizeOfRArray = xmlObject.sizeOfRArray(); sizeOfRArray > 0; sizeOfRArray--) {
                xmlObject.removeR(sizeOfRArray - 1);
            }
            for (int sizeOfFldArray = xmlObject.sizeOfFldArray(); sizeOfFldArray > 0; sizeOfFldArray--) {
                xmlObject.removeFld(sizeOfFldArray - 1);
            }
            XmlCursor newCursor = xmlObject.newCursor();
            newCursor.toEndToken();
            XmlCursor newCursor2 = xmlObject2.newCursor();
            newCursor2.copyXmlContents(newCursor);
            newCursor2.dispose();
            newCursor.dispose();
            List<XSLFTextRun> textRuns = xSLFTextParagraph.getTextRuns();
            CTRegularTextRun[] rArray = xmlObject.getRArray();
            int length = rArray.length;
            int i2 = 0;
            int i3 = 0;
            while (i2 < length) {
                XSLFTextRun newTextRun = newTextRun(rArray[i2]);
                newTextRun.copy(textRuns.get(i3));
                this._runs.add(newTextRun);
                i2++;
                i3++;
            }
            TextParagraph.TextAlign textAlign = xSLFTextParagraph.getTextAlign();
            if (textAlign != getTextAlign()) {
                setTextAlign(textAlign);
            }
            boolean isBullet = xSLFTextParagraph.isBullet();
            if (isBullet != isBullet()) {
                setBullet(isBullet);
                if (isBullet) {
                    String bulletFont = xSLFTextParagraph.getBulletFont();
                    if (bulletFont != null && !bulletFont.equals(getBulletFont())) {
                        setBulletFont(bulletFont);
                    }
                    String bulletCharacter = xSLFTextParagraph.getBulletCharacter();
                    if (bulletCharacter != null && !bulletCharacter.equals(getBulletCharacter())) {
                        setBulletCharacter(bulletCharacter);
                    }
                    PaintStyle bulletFontColor = xSLFTextParagraph.getBulletFontColor();
                    if (bulletFontColor != null && !bulletFontColor.equals(getBulletFontColor())) {
                        setBulletFontColor(bulletFontColor);
                    }
                    Double bulletFontSize = xSLFTextParagraph.getBulletFontSize();
                    if (!doubleEquals(bulletFontSize, getBulletFontSize())) {
                        setBulletFontSize(bulletFontSize.doubleValue());
                    }
                }
            }
            Double leftMargin = xSLFTextParagraph.getLeftMargin();
            if (!doubleEquals(leftMargin, getLeftMargin())) {
                setLeftMargin(leftMargin);
            }
            Double indent = xSLFTextParagraph.getIndent();
            if (!doubleEquals(indent, getIndent())) {
                setIndent(indent);
            }
            Double spaceAfter = xSLFTextParagraph.getSpaceAfter();
            if (!doubleEquals(spaceAfter, getSpaceAfter())) {
                setSpaceAfter(spaceAfter);
            }
            Double spaceBefore = xSLFTextParagraph.getSpaceBefore();
            if (!doubleEquals(spaceBefore, getSpaceBefore())) {
                setSpaceBefore(spaceBefore);
            }
            Double lineSpacing = xSLFTextParagraph.getLineSpacing();
            if (!doubleEquals(lineSpacing, getLineSpacing())) {
                setLineSpacing(lineSpacing);
            }
        }
    }

    public AutoNumberingScheme getAutoNumberingScheme() {
        AnonymousClass7 r0 = new ParagraphPropertyFetcher<AutoNumberingScheme>(getIndentLevel()) {
            /* class org.apache.poi.xslf.usermodel.XSLFTextParagraph.AnonymousClass7 */

            @Override // org.apache.poi.xslf.model.ParagraphPropertyFetcher
            public boolean fetch(CTTextParagraphProperties cTTextParagraphProperties) {
                AutoNumberingScheme forOoxmlID;
                if (!cTTextParagraphProperties.isSetBuAutoNum() || (forOoxmlID = AutoNumberingScheme.forOoxmlID(cTTextParagraphProperties.getBuAutoNum().getType().intValue())) == null) {
                    return false;
                }
                setValue(forOoxmlID);
                return true;
            }
        };
        fetchParagraphProperty(r0);
        return (AutoNumberingScheme) r0.getValue();
    }

    public Integer getAutoNumberingStartAt() {
        AnonymousClass8 r0 = new ParagraphPropertyFetcher<Integer>(getIndentLevel()) {
            /* class org.apache.poi.xslf.usermodel.XSLFTextParagraph.AnonymousClass8 */

            @Override // org.apache.poi.xslf.model.ParagraphPropertyFetcher
            public boolean fetch(CTTextParagraphProperties cTTextParagraphProperties) {
                if (!cTTextParagraphProperties.isSetBuAutoNum() || !cTTextParagraphProperties.getBuAutoNum().isSetStartAt()) {
                    return false;
                }
                setValue(Integer.valueOf(cTTextParagraphProperties.getBuAutoNum().getStartAt()));
                return true;
            }
        };
        fetchParagraphProperty(r0);
        return (Integer) r0.getValue();
    }

    public String getBulletCharacter() {
        AnonymousClass4 r0 = new ParagraphPropertyFetcher<String>(getIndentLevel()) {
            /* class org.apache.poi.xslf.usermodel.XSLFTextParagraph.AnonymousClass4 */

            @Override // org.apache.poi.xslf.model.ParagraphPropertyFetcher
            public boolean fetch(CTTextParagraphProperties cTTextParagraphProperties) {
                if (!cTTextParagraphProperties.isSetBuChar()) {
                    return false;
                }
                setValue(cTTextParagraphProperties.getBuChar().getChar());
                return true;
            }
        };
        fetchParagraphProperty(r0);
        return (String) r0.getValue();
    }

    public String getBulletFont() {
        AnonymousClass3 r0 = new ParagraphPropertyFetcher<String>(getIndentLevel()) {
            /* class org.apache.poi.xslf.usermodel.XSLFTextParagraph.AnonymousClass3 */

            @Override // org.apache.poi.xslf.model.ParagraphPropertyFetcher
            public boolean fetch(CTTextParagraphProperties cTTextParagraphProperties) {
                if (!cTTextParagraphProperties.isSetBuFont()) {
                    return false;
                }
                setValue(cTTextParagraphProperties.getBuFont().getTypeface());
                return true;
            }
        };
        fetchParagraphProperty(r0);
        return (String) r0.getValue();
    }

    /* JADX WARN: Type inference failed for: r0v0, types: [org.apache.poi.xslf.usermodel.XSLFShape, org.apache.poi.xslf.usermodel.XSLFTextShape] */
    /* JADX WARN: Type inference failed for: r0v1, types: [org.apache.poi.xslf.usermodel.XSLFSheet] */
    /* JADX WARNING: Unknown variable types count: 2 */
    public PaintStyle getBulletFontColor() {
        final XSLFTheme theme = getParentShape().getSheet().getTheme();
        AnonymousClass5 r1 = new ParagraphPropertyFetcher<Color>(getIndentLevel()) {
            /* class org.apache.poi.xslf.usermodel.XSLFTextParagraph.AnonymousClass5 */

            @Override // org.apache.poi.xslf.model.ParagraphPropertyFetcher
            public boolean fetch(CTTextParagraphProperties cTTextParagraphProperties) {
                if (!cTTextParagraphProperties.isSetBuClr()) {
                    return false;
                }
                setValue(new XSLFColor(cTTextParagraphProperties.getBuClr(), theme, null).getColor());
                return true;
            }
        };
        fetchParagraphProperty(r1);
        Color color = (Color) r1.getValue();
        if (color == null) {
            return null;
        }
        return DrawPaint.createSolidPaint(color);
    }

    public Double getBulletFontSize() {
        AnonymousClass6 r0 = new ParagraphPropertyFetcher<Double>(getIndentLevel()) {
            /* class org.apache.poi.xslf.usermodel.XSLFTextParagraph.AnonymousClass6 */

            @Override // org.apache.poi.xslf.model.ParagraphPropertyFetcher
            public boolean fetch(CTTextParagraphProperties cTTextParagraphProperties) {
                if (cTTextParagraphProperties.isSetBuSzPct()) {
                    setValue(Double.valueOf(((double) cTTextParagraphProperties.getBuSzPct().getVal()) * 0.001d));
                    return true;
                } else if (!cTTextParagraphProperties.isSetBuSzPts()) {
                    return false;
                } else {
                    setValue(Double.valueOf(((double) (-cTTextParagraphProperties.getBuSzPts().getVal())) * 0.01d));
                    return true;
                }
            }
        };
        fetchParagraphProperty(r0);
        return (Double) r0.getValue();
    }

    @Override // org.apache.poi.sl.usermodel.TextParagraph
    public TextParagraph.BulletStyle getBulletStyle() {
        if (!isBullet()) {
            return null;
        }
        return new TextParagraph.BulletStyle() {
            /* class org.apache.poi.xslf.usermodel.XSLFTextParagraph.AnonymousClass18 */

            @Override // org.apache.poi.sl.usermodel.TextParagraph.BulletStyle
            public AutoNumberingScheme getAutoNumberingScheme() {
                return XSLFTextParagraph.this.getAutoNumberingScheme();
            }

            @Override // org.apache.poi.sl.usermodel.TextParagraph.BulletStyle
            public Integer getAutoNumberingStartAt() {
                return XSLFTextParagraph.this.getAutoNumberingStartAt();
            }

            @Override // org.apache.poi.sl.usermodel.TextParagraph.BulletStyle
            public String getBulletCharacter() {
                return XSLFTextParagraph.this.getBulletCharacter();
            }

            @Override // org.apache.poi.sl.usermodel.TextParagraph.BulletStyle
            public String getBulletFont() {
                return XSLFTextParagraph.this.getBulletFont();
            }

            @Override // org.apache.poi.sl.usermodel.TextParagraph.BulletStyle
            public PaintStyle getBulletFontColor() {
                return XSLFTextParagraph.this.getBulletFontColor();
            }

            @Override // org.apache.poi.sl.usermodel.TextParagraph.BulletStyle
            public Double getBulletFontSize() {
                return XSLFTextParagraph.this.getBulletFontSize();
            }

            public void setBulletFontColor(Color color) {
                setBulletFontColor(DrawPaint.createSolidPaint(color));
            }

            @Override // org.apache.poi.sl.usermodel.TextParagraph.BulletStyle
            public void setBulletFontColor(PaintStyle paintStyle) {
                XSLFTextParagraph.this.setBulletFontColor(paintStyle);
            }
        };
    }

    @Override // org.apache.poi.sl.usermodel.TextParagraph
    public String getDefaultFontFamily() {
        return this._runs.isEmpty() ? HSSFFont.FONT_ARIAL : this._runs.get(0).getFontFamily();
    }

    @Override // org.apache.poi.sl.usermodel.TextParagraph
    public Double getDefaultFontSize() {
        CTTextParagraphProperties defaultMasterStyle;
        CTTextCharacterProperties endParaRPr = this._p.getEndParaRPr();
        if ((endParaRPr == null || !endParaRPr.isSetSz()) && (defaultMasterStyle = getDefaultMasterStyle()) != null) {
            endParaRPr = defaultMasterStyle.getDefRPr();
        }
        return Double.valueOf((endParaRPr == null || !endParaRPr.isSetSz()) ? 12.0d : ((double) endParaRPr.getSz()) / 100.0d);
    }

    /* JADX INFO: finally extract failed */
    /* JADX WARN: Multi-variable type inference failed */
    /* JADX WARN: Type inference failed for: r3v2, types: [org.apache.poi.sl.usermodel.Sheet, org.apache.poi.xslf.usermodel.XSLFSheet] */
    /* JADX WARN: Type inference failed for: r3v5 */
    /* JADX WARNING: Removed duplicated region for block: B:20:0x003d  */
    public CTTextParagraphProperties getDefaultMasterStyle() {
        int i2;
        String str;
        XSLFSheet xSLFSheet;
        CTPlaceholder cTPlaceholder = this._shape.getCTPlaceholder();
        if (cTPlaceholder == null) {
            i2 = -1;
        } else {
            i2 = cTPlaceholder.getType().intValue();
        }
        if (i2 != -1) {
            if (i2 == 1 || i2 == 3) {
                str = "titleStyle";
                int indentLevel = getIndentLevel();
                for (xSLFSheet = this._shape.getSheet(); xSLFSheet != 0; xSLFSheet = (XSLFSheet) xSLFSheet.getMasterSheet()) {
                    XmlCursor newCursor = xSLFSheet.getXmlObject().newCursor();
                    try {
                        newCursor.push();
                        if ((newCursor.toChild(XSLFShape.PML_NS, "txStyles") && newCursor.toChild(XSLFShape.PML_NS, str)) || (newCursor.pop() && newCursor.toChild(XSLFShape.PML_NS, "notesStyle"))) {
                            while (indentLevel >= 0) {
                                newCursor.push();
                                if (newCursor.toChild("http://schemas.openxmlformats.org/drawingml/2006/main", "lvl" + (indentLevel + 1) + "pPr")) {
                                    CTTextParagraphProperties cTTextParagraphProperties = (CTTextParagraphProperties) newCursor.getObject();
                                    newCursor.dispose();
                                    return cTTextParagraphProperties;
                                }
                                newCursor.pop();
                                indentLevel--;
                            }
                            continue;
                        }
                        newCursor.dispose();
                    } catch (Throwable th) {
                        newCursor.dispose();
                        throw th;
                    }
                }
                return null;
            } else if (!(i2 == 5 || i2 == 6 || i2 == 7)) {
                str = "bodyStyle";
                int indentLevel2 = getIndentLevel();
                while (xSLFSheet != 0) {
                }
                return null;
            }
        }
        str = "otherStyle";
        int indentLevel22 = getIndentLevel();
        while (xSLFSheet != 0) {
        }
        return null;
    }

    @Override // org.apache.poi.sl.usermodel.TextParagraph
    public Double getDefaultTabSize() {
        AnonymousClass12 r0 = new ParagraphPropertyFetcher<Double>(getIndentLevel()) {
            /* class org.apache.poi.xslf.usermodel.XSLFTextParagraph.AnonymousClass12 */

            @Override // org.apache.poi.xslf.model.ParagraphPropertyFetcher
            public boolean fetch(CTTextParagraphProperties cTTextParagraphProperties) {
                if (!cTTextParagraphProperties.isSetDefTabSz()) {
                    return false;
                }
                setValue(Double.valueOf(Units.toPoints((long) cTTextParagraphProperties.getDefTabSz())));
                return true;
            }
        };
        fetchParagraphProperty(r0);
        return (Double) r0.getValue();
    }

    @Override // org.apache.poi.sl.usermodel.TextParagraph
    public TextParagraph.FontAlign getFontAlign() {
        AnonymousClass2 r0 = new ParagraphPropertyFetcher<TextParagraph.FontAlign>(getIndentLevel()) {
            /* class org.apache.poi.xslf.usermodel.XSLFTextParagraph.AnonymousClass2 */

            @Override // org.apache.poi.xslf.model.ParagraphPropertyFetcher
            public boolean fetch(CTTextParagraphProperties cTTextParagraphProperties) {
                if (!cTTextParagraphProperties.isSetFontAlgn()) {
                    return false;
                }
                setValue(TextParagraph.FontAlign.values()[cTTextParagraphProperties.getFontAlgn().intValue() - 1]);
                return true;
            }
        };
        fetchParagraphProperty(r0);
        return (TextParagraph.FontAlign) r0.getValue();
    }

    @Override // org.apache.poi.sl.usermodel.TextParagraph
    public Double getIndent() {
        AnonymousClass9 r0 = new ParagraphPropertyFetcher<Double>(getIndentLevel()) {
            /* class org.apache.poi.xslf.usermodel.XSLFTextParagraph.AnonymousClass9 */

            @Override // org.apache.poi.xslf.model.ParagraphPropertyFetcher
            public boolean fetch(CTTextParagraphProperties cTTextParagraphProperties) {
                if (!cTTextParagraphProperties.isSetIndent()) {
                    return false;
                }
                setValue(Double.valueOf(Units.toPoints((long) cTTextParagraphProperties.getIndent())));
                return true;
            }
        };
        fetchParagraphProperty(r0);
        return (Double) r0.getValue();
    }

    @Override // org.apache.poi.sl.usermodel.TextParagraph
    public int getIndentLevel() {
        CTTextParagraphProperties pPr = this._p.getPPr();
        if (pPr == null || !pPr.isSetLvl()) {
            return 0;
        }
        return pPr.getLvl();
    }

    @Override // org.apache.poi.sl.usermodel.TextParagraph
    public Double getLeftMargin() {
        AnonymousClass10 r0 = new ParagraphPropertyFetcher<Double>(getIndentLevel()) {
            /* class org.apache.poi.xslf.usermodel.XSLFTextParagraph.AnonymousClass10 */

            @Override // org.apache.poi.xslf.model.ParagraphPropertyFetcher
            public boolean fetch(CTTextParagraphProperties cTTextParagraphProperties) {
                if (!cTTextParagraphProperties.isSetMarL()) {
                    return false;
                }
                setValue(Double.valueOf(Units.toPoints((long) cTTextParagraphProperties.getMarL())));
                return true;
            }
        };
        fetchParagraphProperty(r0);
        return (Double) r0.getValue();
    }

    /* JADX WARN: Type inference failed for: r1v2, types: [org.apache.poi.xslf.usermodel.XSLFTextShape] */
    /* JADX WARNING: Unknown variable types count: 1 */
    @Override // org.apache.poi.sl.usermodel.TextParagraph
    public Double getLineSpacing() {
        CTTextNormalAutofit normAutofit;
        AnonymousClass14 r0 = new ParagraphPropertyFetcher<Double>(getIndentLevel()) {
            /* class org.apache.poi.xslf.usermodel.XSLFTextParagraph.AnonymousClass14 */

            @Override // org.apache.poi.xslf.model.ParagraphPropertyFetcher
            public boolean fetch(CTTextParagraphProperties cTTextParagraphProperties) {
                if (!cTTextParagraphProperties.isSetLnSpc()) {
                    return false;
                }
                CTTextSpacing lnSpc = cTTextParagraphProperties.getLnSpc();
                if (lnSpc.isSetSpcPct()) {
                    setValue(Double.valueOf(((double) lnSpc.getSpcPct().getVal()) * 0.001d));
                    return true;
                } else if (!lnSpc.isSetSpcPts()) {
                    return true;
                } else {
                    setValue(Double.valueOf(((double) (-lnSpc.getSpcPts().getVal())) * 0.01d));
                    return true;
                }
            }
        };
        fetchParagraphProperty(r0);
        Double d2 = (Double) r0.getValue();
        return (d2 == null || d2.doubleValue() <= NumericFunction.LOG_10_TO_BASE_e || (normAutofit = getParentShape().getTextBodyPr().getNormAutofit()) == null) ? d2 : Double.valueOf(d2.doubleValue() * (1.0d - (((double) normAutofit.getLnSpcReduction()) / 100000.0d)));
    }

    public String getRenderableText() {
        StringBuilder sb = new StringBuilder();
        for (XSLFTextRun xSLFTextRun : this._runs) {
            sb.append(xSLFTextRun.getRenderableText());
        }
        return sb.toString();
    }

    @Override // org.apache.poi.sl.usermodel.TextParagraph
    public Double getRightMargin() {
        AnonymousClass11 r0 = new ParagraphPropertyFetcher<Double>(getIndentLevel()) {
            /* class org.apache.poi.xslf.usermodel.XSLFTextParagraph.AnonymousClass11 */

            @Override // org.apache.poi.xslf.model.ParagraphPropertyFetcher
            public boolean fetch(CTTextParagraphProperties cTTextParagraphProperties) {
                if (!cTTextParagraphProperties.isSetMarR()) {
                    return false;
                }
                setValue(Double.valueOf(Units.toPoints((long) cTTextParagraphProperties.getMarR())));
                return true;
            }
        };
        fetchParagraphProperty(r0);
        return (Double) r0.getValue();
    }

    @Override // org.apache.poi.sl.usermodel.TextParagraph
    public Double getSpaceAfter() {
        AnonymousClass16 r0 = new ParagraphPropertyFetcher<Double>(getIndentLevel()) {
            /* class org.apache.poi.xslf.usermodel.XSLFTextParagraph.AnonymousClass16 */

            @Override // org.apache.poi.xslf.model.ParagraphPropertyFetcher
            public boolean fetch(CTTextParagraphProperties cTTextParagraphProperties) {
                if (!cTTextParagraphProperties.isSetSpcAft()) {
                    return false;
                }
                CTTextSpacing spcAft = cTTextParagraphProperties.getSpcAft();
                if (spcAft.isSetSpcPct()) {
                    setValue(Double.valueOf(((double) spcAft.getSpcPct().getVal()) * 0.001d));
                    return true;
                } else if (!spcAft.isSetSpcPts()) {
                    return true;
                } else {
                    setValue(Double.valueOf(((double) (-spcAft.getSpcPts().getVal())) * 0.01d));
                    return true;
                }
            }
        };
        fetchParagraphProperty(r0);
        return (Double) r0.getValue();
    }

    @Override // org.apache.poi.sl.usermodel.TextParagraph
    public Double getSpaceBefore() {
        AnonymousClass15 r0 = new ParagraphPropertyFetcher<Double>(getIndentLevel()) {
            /* class org.apache.poi.xslf.usermodel.XSLFTextParagraph.AnonymousClass15 */

            @Override // org.apache.poi.xslf.model.ParagraphPropertyFetcher
            public boolean fetch(CTTextParagraphProperties cTTextParagraphProperties) {
                if (!cTTextParagraphProperties.isSetSpcBef()) {
                    return false;
                }
                CTTextSpacing spcBef = cTTextParagraphProperties.getSpcBef();
                if (spcBef.isSetSpcPct()) {
                    setValue(Double.valueOf(((double) spcBef.getSpcPct().getVal()) * 0.001d));
                    return true;
                } else if (!spcBef.isSetSpcPts()) {
                    return true;
                } else {
                    setValue(Double.valueOf(((double) (-spcBef.getSpcPts().getVal())) * 0.01d));
                    return true;
                }
            }
        };
        fetchParagraphProperty(r0);
        return (Double) r0.getValue();
    }

    public double getTabStop(final int i2) {
        AnonymousClass13 r0 = new ParagraphPropertyFetcher<Double>(getIndentLevel()) {
            /* class org.apache.poi.xslf.usermodel.XSLFTextParagraph.AnonymousClass13 */

            @Override // org.apache.poi.xslf.model.ParagraphPropertyFetcher
            public boolean fetch(CTTextParagraphProperties cTTextParagraphProperties) {
                if (!cTTextParagraphProperties.isSetTabLst()) {
                    return false;
                }
                CTTextTabStopList tabLst = cTTextParagraphProperties.getTabLst();
                if (i2 >= tabLst.sizeOfTabArray()) {
                    return false;
                }
                setValue(Double.valueOf(Units.toPoints((long) tabLst.getTabArray(i2).getPos())));
                return true;
            }
        };
        fetchParagraphProperty(r0);
        return r0.getValue() == null ? NumericFunction.LOG_10_TO_BASE_e : ((Double) r0.getValue()).doubleValue();
    }

    public String getText() {
        StringBuilder sb = new StringBuilder();
        for (XSLFTextRun xSLFTextRun : this._runs) {
            sb.append(xSLFTextRun.getRawText());
        }
        return sb.toString();
    }

    @Override // org.apache.poi.sl.usermodel.TextParagraph
    public TextParagraph.TextAlign getTextAlign() {
        AnonymousClass1 r0 = new ParagraphPropertyFetcher<TextParagraph.TextAlign>(getIndentLevel()) {
            /* class org.apache.poi.xslf.usermodel.XSLFTextParagraph.AnonymousClass1 */

            @Override // org.apache.poi.xslf.model.ParagraphPropertyFetcher
            public boolean fetch(CTTextParagraphProperties cTTextParagraphProperties) {
                if (!cTTextParagraphProperties.isSetAlgn()) {
                    return false;
                }
                setValue(TextParagraph.TextAlign.values()[cTTextParagraphProperties.getAlgn().intValue() - 1]);
                return true;
            }
        };
        fetchParagraphProperty(r0);
        return (TextParagraph.TextAlign) r0.getValue();
    }

    @Override // org.apache.poi.sl.usermodel.TextParagraph
    public List<XSLFTextRun> getTextRuns() {
        return this._runs;
    }

    @Internal
    public CTTextParagraph getXmlObject() {
        return this._p;
    }

    public boolean isBullet() {
        AnonymousClass17 r0 = new ParagraphPropertyFetcher<Boolean>(getIndentLevel()) {
            /* class org.apache.poi.xslf.usermodel.XSLFTextParagraph.AnonymousClass17 */

            @Override // org.apache.poi.xslf.model.ParagraphPropertyFetcher
            public boolean fetch(CTTextParagraphProperties cTTextParagraphProperties) {
                if (cTTextParagraphProperties.isSetBuNone()) {
                    setValue(false);
                    return true;
                } else if (!cTTextParagraphProperties.isSetBuFont() && !cTTextParagraphProperties.isSetBuChar()) {
                    return false;
                } else {
                    setValue(true);
                    return true;
                }
            }
        };
        fetchParagraphProperty(r0);
        if (r0.getValue() == null) {
            return false;
        }
        return ((Boolean) r0.getValue()).booleanValue();
    }

    @Override // org.apache.poi.sl.usermodel.TextParagraph
    public boolean isHeaderOrFooter() {
        int i2;
        CTPlaceholder cTPlaceholder = this._shape.getCTPlaceholder();
        if (cTPlaceholder == null) {
            i2 = -1;
        } else {
            i2 = cTPlaceholder.getType().intValue();
        }
        return i2 == 5 || i2 == 6 || i2 == 7 || i2 == 8;
    }

    @Override // java.lang.Iterable
    public Iterator<XSLFTextRun> iterator() {
        return this._runs.iterator();
    }

    public XSLFTextRun newTextRun(CTRegularTextRun cTRegularTextRun) {
        return new XSLFTextRun(cTRegularTextRun, this);
    }

    public void setBullet(boolean z) {
        if (isBullet() != z) {
            CTTextParagraphProperties pPr = this._p.isSetPPr() ? this._p.getPPr() : this._p.addNewPPr();
            if (z) {
                pPr.addNewBuFont().setTypeface(HSSFFont.FONT_ARIAL);
                pPr.addNewBuChar().setChar("•");
                return;
            }
            if (pPr.isSetBuFont()) {
                pPr.unsetBuFont();
            }
            if (pPr.isSetBuChar()) {
                pPr.unsetBuChar();
            }
            if (pPr.isSetBuAutoNum()) {
                pPr.unsetBuAutoNum();
            }
            if (pPr.isSetBuBlip()) {
                pPr.unsetBuBlip();
            }
            if (pPr.isSetBuClr()) {
                pPr.unsetBuClr();
            }
            if (pPr.isSetBuClrTx()) {
                pPr.unsetBuClrTx();
            }
            if (pPr.isSetBuFont()) {
                pPr.unsetBuFont();
            }
            if (pPr.isSetBuFontTx()) {
                pPr.unsetBuFontTx();
            }
            if (pPr.isSetBuSzPct()) {
                pPr.unsetBuSzPct();
            }
            if (pPr.isSetBuSzPts()) {
                pPr.unsetBuSzPts();
            }
            if (pPr.isSetBuSzTx()) {
                pPr.unsetBuSzTx();
            }
            pPr.addNewBuNone();
        }
    }

    public void setBulletAutoNumber(AutoNumberingScheme autoNumberingScheme, int i2) {
        if (i2 >= 1) {
            CTTextParagraphProperties pPr = this._p.isSetPPr() ? this._p.getPPr() : this._p.addNewPPr();
            CTTextAutonumberBullet buAutoNum = pPr.isSetBuAutoNum() ? pPr.getBuAutoNum() : pPr.addNewBuAutoNum();
            buAutoNum.setType(STTextAutonumberScheme.Enum.forInt(autoNumberingScheme.ooxmlId));
            buAutoNum.setStartAt(i2);
            return;
        }
        throw new IllegalArgumentException("Start Number must be greater or equal that 1");
    }

    public void setBulletCharacter(String str) {
        CTTextParagraphProperties pPr = this._p.isSetPPr() ? this._p.getPPr() : this._p.addNewPPr();
        (pPr.isSetBuChar() ? pPr.getBuChar() : pPr.addNewBuChar()).setChar(str);
    }

    public void setBulletFont(String str) {
        CTTextParagraphProperties pPr = this._p.isSetPPr() ? this._p.getPPr() : this._p.addNewPPr();
        (pPr.isSetBuFont() ? pPr.getBuFont() : pPr.addNewBuFont()).setTypeface(str);
    }

    public void setBulletFontColor(Color color) {
        setBulletFontColor(DrawPaint.createSolidPaint(color));
    }

    public void setBulletFontSize(double d2) {
        CTTextParagraphProperties pPr = this._p.isSetPPr() ? this._p.getPPr() : this._p.addNewPPr();
        if (d2 >= NumericFunction.LOG_10_TO_BASE_e) {
            (pPr.isSetBuSzPct() ? pPr.getBuSzPct() : pPr.addNewBuSzPct()).setVal((int) (d2 * 1000.0d));
            if (pPr.isSetBuSzPts()) {
                pPr.unsetBuSzPts();
                return;
            }
            return;
        }
        (pPr.isSetBuSzPts() ? pPr.getBuSzPts() : pPr.addNewBuSzPts()).setVal((int) ((-d2) * 100.0d));
        if (pPr.isSetBuSzPct()) {
            pPr.unsetBuSzPct();
        }
    }

    @Override // org.apache.poi.sl.usermodel.TextParagraph
    public void setBulletStyle(Object... objArr) {
        if (objArr.length == 0) {
            setBullet(false);
            return;
        }
        setBullet(true);
        for (Object obj : objArr) {
            if (obj instanceof Number) {
                setBulletFontSize(((Number) obj).doubleValue());
            } else if (obj instanceof Color) {
                setBulletFontColor((Color) obj);
            } else if (obj instanceof Character) {
                setBulletCharacter(obj.toString());
            } else if (obj instanceof String) {
                setBulletFont((String) obj);
            } else if (obj instanceof AutoNumberingScheme) {
                setBulletAutoNumber((AutoNumberingScheme) obj, 0);
            }
        }
    }

    public void setFontAlign(TextParagraph.FontAlign fontAlign) {
        CTTextParagraphProperties pPr = this._p.isSetPPr() ? this._p.getPPr() : this._p.addNewPPr();
        if (fontAlign != null) {
            pPr.setFontAlgn(STTextFontAlignType.Enum.forInt(fontAlign.ordinal() + 1));
        } else if (pPr.isSetFontAlgn()) {
            pPr.unsetFontAlgn();
        }
    }

    @Override // org.apache.poi.sl.usermodel.TextParagraph
    public void setIndent(Double d2) {
        if (d2 != null || this._p.isSetPPr()) {
            CTTextParagraphProperties pPr = this._p.isSetPPr() ? this._p.getPPr() : this._p.addNewPPr();
            if (d2 != null) {
                pPr.setIndent(Units.toEMU(d2.doubleValue()));
            } else if (pPr.isSetIndent()) {
                pPr.unsetIndent();
            }
        }
    }

    @Override // org.apache.poi.sl.usermodel.TextParagraph
    public void setIndentLevel(int i2) {
        (this._p.isSetPPr() ? this._p.getPPr() : this._p.addNewPPr()).setLvl(i2);
    }

    @Override // org.apache.poi.sl.usermodel.TextParagraph
    public void setLeftMargin(Double d2) {
        if (d2 != null || this._p.isSetPPr()) {
            CTTextParagraphProperties pPr = this._p.isSetPPr() ? this._p.getPPr() : this._p.addNewPPr();
            if (d2 != null) {
                pPr.setMarL(Units.toEMU(d2.doubleValue()));
            } else if (pPr.isSetMarL()) {
                pPr.unsetMarL();
            }
        }
    }

    @Override // org.apache.poi.sl.usermodel.TextParagraph
    public void setLineSpacing(Double d2) {
        if (d2 != null || this._p.isSetPPr()) {
            CTTextParagraphProperties pPr = this._p.isSetPPr() ? this._p.getPPr() : this._p.addNewPPr();
            if (d2 != null) {
                CTTextSpacing lnSpc = pPr.isSetLnSpc() ? pPr.getLnSpc() : pPr.addNewLnSpc();
                if (d2.doubleValue() >= NumericFunction.LOG_10_TO_BASE_e) {
                    (lnSpc.isSetSpcPct() ? lnSpc.getSpcPct() : lnSpc.addNewSpcPct()).setVal((int) (d2.doubleValue() * 1000.0d));
                    if (lnSpc.isSetSpcPts()) {
                        lnSpc.unsetSpcPts();
                        return;
                    }
                    return;
                }
                (lnSpc.isSetSpcPts() ? lnSpc.getSpcPts() : lnSpc.addNewSpcPts()).setVal((int) ((-d2.doubleValue()) * 100.0d));
                if (lnSpc.isSetSpcPct()) {
                    lnSpc.unsetSpcPct();
                }
            } else if (pPr.isSetLnSpc()) {
                pPr.unsetLnSpc();
            }
        }
    }

    @Override // org.apache.poi.sl.usermodel.TextParagraph
    public void setRightMargin(Double d2) {
        if (d2 != null || this._p.isSetPPr()) {
            CTTextParagraphProperties pPr = this._p.isSetPPr() ? this._p.getPPr() : this._p.addNewPPr();
            if (d2 != null) {
                pPr.setMarR(Units.toEMU(d2.doubleValue()));
            } else if (pPr.isSetMarR()) {
                pPr.unsetMarR();
            }
        }
    }

    @Override // org.apache.poi.sl.usermodel.TextParagraph
    public void setSpaceAfter(Double d2) {
        if (d2 == null && !this._p.isSetPPr()) {
            return;
        }
        if (d2 != null) {
            CTTextParagraphProperties pPr = this._p.isSetPPr() ? this._p.getPPr() : this._p.addNewPPr();
            CTTextSpacing newInstance = CTTextSpacing.Factory.newInstance();
            if (d2.doubleValue() >= NumericFunction.LOG_10_TO_BASE_e) {
                newInstance.addNewSpcPct().setVal((int) (d2.doubleValue() * 1000.0d));
            } else {
                newInstance.addNewSpcPts().setVal((int) ((-d2.doubleValue()) * 100.0d));
            }
            pPr.setSpcAft(newInstance);
        } else if (this._p.getPPr().isSetSpcAft()) {
            this._p.getPPr().unsetSpcAft();
        }
    }

    @Override // org.apache.poi.sl.usermodel.TextParagraph
    public void setSpaceBefore(Double d2) {
        if (d2 == null && !this._p.isSetPPr()) {
            return;
        }
        if (d2 != null) {
            CTTextParagraphProperties pPr = this._p.isSetPPr() ? this._p.getPPr() : this._p.addNewPPr();
            CTTextSpacing newInstance = CTTextSpacing.Factory.newInstance();
            if (d2.doubleValue() >= NumericFunction.LOG_10_TO_BASE_e) {
                newInstance.addNewSpcPct().setVal((int) (d2.doubleValue() * 1000.0d));
            } else {
                newInstance.addNewSpcPts().setVal((int) ((-d2.doubleValue()) * 100.0d));
            }
            pPr.setSpcBef(newInstance);
        } else if (this._p.getPPr().isSetSpcBef()) {
            this._p.getPPr().unsetSpcBef();
        }
    }

    @Override // org.apache.poi.sl.usermodel.TextParagraph
    public void setTextAlign(TextParagraph.TextAlign textAlign) {
        CTTextParagraphProperties pPr = this._p.isSetPPr() ? this._p.getPPr() : this._p.addNewPPr();
        if (textAlign != null) {
            pPr.setAlgn(STTextAlignType.Enum.forInt(textAlign.ordinal() + 1));
        } else if (pPr.isSetAlgn()) {
            pPr.unsetAlgn();
        }
    }

    public String toString() {
        StringBuilder b2 = a.b("[");
        b2.append(getClass());
        b2.append("]");
        b2.append(getText());
        return b2.toString();
    }

    /* Return type fixed from 'org.apache.poi.xslf.usermodel.XSLFTextShape' to match base method */
    @Override // org.apache.poi.sl.usermodel.TextParagraph
    public TextShape<XSLFShape, XSLFTextParagraph> getParentShape() {
        return this._shape;
    }

    public void setBulletFontColor(PaintStyle paintStyle) {
        if (paintStyle instanceof PaintStyle.SolidPaint) {
            Color applyColorTransform = DrawPaint.applyColorTransform(((PaintStyle.SolidPaint) paintStyle).getSolidColor());
            CTTextParagraphProperties pPr = this._p.isSetPPr() ? this._p.getPPr() : this._p.addNewPPr();
            CTColor buClr = pPr.isSetBuClr() ? pPr.getBuClr() : pPr.addNewBuClr();
            (buClr.isSetSrgbClr() ? buClr.getSrgbClr() : buClr.addNewSrgbClr()).setVal(new byte[]{(byte) applyColorTransform.getRed(), (byte) applyColorTransform.getGreen(), (byte) applyColorTransform.getBlue()});
            return;
        }
        throw new IllegalArgumentException("Currently XSLF only supports SolidPaint");
    }
}
