package org.apache.poi.xslf.usermodel;

import java.awt.geom.Rectangle2D;
import java.util.ArrayList;
import java.util.Iterator;
import java.util.List;
import org.apache.poi.POIXMLException;
import org.apache.poi.sl.draw.DrawFactory;
import org.apache.poi.sl.usermodel.Insets2D;
import org.apache.poi.sl.usermodel.Placeholder;
import org.apache.poi.sl.usermodel.TextParagraph;
import org.apache.poi.sl.usermodel.TextShape;
import org.apache.poi.sl.usermodel.VerticalAlignment;
import org.apache.poi.ss.formula.functions.NumericFunction;
import org.apache.poi.util.Units;
import org.apache.poi.xslf.model.TextBodyPropertyFetcher;
import org.apache.xmlbeans.XmlObject;
import org.openxmlformats.schemas.drawingml.x2006.main.CTTextBody;
import org.openxmlformats.schemas.drawingml.x2006.main.CTTextBodyProperties;
import org.openxmlformats.schemas.drawingml.x2006.main.CTTextCharacterProperties;
import org.openxmlformats.schemas.drawingml.x2006.main.CTTextListStyle;
import org.openxmlformats.schemas.drawingml.x2006.main.CTTextParagraph;
import org.openxmlformats.schemas.drawingml.x2006.main.CTTextParagraphProperties;
import org.openxmlformats.schemas.drawingml.x2006.main.STTextAnchoringType;
import org.openxmlformats.schemas.drawingml.x2006.main.STTextVerticalType;
import org.openxmlformats.schemas.drawingml.x2006.main.STTextWrappingType;
import org.openxmlformats.schemas.presentationml.x2006.main.CTPlaceholder;

public abstract class XSLFTextShape extends XSLFSimpleShape implements TextShape<XSLFShape, XSLFTextParagraph> {
    public static final /* synthetic */ boolean $assertionsDisabled = false;
    public final List<XSLFTextParagraph> _paragraphs = new ArrayList();

    /* renamed from: org.apache.poi.xslf.usermodel.XSLFTextShape$8  reason: invalid class name */
    public static /* synthetic */ class AnonymousClass8 {
        public static final /* synthetic */ int[] $SwitchMap$org$apache$poi$sl$usermodel$Placeholder;
        public static final /* synthetic */ int[] $SwitchMap$org$apache$poi$sl$usermodel$TextShape$TextAutofit;
        public static final /* synthetic */ int[] $SwitchMap$org$apache$poi$sl$usermodel$TextShape$TextPlaceholder;

        /* JADX WARNING: Can't wrap try/catch for region: R(31:0|1|2|(2:3|4)|5|(2:7|8)|9|(2:11|12)|13|15|16|17|18|19|21|22|(2:23|24)|25|27|28|(2:29|30)|31|33|34|(2:35|36)|37|39|40|41|42|(3:43|44|46)) */
        /* JADX WARNING: Can't wrap try/catch for region: R(38:0|1|2|3|4|5|7|8|9|11|12|13|15|16|17|18|19|21|22|(2:23|24)|25|27|28|29|30|31|33|34|35|36|37|39|40|41|42|43|44|46) */
        /* JADX WARNING: Failed to process nested try/catch */
        /* JADX WARNING: Missing exception handler attribute for start block: B:17:0x0033 */
        /* JADX WARNING: Missing exception handler attribute for start block: B:23:0x0040 */
        /* JADX WARNING: Missing exception handler attribute for start block: B:29:0x004d */
        /* JADX WARNING: Missing exception handler attribute for start block: B:35:0x005a */
        /* JADX WARNING: Missing exception handler attribute for start block: B:3:0x000f */
        /* JADX WARNING: Missing exception handler attribute for start block: B:41:0x006f */
        /* JADX WARNING: Missing exception handler attribute for start block: B:43:0x0075 */
        static {
            int[] iArr = new int[Placeholder.values().length];
            $SwitchMap$org$apache$poi$sl$usermodel$Placeholder = iArr;
            Placeholder placeholder = Placeholder.BODY;
            iArr[2] = 1;
            try {
                int[] iArr2 = $SwitchMap$org$apache$poi$sl$usermodel$Placeholder;
                Placeholder placeholder2 = Placeholder.TITLE;
                iArr2[1] = 2;
            } catch (NoSuchFieldError unused) {
            }
            try {
                int[] iArr3 = $SwitchMap$org$apache$poi$sl$usermodel$Placeholder;
                Placeholder placeholder3 = Placeholder.CENTERED_TITLE;
                iArr3[3] = 3;
            } catch (NoSuchFieldError unused2) {
            }
            try {
                int[] iArr4 = $SwitchMap$org$apache$poi$sl$usermodel$Placeholder;
                Placeholder placeholder4 = Placeholder.CONTENT;
                iArr4[9] = 4;
            } catch (NoSuchFieldError unused3) {
            }
            int[] iArr5 = new int[TextShape.TextPlaceholder.values().length];
            $SwitchMap$org$apache$poi$sl$usermodel$TextShape$TextPlaceholder = iArr5;
            TextShape.TextPlaceholder textPlaceholder = TextShape.TextPlaceholder.NOTES;
            iArr5[6] = 1;
            int[] iArr6 = $SwitchMap$org$apache$poi$sl$usermodel$TextShape$TextPlaceholder;
            TextShape.TextPlaceholder textPlaceholder2 = TextShape.TextPlaceholder.HALF_BODY;
            iArr6[4] = 2;
            int[] iArr7 = $SwitchMap$org$apache$poi$sl$usermodel$TextShape$TextPlaceholder;
            TextShape.TextPlaceholder textPlaceholder3 = TextShape.TextPlaceholder.QUARTER_BODY;
            iArr7[5] = 3;
            try {
                int[] iArr8 = $SwitchMap$org$apache$poi$sl$usermodel$TextShape$TextPlaceholder;
                TextShape.TextPlaceholder textPlaceholder4 = TextShape.TextPlaceholder.BODY;
                iArr8[1] = 4;
            } catch (NoSuchFieldError unused4) {
            }
            int[] iArr9 = $SwitchMap$org$apache$poi$sl$usermodel$TextShape$TextPlaceholder;
            TextShape.TextPlaceholder textPlaceholder5 = TextShape.TextPlaceholder.TITLE;
            iArr9[0] = 5;
            try {
                int[] iArr10 = $SwitchMap$org$apache$poi$sl$usermodel$TextShape$TextPlaceholder;
                TextShape.TextPlaceholder textPlaceholder6 = TextShape.TextPlaceholder.CENTER_BODY;
                iArr10[3] = 6;
            } catch (NoSuchFieldError unused5) {
            }
            int[] iArr11 = $SwitchMap$org$apache$poi$sl$usermodel$TextShape$TextPlaceholder;
            TextShape.TextPlaceholder textPlaceholder7 = TextShape.TextPlaceholder.CENTER_TITLE;
            iArr11[2] = 7;
            try {
                int[] iArr12 = $SwitchMap$org$apache$poi$sl$usermodel$TextShape$TextPlaceholder;
                TextShape.TextPlaceholder textPlaceholder8 = TextShape.TextPlaceholder.OTHER;
                iArr12[7] = 8;
            } catch (NoSuchFieldError unused6) {
            }
            int[] iArr13 = new int[TextShape.TextAutofit.values().length];
            $SwitchMap$org$apache$poi$sl$usermodel$TextShape$TextAutofit = iArr13;
            TextShape.TextAutofit textAutofit = TextShape.TextAutofit.NONE;
            iArr13[0] = 1;
            int[] iArr14 = $SwitchMap$org$apache$poi$sl$usermodel$TextShape$TextAutofit;
            TextShape.TextAutofit textAutofit2 = TextShape.TextAutofit.NORMAL;
            iArr14[1] = 2;
            try {
                int[] iArr15 = $SwitchMap$org$apache$poi$sl$usermodel$TextShape$TextAutofit;
                TextShape.TextAutofit textAutofit3 = TextShape.TextAutofit.SHAPE;
                iArr15[2] = 3;
            } catch (NoSuchFieldError unused7) {
            }
        }
    }

    public XSLFTextShape(XmlObject xmlObject, XSLFSheet xSLFSheet) {
        super(xmlObject, xSLFSheet);
        CTTextBody textBody = getTextBody(false);
        if (textBody != null) {
            for (CTTextParagraph cTTextParagraph : textBody.getPArray()) {
                this._paragraphs.add(newTextParagraph(cTTextParagraph));
            }
        }
    }

    public XSLFTextParagraph addNewTextParagraph() {
        CTTextParagraph cTTextParagraph;
        CTTextBody textBody = getTextBody(false);
        if (textBody == null) {
            cTTextParagraph = getTextBody(true).getPArray(0);
            cTTextParagraph.removeR(0);
        } else {
            cTTextParagraph = textBody.addNewP();
        }
        XSLFTextParagraph newTextParagraph = newTextParagraph(cTTextParagraph);
        this._paragraphs.add(newTextParagraph);
        return newTextParagraph;
    }

    public void clearText() {
        this._paragraphs.clear();
        getTextBody(true).setPArray(null);
    }

    @Override // org.apache.poi.xslf.usermodel.XSLFSimpleShape, org.apache.poi.xslf.usermodel.XSLFShape
    public void copy(XSLFShape xSLFShape) {
        super.copy(xSLFShape);
        XSLFTextShape xSLFTextShape = (XSLFTextShape) xSLFShape;
        CTTextBody textBody = xSLFTextShape.getTextBody(false);
        CTTextBody textBody2 = getTextBody(true);
        if (textBody != null) {
            textBody2.setBodyPr((CTTextBodyProperties) textBody.getBodyPr().copy());
            if (textBody2.isSetLstStyle()) {
                textBody2.unsetLstStyle();
            }
            if (textBody.isSetLstStyle()) {
                textBody2.setLstStyle((CTTextListStyle) textBody.getLstStyle().copy());
            }
            boolean wordWrap = xSLFTextShape.getWordWrap();
            if (wordWrap != getWordWrap()) {
                setWordWrap(wordWrap);
            }
            double leftInset = xSLFTextShape.getLeftInset();
            if (leftInset != getLeftInset()) {
                setLeftInset(leftInset);
            }
            double rightInset = xSLFTextShape.getRightInset();
            if (rightInset != getRightInset()) {
                setRightInset(rightInset);
            }
            double topInset = xSLFTextShape.getTopInset();
            if (topInset != getTopInset()) {
                setTopInset(topInset);
            }
            double bottomInset = xSLFTextShape.getBottomInset();
            if (bottomInset != getBottomInset()) {
                setBottomInset(bottomInset);
            }
            VerticalAlignment verticalAlignment = xSLFTextShape.getVerticalAlignment();
            if (verticalAlignment != getVerticalAlignment()) {
                setVerticalAlignment(verticalAlignment);
            }
            clearText();
            Iterator<? extends TextParagraph<XSLFShape, XSLFTextParagraph, ?>> it = xSLFTextShape.getTextParagraphs().iterator();
            while (it.hasNext()) {
                addNewTextParagraph().copy((XSLFTextParagraph) it.next());
            }
        }
    }

    public double getBottomInset() {
        AnonymousClass3 r0 = new TextBodyPropertyFetcher<Double>() {
            /* class org.apache.poi.xslf.usermodel.XSLFTextShape.AnonymousClass3 */

            @Override // org.apache.poi.xslf.model.TextBodyPropertyFetcher
            public boolean fetch(CTTextBodyProperties cTTextBodyProperties) {
                if (!cTTextBodyProperties.isSetBIns()) {
                    return false;
                }
                setValue(Double.valueOf(Units.toPoints((long) cTTextBodyProperties.getBIns())));
                return true;
            }
        };
        fetchShapeProperty(r0);
        if (r0.getValue() == null) {
            return 3.6d;
        }
        return ((Double) r0.getValue()).doubleValue();
    }

    @Override // org.apache.poi.sl.usermodel.TextShape
    public Insets2D getInsets() {
        return new Insets2D(getTopInset(), getLeftInset(), getBottomInset(), getRightInset());
    }

    public double getLeftInset() {
        AnonymousClass4 r0 = new TextBodyPropertyFetcher<Double>() {
            /* class org.apache.poi.xslf.usermodel.XSLFTextShape.AnonymousClass4 */

            @Override // org.apache.poi.xslf.model.TextBodyPropertyFetcher
            public boolean fetch(CTTextBodyProperties cTTextBodyProperties) {
                if (!cTTextBodyProperties.isSetLIns()) {
                    return false;
                }
                setValue(Double.valueOf(Units.toPoints((long) cTTextBodyProperties.getLIns())));
                return true;
            }
        };
        fetchShapeProperty(r0);
        if (r0.getValue() == null) {
            return 7.2d;
        }
        return ((Double) r0.getValue()).doubleValue();
    }

    public double getRightInset() {
        AnonymousClass5 r0 = new TextBodyPropertyFetcher<Double>() {
            /* class org.apache.poi.xslf.usermodel.XSLFTextShape.AnonymousClass5 */

            @Override // org.apache.poi.xslf.model.TextBodyPropertyFetcher
            public boolean fetch(CTTextBodyProperties cTTextBodyProperties) {
                if (!cTTextBodyProperties.isSetRIns()) {
                    return false;
                }
                setValue(Double.valueOf(Units.toPoints((long) cTTextBodyProperties.getRIns())));
                return true;
            }
        };
        fetchShapeProperty(r0);
        if (r0.getValue() == null) {
            return 7.2d;
        }
        return ((Double) r0.getValue()).doubleValue();
    }

    @Override // org.apache.poi.sl.usermodel.TextShape
    public String getText() {
        StringBuilder sb = new StringBuilder();
        for (XSLFTextParagraph xSLFTextParagraph : this._paragraphs) {
            if (sb.length() > 0) {
                sb.append('\n');
            }
            sb.append(xSLFTextParagraph.getText());
        }
        return sb.toString();
    }

    public TextShape.TextAutofit getTextAutofit() {
        CTTextBodyProperties textBodyPr = getTextBodyPr();
        if (textBodyPr != null) {
            if (textBodyPr.isSetNoAutofit()) {
                return TextShape.TextAutofit.NONE;
            }
            if (textBodyPr.isSetNormAutofit()) {
                return TextShape.TextAutofit.NORMAL;
            }
            if (textBodyPr.isSetSpAutoFit()) {
                return TextShape.TextAutofit.SHAPE;
            }
        }
        return TextShape.TextAutofit.NORMAL;
    }

    public abstract CTTextBody getTextBody(boolean z);

    public CTTextBodyProperties getTextBodyPr() {
        return getTextBodyPr(false);
    }

    @Override // org.apache.poi.sl.usermodel.TextShape
    public TextShape.TextDirection getTextDirection() {
        STTextVerticalType.Enum vert;
        CTTextBodyProperties textBodyPr = getTextBodyPr();
        if (textBodyPr == null || (vert = textBodyPr.getVert()) == null) {
            return TextShape.TextDirection.HORIZONTAL;
        }
        switch (vert.intValue()) {
            case 2:
            case 5:
            case 6:
                return TextShape.TextDirection.VERTICAL;
            case 3:
                return TextShape.TextDirection.VERTICAL_270;
            case 4:
            case 7:
                return TextShape.TextDirection.STACKED;
            default:
                return TextShape.TextDirection.HORIZONTAL;
        }
    }

    @Override // org.apache.poi.sl.usermodel.TextShape
    public double getTextHeight() {
        return DrawFactory.getInstance(null).getDrawable((TextShape<?, ?>) this).getTextHeight();
    }

    /* Return type fixed from 'java.util.List<org.apache.poi.xslf.usermodel.XSLFTextParagraph>' to match base method */
    @Override // org.apache.poi.sl.usermodel.TextShape
    public List<? extends TextParagraph<XSLFShape, XSLFTextParagraph, ?>> getTextParagraphs() {
        return this._paragraphs;
    }

    @Override // org.apache.poi.sl.usermodel.TextShape
    public TextShape.TextPlaceholder getTextPlaceholder() {
        Placeholder textType = getTextType();
        if (textType == null) {
            return TextShape.TextPlaceholder.BODY;
        }
        int ordinal = textType.ordinal();
        if (ordinal == 1) {
            return TextShape.TextPlaceholder.TITLE;
        }
        if (ordinal == 2) {
            return TextShape.TextPlaceholder.BODY;
        }
        if (ordinal != 3) {
            return TextShape.TextPlaceholder.OTHER;
        }
        return TextShape.TextPlaceholder.CENTER_TITLE;
    }

    @Override // org.apache.poi.sl.usermodel.TextShape
    public Double getTextRotation() {
        CTTextBodyProperties textBodyPr = getTextBodyPr();
        if (textBodyPr == null || !textBodyPr.isSetRot()) {
            return null;
        }
        return Double.valueOf(((double) textBodyPr.getRot()) / 60000.0d);
    }

    public Placeholder getTextType() {
        CTPlaceholder cTPlaceholder = getCTPlaceholder();
        if (cTPlaceholder == null) {
            return null;
        }
        return Placeholder.lookupOoxml(cTPlaceholder.getType().intValue());
    }

    public double getTopInset() {
        AnonymousClass6 r0 = new TextBodyPropertyFetcher<Double>() {
            /* class org.apache.poi.xslf.usermodel.XSLFTextShape.AnonymousClass6 */

            @Override // org.apache.poi.xslf.model.TextBodyPropertyFetcher
            public boolean fetch(CTTextBodyProperties cTTextBodyProperties) {
                if (!cTTextBodyProperties.isSetTIns()) {
                    return false;
                }
                setValue(Double.valueOf(Units.toPoints((long) cTTextBodyProperties.getTIns())));
                return true;
            }
        };
        fetchShapeProperty(r0);
        if (r0.getValue() == null) {
            return 3.6d;
        }
        return ((Double) r0.getValue()).doubleValue();
    }

    @Override // org.apache.poi.sl.usermodel.TextShape
    public VerticalAlignment getVerticalAlignment() {
        AnonymousClass1 r0 = new TextBodyPropertyFetcher<VerticalAlignment>() {
            /* class org.apache.poi.xslf.usermodel.XSLFTextShape.AnonymousClass1 */

            @Override // org.apache.poi.xslf.model.TextBodyPropertyFetcher
            public boolean fetch(CTTextBodyProperties cTTextBodyProperties) {
                if (!cTTextBodyProperties.isSetAnchor()) {
                    return false;
                }
                setValue(VerticalAlignment.values()[cTTextBodyProperties.getAnchor().intValue() - 1]);
                return true;
            }
        };
        fetchShapeProperty(r0);
        return r0.getValue() == null ? VerticalAlignment.TOP : (VerticalAlignment) r0.getValue();
    }

    @Override // org.apache.poi.sl.usermodel.TextShape
    public boolean getWordWrap() {
        AnonymousClass7 r0 = new TextBodyPropertyFetcher<Boolean>() {
            /* class org.apache.poi.xslf.usermodel.XSLFTextShape.AnonymousClass7 */

            @Override // org.apache.poi.xslf.model.TextBodyPropertyFetcher
            public boolean fetch(CTTextBodyProperties cTTextBodyProperties) {
                boolean z = false;
                if (!cTTextBodyProperties.isSetWrap()) {
                    return false;
                }
                if (cTTextBodyProperties.getWrap() == STTextWrappingType.SQUARE) {
                    z = true;
                }
                setValue(Boolean.valueOf(z));
                return true;
            }
        };
        fetchShapeProperty(r0);
        if (r0.getValue() == null) {
            return true;
        }
        return ((Boolean) r0.getValue()).booleanValue();
    }

    @Override // org.apache.poi.sl.usermodel.TextShape
    public boolean isHorizontalCentered() {
        AnonymousClass2 r0 = new TextBodyPropertyFetcher<Boolean>() {
            /* class org.apache.poi.xslf.usermodel.XSLFTextShape.AnonymousClass2 */

            @Override // org.apache.poi.xslf.model.TextBodyPropertyFetcher
            public boolean fetch(CTTextBodyProperties cTTextBodyProperties) {
                if (!cTTextBodyProperties.isSetAnchorCtr()) {
                    return false;
                }
                setValue(Boolean.valueOf(cTTextBodyProperties.getAnchorCtr()));
                return true;
            }
        };
        fetchShapeProperty(r0);
        if (r0.getValue() == null) {
            return false;
        }
        return ((Boolean) r0.getValue()).booleanValue();
    }

    /* JADX DEBUG: Type inference failed for r0v1. Raw type applied. Possible types: java.util.Iterator<? extends org.apache.poi.sl.usermodel.TextParagraph<org.apache.poi.xslf.usermodel.XSLFShape, org.apache.poi.xslf.usermodel.XSLFTextParagraph, ?>>, java.util.Iterator<org.apache.poi.xslf.usermodel.XSLFTextParagraph> */
    @Override // java.lang.Iterable
    public Iterator<XSLFTextParagraph> iterator() {
        return getTextParagraphs().iterator();
    }

    public XSLFTextParagraph newTextParagraph(CTTextParagraph cTTextParagraph) {
        return new XSLFTextParagraph(cTTextParagraph, this);
    }

    @Override // org.apache.poi.sl.usermodel.TextShape
    public Rectangle2D resizeToFitText() {
        Rectangle2D anchor = getAnchor();
        if (anchor.getWidth() != NumericFunction.LOG_10_TO_BASE_e) {
            Insets2D insets = getInsets();
            anchor.setRect(anchor.getX(), anchor.getY(), anchor.getWidth(), insets.bottom + getTextHeight() + 1.0d + insets.top);
            setAnchor(anchor);
            return anchor;
        }
        throw new POIXMLException("Anchor of the shape was not set.");
    }

    public void setBottomInset(double d2) {
        CTTextBodyProperties textBodyPr = getTextBodyPr(true);
        if (textBodyPr == null) {
            return;
        }
        if (d2 == -1.0d) {
            textBodyPr.unsetBIns();
        } else {
            textBodyPr.setBIns(Units.toEMU(d2));
        }
    }

    @Override // org.apache.poi.sl.usermodel.TextShape
    public void setHorizontalCentered(Boolean bool) {
        CTTextBodyProperties textBodyPr = getTextBodyPr(true);
        if (textBodyPr == null) {
            return;
        }
        if (bool != null) {
            textBodyPr.setAnchorCtr(bool.booleanValue());
        } else if (textBodyPr.isSetAnchorCtr()) {
            textBodyPr.unsetAnchorCtr();
        }
    }

    @Override // org.apache.poi.sl.usermodel.TextShape
    public void setInsets(Insets2D insets2D) {
        setTopInset(insets2D.top);
        setLeftInset(insets2D.left);
        setBottomInset(insets2D.bottom);
        setRightInset(insets2D.right);
    }

    public void setLeftInset(double d2) {
        CTTextBodyProperties textBodyPr = getTextBodyPr(true);
        if (textBodyPr == null) {
            return;
        }
        if (d2 == -1.0d) {
            textBodyPr.unsetLIns();
        } else {
            textBodyPr.setLIns(Units.toEMU(d2));
        }
    }

    @Override // org.apache.poi.xslf.usermodel.XSLFSimpleShape, org.apache.poi.xslf.usermodel.XSLFShape, org.apache.poi.sl.usermodel.SimpleShape
    public void setPlaceholder(Placeholder placeholder) {
        super.setPlaceholder(placeholder);
    }

    public void setRightInset(double d2) {
        CTTextBodyProperties textBodyPr = getTextBodyPr(true);
        if (textBodyPr == null) {
            return;
        }
        if (d2 == -1.0d) {
            textBodyPr.unsetRIns();
        } else {
            textBodyPr.setRIns(Units.toEMU(d2));
        }
    }

    public void setTextAutofit(TextShape.TextAutofit textAutofit) {
        CTTextBodyProperties textBodyPr = getTextBodyPr(true);
        if (textBodyPr != null) {
            if (textBodyPr.isSetSpAutoFit()) {
                textBodyPr.unsetSpAutoFit();
            }
            if (textBodyPr.isSetNoAutofit()) {
                textBodyPr.unsetNoAutofit();
            }
            if (textBodyPr.isSetNormAutofit()) {
                textBodyPr.unsetNormAutofit();
            }
            int ordinal = textAutofit.ordinal();
            if (ordinal == 0) {
                textBodyPr.addNewNoAutofit();
            } else if (ordinal == 1) {
                textBodyPr.addNewNormAutofit();
            } else if (ordinal == 2) {
                textBodyPr.addNewSpAutoFit();
            }
        }
    }

    @Override // org.apache.poi.sl.usermodel.TextShape
    public void setTextDirection(TextShape.TextDirection textDirection) {
        CTTextBodyProperties textBodyPr = getTextBodyPr(true);
        if (textBodyPr == null) {
            return;
        }
        if (textDirection != null) {
            textBodyPr.setVert(STTextVerticalType.Enum.forInt(textDirection.ordinal() + 1));
        } else if (textBodyPr.isSetVert()) {
            textBodyPr.unsetVert();
        }
    }

    @Override // org.apache.poi.sl.usermodel.TextShape
    public void setTextPlaceholder(TextShape.TextPlaceholder textPlaceholder) {
        int ordinal = textPlaceholder.ordinal();
        if (ordinal == 0) {
            setPlaceholder(Placeholder.TITLE);
        } else if (ordinal == 7) {
            setPlaceholder(Placeholder.CONTENT);
        } else if (ordinal == 2) {
            setPlaceholder(Placeholder.CENTERED_TITLE);
        } else if (ordinal != 3) {
            setPlaceholder(Placeholder.BODY);
        } else {
            setPlaceholder(Placeholder.BODY);
            setHorizontalCentered(true);
        }
    }

    @Override // org.apache.poi.sl.usermodel.TextShape
    public void setTextRotation(Double d2) {
        CTTextBodyProperties textBodyPr = getTextBodyPr(true);
        if (textBodyPr != null) {
            textBodyPr.setRot((int) (d2.doubleValue() * 60000.0d));
        }
    }

    public void setTopInset(double d2) {
        CTTextBodyProperties textBodyPr = getTextBodyPr(true);
        if (textBodyPr == null) {
            return;
        }
        if (d2 == -1.0d) {
            textBodyPr.unsetTIns();
        } else {
            textBodyPr.setTIns(Units.toEMU(d2));
        }
    }

    @Override // org.apache.poi.sl.usermodel.TextShape
    public void setVerticalAlignment(VerticalAlignment verticalAlignment) {
        CTTextBodyProperties textBodyPr = getTextBodyPr(true);
        if (textBodyPr == null) {
            return;
        }
        if (verticalAlignment != null) {
            textBodyPr.setAnchor(STTextAnchoringType.Enum.forInt(verticalAlignment.ordinal() + 1));
        } else if (textBodyPr.isSetAnchor()) {
            textBodyPr.unsetAnchor();
        }
    }

    @Override // org.apache.poi.sl.usermodel.TextShape
    public void setWordWrap(boolean z) {
        CTTextBodyProperties textBodyPr = getTextBodyPr(true);
        if (textBodyPr != null) {
            textBodyPr.setWrap(z ? STTextWrappingType.SQUARE : STTextWrappingType.NONE);
        }
    }

    @Override // org.apache.poi.sl.usermodel.TextShape
    public XSLFTextRun appendText(String str, boolean z) {
        boolean z2;
        CTTextParagraphProperties cTTextParagraphProperties;
        CTTextCharacterProperties cTTextCharacterProperties;
        XSLFTextParagraph xSLFTextParagraph;
        CTTextParagraph xmlObject;
        CTTextCharacterProperties endParaRPr;
        XSLFTextRun xSLFTextRun = null;
        if (str == null) {
            return null;
        }
        if (this._paragraphs.isEmpty()) {
            z2 = false;
            xSLFTextParagraph = null;
            cTTextCharacterProperties = null;
            cTTextParagraphProperties = null;
        } else {
            z2 = !z;
            List<XSLFTextParagraph> list = this._paragraphs;
            xSLFTextParagraph = list.get(list.size() - 1);
            CTTextParagraph xmlObject2 = xSLFTextParagraph.getXmlObject();
            cTTextParagraphProperties = xmlObject2.getPPr();
            List<XSLFTextRun> textRuns = xSLFTextParagraph.getTextRuns();
            if (!textRuns.isEmpty()) {
                cTTextCharacterProperties = textRuns.get(textRuns.size() - 1).getRPr(false);
                if (cTTextCharacterProperties == null) {
                    cTTextCharacterProperties = xmlObject2.getEndParaRPr();
                }
            } else {
                cTTextCharacterProperties = null;
            }
        }
        String[] split = str.split("\\r\\n?|\\n");
        int length = split.length;
        int i2 = 0;
        while (i2 < length) {
            String str2 = split[i2];
            if (!z2) {
                if (!(xSLFTextParagraph == null || (endParaRPr = (xmlObject = xSLFTextParagraph.getXmlObject()).getEndParaRPr()) == null || endParaRPr == cTTextCharacterProperties)) {
                    xmlObject.unsetEndParaRPr();
                }
                XSLFTextParagraph addNewTextParagraph = addNewTextParagraph();
                if (cTTextParagraphProperties != null) {
                    addNewTextParagraph.getXmlObject().setPPr(cTTextParagraphProperties);
                }
                xSLFTextParagraph = addNewTextParagraph;
            }
            String[] split2 = str2.split("[\u000b]");
            int length2 = split2.length;
            int i3 = 0;
            boolean z3 = true;
            while (i3 < length2) {
                String str3 = split2[i3];
                if (!z3) {
                    xSLFTextParagraph.addLineBreak();
                }
                XSLFTextRun addNewTextRun = xSLFTextParagraph.addNewTextRun();
                addNewTextRun.setText(str3);
                if (cTTextCharacterProperties != null) {
                    addNewTextRun.getRPr(true).set(cTTextCharacterProperties);
                }
                i3++;
                xSLFTextRun = addNewTextRun;
                z3 = false;
            }
            i2++;
            z2 = false;
        }
        return xSLFTextRun;
    }

    public CTTextBodyProperties getTextBodyPr(boolean z) {
        CTTextBody textBody = getTextBody(z);
        if (textBody == null) {
            return null;
        }
        CTTextBodyProperties bodyPr = textBody.getBodyPr();
        return (bodyPr != null || !z) ? bodyPr : textBody.addNewBodyPr();
    }

    @Override // org.apache.poi.sl.usermodel.TextShape
    public XSLFTextRun setText(String str) {
        if (!this._paragraphs.isEmpty()) {
            CTTextBody textBody = getTextBody(false);
            for (int sizeOfPArray = textBody.sizeOfPArray(); sizeOfPArray > 1; sizeOfPArray--) {
                int i2 = sizeOfPArray - 1;
                textBody.removeP(i2);
                this._paragraphs.remove(i2);
            }
            this._paragraphs.get(0).clearButKeepProperties();
        }
        return appendText(str, false);
    }
}
