package org.apache.poi.xssf.binary;

import java.io.InputStream;
import java.util.ArrayList;
import java.util.LinkedList;
import java.util.List;
import java.util.Map;
import java.util.Queue;
import java.util.TreeMap;
import org.apache.poi.ss.util.CellAddress;
import org.apache.poi.util.Internal;
import org.apache.poi.util.LittleEndian;

@Internal
public class XSSFBCommentsTable extends XSSFBParser {
    public StringBuilder authorBuffer = new StringBuilder();
    public int authorId = -1;
    public List<String> authors = new ArrayList();
    public CellAddress cellAddress = null;
    public XSSFBCellRange cellRange = null;
    public String comment = null;
    public Queue<CellAddress> commentAddresses = new LinkedList();
    public Map<CellAddress, XSSFBComment> comments = new TreeMap();

    /* renamed from: org.apache.poi.xssf.binary.XSSFBCommentsTable$1  reason: invalid class name */
    public static /* synthetic */ class AnonymousClass1 {
        public static final /* synthetic */ int[] $SwitchMap$org$apache$poi$xssf$binary$XSSFBRecordType;

        /* JADX WARNING: Can't wrap try/catch for region: R(10:0|1|2|3|4|5|6|7|8|10) */
        /* JADX WARNING: Code restructure failed: missing block: B:11:?, code lost:
            return;
         */
        /* JADX WARNING: Failed to process nested try/catch */
        /* JADX WARNING: Missing exception handler attribute for start block: B:3:0x0010 */
        /* JADX WARNING: Missing exception handler attribute for start block: B:5:0x0019 */
        /* JADX WARNING: Missing exception handler attribute for start block: B:7:0x0022 */
        static {
            int[] iArr = new int[XSSFBRecordType.values().length];
            $SwitchMap$org$apache$poi$xssf$binary$XSSFBRecordType = iArr;
            XSSFBRecordType xSSFBRecordType = XSSFBRecordType.BrtBeginComment;
            iArr[24] = 1;
            int[] iArr2 = $SwitchMap$org$apache$poi$xssf$binary$XSSFBRecordType;
            XSSFBRecordType xSSFBRecordType2 = XSSFBRecordType.BrtCommentText;
            iArr2[25] = 2;
            int[] iArr3 = $SwitchMap$org$apache$poi$xssf$binary$XSSFBRecordType;
            XSSFBRecordType xSSFBRecordType3 = XSSFBRecordType.BrtEndComment;
            iArr3[26] = 3;
            int[] iArr4 = $SwitchMap$org$apache$poi$xssf$binary$XSSFBRecordType;
            XSSFBRecordType xSSFBRecordType4 = XSSFBRecordType.BrtCommentAuthor;
            iArr4[23] = 4;
        }
    }

    public XSSFBCommentsTable(InputStream inputStream) {
        super(inputStream);
        parse();
        this.commentAddresses.addAll(this.comments.keySet());
    }

    public XSSFBComment get(CellAddress cellAddress2) {
        if (cellAddress2 == null) {
            return null;
        }
        return this.comments.get(cellAddress2);
    }

    public Queue<CellAddress> getAddresses() {
        return this.commentAddresses;
    }

    @Override // org.apache.poi.xssf.binary.XSSFBParser
    public void handleRecord(int i2, byte[] bArr) {
        switch (XSSFBRecordType.lookup(i2).ordinal()) {
            case 23:
                this.authorBuffer.setLength(0);
                XSSFBUtils.readXLWideString(bArr, 0, this.authorBuffer);
                this.authors.add(this.authorBuffer.toString());
                return;
            case 24:
                this.authorId = XSSFBUtils.castToInt(LittleEndian.getUInt(bArr));
                this.cellRange = XSSFBCellRange.parse(bArr, 4, this.cellRange);
                XSSFBCellRange xSSFBCellRange = this.cellRange;
                this.cellAddress = new CellAddress(xSSFBCellRange.firstRow, xSSFBCellRange.firstCol);
                return;
            case 25:
                this.comment = XSSFBRichStr.build(bArr, 0).getString();
                return;
            case 26:
                Map<CellAddress, XSSFBComment> map = this.comments;
                CellAddress cellAddress2 = this.cellAddress;
                map.put(cellAddress2, new XSSFBComment(cellAddress2, this.authors.get(this.authorId), this.comment));
                this.authorId = -1;
                this.cellAddress = null;
                return;
            default:
                return;
        }
    }
}
