package org.apache.poi.xssf.dev;

import b.b.a.a.a;
import java.io.File;
import java.io.FileOutputStream;
import java.io.PrintStream;
import java.util.Enumeration;
import java.util.zip.ZipEntry;
import java.util.zip.ZipFile;
import org.apache.poi.POIXMLTypeLoader;
import org.apache.poi.openxml4j.opc.internal.ZipHelper;
import org.apache.poi.util.DocumentHelper;
import org.apache.poi.util.IOUtils;
import org.apache.xmlbeans.XmlException;
import org.apache.xmlbeans.XmlObject;
import org.apache.xmlbeans.XmlOptions;

public final class XSSFDump {
    public static void createDirIfMissing(File file) {
        if (!file.exists() && !file.mkdir()) {
            throw new RuntimeException("Unable to create directory: " + file);
        }
    }

    public static void dump(ZipFile zipFile) {
        String name = zipFile.getName();
        File file = new File(name.substring(0, name.lastIndexOf(46)));
        createDirIfMissing(file);
        PrintStream printStream = System.out;
        printStream.println("Dumping to directory " + file);
        Enumeration<? extends ZipEntry> entries = zipFile.entries();
        while (entries.hasMoreElements()) {
            ZipEntry zipEntry = (ZipEntry) entries.nextElement();
            String name2 = zipEntry.getName();
            int lastIndexOf = name2.lastIndexOf(47);
            if (lastIndexOf != -1) {
                recursivelyCreateDirIfMissing(new File(file, name2.substring(0, lastIndexOf)));
            }
            FileOutputStream fileOutputStream = new FileOutputStream(new File(file, zipEntry.getName()));
            try {
                if (!zipEntry.getName().endsWith(".xml") && !zipEntry.getName().endsWith(".vml")) {
                    if (!zipEntry.getName().endsWith(".rels")) {
                        IOUtils.copy(zipFile.getInputStream(zipEntry), fileOutputStream);
                    }
                }
                try {
                    XmlObject parse = XmlObject.Factory.parse(DocumentHelper.readDocument(zipFile.getInputStream(zipEntry)), POIXMLTypeLoader.DEFAULT_XML_OPTIONS);
                    XmlOptions xmlOptions = new XmlOptions();
                    xmlOptions.setSavePrettyPrint();
                    parse.save(fileOutputStream, xmlOptions);
                } catch (XmlException unused) {
                    PrintStream printStream2 = System.err;
                    printStream2.println("Failed to parse " + zipEntry.getName() + ", dumping raw content");
                    IOUtils.copy(zipFile.getInputStream(zipEntry), fileOutputStream);
                }
            } finally {
                fileOutputStream.close();
            }
        }
    }

    /* JADX INFO: finally extract failed */
    public static void main(String[] strArr) {
        for (int i2 = 0; i2 < strArr.length; i2++) {
            PrintStream printStream = System.out;
            StringBuilder b2 = a.b("Dumping ");
            b2.append(strArr[i2]);
            printStream.println(b2.toString());
            ZipFile openZipFile = ZipHelper.openZipFile(strArr[i2]);
            try {
                dump(openZipFile);
                openZipFile.close();
            } catch (Throwable th) {
                openZipFile.close();
                throw th;
            }
        }
    }

    public static void recursivelyCreateDirIfMissing(File file) {
        if (!file.exists() && !file.mkdirs()) {
            throw new RuntimeException("Unable to recursively create directory: " + file);
        }
    }
}
