package org.apache.poi.xssf.eventusermodel;

import b.b.a.a.a;
import java.util.LinkedList;
import java.util.Queue;
import org.apache.lucene.codecs.lucene3x.Lucene3xNormsProducer;
import org.apache.poi.ss.usermodel.BuiltinFormats;
import org.apache.poi.ss.usermodel.DataFormatter;
import org.apache.poi.ss.util.CellAddress;
import org.apache.poi.util.POILogFactory;
import org.apache.poi.util.POILogger;
import org.apache.poi.xssf.model.CommentsTable;
import org.apache.poi.xssf.model.StylesTable;
import org.apache.poi.xssf.usermodel.XSSFCell;
import org.apache.poi.xssf.usermodel.XSSFCellStyle;
import org.apache.poi.xssf.usermodel.XSSFComment;
import org.apache.poi.xssf.usermodel.XSSFRelation;
import org.apache.poi.xssf.usermodel.XSSFRichTextString;
import org.openxmlformats.schemas.spreadsheetml.x2006.main.CTComment;
import org.xml.sax.Attributes;
import org.xml.sax.helpers.DefaultHandler;

public class XSSFSheetXMLHandler extends DefaultHandler {
    public static final POILogger logger = POILogFactory.getLogger(XSSFSheetXMLHandler.class);
    public String cellRef;
    public Queue<CellAddress> commentCellRefs;
    public CommentsTable commentsTable;
    public boolean fIsOpen;
    public short formatIndex;
    public String formatString;
    public final DataFormatter formatter;
    public StringBuffer formula;
    public boolean formulasNotResults;
    public StringBuffer headerFooter;
    public boolean hfIsOpen;
    public boolean isIsOpen;
    public xssfDataType nextDataType;
    public int nextRowNum;
    public final SheetContentsHandler output;
    public int rowNum;
    public ReadOnlySharedStringsTable sharedStringsTable;
    public StylesTable stylesTable;
    public boolean vIsOpen;
    public StringBuffer value;

    /* renamed from: org.apache.poi.xssf.eventusermodel.XSSFSheetXMLHandler$1  reason: invalid class name */
    public static /* synthetic */ class AnonymousClass1 {
        public static final /* synthetic */ int[] $SwitchMap$org$apache$poi$xssf$eventusermodel$XSSFSheetXMLHandler$xssfDataType;

        /* JADX WARNING: Failed to process nested try/catch */
        /* JADX WARNING: Missing exception handler attribute for start block: B:19:0x002b */
        static {
            int[] iArr = new int[xssfDataType.values().length];
            $SwitchMap$org$apache$poi$xssf$eventusermodel$XSSFSheetXMLHandler$xssfDataType = iArr;
            try {
                xssfDataType xssfdatatype = xssfDataType.BOOLEAN;
                iArr[0] = 1;
            } catch (NoSuchFieldError unused) {
            }
            try {
                int[] iArr2 = $SwitchMap$org$apache$poi$xssf$eventusermodel$XSSFSheetXMLHandler$xssfDataType;
                xssfDataType xssfdatatype2 = xssfDataType.ERROR;
                iArr2[1] = 2;
            } catch (NoSuchFieldError unused2) {
            }
            try {
                int[] iArr3 = $SwitchMap$org$apache$poi$xssf$eventusermodel$XSSFSheetXMLHandler$xssfDataType;
                xssfDataType xssfdatatype3 = xssfDataType.FORMULA;
                iArr3[2] = 3;
            } catch (NoSuchFieldError unused3) {
            }
            try {
                int[] iArr4 = $SwitchMap$org$apache$poi$xssf$eventusermodel$XSSFSheetXMLHandler$xssfDataType;
                xssfDataType xssfdatatype4 = xssfDataType.INLINE_STRING;
                iArr4[3] = 4;
            } catch (NoSuchFieldError unused4) {
            }
            int[] iArr5 = $SwitchMap$org$apache$poi$xssf$eventusermodel$XSSFSheetXMLHandler$xssfDataType;
            xssfDataType xssfdatatype5 = xssfDataType.SST_STRING;
            iArr5[4] = 5;
            try {
                int[] iArr6 = $SwitchMap$org$apache$poi$xssf$eventusermodel$XSSFSheetXMLHandler$xssfDataType;
                xssfDataType xssfdatatype6 = xssfDataType.NUMBER;
                iArr6[5] = 6;
            } catch (NoSuchFieldError unused5) {
            }
        }
    }

    public enum EmptyCellCommentsCheckType {
        CELL,
        END_OF_ROW,
        END_OF_SHEET_DATA
    }

    public interface SheetContentsHandler {
        void cell(String str, String str2, XSSFComment xSSFComment);

        void endRow(int i2);

        void headerFooter(String str, boolean z, String str2);

        void startRow(int i2);
    }

    public enum xssfDataType {
        BOOLEAN,
        ERROR,
        FORMULA,
        INLINE_STRING,
        SST_STRING,
        NUMBER
    }

    public XSSFSheetXMLHandler(StylesTable stylesTable2, CommentsTable commentsTable2, ReadOnlySharedStringsTable readOnlySharedStringsTable, SheetContentsHandler sheetContentsHandler, DataFormatter dataFormatter, boolean z) {
        this.value = new StringBuffer();
        this.formula = new StringBuffer();
        this.headerFooter = new StringBuffer();
        this.stylesTable = stylesTable2;
        this.commentsTable = commentsTable2;
        this.sharedStringsTable = readOnlySharedStringsTable;
        this.output = sheetContentsHandler;
        this.formulasNotResults = z;
        this.nextDataType = xssfDataType.NUMBER;
        this.formatter = dataFormatter;
        init();
    }

    private void checkForEmptyCellComments(EmptyCellCommentsCheckType emptyCellCommentsCheckType) {
        CellAddress cellAddress;
        Queue<CellAddress> queue = this.commentCellRefs;
        if (queue != null && !queue.isEmpty()) {
            if (emptyCellCommentsCheckType == EmptyCellCommentsCheckType.END_OF_SHEET_DATA) {
                while (!this.commentCellRefs.isEmpty()) {
                    outputEmptyCellComment(this.commentCellRefs.remove());
                }
            } else if (this.cellRef != null) {
                do {
                    CellAddress cellAddress2 = new CellAddress(this.cellRef);
                    CellAddress peek = this.commentCellRefs.peek();
                    if (emptyCellCommentsCheckType != EmptyCellCommentsCheckType.CELL || !cellAddress2.equals(peek)) {
                        int compareTo = peek.compareTo(cellAddress2);
                        if (compareTo > 0 && emptyCellCommentsCheckType == EmptyCellCommentsCheckType.END_OF_ROW && peek.getRow() <= this.rowNum) {
                            cellAddress = this.commentCellRefs.remove();
                            outputEmptyCellComment(cellAddress);
                        } else if (compareTo >= 0 || emptyCellCommentsCheckType != EmptyCellCommentsCheckType.CELL || peek.getRow() > this.rowNum) {
                            cellAddress = null;
                        } else {
                            cellAddress = this.commentCellRefs.remove();
                            outputEmptyCellComment(cellAddress);
                        }
                        if (cellAddress == null) {
                            return;
                        }
                    } else {
                        this.commentCellRefs.remove();
                        return;
                    }
                } while (!this.commentCellRefs.isEmpty());
            } else if (emptyCellCommentsCheckType == EmptyCellCommentsCheckType.END_OF_ROW) {
                while (!this.commentCellRefs.isEmpty() && this.commentCellRefs.peek().getRow() == this.rowNum) {
                    outputEmptyCellComment(this.commentCellRefs.remove());
                }
            } else {
                StringBuilder b2 = a.b("Cell ref should be null only if there are only empty cells in the row; rowNum: ");
                b2.append(this.rowNum);
                throw new IllegalStateException(b2.toString());
            }
        }
    }

    private void init() {
        if (this.commentsTable != null) {
            this.commentCellRefs = new LinkedList();
            for (CTComment cTComment : this.commentsTable.getCTComments().getCommentList().getCommentArray()) {
                this.commentCellRefs.add(new CellAddress(cTComment.getRef()));
            }
        }
    }

    private boolean isTextTag(String str) {
        if ("v".equals(str) || "inlineStr".equals(str)) {
            return true;
        }
        if (!"t".equals(str) || !this.isIsOpen) {
            return false;
        }
        return true;
    }

    private void outputEmptyCellComment(CellAddress cellAddress) {
        this.output.cell(cellAddress.formatAsString(), null, this.commentsTable.findCellComment(cellAddress));
    }

    @Override // org.xml.sax.helpers.DefaultHandler, org.xml.sax.ContentHandler
    public void characters(char[] cArr, int i2, int i3) {
        if (this.vIsOpen) {
            this.value.append(cArr, i2, i3);
        }
        if (this.fIsOpen) {
            this.formula.append(cArr, i2, i3);
        }
        if (this.hfIsOpen) {
            this.headerFooter.append(cArr, i2, i3);
        }
    }

    @Override // org.xml.sax.helpers.DefaultHandler, org.xml.sax.ContentHandler
    public void endElement(String str, String str2, String str3) {
        String str4;
        if (str != null && !str.equals(XSSFRelation.NS_SPREADSHEETML)) {
            return;
        }
        if (isTextTag(str2)) {
            this.vIsOpen = false;
            int ordinal = this.nextDataType.ordinal();
            XSSFComment xSSFComment = null;
            if (ordinal == 0) {
                str4 = this.value.charAt(0) == '0' ? XSSFCell.FALSE : XSSFCell.TRUE;
            } else if (ordinal == 1) {
                StringBuilder b2 = a.b("ERROR:");
                b2.append((Object) this.value);
                str4 = b2.toString();
            } else if (ordinal != 2) {
                if (ordinal == 3) {
                    str4 = new XSSFRichTextString(this.value.toString()).toString();
                } else if (ordinal == 4) {
                    String stringBuffer = this.value.toString();
                    try {
                        str4 = new XSSFRichTextString(this.sharedStringsTable.getEntryAt(Integer.parseInt(stringBuffer))).toString();
                    } catch (NumberFormatException e2) {
                        logger.log(7, a.b("Failed to parse SST index '", stringBuffer), e2);
                        str4 = null;
                    }
                } else if (ordinal != 5) {
                    StringBuilder b3 = a.b("(TODO: Unexpected type: ");
                    b3.append(this.nextDataType);
                    b3.append(")");
                    str4 = b3.toString();
                } else {
                    str4 = this.value.toString();
                    if (this.formatString != null && str4.length() > 0) {
                        str4 = this.formatter.formatRawCellContents(Double.parseDouble(str4), this.formatIndex, this.formatString);
                    }
                }
            } else if (this.formulasNotResults) {
                str4 = this.formula.toString();
            } else {
                str4 = this.value.toString();
                if (this.formatString != null) {
                    try {
                        str4 = this.formatter.formatRawCellContents(Double.parseDouble(str4), this.formatIndex, this.formatString);
                    } catch (NumberFormatException unused) {
                    }
                }
            }
            checkForEmptyCellComments(EmptyCellCommentsCheckType.CELL);
            CommentsTable commentsTable2 = this.commentsTable;
            if (commentsTable2 != null) {
                xSSFComment = commentsTable2.findCellComment(new CellAddress(this.cellRef));
            }
            this.output.cell(this.cellRef, str4, xSSFComment);
        } else if ("f".equals(str2)) {
            this.fIsOpen = false;
        } else if ("is".equals(str2)) {
            this.isIsOpen = false;
        } else if ("row".equals(str2)) {
            checkForEmptyCellComments(EmptyCellCommentsCheckType.END_OF_ROW);
            this.output.endRow(this.rowNum);
            this.nextRowNum = this.rowNum + 1;
        } else if ("sheetData".equals(str2)) {
            checkForEmptyCellComments(EmptyCellCommentsCheckType.END_OF_SHEET_DATA);
        } else if ("oddHeader".equals(str2) || "evenHeader".equals(str2) || "firstHeader".equals(str2)) {
            this.hfIsOpen = false;
            this.output.headerFooter(this.headerFooter.toString(), true, str2);
        } else if ("oddFooter".equals(str2) || "evenFooter".equals(str2) || "firstFooter".equals(str2)) {
            this.hfIsOpen = false;
            this.output.headerFooter(this.headerFooter.toString(), false, str2);
        }
    }

    @Override // org.xml.sax.helpers.DefaultHandler, org.xml.sax.ContentHandler
    public void startElement(String str, String str2, String str3, Attributes attributes) {
        if (str != null && !str.equals(XSSFRelation.NS_SPREADSHEETML)) {
            return;
        }
        if (isTextTag(str2)) {
            this.vIsOpen = true;
            this.value.setLength(0);
        } else if ("is".equals(str2)) {
            this.isIsOpen = true;
        } else if ("f".equals(str2)) {
            this.formula.setLength(0);
            if (this.nextDataType == xssfDataType.NUMBER) {
                this.nextDataType = xssfDataType.FORMULA;
            }
            String value2 = attributes.getValue("t");
            if (value2 == null || !value2.equals("shared")) {
                this.fIsOpen = true;
                return;
            }
            String value3 = attributes.getValue("ref");
            attributes.getValue("si");
            if (value3 != null) {
                this.fIsOpen = true;
            } else if (this.formulasNotResults) {
                logger.log(5, "shared formulas not yet supported!");
            }
        } else if ("oddHeader".equals(str2) || "evenHeader".equals(str2) || "firstHeader".equals(str2) || "firstFooter".equals(str2) || "oddFooter".equals(str2) || "evenFooter".equals(str2)) {
            this.hfIsOpen = true;
            this.headerFooter.setLength(0);
        } else if ("row".equals(str2)) {
            String value4 = attributes.getValue("r");
            if (value4 != null) {
                this.rowNum = Integer.parseInt(value4) - 1;
            } else {
                this.rowNum = this.nextRowNum;
            }
            this.output.startRow(this.rowNum);
        } else if ("c".equals(str2)) {
            this.nextDataType = xssfDataType.NUMBER;
            this.formatIndex = -1;
            XSSFCellStyle xSSFCellStyle = null;
            this.formatString = null;
            this.cellRef = attributes.getValue("r");
            String value5 = attributes.getValue("t");
            String value6 = attributes.getValue(Lucene3xNormsProducer.SEPARATE_NORMS_EXTENSION);
            if ("b".equals(value5)) {
                this.nextDataType = xssfDataType.BOOLEAN;
            } else if ("e".equals(value5)) {
                this.nextDataType = xssfDataType.ERROR;
            } else if ("inlineStr".equals(value5)) {
                this.nextDataType = xssfDataType.INLINE_STRING;
            } else if (Lucene3xNormsProducer.SEPARATE_NORMS_EXTENSION.equals(value5)) {
                this.nextDataType = xssfDataType.SST_STRING;
            } else if ("str".equals(value5)) {
                this.nextDataType = xssfDataType.FORMULA;
            } else {
                StylesTable stylesTable2 = this.stylesTable;
                if (stylesTable2 != null) {
                    if (value6 != null) {
                        xSSFCellStyle = this.stylesTable.getStyleAt(Integer.parseInt(value6));
                    } else if (stylesTable2.getNumCellStyles() > 0) {
                        xSSFCellStyle = this.stylesTable.getStyleAt(0);
                    }
                }
                if (xSSFCellStyle != null) {
                    this.formatIndex = xSSFCellStyle.getDataFormat();
                    String dataFormatString = xSSFCellStyle.getDataFormatString();
                    this.formatString = dataFormatString;
                    if (dataFormatString == null) {
                        this.formatString = BuiltinFormats.getBuiltinFormat(this.formatIndex);
                    }
                }
            }
        }
    }

    public XSSFSheetXMLHandler(StylesTable stylesTable2, ReadOnlySharedStringsTable readOnlySharedStringsTable, SheetContentsHandler sheetContentsHandler, DataFormatter dataFormatter, boolean z) {
        this(stylesTable2, null, readOnlySharedStringsTable, sheetContentsHandler, dataFormatter, z);
    }

    public XSSFSheetXMLHandler(StylesTable stylesTable2, ReadOnlySharedStringsTable readOnlySharedStringsTable, SheetContentsHandler sheetContentsHandler, boolean z) {
        this(stylesTable2, readOnlySharedStringsTable, sheetContentsHandler, new DataFormatter(), z);
    }
}
