package org.apache.poi.xssf.streaming;

import b.b.a.a.a;
import java.util.Iterator;
import java.util.Map;
import java.util.NoSuchElementException;
import java.util.SortedMap;
import java.util.TreeMap;
import org.apache.poi.ss.SpreadsheetVersion;
import org.apache.poi.ss.usermodel.Cell;
import org.apache.poi.ss.usermodel.CellStyle;
import org.apache.poi.ss.usermodel.CellType;
import org.apache.poi.ss.usermodel.Row;
import org.apache.poi.util.Internal;

public class SXSSFRow implements Row, Comparable<SXSSFRow> {
    public static final Boolean UNDEFINED = null;
    public final SortedMap<Integer, SXSSFCell> _cells;
    public Boolean _collapsed;
    public short _height;
    public Boolean _hidden;
    public int _outlineLevel;
    public final SXSSFSheet _sheet;
    public short _style;
    public boolean _zHeight;

    /* renamed from: org.apache.poi.xssf.streaming.SXSSFRow$1  reason: invalid class name */
    public static /* synthetic */ class AnonymousClass1 {
        public static final /* synthetic */ int[] $SwitchMap$org$apache$poi$ss$usermodel$Row$MissingCellPolicy;

        /* JADX WARNING: Can't wrap try/catch for region: R(8:0|(2:1|2)|3|5|6|7|8|10) */
        /* JADX WARNING: Code restructure failed: missing block: B:11:?, code lost:
            return;
         */
        /* JADX WARNING: Failed to process nested try/catch */
        /* JADX WARNING: Missing exception handler attribute for start block: B:7:0x0016 */
        static {
            int[] iArr = new int[Row.MissingCellPolicy.values().length];
            $SwitchMap$org$apache$poi$ss$usermodel$Row$MissingCellPolicy = iArr;
            try {
                Row.MissingCellPolicy missingCellPolicy = Row.MissingCellPolicy.RETURN_NULL_AND_BLANK;
                iArr[0] = 1;
            } catch (NoSuchFieldError unused) {
            }
            int[] iArr2 = $SwitchMap$org$apache$poi$ss$usermodel$Row$MissingCellPolicy;
            Row.MissingCellPolicy missingCellPolicy2 = Row.MissingCellPolicy.RETURN_BLANK_AS_NULL;
            iArr2[1] = 2;
            int[] iArr3 = $SwitchMap$org$apache$poi$ss$usermodel$Row$MissingCellPolicy;
            Row.MissingCellPolicy missingCellPolicy3 = Row.MissingCellPolicy.CREATE_NULL_AS_BLANK;
            iArr3[2] = 3;
        }
    }

    public class CellIterator implements Iterator<Cell> {
        public final int maxColumn = SXSSFRow.this.getLastCellNum();
        public int pos = 0;

        public CellIterator() {
        }

        public boolean hasNext() {
            return this.pos < this.maxColumn;
        }

        public void remove() {
            throw new UnsupportedOperationException();
        }

        @Override // java.util.Iterator
        public Cell next() {
            if (hasNext()) {
                SortedMap sortedMap = SXSSFRow.this._cells;
                int i2 = this.pos;
                this.pos = i2 + 1;
                return (Cell) sortedMap.get(Integer.valueOf(i2));
            }
            throw new NoSuchElementException();
        }
    }

    public class FilledCellIterator implements Iterator<Cell> {
        public final Iterator<SXSSFCell> iter = SXSSFRow.this._cells.values().iterator();

        public FilledCellIterator() {
        }

        public boolean hasNext() {
            return this.iter.hasNext();
        }

        public void remove() {
            throw new UnsupportedOperationException();
        }

        @Override // java.util.Iterator
        public Cell next() {
            return this.iter.next();
        }
    }

    @Deprecated
    public SXSSFRow(SXSSFSheet sXSSFSheet, int i2) {
        this(sXSSFSheet);
    }

    public static void checkBounds(int i2) {
        SpreadsheetVersion spreadsheetVersion = SpreadsheetVersion.EXCEL2007;
        int lastColumnIndex = spreadsheetVersion.getLastColumnIndex();
        if (i2 < 0 || i2 > lastColumnIndex) {
            throw new IllegalArgumentException("Invalid column index (" + i2 + ").  Allowable column range for " + "EXCEL2007" + " is (0.." + lastColumnIndex + ") or ('A'..'" + spreadsheetVersion.getLastColumnName() + "')");
        }
    }

    public Iterator<Cell> allCellsIterator() {
        return new CellIterator();
    }

    @Override // org.apache.poi.ss.usermodel.Row
    public Iterator<Cell> cellIterator() {
        return iterator();
    }

    public boolean equals(Object obj) {
        if (!(obj instanceof SXSSFRow)) {
            return false;
        }
        SXSSFRow sXSSFRow = (SXSSFRow) obj;
        if (getRowNum() == sXSSFRow.getRowNum() && getSheet() == sXSSFRow.getSheet()) {
            return true;
        }
        return false;
    }

    public int getCellIndex(SXSSFCell sXSSFCell) {
        for (Map.Entry<Integer, SXSSFCell> entry : this._cells.entrySet()) {
            if (entry.getValue() == sXSSFCell) {
                return entry.getKey().intValue();
            }
        }
        return -1;
    }

    public Boolean getCollapsed() {
        return this._collapsed;
    }

    @Override // org.apache.poi.ss.usermodel.Row
    public short getFirstCellNum() {
        try {
            return this._cells.firstKey().shortValue();
        } catch (NoSuchElementException unused) {
            return -1;
        }
    }

    @Override // org.apache.poi.ss.usermodel.Row
    public short getHeight() {
        short s = this._height;
        return (short) ((int) (s == -1 ? getSheet().getDefaultRowHeightInPoints() * 20.0f : (float) s));
    }

    @Override // org.apache.poi.ss.usermodel.Row
    public float getHeightInPoints() {
        short s = this._height;
        return (float) (s == -1 ? (double) getSheet().getDefaultRowHeightInPoints() : ((double) s) / 20.0d);
    }

    public Boolean getHidden() {
        return this._hidden;
    }

    @Override // org.apache.poi.ss.usermodel.Row
    public short getLastCellNum() {
        if (this._cells.isEmpty()) {
            return -1;
        }
        return (short) (this._cells.lastKey().intValue() + 1);
    }

    @Override // org.apache.poi.ss.usermodel.Row
    public int getOutlineLevel() {
        return this._outlineLevel;
    }

    @Override // org.apache.poi.ss.usermodel.Row
    public int getPhysicalNumberOfCells() {
        return this._cells.size();
    }

    @Override // org.apache.poi.ss.usermodel.Row
    public int getRowNum() {
        return this._sheet.getRowNum(this);
    }

    @Override // org.apache.poi.ss.usermodel.Row
    public CellStyle getRowStyle() {
        if (!isFormatted()) {
            return null;
        }
        return getSheet().getWorkbook().getCellStyleAt(this._style);
    }

    @Internal
    public int getRowStyleIndex() {
        return this._style;
    }

    @Override // org.apache.poi.ss.usermodel.Row
    public boolean getZeroHeight() {
        return this._zHeight;
    }

    public boolean hasCustomHeight() {
        return this._height != -1;
    }

    public int hashCode() {
        return this._cells.hashCode();
    }

    @Override // org.apache.poi.ss.usermodel.Row
    public boolean isFormatted() {
        return this._style > -1;
    }

    @Override // java.lang.Iterable
    public Iterator<Cell> iterator() {
        return new FilledCellIterator();
    }

    @Override // org.apache.poi.ss.usermodel.Row
    public void removeCell(Cell cell) {
        this._cells.remove(Integer.valueOf(getCellIndex((SXSSFCell) cell)));
    }

    public void setCollapsed(Boolean bool) {
        this._collapsed = bool;
    }

    @Override // org.apache.poi.ss.usermodel.Row
    public void setHeight(short s) {
        this._height = s;
    }

    @Override // org.apache.poi.ss.usermodel.Row
    public void setHeightInPoints(float f2) {
        if (f2 == -1.0f) {
            this._height = -1;
        } else {
            this._height = (short) ((int) (f2 * 20.0f));
        }
    }

    public void setHidden(Boolean bool) {
        this._hidden = bool;
    }

    public void setOutlineLevel(int i2) {
        this._outlineLevel = i2;
    }

    @Override // org.apache.poi.ss.usermodel.Row
    public void setRowNum(int i2) {
        this._sheet.changeRowNum(this, i2);
    }

    @Override // org.apache.poi.ss.usermodel.Row
    public void setRowStyle(CellStyle cellStyle) {
        if (cellStyle == null) {
            this._style = -1;
        } else {
            this._style = cellStyle.getIndex();
        }
    }

    @Override // org.apache.poi.ss.usermodel.Row
    public void setZeroHeight(boolean z) {
        this._zHeight = z;
    }

    public SXSSFRow(SXSSFSheet sXSSFSheet) {
        this._cells = new TreeMap();
        this._style = -1;
        this._height = -1;
        this._zHeight = false;
        this._outlineLevel = 0;
        Boolean bool = UNDEFINED;
        this._hidden = bool;
        this._collapsed = bool;
        this._sheet = sXSSFSheet;
    }

    public int compareTo(SXSSFRow sXSSFRow) {
        if (getSheet() == sXSSFRow.getSheet()) {
            return Integer.valueOf(getRowNum()).compareTo(Integer.valueOf(sXSSFRow.getRowNum()));
        }
        throw new IllegalArgumentException("The compared rows must belong to the same sheet");
    }

    @Override // org.apache.poi.ss.usermodel.Row
    public SXSSFSheet getSheet() {
        return this._sheet;
    }

    @Override // org.apache.poi.ss.usermodel.Row
    public SXSSFCell getCell(int i2) {
        return getCell(i2, this._sheet.getWorkbook().getMissingCellPolicy());
    }

    @Override // org.apache.poi.ss.usermodel.Row
    public SXSSFCell createCell(int i2) {
        return createCell(i2, CellType.BLANK);
    }

    @Override // org.apache.poi.ss.usermodel.Row
    public SXSSFCell createCell(int i2, int i3) {
        return createCell(i2, CellType.forInt(i3));
    }

    @Override // org.apache.poi.ss.usermodel.Row
    public SXSSFCell getCell(int i2, Row.MissingCellPolicy missingCellPolicy) {
        checkBounds(i2);
        SXSSFCell sXSSFCell = this._cells.get(Integer.valueOf(i2));
        int ordinal = missingCellPolicy.ordinal();
        if (ordinal == 0) {
            return sXSSFCell;
        }
        boolean z = true;
        if (ordinal == 1) {
            if (sXSSFCell == null || sXSSFCell.getCellTypeEnum() != CellType.BLANK) {
                z = false;
            }
            if (z) {
                return null;
            }
            return sXSSFCell;
        } else if (ordinal == 2) {
            return sXSSFCell == null ? createCell(i2, CellType.BLANK) : sXSSFCell;
        } else {
            StringBuilder sb = new StringBuilder();
            sb.append("Illegal policy ");
            sb.append(missingCellPolicy);
            sb.append(" (");
            throw new IllegalArgumentException(a.a(sb, missingCellPolicy.id, ")"));
        }
    }

    @Override // org.apache.poi.ss.usermodel.Row
    public SXSSFCell createCell(int i2, CellType cellType) {
        checkBounds(i2);
        SXSSFCell sXSSFCell = new SXSSFCell(this, cellType);
        this._cells.put(Integer.valueOf(i2), sXSSFCell);
        return sXSSFCell;
    }
}
