package org.apache.poi.xssf.streaming;

import b.b.a.a.a;
import java.io.File;
import java.io.FileOutputStream;
import java.io.IOException;
import java.io.InputStream;
import java.io.InputStreamReader;
import java.io.OutputStream;
import java.io.OutputStreamWriter;
import java.util.Enumeration;
import java.util.HashMap;
import java.util.Iterator;
import java.util.List;
import java.util.Map;
import java.util.zip.ZipEntry;
import java.util.zip.ZipFile;
import java.util.zip.ZipOutputStream;
import org.apache.poi.Version;
import org.apache.poi.openxml4j.util.ZipEntrySource;
import org.apache.poi.openxml4j.util.ZipFileZipEntrySource;
import org.apache.poi.ss.SpreadsheetVersion;
import org.apache.poi.ss.formula.udf.UDFFinder;
import org.apache.poi.ss.usermodel.CellStyle;
import org.apache.poi.ss.usermodel.CreationHelper;
import org.apache.poi.ss.usermodel.DataFormat;
import org.apache.poi.ss.usermodel.Font;
import org.apache.poi.ss.usermodel.Name;
import org.apache.poi.ss.usermodel.PictureData;
import org.apache.poi.ss.usermodel.Row;
import org.apache.poi.ss.usermodel.Sheet;
import org.apache.poi.ss.usermodel.SheetVisibility;
import org.apache.poi.ss.usermodel.Workbook;
import org.apache.poi.util.IOUtils;
import org.apache.poi.util.Internal;
import org.apache.poi.util.NotImplemented;
import org.apache.poi.util.POILogFactory;
import org.apache.poi.util.POILogger;
import org.apache.poi.util.Removal;
import org.apache.poi.util.TempFile;
import org.apache.poi.xssf.model.SharedStringsTable;
import org.apache.poi.xssf.usermodel.XSSFChartSheet;
import org.apache.poi.xssf.usermodel.XSSFSheet;
import org.apache.poi.xssf.usermodel.XSSFWorkbook;

public class SXSSFWorkbook implements Workbook {
    public static final int DEFAULT_WINDOW_SIZE = 100;
    public static final POILogger logger = POILogFactory.getLogger(SXSSFWorkbook.class);
    public boolean _compressTmpFiles;
    public int _randomAccessWindowSize;
    public final SharedStringsTable _sharedStringSource;
    public final Map<SXSSFSheet, XSSFSheet> _sxFromXHash;
    public final XSSFWorkbook _wb;
    public final Map<XSSFSheet, SXSSFSheet> _xFromSxHash;

    public final class SheetIterator<T extends Sheet> implements Iterator<T> {
        public final Iterator<XSSFSheet> it;

        /* JADX DEBUG: Type inference failed for r1v2. Raw type applied. Possible types: java.util.Iterator<org.apache.poi.ss.usermodel.Sheet>, java.util.Iterator<org.apache.poi.xssf.usermodel.XSSFSheet> */
        public SheetIterator() {
            this.it = SXSSFWorkbook.this._wb.iterator();
        }

        public boolean hasNext() {
            return this.it.hasNext();
        }

        public void remove() {
            throw new UnsupportedOperationException("remove method not supported on XSSFWorkbook.iterator(). Use Sheet.removeSheetAt(int) instead.");
        }

        @Override // java.util.Iterator
        public T next() {
            return SXSSFWorkbook.this.getSXSSFSheet(this.it.next());
        }
    }

    public SXSSFWorkbook() {
        this((XSSFWorkbook) null);
    }

    public static void copyStreamAndInjectWorksheet(InputStream inputStream, OutputStream outputStream, InputStream inputStream2) {
        InputStreamReader inputStreamReader = new InputStreamReader(inputStream, "UTF-8");
        OutputStreamWriter outputStreamWriter = new OutputStreamWriter(outputStream, "UTF-8");
        int i2 = 10;
        String str = "<sheetData";
        int i3 = 0;
        boolean z = true;
        while (true) {
            int read = inputStreamReader.read();
            if (read == -1) {
                break;
            }
            if (read == str.charAt(i3)) {
                i3++;
                if (i3 != i2) {
                    continue;
                } else if (!"<sheetData".equals(str)) {
                    break;
                } else {
                    int read2 = inputStreamReader.read();
                    if (read2 == -1) {
                        outputStreamWriter.write(str);
                        break;
                    } else if (read2 == 62) {
                        outputStreamWriter.write(str);
                        outputStreamWriter.write(read2);
                        i2 = 12;
                        str = "</sheetData>";
                        i3 = 0;
                        z = false;
                    } else if (read2 == 47) {
                        int read3 = inputStreamReader.read();
                        if (read3 == -1) {
                            outputStreamWriter.write(str);
                            break;
                        } else if (read3 == 62) {
                            break;
                        } else {
                            outputStreamWriter.write(str);
                            outputStreamWriter.write(47);
                            outputStreamWriter.write(read3);
                        }
                    } else {
                        outputStreamWriter.write(str);
                        outputStreamWriter.write(47);
                        outputStreamWriter.write(read2);
                    }
                }
            } else {
                if (i3 > 0) {
                    outputStreamWriter.write(str, 0, i3);
                }
                if (read == str.charAt(0)) {
                    i3 = 1;
                } else {
                    outputStreamWriter.write(read);
                }
            }
            i3 = 0;
        }
        outputStreamWriter.flush();
        if (z) {
            outputStreamWriter.write("<sheetData>\n");
            outputStreamWriter.flush();
        }
        IOUtils.copy(inputStream2, outputStream);
        outputStreamWriter.write("</sheetData>");
        outputStreamWriter.flush();
        while (true) {
            int read4 = inputStreamReader.read();
            if (read4 != -1) {
                outputStreamWriter.write(read4);
            } else {
                outputStreamWriter.flush();
                return;
            }
        }
    }

    private XSSFSheet getSheetFromZipEntryName(String str) {
        for (XSSFSheet xSSFSheet : this._sxFromXHash.values()) {
            if (str.equals(xSSFSheet.getPackagePart().getPartName().getName().substring(1))) {
                return xSSFSheet;
            }
        }
        return null;
    }

    private void setRandomAccessWindowSize(int i2) {
        if (i2 == 0 || i2 < -1) {
            throw new IllegalArgumentException("rowAccessWindowSize must be greater than 0 or -1");
        }
        this._randomAccessWindowSize = i2;
    }

    @Override // org.apache.poi.ss.usermodel.Workbook
    public int addOlePackage(byte[] bArr, String str, String str2, String str3) {
        return this._wb.addOlePackage(bArr, str, str2, str3);
    }

    @Override // org.apache.poi.ss.usermodel.Workbook
    public int addPicture(byte[] bArr, int i2) {
        return this._wb.addPicture(bArr, i2);
    }

    @Override // org.apache.poi.ss.usermodel.Workbook
    public void addToolPack(UDFFinder uDFFinder) {
        this._wb.addToolPack(uDFFinder);
    }

    @Override // org.apache.poi.ss.usermodel.Workbook
    @NotImplemented
    public Sheet cloneSheet(int i2) {
        throw new RuntimeException("NotImplemented");
    }

    @Override // org.apache.poi.ss.usermodel.Workbook, java.io.Closeable, java.lang.AutoCloseable
    public void close() {
        for (SXSSFSheet sXSSFSheet : this._xFromSxHash.values()) {
            try {
                sXSSFSheet.getSheetDataWriter().close();
            } catch (IOException e2) {
                POILogger pOILogger = logger;
                StringBuilder b2 = a.b("An exception occurred while closing sheet data writer for sheet ");
                b2.append(sXSSFSheet.getSheetName());
                b2.append(".");
                pOILogger.log(5, b2.toString(), e2);
            }
        }
        this._wb.close();
    }

    public SXSSFSheet createAndRegisterSXSSFSheet(XSSFSheet xSSFSheet) {
        try {
            SXSSFSheet sXSSFSheet = new SXSSFSheet(this, xSSFSheet);
            registerSheetMapping(sXSSFSheet, xSSFSheet);
            return sXSSFSheet;
        } catch (IOException e2) {
            throw new RuntimeException(e2);
        }
    }

    @Override // org.apache.poi.ss.usermodel.Workbook
    public CellStyle createCellStyle() {
        return this._wb.createCellStyle();
    }

    @Override // org.apache.poi.ss.usermodel.Workbook
    public DataFormat createDataFormat() {
        return this._wb.createDataFormat();
    }

    @Override // org.apache.poi.ss.usermodel.Workbook
    public Font createFont() {
        return this._wb.createFont();
    }

    @Override // org.apache.poi.ss.usermodel.Workbook
    public Name createName() {
        return this._wb.createName();
    }

    public SheetDataWriter createSheetDataWriter() {
        if (this._compressTmpFiles) {
            return new GZIPSheetDataWriter(this._sharedStringSource);
        }
        return new SheetDataWriter(this._sharedStringSource);
    }

    public void deregisterSheetMapping(XSSFSheet xSSFSheet) {
        SXSSFSheet sXSSFSheet = getSXSSFSheet(xSSFSheet);
        try {
            sXSSFSheet.getSheetDataWriter().close();
        } catch (IOException unused) {
        }
        this._sxFromXHash.remove(sXSSFSheet);
        this._xFromSxHash.remove(xSSFSheet);
    }

    public boolean dispose() {
        boolean z = true;
        for (SXSSFSheet sXSSFSheet : this._sxFromXHash.keySet()) {
            boolean z2 = false;
            try {
                if (sXSSFSheet.dispose() && z) {
                    z2 = true;
                }
                z = z2;
            } catch (IOException e2) {
                logger.log(5, e2);
                z = false;
            }
        }
        return z;
    }

    @Removal(version = Version.VERSION_STRING)
    @Deprecated
    public Font findFont(short s, short s2, short s3, String str, boolean z, boolean z2, short s4, byte b2) {
        return this._wb.findFont(s, s2, s3, str, z, z2, s4, b2);
    }

    public void flushSheets() {
        for (SXSSFSheet sXSSFSheet : this._xFromSxHash.values()) {
            sXSSFSheet.flushRows();
        }
    }

    @Override // org.apache.poi.ss.usermodel.Workbook
    public int getActiveSheetIndex() {
        return this._wb.getActiveSheetIndex();
    }

    @Override // org.apache.poi.ss.usermodel.Workbook
    public List<? extends Name> getAllNames() {
        return this._wb.getAllNames();
    }

    @Override // org.apache.poi.ss.usermodel.Workbook
    public List<? extends PictureData> getAllPictures() {
        return this._wb.getAllPictures();
    }

    @Override // org.apache.poi.ss.usermodel.Workbook
    public CellStyle getCellStyleAt(int i2) {
        return this._wb.getCellStyleAt(i2);
    }

    @Override // org.apache.poi.ss.usermodel.Workbook
    public CreationHelper getCreationHelper() {
        return new SXSSFCreationHelper(this);
    }

    @Override // org.apache.poi.ss.usermodel.Workbook
    public int getFirstVisibleTab() {
        return this._wb.getFirstVisibleTab();
    }

    @Override // org.apache.poi.ss.usermodel.Workbook
    public Font getFontAt(short s) {
        return this._wb.getFontAt(s);
    }

    @Override // org.apache.poi.ss.usermodel.Workbook
    public boolean getForceFormulaRecalculation() {
        return this._wb.getForceFormulaRecalculation();
    }

    @Override // org.apache.poi.ss.usermodel.Workbook
    public Row.MissingCellPolicy getMissingCellPolicy() {
        return this._wb.getMissingCellPolicy();
    }

    @Override // org.apache.poi.ss.usermodel.Workbook
    public Name getName(String str) {
        return this._wb.getName(str);
    }

    @Override // org.apache.poi.ss.usermodel.Workbook
    @Removal(version = "3.18")
    @Deprecated
    public Name getNameAt(int i2) {
        return this._wb.getNameAt(i2);
    }

    @Override // org.apache.poi.ss.usermodel.Workbook
    @Removal(version = "3.18")
    @Deprecated
    public int getNameIndex(String str) {
        return this._wb.getNameIndex(str);
    }

    @Override // org.apache.poi.ss.usermodel.Workbook
    public List<? extends Name> getNames(String str) {
        return this._wb.getNames(str);
    }

    @Override // org.apache.poi.ss.usermodel.Workbook
    public int getNumCellStyles() {
        return this._wb.getNumCellStyles();
    }

    @Override // org.apache.poi.ss.usermodel.Workbook
    public short getNumberOfFonts() {
        return this._wb.getNumberOfFonts();
    }

    @Override // org.apache.poi.ss.usermodel.Workbook
    public int getNumberOfNames() {
        return this._wb.getNumberOfNames();
    }

    @Override // org.apache.poi.ss.usermodel.Workbook
    public int getNumberOfSheets() {
        return this._wb.getNumberOfSheets();
    }

    @Override // org.apache.poi.ss.usermodel.Workbook
    public String getPrintArea(int i2) {
        return this._wb.getPrintArea(i2);
    }

    public int getRandomAccessWindowSize() {
        return this._randomAccessWindowSize;
    }

    public SXSSFSheet getSXSSFSheet(XSSFSheet xSSFSheet) {
        return this._xFromSxHash.get(xSSFSheet);
    }

    @Internal
    public SharedStringsTable getSharedStringSource() {
        return this._sharedStringSource;
    }

    @Override // org.apache.poi.ss.usermodel.Workbook
    public int getSheetIndex(String str) {
        return this._wb.getSheetIndex(str);
    }

    @Override // org.apache.poi.ss.usermodel.Workbook
    public String getSheetName(int i2) {
        return this._wb.getSheetName(i2);
    }

    @Override // org.apache.poi.ss.usermodel.Workbook
    public SheetVisibility getSheetVisibility(int i2) {
        return this._wb.getSheetVisibility(i2);
    }

    @Override // org.apache.poi.ss.usermodel.Workbook
    public SpreadsheetVersion getSpreadsheetVersion() {
        return SpreadsheetVersion.EXCEL2007;
    }

    public XSSFSheet getXSSFSheet(SXSSFSheet sXSSFSheet) {
        return this._sxFromXHash.get(sXSSFSheet);
    }

    public XSSFWorkbook getXSSFWorkbook() {
        return this._wb;
    }

    /* JADX INFO: finally extract failed */
    public void injectData(ZipEntrySource zipEntrySource, OutputStream outputStream) {
        try {
            ZipOutputStream zipOutputStream = new ZipOutputStream(outputStream);
            try {
                Enumeration<? extends ZipEntry> entries = zipEntrySource.getEntries();
                while (entries.hasMoreElements()) {
                    ZipEntry zipEntry = (ZipEntry) entries.nextElement();
                    zipOutputStream.putNextEntry(new ZipEntry(zipEntry.getName()));
                    InputStream inputStream = zipEntrySource.getInputStream(zipEntry);
                    XSSFSheet sheetFromZipEntryName = getSheetFromZipEntryName(zipEntry.getName());
                    if (sheetFromZipEntryName == null || (sheetFromZipEntryName instanceof XSSFChartSheet)) {
                        IOUtils.copy(inputStream, zipOutputStream);
                    } else {
                        InputStream worksheetXMLInputStream = getSXSSFSheet(sheetFromZipEntryName).getWorksheetXMLInputStream();
                        try {
                            copyStreamAndInjectWorksheet(inputStream, zipOutputStream, worksheetXMLInputStream);
                        } finally {
                            worksheetXMLInputStream.close();
                        }
                    }
                    inputStream.close();
                }
                zipOutputStream.close();
            } catch (Throwable th) {
                zipOutputStream.close();
                throw th;
            }
        } finally {
            zipEntrySource.close();
        }
    }

    public boolean isCompressTempFiles() {
        return this._compressTmpFiles;
    }

    public boolean isDate1904() {
        return this._wb.isDate1904();
    }

    @Override // org.apache.poi.ss.usermodel.Workbook
    @NotImplemented("XSSFWorkbook#isHidden is not implemented")
    public boolean isHidden() {
        return this._wb.isHidden();
    }

    @Override // org.apache.poi.ss.usermodel.Workbook
    public boolean isSheetHidden(int i2) {
        return this._wb.isSheetHidden(i2);
    }

    @Override // org.apache.poi.ss.usermodel.Workbook
    public boolean isSheetVeryHidden(int i2) {
        return this._wb.isSheetVeryHidden(i2);
    }

    @Override // java.lang.Iterable
    public Iterator<Sheet> iterator() {
        return sheetIterator();
    }

    @Override // org.apache.poi.ss.usermodel.Workbook
    @NotImplemented
    public int linkExternalWorkbook(String str, Workbook workbook) {
        throw new RuntimeException("NotImplemented");
    }

    public void registerSheetMapping(SXSSFSheet sXSSFSheet, XSSFSheet xSSFSheet) {
        this._sxFromXHash.put(sXSSFSheet, xSSFSheet);
        this._xFromSxHash.put(xSSFSheet, sXSSFSheet);
    }

    @Override // org.apache.poi.ss.usermodel.Workbook
    @Removal(version = "3.18")
    @Deprecated
    public void removeName(int i2) {
        this._wb.removeName(i2);
    }

    @Override // org.apache.poi.ss.usermodel.Workbook
    public void removePrintArea(int i2) {
        this._wb.removePrintArea(i2);
    }

    @Override // org.apache.poi.ss.usermodel.Workbook
    public void removeSheetAt(int i2) {
        XSSFSheet sheetAt = this._wb.getSheetAt(i2);
        SXSSFSheet sXSSFSheet = getSXSSFSheet(sheetAt);
        this._wb.removeSheetAt(i2);
        deregisterSheetMapping(sheetAt);
        try {
            sXSSFSheet.dispose();
        } catch (IOException e2) {
            logger.log(5, e2);
        }
    }

    @Override // org.apache.poi.ss.usermodel.Workbook
    public void setActiveSheet(int i2) {
        this._wb.setActiveSheet(i2);
    }

    public void setCompressTempFiles(boolean z) {
        this._compressTmpFiles = z;
    }

    @Override // org.apache.poi.ss.usermodel.Workbook
    public void setFirstVisibleTab(int i2) {
        this._wb.setFirstVisibleTab(i2);
    }

    @Override // org.apache.poi.ss.usermodel.Workbook
    public void setForceFormulaRecalculation(boolean z) {
        this._wb.setForceFormulaRecalculation(z);
    }

    @Override // org.apache.poi.ss.usermodel.Workbook
    @NotImplemented("XSSFWorkbook#setHidden is not implemented")
    public void setHidden(boolean z) {
        this._wb.setHidden(z);
    }

    @Override // org.apache.poi.ss.usermodel.Workbook
    public void setMissingCellPolicy(Row.MissingCellPolicy missingCellPolicy) {
        this._wb.setMissingCellPolicy(missingCellPolicy);
    }

    @Override // org.apache.poi.ss.usermodel.Workbook
    public void setPrintArea(int i2, String str) {
        this._wb.setPrintArea(i2, str);
    }

    @Override // org.apache.poi.ss.usermodel.Workbook
    public void setSelectedTab(int i2) {
        this._wb.setSelectedTab(i2);
    }

    @Override // org.apache.poi.ss.usermodel.Workbook
    public void setSheetHidden(int i2, boolean z) {
        this._wb.setSheetHidden(i2, z);
    }

    @Override // org.apache.poi.ss.usermodel.Workbook
    public void setSheetName(int i2, String str) {
        this._wb.setSheetName(i2, str);
    }

    @Override // org.apache.poi.ss.usermodel.Workbook
    public void setSheetOrder(String str, int i2) {
        this._wb.setSheetOrder(str, i2);
    }

    @Override // org.apache.poi.ss.usermodel.Workbook
    public void setSheetVisibility(int i2, SheetVisibility sheetVisibility) {
        this._wb.setSheetVisibility(i2, sheetVisibility);
    }

    @Override // org.apache.poi.ss.usermodel.Workbook
    public Iterator<Sheet> sheetIterator() {
        return new SheetIterator();
    }

    /* JADX INFO: finally extract failed */
    @Override // org.apache.poi.ss.usermodel.Workbook
    public void write(OutputStream outputStream) {
        flushSheets();
        File createTempFile = TempFile.createTempFile("poi-sxssf-template", ".xlsx");
        try {
            FileOutputStream fileOutputStream = new FileOutputStream(createTempFile);
            try {
                this._wb.write(fileOutputStream);
                fileOutputStream.close();
                injectData(new ZipFileZipEntrySource(new ZipFile(createTempFile)), outputStream);
                if (!createTempFile.delete()) {
                    throw new IOException("Could not delete temporary file after processing: " + createTempFile);
                }
            } catch (Throwable th) {
                fileOutputStream.close();
                throw th;
            }
        } finally {
            createTempFile.delete();
        }
    }

    public SXSSFWorkbook(XSSFWorkbook xSSFWorkbook) {
        this(xSSFWorkbook, 100);
    }

    @Override // org.apache.poi.ss.usermodel.Workbook
    public Font findFont(boolean z, short s, short s2, String str, boolean z2, boolean z3, short s3, byte b2) {
        return this._wb.findFont(z, s, s2, str, z2, z3, s3, b2);
    }

    @Override // org.apache.poi.ss.usermodel.Workbook
    public SXSSFSheet getSheet(String str) {
        return getSXSSFSheet(this._wb.getSheet(str));
    }

    @Override // org.apache.poi.ss.usermodel.Workbook
    public SXSSFSheet getSheetAt(int i2) {
        return getSXSSFSheet(this._wb.getSheetAt(i2));
    }

    @Override // org.apache.poi.ss.usermodel.Workbook
    public int getSheetIndex(Sheet sheet) {
        return this._wb.getSheetIndex(getXSSFSheet((SXSSFSheet) sheet));
    }

    @Override // org.apache.poi.ss.usermodel.Workbook
    @Removal(version = "3.18")
    @Deprecated
    public void removeName(String str) {
        this._wb.removeName(str);
    }

    @Override // org.apache.poi.ss.usermodel.Workbook
    public void setPrintArea(int i2, int i3, int i4, int i5, int i6) {
        this._wb.setPrintArea(i2, i3, i4, i5, i6);
    }

    @Override // org.apache.poi.ss.usermodel.Workbook
    @Removal(version = "3.18")
    @Deprecated
    public void setSheetHidden(int i2, int i3) {
        this._wb.setSheetHidden(i2, i3);
    }

    public SXSSFWorkbook(XSSFWorkbook xSSFWorkbook, int i2) {
        this(xSSFWorkbook, i2, false);
    }

    @Override // org.apache.poi.ss.usermodel.Workbook
    public SXSSFSheet createSheet() {
        return createAndRegisterSXSSFSheet(this._wb.createSheet());
    }

    @Override // org.apache.poi.ss.usermodel.Workbook
    public void removeName(Name name) {
        this._wb.removeName(name);
    }

    public SXSSFWorkbook(XSSFWorkbook xSSFWorkbook, int i2, boolean z) {
        this(xSSFWorkbook, i2, z, false);
    }

    @Override // org.apache.poi.ss.usermodel.Workbook
    public SXSSFSheet createSheet(String str) {
        return createAndRegisterSXSSFSheet(this._wb.createSheet(str));
    }

    public SXSSFWorkbook(XSSFWorkbook xSSFWorkbook, int i2, boolean z, boolean z2) {
        this._sxFromXHash = new HashMap();
        this._xFromSxHash = new HashMap();
        this._randomAccessWindowSize = 100;
        setRandomAccessWindowSize(i2);
        setCompressTempFiles(z);
        SharedStringsTable sharedStringsTable = null;
        if (xSSFWorkbook == null) {
            XSSFWorkbook xSSFWorkbook2 = new XSSFWorkbook();
            this._wb = xSSFWorkbook2;
            this._sharedStringSource = z2 ? xSSFWorkbook2.getSharedStringSource() : sharedStringsTable;
            return;
        }
        this._wb = xSSFWorkbook;
        this._sharedStringSource = z2 ? xSSFWorkbook.getSharedStringSource() : sharedStringsTable;
        Iterator<Sheet> it = this._wb.iterator();
        while (it.hasNext()) {
            createAndRegisterSXSSFSheet((XSSFSheet) it.next());
        }
    }

    public SXSSFWorkbook(int i2) {
        this(null, i2);
    }
}
