package org.apache.poi.xssf.usermodel;

import b.b.a.a.a;
import java.text.SimpleDateFormat;
import java.util.Calendar;
import java.util.Date;
import org.apache.poi.Version;
import org.apache.poi.ss.SpreadsheetVersion;
import org.apache.poi.ss.formula.FormulaParser;
import org.apache.poi.ss.formula.FormulaRenderer;
import org.apache.poi.ss.formula.FormulaType;
import org.apache.poi.ss.formula.SharedFormula;
import org.apache.poi.ss.formula.eval.ErrorEval;
import org.apache.poi.ss.formula.functions.NumericFunction;
import org.apache.poi.ss.usermodel.Cell;
import org.apache.poi.ss.usermodel.CellCopyPolicy;
import org.apache.poi.ss.usermodel.CellStyle;
import org.apache.poi.ss.usermodel.CellType;
import org.apache.poi.ss.usermodel.Comment;
import org.apache.poi.ss.usermodel.DateUtil;
import org.apache.poi.ss.usermodel.FormulaError;
import org.apache.poi.ss.usermodel.Hyperlink;
import org.apache.poi.ss.usermodel.RichTextString;
import org.apache.poi.ss.usermodel.Row;
import org.apache.poi.ss.util.CellAddress;
import org.apache.poi.ss.util.CellRangeAddress;
import org.apache.poi.ss.util.CellReference;
import org.apache.poi.util.Internal;
import org.apache.poi.util.LocaleUtil;
import org.apache.poi.util.Removal;
import org.apache.poi.xssf.model.SharedStringsTable;
import org.apache.poi.xssf.model.StylesTable;
import org.openxmlformats.schemas.spreadsheetml.x2006.main.CTCell;
import org.openxmlformats.schemas.spreadsheetml.x2006.main.CTCellFormula;
import org.openxmlformats.schemas.spreadsheetml.x2006.main.STCellFormulaType;
import org.openxmlformats.schemas.spreadsheetml.x2006.main.STCellType;

public final class XSSFCell implements Cell {
    public static final String FALSE = "FALSE";
    public static final String FALSE_AS_STRING = "0";
    public static final String TRUE = "TRUE";
    public static final String TRUE_AS_STRING = "1";
    public CTCell _cell;
    public int _cellNum;
    public final XSSFRow _row;
    public SharedStringsTable _sharedStringSource;
    public StylesTable _stylesSource;

    /* renamed from: org.apache.poi.xssf.usermodel.XSSFCell$1  reason: invalid class name */
    public static /* synthetic */ class AnonymousClass1 {
        public static final /* synthetic */ int[] $SwitchMap$org$apache$poi$ss$usermodel$CellType;

        /* JADX WARNING: Can't wrap try/catch for region: R(14:0|1|2|3|4|5|6|7|8|9|10|11|12|14) */
        /* JADX WARNING: Code restructure failed: missing block: B:15:?, code lost:
            return;
         */
        /* JADX WARNING: Failed to process nested try/catch */
        /* JADX WARNING: Missing exception handler attribute for start block: B:11:0x002a */
        /* JADX WARNING: Missing exception handler attribute for start block: B:3:0x000e */
        /* JADX WARNING: Missing exception handler attribute for start block: B:5:0x0015 */
        /* JADX WARNING: Missing exception handler attribute for start block: B:7:0x001c */
        /* JADX WARNING: Missing exception handler attribute for start block: B:9:0x0023 */
        static {
            int[] iArr = new int[CellType.values().length];
            $SwitchMap$org$apache$poi$ss$usermodel$CellType = iArr;
            CellType cellType = CellType.NUMERIC;
            iArr[1] = 1;
            int[] iArr2 = $SwitchMap$org$apache$poi$ss$usermodel$CellType;
            CellType cellType2 = CellType.STRING;
            iArr2[2] = 2;
            int[] iArr3 = $SwitchMap$org$apache$poi$ss$usermodel$CellType;
            CellType cellType3 = CellType.FORMULA;
            iArr3[3] = 3;
            int[] iArr4 = $SwitchMap$org$apache$poi$ss$usermodel$CellType;
            CellType cellType4 = CellType.BLANK;
            iArr4[4] = 4;
            int[] iArr5 = $SwitchMap$org$apache$poi$ss$usermodel$CellType;
            CellType cellType5 = CellType.BOOLEAN;
            iArr5[5] = 5;
            int[] iArr6 = $SwitchMap$org$apache$poi$ss$usermodel$CellType;
            CellType cellType6 = CellType.ERROR;
            iArr6[6] = 6;
        }
    }

    public XSSFCell(XSSFRow xSSFRow, CTCell cTCell) {
        this._cell = cTCell;
        this._row = xSSFRow;
        if (cTCell.getR() != null) {
            this._cellNum = new CellReference(cTCell.getR()).getCol();
        } else {
            short lastCellNum = xSSFRow.getLastCellNum();
            if (lastCellNum != -1) {
                this._cellNum = xSSFRow.getCell(lastCellNum - 1, Row.MissingCellPolicy.RETURN_NULL_AND_BLANK).getColumnIndex() + 1;
            }
        }
        this._sharedStringSource = xSSFRow.getSheet().getWorkbook().getSharedStringSource();
        this._stylesSource = xSSFRow.getSheet().getWorkbook().getStylesSource();
    }

    public static void checkBounds(int i2) {
        SpreadsheetVersion spreadsheetVersion = SpreadsheetVersion.EXCEL2007;
        int lastColumnIndex = spreadsheetVersion.getLastColumnIndex();
        if (i2 < 0 || i2 > lastColumnIndex) {
            throw new IllegalArgumentException("Invalid column index (" + i2 + ").  Allowable column range for " + "EXCEL2007" + " is (0.." + lastColumnIndex + ") or ('A'..'" + spreadsheetVersion.getLastColumnName() + "')");
        }
    }

    public static void checkFormulaCachedValueType(CellType cellType, CellType cellType2) {
        if (cellType2 != cellType) {
            throw typeMismatch(cellType, cellType2, true);
        }
    }

    private boolean convertCellValueToBoolean() {
        CellType cellTypeEnum = getCellTypeEnum();
        if (cellTypeEnum == CellType.FORMULA) {
            cellTypeEnum = getBaseCellType(false);
        }
        int ordinal = cellTypeEnum.ordinal();
        if (ordinal != 1) {
            if (ordinal != 2) {
                if (ordinal != 4) {
                    if (ordinal == 5) {
                        return "1".equals(this._cell.getV());
                    }
                    if (ordinal != 6) {
                        throw new RuntimeException("Unexpected cell type (" + cellTypeEnum + ")");
                    }
                }
                return false;
            }
            return Boolean.parseBoolean(new XSSFRichTextString(this._sharedStringSource.getEntryAt(Integer.parseInt(this._cell.getV()))).getString());
        } else if (Double.parseDouble(this._cell.getV()) != NumericFunction.LOG_10_TO_BASE_e) {
            return true;
        } else {
            return false;
        }
    }

    private String convertCellValueToString() {
        CellType cellTypeEnum = getCellTypeEnum();
        switch (cellTypeEnum.ordinal()) {
            case 1:
            case 6:
                return this._cell.getV();
            case 2:
                return new XSSFRichTextString(this._sharedStringSource.getEntryAt(Integer.parseInt(this._cell.getV()))).getString();
            case 3:
                CellType baseCellType = getBaseCellType(false);
                String v = this._cell.getV();
                int ordinal = baseCellType.ordinal();
                if (!(ordinal == 1 || ordinal == 2)) {
                    if (ordinal != 5) {
                        if (ordinal != 6) {
                            throw new IllegalStateException("Unexpected formula result type (" + baseCellType + ")");
                        }
                    } else if ("1".equals(v)) {
                        return TRUE;
                    } else {
                        if ("0".equals(v)) {
                            return FALSE;
                        }
                        throw new IllegalStateException(a.b("Unexpected boolean cached formula value '", v, "'."));
                    }
                }
                return v;
            case 4:
                return "";
            case 5:
                return "1".equals(this._cell.getV()) ? TRUE : FALSE;
            default:
                throw new IllegalStateException("Unexpected cell type (" + cellTypeEnum + ")");
        }
    }

    private String convertSharedFormula(int i2, XSSFEvaluationWorkbook xSSFEvaluationWorkbook) {
        XSSFSheet sheet = getSheet();
        CTCellFormula sharedFormula = sheet.getSharedFormula(i2);
        if (sharedFormula != null) {
            String stringValue = sharedFormula.getStringValue();
            CellRangeAddress valueOf = CellRangeAddress.valueOf(sharedFormula.getRef());
            return FormulaRenderer.toFormulaString(xSSFEvaluationWorkbook, new SharedFormula(SpreadsheetVersion.EXCEL2007).convertSharedFormulas(FormulaParser.parse(stringValue, xSSFEvaluationWorkbook, FormulaType.CELL, sheet.getWorkbook().getSheetIndex(sheet), getRowIndex()), getRowIndex() - valueOf.getFirstRow(), getColumnIndex() - valueOf.getFirstColumn()));
        }
        throw new IllegalStateException(a.b("Master cell of a shared formula with sid=", i2, " was not found"));
    }

    private CellType getBaseCellType(boolean z) {
        switch (this._cell.getT().intValue()) {
            case 1:
                return CellType.BOOLEAN;
            case 2:
                if (this._cell.isSetV() || !z) {
                    return CellType.NUMERIC;
                }
                return CellType.BLANK;
            case 3:
                return CellType.ERROR;
            case 4:
            case 5:
            case 6:
                return CellType.STRING;
            default:
                StringBuilder b2 = a.b("Illegal cell type: ");
                b2.append(this._cell.getT());
                throw new IllegalStateException(b2.toString());
        }
    }

    private boolean isFormulaCell() {
        return (this._cell.isSetF() && this._cell.getF().getT() != STCellFormulaType.DATA_TABLE) || getSheet().isCellInArrayFormulaContext(this);
    }

    private void setBlank() {
        CTCell newInstance = CTCell.Factory.newInstance();
        newInstance.setR(this._cell.getR());
        if (this._cell.isSetS()) {
            newInstance.setS(this._cell.getS());
        }
        this._cell.set(newInstance);
    }

    private void setFormula(String str, FormulaType formulaType) {
        XSSFWorkbook workbook = this._row.getSheet().getWorkbook();
        if (str == null) {
            workbook.onDeleteFormula(this);
            if (this._cell.isSetF()) {
                this._cell.unsetF();
                return;
            }
            return;
        }
        FormulaParser.parse(str, XSSFEvaluationWorkbook.create(workbook), formulaType, workbook.getSheetIndex(getSheet()), getRowIndex());
        CTCellFormula newInstance = CTCellFormula.Factory.newInstance();
        newInstance.setStringValue(str);
        this._cell.setF(newInstance);
        if (this._cell.isSetV()) {
            this._cell.unsetV();
        }
    }

    public static RuntimeException typeMismatch(CellType cellType, CellType cellType2, boolean z) {
        StringBuilder sb = new StringBuilder();
        sb.append("Cannot get a ");
        sb.append(cellType);
        sb.append(" value from a ");
        sb.append(cellType2);
        sb.append(" ");
        return new IllegalStateException(a.a(sb, z ? "formula " : "", "cell"));
    }

    @Internal
    public void copyCellFrom(Cell cell, CellCopyPolicy cellCopyPolicy) {
        Hyperlink hyperlink;
        CellStyle cellStyle;
        if (cellCopyPolicy.isCopyCellValue()) {
            if (cell != null) {
                CellType cellTypeEnum = cell.getCellTypeEnum();
                if (cellTypeEnum == CellType.FORMULA && !cellCopyPolicy.isCopyCellFormula()) {
                    cellTypeEnum = cell.getCachedFormulaResultTypeEnum();
                }
                switch (cellTypeEnum.ordinal()) {
                    case 1:
                        if (!DateUtil.isCellDateFormatted(cell)) {
                            setCellValue(cell.getNumericCellValue());
                            break;
                        } else {
                            setCellValue(cell.getDateCellValue());
                            break;
                        }
                    case 2:
                        setCellValue(cell.getStringCellValue());
                        break;
                    case 3:
                        setCellFormula(cell.getCellFormula());
                        break;
                    case 4:
                        setBlank();
                        break;
                    case 5:
                        setCellValue(cell.getBooleanCellValue());
                        break;
                    case 6:
                        setCellErrorValue(cell.getErrorCellValue());
                        break;
                    default:
                        StringBuilder b2 = a.b("Invalid cell type ");
                        b2.append(cell.getCellTypeEnum());
                        throw new IllegalArgumentException(b2.toString());
                }
            } else {
                setBlank();
            }
        }
        XSSFHyperlink xSSFHyperlink = null;
        if (cellCopyPolicy.isCopyCellStyle()) {
            if (cell == null) {
                cellStyle = null;
            } else {
                cellStyle = cell.getCellStyle();
            }
            setCellStyle(cellStyle);
        }
        if (cell == null) {
            hyperlink = null;
        } else {
            hyperlink = cell.getHyperlink();
        }
        if (cellCopyPolicy.isMergeHyperlink()) {
            if (hyperlink != null) {
                setHyperlink(new XSSFHyperlink(hyperlink));
            }
        } else if (cellCopyPolicy.isCopyHyperlink()) {
            if (hyperlink != null) {
                xSSFHyperlink = new XSSFHyperlink(hyperlink);
            }
            setHyperlink(xSSFHyperlink);
        }
    }

    @Override // org.apache.poi.ss.usermodel.Cell
    public CellAddress getAddress() {
        return new CellAddress(this);
    }

    @Override // org.apache.poi.ss.usermodel.Cell
    public CellRangeAddress getArrayFormulaRange() {
        XSSFCell firstCellInArrayFormula = getSheet().getFirstCellInArrayFormula(this);
        if (firstCellInArrayFormula != null) {
            return CellRangeAddress.valueOf(firstCellInArrayFormula._cell.getF().getRef());
        }
        StringBuilder b2 = a.b("Cell ");
        b2.append(getReference());
        b2.append(" is not part of an array formula.");
        throw new IllegalStateException(b2.toString());
    }

    @Override // org.apache.poi.ss.usermodel.Cell
    public boolean getBooleanCellValue() {
        CellType cellTypeEnum = getCellTypeEnum();
        int ordinal = cellTypeEnum.ordinal();
        if (ordinal != 3) {
            if (ordinal == 4) {
                return false;
            }
            if (ordinal != 5) {
                throw typeMismatch(CellType.BOOLEAN, cellTypeEnum, false);
            } else if (!this._cell.isSetV() || !"1".equals(this._cell.getV())) {
                return false;
            } else {
                return true;
            }
        } else if (!this._cell.isSetV() || !"1".equals(this._cell.getV())) {
            return false;
        } else {
            return true;
        }
    }

    @Internal
    public CTCell getCTCell() {
        return this._cell;
    }

    @Override // org.apache.poi.ss.usermodel.Cell
    @Removal(version = Version.VERSION_STRING)
    @Deprecated
    public int getCachedFormulaResultType() {
        return getCachedFormulaResultTypeEnum().getCode();
    }

    @Override // org.apache.poi.ss.usermodel.Cell
    public CellType getCachedFormulaResultTypeEnum() {
        if (isFormulaCell()) {
            return getBaseCellType(false);
        }
        throw new IllegalStateException("Only formula cells have cached results");
    }

    @Override // org.apache.poi.ss.usermodel.Cell
    public String getCellFormula() {
        return getCellFormula(null);
    }

    @Override // org.apache.poi.ss.usermodel.Cell
    @Removal(version = Version.VERSION_STRING)
    @Deprecated
    public int getCellType() {
        return getCellTypeEnum().getCode();
    }

    @Override // org.apache.poi.ss.usermodel.Cell
    public CellType getCellTypeEnum() {
        if (isFormulaCell()) {
            return CellType.FORMULA;
        }
        return getBaseCellType(true);
    }

    @Override // org.apache.poi.ss.usermodel.Cell
    public int getColumnIndex() {
        return this._cellNum;
    }

    @Override // org.apache.poi.ss.usermodel.Cell
    public Date getDateCellValue() {
        if (getCellTypeEnum() == CellType.BLANK) {
            return null;
        }
        return DateUtil.getJavaDate(getNumericCellValue(), getSheet().getWorkbook().isDate1904());
    }

    public String getErrorCellString() {
        CellType baseCellType = getBaseCellType(true);
        CellType cellType = CellType.ERROR;
        if (baseCellType == cellType) {
            return this._cell.getV();
        }
        throw typeMismatch(cellType, baseCellType, false);
    }

    @Override // org.apache.poi.ss.usermodel.Cell
    public byte getErrorCellValue() {
        String errorCellString = getErrorCellString();
        if (errorCellString == null) {
            return 0;
        }
        try {
            return FormulaError.forString(errorCellString).getCode();
        } catch (IllegalArgumentException e2) {
            throw new IllegalStateException("Unexpected error code", e2);
        }
    }

    @Override // org.apache.poi.ss.usermodel.Cell
    public double getNumericCellValue() {
        CellType cellTypeEnum = getCellTypeEnum();
        int ordinal = cellTypeEnum.ordinal();
        if (ordinal == 1 || ordinal == 3) {
            if (!this._cell.isSetV()) {
                return NumericFunction.LOG_10_TO_BASE_e;
            }
            String v = this._cell.getV();
            if (v.isEmpty()) {
                return NumericFunction.LOG_10_TO_BASE_e;
            }
            try {
                return Double.parseDouble(v);
            } catch (NumberFormatException unused) {
                throw typeMismatch(CellType.NUMERIC, CellType.STRING, false);
            }
        } else if (ordinal == 4) {
            return NumericFunction.LOG_10_TO_BASE_e;
        } else {
            throw typeMismatch(CellType.NUMERIC, cellTypeEnum, false);
        }
    }

    public String getRawValue() {
        return this._cell.getV();
    }

    public String getReference() {
        String r = this._cell.getR();
        return r == null ? getAddress().formatAsString() : r;
    }

    @Override // org.apache.poi.ss.usermodel.Cell
    public int getRowIndex() {
        return this._row.getRowNum();
    }

    public SharedStringsTable getSharedStringSource() {
        return this._sharedStringSource;
    }

    @Override // org.apache.poi.ss.usermodel.Cell
    public String getStringCellValue() {
        return getRichStringCellValue().getString();
    }

    public StylesTable getStylesSource() {
        return this._stylesSource;
    }

    @Override // org.apache.poi.ss.usermodel.Cell
    public boolean isPartOfArrayFormulaGroup() {
        return getSheet().isCellInArrayFormulaContext(this);
    }

    public void notifyArrayFormulaChanging(String str) {
        if (!isPartOfArrayFormulaGroup()) {
            return;
        }
        if (getArrayFormulaRange().getNumberOfCells() <= 1) {
            getRow().getSheet().removeArrayFormula(this);
            return;
        }
        throw new IllegalStateException(str);
    }

    @Override // org.apache.poi.ss.usermodel.Cell
    public void removeCellComment() {
        if (getCellComment() != null) {
            CellAddress cellAddress = new CellAddress(getReference());
            XSSFSheet sheet = getSheet();
            sheet.getCommentsTable(false).removeComment(cellAddress);
            sheet.getVMLDrawing(false).removeCommentShape(getRowIndex(), getColumnIndex());
        }
    }

    @Override // org.apache.poi.ss.usermodel.Cell
    public void removeHyperlink() {
        getSheet().removeHyperlink(this._row.getRowNum(), this._cellNum);
    }

    @Override // org.apache.poi.ss.usermodel.Cell
    public void setAsActiveCell() {
        getSheet().setActiveCell(getAddress());
    }

    @Internal
    public void setCTCell(CTCell cTCell) {
        this._cell = cTCell;
    }

    public void setCellArrayFormula(String str, CellRangeAddress cellRangeAddress) {
        setFormula(str, FormulaType.ARRAY);
        CTCellFormula f2 = this._cell.getF();
        f2.setT(STCellFormulaType.ARRAY);
        f2.setRef(cellRangeAddress.formatAsString());
    }

    @Override // org.apache.poi.ss.usermodel.Cell
    public void setCellComment(Comment comment) {
        if (comment == null) {
            removeCellComment();
        } else {
            comment.setAddress(getRowIndex(), getColumnIndex());
        }
    }

    @Override // org.apache.poi.ss.usermodel.Cell
    public void setCellErrorValue(byte b2) {
        setCellErrorValue(FormulaError.forInt(b2));
    }

    @Override // org.apache.poi.ss.usermodel.Cell
    public void setCellFormula(String str) {
        if (isPartOfArrayFormulaGroup()) {
            notifyArrayFormulaChanging();
        }
        setFormula(str, FormulaType.CELL);
    }

    public void setCellNum(int i2) {
        checkBounds(i2);
        this._cellNum = i2;
        this._cell.setR(new CellReference(getRowIndex(), getColumnIndex()).formatAsString());
    }

    @Override // org.apache.poi.ss.usermodel.Cell
    public void setCellStyle(CellStyle cellStyle) {
        if (cellStyle != null) {
            XSSFCellStyle xSSFCellStyle = (XSSFCellStyle) cellStyle;
            xSSFCellStyle.verifyBelongsToStylesSource(this._stylesSource);
            this._cell.setS((long) this._stylesSource.putStyle(xSSFCellStyle));
        } else if (this._cell.isSetS()) {
            this._cell.unsetS();
        }
    }

    @Override // org.apache.poi.ss.usermodel.Cell
    @Removal(version = Version.VERSION_STRING)
    @Deprecated
    public void setCellType(int i2) {
        setCellType(CellType.forInt(i2));
    }

    @Override // org.apache.poi.ss.usermodel.Cell
    public void setCellValue(boolean z) {
        this._cell.setT(STCellType.B);
        this._cell.setV(z ? "1" : "0");
    }

    @Override // org.apache.poi.ss.usermodel.Cell
    public void setHyperlink(Hyperlink hyperlink) {
        if (hyperlink == null) {
            removeHyperlink();
            return;
        }
        XSSFHyperlink xSSFHyperlink = (XSSFHyperlink) hyperlink;
        xSSFHyperlink.setCellReference(new CellReference(this._row.getRowNum(), this._cellNum).formatAsString());
        getSheet().addHyperlink(xSSFHyperlink);
    }

    public String toString() {
        switch (getCellTypeEnum().ordinal()) {
            case 1:
                if (!DateUtil.isCellDateFormatted(this)) {
                    return Double.toString(getNumericCellValue());
                }
                SimpleDateFormat simpleDateFormat = new SimpleDateFormat("dd-MMM-yyyy", LocaleUtil.getUserLocale());
                simpleDateFormat.setTimeZone(LocaleUtil.getUserTimeZone());
                return simpleDateFormat.format(getDateCellValue());
            case 2:
                return getRichStringCellValue().toString();
            case 3:
                return getCellFormula();
            case 4:
                return "";
            case 5:
                return getBooleanCellValue() ? TRUE : FALSE;
            case 6:
                return ErrorEval.getText(getErrorCellValue());
            default:
                StringBuilder b2 = a.b("Unknown Cell Type: ");
                b2.append(getCellTypeEnum());
                return b2.toString();
        }
    }

    @Override // org.apache.poi.ss.usermodel.Cell
    public XSSFComment getCellComment() {
        return getSheet().getCellComment(new CellAddress(this));
    }

    public String getCellFormula(XSSFEvaluationWorkbook xSSFEvaluationWorkbook) {
        CellType cellTypeEnum = getCellTypeEnum();
        CellType cellType = CellType.FORMULA;
        if (cellTypeEnum == cellType) {
            CTCellFormula f2 = this._cell.getF();
            if (isPartOfArrayFormulaGroup() && f2 == null) {
                return getSheet().getFirstCellInArrayFormula(this).getCellFormula(xSSFEvaluationWorkbook);
            }
            if (f2.getT() != STCellFormulaType.SHARED) {
                return f2.getStringValue();
            }
            int si = (int) f2.getSi();
            if (xSSFEvaluationWorkbook == null) {
                xSSFEvaluationWorkbook = XSSFEvaluationWorkbook.create(getSheet().getWorkbook());
            }
            return convertSharedFormula(si, xSSFEvaluationWorkbook);
        }
        throw typeMismatch(cellType, cellTypeEnum, false);
    }

    @Override // org.apache.poi.ss.usermodel.Cell
    public XSSFCellStyle getCellStyle() {
        if (this._stylesSource.getNumCellStyles() <= 0) {
            return null;
        }
        return this._stylesSource.getStyleAt((int) (this._cell.isSetS() ? this._cell.getS() : 0));
    }

    @Override // org.apache.poi.ss.usermodel.Cell
    public XSSFHyperlink getHyperlink() {
        return getSheet().getHyperlink(this._row.getRowNum(), this._cellNum);
    }

    @Override // org.apache.poi.ss.usermodel.Cell
    public XSSFRichTextString getRichStringCellValue() {
        XSSFRichTextString xSSFRichTextString;
        CellType cellTypeEnum = getCellTypeEnum();
        int ordinal = cellTypeEnum.ordinal();
        String str = "";
        if (ordinal != 2) {
            if (ordinal == 3) {
                checkFormulaCachedValueType(CellType.STRING, getBaseCellType(false));
                if (this._cell.isSetV()) {
                    str = this._cell.getV();
                }
                xSSFRichTextString = new XSSFRichTextString(str);
            } else if (ordinal == 4) {
                xSSFRichTextString = new XSSFRichTextString(str);
            } else {
                throw typeMismatch(CellType.STRING, cellTypeEnum, false);
            }
        } else if (this._cell.getT() == STCellType.INLINE_STR) {
            if (this._cell.isSetIs()) {
                xSSFRichTextString = new XSSFRichTextString(this._cell.getIs());
            } else if (this._cell.isSetV()) {
                xSSFRichTextString = new XSSFRichTextString(this._cell.getV());
            } else {
                xSSFRichTextString = new XSSFRichTextString(str);
            }
        } else if (this._cell.getT() == STCellType.STR) {
            if (this._cell.isSetV()) {
                str = this._cell.getV();
            }
            xSSFRichTextString = new XSSFRichTextString(str);
        } else if (this._cell.isSetV()) {
            xSSFRichTextString = new XSSFRichTextString(this._sharedStringSource.getEntryAt(Integer.parseInt(this._cell.getV())));
        } else {
            xSSFRichTextString = new XSSFRichTextString(str);
        }
        xSSFRichTextString.setStylesTableReference(this._stylesSource);
        return xSSFRichTextString;
    }

    @Override // org.apache.poi.ss.usermodel.Cell
    public XSSFRow getRow() {
        return this._row;
    }

    @Override // org.apache.poi.ss.usermodel.Cell
    public XSSFSheet getSheet() {
        return getRow().getSheet();
    }

    @Override // org.apache.poi.ss.usermodel.Cell
    public void setCellType(CellType cellType) {
        CellType cellTypeEnum = getCellTypeEnum();
        if (isPartOfArrayFormulaGroup()) {
            notifyArrayFormulaChanging();
        }
        CellType cellType2 = CellType.FORMULA;
        if (cellTypeEnum == cellType2 && cellType != cellType2) {
            getSheet().getWorkbook().onDeleteFormula(this);
        }
        String str = "0";
        switch (cellType.ordinal()) {
            case 1:
                this._cell.setT(STCellType.N);
                break;
            case 2:
                if (cellTypeEnum != CellType.STRING) {
                    XSSFRichTextString xSSFRichTextString = new XSSFRichTextString(convertCellValueToString());
                    xSSFRichTextString.setStylesTableReference(this._stylesSource);
                    this._cell.setV(Integer.toString(this._sharedStringSource.addEntry(xSSFRichTextString.getCTRst())));
                }
                this._cell.setT(STCellType.S);
                break;
            case 3:
                if (!this._cell.isSetF()) {
                    CTCellFormula newInstance = CTCellFormula.Factory.newInstance();
                    newInstance.setStringValue(str);
                    this._cell.setF(newInstance);
                    if (this._cell.isSetT()) {
                        this._cell.unsetT();
                        break;
                    }
                }
                break;
            case 4:
                setBlank();
                break;
            case 5:
                if (convertCellValueToBoolean()) {
                    str = "1";
                }
                this._cell.setT(STCellType.B);
                this._cell.setV(str);
                break;
            case 6:
                this._cell.setT(STCellType.E);
                break;
            default:
                throw new IllegalArgumentException("Illegal cell type: " + cellType);
        }
        if (cellType != CellType.FORMULA && this._cell.isSetF()) {
            this._cell.unsetF();
        }
    }

    public void setCellErrorValue(FormulaError formulaError) {
        this._cell.setT(STCellType.E);
        this._cell.setV(formulaError.getString());
    }

    @Override // org.apache.poi.ss.usermodel.Cell
    public void setCellValue(double d2) {
        if (Double.isInfinite(d2)) {
            this._cell.setT(STCellType.E);
            this._cell.setV(FormulaError.DIV0.getString());
        } else if (Double.isNaN(d2)) {
            this._cell.setT(STCellType.E);
            this._cell.setV(FormulaError.NUM.getString());
        } else {
            this._cell.setT(STCellType.N);
            this._cell.setV(String.valueOf(d2));
        }
    }

    public void notifyArrayFormulaChanging() {
        CellReference cellReference = new CellReference(this);
        StringBuilder b2 = a.b("Cell ");
        b2.append(cellReference.formatAsString());
        b2.append(" is part of a multi-cell array formula. ");
        b2.append("You cannot change part of an array.");
        notifyArrayFormulaChanging(b2.toString());
    }

    @Override // org.apache.poi.ss.usermodel.Cell
    public void setCellValue(String str) {
        setCellValue(str == null ? null : new XSSFRichTextString(str));
    }

    @Override // org.apache.poi.ss.usermodel.Cell
    public void setCellValue(RichTextString richTextString) {
        if (richTextString == null || richTextString.getString() == null) {
            setCellType(CellType.BLANK);
        } else if (richTextString.length() > SpreadsheetVersion.EXCEL2007.getMaxTextLength()) {
            throw new IllegalArgumentException("The maximum length of cell contents (text) is 32,767 characters");
        } else if (getCellTypeEnum().ordinal() == 3) {
            this._cell.setV(richTextString.getString());
            this._cell.setT(STCellType.STR);
        } else if (this._cell.getT() == STCellType.INLINE_STR) {
            this._cell.setV(richTextString.getString());
        } else {
            this._cell.setT(STCellType.S);
            XSSFRichTextString xSSFRichTextString = (XSSFRichTextString) richTextString;
            xSSFRichTextString.setStylesTableReference(this._stylesSource);
            this._cell.setV(Integer.toString(this._sharedStringSource.addEntry(xSSFRichTextString.getCTRst())));
        }
    }

    @Override // org.apache.poi.ss.usermodel.Cell
    public void setCellValue(Date date) {
        if (date == null) {
            setCellType(CellType.BLANK);
        } else {
            setCellValue(DateUtil.getExcelDate(date, getSheet().getWorkbook().isDate1904()));
        }
    }

    @Override // org.apache.poi.ss.usermodel.Cell
    public void setCellValue(Calendar calendar) {
        if (calendar == null) {
            setCellType(CellType.BLANK);
        } else {
            setCellValue(DateUtil.getExcelDate(calendar, getSheet().getWorkbook().isDate1904()));
        }
    }
}
