package org.apache.poi.xssf.usermodel;

import b.e.a.b.i;
import java.io.InputStream;
import java.io.OutputStream;
import java.util.ArrayList;
import java.util.Iterator;
import java.util.List;
import org.apache.poi.POIXMLDocument;
import org.apache.poi.POIXMLDocumentPart;
import org.apache.poi.POIXMLException;
import org.apache.poi.POIXMLTypeLoader;
import org.apache.poi.javax.xml.namespace.QName;
import org.apache.poi.openxml4j.exceptions.InvalidFormatException;
import org.apache.poi.openxml4j.opc.PackagePart;
import org.apache.poi.openxml4j.opc.PackagePartName;
import org.apache.poi.openxml4j.opc.PackageRelationship;
import org.apache.poi.openxml4j.opc.PackageRelationshipTypes;
import org.apache.poi.openxml4j.opc.PackagingURIHelper;
import org.apache.poi.openxml4j.opc.TargetMode;
import org.apache.poi.ss.formula.functions.NumericFunction;
import org.apache.poi.ss.usermodel.ClientAnchor;
import org.apache.poi.ss.usermodel.Drawing;
import org.apache.poi.ss.util.CellAddress;
import org.apache.poi.ss.util.ImageUtils;
import org.apache.poi.util.Internal;
import org.apache.poi.util.POILogFactory;
import org.apache.poi.util.POILogger;
import org.apache.poi.util.Units;
import org.apache.poi.xssf.model.CommentsTable;
import org.apache.xmlbeans.XmlCursor;
import org.apache.xmlbeans.XmlException;
import org.apache.xmlbeans.XmlObject;
import org.apache.xmlbeans.XmlOptions;
import org.apache.xmlbeans.impl.values.XmlAnyTypeImpl;
import org.openxmlformats.schemas.drawingml.x2006.main.CTBlipFillProperties;
import org.openxmlformats.schemas.drawingml.x2006.main.CTGroupTransform2D;
import org.openxmlformats.schemas.drawingml.x2006.main.CTNonVisualDrawingProps;
import org.openxmlformats.schemas.drawingml.x2006.main.CTPoint2D;
import org.openxmlformats.schemas.drawingml.x2006.main.CTPositiveSize2D;
import org.openxmlformats.schemas.drawingml.x2006.main.CTTransform2D;
import org.openxmlformats.schemas.drawingml.x2006.spreadsheetDrawing.CTAbsoluteAnchor;
import org.openxmlformats.schemas.drawingml.x2006.spreadsheetDrawing.CTConnector;
import org.openxmlformats.schemas.drawingml.x2006.spreadsheetDrawing.CTDrawing;
import org.openxmlformats.schemas.drawingml.x2006.spreadsheetDrawing.CTGraphicalObjectFrame;
import org.openxmlformats.schemas.drawingml.x2006.spreadsheetDrawing.CTGroupShape;
import org.openxmlformats.schemas.drawingml.x2006.spreadsheetDrawing.CTMarker;
import org.openxmlformats.schemas.drawingml.x2006.spreadsheetDrawing.CTOneCellAnchor;
import org.openxmlformats.schemas.drawingml.x2006.spreadsheetDrawing.CTPicture;
import org.openxmlformats.schemas.drawingml.x2006.spreadsheetDrawing.CTShape;
import org.openxmlformats.schemas.drawingml.x2006.spreadsheetDrawing.CTTwoCellAnchor;
import org.openxmlformats.schemas.drawingml.x2006.spreadsheetDrawing.STEditAs;
import org.openxmlformats.schemas.spreadsheetml.x2006.main.CTOleObject;
import org.openxmlformats.schemas.spreadsheetml.x2006.main.CTWorksheet;

public final class XSSFDrawing extends POIXMLDocumentPart implements Drawing<XSSFShape> {
    public static final /* synthetic */ boolean $assertionsDisabled = false;
    public static final POILogger LOG = POILogFactory.getLogger(XSSFDrawing.class);
    public static final String NAMESPACE_A = "http://schemas.openxmlformats.org/drawingml/2006/main";
    public static final String NAMESPACE_C = "http://schemas.openxmlformats.org/drawingml/2006/chart";
    public CTDrawing drawing;
    public long numOfGraphicFrames;

    /* renamed from: org.apache.poi.xssf.usermodel.XSSFDrawing$1  reason: invalid class name */
    public static /* synthetic */ class AnonymousClass1 {
        public static final /* synthetic */ int[] $SwitchMap$org$apache$poi$ss$usermodel$ClientAnchor$AnchorType;

        /* JADX WARNING: Can't wrap try/catch for region: R(8:0|(2:1|2)|3|5|6|7|8|10) */
        /* JADX WARNING: Code restructure failed: missing block: B:11:?, code lost:
            return;
         */
        /* JADX WARNING: Failed to process nested try/catch */
        /* JADX WARNING: Missing exception handler attribute for start block: B:7:0x0017 */
        static {
            int[] iArr = new int[ClientAnchor.AnchorType.values().length];
            $SwitchMap$org$apache$poi$ss$usermodel$ClientAnchor$AnchorType = iArr;
            try {
                ClientAnchor.AnchorType anchorType = ClientAnchor.AnchorType.DONT_MOVE_AND_RESIZE;
                iArr[3] = 1;
            } catch (NoSuchFieldError unused) {
            }
            int[] iArr2 = $SwitchMap$org$apache$poi$ss$usermodel$ClientAnchor$AnchorType;
            ClientAnchor.AnchorType anchorType2 = ClientAnchor.AnchorType.MOVE_AND_RESIZE;
            iArr2[0] = 2;
            int[] iArr3 = $SwitchMap$org$apache$poi$ss$usermodel$ClientAnchor$AnchorType;
            ClientAnchor.AnchorType anchorType3 = ClientAnchor.AnchorType.MOVE_DONT_RESIZE;
            iArr3[2] = 3;
        }
    }

    public XSSFDrawing() {
        this.numOfGraphicFrames = 0;
        this.drawing = newDrawing();
    }

    private void addShapes(XmlCursor xmlCursor, List<XSSFShape> list) {
        XSSFShape xSSFShape;
        do {
            try {
                xmlCursor.push();
                if (xmlCursor.toFirstChild()) {
                    do {
                        XmlObject object = xmlCursor.getObject();
                        if (!(object instanceof CTMarker)) {
                            if (object instanceof CTPicture) {
                                xSSFShape = new XSSFPicture(this, (CTPicture) object);
                            } else if (object instanceof CTConnector) {
                                xSSFShape = new XSSFConnector(this, (CTConnector) object);
                            } else if (object instanceof CTShape) {
                                xSSFShape = hasOleLink(object) ? new XSSFObjectData(this, (CTShape) object) : new XSSFSimpleShape(this, (CTShape) object);
                            } else if (object instanceof CTGraphicalObjectFrame) {
                                xSSFShape = new XSSFGraphicFrame(this, (CTGraphicalObjectFrame) object);
                            } else if (object instanceof CTGroupShape) {
                                xSSFShape = new XSSFShapeGroup(this, (CTGroupShape) object);
                            } else if (object instanceof XmlAnyTypeImpl) {
                                LOG.log(5, "trying to parse AlternateContent, this unlinks the returned Shapes from the underlying xml content, so those shapes can't be used to modify the drawing, i.e. modifications will be ignored!");
                                xmlCursor.push();
                                xmlCursor.toFirstChild();
                                XmlCursor xmlCursor2 = null;
                                try {
                                    XmlCursor newCursor = CTDrawing.Factory.parse(xmlCursor.newXMLStreamReader()).newCursor();
                                    if (newCursor.toFirstChild()) {
                                        addShapes(newCursor, list);
                                    }
                                    newCursor.dispose();
                                } catch (XmlException e2) {
                                    LOG.log(5, "unable to parse CTDrawing in alternate content.", e2);
                                    if (0 != 0) {
                                        xmlCursor2.dispose();
                                    }
                                } catch (Throwable th) {
                                    if (0 != 0) {
                                        xmlCursor2.dispose();
                                    }
                                    xmlCursor.pop();
                                    throw th;
                                }
                                xmlCursor.pop();
                            }
                            xSSFShape.anchor = getAnchorFromParent(object);
                            list.add(xSSFShape);
                        }
                    } while (xmlCursor.toNextSibling());
                }
                xmlCursor.pop();
            } finally {
                xmlCursor.dispose();
            }
        } while (xmlCursor.toNextSibling());
    }

    private XSSFGraphicFrame createGraphicFrame(XSSFClientAnchor xSSFClientAnchor) {
        CTGraphicalObjectFrame addNewGraphicFrame = createTwoCellAnchor(xSSFClientAnchor).addNewGraphicFrame();
        addNewGraphicFrame.set(XSSFGraphicFrame.prototype());
        addNewGraphicFrame.setXfrm(createXfrm(xSSFClientAnchor));
        long j = this.numOfGraphicFrames;
        this.numOfGraphicFrames = 1 + j;
        XSSFGraphicFrame xSSFGraphicFrame = new XSSFGraphicFrame(this, addNewGraphicFrame);
        xSSFGraphicFrame.setAnchor(xSSFClientAnchor);
        xSSFGraphicFrame.setId(j);
        xSSFGraphicFrame.setName("Diagramm" + j);
        return xSSFGraphicFrame;
    }

    private CTTwoCellAnchor createTwoCellAnchor(XSSFClientAnchor xSSFClientAnchor) {
        STEditAs.Enum r3;
        CTTwoCellAnchor addNewTwoCellAnchor = this.drawing.addNewTwoCellAnchor();
        addNewTwoCellAnchor.setFrom(xSSFClientAnchor.getFrom());
        addNewTwoCellAnchor.setTo(xSSFClientAnchor.getTo());
        addNewTwoCellAnchor.addNewClientData();
        xSSFClientAnchor.setTo(addNewTwoCellAnchor.getTo());
        xSSFClientAnchor.setFrom(addNewTwoCellAnchor.getFrom());
        int ordinal = xSSFClientAnchor.getAnchorType().ordinal();
        if (ordinal == 0) {
            r3 = STEditAs.TWO_CELL;
        } else if (ordinal == 2) {
            r3 = STEditAs.ONE_CELL;
        } else if (ordinal != 3) {
            r3 = STEditAs.ONE_CELL;
        } else {
            r3 = STEditAs.ABSOLUTE;
        }
        addNewTwoCellAnchor.setEditAs(r3);
        return addNewTwoCellAnchor;
    }

    private CTTransform2D createXfrm(XSSFClientAnchor xSSFClientAnchor) {
        CTTransform2D newInstance = CTTransform2D.Factory.newInstance();
        CTPoint2D addNewOff = newInstance.addNewOff();
        addNewOff.setX((long) xSSFClientAnchor.getDx1());
        addNewOff.setY((long) xSSFClientAnchor.getDy1());
        XSSFSheet sheet = getSheet();
        double d2 = NumericFunction.LOG_10_TO_BASE_e;
        double d3 = 0.0d;
        for (int col1 = xSSFClientAnchor.getCol1(); col1 < xSSFClientAnchor.getCol2(); col1++) {
            d3 += (double) sheet.getColumnWidthInPixels(col1);
        }
        for (int row1 = xSSFClientAnchor.getRow1(); row1 < xSSFClientAnchor.getRow2(); row1++) {
            d2 += ImageUtils.getRowHeightInPixels(sheet, row1);
        }
        CTPositiveSize2D addNewExt = newInstance.addNewExt();
        addNewExt.setCx((((long) Units.pixelToEMU((int) d3)) - ((long) xSSFClientAnchor.getDx1())) + ((long) xSSFClientAnchor.getDx2()));
        addNewExt.setCy((((long) Units.pixelToEMU((int) d2)) - ((long) xSSFClientAnchor.getDy1())) + ((long) xSSFClientAnchor.getDy2()));
        return newInstance;
    }

    private XSSFAnchor getAnchorFromParent(XmlObject xmlObject) {
        XmlCursor newCursor = xmlObject.newCursor();
        XmlObject object = newCursor.toParent() ? newCursor.getObject() : null;
        newCursor.dispose();
        if (object == null) {
            return null;
        }
        if (object instanceof CTTwoCellAnchor) {
            CTTwoCellAnchor cTTwoCellAnchor = (CTTwoCellAnchor) object;
            return new XSSFClientAnchor(cTTwoCellAnchor.getFrom(), cTTwoCellAnchor.getTo());
        } else if (object instanceof CTOneCellAnchor) {
            CTOneCellAnchor cTOneCellAnchor = (CTOneCellAnchor) object;
            return new XSSFClientAnchor(getSheet(), cTOneCellAnchor.getFrom(), cTOneCellAnchor.getExt());
        } else if (!(object instanceof CTAbsoluteAnchor)) {
            return null;
        } else {
            CTAbsoluteAnchor cTAbsoluteAnchor = (CTAbsoluteAnchor) object;
            return new XSSFClientAnchor(getSheet(), cTAbsoluteAnchor.getPos(), cTAbsoluteAnchor.getExt());
        }
    }

    private boolean hasOleLink(XmlObject xmlObject) {
        QName qName = new QName(null, "uri");
        XmlCursor newCursor = xmlObject.newCursor();
        newCursor.selectPath("declare namespace a='http://schemas.openxmlformats.org/drawingml/2006/main' .//a:extLst/a:ext");
        do {
            try {
                if (!newCursor.toNextSelection()) {
                    newCursor.dispose();
                    return false;
                }
            } finally {
                newCursor.dispose();
            }
        } while (!"{63B3BB69-23CF-44E3-9099-C40C66FF867C}".equals(newCursor.getAttributeText(qName)));
        return true;
    }

    public static CTDrawing newDrawing() {
        return CTDrawing.Factory.newInstance();
    }

    private long newShapeId() {
        return (long) (this.drawing.sizeOfTwoCellAnchorArray() + this.drawing.sizeOfOneCellAnchorArray() + this.drawing.sizeOfAbsoluteAnchorArray() + 1);
    }

    public PackageRelationship addPictureReference(int i2) {
        return addRelation(null, XSSFRelation.IMAGES, new XSSFPictureData(((XSSFWorkbook) getParent().getParent()).getAllPictures().get(i2).getPackagePart())).getRelationship();
    }

    @Override // org.apache.poi.POIXMLDocumentPart
    public void commit() {
        XmlOptions xmlOptions = new XmlOptions(POIXMLTypeLoader.DEFAULT_XML_OPTIONS);
        xmlOptions.setSaveSyntheticDocumentElement(new QName(CTDrawing.type.getName().getNamespaceURI(), "wsDr", "xdr"));
        OutputStream outputStream = getPackagePart().getOutputStream();
        this.drawing.save(outputStream, xmlOptions);
        outputStream.close();
    }

    public XSSFConnector createConnector(XSSFClientAnchor xSSFClientAnchor) {
        CTConnector addNewCxnSp = createTwoCellAnchor(xSSFClientAnchor).addNewCxnSp();
        addNewCxnSp.set(XSSFConnector.prototype());
        XSSFConnector xSSFConnector = new XSSFConnector(this, addNewCxnSp);
        xSSFConnector.anchor = xSSFClientAnchor;
        return xSSFConnector;
    }

    public XSSFShapeGroup createGroup(XSSFClientAnchor xSSFClientAnchor) {
        CTGroupShape addNewGrpSp = createTwoCellAnchor(xSSFClientAnchor).addNewGrpSp();
        addNewGrpSp.set(XSSFShapeGroup.prototype());
        CTTransform2D createXfrm = createXfrm(xSSFClientAnchor);
        CTGroupTransform2D xfrm = addNewGrpSp.getGrpSpPr().getXfrm();
        xfrm.setOff(createXfrm.getOff());
        xfrm.setExt(createXfrm.getExt());
        xfrm.setChExt(createXfrm.getExt());
        XSSFShapeGroup xSSFShapeGroup = new XSSFShapeGroup(this, addNewGrpSp);
        xSSFShapeGroup.anchor = xSSFClientAnchor;
        return xSSFShapeGroup;
    }

    public XSSFSimpleShape createSimpleShape(XSSFClientAnchor xSSFClientAnchor) {
        long newShapeId = newShapeId();
        CTShape addNewSp = createTwoCellAnchor(xSSFClientAnchor).addNewSp();
        addNewSp.set(XSSFSimpleShape.prototype());
        addNewSp.getNvSpPr().getCNvPr().setId(newShapeId);
        addNewSp.getSpPr().setXfrm(createXfrm(xSSFClientAnchor));
        XSSFSimpleShape xSSFSimpleShape = new XSSFSimpleShape(this, addNewSp);
        xSSFSimpleShape.anchor = xSSFClientAnchor;
        return xSSFSimpleShape;
    }

    public XSSFTextBox createTextbox(XSSFClientAnchor xSSFClientAnchor) {
        long newShapeId = newShapeId();
        CTShape addNewSp = createTwoCellAnchor(xSSFClientAnchor).addNewSp();
        addNewSp.set(XSSFSimpleShape.prototype());
        addNewSp.getNvSpPr().getCNvPr().setId(newShapeId);
        XSSFTextBox xSSFTextBox = new XSSFTextBox(this, addNewSp);
        xSSFTextBox.anchor = xSSFClientAnchor;
        return xSSFTextBox;
    }

    @Internal
    public CTDrawing getCTDrawing() {
        return this.drawing;
    }

    public List<XSSFChart> getCharts() {
        ArrayList arrayList = new ArrayList();
        for (POIXMLDocumentPart pOIXMLDocumentPart : getRelations()) {
            if (pOIXMLDocumentPart instanceof XSSFChart) {
                arrayList.add((XSSFChart) pOIXMLDocumentPart);
            }
        }
        return arrayList;
    }

    public List<XSSFShape> getShapes() {
        ArrayList arrayList = new ArrayList();
        XmlCursor newCursor = this.drawing.newCursor();
        try {
            if (newCursor.toFirstChild()) {
                addShapes(newCursor, arrayList);
            }
            return arrayList;
        } finally {
            newCursor.dispose();
        }
    }

    public XSSFSheet getSheet() {
        return (XSSFSheet) getParent();
    }

    @Override // java.lang.Iterable
    public Iterator<XSSFShape> iterator() {
        return getShapes().iterator();
    }

    @Override // org.apache.poi.ss.usermodel.Drawing
    public XSSFClientAnchor createAnchor(int i2, int i3, int i4, int i5, int i6, int i7, int i8, int i9) {
        return new XSSFClientAnchor(i2, i3, i4, i5, i6, i7, i8, i9);
    }

    @Override // org.apache.poi.ss.usermodel.Drawing
    public XSSFComment createCellComment(ClientAnchor clientAnchor) {
        XSSFClientAnchor xSSFClientAnchor = (XSSFClientAnchor) clientAnchor;
        XSSFSheet sheet = getSheet();
        CommentsTable commentsTable = sheet.getCommentsTable(true);
        i newCommentShape = sheet.getVMLDrawing(true).newCommentShape();
        if (xSSFClientAnchor.isSet()) {
            newCommentShape.a(0).a(0, ((int) xSSFClientAnchor.getCol1()) + ", " + (xSSFClientAnchor.getDx1() / 9525) + ", " + xSSFClientAnchor.getRow1() + ", " + (xSSFClientAnchor.getDy1() / 9525) + ", " + ((int) xSSFClientAnchor.getCol2()) + ", " + (xSSFClientAnchor.getDx2() / 9525) + ", " + xSSFClientAnchor.getRow2() + ", " + (xSSFClientAnchor.getDy2() / 9525));
        }
        CellAddress cellAddress = new CellAddress(xSSFClientAnchor.getRow1(), xSSFClientAnchor.getCol1());
        if (commentsTable.findCellComment(cellAddress) == null) {
            return new XSSFComment(commentsTable, commentsTable.newComment(cellAddress), newCommentShape);
        }
        throw new IllegalArgumentException("Multiple cell comments in one cell are not allowed, cell: " + cellAddress);
    }

    public XSSFChart createChart(XSSFClientAnchor xSSFClientAnchor) {
        POIXMLDocumentPart.RelationPart createRelationship = createRelationship(XSSFRelation.CHART, XSSFFactory.getInstance(), getPackagePart().getPackage().getPartsByContentType(XSSFRelation.CHART.getContentType()).size() + 1, false);
        XSSFChart xSSFChart = (XSSFChart) createRelationship.getDocumentPart();
        String id = createRelationship.getRelationship().getId();
        XSSFGraphicFrame createGraphicFrame = createGraphicFrame(xSSFClientAnchor);
        createGraphicFrame.setChart(xSSFChart, id);
        createGraphicFrame.getCTGraphicalObjectFrame().setXfrm(createXfrm(xSSFClientAnchor));
        return xSSFChart;
    }

    @Override // org.apache.poi.ss.usermodel.Drawing
    public XSSFObjectData createObjectData(ClientAnchor clientAnchor, int i2, int i3) {
        XSSFSheet sheet = getSheet();
        PackagePart packagePart = sheet.getPackagePart();
        XSSFSheet sheet2 = getSheet();
        long sheetIndex = ((long) ((sheet2.getWorkbook().getSheetIndex(sheet2) + 1) * 1024)) + newShapeId();
        try {
            PackageRelationship addRelationship = packagePart.addRelationship(PackagingURIHelper.createPartName("/xl/embeddings/oleObject" + i2 + ".bin"), TargetMode.INTERNAL, POIXMLDocument.OLE_OBJECT_REL_TYPE);
            PackagePartName partName = sheet.getWorkbook().getAllPictures().get(i3).getPackagePart().getPartName();
            PackageRelationship addRelationship2 = packagePart.addRelationship(partName, TargetMode.INTERNAL, PackageRelationshipTypes.IMAGE_PART);
            PackageRelationship addRelationship3 = getPackagePart().addRelationship(partName, TargetMode.INTERNAL, PackageRelationshipTypes.IMAGE_PART);
            CTWorksheet cTWorksheet = sheet.getCTWorksheet();
            CTOleObject addNewOleObject = (cTWorksheet.isSetOleObjects() ? cTWorksheet.getOleObjects() : cTWorksheet.addNewOleObjects()).addNewOleObject();
            addNewOleObject.setProgId("Package");
            addNewOleObject.setShapeId(sheetIndex);
            addNewOleObject.setId(addRelationship.getId());
            XmlCursor newCursor = addNewOleObject.newCursor();
            newCursor.toEndToken();
            newCursor.beginElement("objectPr", XSSFRelation.NS_SPREADSHEETML);
            newCursor.insertAttributeWithValue("id", PackageRelationshipTypes.CORE_PROPERTIES_ECMA376_NS, addRelationship2.getId());
            newCursor.insertAttributeWithValue("defaultSize", "0");
            newCursor.beginElement("anchor", XSSFRelation.NS_SPREADSHEETML);
            newCursor.insertAttributeWithValue("moveWithCells", "1");
            XSSFClientAnchor xSSFClientAnchor = (XSSFClientAnchor) clientAnchor;
            CTTwoCellAnchor createTwoCellAnchor = createTwoCellAnchor(xSSFClientAnchor);
            XmlCursor newCursor2 = createTwoCellAnchor.newCursor();
            newCursor2.copyXmlContents(newCursor);
            newCursor2.dispose();
            newCursor.toParent();
            newCursor.toFirstChild();
            newCursor.setName(new QName(XSSFRelation.NS_SPREADSHEETML, "from"));
            newCursor.toNextSibling();
            newCursor.setName(new QName(XSSFRelation.NS_SPREADSHEETML, "to"));
            newCursor.dispose();
            CTShape addNewSp = createTwoCellAnchor.addNewSp();
            addNewSp.set(XSSFObjectData.prototype());
            addNewSp.getSpPr().setXfrm(createXfrm(xSSFClientAnchor));
            CTBlipFillProperties addNewBlipFill = addNewSp.getSpPr().addNewBlipFill();
            addNewBlipFill.addNewBlip().setEmbed(addRelationship3.getId());
            addNewBlipFill.addNewStretch().addNewFillRect();
            CTNonVisualDrawingProps cNvPr = addNewSp.getNvSpPr().getCNvPr();
            cNvPr.setId(sheetIndex);
            cNvPr.setName("Object " + sheetIndex);
            XmlCursor newCursor3 = cNvPr.getExtLst().getExtArray(0).newCursor();
            newCursor3.toFirstChild();
            QName qName = new QName("spid");
            newCursor3.setAttributeText(qName, "_x0000_s" + sheetIndex);
            newCursor3.dispose();
            XSSFObjectData xSSFObjectData = new XSSFObjectData(this, addNewSp);
            xSSFObjectData.anchor = xSSFClientAnchor;
            return xSSFObjectData;
        } catch (InvalidFormatException e2) {
            throw new POIXMLException(e2);
        }
    }

    public XSSFPicture createPicture(XSSFClientAnchor xSSFClientAnchor, int i2) {
        PackageRelationship addPictureReference = addPictureReference(i2);
        long newShapeId = newShapeId();
        CTPicture addNewPic = createTwoCellAnchor(xSSFClientAnchor).addNewPic();
        addNewPic.set(XSSFPicture.prototype());
        addNewPic.getNvPicPr().getCNvPr().setId(newShapeId);
        XSSFPicture xSSFPicture = new XSSFPicture(this, addNewPic);
        xSSFPicture.anchor = xSSFClientAnchor;
        xSSFPicture.setPictureReference(addPictureReference);
        addNewPic.getSpPr().setXfrm(createXfrm(xSSFClientAnchor));
        return xSSFPicture;
    }

    public XSSFDrawing(PackagePart packagePart) {
        super(packagePart);
        this.numOfGraphicFrames = 0;
        XmlOptions xmlOptions = new XmlOptions(POIXMLTypeLoader.DEFAULT_XML_OPTIONS);
        xmlOptions.setLoadReplaceDocumentElement(null);
        InputStream inputStream = packagePart.getInputStream();
        try {
            this.drawing = CTDrawing.Factory.parse(inputStream, xmlOptions);
        } finally {
            inputStream.close();
        }
    }

    public List<XSSFShape> getShapes(XSSFShapeGroup xSSFShapeGroup) {
        ArrayList arrayList = new ArrayList();
        XmlCursor newCursor = xSSFShapeGroup.getCTGroupShape().newCursor();
        try {
            addShapes(newCursor, arrayList);
            return arrayList;
        } finally {
            newCursor.dispose();
        }
    }

    @Override // org.apache.poi.ss.usermodel.Drawing
    public XSSFChart createChart(ClientAnchor clientAnchor) {
        return createChart((XSSFClientAnchor) clientAnchor);
    }

    @Override // org.apache.poi.ss.usermodel.Drawing
    public XSSFPicture createPicture(ClientAnchor clientAnchor, int i2) {
        return createPicture((XSSFClientAnchor) clientAnchor, i2);
    }
}
