package org.apache.poi.xssf.usermodel;

import b.b.a.a.a;
import java.net.URI;
import java.net.URISyntaxException;
import org.apache.poi.common.usermodel.HyperlinkType;
import org.apache.poi.openxml4j.opc.PackagePart;
import org.apache.poi.openxml4j.opc.PackageRelationship;
import org.apache.poi.ss.usermodel.DataFormatter;
import org.apache.poi.ss.usermodel.Hyperlink;
import org.apache.poi.ss.util.CellReference;
import org.apache.poi.util.Internal;
import org.openxmlformats.schemas.spreadsheetml.x2006.main.CTHyperlink;

public class XSSFHyperlink implements Hyperlink {
    public final CTHyperlink _ctHyperlink;
    public final PackageRelationship _externalRel;
    public String _location;
    public final HyperlinkType _type;

    /* renamed from: org.apache.poi.xssf.usermodel.XSSFHyperlink$1  reason: invalid class name */
    public static /* synthetic */ class AnonymousClass1 {
        public static final /* synthetic */ int[] $SwitchMap$org$apache$poi$common$usermodel$HyperlinkType;

        /* JADX WARNING: Can't wrap try/catch for region: R(8:0|(2:1|2)|3|5|6|7|8|(3:9|10|12)) */
        /* JADX WARNING: Failed to process nested try/catch */
        /* JADX WARNING: Missing exception handler attribute for start block: B:7:0x0017 */
        /* JADX WARNING: Missing exception handler attribute for start block: B:9:0x001d */
        static {
            int[] iArr = new int[HyperlinkType.values().length];
            $SwitchMap$org$apache$poi$common$usermodel$HyperlinkType = iArr;
            try {
                HyperlinkType hyperlinkType = HyperlinkType.EMAIL;
                iArr[3] = 1;
            } catch (NoSuchFieldError unused) {
            }
            int[] iArr2 = $SwitchMap$org$apache$poi$common$usermodel$HyperlinkType;
            HyperlinkType hyperlinkType2 = HyperlinkType.FILE;
            iArr2[4] = 2;
            int[] iArr3 = $SwitchMap$org$apache$poi$common$usermodel$HyperlinkType;
            HyperlinkType hyperlinkType3 = HyperlinkType.URL;
            iArr3[1] = 3;
            try {
                int[] iArr4 = $SwitchMap$org$apache$poi$common$usermodel$HyperlinkType;
                HyperlinkType hyperlinkType4 = HyperlinkType.DOCUMENT;
                iArr4[2] = 4;
            } catch (NoSuchFieldError unused2) {
            }
        }
    }

    public XSSFHyperlink(int i2) {
        this(HyperlinkType.forInt(i2));
    }

    private CellReference buildCellReference() {
        String ref = this._ctHyperlink.getRef();
        if (ref == null) {
            ref = "A1";
        }
        return new CellReference(ref);
    }

    private void validate(String str) {
        int ordinal = this._type.ordinal();
        if (ordinal != 1) {
            if (ordinal == 2) {
                return;
            }
            if (!(ordinal == 3 || ordinal == 4)) {
                StringBuilder b2 = a.b("Invalid Hyperlink type: ");
                b2.append(this._type);
                throw new IllegalStateException(b2.toString());
            }
        }
        try {
            new URI(str);
        } catch (URISyntaxException e2) {
            throw new IllegalArgumentException("Address of hyperlink must be a valid URI", e2);
        }
    }

    public void generateRelationIfNeeded(PackagePart packagePart) {
        if (this._externalRel == null && needsRelationToo()) {
            this._ctHyperlink.setId(packagePart.addExternalRelationship(this._location, XSSFRelation.SHEET_HYPERLINKS.getRelation()).getId());
        }
    }

    @Override // org.apache.poi.common.usermodel.Hyperlink
    public String getAddress() {
        return this._location;
    }

    @Internal
    public CTHyperlink getCTHyperlink() {
        return this._ctHyperlink;
    }

    public String getCellRef() {
        return this._ctHyperlink.getRef();
    }

    @Override // org.apache.poi.ss.usermodel.Hyperlink
    public int getFirstColumn() {
        return buildCellReference().getCol();
    }

    @Override // org.apache.poi.ss.usermodel.Hyperlink
    public int getFirstRow() {
        return buildCellReference().getRow();
    }

    @Override // org.apache.poi.common.usermodel.Hyperlink
    public String getLabel() {
        return this._ctHyperlink.getDisplay();
    }

    @Override // org.apache.poi.ss.usermodel.Hyperlink
    public int getLastColumn() {
        return buildCellReference().getCol();
    }

    @Override // org.apache.poi.ss.usermodel.Hyperlink
    public int getLastRow() {
        return buildCellReference().getRow();
    }

    public String getLocation() {
        return this._ctHyperlink.getLocation();
    }

    public String getTooltip() {
        return this._ctHyperlink.getTooltip();
    }

    @Override // org.apache.poi.common.usermodel.Hyperlink
    public int getType() {
        return this._type.getCode();
    }

    @Override // org.apache.poi.common.usermodel.Hyperlink
    public HyperlinkType getTypeEnum() {
        return this._type;
    }

    public boolean needsRelationToo() {
        return this._type != HyperlinkType.DOCUMENT;
    }

    @Override // org.apache.poi.common.usermodel.Hyperlink
    public void setAddress(String str) {
        validate(str);
        this._location = str;
        if (this._type == HyperlinkType.DOCUMENT) {
            setLocation(str);
        }
    }

    @Internal
    public void setCellReference(String str) {
        this._ctHyperlink.setRef(str);
    }

    @Override // org.apache.poi.ss.usermodel.Hyperlink
    public void setFirstColumn(int i2) {
        setCellReference(new CellReference(getFirstRow(), i2));
    }

    @Override // org.apache.poi.ss.usermodel.Hyperlink
    public void setFirstRow(int i2) {
        setCellReference(new CellReference(i2, getFirstColumn()));
    }

    @Override // org.apache.poi.common.usermodel.Hyperlink
    public void setLabel(String str) {
        this._ctHyperlink.setDisplay(str);
    }

    @Override // org.apache.poi.ss.usermodel.Hyperlink
    public void setLastColumn(int i2) {
        setFirstColumn(i2);
    }

    @Override // org.apache.poi.ss.usermodel.Hyperlink
    public void setLastRow(int i2) {
        setFirstRow(i2);
    }

    public void setLocation(String str) {
        this._ctHyperlink.setLocation(str);
    }

    public void setTooltip(String str) {
        this._ctHyperlink.setTooltip(str);
    }

    public XSSFHyperlink(HyperlinkType hyperlinkType) {
        this._type = hyperlinkType;
        this._ctHyperlink = CTHyperlink.Factory.newInstance();
        this._externalRel = null;
    }

    @Internal
    public void setCellReference(CellReference cellReference) {
        setCellReference(cellReference.formatAsString());
    }

    public XSSFHyperlink(CTHyperlink cTHyperlink, PackageRelationship packageRelationship) {
        this._ctHyperlink = cTHyperlink;
        this._externalRel = packageRelationship;
        if (packageRelationship != null) {
            this._location = packageRelationship.getTargetURI().toString();
            if (cTHyperlink.getLocation() != null) {
                this._location += DataFormatter.defaultFractionWholePartFormat + cTHyperlink.getLocation();
            }
            if (this._location.startsWith("http://") || this._location.startsWith("https://") || this._location.startsWith("ftp://")) {
                this._type = HyperlinkType.URL;
            } else if (this._location.startsWith("mailto:")) {
                this._type = HyperlinkType.EMAIL;
            } else {
                this._type = HyperlinkType.FILE;
            }
        } else if (cTHyperlink.getLocation() != null) {
            this._type = HyperlinkType.DOCUMENT;
            this._location = cTHyperlink.getLocation();
        } else if (cTHyperlink.getId() == null) {
            this._type = HyperlinkType.DOCUMENT;
        } else {
            StringBuilder b2 = a.b("The hyperlink for cell ");
            b2.append(cTHyperlink.getRef());
            b2.append(" references relation ");
            b2.append(cTHyperlink.getId());
            b2.append(", but that didn't exist!");
            throw new IllegalStateException(b2.toString());
        }
    }

    @Internal
    public XSSFHyperlink(Hyperlink hyperlink) {
        if (hyperlink instanceof XSSFHyperlink) {
            XSSFHyperlink xSSFHyperlink = (XSSFHyperlink) hyperlink;
            this._type = xSSFHyperlink.getTypeEnum();
            this._location = xSSFHyperlink._location;
            this._externalRel = xSSFHyperlink._externalRel;
            this._ctHyperlink = (CTHyperlink) xSSFHyperlink._ctHyperlink.copy();
            return;
        }
        this._type = hyperlink.getTypeEnum();
        this._location = hyperlink.getAddress();
        this._externalRel = null;
        this._ctHyperlink = CTHyperlink.Factory.newInstance();
        setCellReference(new CellReference(hyperlink.getFirstRow(), hyperlink.getFirstColumn()));
    }
}
