package org.apache.poi.xssf.usermodel;

import b.b.a.a.a;
import java.util.HashSet;
import java.util.Iterator;
import java.util.TreeMap;
import org.apache.poi.ss.SpreadsheetVersion;
import org.apache.poi.ss.formula.FormulaShifter;
import org.apache.poi.ss.usermodel.Cell;
import org.apache.poi.ss.usermodel.CellCopyPolicy;
import org.apache.poi.ss.usermodel.CellStyle;
import org.apache.poi.ss.usermodel.CellType;
import org.apache.poi.ss.usermodel.Row;
import org.apache.poi.ss.util.CellRangeAddress;
import org.apache.poi.ss.util.CellReference;
import org.apache.poi.util.Internal;
import org.apache.poi.xssf.model.CalculationChain;
import org.apache.poi.xssf.model.StylesTable;
import org.apache.poi.xssf.usermodel.helpers.XSSFRowShifter;
import org.openxmlformats.schemas.spreadsheetml.x2006.main.CTCell;
import org.openxmlformats.schemas.spreadsheetml.x2006.main.CTRow;

public class XSSFRow implements Row, Comparable<XSSFRow> {
    public final TreeMap<Integer, XSSFCell> _cells = new TreeMap<>();
    public final CTRow _row;
    public final XSSFSheet _sheet;

    /* renamed from: org.apache.poi.xssf.usermodel.XSSFRow$1  reason: invalid class name */
    public static /* synthetic */ class AnonymousClass1 {
        public static final /* synthetic */ int[] $SwitchMap$org$apache$poi$ss$usermodel$Row$MissingCellPolicy;

        /* JADX WARNING: Can't wrap try/catch for region: R(8:0|(2:1|2)|3|5|6|7|8|10) */
        /* JADX WARNING: Code restructure failed: missing block: B:11:?, code lost:
            return;
         */
        /* JADX WARNING: Failed to process nested try/catch */
        /* JADX WARNING: Missing exception handler attribute for start block: B:7:0x0016 */
        static {
            int[] iArr = new int[Row.MissingCellPolicy.values().length];
            $SwitchMap$org$apache$poi$ss$usermodel$Row$MissingCellPolicy = iArr;
            try {
                Row.MissingCellPolicy missingCellPolicy = Row.MissingCellPolicy.RETURN_NULL_AND_BLANK;
                iArr[0] = 1;
            } catch (NoSuchFieldError unused) {
            }
            int[] iArr2 = $SwitchMap$org$apache$poi$ss$usermodel$Row$MissingCellPolicy;
            Row.MissingCellPolicy missingCellPolicy2 = Row.MissingCellPolicy.RETURN_BLANK_AS_NULL;
            iArr2[1] = 2;
            int[] iArr3 = $SwitchMap$org$apache$poi$ss$usermodel$Row$MissingCellPolicy;
            Row.MissingCellPolicy missingCellPolicy3 = Row.MissingCellPolicy.CREATE_NULL_AS_BLANK;
            iArr3[2] = 3;
        }
    }

    public XSSFRow(CTRow cTRow, XSSFSheet xSSFSheet) {
        this._row = cTRow;
        this._sheet = xSSFSheet;
        for (CTCell cTCell : cTRow.getCArray()) {
            XSSFCell xSSFCell = new XSSFCell(this, cTCell);
            this._cells.put(new Integer(xSSFCell.getColumnIndex()), xSSFCell);
            xSSFSheet.onReadCell(xSSFCell);
        }
        if (!cTRow.isSetR()) {
            int lastRowNum = xSSFSheet.getLastRowNum() + 2;
            if (lastRowNum == 2 && xSSFSheet.getPhysicalNumberOfRows() == 0) {
                lastRowNum = 1;
            }
            cTRow.setR((long) lastRowNum);
        }
    }

    @Override // org.apache.poi.ss.usermodel.Row
    public Iterator<Cell> cellIterator() {
        return this._cells.values().iterator();
    }

    public void copyRowFrom(Row row, CellCopyPolicy cellCopyPolicy) {
        if (row == null) {
            Iterator<Cell> it = iterator();
            while (it.hasNext()) {
                ((XSSFCell) it.next()).copyCellFrom(null, cellCopyPolicy);
            }
            if (cellCopyPolicy.isCopyMergedRegions()) {
                int rowNum = getRowNum();
                int i2 = 0;
                HashSet hashSet = new HashSet();
                for (CellRangeAddress cellRangeAddress : getSheet().getMergedRegions()) {
                    if (rowNum == cellRangeAddress.getFirstRow() && rowNum == cellRangeAddress.getLastRow()) {
                        hashSet.add(Integer.valueOf(i2));
                    }
                    i2++;
                }
                getSheet().removeMergedRegions(hashSet);
            }
            if (cellCopyPolicy.isCopyRowHeight()) {
                setHeight(-1);
                return;
            }
            return;
        }
        Iterator it2 = row.iterator();
        while (it2.hasNext()) {
            XSSFCell xSSFCell = (XSSFCell) ((Cell) it2.next());
            createCell(xSSFCell.getColumnIndex(), xSSFCell.getCellTypeEnum()).copyCellFrom(xSSFCell, cellCopyPolicy);
        }
        XSSFRowShifter xSSFRowShifter = new XSSFRowShifter(this._sheet);
        int sheetIndex = this._sheet.getWorkbook().getSheetIndex(this._sheet);
        String sheetName = this._sheet.getWorkbook().getSheetName(sheetIndex);
        int rowNum2 = row.getRowNum();
        int rowNum3 = getRowNum();
        xSSFRowShifter.updateRowFormulas(this, FormulaShifter.createForRowCopy(sheetIndex, sheetName, rowNum2, rowNum2, rowNum3 - rowNum2, SpreadsheetVersion.EXCEL2007));
        if (cellCopyPolicy.isCopyMergedRegions()) {
            for (CellRangeAddress cellRangeAddress2 : row.getSheet().getMergedRegions()) {
                if (rowNum2 == cellRangeAddress2.getFirstRow() && rowNum2 == cellRangeAddress2.getLastRow()) {
                    CellRangeAddress copy = cellRangeAddress2.copy();
                    copy.setFirstRow(rowNum3);
                    copy.setLastRow(rowNum3);
                    getSheet().addMergedRegion(copy);
                }
            }
        }
        if (cellCopyPolicy.isCopyRowHeight()) {
            setHeight(row.getHeight());
        }
    }

    public boolean equals(Object obj) {
        if (!(obj instanceof XSSFRow)) {
            return false;
        }
        XSSFRow xSSFRow = (XSSFRow) obj;
        if (getRowNum() == xSSFRow.getRowNum() && getSheet() == xSSFRow.getSheet()) {
            return true;
        }
        return false;
    }

    @Internal
    public CTRow getCTRow() {
        return this._row;
    }

    @Override // org.apache.poi.ss.usermodel.Row
    public short getFirstCellNum() {
        return (short) (this._cells.size() == 0 ? -1 : this._cells.firstKey().intValue());
    }

    @Override // org.apache.poi.ss.usermodel.Row
    public short getHeight() {
        return (short) ((int) (getHeightInPoints() * 20.0f));
    }

    @Override // org.apache.poi.ss.usermodel.Row
    public float getHeightInPoints() {
        if (this._row.isSetHt()) {
            return (float) this._row.getHt();
        }
        return this._sheet.getDefaultRowHeightInPoints();
    }

    @Override // org.apache.poi.ss.usermodel.Row
    public short getLastCellNum() {
        return (short) (this._cells.size() == 0 ? -1 : this._cells.lastKey().intValue() + 1);
    }

    @Override // org.apache.poi.ss.usermodel.Row
    public int getOutlineLevel() {
        return this._row.getOutlineLevel();
    }

    @Override // org.apache.poi.ss.usermodel.Row
    public int getPhysicalNumberOfCells() {
        return this._cells.size();
    }

    @Override // org.apache.poi.ss.usermodel.Row
    public int getRowNum() {
        return (int) (this._row.getR() - 1);
    }

    @Override // org.apache.poi.ss.usermodel.Row
    public boolean getZeroHeight() {
        return this._row.getHidden();
    }

    public int hashCode() {
        return this._row.hashCode();
    }

    @Override // org.apache.poi.ss.usermodel.Row
    public boolean isFormatted() {
        return this._row.isSetS();
    }

    @Override // java.lang.Iterable
    public Iterator<Cell> iterator() {
        return cellIterator();
    }

    public void onDocumentWrite() {
        boolean z;
        CTCell[] cArray = this._row.getCArray();
        int i2 = 0;
        if (cArray.length == this._cells.size()) {
            Iterator<XSSFCell> it = this._cells.values().iterator();
            int i3 = 0;
            while (true) {
                if (!it.hasNext()) {
                    z = true;
                    break;
                }
                CTCell cTCell = it.next().getCTCell();
                int i4 = i3 + 1;
                CTCell cTCell2 = cArray[i3];
                String r = cTCell.getR();
                String r2 = cTCell2.getR();
                if (r == null) {
                    if (r2 != null) {
                        break;
                    }
                } else if (!r.equals(r2)) {
                    break;
                }
                i3 = i4;
            }
        }
        z = false;
        if (!z) {
            CTCell[] cTCellArr = new CTCell[this._cells.size()];
            for (XSSFCell xSSFCell : this._cells.values()) {
                cTCellArr[i2] = (CTCell) xSSFCell.getCTCell().copy();
                xSSFCell.setCTCell(cTCellArr[i2]);
                i2++;
            }
            this._row.setCArray(cTCellArr);
        }
    }

    @Override // org.apache.poi.ss.usermodel.Row
    public void removeCell(Cell cell) {
        if (cell.getRow() == this) {
            XSSFCell xSSFCell = (XSSFCell) cell;
            if (xSSFCell.isPartOfArrayFormulaGroup()) {
                xSSFCell.notifyArrayFormulaChanging();
            }
            if (cell.getCellTypeEnum() == CellType.FORMULA) {
                this._sheet.getWorkbook().onDeleteFormula(xSSFCell);
            }
            this._cells.remove(new Integer(cell.getColumnIndex()));
            return;
        }
        throw new IllegalArgumentException("Specified cell does not belong to this row");
    }

    @Override // org.apache.poi.ss.usermodel.Row
    public void setHeight(short s) {
        if (s == -1) {
            if (this._row.isSetHt()) {
                this._row.unsetHt();
            }
            if (this._row.isSetCustomHeight()) {
                this._row.unsetCustomHeight();
                return;
            }
            return;
        }
        this._row.setHt(((double) s) / 20.0d);
        this._row.setCustomHeight(true);
    }

    @Override // org.apache.poi.ss.usermodel.Row
    public void setHeightInPoints(float f2) {
        float f3 = -1.0f;
        if (f2 != -1.0f) {
            f3 = 20.0f * f2;
        }
        setHeight((short) ((int) f3));
    }

    @Override // org.apache.poi.ss.usermodel.Row
    public void setRowNum(int i2) {
        int lastRowIndex = SpreadsheetVersion.EXCEL2007.getLastRowIndex();
        if (i2 < 0 || i2 > lastRowIndex) {
            throw new IllegalArgumentException(a.b("Invalid row number (", i2, ") outside allowable range (0..", lastRowIndex, ")"));
        }
        this._row.setR((long) (i2 + 1));
    }

    @Override // org.apache.poi.ss.usermodel.Row
    public void setRowStyle(CellStyle cellStyle) {
        if (cellStyle != null) {
            StylesTable stylesSource = getSheet().getWorkbook().getStylesSource();
            XSSFCellStyle xSSFCellStyle = (XSSFCellStyle) cellStyle;
            xSSFCellStyle.verifyBelongsToStylesSource(stylesSource);
            this._row.setS((long) stylesSource.putStyle(xSSFCellStyle));
            this._row.setCustomFormat(true);
        } else if (this._row.isSetS()) {
            this._row.unsetS();
            this._row.unsetCustomFormat();
        }
    }

    @Override // org.apache.poi.ss.usermodel.Row
    public void setZeroHeight(boolean z) {
        this._row.setHidden(z);
    }

    public void shift(int i2) {
        int rowNum = getRowNum() + i2;
        CalculationChain calculationChain = this._sheet.getWorkbook().getCalculationChain();
        int sheetId = (int) this._sheet.sheet.getSheetId();
        StringBuilder b2 = a.b("Row[rownum=");
        b2.append(getRowNum());
        b2.append("] contains cell(s) included in a multi-cell array formula. ");
        b2.append("You cannot change part of an array.");
        String sb = b2.toString();
        Iterator<Cell> it = iterator();
        while (it.hasNext()) {
            XSSFCell xSSFCell = (XSSFCell) it.next();
            if (xSSFCell.isPartOfArrayFormulaGroup()) {
                xSSFCell.notifyArrayFormulaChanging(sb);
            }
            if (calculationChain != null) {
                calculationChain.removeItem(sheetId, xSSFCell.getReference());
            }
            xSSFCell.getCTCell().setR(new CellReference(rowNum, xSSFCell.getColumnIndex()).formatAsString());
        }
        setRowNum(rowNum);
    }

    public String toString() {
        return this._row.toString();
    }

    public int compareTo(XSSFRow xSSFRow) {
        if (getSheet() == xSSFRow.getSheet()) {
            return Integer.valueOf(getRowNum()).compareTo(Integer.valueOf(xSSFRow.getRowNum()));
        }
        throw new IllegalArgumentException("The compared rows must belong to the same sheet");
    }

    @Override // org.apache.poi.ss.usermodel.Row
    public XSSFCellStyle getRowStyle() {
        if (!isFormatted()) {
            return null;
        }
        StylesTable stylesSource = getSheet().getWorkbook().getStylesSource();
        if (stylesSource.getNumCellStyles() > 0) {
            return stylesSource.getStyleAt((int) this._row.getS());
        }
        return null;
    }

    @Override // org.apache.poi.ss.usermodel.Row
    public XSSFSheet getSheet() {
        return this._sheet;
    }

    @Override // org.apache.poi.ss.usermodel.Row
    public XSSFCell getCell(int i2) {
        return getCell(i2, this._sheet.getWorkbook().getMissingCellPolicy());
    }

    @Override // org.apache.poi.ss.usermodel.Row
    public XSSFCell createCell(int i2) {
        return createCell(i2, CellType.BLANK);
    }

    @Override // org.apache.poi.ss.usermodel.Row
    public XSSFCell getCell(int i2, Row.MissingCellPolicy missingCellPolicy) {
        if (i2 >= 0) {
            XSSFCell xSSFCell = this._cells.get(new Integer(i2));
            int ordinal = missingCellPolicy.ordinal();
            if (ordinal == 0) {
                return xSSFCell;
            }
            boolean z = true;
            if (ordinal == 1) {
                if (xSSFCell == null || xSSFCell.getCellTypeEnum() != CellType.BLANK) {
                    z = false;
                }
                if (z) {
                    return null;
                }
                return xSSFCell;
            } else if (ordinal == 2) {
                return xSSFCell == null ? createCell(i2, CellType.BLANK) : xSSFCell;
            } else {
                StringBuilder sb = new StringBuilder();
                sb.append("Illegal policy ");
                sb.append(missingCellPolicy);
                sb.append(" (");
                throw new IllegalArgumentException(a.a(sb, missingCellPolicy.id, ")"));
            }
        } else {
            throw new IllegalArgumentException("Cell index must be >= 0");
        }
    }

    @Override // org.apache.poi.ss.usermodel.Row
    public XSSFCell createCell(int i2, int i3) {
        return createCell(i2, CellType.forInt(i3));
    }

    @Override // org.apache.poi.ss.usermodel.Row
    public XSSFCell createCell(int i2, CellType cellType) {
        CTCell cTCell;
        Integer num = new Integer(i2);
        XSSFCell xSSFCell = this._cells.get(num);
        if (xSSFCell != null) {
            cTCell = xSSFCell.getCTCell();
            cTCell.set(CTCell.Factory.newInstance());
        } else {
            cTCell = this._row.addNewC();
        }
        XSSFCell xSSFCell2 = new XSSFCell(this, cTCell);
        xSSFCell2.setCellNum(i2);
        if (cellType != CellType.BLANK) {
            xSSFCell2.setCellType(cellType);
        }
        this._cells.put(num, xSSFCell2);
        return xSSFCell2;
    }
}
