package org.apache.poi.xssf.usermodel.extensions;

import org.apache.poi.ss.usermodel.BorderStyle;
import org.apache.poi.util.Internal;
import org.apache.poi.xssf.model.ThemesTable;
import org.apache.poi.xssf.usermodel.IndexedColorMap;
import org.apache.poi.xssf.usermodel.XSSFColor;
import org.openxmlformats.schemas.spreadsheetml.x2006.main.CTBorder;
import org.openxmlformats.schemas.spreadsheetml.x2006.main.CTBorderPr;
import org.openxmlformats.schemas.spreadsheetml.x2006.main.STBorderStyle;

public class XSSFCellBorder {
    public IndexedColorMap _indexedColorMap;
    public ThemesTable _theme;
    public CTBorder border;

    /* renamed from: org.apache.poi.xssf.usermodel.extensions.XSSFCellBorder$1  reason: invalid class name */
    public static /* synthetic */ class AnonymousClass1 {
        public static final /* synthetic */ int[] $SwitchMap$org$apache$poi$xssf$usermodel$extensions$XSSFCellBorder$BorderSide;

        /* JADX WARNING: Failed to process nested try/catch */
        /* JADX WARNING: Missing exception handler attribute for start block: B:11:0x001d */
        static {
            int[] iArr = new int[BorderSide.values().length];
            $SwitchMap$org$apache$poi$xssf$usermodel$extensions$XSSFCellBorder$BorderSide = iArr;
            try {
                BorderSide borderSide = BorderSide.TOP;
                iArr[0] = 1;
            } catch (NoSuchFieldError unused) {
            }
            try {
                int[] iArr2 = $SwitchMap$org$apache$poi$xssf$usermodel$extensions$XSSFCellBorder$BorderSide;
                BorderSide borderSide2 = BorderSide.RIGHT;
                iArr2[1] = 2;
            } catch (NoSuchFieldError unused2) {
            }
            int[] iArr3 = $SwitchMap$org$apache$poi$xssf$usermodel$extensions$XSSFCellBorder$BorderSide;
            BorderSide borderSide3 = BorderSide.BOTTOM;
            iArr3[2] = 3;
            try {
                int[] iArr4 = $SwitchMap$org$apache$poi$xssf$usermodel$extensions$XSSFCellBorder$BorderSide;
                BorderSide borderSide4 = BorderSide.LEFT;
                iArr4[3] = 4;
            } catch (NoSuchFieldError unused3) {
            }
        }
    }

    public enum BorderSide {
        TOP,
        RIGHT,
        BOTTOM,
        LEFT
    }

    public XSSFCellBorder(CTBorder cTBorder, ThemesTable themesTable, IndexedColorMap indexedColorMap) {
        this(cTBorder, indexedColorMap);
        this._theme = themesTable;
    }

    private CTBorderPr getBorder(BorderSide borderSide) {
        return getBorder(borderSide, false);
    }

    public boolean equals(Object obj) {
        if (!(obj instanceof XSSFCellBorder)) {
            return false;
        }
        return this.border.toString().equals(((XSSFCellBorder) obj).getCTBorder().toString());
    }

    public XSSFColor getBorderColor(BorderSide borderSide) {
        CTBorderPr border2 = getBorder(borderSide);
        if (border2 == null || !border2.isSetColor()) {
            return null;
        }
        XSSFColor xSSFColor = new XSSFColor(border2.getColor(), this._indexedColorMap);
        ThemesTable themesTable = this._theme;
        if (themesTable != null) {
            themesTable.inheritFromThemeAsRequired(xSSFColor);
        }
        return xSSFColor;
    }

    public BorderStyle getBorderStyle(BorderSide borderSide) {
        CTBorderPr border2 = getBorder(borderSide);
        return BorderStyle.values()[(border2 == null ? STBorderStyle.NONE : border2.getStyle()).intValue() - 1];
    }

    @Internal
    public CTBorder getCTBorder() {
        return this.border;
    }

    public int hashCode() {
        return this.border.toString().hashCode();
    }

    public void setBorderColor(BorderSide borderSide, XSSFColor xSSFColor) {
        CTBorderPr border2 = getBorder(borderSide, true);
        if (xSSFColor == null) {
            border2.unsetColor();
        } else {
            border2.setColor(xSSFColor.getCTColor());
        }
    }

    public void setBorderStyle(BorderSide borderSide, BorderStyle borderStyle) {
        getBorder(borderSide, true).setStyle(STBorderStyle.Enum.forInt(borderStyle.ordinal() + 1));
    }

    public void setThemesTable(ThemesTable themesTable) {
        this._theme = themesTable;
    }

    private CTBorderPr getBorder(BorderSide borderSide, boolean z) {
        int ordinal = borderSide.ordinal();
        if (ordinal == 0) {
            CTBorderPr top = this.border.getTop();
            return (!z || top != null) ? top : this.border.addNewTop();
        } else if (ordinal == 1) {
            CTBorderPr right = this.border.getRight();
            if (!z || right != null) {
                return right;
            }
            return this.border.addNewRight();
        } else if (ordinal == 2) {
            CTBorderPr bottom = this.border.getBottom();
            if (!z || bottom != null) {
                return bottom;
            }
            return this.border.addNewBottom();
        } else if (ordinal == 3) {
            CTBorderPr left = this.border.getLeft();
            if (!z || left != null) {
                return left;
            }
            return this.border.addNewLeft();
        } else {
            throw new IllegalArgumentException("No suitable side specified for the border");
        }
    }

    public XSSFCellBorder(CTBorder cTBorder) {
        this(cTBorder, null);
    }

    public XSSFCellBorder(CTBorder cTBorder, IndexedColorMap indexedColorMap) {
        this.border = cTBorder;
        this._indexedColorMap = indexedColorMap;
    }

    public XSSFCellBorder() {
        this.border = CTBorder.Factory.newInstance();
    }
}
