package org.apache.xerces.dom;

import java.io.ObjectInputStream;
import java.io.ObjectOutputStream;
import java.lang.reflect.Constructor;
import java.util.Enumeration;
import java.util.HashMap;
import java.util.Hashtable;
import java.util.Map;
import java.util.WeakHashMap;
import org.apache.xerces.dom.ParentNode;
import org.apache.xerces.util.URI;
import org.apache.xerces.util.XML11Char;
import org.apache.xerces.util.XMLChar;
import org.apache.xerces.xni.NamespaceContext;
import org.w3c.dom.Attr;
import org.w3c.dom.CDATASection;
import org.w3c.dom.Comment;
import org.w3c.dom.DOMConfiguration;
import org.w3c.dom.DOMException;
import org.w3c.dom.DOMImplementation;
import org.w3c.dom.Document;
import org.w3c.dom.DocumentFragment;
import org.w3c.dom.DocumentType;
import org.w3c.dom.Element;
import org.w3c.dom.Entity;
import org.w3c.dom.EntityReference;
import org.w3c.dom.NamedNodeMap;
import org.w3c.dom.Node;
import org.w3c.dom.NodeList;
import org.w3c.dom.Notation;
import org.w3c.dom.ProcessingInstruction;
import org.w3c.dom.Text;
import org.w3c.dom.UserDataHandler;
import org.w3c.dom.events.Event;
import org.w3c.dom.events.EventListener;
import org.w3c.dom.ls.DOMImplementationLS;
import org.w3c.dom.ls.LSSerializer;

public class CoreDocumentImpl extends ParentNode implements Document {
    public static /* synthetic */ Class class$org$w3c$dom$Document;
    public static final int[] kidOK;
    public static final long serialVersionUID = 0;
    public String actualEncoding;
    public boolean allowGrammarAccess;
    public int changes;
    public ElementImpl docElement;
    public DocumentTypeImpl docType;
    public int documentNumber;
    public transient DOMNormalizer domNormalizer;
    public String encoding;
    public boolean errorChecking;
    public transient DOMConfigurationImpl fConfiguration;
    public String fDocumentURI;
    public transient NodeListCache fFreeNLCache;
    public transient Object fXPathEvaluator;
    public Hashtable identifiers;
    public int nodeCounter;
    public Map nodeTable;
    public boolean standalone;
    public Map userData;
    public String version;
    public boolean xml11Version;
    public boolean xmlVersionChanged;

    static {
        int[] iArr = new int[13];
        kidOK = iArr;
        iArr[9] = 1410;
        iArr[1] = 442;
        iArr[5] = 442;
        iArr[6] = 442;
        iArr[11] = 442;
        iArr[2] = 40;
        iArr[12] = 0;
        iArr[4] = 0;
        iArr[3] = 0;
        iArr[8] = 0;
        iArr[7] = 0;
        iArr[10] = 0;
    }

    public CoreDocumentImpl() {
        this(false);
    }

    public CoreDocumentImpl(DocumentType documentType) {
        this(documentType, false);
    }

    public CoreDocumentImpl(DocumentType documentType, boolean z) {
        this(z);
        if (documentType != null) {
            try {
                ((DocumentTypeImpl) documentType).ownerDocument = this;
                appendChild(documentType);
            } catch (ClassCastException unused) {
                throw new DOMException(4, DOMMessageFormatter.formatMessage(DOMMessageFormatter.DOM_DOMAIN, "WRONG_DOCUMENT_ERR", null));
            }
        }
    }

    public CoreDocumentImpl(boolean z) {
        super(null);
        this.domNormalizer = null;
        this.fConfiguration = null;
        this.fXPathEvaluator = null;
        this.changes = 0;
        this.errorChecking = true;
        this.xmlVersionChanged = false;
        this.documentNumber = 0;
        this.nodeCounter = 0;
        this.xml11Version = false;
        this.ownerDocument = this;
        this.allowGrammarAccess = z;
    }

    public static /* synthetic */ Class class$(String str) {
        try {
            return Class.forName(str);
        } catch (ClassNotFoundException e2) {
            throw new NoClassDefFoundError(e2.getMessage());
        }
    }

    /* JADX DEBUG: Failed to insert an additional move for type inference into block B:66:0x01c7 */
    /* JADX WARN: Multi-variable type inference failed */
    /* JADX WARN: Type inference failed for: r10v0, types: [org.apache.xerces.dom.CoreDocumentImpl] */
    /* JADX WARN: Type inference failed for: r2v1, types: [org.w3c.dom.Node] */
    /* JADX WARN: Type inference failed for: r2v2, types: [org.w3c.dom.Element, java.lang.Object] */
    /* JADX WARN: Type inference failed for: r2v8, types: [org.w3c.dom.Node] */
    /* JADX WARN: Type inference failed for: r2v9, types: [org.w3c.dom.Text] */
    /* JADX WARN: Type inference failed for: r2v10, types: [org.w3c.dom.CDATASection] */
    /* JADX WARN: Type inference failed for: r2v11 */
    /* JADX WARN: Type inference failed for: r2v15, types: [org.apache.xerces.dom.NodeImpl, org.apache.xerces.dom.EntityImpl] */
    /* JADX WARN: Type inference failed for: r2v17, types: [org.w3c.dom.ProcessingInstruction] */
    /* JADX WARN: Type inference failed for: r2v18, types: [org.w3c.dom.Comment] */
    /* JADX WARN: Type inference failed for: r2v21, types: [org.apache.xerces.dom.DocumentTypeImpl] */
    /* JADX WARN: Type inference failed for: r2v22, types: [org.w3c.dom.DocumentFragment] */
    /* JADX WARN: Type inference failed for: r2v25, types: [org.apache.xerces.dom.NotationImpl] */
    /* JADX WARN: Type inference failed for: r2v26 */
    /* JADX WARN: Type inference failed for: r2v27 */
    /* JADX WARN: Type inference failed for: r2v28 */
    /* JADX WARN: Type inference failed for: r2v29 */
    /* JADX WARN: Type inference failed for: r2v30 */
    /* JADX WARNING: Unknown variable types count: 1 */
    private Node importNode(Node node, boolean z, boolean z2, HashMap hashMap) {
        ?? r2;
        Object obj;
        Hashtable userDataRecord = node instanceof NodeImpl ? ((NodeImpl) node).getUserDataRecord() : null;
        int i2 = 0;
        switch (node.getNodeType()) {
            case 1:
                boolean hasFeature = node.getOwnerDocument().getImplementation().hasFeature("XML", "2.0");
                r2 = (!hasFeature || node.getLocalName() == null) ? createElement(node.getNodeName()) : createElementNS(node.getNamespaceURI(), node.getNodeName());
                NamedNodeMap attributes = node.getAttributes();
                if (attributes != null) {
                    int length = attributes.getLength();
                    while (i2 < length) {
                        Attr attr = (Attr) attributes.item(i2);
                        if (attr.getSpecified() || z2) {
                            Attr attr2 = (Attr) importNode(attr, true, z2, hashMap);
                            if (!hasFeature || attr.getLocalName() == null) {
                                r2.setAttributeNode(attr2);
                            } else {
                                r2.setAttributeNodeNS(attr2);
                            }
                        }
                        i2++;
                    }
                }
                if (!(hashMap == null || (obj = hashMap.get(node)) == null)) {
                    if (this.identifiers == null) {
                        this.identifiers = new Hashtable();
                    }
                    this.identifiers.put(obj, r2);
                    break;
                }
                break;
            case 2:
                r2 = (!node.getOwnerDocument().getImplementation().hasFeature("XML", "2.0") || node.getLocalName() == null) ? createAttribute(node.getNodeName()) : createAttributeNS(node.getNamespaceURI(), node.getNodeName());
                if (node instanceof AttrImpl) {
                    AttrImpl attrImpl = (AttrImpl) node;
                    if (attrImpl.hasStringValue()) {
                        ((AttrImpl) r2).setValue(attrImpl.getValue());
                        r2 = r2;
                        z = false;
                        break;
                    }
                } else if (node.getFirstChild() == null) {
                    r2.setNodeValue(node.getNodeValue());
                    r2 = r2;
                    z = false;
                }
                z = true;
                break;
            case 3:
                r2 = createTextNode(node.getNodeValue());
                break;
            case 4:
                r2 = createCDATASection(node.getNodeValue());
                break;
            case 5:
                r2 = createEntityReference(node.getNodeName());
                z = false;
                break;
            case 6:
                Entity entity = (Entity) node;
                r2 = (EntityImpl) createEntity(node.getNodeName());
                r2.setPublicId(entity.getPublicId());
                r2.setSystemId(entity.getSystemId());
                r2.setNotationName(entity.getNotationName());
                r2.isReadOnly(false);
                break;
            case 7:
                r2 = createProcessingInstruction(node.getNodeName(), node.getNodeValue());
                break;
            case 8:
                r2 = createComment(node.getNodeValue());
                break;
            case 9:
            default:
                throw new DOMException(9, DOMMessageFormatter.formatMessage(DOMMessageFormatter.DOM_DOMAIN, "NOT_SUPPORTED_ERR", null));
            case 10:
                if (z2) {
                    DocumentType documentType = (DocumentType) node;
                    r2 = (DocumentTypeImpl) createDocumentType(documentType.getNodeName(), documentType.getPublicId(), documentType.getSystemId());
                    r2.setInternalSubset(documentType.getInternalSubset());
                    NamedNodeMap entities = documentType.getEntities();
                    NamedNodeMap entities2 = r2.getEntities();
                    if (entities != null) {
                        for (int i3 = 0; i3 < entities.getLength(); i3++) {
                            entities2.setNamedItem(importNode(entities.item(i3), true, true, hashMap));
                        }
                    }
                    NamedNodeMap notations = documentType.getNotations();
                    NamedNodeMap notations2 = r2.getNotations();
                    if (notations != null) {
                        while (i2 < notations.getLength()) {
                            notations2.setNamedItem(importNode(notations.item(i2), true, true, hashMap));
                            i2++;
                        }
                        break;
                    }
                } else {
                    throw new DOMException(9, DOMMessageFormatter.formatMessage(DOMMessageFormatter.DOM_DOMAIN, "NOT_SUPPORTED_ERR", null));
                }
                break;
            case 11:
                r2 = createDocumentFragment();
                break;
            case 12:
                Notation notation = (Notation) node;
                r2 = (NotationImpl) createNotation(node.getNodeName());
                r2.setPublicId(notation.getPublicId());
                r2.setSystemId(notation.getSystemId());
                break;
        }
        if (userDataRecord != null) {
            callUserDataHandlers(node, r2, 2, userDataRecord);
        }
        if (z) {
            for (Node firstChild = node.getFirstChild(); firstChild != null; firstChild = firstChild.getNextSibling()) {
                r2.appendChild(importNode(firstChild, true, z2, hashMap));
            }
        }
        if (r2.getNodeType() == 6) {
            ((NodeImpl) r2).setReadOnly(true, true);
        }
        return r2;
    }

    /* JADX WARNING: Removed duplicated region for block: B:10:0x0015 A[RETURN, SYNTHETIC] */
    public static final boolean isValidQName(String str, String str2, boolean z) {
        if (str2 == null) {
            return false;
        }
        if (!z) {
            return (str == null || XMLChar.isValidNCName(str)) && XMLChar.isValidNCName(str2);
        }
        if ((str != null && !XML11Char.isXML11ValidNCName(str)) || !XML11Char.isXML11ValidNCName(str2)) {
            return false;
        }
    }

    public static final boolean isXMLName(String str, boolean z) {
        if (str == null) {
            return false;
        }
        return !z ? XMLChar.isValidName(str) : XML11Char.isXML11ValidName(str);
    }

    private void readObject(ObjectInputStream objectInputStream) {
        objectInputStream.defaultReadObject();
        if (this.userData != null) {
            this.userData = new WeakHashMap(this.userData);
        }
        if (this.nodeTable != null) {
            this.nodeTable = new WeakHashMap(this.nodeTable);
        }
    }

    private ElementImpl replaceRenameElement(ElementImpl elementImpl, String str, String str2) {
        ElementNSImpl elementNSImpl = (ElementNSImpl) createElementNS(str, str2);
        copyEventListeners(elementImpl, elementNSImpl);
        Hashtable removeUserDataTable = removeUserDataTable(elementImpl);
        Node parentNode = elementImpl.getParentNode();
        Node nextSibling = elementImpl.getNextSibling();
        if (parentNode != null) {
            parentNode.removeChild(elementImpl);
        }
        while (true) {
            Node firstChild = elementImpl.getFirstChild();
            if (firstChild == null) {
                break;
            }
            elementImpl.removeChild(firstChild);
            elementNSImpl.appendChild(firstChild);
        }
        elementNSImpl.moveSpecifiedAttributes(elementImpl);
        setUserDataTable(elementNSImpl, removeUserDataTable);
        callUserDataHandlers(elementImpl, elementNSImpl, 4);
        if (parentNode != null) {
            parentNode.insertBefore(elementNSImpl, nextSibling);
        }
        return elementNSImpl;
    }

    private void writeObject(ObjectOutputStream objectOutputStream) {
        Map map = this.userData;
        Map map2 = this.nodeTable;
        if (map != null) {
            try {
                this.userData = new Hashtable(map);
            } catch (Throwable th) {
                this.userData = map;
                this.nodeTable = map2;
                throw th;
            }
        }
        if (map2 != null) {
            this.nodeTable = new Hashtable(map2);
        }
        objectOutputStream.defaultWriteObject();
        this.userData = map;
        this.nodeTable = map2;
    }

    public void abort() {
    }

    public void addEventListener(NodeImpl nodeImpl, String str, EventListener eventListener, boolean z) {
    }

    /* JADX WARNING: Code restructure failed: missing block: B:19:0x0030, code lost:
        if ((r3 instanceof org.apache.xerces.dom.DeferredDOMImplementationImpl) != false) goto L_0x0032;
     */
    @Override // org.w3c.dom.Document
    public Node adoptNode(Node node) {
        Hashtable hashtable;
        Node namedItem;
        try {
            NodeImpl nodeImpl = (NodeImpl) node;
            if (node == null) {
                return null;
            }
            if (node.getOwnerDocument() != null) {
                DOMImplementation implementation = getImplementation();
                DOMImplementation implementation2 = node.getOwnerDocument().getImplementation();
                if (implementation != implementation2) {
                    if (!(implementation instanceof DOMImplementationImpl) || !(implementation2 instanceof DeferredDOMImplementationImpl)) {
                        if (!(implementation instanceof DeferredDOMImplementationImpl) || !(implementation2 instanceof DOMImplementationImpl)) {
                            return null;
                        }
                    }
                }
                undeferChildren(nodeImpl);
            }
            short nodeType = nodeImpl.getNodeType();
            if (nodeType == 1) {
                hashtable = nodeImpl.getUserDataRecord();
                Node parentNode = nodeImpl.getParentNode();
                if (parentNode != null) {
                    parentNode.removeChild(node);
                }
                nodeImpl.setOwnerDocument(this);
                if (hashtable != null) {
                    setUserDataTable(nodeImpl, hashtable);
                }
                ((ElementImpl) nodeImpl).reconcileDefaultAttributes();
            } else if (nodeType == 2) {
                AttrImpl attrImpl = (AttrImpl) nodeImpl;
                if (attrImpl.getOwnerElement() != null) {
                    attrImpl.getOwnerElement().removeAttributeNode(attrImpl);
                }
                attrImpl.isSpecified(true);
                Hashtable userDataRecord = nodeImpl.getUserDataRecord();
                attrImpl.setOwnerDocument(this);
                if (userDataRecord != null) {
                    setUserDataTable(nodeImpl, userDataRecord);
                }
                hashtable = userDataRecord;
            } else if (nodeType != 5) {
                if (nodeType != 6) {
                    if (nodeType == 9 || nodeType == 10) {
                        throw new DOMException(9, DOMMessageFormatter.formatMessage(DOMMessageFormatter.DOM_DOMAIN, "NOT_SUPPORTED_ERR", null));
                    } else if (nodeType != 12) {
                        hashtable = nodeImpl.getUserDataRecord();
                        Node parentNode2 = nodeImpl.getParentNode();
                        if (parentNode2 != null) {
                            parentNode2.removeChild(node);
                        }
                        nodeImpl.setOwnerDocument(this);
                        if (hashtable != null) {
                            setUserDataTable(nodeImpl, hashtable);
                        }
                    }
                }
                throw new DOMException(7, DOMMessageFormatter.formatMessage(DOMMessageFormatter.DOM_DOMAIN, "NO_MODIFICATION_ALLOWED_ERR", null));
            } else {
                hashtable = nodeImpl.getUserDataRecord();
                Node parentNode3 = nodeImpl.getParentNode();
                if (parentNode3 != null) {
                    parentNode3.removeChild(node);
                }
                while (true) {
                    Node firstChild = nodeImpl.getFirstChild();
                    if (firstChild == null) {
                        break;
                    }
                    nodeImpl.removeChild(firstChild);
                }
                nodeImpl.setOwnerDocument(this);
                if (hashtable != null) {
                    setUserDataTable(nodeImpl, hashtable);
                }
                DocumentTypeImpl documentTypeImpl = this.docType;
                if (!(documentTypeImpl == null || (namedItem = documentTypeImpl.getEntities().getNamedItem(nodeImpl.getNodeName())) == null)) {
                    for (Node firstChild2 = namedItem.getFirstChild(); firstChild2 != null; firstChild2 = firstChild2.getNextSibling()) {
                        nodeImpl.appendChild(firstChild2.cloneNode(true));
                    }
                }
            }
            if (hashtable != null) {
                callUserDataHandlers(node, null, 5, hashtable);
            }
            return nodeImpl;
        } catch (ClassCastException unused) {
            return null;
        }
    }

    public void callUserDataHandlers(Node node, Node node2, short s) {
        Hashtable userDataRecord;
        if (this.userData != null && (node instanceof NodeImpl) && (userDataRecord = ((NodeImpl) node).getUserDataRecord()) != null && !userDataRecord.isEmpty()) {
            callUserDataHandlers(node, node2, s, userDataRecord);
        }
    }

    public void callUserDataHandlers(Node node, Node node2, short s, Hashtable hashtable) {
        if (!(hashtable == null || hashtable.isEmpty())) {
            for (Map.Entry entry : hashtable.entrySet()) {
                String str = (String) entry.getKey();
                ParentNode.UserDataRecord userDataRecord = (ParentNode.UserDataRecord) entry.getValue();
                UserDataHandler userDataHandler = userDataRecord.fHandler;
                if (userDataHandler != null) {
                    userDataHandler.handle(s, str, userDataRecord.fData, node, node2);
                }
            }
        }
    }

    public boolean canRenameElements(String str, String str2, ElementImpl elementImpl) {
        return true;
    }

    @Override // org.apache.xerces.dom.NodeImpl
    public void changed() {
        this.changes++;
    }

    @Override // org.apache.xerces.dom.NodeImpl
    public int changes() {
        return this.changes;
    }

    public final void checkDOMNSErr(String str, String str2) {
        if (!this.errorChecking) {
            return;
        }
        if (str2 == null) {
            throw new DOMException(14, DOMMessageFormatter.formatMessage(DOMMessageFormatter.DOM_DOMAIN, "NAMESPACE_ERR", null));
        } else if (str.equals("xml") && !str2.equals(NamespaceContext.XML_URI)) {
            throw new DOMException(14, DOMMessageFormatter.formatMessage(DOMMessageFormatter.DOM_DOMAIN, "NAMESPACE_ERR", null));
        } else if ((str.equals("xmlns") && !str2.equals(NamespaceContext.XMLNS_URI)) || (!str.equals("xmlns") && str2.equals(NamespaceContext.XMLNS_URI))) {
            throw new DOMException(14, DOMMessageFormatter.formatMessage(DOMMessageFormatter.DOM_DOMAIN, "NAMESPACE_ERR", null));
        }
    }

    public final void checkNamespaceWF(String str, int i2, int i3) {
        if (this.errorChecking) {
            if (i2 == 0 || i2 == str.length() - 1 || i3 != i2) {
                throw new DOMException(14, DOMMessageFormatter.formatMessage(DOMMessageFormatter.DOM_DOMAIN, "NAMESPACE_ERR", null));
            }
        }
    }

    public final void checkQName(String str, String str2) {
        if (this.errorChecking) {
            boolean z = true;
            if (this.xml11Version ? !((str == null || XML11Char.isXML11ValidNCName(str)) && XML11Char.isXML11ValidNCName(str2)) : !((str == null || XMLChar.isValidNCName(str)) && XMLChar.isValidNCName(str2))) {
                z = false;
            }
            if (!z) {
                throw new DOMException(5, DOMMessageFormatter.formatMessage(DOMMessageFormatter.DOM_DOMAIN, "INVALID_CHARACTER_ERR", null));
            }
        }
    }

    public final void clearIdentifiers() {
        Hashtable hashtable = this.identifiers;
        if (hashtable != null) {
            hashtable.clear();
        }
    }

    @Override // java.lang.Object
    public Object clone() {
        CoreDocumentImpl coreDocumentImpl = (CoreDocumentImpl) super.clone();
        coreDocumentImpl.docType = null;
        coreDocumentImpl.docElement = null;
        return coreDocumentImpl;
    }

    @Override // org.apache.xerces.dom.NodeImpl, org.w3c.dom.Node, org.apache.xerces.dom.ParentNode, org.apache.xerces.dom.ChildNode
    public Node cloneNode(boolean z) {
        CoreDocumentImpl coreDocumentImpl = new CoreDocumentImpl();
        callUserDataHandlers(this, coreDocumentImpl, 1);
        cloneNode(coreDocumentImpl, z);
        return coreDocumentImpl;
    }

    public void cloneNode(CoreDocumentImpl coreDocumentImpl, boolean z) {
        if (needsSyncChildren()) {
            synchronizeChildren();
        }
        if (z) {
            HashMap hashMap = null;
            if (this.identifiers != null) {
                HashMap hashMap2 = new HashMap();
                for (Map.Entry entry : this.identifiers.entrySet()) {
                    hashMap2.put(entry.getValue(), entry.getKey());
                }
                hashMap = hashMap2;
            }
            for (ChildNode childNode = this.firstChild; childNode != null; childNode = childNode.nextSibling) {
                coreDocumentImpl.appendChild(coreDocumentImpl.importNode(childNode, true, true, hashMap));
            }
        }
        coreDocumentImpl.allowGrammarAccess = this.allowGrammarAccess;
        coreDocumentImpl.errorChecking = this.errorChecking;
    }

    public void copyEventListeners(NodeImpl nodeImpl, NodeImpl nodeImpl2) {
    }

    @Override // org.w3c.dom.Document
    public Attr createAttribute(String str) {
        if (!this.errorChecking || isXMLName(str, this.xml11Version)) {
            return new AttrImpl(this, str);
        }
        throw new DOMException(5, DOMMessageFormatter.formatMessage(DOMMessageFormatter.DOM_DOMAIN, "INVALID_CHARACTER_ERR", null));
    }

    @Override // org.w3c.dom.Document
    public Attr createAttributeNS(String str, String str2) {
        return new AttrNSImpl(this, str, str2);
    }

    public Attr createAttributeNS(String str, String str2, String str3) {
        return new AttrNSImpl(this, str, str2, str3);
    }

    @Override // org.w3c.dom.Document
    public CDATASection createCDATASection(String str) {
        return new CDATASectionImpl(this, str);
    }

    @Override // org.w3c.dom.Document
    public Comment createComment(String str) {
        return new CommentImpl(this, str);
    }

    @Override // org.w3c.dom.Document
    public DocumentFragment createDocumentFragment() {
        return new DocumentFragmentImpl(this);
    }

    public DocumentType createDocumentType(String str, String str2, String str3) {
        return new DocumentTypeImpl(this, str, str2, str3);
    }

    @Override // org.w3c.dom.Document
    public Element createElement(String str) {
        if (!this.errorChecking || isXMLName(str, this.xml11Version)) {
            return new ElementImpl(this, str);
        }
        throw new DOMException(5, DOMMessageFormatter.formatMessage(DOMMessageFormatter.DOM_DOMAIN, "INVALID_CHARACTER_ERR", null));
    }

    public ElementDefinitionImpl createElementDefinition(String str) {
        if (!this.errorChecking || isXMLName(str, this.xml11Version)) {
            return new ElementDefinitionImpl(this, str);
        }
        throw new DOMException(5, DOMMessageFormatter.formatMessage(DOMMessageFormatter.DOM_DOMAIN, "INVALID_CHARACTER_ERR", null));
    }

    @Override // org.w3c.dom.Document
    public Element createElementNS(String str, String str2) {
        return new ElementNSImpl(this, str, str2);
    }

    public Element createElementNS(String str, String str2, String str3) {
        return new ElementNSImpl(this, str, str2, str3);
    }

    public Entity createEntity(String str) {
        if (!this.errorChecking || isXMLName(str, this.xml11Version)) {
            return new EntityImpl(this, str);
        }
        throw new DOMException(5, DOMMessageFormatter.formatMessage(DOMMessageFormatter.DOM_DOMAIN, "INVALID_CHARACTER_ERR", null));
    }

    @Override // org.w3c.dom.Document
    public EntityReference createEntityReference(String str) {
        if (!this.errorChecking || isXMLName(str, this.xml11Version)) {
            return new EntityReferenceImpl(this, str);
        }
        throw new DOMException(5, DOMMessageFormatter.formatMessage(DOMMessageFormatter.DOM_DOMAIN, "INVALID_CHARACTER_ERR", null));
    }

    public Notation createNotation(String str) {
        if (!this.errorChecking || isXMLName(str, this.xml11Version)) {
            return new NotationImpl(this, str);
        }
        throw new DOMException(5, DOMMessageFormatter.formatMessage(DOMMessageFormatter.DOM_DOMAIN, "INVALID_CHARACTER_ERR", null));
    }

    @Override // org.w3c.dom.Document
    public ProcessingInstruction createProcessingInstruction(String str, String str2) {
        if (!this.errorChecking || isXMLName(str, this.xml11Version)) {
            return new ProcessingInstructionImpl(this, str, str2);
        }
        throw new DOMException(5, DOMMessageFormatter.formatMessage(DOMMessageFormatter.DOM_DOMAIN, "INVALID_CHARACTER_ERR", null));
    }

    @Override // org.w3c.dom.Document
    public Text createTextNode(String str) {
        return new TextImpl(this, str);
    }

    public void deletedText(CharacterDataImpl characterDataImpl, int i2, int i3) {
    }

    public boolean dispatchEvent(NodeImpl nodeImpl, Event event) {
        return false;
    }

    public void freeNodeListCache(NodeListCache nodeListCache) {
        nodeListCache.next = this.fFreeNLCache;
        this.fFreeNLCache = nodeListCache;
    }

    public boolean getAsync() {
        return false;
    }

    @Override // org.apache.xerces.dom.NodeImpl, org.w3c.dom.Node
    public String getBaseURI() {
        String str = this.fDocumentURI;
        if (str == null || str.length() == 0) {
            return this.fDocumentURI;
        }
        try {
            return new URI(this.fDocumentURI).toString();
        } catch (URI.MalformedURIException unused) {
            return null;
        }
    }

    @Override // org.w3c.dom.Document
    public DocumentType getDoctype() {
        if (needsSyncChildren()) {
            synchronizeChildren();
        }
        return this.docType;
    }

    @Override // org.w3c.dom.Document
    public Element getDocumentElement() {
        if (needsSyncChildren()) {
            synchronizeChildren();
        }
        return this.docElement;
    }

    @Override // org.w3c.dom.Document
    public String getDocumentURI() {
        return this.fDocumentURI;
    }

    @Override // org.w3c.dom.Document
    public DOMConfiguration getDomConfig() {
        if (this.fConfiguration == null) {
            this.fConfiguration = new DOMConfigurationImpl();
        }
        return this.fConfiguration;
    }

    @Override // org.w3c.dom.Document
    public Element getElementById(String str) {
        return getIdentifier(str);
    }

    @Override // org.w3c.dom.Document
    public NodeList getElementsByTagName(String str) {
        return new DeepNodeListImpl(this, str);
    }

    @Override // org.w3c.dom.Document
    public NodeList getElementsByTagNameNS(String str, String str2) {
        return new DeepNodeListImpl(this, str, str2);
    }

    public String getEncoding() {
        return getXmlEncoding();
    }

    public boolean getErrorChecking() {
        return this.errorChecking;
    }

    @Override // org.apache.xerces.dom.NodeImpl, org.w3c.dom.Node
    public Object getFeature(String str, String str2) {
        Class<?> cls;
        Class<?>[] interfaces;
        boolean z = str2 == null || str2.length() == 0;
        if (!str.equalsIgnoreCase("+XPath") || (!z && !str2.equals("3.0"))) {
            return super.getFeature(str, str2);
        }
        Object obj = this.fXPathEvaluator;
        if (obj != null) {
            return obj;
        }
        try {
            Class findProviderClass = ObjectFactory.findProviderClass("org.apache.xpath.domapi.XPathEvaluatorImpl", ObjectFactory.findClassLoader(), true);
            Class<?>[] clsArr = new Class[1];
            if (class$org$w3c$dom$Document == null) {
                cls = class$("org.w3c.dom.Document");
                class$org$w3c$dom$Document = cls;
            } else {
                cls = class$org$w3c$dom$Document;
            }
            clsArr[0] = cls;
            Constructor constructor = findProviderClass.getConstructor(clsArr);
            for (Class<?> cls2 : findProviderClass.getInterfaces()) {
                if (cls2.getName().equals("org.w3c.dom.xpath.XPathEvaluator")) {
                    Object newInstance = constructor.newInstance(this);
                    this.fXPathEvaluator = newInstance;
                    return newInstance;
                }
            }
            return null;
        } catch (Exception unused) {
            return null;
        }
    }

    public Element getIdentifier(String str) {
        Element element;
        if (needsSyncData()) {
            synchronizeData();
        }
        Hashtable hashtable = this.identifiers;
        if (!(hashtable == null || (element = (Element) hashtable.get(str)) == null)) {
            for (Node parentNode = element.getParentNode(); parentNode != null; parentNode = parentNode.getParentNode()) {
                if (parentNode == this) {
                    return element;
                }
            }
        }
        return null;
    }

    public Enumeration getIdentifiers() {
        if (needsSyncData()) {
            synchronizeData();
        }
        if (this.identifiers == null) {
            this.identifiers = new Hashtable();
        }
        return this.identifiers.keys();
    }

    @Override // org.w3c.dom.Document
    public DOMImplementation getImplementation() {
        return CoreDOMImplementationImpl.getDOMImplementation();
    }

    @Override // org.w3c.dom.Document
    public String getInputEncoding() {
        return this.actualEncoding;
    }

    public boolean getMutationEvents() {
        return false;
    }

    public NodeListCache getNodeListCache(ParentNode parentNode) {
        NodeListCache nodeListCache = this.fFreeNLCache;
        if (nodeListCache == null) {
            return new NodeListCache(parentNode);
        }
        this.fFreeNLCache = nodeListCache.next;
        nodeListCache.fChild = null;
        nodeListCache.fChildIndex = -1;
        nodeListCache.fLength = -1;
        ParentNode parentNode2 = nodeListCache.fOwner;
        if (parentNode2 != null) {
            parentNode2.fNodeListCache = null;
        }
        nodeListCache.fOwner = parentNode;
        return nodeListCache;
    }

    @Override // org.apache.xerces.dom.NodeImpl, org.w3c.dom.Node
    public String getNodeName() {
        return "#document";
    }

    @Override // org.apache.xerces.dom.NodeImpl
    public int getNodeNumber() {
        if (this.documentNumber == 0) {
            this.documentNumber = ((CoreDOMImplementationImpl) CoreDOMImplementationImpl.getDOMImplementation()).assignDocumentNumber();
        }
        return this.documentNumber;
    }

    public int getNodeNumber(Node node) {
        int i2;
        Map map;
        Integer num;
        Map map2 = this.nodeTable;
        if (map2 == null) {
            map = new WeakHashMap();
            this.nodeTable = map;
            i2 = this.nodeCounter - 1;
            this.nodeCounter = i2;
            num = new Integer(i2);
        } else {
            Integer num2 = (Integer) map2.get(node);
            if (num2 != null) {
                return num2.intValue();
            }
            i2 = this.nodeCounter - 1;
            this.nodeCounter = i2;
            map = this.nodeTable;
            num = new Integer(i2);
        }
        map.put(node, num);
        return i2;
    }

    @Override // org.apache.xerces.dom.NodeImpl, org.w3c.dom.Node
    public short getNodeType() {
        return 9;
    }

    @Override // org.apache.xerces.dom.NodeImpl, org.w3c.dom.Node, org.apache.xerces.dom.ParentNode
    public final Document getOwnerDocument() {
        return null;
    }

    public boolean getStandalone() {
        return getXmlStandalone();
    }

    @Override // org.w3c.dom.Document
    public boolean getStrictErrorChecking() {
        return this.errorChecking;
    }

    @Override // org.apache.xerces.dom.NodeImpl, org.w3c.dom.Node, org.apache.xerces.dom.ParentNode
    public String getTextContent() {
        return null;
    }

    public Object getUserData(NodeImpl nodeImpl) {
        return getUserData(nodeImpl, "XERCES1DOMUSERDATA");
    }

    public Object getUserData(Node node, String str) {
        Hashtable hashtable;
        Object obj;
        Map map = this.userData;
        if (map == null || (hashtable = (Hashtable) map.get(node)) == null || (obj = hashtable.get(str)) == null) {
            return null;
        }
        return ((ParentNode.UserDataRecord) obj).fData;
    }

    public Hashtable getUserDataRecord(Node node) {
        Hashtable hashtable;
        Map map = this.userData;
        if (map == null || (hashtable = (Hashtable) map.get(node)) == null) {
            return null;
        }
        return hashtable;
    }

    public String getVersion() {
        return getXmlVersion();
    }

    @Override // org.w3c.dom.Document
    public String getXmlEncoding() {
        return this.encoding;
    }

    @Override // org.w3c.dom.Document
    public boolean getXmlStandalone() {
        return this.standalone;
    }

    @Override // org.w3c.dom.Document
    public String getXmlVersion() {
        String str = this.version;
        return str == null ? "1.0" : str;
    }

    @Override // org.w3c.dom.Document
    public Node importNode(Node node, boolean z) {
        return importNode(node, z, false, null);
    }

    @Override // org.apache.xerces.dom.NodeImpl, org.w3c.dom.Node, org.apache.xerces.dom.ParentNode
    public Node insertBefore(Node node, Node node2) {
        short nodeType = node.getNodeType();
        if (this.errorChecking) {
            if (needsSyncChildren()) {
                synchronizeChildren();
            }
            if ((nodeType == 1 && this.docElement != null) || (nodeType == 10 && this.docType != null)) {
                throw new DOMException(3, DOMMessageFormatter.formatMessage(DOMMessageFormatter.DOM_DOMAIN, "HIERARCHY_REQUEST_ERR", null));
            }
        }
        if (node.getOwnerDocument() == null && (node instanceof DocumentTypeImpl)) {
            ((DocumentTypeImpl) node).ownerDocument = this;
        }
        super.insertBefore(node, node2);
        if (nodeType == 1) {
            this.docElement = (ElementImpl) node;
        } else if (nodeType == 10) {
            this.docType = (DocumentTypeImpl) node;
        }
        return node;
    }

    public void insertedNode(NodeImpl nodeImpl, NodeImpl nodeImpl2, boolean z) {
    }

    public void insertedText(CharacterDataImpl characterDataImpl, int i2, int i3) {
    }

    public void insertingNode(NodeImpl nodeImpl, boolean z) {
    }

    public boolean isKidOK(Node node, Node node2) {
        return (!this.allowGrammarAccess || node.getNodeType() != 10) ? (kidOK[node.getNodeType()] & (1 << node2.getNodeType())) != 0 : node2.getNodeType() == 1;
    }

    public boolean isNormalizeDocRequired() {
        return true;
    }

    public boolean isXML11Version() {
        return this.xml11Version;
    }

    public boolean isXMLVersionChanged() {
        return this.xmlVersionChanged;
    }

    public boolean load(String str) {
        return false;
    }

    public boolean loadXML(String str) {
        return false;
    }

    public void modifiedAttrValue(AttrImpl attrImpl, String str) {
    }

    public void modifiedCharacterData(NodeImpl nodeImpl, String str, String str2, boolean z) {
    }

    public void modifyingCharacterData(NodeImpl nodeImpl, boolean z) {
    }

    @Override // org.w3c.dom.Document
    public void normalizeDocument() {
        if (!isNormalized() || isNormalizeDocRequired()) {
            if (needsSyncChildren()) {
                synchronizeChildren();
            }
            if (this.domNormalizer == null) {
                this.domNormalizer = new DOMNormalizer();
            }
            DOMConfigurationImpl dOMConfigurationImpl = this.fConfiguration;
            if (dOMConfigurationImpl == null) {
                this.fConfiguration = new DOMConfigurationImpl();
            } else {
                dOMConfigurationImpl.reset();
            }
            this.domNormalizer.normalizeDocument(this, this.fConfiguration);
            isNormalized(true);
            this.xmlVersionChanged = false;
        }
    }

    public void putIdentifier(String str, Element element) {
        if (element == null) {
            removeIdentifier(str);
            return;
        }
        if (needsSyncData()) {
            synchronizeData();
        }
        if (this.identifiers == null) {
            this.identifiers = new Hashtable();
        }
        this.identifiers.put(str, element);
    }

    @Override // org.apache.xerces.dom.NodeImpl, org.w3c.dom.Node, org.apache.xerces.dom.ParentNode
    public Node removeChild(Node node) {
        super.removeChild(node);
        short nodeType = node.getNodeType();
        if (nodeType == 1) {
            this.docElement = null;
        } else if (nodeType == 10) {
            this.docType = null;
        }
        return node;
    }

    public void removeEventListener(NodeImpl nodeImpl, String str, EventListener eventListener, boolean z) {
    }

    public void removeIdentifier(String str) {
        if (needsSyncData()) {
            synchronizeData();
        }
        Hashtable hashtable = this.identifiers;
        if (hashtable != null) {
            hashtable.remove(str);
        }
    }

    public Hashtable removeUserDataTable(Node node) {
        Map map = this.userData;
        if (map == null) {
            return null;
        }
        return (Hashtable) map.get(node);
    }

    public void removedAttrNode(AttrImpl attrImpl, NodeImpl nodeImpl, String str) {
    }

    public void removedNode(NodeImpl nodeImpl, boolean z) {
    }

    public void removingNode(NodeImpl nodeImpl, NodeImpl nodeImpl2, boolean z) {
    }

    @Override // org.w3c.dom.Document
    public Node renameNode(Node node, String str, String str2) {
        if (!this.errorChecking || node.getOwnerDocument() == this || node == this) {
            short nodeType = node.getNodeType();
            if (nodeType == 1) {
                ElementImpl elementImpl = (ElementImpl) node;
                if (elementImpl instanceof ElementNSImpl) {
                    if (canRenameElements(str, str2, elementImpl)) {
                        ((ElementNSImpl) elementImpl).rename(str, str2);
                    }
                    elementImpl = replaceRenameElement(elementImpl, str, str2);
                    renamedElement((Element) node, elementImpl);
                    return elementImpl;
                }
                if (str == null && canRenameElements(null, str2, elementImpl)) {
                    elementImpl.rename(str2);
                }
                elementImpl = replaceRenameElement(elementImpl, str, str2);
                renamedElement((Element) node, elementImpl);
                return elementImpl;
                callUserDataHandlers(elementImpl, null, 4);
                renamedElement((Element) node, elementImpl);
                return elementImpl;
            } else if (nodeType == 2) {
                AttrImpl attrImpl = (AttrImpl) node;
                Element ownerElement = attrImpl.getOwnerElement();
                if (ownerElement != null) {
                    ownerElement.removeAttributeNode(attrImpl);
                }
                if (node instanceof AttrNSImpl) {
                    ((AttrNSImpl) attrImpl).rename(str, str2);
                    if (ownerElement != 0) {
                        ownerElement.setAttributeNodeNS(attrImpl);
                    }
                } else if (str == null) {
                    attrImpl.rename(str2);
                    if (ownerElement != 0) {
                        ownerElement.setAttributeNode(attrImpl);
                    }
                } else {
                    AttrNSImpl attrNSImpl = (AttrNSImpl) createAttributeNS(str, str2);
                    copyEventListeners(attrImpl, attrNSImpl);
                    Hashtable removeUserDataTable = removeUserDataTable(attrImpl);
                    while (true) {
                        Node firstChild = attrImpl.getFirstChild();
                        if (firstChild == null) {
                            break;
                        }
                        attrImpl.removeChild(firstChild);
                        attrNSImpl.appendChild(firstChild);
                    }
                    setUserDataTable(attrNSImpl, removeUserDataTable);
                    callUserDataHandlers(attrImpl, attrNSImpl, 4);
                    if (ownerElement != null) {
                        ownerElement.setAttributeNode(attrNSImpl);
                    }
                    attrImpl = attrNSImpl;
                    renamedAttrNode((Attr) node, attrImpl);
                    return attrImpl;
                }
                callUserDataHandlers(attrImpl, null, 4);
                renamedAttrNode((Attr) node, attrImpl);
                return attrImpl;
            } else {
                throw new DOMException(9, DOMMessageFormatter.formatMessage(DOMMessageFormatter.DOM_DOMAIN, "NOT_SUPPORTED_ERR", null));
            }
        } else {
            throw new DOMException(4, DOMMessageFormatter.formatMessage(DOMMessageFormatter.DOM_DOMAIN, "WRONG_DOCUMENT_ERR", null));
        }
    }

    public void renamedAttrNode(Attr attr, Attr attr2) {
    }

    public void renamedElement(Element element, Element element2) {
    }

    @Override // org.apache.xerces.dom.NodeImpl, org.w3c.dom.Node, org.apache.xerces.dom.ParentNode
    public Node replaceChild(Node node, Node node2) {
        if (node.getOwnerDocument() == null && (node instanceof DocumentTypeImpl)) {
            ((DocumentTypeImpl) node).ownerDocument = this;
        }
        if (!this.errorChecking || ((this.docType == null || node2.getNodeType() == 10 || node.getNodeType() != 10) && (this.docElement == null || node2.getNodeType() == 1 || node.getNodeType() != 1))) {
            super.replaceChild(node, node2);
            short nodeType = node2.getNodeType();
            if (nodeType == 1) {
                this.docElement = (ElementImpl) node;
            } else if (nodeType == 10) {
                this.docType = (DocumentTypeImpl) node;
            }
            return node2;
        }
        throw new DOMException(3, DOMMessageFormatter.formatMessage(DOMMessageFormatter.DOM_DOMAIN, "HIERARCHY_REQUEST_ERR", null));
    }

    public void replacedCharacterData(NodeImpl nodeImpl, String str, String str2) {
    }

    public void replacedNode(NodeImpl nodeImpl) {
    }

    public void replacedText(CharacterDataImpl characterDataImpl) {
    }

    public void replacingData(NodeImpl nodeImpl) {
    }

    public void replacingNode(NodeImpl nodeImpl) {
    }

    public String saveXML(Node node) {
        if (!this.errorChecking || node == null || this == node.getOwnerDocument()) {
            LSSerializer createLSSerializer = ((DOMImplementationLS) DOMImplementationImpl.getDOMImplementation()).createLSSerializer();
            if (node == null) {
                node = this;
            }
            return createLSSerializer.writeToString(node);
        }
        throw new DOMException(4, DOMMessageFormatter.formatMessage(DOMMessageFormatter.DOM_DOMAIN, "WRONG_DOCUMENT_ERR", null));
    }

    public void setAsync(boolean z) {
        if (z) {
            throw new DOMException(9, DOMMessageFormatter.formatMessage(DOMMessageFormatter.DOM_DOMAIN, "NOT_SUPPORTED_ERR", null));
        }
    }

    public void setAttrNode(AttrImpl attrImpl, AttrImpl attrImpl2) {
    }

    @Override // org.w3c.dom.Document
    public void setDocumentURI(String str) {
        this.fDocumentURI = str;
    }

    public void setEncoding(String str) {
        setXmlEncoding(str);
    }

    public void setErrorChecking(boolean z) {
        this.errorChecking = z;
    }

    public void setInputEncoding(String str) {
        this.actualEncoding = str;
    }

    public void setMutationEvents(boolean z) {
    }

    public void setStandalone(boolean z) {
        setXmlStandalone(z);
    }

    @Override // org.w3c.dom.Document
    public void setStrictErrorChecking(boolean z) {
        this.errorChecking = z;
    }

    @Override // org.apache.xerces.dom.NodeImpl, org.w3c.dom.Node, org.apache.xerces.dom.ParentNode
    public void setTextContent(String str) {
    }

    /* JADX WARNING: Removed duplicated region for block: B:20:0x004b A[RETURN] */
    public Object setUserData(Node node, String str, Object obj, UserDataHandler userDataHandler) {
        Hashtable hashtable;
        Object put;
        Hashtable hashtable2;
        if (obj == null) {
            Map map = this.userData;
            if (map == null || (hashtable2 = (Hashtable) map.get(node)) == null || (put = hashtable2.remove(str)) == null) {
                return null;
            }
        } else {
            Map map2 = this.userData;
            if (map2 == null) {
                this.userData = new WeakHashMap();
                hashtable = new Hashtable();
            } else {
                hashtable = (Hashtable) map2.get(node);
                if (hashtable == null) {
                    hashtable = new Hashtable();
                }
                put = hashtable.put(str, new ParentNode.UserDataRecord(obj, userDataHandler));
                if (put == null) {
                    return null;
                }
            }
            this.userData.put(node, hashtable);
            put = hashtable.put(str, new ParentNode.UserDataRecord(obj, userDataHandler));
            if (put == null) {
            }
        }
        return ((ParentNode.UserDataRecord) put).fData;
    }

    public void setUserData(NodeImpl nodeImpl, Object obj) {
        setUserData(nodeImpl, "XERCES1DOMUSERDATA", obj, null);
    }

    public void setUserDataTable(Node node, Hashtable hashtable) {
        if (this.userData == null) {
            this.userData = new WeakHashMap();
        }
        if (hashtable != null) {
            this.userData.put(node, hashtable);
        }
    }

    public void setVersion(String str) {
        setXmlVersion(str);
    }

    public void setXmlEncoding(String str) {
        this.encoding = str;
    }

    @Override // org.w3c.dom.Document
    public void setXmlStandalone(boolean z) {
        this.standalone = z;
    }

    @Override // org.w3c.dom.Document
    public void setXmlVersion(String str) {
        if (str.equals("1.0") || str.equals("1.1")) {
            if (!getXmlVersion().equals(str)) {
                this.xmlVersionChanged = true;
                isNormalized(false);
                this.version = str;
            }
            if (getXmlVersion().equals("1.1")) {
                this.xml11Version = true;
            } else {
                this.xml11Version = false;
            }
        } else {
            throw new DOMException(9, DOMMessageFormatter.formatMessage(DOMMessageFormatter.DOM_DOMAIN, "NOT_SUPPORTED_ERR", null));
        }
    }

    /* JADX WARNING: Code restructure failed: missing block: B:22:0x0049, code lost:
        r0 = null;
     */
    public void undeferChildren(Node node) {
        Node node2 = node;
        while (node2 != null) {
            NodeImpl nodeImpl = (NodeImpl) node2;
            if (nodeImpl.needsSyncData()) {
                nodeImpl.synchronizeData();
            }
            NamedNodeMap attributes = node2.getAttributes();
            if (attributes != null) {
                int length = attributes.getLength();
                for (int i2 = 0; i2 < length; i2++) {
                    undeferChildren(attributes.item(i2));
                }
            }
            Node firstChild = node2.getFirstChild();
            while (true) {
                if (firstChild == null && !node.equals(node2)) {
                    firstChild = node2.getNextSibling();
                    if (firstChild != null || ((node2 = node2.getParentNode()) != null && !node.equals(node2))) {
                    }
                }
            }
            node2 = firstChild;
        }
    }
}
