package org.apache.xerces.impl;

import org.apache.poi.ss.formula.ptg.StringPtg;
import org.apache.xerces.util.XML11Char;
import org.apache.xerces.util.XMLChar;
import org.apache.xerces.util.XMLStringBuffer;
import org.apache.xerces.xni.XMLDocumentHandler;
import org.apache.xerces.xni.XMLString;

public class XML11DocumentScannerImpl extends XMLDocumentScannerImpl {
    public final XMLString fString = new XMLString();
    public final XMLStringBuffer fStringBuffer = new XMLStringBuffer();
    public final XMLStringBuffer fStringBuffer2 = new XMLStringBuffer();
    public final XMLStringBuffer fStringBuffer3 = new XMLStringBuffer();

    @Override // org.apache.xerces.impl.XMLScanner
    public String getVersionNotSupportedKey() {
        return "VersionNotSupported11";
    }

    @Override // org.apache.xerces.impl.XMLScanner
    public boolean isInvalid(int i2) {
        return XML11Char.isXML11Invalid(i2);
    }

    @Override // org.apache.xerces.impl.XMLScanner
    public boolean isInvalidLiteral(int i2) {
        return !XML11Char.isXML11ValidLiteral(i2);
    }

    @Override // org.apache.xerces.impl.XMLScanner
    public int isUnchangedByNormalization(XMLString xMLString) {
        int i2 = xMLString.offset;
        int i3 = xMLString.length + i2;
        while (i2 < i3) {
            if (XMLChar.isSpace(xMLString.ch[i2])) {
                return i2 - xMLString.offset;
            }
            i2++;
        }
        return -1;
    }

    @Override // org.apache.xerces.impl.XMLScanner
    public boolean isValidNCName(int i2) {
        return XML11Char.isXML11NCName(i2);
    }

    @Override // org.apache.xerces.impl.XMLScanner
    public boolean isValidNameChar(int i2) {
        return XML11Char.isXML11Name(i2);
    }

    @Override // org.apache.xerces.impl.XMLScanner
    public boolean isValidNameStartChar(int i2) {
        return XML11Char.isXML11NameStart(i2);
    }

    @Override // org.apache.xerces.impl.XMLScanner
    public boolean isValidNameStartHighSurrogate(int i2) {
        return XML11Char.isXML11NameHighSurrogate(i2);
    }

    @Override // org.apache.xerces.impl.XMLScanner
    public void normalizeWhitespace(XMLString xMLString) {
        int i2 = xMLString.offset;
        int i3 = xMLString.length + i2;
        while (i2 < i3) {
            if (XMLChar.isSpace(xMLString.ch[i2])) {
                xMLString.ch[i2] = ' ';
            }
            i2++;
        }
    }

    @Override // org.apache.xerces.impl.XMLScanner
    public void normalizeWhitespace(XMLString xMLString, int i2) {
        int i3 = xMLString.offset;
        int i4 = xMLString.length + i3;
        for (int i5 = i3 + i2; i5 < i4; i5++) {
            if (XMLChar.isSpace(xMLString.ch[i5])) {
                xMLString.ch[i5] = ' ';
            }
        }
    }

    /* JADX WARNING: Removed duplicated region for block: B:108:0x0207  */
    /* JADX WARNING: Removed duplicated region for block: B:111:0x0211  */
    /* JADX WARNING: Removed duplicated region for block: B:121:0x0222 A[ADDED_TO_REGION, SYNTHETIC] */
    @Override // org.apache.xerces.impl.XMLScanner
    public boolean scanAttributeValue(XMLString xMLString, XMLString xMLString2, String str, boolean z, String str2) {
        int i2;
        XMLStringBuffer xMLStringBuffer;
        char c;
        int peekChar = this.fEntityScanner.peekChar();
        if (!(peekChar == 39 || peekChar == 34)) {
            reportFatalError("OpenQuoteExpected", new Object[]{str2, str});
        }
        this.fEntityScanner.scanChar();
        int i3 = this.fEntityDepth;
        int scanLiteral = this.fEntityScanner.scanLiteral(peekChar, xMLString);
        if (scanLiteral == peekChar) {
            i2 = isUnchangedByNormalization(xMLString);
            if (i2 == -1) {
                xMLString2.setValues(xMLString);
                if (this.fEntityScanner.scanChar() != peekChar) {
                    reportFatalError("CloseQuoteExpected", new Object[]{str2, str});
                }
                return true;
            }
        } else {
            i2 = 0;
        }
        this.fStringBuffer2.clear();
        this.fStringBuffer2.append(xMLString);
        normalizeWhitespace(xMLString, i2);
        if (scanLiteral != peekChar) {
            this.fScanningAttribute = true;
            this.fStringBuffer.clear();
            while (true) {
                this.fStringBuffer.append(xMLString);
                if (scanLiteral == 38) {
                    this.fEntityScanner.skipChar(38);
                    if (i3 == this.fEntityDepth) {
                        this.fStringBuffer2.append('&');
                    }
                    if (this.fEntityScanner.skipChar(35)) {
                        if (i3 == this.fEntityDepth) {
                            this.fStringBuffer2.append('#');
                        }
                        scanCharReferenceValue(this.fStringBuffer, this.fStringBuffer2);
                    } else {
                        String scanName = this.fEntityScanner.scanName();
                        if (scanName == null) {
                            reportFatalError("NameRequiredInReference", null);
                        } else if (i3 == this.fEntityDepth) {
                            this.fStringBuffer2.append(scanName);
                        }
                        if (!this.fEntityScanner.skipChar(59)) {
                            reportFatalError("SemicolonRequiredInReference", new Object[]{scanName});
                        } else if (i3 == this.fEntityDepth) {
                            this.fStringBuffer2.append(';');
                        }
                        if (scanName == XMLScanner.fAmpSymbol) {
                            this.fStringBuffer.append('&');
                        } else if (scanName == XMLScanner.fAposSymbol) {
                            this.fStringBuffer.append('\'');
                        } else if (scanName == XMLScanner.fLtSymbol) {
                            this.fStringBuffer.append('<');
                        } else if (scanName == XMLScanner.fGtSymbol) {
                            this.fStringBuffer.append('>');
                        } else if (scanName == XMLScanner.fQuotSymbol) {
                            this.fStringBuffer.append(StringPtg.FORMULA_DELIMITER);
                        } else if (this.fEntityManager.isExternalEntity(scanName)) {
                            reportFatalError("ReferenceToExternalEntity", new Object[]{scanName});
                        } else {
                            if (!this.fEntityManager.isDeclaredEntity(scanName)) {
                                if (!z) {
                                    reportFatalError("EntityNotDeclared", new Object[]{scanName});
                                } else if (this.fValidation) {
                                    this.fErrorReporter.reportError("http://www.w3.org/TR/1998/REC-xml-19980210", "EntityNotDeclared", new Object[]{scanName}, 1);
                                }
                            }
                            this.fEntityManager.startEntity(scanName, true);
                        }
                    }
                } else if (scanLiteral == 60) {
                    reportFatalError("LessthanInAttValue", new Object[]{str2, str});
                    this.fEntityScanner.scanChar();
                    if (i3 == this.fEntityDepth) {
                        this.fStringBuffer2.append((char) scanLiteral);
                    }
                } else {
                    if (scanLiteral == 37 || scanLiteral == 93) {
                        this.fEntityScanner.scanChar();
                        c = (char) scanLiteral;
                        this.fStringBuffer.append(c);
                        if (i3 == this.fEntityDepth) {
                            xMLStringBuffer = this.fStringBuffer2;
                        }
                        scanLiteral = this.fEntityScanner.scanLiteral(peekChar, xMLString);
                        if (i3 == this.fEntityDepth) {
                            this.fStringBuffer2.append(xMLString);
                        }
                        normalizeWhitespace(xMLString);
                        if (scanLiteral == peekChar && i3 == this.fEntityDepth) {
                            break;
                        }
                    } else if (scanLiteral == 10 || scanLiteral == 13 || scanLiteral == 133 || scanLiteral == 8232) {
                        this.fEntityScanner.scanChar();
                        this.fStringBuffer.append(' ');
                        if (i3 == this.fEntityDepth) {
                            this.fStringBuffer2.append('\n');
                        }
                        scanLiteral = this.fEntityScanner.scanLiteral(peekChar, xMLString);
                        if (i3 == this.fEntityDepth) {
                        }
                        normalizeWhitespace(xMLString);
                        if (scanLiteral == peekChar) {
                        }
                    } else {
                        int i4 = -1;
                        if (scanLiteral != -1) {
                            if (XMLChar.isHighSurrogate(scanLiteral)) {
                                this.fStringBuffer3.clear();
                                if (scanSurrogates(this.fStringBuffer3)) {
                                    this.fStringBuffer.append(this.fStringBuffer3);
                                    if (i3 == this.fEntityDepth) {
                                        this.fStringBuffer2.append(this.fStringBuffer3);
                                    }
                                }
                            } else {
                                i4 = -1;
                            }
                        }
                        if (scanLiteral != i4 && isInvalidLiteral(scanLiteral)) {
                            reportFatalError("InvalidCharInAttValue", new Object[]{str2, str, Integer.toString(scanLiteral, 16)});
                            this.fEntityScanner.scanChar();
                            if (i3 == this.fEntityDepth) {
                                xMLStringBuffer = this.fStringBuffer2;
                                c = (char) scanLiteral;
                            }
                        }
                        scanLiteral = this.fEntityScanner.scanLiteral(peekChar, xMLString);
                        if (i3 == this.fEntityDepth) {
                        }
                        normalizeWhitespace(xMLString);
                        if (scanLiteral == peekChar) {
                        }
                    }
                    xMLStringBuffer.append(c);
                    scanLiteral = this.fEntityScanner.scanLiteral(peekChar, xMLString);
                    if (i3 == this.fEntityDepth) {
                    }
                    normalizeWhitespace(xMLString);
                    if (scanLiteral == peekChar) {
                    }
                }
                scanLiteral = this.fEntityScanner.scanLiteral(peekChar, xMLString);
                if (i3 == this.fEntityDepth) {
                }
                normalizeWhitespace(xMLString);
                if (scanLiteral == peekChar) {
                }
            }
            this.fStringBuffer.append(xMLString);
            xMLString.setValues(this.fStringBuffer);
            this.fScanningAttribute = false;
        }
        xMLString2.setValues(this.fStringBuffer2);
        if (this.fEntityScanner.scanChar() != peekChar) {
            reportFatalError("CloseQuoteExpected", new Object[]{str2, str});
        }
        return xMLString2.equals(xMLString.ch, xMLString.offset, xMLString.length);
    }

    @Override // org.apache.xerces.impl.XMLDocumentFragmentScannerImpl
    public int scanContent() {
        XMLString xMLString = this.fString;
        int scanContent = this.fEntityScanner.scanContent(xMLString);
        if (scanContent == 13 || scanContent == 133 || scanContent == 8232) {
            this.fEntityScanner.scanChar();
            this.fStringBuffer.clear();
            this.fStringBuffer.append(this.fString);
            this.fStringBuffer.append((char) scanContent);
            xMLString = this.fStringBuffer;
            scanContent = -1;
        }
        XMLDocumentHandler xMLDocumentHandler = this.fDocumentHandler;
        if (xMLDocumentHandler != null && xMLString.length > 0) {
            xMLDocumentHandler.characters(xMLString, null);
        }
        if (scanContent != 93 || this.fString.length != 0) {
            return scanContent;
        }
        this.fStringBuffer.clear();
        this.fStringBuffer.append((char) this.fEntityScanner.scanChar());
        this.fInScanContent = true;
        if (this.fEntityScanner.skipChar(93)) {
            do {
                this.fStringBuffer.append(']');
            } while (this.fEntityScanner.skipChar(93));
            if (this.fEntityScanner.skipChar(62)) {
                reportFatalError("CDEndInContent", null);
            }
        }
        XMLDocumentHandler xMLDocumentHandler2 = this.fDocumentHandler;
        if (xMLDocumentHandler2 != null) {
            XMLStringBuffer xMLStringBuffer = this.fStringBuffer;
            if (xMLStringBuffer.length != 0) {
                xMLDocumentHandler2.characters(xMLStringBuffer, null);
            }
        }
        this.fInScanContent = false;
        return -1;
    }

    @Override // org.apache.xerces.impl.XMLScanner
    public boolean scanPubidLiteral(XMLString xMLString) {
        String str;
        int scanChar = this.fEntityScanner.scanChar();
        if (scanChar == 39 || scanChar == 34) {
            this.fStringBuffer.clear();
            boolean z = true;
            boolean z2 = true;
            while (true) {
                int scanChar2 = this.fEntityScanner.scanChar();
                if (scanChar2 == 32 || scanChar2 == 10 || scanChar2 == 13 || scanChar2 == 133 || scanChar2 == 8232) {
                    if (!z) {
                        this.fStringBuffer.append(' ');
                        z = true;
                    }
                } else if (scanChar2 == scanChar) {
                    if (z) {
                        this.fStringBuffer.length--;
                    }
                    xMLString.setValues(this.fStringBuffer);
                    return z2;
                } else if (XMLChar.isPubid(scanChar2)) {
                    this.fStringBuffer.append((char) scanChar2);
                    z = false;
                } else if (scanChar2 == -1) {
                    str = "PublicIDUnterminated";
                    break;
                } else {
                    reportFatalError("InvalidCharInPublicID", new Object[]{Integer.toHexString(scanChar2)});
                    z2 = false;
                }
            }
        } else {
            str = "QuoteRequiredInPublicID";
        }
        reportFatalError(str, null);
        return false;
    }

    @Override // org.apache.xerces.impl.XMLScanner
    public boolean versionSupported(String str) {
        return str.equals("1.1") || str.equals("1.0");
    }
}
