package org.apache.xerces.impl.xpath.regex;

import b.b.a.a.a;
import java.util.Locale;
import java.util.MissingResourceException;
import java.util.ResourceBundle;
import java.util.Vector;
import org.apache.poi.ss.util.SheetUtil;
import org.apache.xerces.impl.xpath.regex.Token;

public class RegexParser {
    public static final int S_INBRACKETS = 1;
    public static final int S_INXBRACKETS = 2;
    public static final int S_NORMAL = 0;
    public static final int T_BACKSOLIDUS = 10;
    public static final int T_CARET = 11;
    public static final int T_CHAR = 0;
    public static final int T_COMMENT = 21;
    public static final int T_CONDITION = 23;
    public static final int T_DOLLAR = 12;
    public static final int T_DOT = 8;
    public static final int T_EOF = 1;
    public static final int T_INDEPENDENT = 18;
    public static final int T_LBRACKET = 9;
    public static final int T_LOOKAHEAD = 14;
    public static final int T_LOOKBEHIND = 16;
    public static final int T_LPAREN = 6;
    public static final int T_LPAREN2 = 13;
    public static final int T_MODIFIERS = 22;
    public static final int T_NEGATIVELOOKAHEAD = 15;
    public static final int T_NEGATIVELOOKBEHIND = 17;
    public static final int T_OR = 2;
    public static final int T_PLUS = 4;
    public static final int T_POSIX_CHARCLASS_START = 20;
    public static final int T_QUESTION = 5;
    public static final int T_RPAREN = 7;
    public static final int T_SET_OPERATIONS = 19;
    public static final int T_STAR = 3;
    public static final int T_XMLSCHEMA_CC_SUBTRACTION = 24;
    public int chardata;
    public int context = 0;
    public boolean hasBackReferences;
    public int nexttoken;
    public int offset;
    public int options;
    public int parenOpened = 1;
    public int parennumber = 1;
    public Vector references = null;
    public String regex;
    public int regexlen;
    public ResourceBundle resources;

    public static class ReferencePosition {
        public int position;
        public int refNumber;

        public ReferencePosition(int i2, int i3) {
            this.refNumber = i2;
            this.position = i3;
        }
    }

    public RegexParser() {
        setLocale(Locale.getDefault());
    }

    public RegexParser(Locale locale) {
        setLocale(locale);
    }

    public static final void addCaseInsensitiveChar(RangeToken rangeToken, int i2) {
        int[] iArr = CaseInsensitiveMap.get(i2);
        rangeToken.addRange(i2, i2);
        if (iArr != null) {
            for (int i3 = 0; i3 < iArr.length; i3 += 2) {
                rangeToken.addRange(iArr[i3], iArr[i3]);
            }
        }
    }

    public static final void addCaseInsensitiveCharRange(RangeToken rangeToken, int i2, int i3) {
        if (i2 > i3) {
            i3 = i2;
            i2 = i3;
        }
        rangeToken.addRange(i2, i3);
        while (i2 <= i3) {
            int[] iArr = CaseInsensitiveMap.get(i2);
            if (iArr != null) {
                for (int i4 = 0; i4 < iArr.length; i4 += 2) {
                    rangeToken.addRange(iArr[i4], iArr[i4]);
                }
            }
            i2++;
        }
    }

    public static final int hexChar(int i2) {
        if (i2 < 48 || i2 > 102) {
            return -1;
        }
        if (i2 <= 57) {
            return i2 - 48;
        }
        int i3 = 65;
        if (i2 < 65) {
            return -1;
        }
        if (i2 > 70) {
            i3 = 97;
            if (i2 < 97) {
                return -1;
            }
        }
        return (i2 - i3) + 10;
    }

    public boolean checkQuestion(int i2) {
        return i2 < this.regexlen && this.regex.charAt(i2) == '?';
    }

    /* JADX INFO: Can't fix incorrect switch cases order, some code will duplicate */
    public int decodeEscaped() {
        int i2;
        int i3;
        int hexChar;
        int hexChar2;
        int hexChar3;
        int hexChar4;
        int hexChar5;
        int hexChar6;
        int hexChar7;
        int hexChar8;
        int hexChar9;
        if (read() == 10) {
            int i4 = this.chardata;
            if (!(i4 == 65 || i4 == 90)) {
                if (i4 == 110) {
                    return 10;
                }
                if (i4 == 114) {
                    return 13;
                }
                if (i4 == 120) {
                    next();
                    if (read() != 0) {
                        throw ex("parser.descape.1", this.offset - 1);
                    } else if (this.chardata == 123) {
                        int i5 = 0;
                        while (true) {
                            next();
                            if (read() == 0) {
                                int hexChar10 = hexChar(this.chardata);
                                if (hexChar10 >= 0) {
                                    int i6 = i5 * 16;
                                    if (i5 <= i6) {
                                        i5 = i6 + hexChar10;
                                    } else {
                                        throw ex("parser.descape.2", this.offset - 1);
                                    }
                                } else if (this.chardata != 125) {
                                    throw ex("parser.descape.3", this.offset - 1);
                                } else if (i5 <= 1114111) {
                                    return i5;
                                } else {
                                    throw ex("parser.descape.4", this.offset - 1);
                                }
                            } else {
                                throw ex("parser.descape.1", this.offset - 1);
                            }
                        }
                    } else if (read() != 0 || (i3 = hexChar(this.chardata)) < 0) {
                        throw ex("parser.descape.1", this.offset - 1);
                    } else {
                        next();
                        if (read() != 0 || (i2 = hexChar(this.chardata)) < 0) {
                            throw ex("parser.descape.1", this.offset - 1);
                        }
                    }
                } else if (i4 != 122) {
                    if (i4 == 101) {
                        return 27;
                    }
                    if (i4 == 102) {
                        return 12;
                    }
                    switch (i4) {
                        case 116:
                            return 9;
                        case 117:
                            next();
                            if (read() != 0 || (hexChar = hexChar(this.chardata)) < 0) {
                                throw ex("parser.descape.1", this.offset - 1);
                            }
                            next();
                            if (read() != 0 || (hexChar2 = hexChar(this.chardata)) < 0) {
                                throw ex("parser.descape.1", this.offset - 1);
                            }
                            int i7 = (hexChar * 16) + hexChar2;
                            next();
                            if (read() != 0 || (hexChar3 = hexChar(this.chardata)) < 0) {
                                throw ex("parser.descape.1", this.offset - 1);
                            }
                            i3 = (i7 * 16) + hexChar3;
                            next();
                            if (read() != 0 || (i2 = hexChar(this.chardata)) < 0) {
                                throw ex("parser.descape.1", this.offset - 1);
                            }
                            break;
                        case 118:
                            next();
                            if (read() != 0 || (hexChar4 = hexChar(this.chardata)) < 0) {
                                throw ex("parser.descape.1", this.offset - 1);
                            }
                            next();
                            if (read() != 0 || (hexChar5 = hexChar(this.chardata)) < 0) {
                                throw ex("parser.descape.1", this.offset - 1);
                            }
                            int i8 = (hexChar4 * 16) + hexChar5;
                            next();
                            if (read() != 0 || (hexChar6 = hexChar(this.chardata)) < 0) {
                                throw ex("parser.descape.1", this.offset - 1);
                            }
                            int i9 = (i8 * 16) + hexChar6;
                            next();
                            if (read() != 0 || (hexChar7 = hexChar(this.chardata)) < 0) {
                                throw ex("parser.descape.1", this.offset - 1);
                            }
                            int i10 = (i9 * 16) + hexChar7;
                            next();
                            if (read() != 0 || (hexChar8 = hexChar(this.chardata)) < 0) {
                                throw ex("parser.descape.1", this.offset - 1);
                            }
                            int i11 = (i10 * 16) + hexChar8;
                            next();
                            if (read() != 0 || (hexChar9 = hexChar(this.chardata)) < 0) {
                                throw ex("parser.descape.1", this.offset - 1);
                            }
                            int i12 = hexChar9 + (i11 * 16);
                            if (i12 <= 1114111) {
                                return i12;
                            }
                            throw ex("parser.descappe.4", this.offset - 1);
                        default:
                            return i4;
                    }
                }
                return i2 + (i3 * 16);
            }
            throw ex("parser.descape.5", this.offset - 2);
        }
        throw ex("parser.next.1", this.offset - 1);
    }

    public final ParseException ex(String str, int i2) {
        return new ParseException(this.resources.getString(str), i2);
    }

    public Token getTokenForShorthand(int i2) {
        boolean z = false;
        if (i2 != 68) {
            if (i2 != 83) {
                if (i2 != 87) {
                    z = true;
                    if (i2 != 100) {
                        if (i2 != 115) {
                            if (i2 != 119) {
                                StringBuffer a = a.a("Internal Error: shorthands: \\u");
                                a.append(Integer.toString(i2, 16));
                                throw new RuntimeException(a.toString());
                            } else if (!isSet(32)) {
                                return Token.token_wordchars;
                            }
                        } else if (!isSet(32)) {
                            return Token.token_spaces;
                        }
                    } else if (!isSet(32)) {
                        return Token.token_0to9;
                    }
                } else if (!isSet(32)) {
                    return Token.token_not_wordchars;
                }
                return Token.getRange("IsWord", z);
            } else if (!isSet(32)) {
                return Token.token_not_spaces;
            }
            return Token.getRange("IsSpace", z);
        } else if (!isSet(32)) {
            return Token.token_not_0to9;
        }
        return Token.getRange("Nd", z);
    }

    public final boolean isSet(int i2) {
        return (this.options & i2) == i2;
    }

    /* JADX WARNING: Removed duplicated region for block: B:101:0x0189  */
    /* JADX WARNING: Removed duplicated region for block: B:102:0x018c  */
    public final void next() {
        int i2;
        int i3;
        int i4 = this.offset;
        if (i4 >= this.regexlen) {
            this.chardata = -1;
            this.nexttoken = 1;
            return;
        }
        String str = this.regex;
        this.offset = i4 + 1;
        char charAt = str.charAt(i4);
        this.chardata = charAt;
        int i5 = 10;
        if (this.context == 1) {
            if (charAt != '-') {
                if (charAt != '[') {
                    if (charAt == '\\') {
                        int i6 = this.offset;
                        if (i6 < this.regexlen) {
                            String str2 = this.regex;
                            this.offset = i6 + 1;
                            this.chardata = str2.charAt(i6);
                            this.nexttoken = i5;
                            return;
                        }
                        throw ex("parser.next.1", i6 - 1);
                    }
                } else if (!isSet(512) && (i3 = this.offset) < this.regexlen && this.regex.charAt(i3) == ':') {
                    this.offset++;
                    i5 = 20;
                    this.nexttoken = i5;
                    return;
                }
                if (REUtil.isHighSurrogate(charAt) && (i2 = this.offset) < this.regexlen) {
                    char charAt2 = this.regex.charAt(i2);
                    if (REUtil.isLowSurrogate(charAt2)) {
                        this.chardata = REUtil.composeFromSurrogates(charAt, charAt2);
                        this.offset++;
                    }
                }
            } else {
                int i7 = this.offset;
                if (i7 < this.regexlen && this.regex.charAt(i7) == '[') {
                    this.offset++;
                    i5 = 24;
                    this.nexttoken = i5;
                    return;
                }
            }
            i5 = 0;
            this.nexttoken = i5;
            return;
        }
        if (charAt != '$') {
            if (charAt == '.') {
                i5 = 8;
            } else if (charAt == '?') {
                i5 = 5;
            } else if (charAt != '^') {
                if (charAt == '|') {
                    i5 = 2;
                } else if (charAt == '[') {
                    i5 = 9;
                } else if (charAt != '\\') {
                    switch (charAt) {
                        case '(':
                            i5 = 6;
                            int i8 = this.offset;
                            if (i8 < this.regexlen && this.regex.charAt(i8) == '?') {
                                int i9 = this.offset + 1;
                                this.offset = i9;
                                if (i9 < this.regexlen) {
                                    String str3 = this.regex;
                                    this.offset = i9 + 1;
                                    char charAt3 = str3.charAt(i9);
                                    if (charAt3 == '!') {
                                        i5 = 15;
                                        break;
                                    } else if (charAt3 != '#') {
                                        if (charAt3 != ':') {
                                            if (charAt3 == '[') {
                                                i5 = 19;
                                                break;
                                            } else {
                                                switch (charAt3) {
                                                    case '<':
                                                        int i10 = this.offset;
                                                        if (i10 < this.regexlen) {
                                                            String str4 = this.regex;
                                                            this.offset = i10 + 1;
                                                            char charAt4 = str4.charAt(i10);
                                                            if (charAt4 == '=') {
                                                                i5 = 16;
                                                                break;
                                                            } else if (charAt4 == '!') {
                                                                i5 = 17;
                                                                break;
                                                            } else {
                                                                throw ex("parser.next.3", this.offset - 3);
                                                            }
                                                        } else {
                                                            throw ex("parser.next.2", i10 - 3);
                                                        }
                                                    case '=':
                                                        i5 = 14;
                                                        break;
                                                    case '>':
                                                        i5 = 18;
                                                        break;
                                                    default:
                                                        if (charAt3 == '-' || (('a' <= charAt3 && charAt3 <= 'z') || ('A' <= charAt3 && charAt3 <= 'Z'))) {
                                                            this.offset--;
                                                            i5 = 22;
                                                            break;
                                                        } else if (charAt3 == '(') {
                                                            i5 = 23;
                                                            break;
                                                        } else {
                                                            throw ex("parser.next.2", this.offset - 2);
                                                        }
                                                        break;
                                                }
                                            }
                                        } else {
                                            i5 = 13;
                                            break;
                                        }
                                    } else {
                                        do {
                                            int i11 = this.offset;
                                            if (i11 < this.regexlen) {
                                                String str5 = this.regex;
                                                this.offset = i11 + 1;
                                                charAt3 = str5.charAt(i11);
                                            }
                                            if (charAt3 != ')') {
                                                i5 = 21;
                                                break;
                                            } else {
                                                throw ex("parser.next.4", this.offset - 1);
                                            }
                                        } while (charAt3 != ')');
                                        if (charAt3 != ')') {
                                        }
                                    }
                                } else {
                                    throw ex("parser.next.2", i9 - 1);
                                }
                            }
                            break;
                        case ')':
                            i5 = 7;
                            break;
                        case '*':
                            i5 = 3;
                            break;
                        case '+':
                            i5 = 4;
                            break;
                    }
                } else {
                    int i12 = this.offset;
                    if (i12 < this.regexlen) {
                        String str6 = this.regex;
                        this.offset = i12 + 1;
                        this.chardata = str6.charAt(i12);
                    } else {
                        throw ex("parser.next.1", i12 - 1);
                    }
                }
            } else if (!isSet(512)) {
                i5 = 11;
            }
            this.nexttoken = i5;
        } else if (!isSet(512)) {
            i5 = 12;
            this.nexttoken = i5;
        }
        i5 = 0;
        this.nexttoken = i5;
    }

    public synchronized Token parse(String str, int i2) {
        Token parseRegex;
        this.options = i2;
        this.offset = 0;
        setContext(0);
        this.parennumber = 1;
        this.parenOpened = 1;
        this.hasBackReferences = false;
        this.regex = str;
        if (isSet(16)) {
            this.regex = REUtil.stripExtendedComment(this.regex);
        }
        this.regexlen = this.regex.length();
        next();
        parseRegex = parseRegex();
        if (this.offset != this.regexlen) {
            throw ex("parser.parse.1", this.offset);
        } else if (this.references != null) {
            for (int i3 = 0; i3 < this.references.size(); i3++) {
                ReferencePosition referencePosition = (ReferencePosition) this.references.elementAt(i3);
                if (this.parennumber <= referencePosition.refNumber) {
                    throw ex("parser.parse.2", referencePosition.position);
                }
            }
            this.references.removeAllElements();
        }
        return parseRegex;
    }

    /* JADX INFO: Can't fix incorrect switch cases order, some code will duplicate */
    public Token parseAtom() {
        Token createParen;
        int read = read();
        if (read == 0) {
            int i2 = this.chardata;
            if (i2 == 93 || i2 == 123 || i2 == 125) {
                throw ex("parser.atom.4", this.offset - 1);
            }
            Token.CharToken createChar = Token.createChar(i2);
            int i3 = this.chardata;
            next();
            if (!REUtil.isHighSurrogate(i3) || read() != 0 || !REUtil.isLowSurrogate(this.chardata)) {
                return createChar;
            }
            createParen = Token.createParen(Token.createString(new String(new char[]{(char) i3, (char) this.chardata})), 0);
        } else if (read == 6) {
            return processParen();
        } else {
            if (read == 13) {
                return processParen2();
            }
            if (read == 18) {
                return processIndependent();
            }
            if (read == 19) {
                return parseSetOperations();
            }
            if (read == 22) {
                return processModifiers();
            }
            if (read == 23) {
                return processCondition();
            }
            switch (read) {
                case 8:
                    next();
                    return Token.token_dot;
                case 9:
                    return parseCharacterClass(true);
                case 10:
                    int i4 = this.chardata;
                    if (i4 == 67) {
                        return processBacksolidus_C();
                    }
                    if (i4 != 68) {
                        if (i4 == 73) {
                            return processBacksolidus_I();
                        }
                        if (i4 != 80) {
                            if (i4 != 83) {
                                if (i4 == 105) {
                                    return processBacksolidus_i();
                                }
                                if (i4 != 110) {
                                    if (i4 != 112) {
                                        if (i4 != 87) {
                                            if (i4 != 88) {
                                                switch (i4) {
                                                    case 49:
                                                    case 50:
                                                    case 51:
                                                    case 52:
                                                    case 53:
                                                    case 54:
                                                    case 55:
                                                    case 56:
                                                    case 57:
                                                        return processBackreference();
                                                    default:
                                                        switch (i4) {
                                                            case 99:
                                                                return processBacksolidus_c();
                                                            case 100:
                                                                break;
                                                            case 101:
                                                            case 102:
                                                                break;
                                                            case 103:
                                                                return processBacksolidus_g();
                                                            default:
                                                                switch (i4) {
                                                                    case 114:
                                                                    case 116:
                                                                    case 117:
                                                                    case 118:
                                                                    case 120:
                                                                        break;
                                                                    case 115:
                                                                    case 119:
                                                                        break;
                                                                    default:
                                                                        createParen = Token.createChar(i4);
                                                                        break;
                                                                }
                                                        }
                                                }
                                            } else {
                                                return processBacksolidus_X();
                                            }
                                        }
                                    }
                                }
                                i4 = decodeEscaped();
                                if (i4 >= 65536) {
                                    createParen = Token.createString(REUtil.decomposeToSurrogates(i4));
                                    break;
                                }
                                createParen = Token.createChar(i4);
                            }
                        }
                        int i5 = this.offset;
                        RangeToken processBacksolidus_pP = processBacksolidus_pP(this.chardata);
                        if (processBacksolidus_pP != null) {
                            createParen = processBacksolidus_pP;
                            break;
                        } else {
                            throw ex("parser.atom.5", i5);
                        }
                    }
                    Token tokenForShorthand = getTokenForShorthand(this.chardata);
                    next();
                    return tokenForShorthand;
                default:
                    throw ex("parser.atom.4", this.offset - 1);
            }
        }
        next();
        return createParen;
    }

    /* JADX WARNING: Code restructure failed: missing block: B:53:0x00ae, code lost:
        if (r11 < 0) goto L_0x00a7;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:87:0x013f, code lost:
        if (read() == 1) goto L_0x0157;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:88:0x0141, code lost:
        if (r17 != false) goto L_0x0149;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:89:0x0143, code lost:
        if (r6 == false) goto L_0x0149;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:90:0x0145, code lost:
        r5.subtractRanges(r2);
     */
    /* JADX WARNING: Code restructure failed: missing block: B:91:0x0149, code lost:
        r5 = r2;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:92:0x014a, code lost:
        r5.sortRanges();
        r5.compactRanges();
        setContext(0);
        next();
     */
    /* JADX WARNING: Code restructure failed: missing block: B:93:0x0156, code lost:
        return r5;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:95:0x015d, code lost:
        throw ex("parser.cc.2", r16.offset);
     */
    /* JADX WARNING: Removed duplicated region for block: B:101:0x016e  */
    public RangeToken parseCharacterClass(boolean z) {
        boolean z2;
        RangeToken rangeToken;
        boolean z3;
        int indexOf;
        boolean z4;
        setContext(1);
        next();
        char c = '^';
        RangeToken rangeToken2 = null;
        if (read() == 0 && this.chardata == 94) {
            next();
            if (z) {
                rangeToken = Token.createNRange();
            } else {
                rangeToken2 = Token.createRange();
                rangeToken2.addRange(0, 1114111);
                rangeToken = Token.createRange();
            }
            z2 = true;
        } else {
            rangeToken = Token.createRange();
            z2 = false;
        }
        boolean z5 = true;
        while (true) {
            int read = read();
            if (read == 1 || (read == 0 && this.chardata == 93 && !z5)) {
                break;
            }
            int i2 = this.chardata;
            if (read == 10) {
                if (i2 != 67) {
                    if (i2 != 68) {
                        if (i2 != 73) {
                            if (i2 != 80) {
                                if (!(i2 == 83 || i2 == 87)) {
                                    if (i2 != 105) {
                                        if (i2 != 112) {
                                            if (!(i2 == 115 || i2 == 119)) {
                                                if (i2 != 99) {
                                                    if (i2 != 100) {
                                                        i2 = decodeEscaped();
                                                        z3 = false;
                                                        next();
                                                        if (!z3) {
                                                            if (read() == 0 && this.chardata == 45) {
                                                                if (read != 24) {
                                                                    next();
                                                                    int read2 = read();
                                                                    if (read2 == 1) {
                                                                        throw ex("parser.cc.2", this.offset);
                                                                    } else if (read2 == 0 && this.chardata == 93) {
                                                                        if (!isSet(2) || i2 > 65535) {
                                                                            rangeToken.addRange(i2, i2);
                                                                        } else {
                                                                            addCaseInsensitiveChar(rangeToken, i2);
                                                                        }
                                                                        rangeToken.addRange(45, 45);
                                                                    } else {
                                                                        int i3 = this.chardata;
                                                                        if (read2 == 10) {
                                                                            i3 = decodeEscaped();
                                                                        }
                                                                        next();
                                                                        if (i2 > i3) {
                                                                            throw ex("parser.ope.3", this.offset - 1);
                                                                        } else if (!isSet(2) || (i2 > 65535 && i3 > 65535)) {
                                                                            rangeToken.addRange(i2, i3);
                                                                        } else {
                                                                            addCaseInsensitiveCharRange(rangeToken, i2, i3);
                                                                        }
                                                                    }
                                                                } else {
                                                                    throw ex("parser.cc.8", this.offset - 1);
                                                                }
                                                            } else if (!isSet(2) || i2 > 65535) {
                                                                rangeToken.addRange(i2, i2);
                                                            } else {
                                                                addCaseInsensitiveChar(rangeToken, i2);
                                                            }
                                                        }
                                                        if (isSet(1024) && read() == 0 && this.chardata == 44) {
                                                            next();
                                                        }
                                                        c = '^';
                                                        z5 = false;
                                                    }
                                                }
                                            }
                                        }
                                    }
                                }
                            }
                            int i4 = this.offset;
                            RangeToken processBacksolidus_pP = processBacksolidus_pP(i2);
                            if (processBacksolidus_pP != null) {
                                rangeToken.mergeRanges(processBacksolidus_pP);
                            } else {
                                throw ex("parser.atom.5", i4);
                            }
                        }
                    }
                    rangeToken.mergeRanges(getTokenForShorthand(i2));
                }
                i2 = processCIinCharacterClass(rangeToken, i2);
            } else if (read == 20) {
                indexOf = this.regex.indexOf(58, this.offset);
                if (indexOf >= 0) {
                    if (this.regex.charAt(this.offset) == c) {
                        this.offset++;
                        z4 = false;
                    } else {
                        z4 = true;
                    }
                    RangeToken range = Token.getRange(this.regex.substring(this.offset, indexOf), z4, isSet(512));
                    if (range != null) {
                        rangeToken.mergeRanges(range);
                        int i5 = indexOf + 1;
                        if (i5 < this.regexlen && this.regex.charAt(i5) == ']') {
                            this.offset = indexOf + 2;
                        }
                    } else {
                        throw ex("parser.cc.3", this.offset);
                    }
                } else {
                    throw ex("parser.cc.1", this.offset);
                }
            } else {
                if (read == 24 && !z5) {
                    if (z2) {
                        if (z) {
                            rangeToken = (RangeToken) Token.complementRanges(rangeToken);
                        } else {
                            rangeToken2.subtractRanges(rangeToken);
                            rangeToken = rangeToken2;
                        }
                        z2 = false;
                    }
                    rangeToken.subtractRanges(parseCharacterClass(false));
                    if (read() != 0 || this.chardata != 93) {
                        throw ex("parser.cc.5", this.offset);
                    }
                }
                z3 = false;
                next();
                if (!z3) {
                }
                next();
                c = '^';
                z5 = false;
            }
            z3 = true;
            next();
            if (!z3) {
            }
            next();
            c = '^';
            z5 = false;
        }
        throw ex("parser.cc.1", indexOf);
    }

    /* JADX INFO: Can't fix incorrect switch cases order, some code will duplicate */
    public Token parseFactor() {
        Token.ClosureToken closureToken;
        int i2;
        Token.ClosureToken closureToken2;
        switch (read()) {
            case 10:
                int i3 = this.chardata;
                if (i3 == 60) {
                    return processBacksolidus_lt();
                }
                if (i3 == 62) {
                    return processBacksolidus_gt();
                }
                if (i3 == 90) {
                    return processBacksolidus_Z();
                }
                if (i3 == 98) {
                    return processBacksolidus_b();
                }
                if (i3 == 122) {
                    return processBacksolidus_z();
                }
                if (i3 == 65) {
                    return processBacksolidus_A();
                }
                if (i3 == 66) {
                    return processBacksolidus_B();
                }
                break;
            case 11:
                return processCaret();
            case 12:
                return processDollar();
            case 14:
                return processLookahead();
            case 15:
                return processNegativelookahead();
            case 16:
                return processLookbehind();
            case 17:
                return processNegativelookbehind();
            case 21:
                next();
                return Token.createEmpty();
        }
        Token parseAtom = parseAtom();
        int read = read();
        if (read == 0) {
            closureToken = parseAtom;
            if (this.chardata == 123) {
                int i4 = this.offset;
                closureToken = parseAtom;
                if (i4 < this.regexlen) {
                    int i5 = i4 + 1;
                    char charAt = this.regex.charAt(i4);
                    if (charAt < '0' || charAt > '9') {
                        throw ex("parser.quantifier.1", this.offset);
                    }
                    int i6 = charAt - '0';
                    while (true) {
                        if (i5 < this.regexlen) {
                            int i7 = i5 + 1;
                            charAt = this.regex.charAt(i5);
                            if (charAt < '0' || charAt > '9') {
                                i5 = i7;
                            } else {
                                i6 = ((i6 * 10) + charAt) - 48;
                                if (i6 >= 0) {
                                    i5 = i7;
                                } else {
                                    throw ex("parser.quantifier.5", this.offset);
                                }
                            }
                        }
                    }
                    if (charAt != ',') {
                        i2 = i6;
                    } else if (i5 < this.regexlen) {
                        int i8 = i5 + 1;
                        charAt = this.regex.charAt(i5);
                        if (charAt < '0' || charAt > '9') {
                            i5 = i8;
                            i2 = -1;
                        } else {
                            int i9 = charAt - '0';
                            while (true) {
                                if (i8 < this.regexlen) {
                                    int i10 = i8 + 1;
                                    charAt = this.regex.charAt(i8);
                                    if (charAt < '0' || charAt > '9') {
                                        i8 = i10;
                                    } else {
                                        i9 = ((i9 * 10) + charAt) - 48;
                                        if (i9 >= 0) {
                                            i8 = i10;
                                        } else {
                                            throw ex("parser.quantifier.5", this.offset);
                                        }
                                    }
                                }
                            }
                            if (i6 <= i9) {
                                i2 = i9;
                                i5 = i8;
                            } else {
                                throw ex("parser.quantifier.4", this.offset);
                            }
                        }
                    } else {
                        throw ex("parser.quantifier.3", this.offset);
                    }
                    if (charAt == '}') {
                        if (checkQuestion(i5)) {
                            i5++;
                            closureToken2 = Token.createNGClosure(parseAtom);
                        } else {
                            closureToken2 = Token.createClosure(parseAtom);
                        }
                        this.offset = i5;
                        closureToken2.setMin(i6);
                        closureToken2.setMax(i2);
                        next();
                        closureToken = closureToken2;
                    } else {
                        throw ex("parser.quantifier.2", this.offset);
                    }
                }
            }
        } else if (read == 3) {
            return processStar(parseAtom);
        } else {
            if (read == 4) {
                return processPlus(parseAtom);
            }
            closureToken = parseAtom;
            if (read == 5) {
                return processQuestion(parseAtom);
            }
        }
        return closureToken;
    }

    public Token parseRegex() {
        Token parseTerm = parseTerm();
        Token.UnionToken unionToken = null;
        while (read() == 2) {
            next();
            if (unionToken == null) {
                unionToken = Token.createUnion();
                unionToken.addChild(parseTerm);
                parseTerm = unionToken;
            }
            parseTerm.addChild(parseTerm());
        }
        return parseTerm;
    }

    public RangeToken parseSetOperations() {
        RangeToken parseCharacterClass = parseCharacterClass(false);
        while (true) {
            int read = read();
            if (read == 7) {
                next();
                return parseCharacterClass;
            }
            int i2 = this.chardata;
            if ((read == 0 && (i2 == 45 || i2 == 38)) || read == 4) {
                next();
                if (read() == 9) {
                    RangeToken parseCharacterClass2 = parseCharacterClass(false);
                    if (read == 4) {
                        parseCharacterClass.mergeRanges(parseCharacterClass2);
                    } else if (i2 == 45) {
                        parseCharacterClass.subtractRanges(parseCharacterClass2);
                    } else if (i2 == 38) {
                        parseCharacterClass.intersectRanges(parseCharacterClass2);
                    } else {
                        throw new RuntimeException("ASSERT");
                    }
                } else {
                    throw ex("parser.ope.1", this.offset - 1);
                }
            } else {
                throw ex("parser.ope.2", this.offset - 1);
            }
        }
    }

    public Token parseTerm() {
        int read = read();
        if (read == 2 || read == 7 || read == 1) {
            return Token.createEmpty();
        }
        Token parseFactor = parseFactor();
        Token.UnionToken unionToken = null;
        while (true) {
            int read2 = read();
            if (read2 == 2 || read2 == 7 || read2 == 1) {
                return parseFactor;
            }
            if (unionToken == null) {
                unionToken = Token.createConcat();
                unionToken.addChild(parseFactor);
                parseFactor = unionToken;
            }
            unionToken.addChild(parseFactor());
        }
        return parseFactor;
    }

    public Token processBackreference() {
        char charAt;
        int i2;
        int i3 = this.chardata - 48;
        if (this.parennumber > i3) {
            while (true) {
                int i4 = this.offset;
                if (i4 < this.regexlen && '0' <= (charAt = this.regex.charAt(i4)) && charAt <= '9' && (i2 = (i3 * 10) + (charAt - '0')) < this.parennumber) {
                    this.offset++;
                    this.chardata = charAt;
                    i3 = i2;
                }
            }
            Token.StringToken createBackReference = Token.createBackReference(i3);
            this.hasBackReferences = true;
            if (this.references == null) {
                this.references = new Vector();
            }
            this.references.addElement(new ReferencePosition(i3, this.offset - 2));
            next();
            return createBackReference;
        }
        throw ex("parser.parse.2", this.offset - 2);
    }

    public Token processBacksolidus_A() {
        next();
        return Token.token_stringbeginning;
    }

    public Token processBacksolidus_B() {
        next();
        return Token.token_not_wordedge;
    }

    public Token processBacksolidus_C() {
        throw ex("parser.process.1", this.offset);
    }

    public Token processBacksolidus_I() {
        throw ex("parser.process.1", this.offset);
    }

    public Token processBacksolidus_X() {
        next();
        return Token.getCombiningCharacterSequence();
    }

    public Token processBacksolidus_Z() {
        next();
        return Token.token_stringend2;
    }

    public Token processBacksolidus_b() {
        next();
        return Token.token_wordedge;
    }

    public Token processBacksolidus_c() {
        int i2 = this.offset;
        if (i2 < this.regexlen) {
            String str = this.regex;
            this.offset = i2 + 1;
            char charAt = str.charAt(i2);
            if ((65504 & charAt) == 64) {
                next();
                return Token.createChar(charAt - '@');
            }
        }
        throw ex("parser.atom.1", this.offset - 1);
    }

    public Token processBacksolidus_g() {
        next();
        return Token.getGraphemePattern();
    }

    public Token processBacksolidus_gt() {
        next();
        return Token.token_wordend;
    }

    public Token processBacksolidus_i() {
        Token.CharToken createChar = Token.createChar(105);
        next();
        return createChar;
    }

    public Token processBacksolidus_lt() {
        next();
        return Token.token_wordbeginning;
    }

    public RangeToken processBacksolidus_pP(int i2) {
        next();
        if (read() == 0 && this.chardata == 123) {
            boolean z = i2 == 112;
            int i3 = this.offset;
            int indexOf = this.regex.indexOf(125, i3);
            if (indexOf >= 0) {
                String substring = this.regex.substring(i3, indexOf);
                this.offset = indexOf + 1;
                return Token.getRange(substring, z, isSet(512));
            }
            throw ex("parser.atom.3", this.offset);
        }
        throw ex("parser.atom.2", this.offset - 1);
    }

    public Token processBacksolidus_z() {
        next();
        return Token.token_stringend;
    }

    public int processCIinCharacterClass(RangeToken rangeToken, int i2) {
        return decodeEscaped();
    }

    public Token processCaret() {
        next();
        return Token.token_linebeginning;
    }

    public Token processCondition() {
        Token token;
        char charAt;
        int i2 = this.offset;
        if (i2 + 1 < this.regexlen) {
            int i3 = -1;
            char charAt2 = this.regex.charAt(i2);
            Token token2 = null;
            if ('1' > charAt2 || charAt2 > '9') {
                if (charAt2 == '?') {
                    this.offset--;
                }
                next();
                token = parseFactor();
                int i4 = token.type;
                if (i4 != 8) {
                    switch (i4) {
                        case 20:
                        case 21:
                        case 22:
                        case 23:
                            break;
                        default:
                            throw ex("parser.factor.5", this.offset);
                    }
                } else if (read() != 7) {
                    throw ex("parser.factor.1", this.offset - 1);
                }
            } else {
                int i5 = charAt2 - SheetUtil.defaultChar;
                if (this.parennumber > i5) {
                    while (true) {
                        int i6 = this.offset;
                        if (i6 + 1 < this.regexlen && '0' <= (charAt = this.regex.charAt(i6 + 1)) && charAt <= '9') {
                            int i7 = (charAt - '0') + (i5 * 10);
                            if (i7 >= this.parennumber) {
                                i3 = i7;
                                break;
                            }
                            this.offset++;
                            i5 = i7;
                        }
                    }
                    i3 = i5;
                    this.hasBackReferences = true;
                    if (this.references == null) {
                        this.references = new Vector();
                    }
                    this.references.addElement(new ReferencePosition(i5, this.offset));
                    int i8 = this.offset + 1;
                    this.offset = i8;
                    if (this.regex.charAt(i8) == ')') {
                        this.offset++;
                        token = null;
                    } else {
                        throw ex("parser.factor.1", this.offset);
                    }
                } else {
                    throw ex("parser.parse.2", this.offset);
                }
            }
            next();
            Token parseRegex = parseRegex();
            if (parseRegex.type == 2) {
                if (parseRegex.size() == 2) {
                    token2 = parseRegex.getChild(1);
                    parseRegex = parseRegex.getChild(0);
                } else {
                    throw ex("parser.factor.6", this.offset);
                }
            }
            if (read() == 7) {
                next();
                return Token.createCondition(i3, token, parseRegex, token2);
            }
            throw ex("parser.factor.1", this.offset - 1);
        }
        throw ex("parser.factor.4", i2);
    }

    public Token processDollar() {
        next();
        return Token.token_lineend;
    }

    public Token processIndependent() {
        next();
        Token.ParenToken createLook = Token.createLook(24, parseRegex());
        if (read() == 7) {
            next();
            return createLook;
        }
        throw ex("parser.factor.1", this.offset - 1);
    }

    public Token processLookahead() {
        next();
        Token.ParenToken createLook = Token.createLook(20, parseRegex());
        if (read() == 7) {
            next();
            return createLook;
        }
        throw ex("parser.factor.1", this.offset - 1);
    }

    public Token processLookbehind() {
        next();
        Token.ParenToken createLook = Token.createLook(22, parseRegex());
        if (read() == 7) {
            next();
            return createLook;
        }
        throw ex("parser.factor.1", this.offset - 1);
    }

    public Token processModifiers() {
        int optionValue;
        int optionValue2;
        int i2 = 0;
        char c = 65535;
        int i3 = 0;
        while (true) {
            int i4 = this.offset;
            if (i4 < this.regexlen && (optionValue2 = REUtil.getOptionValue((c = this.regex.charAt(i4)))) != 0) {
                i3 |= optionValue2;
                this.offset++;
            }
        }
        int i5 = this.offset;
        if (i5 < this.regexlen) {
            if (c == '-') {
                while (true) {
                    this.offset = i5 + 1;
                    int i6 = this.offset;
                    if (i6 < this.regexlen && (optionValue = REUtil.getOptionValue((c = this.regex.charAt(i6)))) != 0) {
                        i2 |= optionValue;
                        i5 = this.offset;
                    }
                }
                int i7 = this.offset;
                if (i7 >= this.regexlen) {
                    throw ex("parser.factor.2", i7 - 1);
                }
            }
            if (c == ':') {
                this.offset++;
                next();
                Token.ModifierToken createModifierGroup = Token.createModifierGroup(parseRegex(), i3, i2);
                if (read() == 7) {
                    next();
                    return createModifierGroup;
                }
                throw ex("parser.factor.1", this.offset - 1);
            } else if (c == ')') {
                this.offset++;
                next();
                return Token.createModifierGroup(parseRegex(), i3, i2);
            } else {
                throw ex("parser.factor.3", this.offset);
            }
        } else {
            throw ex("parser.factor.2", i5 - 1);
        }
    }

    public Token processNegativelookahead() {
        next();
        Token.ParenToken createLook = Token.createLook(21, parseRegex());
        if (read() == 7) {
            next();
            return createLook;
        }
        throw ex("parser.factor.1", this.offset - 1);
    }

    public Token processNegativelookbehind() {
        next();
        Token.ParenToken createLook = Token.createLook(23, parseRegex());
        if (read() == 7) {
            next();
            return createLook;
        }
        throw ex("parser.factor.1", this.offset - 1);
    }

    public Token processParen() {
        next();
        int i2 = this.parenOpened;
        this.parenOpened = i2 + 1;
        Token.ParenToken createParen = Token.createParen(parseRegex(), i2);
        if (read() == 7) {
            this.parennumber++;
            next();
            return createParen;
        }
        throw ex("parser.factor.1", this.offset - 1);
    }

    public Token processParen2() {
        next();
        Token.ParenToken createParen = Token.createParen(parseRegex(), 0);
        if (read() == 7) {
            next();
            return createParen;
        }
        throw ex("parser.factor.1", this.offset - 1);
    }

    public Token processPlus(Token token) {
        Token.ClosureToken createClosure;
        next();
        if (read() == 5) {
            next();
            createClosure = Token.createNGClosure(token);
        } else {
            createClosure = Token.createClosure(token);
        }
        return Token.createConcat(token, createClosure);
    }

    public Token processQuestion(Token token) {
        next();
        Token.UnionToken createUnion = Token.createUnion();
        if (read() == 5) {
            next();
            createUnion.addChild(Token.createEmpty());
        } else {
            createUnion.addChild(token);
            token = Token.createEmpty();
        }
        createUnion.addChild(token);
        return createUnion;
    }

    public Token processStar(Token token) {
        next();
        if (read() != 5) {
            return Token.createClosure(token);
        }
        next();
        return Token.createNGClosure(token);
    }

    public final int read() {
        return this.nexttoken;
    }

    public final void setContext(int i2) {
        this.context = i2;
    }

    public void setLocale(Locale locale) {
        ResourceBundle resourceBundle;
        if (locale != null) {
            try {
                resourceBundle = ResourceBundle.getBundle("org.apache.xerces.impl.xpath.regex.message", locale);
            } catch (MissingResourceException e2) {
                StringBuffer a = a.a("Installation Problem???  Couldn't load messages: ");
                a.append(e2.getMessage());
                throw new RuntimeException(a.toString());
            }
        } else {
            resourceBundle = ResourceBundle.getBundle("org.apache.xerces.impl.xpath.regex.message");
        }
        this.resources = resourceBundle;
    }
}
