package org.apache.xerces.impl.xs.identity;

import org.apache.xerces.impl.xpath.XPath;
import org.apache.xerces.impl.xpath.XPathException;
import org.apache.xerces.impl.xs.util.ShortListImpl;
import org.apache.xerces.util.SymbolTable;
import org.apache.xerces.util.XMLChar;
import org.apache.xerces.xni.NamespaceContext;
import org.apache.xerces.xs.ShortList;
import org.apache.xerces.xs.XSComplexTypeDefinition;
import org.apache.xerces.xs.XSTypeDefinition;
import org.apache.xmlbeans.XmlErrorCodes;

public class Field {
    public final IdentityConstraint fIdentityConstraint;
    public final XPath fXPath;

    public class Matcher extends XPathMatcher {
        public boolean fMayMatch = true;
        public final ValueStore fStore;
        public final /* synthetic */ Field this$0;

        public Matcher(Field field, XPath xPath, ValueStore valueStore) {
            super(xPath);
            this.this$0 = field;
            this.fStore = valueStore;
        }

        private ShortList convertToPrimitiveKind(ShortList shortList) {
            if (shortList != null) {
                int length = shortList.getLength();
                int i2 = 0;
                while (i2 < length) {
                    short item = shortList.item(i2);
                    if (item != convertToPrimitiveKind(item)) {
                        break;
                    }
                    i2++;
                }
                if (i2 != length) {
                    short[] sArr = new short[length];
                    for (int i3 = 0; i3 < i2; i3++) {
                        sArr[i3] = shortList.item(i3);
                    }
                    while (i2 < length) {
                        sArr[i2] = convertToPrimitiveKind(shortList.item(i2));
                        i2++;
                    }
                    return new ShortListImpl(sArr, length);
                }
            }
            return shortList;
        }

        private short convertToPrimitiveKind(short s) {
            if (s <= 20) {
                return s;
            }
            if (s <= 29) {
                return 2;
            }
            if (s <= 42) {
                return 4;
            }
            return s;
        }

        @Override // org.apache.xerces.impl.xs.identity.XPathMatcher
        public void handleContent(XSTypeDefinition xSTypeDefinition, boolean z, Object obj, short s, ShortList shortList) {
            if (xSTypeDefinition == null || (xSTypeDefinition.getTypeCategory() == 15 && ((XSComplexTypeDefinition) xSTypeDefinition).getContentType() != 1)) {
                this.fStore.reportError("cvc-id.3", new Object[]{this.this$0.fIdentityConstraint.getName(), this.this$0.fIdentityConstraint.getElementName()});
            }
            this.fMatchedString = obj;
            matched(obj, s, shortList, z);
        }

        @Override // org.apache.xerces.impl.xs.identity.XPathMatcher
        public void matched(Object obj, short s, ShortList shortList, boolean z) {
            super.matched(obj, s, shortList, z);
            if (z && this.this$0.fIdentityConstraint.getCategory() == 1) {
                this.fStore.reportError("KeyMatchesNillable", new Object[]{this.this$0.fIdentityConstraint.getElementName(), this.this$0.fIdentityConstraint.getIdentityConstraintName()});
            }
            this.fStore.addValue(this.this$0, this.fMayMatch, obj, convertToPrimitiveKind(s), convertToPrimitiveKind(shortList));
            this.fMayMatch = false;
        }
    }

    public static class XPath extends org.apache.xerces.impl.xpath.XPath {
        /* JADX WARNING: Code restructure failed: missing block: B:7:0x0019, code lost:
            r5 = r5 + 1;
         */
        public XPath(String str, SymbolTable symbolTable, NamespaceContext namespaceContext) {
            super(fixupXPath(str), symbolTable, namespaceContext);
            int i2 = 0;
            while (i2 < this.fLocationPaths.length) {
                int i3 = 0;
                while (true) {
                    XPath.LocationPath[] locationPathArr = this.fLocationPaths;
                    if (i3 >= locationPathArr[i2].steps.length) {
                        break;
                    } else if (locationPathArr[i2].steps[i3].axis.type != 2 || i3 >= locationPathArr[i2].steps.length - 1) {
                        i3++;
                    } else {
                        throw new XPathException(XmlErrorCodes.FIELDS_XPATH);
                    }
                }
            }
        }

        public static String fixupXPath(String str) {
            int length = str.length();
            boolean z = true;
            for (int i2 = 0; i2 < length; i2++) {
                char charAt = str.charAt(i2);
                if (z) {
                    if (XMLChar.isSpace(charAt)) {
                        continue;
                    } else if (charAt == '.' || charAt == '/') {
                        z = false;
                    } else if (charAt != '|') {
                        return fixupXPath2(str, i2, length);
                    }
                } else if (charAt == '|') {
                    z = true;
                }
            }
            return str;
        }

        public static String fixupXPath2(String str, int i2, int i3) {
            StringBuffer stringBuffer = new StringBuffer(i3 + 2);
            for (int i4 = 0; i4 < i2; i4++) {
                stringBuffer.append(str.charAt(i4));
            }
            stringBuffer.append("./");
            boolean z = false;
            while (i2 < i3) {
                char charAt = str.charAt(i2);
                if (z) {
                    if (!XMLChar.isSpace(charAt)) {
                        if (!(charAt == '.' || charAt == '/')) {
                            if (charAt != '|') {
                                stringBuffer.append("./");
                            }
                        }
                        z = false;
                    }
                } else if (charAt == '|') {
                    z = true;
                }
                stringBuffer.append(charAt);
                i2++;
            }
            return stringBuffer.toString();
        }
    }

    public Field(XPath xPath, IdentityConstraint identityConstraint) {
        this.fXPath = xPath;
        this.fIdentityConstraint = identityConstraint;
    }

    public XPathMatcher createMatcher(ValueStore valueStore) {
        return new Matcher(this, this.fXPath, valueStore);
    }

    public IdentityConstraint getIdentityConstraint() {
        return this.fIdentityConstraint;
    }

    public org.apache.xerces.impl.xpath.XPath getXPath() {
        return this.fXPath;
    }

    public String toString() {
        return this.fXPath.toString();
    }
}
