package org.apache.xerces.impl.xs.traversers;

import org.apache.xerces.impl.xs.SchemaGrammar;
import org.apache.xerces.impl.xs.SchemaSymbols;
import org.apache.xerces.impl.xs.XSAnnotationImpl;
import org.apache.xerces.impl.xs.XSModelGroupImpl;
import org.apache.xerces.impl.xs.XSParticleDecl;
import org.apache.xerces.impl.xs.util.XInt;
import org.apache.xerces.impl.xs.util.XSObjectListImpl;
import org.apache.xerces.util.DOMUtil;
import org.apache.xerces.xs.XSObject;
import org.w3c.dom.Element;

public abstract class XSDAbstractParticleTraverser extends XSDAbstractTraverser {
    public ParticleArray fPArray = new ParticleArray();

    public static class ParticleArray {
        public int fContextCount = 0;
        public XSParticleDecl[] fParticles = new XSParticleDecl[10];
        public int[] fPos = new int[5];

        public void addParticle(XSParticleDecl xSParticleDecl) {
            int[] iArr = this.fPos;
            int i2 = this.fContextCount;
            int i3 = iArr[i2];
            XSParticleDecl[] xSParticleDeclArr = this.fParticles;
            if (i3 == xSParticleDeclArr.length) {
                XSParticleDecl[] xSParticleDeclArr2 = new XSParticleDecl[(iArr[i2] * 2)];
                System.arraycopy(xSParticleDeclArr, 0, xSParticleDeclArr2, 0, iArr[i2]);
                this.fParticles = xSParticleDeclArr2;
            }
            XSParticleDecl[] xSParticleDeclArr3 = this.fParticles;
            int[] iArr2 = this.fPos;
            int i4 = this.fContextCount;
            int i5 = iArr2[i4];
            iArr2[i4] = i5 + 1;
            xSParticleDeclArr3[i5] = xSParticleDecl;
        }

        public int getParticleCount() {
            int[] iArr = this.fPos;
            int i2 = this.fContextCount;
            return iArr[i2] - iArr[i2 - 1];
        }

        public XSParticleDecl[] popContext() {
            int[] iArr = this.fPos;
            int i2 = this.fContextCount;
            int i3 = iArr[i2] - iArr[i2 - 1];
            XSParticleDecl[] xSParticleDeclArr = null;
            if (i3 != 0) {
                XSParticleDecl[] xSParticleDeclArr2 = new XSParticleDecl[i3];
                System.arraycopy(this.fParticles, iArr[i2 - 1], xSParticleDeclArr2, 0, i3);
                for (int i4 = this.fPos[this.fContextCount - 1]; i4 < this.fPos[this.fContextCount]; i4++) {
                    this.fParticles[i4] = null;
                }
                xSParticleDeclArr = xSParticleDeclArr2;
            }
            this.fContextCount--;
            return xSParticleDeclArr;
        }

        public void pushContext() {
            int i2 = this.fContextCount + 1;
            this.fContextCount = i2;
            int[] iArr = this.fPos;
            if (i2 == iArr.length) {
                int[] iArr2 = new int[(i2 * 2)];
                System.arraycopy(iArr, 0, iArr2, 0, i2);
                this.fPos = iArr2;
            }
            int[] iArr3 = this.fPos;
            int i3 = this.fContextCount;
            iArr3[i3] = iArr3[i3 - 1];
        }
    }

    public XSDAbstractParticleTraverser(XSDHandler xSDHandler, XSAttributeChecker xSAttributeChecker) {
        super(xSDHandler, xSAttributeChecker);
    }

    /* JADX WARNING: Removed duplicated region for block: B:15:0x0065  */
    /* JADX WARNING: Removed duplicated region for block: B:16:0x0068  */
    /* JADX WARNING: Removed duplicated region for block: B:19:0x007e  */
    /* JADX WARNING: Removed duplicated region for block: B:20:0x0087  */
    /* JADX WARNING: Removed duplicated region for block: B:23:0x00a4  */
    /* JADX WARNING: Removed duplicated region for block: B:24:0x00a7  */
    /* JADX WARNING: Removed duplicated region for block: B:27:0x00c6  */
    private XSParticleDecl traverseSeqChoice(Element element, XSDocumentInfo xSDocumentInfo, SchemaGrammar schemaGrammar, int i2, boolean z, XSObject xSObject) {
        XSAnnotationImpl xSAnnotationImpl;
        Element element2;
        Element element3;
        XSObjectListImpl xSObjectListImpl;
        XSParticleDecl xSParticleDecl;
        XSAnnotationImpl xSAnnotationImpl2;
        Object[] checkAttributes = this.fAttrChecker.checkAttributes(element, false, xSDocumentInfo);
        Element firstChildElement = DOMUtil.getFirstChildElement(element);
        if (firstChildElement == null || !DOMUtil.getLocalName(firstChildElement).equals(SchemaSymbols.ELT_ANNOTATION)) {
            String syntheticAnnotation = DOMUtil.getSyntheticAnnotation(element);
            if (syntheticAnnotation != null) {
                xSAnnotationImpl2 = traverseSyntheticAnnotation(element, syntheticAnnotation, checkAttributes, false, xSDocumentInfo);
            } else {
                element2 = firstChildElement;
                xSAnnotationImpl = null;
                this.fPArray.pushContext();
                for (element3 = element2; element3 != null; element3 = DOMUtil.getNextSiblingElement(element3)) {
                    String localName = DOMUtil.getLocalName(element3);
                    if (localName.equals(SchemaSymbols.ELT_ELEMENT)) {
                        xSParticleDecl = this.fSchemaHandler.fElementTraverser.traverseLocal(element3, xSDocumentInfo, schemaGrammar, 0, xSObject);
                    } else {
                        if (localName.equals(SchemaSymbols.ELT_GROUP)) {
                            xSParticleDecl = this.fSchemaHandler.fGroupTraverser.traverseLocal(element3, xSDocumentInfo, schemaGrammar);
                            if (hasAllContent(xSParticleDecl)) {
                                reportSchemaError("cos-all-limited.1.2", null, element3);
                            }
                        } else if (localName.equals(SchemaSymbols.ELT_CHOICE)) {
                            xSParticleDecl = traverseChoice(element3, xSDocumentInfo, schemaGrammar, 0, xSObject);
                        } else if (localName.equals(SchemaSymbols.ELT_SEQUENCE)) {
                            xSParticleDecl = traverseSequence(element3, xSDocumentInfo, schemaGrammar, 0, xSObject);
                        } else if (localName.equals(SchemaSymbols.ELT_ANY)) {
                            xSParticleDecl = this.fSchemaHandler.fWildCardTraverser.traverseAny(element3, xSDocumentInfo, schemaGrammar);
                        } else {
                            Object[] objArr = new Object[3];
                            if (z) {
                                objArr[0] = "choice";
                                objArr[1] = "(annotation?, (element | group | choice | sequence | any)*)";
                                objArr[2] = DOMUtil.getLocalName(element3);
                            } else {
                                objArr[0] = "sequence";
                                objArr[1] = "(annotation?, (element | group | choice | sequence | any)*)";
                                objArr[2] = DOMUtil.getLocalName(element3);
                            }
                            reportSchemaError("s4s-elt-must-match.1", objArr, element3);
                        }
                        xSParticleDecl = null;
                    }
                    if (xSParticleDecl != null) {
                        this.fPArray.addParticle(xSParticleDecl);
                    }
                }
                XInt xInt = (XInt) checkAttributes[XSAttributeChecker.ATTIDX_MINOCCURS];
                XInt xInt2 = (XInt) checkAttributes[XSAttributeChecker.ATTIDX_MAXOCCURS];
                Long l = (Long) checkAttributes[XSAttributeChecker.ATTIDX_FROMDEFAULT];
                XSModelGroupImpl xSModelGroupImpl = new XSModelGroupImpl();
                xSModelGroupImpl.fCompositor = !z ? (short) 101 : 102;
                xSModelGroupImpl.fParticleCount = this.fPArray.getParticleCount();
                xSModelGroupImpl.fParticles = this.fPArray.popContext();
                if (xSAnnotationImpl == null) {
                    xSObjectListImpl = new XSObjectListImpl();
                    xSObjectListImpl.addXSObject(xSAnnotationImpl);
                } else {
                    xSObjectListImpl = XSObjectListImpl.EMPTY_LIST;
                }
                xSModelGroupImpl.fAnnotations = xSObjectListImpl;
                XSParticleDecl xSParticleDecl2 = new XSParticleDecl();
                xSParticleDecl2.fType = 3;
                xSParticleDecl2.fMinOccurs = xInt.intValue();
                xSParticleDecl2.fMaxOccurs = xInt2.intValue();
                xSParticleDecl2.fValue = xSModelGroupImpl;
                xSParticleDecl2.fAnnotations = xSObjectListImpl;
                XSParticleDecl checkOccurrences = checkOccurrences(xSParticleDecl2, !z ? SchemaSymbols.ELT_CHOICE : SchemaSymbols.ELT_SEQUENCE, (Element) element.getParentNode(), i2, l.longValue());
                this.fAttrChecker.returnAttrArray(checkAttributes, xSDocumentInfo);
                return checkOccurrences;
            }
        } else {
            xSAnnotationImpl2 = traverseAnnotationDecl(firstChildElement, checkAttributes, false, xSDocumentInfo);
            firstChildElement = DOMUtil.getNextSiblingElement(firstChildElement);
        }
        xSAnnotationImpl = xSAnnotationImpl2;
        element2 = firstChildElement;
        this.fPArray.pushContext();
        while (element3 != null) {
        }
        XInt xInt3 = (XInt) checkAttributes[XSAttributeChecker.ATTIDX_MINOCCURS];
        XInt xInt22 = (XInt) checkAttributes[XSAttributeChecker.ATTIDX_MAXOCCURS];
        Long l2 = (Long) checkAttributes[XSAttributeChecker.ATTIDX_FROMDEFAULT];
        XSModelGroupImpl xSModelGroupImpl2 = new XSModelGroupImpl();
        xSModelGroupImpl2.fCompositor = !z ? (short) 101 : 102;
        xSModelGroupImpl2.fParticleCount = this.fPArray.getParticleCount();
        xSModelGroupImpl2.fParticles = this.fPArray.popContext();
        if (xSAnnotationImpl == null) {
        }
        xSModelGroupImpl2.fAnnotations = xSObjectListImpl;
        XSParticleDecl xSParticleDecl22 = new XSParticleDecl();
        xSParticleDecl22.fType = 3;
        xSParticleDecl22.fMinOccurs = xInt3.intValue();
        xSParticleDecl22.fMaxOccurs = xInt22.intValue();
        xSParticleDecl22.fValue = xSModelGroupImpl2;
        xSParticleDecl22.fAnnotations = xSObjectListImpl;
        XSParticleDecl checkOccurrences2 = checkOccurrences(xSParticleDecl22, !z ? SchemaSymbols.ELT_CHOICE : SchemaSymbols.ELT_SEQUENCE, (Element) element.getParentNode(), i2, l2.longValue());
        this.fAttrChecker.returnAttrArray(checkAttributes, xSDocumentInfo);
        return checkOccurrences2;
    }

    public boolean hasAllContent(XSParticleDecl xSParticleDecl) {
        return xSParticleDecl != null && xSParticleDecl.fType == 3 && ((XSModelGroupImpl) xSParticleDecl.fValue).fCompositor == 103;
    }

    /* JADX WARNING: Removed duplicated region for block: B:15:0x0075  */
    /* JADX WARNING: Removed duplicated region for block: B:16:0x007e  */
    /* JADX WARNING: Removed duplicated region for block: B:19:0x00b6  */
    public XSParticleDecl traverseAll(Element element, XSDocumentInfo xSDocumentInfo, SchemaGrammar schemaGrammar, int i2, XSObject xSObject) {
        XSAnnotationImpl xSAnnotationImpl;
        Element element2;
        Element element3;
        XSObjectListImpl xSObjectListImpl;
        XSParticleDecl xSParticleDecl;
        XSAnnotationImpl xSAnnotationImpl2;
        Object[] checkAttributes = this.fAttrChecker.checkAttributes(element, false, xSDocumentInfo);
        Element firstChildElement = DOMUtil.getFirstChildElement(element);
        if (firstChildElement == null || !DOMUtil.getLocalName(firstChildElement).equals(SchemaSymbols.ELT_ANNOTATION)) {
            String syntheticAnnotation = DOMUtil.getSyntheticAnnotation(element);
            if (syntheticAnnotation != null) {
                xSAnnotationImpl2 = traverseSyntheticAnnotation(element, syntheticAnnotation, checkAttributes, false, xSDocumentInfo);
            } else {
                element2 = firstChildElement;
                xSAnnotationImpl = null;
                this.fPArray.pushContext();
                for (element3 = element2; element3 != null; element3 = DOMUtil.getNextSiblingElement(element3)) {
                    if (DOMUtil.getLocalName(element3).equals(SchemaSymbols.ELT_ELEMENT)) {
                        xSParticleDecl = this.fSchemaHandler.fElementTraverser.traverseLocal(element3, xSDocumentInfo, schemaGrammar, 1, xSObject);
                    } else {
                        reportSchemaError("s4s-elt-must-match.1", new Object[]{"all", "(annotation?, element*)", DOMUtil.getLocalName(element3)}, element3);
                        xSParticleDecl = null;
                    }
                    if (xSParticleDecl != null) {
                        this.fPArray.addParticle(xSParticleDecl);
                    }
                }
                XInt xInt = (XInt) checkAttributes[XSAttributeChecker.ATTIDX_MINOCCURS];
                XInt xInt2 = (XInt) checkAttributes[XSAttributeChecker.ATTIDX_MAXOCCURS];
                Long l = (Long) checkAttributes[XSAttributeChecker.ATTIDX_FROMDEFAULT];
                XSModelGroupImpl xSModelGroupImpl = new XSModelGroupImpl();
                xSModelGroupImpl.fCompositor = 103;
                xSModelGroupImpl.fParticleCount = this.fPArray.getParticleCount();
                xSModelGroupImpl.fParticles = this.fPArray.popContext();
                if (xSAnnotationImpl == null) {
                    xSObjectListImpl = new XSObjectListImpl();
                    xSObjectListImpl.addXSObject(xSAnnotationImpl);
                } else {
                    xSObjectListImpl = XSObjectListImpl.EMPTY_LIST;
                }
                xSModelGroupImpl.fAnnotations = xSObjectListImpl;
                XSParticleDecl xSParticleDecl2 = new XSParticleDecl();
                xSParticleDecl2.fType = 3;
                xSParticleDecl2.fMinOccurs = xInt.intValue();
                xSParticleDecl2.fMaxOccurs = xInt2.intValue();
                xSParticleDecl2.fValue = xSModelGroupImpl;
                xSParticleDecl2.fAnnotations = xSObjectListImpl;
                XSParticleDecl checkOccurrences = checkOccurrences(xSParticleDecl2, SchemaSymbols.ELT_ALL, (Element) element.getParentNode(), i2, l.longValue());
                this.fAttrChecker.returnAttrArray(checkAttributes, xSDocumentInfo);
                return checkOccurrences;
            }
        } else {
            xSAnnotationImpl2 = traverseAnnotationDecl(firstChildElement, checkAttributes, false, xSDocumentInfo);
            firstChildElement = DOMUtil.getNextSiblingElement(firstChildElement);
        }
        xSAnnotationImpl = xSAnnotationImpl2;
        element2 = firstChildElement;
        this.fPArray.pushContext();
        while (element3 != null) {
        }
        XInt xInt3 = (XInt) checkAttributes[XSAttributeChecker.ATTIDX_MINOCCURS];
        XInt xInt22 = (XInt) checkAttributes[XSAttributeChecker.ATTIDX_MAXOCCURS];
        Long l2 = (Long) checkAttributes[XSAttributeChecker.ATTIDX_FROMDEFAULT];
        XSModelGroupImpl xSModelGroupImpl2 = new XSModelGroupImpl();
        xSModelGroupImpl2.fCompositor = 103;
        xSModelGroupImpl2.fParticleCount = this.fPArray.getParticleCount();
        xSModelGroupImpl2.fParticles = this.fPArray.popContext();
        if (xSAnnotationImpl == null) {
        }
        xSModelGroupImpl2.fAnnotations = xSObjectListImpl;
        XSParticleDecl xSParticleDecl22 = new XSParticleDecl();
        xSParticleDecl22.fType = 3;
        xSParticleDecl22.fMinOccurs = xInt3.intValue();
        xSParticleDecl22.fMaxOccurs = xInt22.intValue();
        xSParticleDecl22.fValue = xSModelGroupImpl2;
        xSParticleDecl22.fAnnotations = xSObjectListImpl;
        XSParticleDecl checkOccurrences2 = checkOccurrences(xSParticleDecl22, SchemaSymbols.ELT_ALL, (Element) element.getParentNode(), i2, l2.longValue());
        this.fAttrChecker.returnAttrArray(checkAttributes, xSDocumentInfo);
        return checkOccurrences2;
    }

    public XSParticleDecl traverseChoice(Element element, XSDocumentInfo xSDocumentInfo, SchemaGrammar schemaGrammar, int i2, XSObject xSObject) {
        return traverseSeqChoice(element, xSDocumentInfo, schemaGrammar, i2, true, xSObject);
    }

    public XSParticleDecl traverseSequence(Element element, XSDocumentInfo xSDocumentInfo, SchemaGrammar schemaGrammar, int i2, XSObject xSObject) {
        return traverseSeqChoice(element, xSDocumentInfo, schemaGrammar, i2, false, xSObject);
    }
}
