package org.apache.xerces.parsers;

import java.io.StringReader;
import java.util.ArrayList;
import java.util.Locale;
import java.util.Stack;
import java.util.StringTokenizer;
import org.apache.xerces.dom.DOMErrorImpl;
import org.apache.xerces.dom.DOMMessageFormatter;
import org.apache.xerces.dom.DOMStringListImpl;
import org.apache.xerces.impl.Constants;
import org.apache.xerces.parsers.AbstractDOMParser;
import org.apache.xerces.util.DOMEntityResolverWrapper;
import org.apache.xerces.util.DOMErrorHandlerWrapper;
import org.apache.xerces.util.DOMUtil;
import org.apache.xerces.util.SymbolTable;
import org.apache.xerces.util.XMLSymbols;
import org.apache.xerces.xni.Augmentations;
import org.apache.xerces.xni.NamespaceContext;
import org.apache.xerces.xni.QName;
import org.apache.xerces.xni.XMLAttributes;
import org.apache.xerces.xni.XMLDTDContentModelHandler;
import org.apache.xerces.xni.XMLDTDHandler;
import org.apache.xerces.xni.XMLDocumentHandler;
import org.apache.xerces.xni.XMLLocator;
import org.apache.xerces.xni.XMLResourceIdentifier;
import org.apache.xerces.xni.XMLString;
import org.apache.xerces.xni.grammars.XMLGrammarPool;
import org.apache.xerces.xni.parser.XMLConfigurationException;
import org.apache.xerces.xni.parser.XMLDTDContentModelSource;
import org.apache.xerces.xni.parser.XMLDTDSource;
import org.apache.xerces.xni.parser.XMLDocumentSource;
import org.apache.xerces.xni.parser.XMLEntityResolver;
import org.apache.xerces.xni.parser.XMLInputSource;
import org.apache.xerces.xni.parser.XMLParseException;
import org.apache.xerces.xni.parser.XMLParserConfiguration;
import org.w3c.dom.DOMConfiguration;
import org.w3c.dom.DOMErrorHandler;
import org.w3c.dom.DOMException;
import org.w3c.dom.DOMStringList;
import org.w3c.dom.Document;
import org.w3c.dom.Element;
import org.w3c.dom.Node;
import org.w3c.dom.ls.LSException;
import org.w3c.dom.ls.LSInput;
import org.w3c.dom.ls.LSParser;
import org.w3c.dom.ls.LSParserFilter;
import org.w3c.dom.ls.LSResourceResolver;

public class DOMParserImpl extends AbstractDOMParser implements LSParser, DOMConfiguration {
    public static final boolean DEBUG = false;
    public static final String DISALLOW_DOCTYPE_DECL_FEATURE = "http://apache.org/xml/features/disallow-doctype-decl";
    public static final String DYNAMIC_VALIDATION = "http://apache.org/xml/features/validation/dynamic";
    public static final String HONOUR_ALL_SCHEMALOCATIONS = "http://apache.org/xml/features/honour-all-schemaLocations";
    public static final String NAMESPACES = "http://xml.org/sax/features/namespaces";
    public static final String NAMESPACE_GROWTH = "http://apache.org/xml/features/namespace-growth";
    public static final String NORMALIZE_DATA = "http://apache.org/xml/features/validation/schema/normalized-value";
    public static final String PSVI_AUGMENT = "http://apache.org/xml/features/validation/schema/augment-psvi";
    public static final String SYMBOL_TABLE = "http://apache.org/xml/properties/internal/symbol-table";
    public static final String TOLERATE_DUPLICATES = "http://apache.org/xml/features/internal/tolerate-duplicates";
    public static final String VALIDATION_FEATURE = "http://xml.org/sax/features/validation";
    public static final String XMLSCHEMA = "http://apache.org/xml/features/validation/schema";
    public static final String XMLSCHEMA_FULL_CHECKING = "http://apache.org/xml/features/validation/schema-full-checking";
    public AbortHandler abortHandler;
    public boolean abortNow;
    public Thread currentThread;
    public boolean fBusy;
    public boolean fNamespaceDeclarations;
    public boolean fNullFilterInUse;
    public DOMStringList fRecognizedParameters;
    public String fSchemaLocation;
    public String fSchemaType;

    /* renamed from: org.apache.xerces.parsers.DOMParserImpl$1  reason: invalid class name */
    public class AnonymousClass1 {
    }

    public static final class AbortHandler implements XMLDocumentHandler, XMLDTDHandler, XMLDTDContentModelHandler {
        public XMLDocumentSource documentSource;
        public XMLDTDContentModelSource dtdContentSource;
        public XMLDTDSource dtdSource;

        public AbortHandler() {
        }

        public /* synthetic */ AbortHandler(AnonymousClass1 r1) {
            this();
        }

        @Override // org.apache.xerces.xni.XMLDTDContentModelHandler
        public void any(Augmentations augmentations) {
            throw AbstractDOMParser.Abort.INSTANCE;
        }

        @Override // org.apache.xerces.xni.XMLDTDHandler
        public void attributeDecl(String str, String str2, String str3, String[] strArr, String str4, XMLString xMLString, XMLString xMLString2, Augmentations augmentations) {
            throw AbstractDOMParser.Abort.INSTANCE;
        }

        @Override // org.apache.xerces.xni.XMLDocumentHandler
        public void characters(XMLString xMLString, Augmentations augmentations) {
            throw AbstractDOMParser.Abort.INSTANCE;
        }

        @Override // org.apache.xerces.xni.XMLDocumentHandler, org.apache.xerces.xni.XMLDTDHandler
        public void comment(XMLString xMLString, Augmentations augmentations) {
            throw AbstractDOMParser.Abort.INSTANCE;
        }

        @Override // org.apache.xerces.xni.XMLDocumentHandler
        public void doctypeDecl(String str, String str2, String str3, Augmentations augmentations) {
            throw AbstractDOMParser.Abort.INSTANCE;
        }

        @Override // org.apache.xerces.xni.XMLDTDContentModelHandler
        public void element(String str, Augmentations augmentations) {
            throw AbstractDOMParser.Abort.INSTANCE;
        }

        @Override // org.apache.xerces.xni.XMLDTDHandler
        public void elementDecl(String str, String str2, Augmentations augmentations) {
            throw AbstractDOMParser.Abort.INSTANCE;
        }

        @Override // org.apache.xerces.xni.XMLDTDContentModelHandler
        public void empty(Augmentations augmentations) {
            throw AbstractDOMParser.Abort.INSTANCE;
        }

        @Override // org.apache.xerces.xni.XMLDocumentHandler
        public void emptyElement(QName qName, XMLAttributes xMLAttributes, Augmentations augmentations) {
            throw AbstractDOMParser.Abort.INSTANCE;
        }

        @Override // org.apache.xerces.xni.XMLDTDHandler
        public void endAttlist(Augmentations augmentations) {
            throw AbstractDOMParser.Abort.INSTANCE;
        }

        @Override // org.apache.xerces.xni.XMLDocumentHandler
        public void endCDATA(Augmentations augmentations) {
            throw AbstractDOMParser.Abort.INSTANCE;
        }

        @Override // org.apache.xerces.xni.XMLDTDHandler
        public void endConditional(Augmentations augmentations) {
            throw AbstractDOMParser.Abort.INSTANCE;
        }

        @Override // org.apache.xerces.xni.XMLDTDContentModelHandler
        public void endContentModel(Augmentations augmentations) {
            throw AbstractDOMParser.Abort.INSTANCE;
        }

        @Override // org.apache.xerces.xni.XMLDTDHandler
        public void endDTD(Augmentations augmentations) {
            throw AbstractDOMParser.Abort.INSTANCE;
        }

        @Override // org.apache.xerces.xni.XMLDocumentHandler
        public void endDocument(Augmentations augmentations) {
            throw AbstractDOMParser.Abort.INSTANCE;
        }

        @Override // org.apache.xerces.xni.XMLDocumentHandler
        public void endElement(QName qName, Augmentations augmentations) {
            throw AbstractDOMParser.Abort.INSTANCE;
        }

        @Override // org.apache.xerces.xni.XMLDTDHandler
        public void endExternalSubset(Augmentations augmentations) {
            throw AbstractDOMParser.Abort.INSTANCE;
        }

        @Override // org.apache.xerces.xni.XMLDocumentHandler
        public void endGeneralEntity(String str, Augmentations augmentations) {
            throw AbstractDOMParser.Abort.INSTANCE;
        }

        @Override // org.apache.xerces.xni.XMLDTDContentModelHandler
        public void endGroup(Augmentations augmentations) {
            throw AbstractDOMParser.Abort.INSTANCE;
        }

        @Override // org.apache.xerces.xni.XMLDTDHandler
        public void endParameterEntity(String str, Augmentations augmentations) {
            throw AbstractDOMParser.Abort.INSTANCE;
        }

        @Override // org.apache.xerces.xni.XMLDTDHandler
        public void externalEntityDecl(String str, XMLResourceIdentifier xMLResourceIdentifier, Augmentations augmentations) {
            throw AbstractDOMParser.Abort.INSTANCE;
        }

        @Override // org.apache.xerces.xni.XMLDTDContentModelHandler
        public XMLDTDContentModelSource getDTDContentModelSource() {
            return this.dtdContentSource;
        }

        @Override // org.apache.xerces.xni.XMLDTDHandler
        public XMLDTDSource getDTDSource() {
            return this.dtdSource;
        }

        @Override // org.apache.xerces.xni.XMLDocumentHandler
        public XMLDocumentSource getDocumentSource() {
            return this.documentSource;
        }

        @Override // org.apache.xerces.xni.XMLDocumentHandler
        public void ignorableWhitespace(XMLString xMLString, Augmentations augmentations) {
            throw AbstractDOMParser.Abort.INSTANCE;
        }

        @Override // org.apache.xerces.xni.XMLDTDHandler
        public void ignoredCharacters(XMLString xMLString, Augmentations augmentations) {
            throw AbstractDOMParser.Abort.INSTANCE;
        }

        @Override // org.apache.xerces.xni.XMLDTDHandler
        public void internalEntityDecl(String str, XMLString xMLString, XMLString xMLString2, Augmentations augmentations) {
            throw AbstractDOMParser.Abort.INSTANCE;
        }

        @Override // org.apache.xerces.xni.XMLDTDHandler
        public void notationDecl(String str, XMLResourceIdentifier xMLResourceIdentifier, Augmentations augmentations) {
            throw AbstractDOMParser.Abort.INSTANCE;
        }

        @Override // org.apache.xerces.xni.XMLDTDContentModelHandler
        public void occurrence(short s, Augmentations augmentations) {
            throw AbstractDOMParser.Abort.INSTANCE;
        }

        @Override // org.apache.xerces.xni.XMLDTDContentModelHandler
        public void pcdata(Augmentations augmentations) {
            throw AbstractDOMParser.Abort.INSTANCE;
        }

        @Override // org.apache.xerces.xni.XMLDocumentHandler, org.apache.xerces.xni.XMLDTDHandler
        public void processingInstruction(String str, XMLString xMLString, Augmentations augmentations) {
            throw AbstractDOMParser.Abort.INSTANCE;
        }

        @Override // org.apache.xerces.xni.XMLDTDContentModelHandler
        public void separator(short s, Augmentations augmentations) {
            throw AbstractDOMParser.Abort.INSTANCE;
        }

        @Override // org.apache.xerces.xni.XMLDTDContentModelHandler
        public void setDTDContentModelSource(XMLDTDContentModelSource xMLDTDContentModelSource) {
            this.dtdContentSource = xMLDTDContentModelSource;
        }

        @Override // org.apache.xerces.xni.XMLDTDHandler
        public void setDTDSource(XMLDTDSource xMLDTDSource) {
            this.dtdSource = xMLDTDSource;
        }

        @Override // org.apache.xerces.xni.XMLDocumentHandler
        public void setDocumentSource(XMLDocumentSource xMLDocumentSource) {
            this.documentSource = xMLDocumentSource;
        }

        @Override // org.apache.xerces.xni.XMLDTDHandler
        public void startAttlist(String str, Augmentations augmentations) {
            throw AbstractDOMParser.Abort.INSTANCE;
        }

        @Override // org.apache.xerces.xni.XMLDocumentHandler
        public void startCDATA(Augmentations augmentations) {
            throw AbstractDOMParser.Abort.INSTANCE;
        }

        @Override // org.apache.xerces.xni.XMLDTDHandler
        public void startConditional(short s, Augmentations augmentations) {
            throw AbstractDOMParser.Abort.INSTANCE;
        }

        @Override // org.apache.xerces.xni.XMLDTDContentModelHandler
        public void startContentModel(String str, Augmentations augmentations) {
            throw AbstractDOMParser.Abort.INSTANCE;
        }

        @Override // org.apache.xerces.xni.XMLDTDHandler
        public void startDTD(XMLLocator xMLLocator, Augmentations augmentations) {
            throw AbstractDOMParser.Abort.INSTANCE;
        }

        @Override // org.apache.xerces.xni.XMLDocumentHandler
        public void startDocument(XMLLocator xMLLocator, String str, NamespaceContext namespaceContext, Augmentations augmentations) {
            throw AbstractDOMParser.Abort.INSTANCE;
        }

        @Override // org.apache.xerces.xni.XMLDocumentHandler
        public void startElement(QName qName, XMLAttributes xMLAttributes, Augmentations augmentations) {
            throw AbstractDOMParser.Abort.INSTANCE;
        }

        @Override // org.apache.xerces.xni.XMLDTDHandler
        public void startExternalSubset(XMLResourceIdentifier xMLResourceIdentifier, Augmentations augmentations) {
            throw AbstractDOMParser.Abort.INSTANCE;
        }

        @Override // org.apache.xerces.xni.XMLDocumentHandler
        public void startGeneralEntity(String str, XMLResourceIdentifier xMLResourceIdentifier, String str2, Augmentations augmentations) {
            throw AbstractDOMParser.Abort.INSTANCE;
        }

        @Override // org.apache.xerces.xni.XMLDTDContentModelHandler
        public void startGroup(Augmentations augmentations) {
            throw AbstractDOMParser.Abort.INSTANCE;
        }

        @Override // org.apache.xerces.xni.XMLDTDHandler
        public void startParameterEntity(String str, XMLResourceIdentifier xMLResourceIdentifier, String str2, Augmentations augmentations) {
            throw AbstractDOMParser.Abort.INSTANCE;
        }

        @Override // org.apache.xerces.xni.XMLDocumentHandler, org.apache.xerces.xni.XMLDTDHandler
        public void textDecl(String str, String str2, Augmentations augmentations) {
            throw AbstractDOMParser.Abort.INSTANCE;
        }

        @Override // org.apache.xerces.xni.XMLDTDHandler
        public void unparsedEntityDecl(String str, XMLResourceIdentifier xMLResourceIdentifier, String str2, Augmentations augmentations) {
            throw AbstractDOMParser.Abort.INSTANCE;
        }

        @Override // org.apache.xerces.xni.XMLDocumentHandler
        public void xmlDecl(String str, String str2, String str3, Augmentations augmentations) {
            throw AbstractDOMParser.Abort.INSTANCE;
        }
    }

    public static final class NullLSParserFilter implements LSParserFilter {
        public static final NullLSParserFilter INSTANCE = new NullLSParserFilter();

        @Override // org.w3c.dom.ls.LSParserFilter
        public short acceptNode(Node node) {
            return 1;
        }

        @Override // org.w3c.dom.ls.LSParserFilter
        public int getWhatToShow() {
            return -1;
        }

        @Override // org.w3c.dom.ls.LSParserFilter
        public short startElement(Element element) {
            return 1;
        }
    }

    public DOMParserImpl(String str, String str2) {
        this((XMLParserConfiguration) ObjectFactory.createObject("org.apache.xerces.xni.parser.XMLParserConfiguration", str));
        if (str2 == null) {
            return;
        }
        if (str2.equals(Constants.NS_DTD)) {
            this.fConfiguration.setProperty("http://java.sun.com/xml/jaxp/properties/schemaLanguage", Constants.NS_DTD);
            this.fSchemaType = Constants.NS_DTD;
        } else if (str2.equals(Constants.NS_XMLSCHEMA)) {
            this.fConfiguration.setProperty("http://java.sun.com/xml/jaxp/properties/schemaLanguage", Constants.NS_XMLSCHEMA);
        }
    }

    public DOMParserImpl(SymbolTable symbolTable) {
        this((XMLParserConfiguration) ObjectFactory.createObject("org.apache.xerces.xni.parser.XMLParserConfiguration", "org.apache.xerces.parsers.XIncludeAwareParserConfiguration"));
        this.fConfiguration.setProperty("http://apache.org/xml/properties/internal/symbol-table", symbolTable);
    }

    public DOMParserImpl(SymbolTable symbolTable, XMLGrammarPool xMLGrammarPool) {
        this((XMLParserConfiguration) ObjectFactory.createObject("org.apache.xerces.xni.parser.XMLParserConfiguration", "org.apache.xerces.parsers.XIncludeAwareParserConfiguration"));
        this.fConfiguration.setProperty("http://apache.org/xml/properties/internal/symbol-table", symbolTable);
        this.fConfiguration.setProperty("http://apache.org/xml/properties/internal/grammar-pool", xMLGrammarPool);
    }

    public DOMParserImpl(XMLParserConfiguration xMLParserConfiguration) {
        super(xMLParserConfiguration);
        this.fNamespaceDeclarations = true;
        this.fSchemaType = null;
        this.fBusy = false;
        this.abortNow = false;
        this.fSchemaLocation = null;
        this.fNullFilterInUse = false;
        this.abortHandler = null;
        this.fConfiguration.addRecognizedFeatures(new String[]{Constants.DOM_CANONICAL_FORM, Constants.DOM_CDATA_SECTIONS, Constants.DOM_CHARSET_OVERRIDES_XML_ENCODING, Constants.DOM_INFOSET, Constants.DOM_NAMESPACE_DECLARATIONS, Constants.DOM_SPLIT_CDATA, Constants.DOM_SUPPORTED_MEDIATYPES_ONLY, Constants.DOM_CERTIFIED, Constants.DOM_WELLFORMED, Constants.DOM_IGNORE_UNKNOWN_CHARACTER_DENORMALIZATIONS});
        this.fConfiguration.setFeature(AbstractDOMParser.DEFER_NODE_EXPANSION, false);
        this.fConfiguration.setFeature(Constants.DOM_NAMESPACE_DECLARATIONS, true);
        this.fConfiguration.setFeature(Constants.DOM_WELLFORMED, true);
        this.fConfiguration.setFeature("http://apache.org/xml/features/include-comments", true);
        this.fConfiguration.setFeature("http://apache.org/xml/features/dom/include-ignorable-whitespace", true);
        this.fConfiguration.setFeature("http://xml.org/sax/features/namespaces", true);
        this.fConfiguration.setFeature("http://apache.org/xml/features/validation/dynamic", false);
        this.fConfiguration.setFeature("http://apache.org/xml/features/dom/create-entity-ref-nodes", false);
        this.fConfiguration.setFeature("http://apache.org/xml/features/create-cdata-nodes", false);
        this.fConfiguration.setFeature(Constants.DOM_CANONICAL_FORM, false);
        this.fConfiguration.setFeature(Constants.DOM_CHARSET_OVERRIDES_XML_ENCODING, true);
        this.fConfiguration.setFeature(Constants.DOM_SPLIT_CDATA, true);
        this.fConfiguration.setFeature(Constants.DOM_SUPPORTED_MEDIATYPES_ONLY, false);
        this.fConfiguration.setFeature(Constants.DOM_IGNORE_UNKNOWN_CHARACTER_DENORMALIZATIONS, true);
        this.fConfiguration.setFeature(Constants.DOM_CERTIFIED, true);
        try {
            this.fConfiguration.setFeature("http://apache.org/xml/features/validation/schema/normalized-value", false);
        } catch (XMLConfigurationException unused) {
        }
    }

    public static DOMException newFeatureNotFoundError(String str) {
        return new DOMException(8, DOMMessageFormatter.formatMessage(DOMMessageFormatter.DOM_DOMAIN, "FEATURE_NOT_FOUND", new Object[]{str}));
    }

    public static DOMException newFeatureNotSupportedError(String str) {
        return new DOMException(9, DOMMessageFormatter.formatMessage(DOMMessageFormatter.DOM_DOMAIN, "FEATURE_NOT_SUPPORTED", new Object[]{str}));
    }

    public static DOMException newInvalidStateError() {
        throw new DOMException(11, DOMMessageFormatter.formatMessage(DOMMessageFormatter.DOM_DOMAIN, "INVALID_STATE_ERR", null));
    }

    public static DOMException newTypeMismatchError(String str) {
        return new DOMException(17, DOMMessageFormatter.formatMessage(DOMMessageFormatter.DOM_DOMAIN, "TYPE_MISMATCH_ERR", new Object[]{str}));
    }

    private void restoreHandlers() {
        this.fConfiguration.setDocumentHandler(this);
        this.fConfiguration.setDTDHandler(this);
        this.fConfiguration.setDTDContentModelHandler(this);
    }

    @Override // org.w3c.dom.ls.LSParser, org.apache.xerces.parsers.AbstractDOMParser
    public void abort() {
        if (this.fBusy) {
            this.fBusy = false;
            if (this.currentThread != null) {
                this.abortNow = true;
                if (this.abortHandler == null) {
                    this.abortHandler = new AbortHandler(null);
                }
                this.fConfiguration.setDocumentHandler(this.abortHandler);
                this.fConfiguration.setDTDHandler(this.abortHandler);
                this.fConfiguration.setDTDContentModelHandler(this.abortHandler);
                if (this.currentThread != Thread.currentThread()) {
                    this.currentThread.interrupt();
                    return;
                }
                throw AbstractDOMParser.Abort.INSTANCE;
            }
        }
    }

    @Override // org.w3c.dom.DOMConfiguration
    public boolean canSetParameter(String str, Object obj) {
        String str2 = "http://apache.org/xml/features/honour-all-schemaLocations";
        if (obj == null) {
            return true;
        }
        if (obj instanceof Boolean) {
            boolean booleanValue = ((Boolean) obj).booleanValue();
            if (str.equalsIgnoreCase(Constants.DOM_SUPPORTED_MEDIATYPES_ONLY) || str.equalsIgnoreCase(Constants.DOM_NORMALIZE_CHARACTERS) || str.equalsIgnoreCase(Constants.DOM_CHECK_CHAR_NORMALIZATION) || str.equalsIgnoreCase(Constants.DOM_CANONICAL_FORM)) {
                return !booleanValue;
            }
            if (str.equalsIgnoreCase(Constants.DOM_WELLFORMED) || str.equalsIgnoreCase(Constants.DOM_IGNORE_UNKNOWN_CHARACTER_DENORMALIZATIONS)) {
                return booleanValue;
            }
            if (str.equalsIgnoreCase(Constants.DOM_CDATA_SECTIONS) || str.equalsIgnoreCase(Constants.DOM_CHARSET_OVERRIDES_XML_ENCODING) || str.equalsIgnoreCase(Constants.DOM_COMMENTS) || str.equalsIgnoreCase(Constants.DOM_DATATYPE_NORMALIZATION) || str.equalsIgnoreCase(Constants.DOM_DISALLOW_DOCTYPE) || str.equalsIgnoreCase(Constants.DOM_ENTITIES) || str.equalsIgnoreCase(Constants.DOM_INFOSET) || str.equalsIgnoreCase("namespaces") || str.equalsIgnoreCase(Constants.DOM_NAMESPACE_DECLARATIONS) || str.equalsIgnoreCase(Constants.DOM_VALIDATE) || str.equalsIgnoreCase(Constants.DOM_VALIDATE_IF_SCHEMA) || str.equalsIgnoreCase(Constants.DOM_ELEMENT_CONTENT_WHITESPACE) || str.equalsIgnoreCase(Constants.DOM_XMLDECL)) {
                return true;
            }
            try {
                if (!str.equalsIgnoreCase(str2)) {
                    str2 = str.equalsIgnoreCase("http://apache.org/xml/features/namespace-growth") ? "http://apache.org/xml/features/namespace-growth" : str.equalsIgnoreCase("http://apache.org/xml/features/internal/tolerate-duplicates") ? "http://apache.org/xml/features/internal/tolerate-duplicates" : str.toLowerCase(Locale.ENGLISH);
                }
                this.fConfiguration.getFeature(str2);
                return true;
            } catch (XMLConfigurationException unused) {
                return false;
            }
        } else if (str.equalsIgnoreCase(Constants.DOM_ERROR_HANDLER)) {
            return obj instanceof DOMErrorHandler;
        } else {
            if (str.equalsIgnoreCase(Constants.DOM_RESOURCE_RESOLVER)) {
                return obj instanceof LSResourceResolver;
            }
            if (str.equalsIgnoreCase(Constants.DOM_SCHEMA_TYPE)) {
                return (obj instanceof String) && (obj.equals(Constants.NS_XMLSCHEMA) || obj.equals(Constants.NS_DTD));
            }
            if (str.equalsIgnoreCase(Constants.DOM_SCHEMA_LOCATION)) {
                return obj instanceof String;
            }
            if (str.equalsIgnoreCase(AbstractDOMParser.DOCUMENT_CLASS_NAME)) {
                return true;
            }
            try {
                this.fConfiguration.getProperty(str.toLowerCase(Locale.ENGLISH));
                return true;
            } catch (XMLConfigurationException unused2) {
                return false;
            }
        }
    }

    public XMLInputSource dom2xmlInputSource(LSInput lSInput) {
        if (lSInput.getCharacterStream() != null) {
            return new XMLInputSource(lSInput.getPublicId(), lSInput.getSystemId(), lSInput.getBaseURI(), lSInput.getCharacterStream(), "UTF-16");
        }
        if (lSInput.getByteStream() != null) {
            return new XMLInputSource(lSInput.getPublicId(), lSInput.getSystemId(), lSInput.getBaseURI(), lSInput.getByteStream(), lSInput.getEncoding());
        }
        if (lSInput.getStringData() != null && lSInput.getStringData().length() > 0) {
            return new XMLInputSource(lSInput.getPublicId(), lSInput.getSystemId(), lSInput.getBaseURI(), new StringReader(lSInput.getStringData()), "UTF-16");
        }
        if ((lSInput.getSystemId() != null && lSInput.getSystemId().length() > 0) || (lSInput.getPublicId() != null && lSInput.getPublicId().length() > 0)) {
            return new XMLInputSource(lSInput.getPublicId(), lSInput.getSystemId(), lSInput.getBaseURI());
        }
        if (this.fErrorHandler != null) {
            DOMErrorImpl dOMErrorImpl = new DOMErrorImpl();
            dOMErrorImpl.fType = "no-input-specified";
            dOMErrorImpl.fMessage = "no-input-specified";
            dOMErrorImpl.fSeverity = 3;
            this.fErrorHandler.getErrorHandler().handleError(dOMErrorImpl);
        }
        throw new LSException(81, "no-input-specified");
    }

    @Override // org.w3c.dom.ls.LSParser
    public boolean getAsync() {
        return false;
    }

    @Override // org.w3c.dom.ls.LSParser
    public boolean getBusy() {
        return this.fBusy;
    }

    @Override // org.w3c.dom.ls.LSParser
    public DOMConfiguration getDomConfig() {
        return this;
    }

    @Override // org.w3c.dom.ls.LSParser
    public LSParserFilter getFilter() {
        if (!this.fNullFilterInUse) {
            return this.fDOMFilter;
        }
        return null;
    }

    /* JADX WARNING: Code restructure failed: missing block: B:143:0x022e, code lost:
        return r9.fConfiguration.getProperty(r0);
     */
    /* JADX WARNING: Code restructure failed: missing block: B:146:0x0233, code lost:
        throw newFeatureNotFoundError(r10);
     */
    /* JADX WARNING: Failed to process nested try/catch */
    /* JADX WARNING: Missing exception handler attribute for start block: B:141:0x0228 */
    @Override // org.w3c.dom.DOMConfiguration
    public Object getParameter(String str) {
        String str2;
        XMLParserConfiguration xMLParserConfiguration;
        if (str.equalsIgnoreCase(Constants.DOM_COMMENTS)) {
            return this.fConfiguration.getFeature("http://apache.org/xml/features/include-comments") ? Boolean.TRUE : Boolean.FALSE;
        }
        if (str.equalsIgnoreCase(Constants.DOM_DATATYPE_NORMALIZATION)) {
            return this.fConfiguration.getFeature("http://apache.org/xml/features/validation/schema/normalized-value") ? Boolean.TRUE : Boolean.FALSE;
        }
        if (str.equalsIgnoreCase(Constants.DOM_ENTITIES)) {
            return this.fConfiguration.getFeature("http://apache.org/xml/features/dom/create-entity-ref-nodes") ? Boolean.TRUE : Boolean.FALSE;
        }
        if (str.equalsIgnoreCase("namespaces")) {
            return this.fConfiguration.getFeature("http://xml.org/sax/features/namespaces") ? Boolean.TRUE : Boolean.FALSE;
        }
        if (str.equalsIgnoreCase(Constants.DOM_VALIDATE)) {
            return this.fConfiguration.getFeature("http://xml.org/sax/features/validation") ? Boolean.TRUE : Boolean.FALSE;
        }
        if (str.equalsIgnoreCase(Constants.DOM_VALIDATE_IF_SCHEMA)) {
            return this.fConfiguration.getFeature("http://apache.org/xml/features/validation/dynamic") ? Boolean.TRUE : Boolean.FALSE;
        }
        if (str.equalsIgnoreCase(Constants.DOM_ELEMENT_CONTENT_WHITESPACE)) {
            return this.fConfiguration.getFeature("http://apache.org/xml/features/dom/include-ignorable-whitespace") ? Boolean.TRUE : Boolean.FALSE;
        }
        if (str.equalsIgnoreCase(Constants.DOM_DISALLOW_DOCTYPE)) {
            return this.fConfiguration.getFeature("http://apache.org/xml/features/disallow-doctype-decl") ? Boolean.TRUE : Boolean.FALSE;
        }
        if (str.equalsIgnoreCase(Constants.DOM_INFOSET)) {
            return this.fConfiguration.getFeature("http://xml.org/sax/features/namespaces") && this.fConfiguration.getFeature(Constants.DOM_NAMESPACE_DECLARATIONS) && this.fConfiguration.getFeature("http://apache.org/xml/features/include-comments") && this.fConfiguration.getFeature("http://apache.org/xml/features/dom/include-ignorable-whitespace") && !this.fConfiguration.getFeature("http://apache.org/xml/features/validation/dynamic") && !this.fConfiguration.getFeature("http://apache.org/xml/features/dom/create-entity-ref-nodes") && !this.fConfiguration.getFeature("http://apache.org/xml/features/validation/schema/normalized-value") && !this.fConfiguration.getFeature("http://apache.org/xml/features/create-cdata-nodes") ? Boolean.TRUE : Boolean.FALSE;
        } else if (str.equalsIgnoreCase(Constants.DOM_CDATA_SECTIONS)) {
            return this.fConfiguration.getFeature("http://apache.org/xml/features/create-cdata-nodes") ? Boolean.TRUE : Boolean.FALSE;
        } else {
            if (str.equalsIgnoreCase(Constants.DOM_CHECK_CHAR_NORMALIZATION) || str.equalsIgnoreCase(Constants.DOM_NORMALIZE_CHARACTERS)) {
                return Boolean.FALSE;
            }
            if (str.equalsIgnoreCase(Constants.DOM_NAMESPACE_DECLARATIONS) || str.equalsIgnoreCase(Constants.DOM_WELLFORMED) || str.equalsIgnoreCase(Constants.DOM_IGNORE_UNKNOWN_CHARACTER_DENORMALIZATIONS) || str.equalsIgnoreCase(Constants.DOM_CANONICAL_FORM) || str.equalsIgnoreCase(Constants.DOM_SUPPORTED_MEDIATYPES_ONLY) || str.equalsIgnoreCase(Constants.DOM_SPLIT_CDATA) || str.equalsIgnoreCase(Constants.DOM_CHARSET_OVERRIDES_XML_ENCODING)) {
                return this.fConfiguration.getFeature(str.toLowerCase(Locale.ENGLISH)) ? Boolean.TRUE : Boolean.FALSE;
            }
            if (str.equalsIgnoreCase(Constants.DOM_ERROR_HANDLER)) {
                DOMErrorHandlerWrapper dOMErrorHandlerWrapper = this.fErrorHandler;
                if (dOMErrorHandlerWrapper != null) {
                    return dOMErrorHandlerWrapper.getErrorHandler();
                }
                return null;
            } else if (str.equalsIgnoreCase(Constants.DOM_RESOURCE_RESOLVER)) {
                try {
                    XMLEntityResolver xMLEntityResolver = (XMLEntityResolver) this.fConfiguration.getProperty("http://apache.org/xml/properties/internal/entity-resolver");
                    if (xMLEntityResolver != null && (xMLEntityResolver instanceof DOMEntityResolverWrapper)) {
                        return ((DOMEntityResolverWrapper) xMLEntityResolver).getEntityResolver();
                    }
                } catch (XMLConfigurationException unused) {
                }
                return null;
            } else {
                if (str.equalsIgnoreCase(Constants.DOM_SCHEMA_TYPE)) {
                    xMLParserConfiguration = this.fConfiguration;
                    str2 = "http://java.sun.com/xml/jaxp/properties/schemaLanguage";
                } else if (str.equalsIgnoreCase(Constants.DOM_SCHEMA_LOCATION)) {
                    return this.fSchemaLocation;
                } else {
                    str2 = "http://apache.org/xml/properties/internal/symbol-table";
                    if (!str.equalsIgnoreCase(str2)) {
                        str2 = AbstractDOMParser.DOCUMENT_CLASS_NAME;
                        if (!str.equalsIgnoreCase(str2)) {
                            String str3 = "http://apache.org/xml/features/honour-all-schemaLocations";
                            if (!str.equalsIgnoreCase(str3)) {
                                str3 = str.equals("http://apache.org/xml/features/namespace-growth") ? "http://apache.org/xml/features/namespace-growth" : str.equals("http://apache.org/xml/features/internal/tolerate-duplicates") ? "http://apache.org/xml/features/internal/tolerate-duplicates" : str.toLowerCase(Locale.ENGLISH);
                            }
                            return this.fConfiguration.getFeature(str3) ? Boolean.TRUE : Boolean.FALSE;
                        }
                    }
                    xMLParserConfiguration = this.fConfiguration;
                }
                return xMLParserConfiguration.getProperty(str2);
            }
        }
    }

    @Override // org.w3c.dom.DOMConfiguration
    public DOMStringList getParameterNames() {
        if (this.fRecognizedParameters == null) {
            ArrayList arrayList = new ArrayList();
            arrayList.add("namespaces");
            arrayList.add(Constants.DOM_CDATA_SECTIONS);
            arrayList.add(Constants.DOM_CANONICAL_FORM);
            arrayList.add(Constants.DOM_NAMESPACE_DECLARATIONS);
            arrayList.add(Constants.DOM_SPLIT_CDATA);
            arrayList.add(Constants.DOM_ENTITIES);
            arrayList.add(Constants.DOM_VALIDATE_IF_SCHEMA);
            arrayList.add(Constants.DOM_VALIDATE);
            arrayList.add(Constants.DOM_DATATYPE_NORMALIZATION);
            arrayList.add(Constants.DOM_CHARSET_OVERRIDES_XML_ENCODING);
            arrayList.add(Constants.DOM_CHECK_CHAR_NORMALIZATION);
            arrayList.add(Constants.DOM_SUPPORTED_MEDIATYPES_ONLY);
            arrayList.add(Constants.DOM_IGNORE_UNKNOWN_CHARACTER_DENORMALIZATIONS);
            arrayList.add(Constants.DOM_NORMALIZE_CHARACTERS);
            arrayList.add(Constants.DOM_WELLFORMED);
            arrayList.add(Constants.DOM_INFOSET);
            arrayList.add(Constants.DOM_DISALLOW_DOCTYPE);
            arrayList.add(Constants.DOM_ELEMENT_CONTENT_WHITESPACE);
            arrayList.add(Constants.DOM_COMMENTS);
            arrayList.add(Constants.DOM_ERROR_HANDLER);
            arrayList.add(Constants.DOM_RESOURCE_RESOLVER);
            arrayList.add(Constants.DOM_SCHEMA_LOCATION);
            arrayList.add(Constants.DOM_SCHEMA_TYPE);
            this.fRecognizedParameters = new DOMStringListImpl(arrayList);
        }
        return this.fRecognizedParameters;
    }

    @Override // org.w3c.dom.ls.LSParser
    public Document parse(LSInput lSInput) {
        XMLInputSource dom2xmlInputSource = dom2xmlInputSource(lSInput);
        if (!this.fBusy) {
            try {
                this.currentThread = Thread.currentThread();
                this.fBusy = true;
                parse(dom2xmlInputSource);
                this.fBusy = false;
                if (this.abortNow && this.currentThread.isInterrupted()) {
                    this.abortNow = false;
                    Thread.interrupted();
                }
            } catch (Exception e2) {
                this.fBusy = false;
                if (this.abortNow && this.currentThread.isInterrupted()) {
                    Thread.interrupted();
                }
                if (this.abortNow) {
                    this.abortNow = false;
                    restoreHandlers();
                    return null;
                } else if (e2 != AbstractDOMParser.Abort.INSTANCE) {
                    if (!(e2 instanceof XMLParseException) && this.fErrorHandler != null) {
                        DOMErrorImpl dOMErrorImpl = new DOMErrorImpl();
                        dOMErrorImpl.fException = e2;
                        dOMErrorImpl.fMessage = e2.getMessage();
                        dOMErrorImpl.fSeverity = 3;
                        this.fErrorHandler.getErrorHandler().handleError(dOMErrorImpl);
                    }
                    throw ((LSException) DOMUtil.createLSException(81, e2).fillInStackTrace());
                }
            }
            Document document = getDocument();
            dropDocumentReferences();
            return document;
        }
        throw newInvalidStateError();
    }

    @Override // org.w3c.dom.ls.LSParser
    public Document parseURI(String str) {
        if (!this.fBusy) {
            XMLInputSource xMLInputSource = new XMLInputSource(null, str, null);
            try {
                this.currentThread = Thread.currentThread();
                this.fBusy = true;
                parse(xMLInputSource);
                this.fBusy = false;
                if (this.abortNow && this.currentThread.isInterrupted()) {
                    this.abortNow = false;
                    Thread.interrupted();
                }
            } catch (Exception e2) {
                this.fBusy = false;
                if (this.abortNow && this.currentThread.isInterrupted()) {
                    Thread.interrupted();
                }
                if (this.abortNow) {
                    this.abortNow = false;
                    restoreHandlers();
                    return null;
                } else if (e2 != AbstractDOMParser.Abort.INSTANCE) {
                    if (!(e2 instanceof XMLParseException) && this.fErrorHandler != null) {
                        DOMErrorImpl dOMErrorImpl = new DOMErrorImpl();
                        dOMErrorImpl.fException = e2;
                        dOMErrorImpl.fMessage = e2.getMessage();
                        dOMErrorImpl.fSeverity = 3;
                        this.fErrorHandler.getErrorHandler().handleError(dOMErrorImpl);
                    }
                    throw ((LSException) DOMUtil.createLSException(81, e2).fillInStackTrace());
                }
            }
            Document document = getDocument();
            dropDocumentReferences();
            return document;
        }
        throw newInvalidStateError();
    }

    @Override // org.w3c.dom.ls.LSParser
    public Node parseWithContext(LSInput lSInput, Node node, short s) {
        throw new DOMException(9, "Not supported");
    }

    @Override // org.apache.xerces.parsers.AbstractXMLDocumentParser, org.apache.xerces.parsers.XMLParser, org.apache.xerces.parsers.AbstractDOMParser
    public void reset() {
        super.reset();
        this.fNamespaceDeclarations = this.fConfiguration.getFeature(Constants.DOM_NAMESPACE_DECLARATIONS);
        if (this.fNullFilterInUse) {
            this.fDOMFilter = null;
            this.fNullFilterInUse = false;
        }
        Stack stack = this.fSkippedElemStack;
        if (stack != null) {
            stack.removeAllElements();
        }
        this.fRejectedElementDepth = 0;
        this.fFilterReject = false;
        this.fSchemaType = null;
    }

    @Override // org.w3c.dom.ls.LSParser
    public void setFilter(LSParserFilter lSParserFilter) {
        if (this.fBusy && lSParserFilter == null && this.fDOMFilter != null) {
            this.fNullFilterInUse = true;
            lSParserFilter = NullLSParserFilter.INSTANCE;
        }
        this.fDOMFilter = lSParserFilter;
        if (this.fSkippedElemStack == null) {
            this.fSkippedElemStack = new Stack();
        }
    }

    /* JADX WARNING: Can't wrap try/catch for region: R(5:139|140|(2:142|(2:144|(1:146)(1:147))(1:148))(1:149)|150|151) */
    /* JADX WARNING: Code restructure failed: missing block: B:141:0x02f0, code lost:
        if (r19.equalsIgnoreCase("http://apache.org/xml/features/honour-all-schemaLocations") == false) goto L_0x02f2;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:143:0x02f6, code lost:
        if (r19.equals("http://apache.org/xml/features/namespace-growth") == false) goto L_0x02f8;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:145:0x02fc, code lost:
        if (r19.equals(r5) != false) goto L_0x02fe;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:147:0x02ff, code lost:
        r5 = r4;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:148:0x0301, code lost:
        r5 = "http://apache.org/xml/features/namespace-growth";
     */
    /* JADX WARNING: Code restructure failed: missing block: B:149:0x0303, code lost:
        r5 = "http://apache.org/xml/features/honour-all-schemaLocations";
     */
    /* JADX WARNING: Code restructure failed: missing block: B:150:0x0304, code lost:
        r18.fConfiguration.getFeature(r5);
     */
    /* JADX WARNING: Code restructure failed: missing block: B:151:0x030d, code lost:
        throw newTypeMismatchError(r19);
     */
    /* JADX WARNING: Code restructure failed: missing block: B:154:0x0312, code lost:
        throw newFeatureNotFoundError(r19);
     */
    /* JADX WARNING: Failed to process nested try/catch */
    /* JADX WARNING: Missing exception handler attribute for start block: B:139:0x02ec */
    @Override // org.w3c.dom.DOMConfiguration
    public void setParameter(String str, Object obj) {
        String str2;
        XMLParserConfiguration xMLParserConfiguration;
        Object[] objArr;
        String str3;
        Object obj2 = obj;
        String str4 = "http://apache.org/xml/features/internal/tolerate-duplicates";
        if (obj2 instanceof Boolean) {
            boolean booleanValue = ((Boolean) obj2).booleanValue();
            try {
                if (str.equalsIgnoreCase(Constants.DOM_COMMENTS)) {
                    this.fConfiguration.setFeature("http://apache.org/xml/features/include-comments", booleanValue);
                } else if (str.equalsIgnoreCase(Constants.DOM_DATATYPE_NORMALIZATION)) {
                    this.fConfiguration.setFeature("http://apache.org/xml/features/validation/schema/normalized-value", booleanValue);
                } else if (str.equalsIgnoreCase(Constants.DOM_ENTITIES)) {
                    this.fConfiguration.setFeature("http://apache.org/xml/features/dom/create-entity-ref-nodes", booleanValue);
                } else if (str.equalsIgnoreCase(Constants.DOM_DISALLOW_DOCTYPE)) {
                    this.fConfiguration.setFeature("http://apache.org/xml/features/disallow-doctype-decl", booleanValue);
                } else if (str.equalsIgnoreCase(Constants.DOM_SUPPORTED_MEDIATYPES_ONLY) || str.equalsIgnoreCase(Constants.DOM_NORMALIZE_CHARACTERS) || str.equalsIgnoreCase(Constants.DOM_CHECK_CHAR_NORMALIZATION) || str.equalsIgnoreCase(Constants.DOM_CANONICAL_FORM)) {
                    if (booleanValue) {
                        throw newFeatureNotSupportedError(str);
                    }
                } else if (str.equalsIgnoreCase("namespaces")) {
                    this.fConfiguration.setFeature("http://xml.org/sax/features/namespaces", booleanValue);
                } else if (str.equalsIgnoreCase(Constants.DOM_INFOSET)) {
                    if (booleanValue) {
                        this.fConfiguration.setFeature("http://xml.org/sax/features/namespaces", true);
                        this.fConfiguration.setFeature(Constants.DOM_NAMESPACE_DECLARATIONS, true);
                        this.fConfiguration.setFeature("http://apache.org/xml/features/include-comments", true);
                        this.fConfiguration.setFeature("http://apache.org/xml/features/dom/include-ignorable-whitespace", true);
                        this.fConfiguration.setFeature("http://apache.org/xml/features/validation/dynamic", false);
                        this.fConfiguration.setFeature("http://apache.org/xml/features/dom/create-entity-ref-nodes", false);
                        this.fConfiguration.setFeature("http://apache.org/xml/features/validation/schema/normalized-value", false);
                        this.fConfiguration.setFeature("http://apache.org/xml/features/create-cdata-nodes", false);
                    }
                } else if (str.equalsIgnoreCase(Constants.DOM_CDATA_SECTIONS)) {
                    this.fConfiguration.setFeature("http://apache.org/xml/features/create-cdata-nodes", booleanValue);
                } else if (str.equalsIgnoreCase(Constants.DOM_NAMESPACE_DECLARATIONS)) {
                    this.fConfiguration.setFeature(Constants.DOM_NAMESPACE_DECLARATIONS, booleanValue);
                } else if (str.equalsIgnoreCase(Constants.DOM_WELLFORMED) || str.equalsIgnoreCase(Constants.DOM_IGNORE_UNKNOWN_CHARACTER_DENORMALIZATIONS)) {
                    if (!booleanValue) {
                        throw newFeatureNotSupportedError(str);
                    }
                } else if (str.equalsIgnoreCase(Constants.DOM_VALIDATE)) {
                    this.fConfiguration.setFeature("http://xml.org/sax/features/validation", booleanValue);
                    if (this.fSchemaType != Constants.NS_DTD) {
                        this.fConfiguration.setFeature("http://apache.org/xml/features/validation/schema", booleanValue);
                        this.fConfiguration.setFeature("http://apache.org/xml/features/validation/schema-full-checking", booleanValue);
                    }
                    if (booleanValue) {
                        this.fConfiguration.setFeature("http://apache.org/xml/features/validation/dynamic", false);
                    }
                } else if (str.equalsIgnoreCase(Constants.DOM_VALIDATE_IF_SCHEMA)) {
                    this.fConfiguration.setFeature("http://apache.org/xml/features/validation/dynamic", booleanValue);
                    if (booleanValue) {
                        this.fConfiguration.setFeature("http://xml.org/sax/features/validation", false);
                    }
                } else if (str.equalsIgnoreCase(Constants.DOM_ELEMENT_CONTENT_WHITESPACE)) {
                    this.fConfiguration.setFeature("http://apache.org/xml/features/dom/include-ignorable-whitespace", booleanValue);
                } else if (str.equalsIgnoreCase(Constants.DOM_PSVI)) {
                    this.fConfiguration.setFeature("http://apache.org/xml/features/validation/schema/augment-psvi", true);
                    this.fConfiguration.setProperty(AbstractDOMParser.DOCUMENT_CLASS_NAME, AbstractDOMParser.PSVI_DOCUMENT_CLASS_NAME);
                } else {
                    if (str.equalsIgnoreCase("http://apache.org/xml/features/honour-all-schemaLocations")) {
                        str3 = "http://apache.org/xml/features/honour-all-schemaLocations";
                    } else if (str.equals("http://apache.org/xml/features/namespace-growth")) {
                        str3 = "http://apache.org/xml/features/namespace-growth";
                    } else {
                        str3 = str4;
                        if (!str.equals(str3)) {
                            str3 = str.toLowerCase(Locale.ENGLISH);
                        }
                    }
                    this.fConfiguration.setFeature(str3, booleanValue);
                }
            } catch (XMLConfigurationException unused) {
                throw newFeatureNotFoundError(str);
            }
        } else if (str.equalsIgnoreCase(Constants.DOM_ERROR_HANDLER)) {
            if ((obj2 instanceof DOMErrorHandler) || obj2 == null) {
                try {
                    DOMErrorHandlerWrapper dOMErrorHandlerWrapper = new DOMErrorHandlerWrapper((DOMErrorHandler) obj2);
                    this.fErrorHandler = dOMErrorHandlerWrapper;
                    this.fConfiguration.setProperty("http://apache.org/xml/properties/internal/error-handler", dOMErrorHandlerWrapper);
                } catch (XMLConfigurationException unused2) {
                }
            } else {
                throw newTypeMismatchError(str);
            }
        } else if (str.equalsIgnoreCase(Constants.DOM_RESOURCE_RESOLVER)) {
            if ((obj2 instanceof LSResourceResolver) || obj2 == null) {
                this.fConfiguration.setProperty("http://apache.org/xml/properties/internal/entity-resolver", new DOMEntityResolverWrapper((LSResourceResolver) obj2));
                return;
            }
            throw newTypeMismatchError(str);
        } else if (str.equalsIgnoreCase(Constants.DOM_SCHEMA_LOCATION)) {
            if (!(obj2 instanceof String) && obj2 != null) {
                throw newTypeMismatchError(str);
            } else if (obj2 == null) {
                this.fSchemaLocation = null;
                this.fConfiguration.setProperty("http://java.sun.com/xml/jaxp/properties/schemaSource", null);
            } else {
                this.fSchemaLocation = (String) obj2;
                StringTokenizer stringTokenizer = new StringTokenizer(this.fSchemaLocation, " \n\t\r");
                if (stringTokenizer.hasMoreTokens()) {
                    ArrayList arrayList = new ArrayList();
                    do {
                        arrayList.add(stringTokenizer.nextToken());
                    } while (stringTokenizer.hasMoreTokens());
                    xMLParserConfiguration = this.fConfiguration;
                    objArr = arrayList.toArray();
                } else {
                    xMLParserConfiguration = this.fConfiguration;
                    objArr = obj2;
                }
                xMLParserConfiguration.setProperty("http://java.sun.com/xml/jaxp/properties/schemaSource", objArr);
            }
        } else if (str.equalsIgnoreCase(Constants.DOM_SCHEMA_TYPE)) {
            if (!(obj2 instanceof String) && obj2 != null) {
                throw newTypeMismatchError(str);
            } else if (obj2 == null) {
                this.fConfiguration.setFeature("http://apache.org/xml/features/validation/schema", false);
                this.fConfiguration.setFeature("http://apache.org/xml/features/validation/schema-full-checking", false);
                this.fConfiguration.setProperty("http://java.sun.com/xml/jaxp/properties/schemaLanguage", null);
                this.fSchemaType = null;
            } else {
                if (obj2.equals(Constants.NS_XMLSCHEMA)) {
                    this.fConfiguration.setFeature("http://apache.org/xml/features/validation/schema", true);
                    this.fConfiguration.setFeature("http://apache.org/xml/features/validation/schema-full-checking", true);
                    this.fConfiguration.setProperty("http://java.sun.com/xml/jaxp/properties/schemaLanguage", Constants.NS_XMLSCHEMA);
                    str2 = Constants.NS_XMLSCHEMA;
                } else if (obj2.equals(Constants.NS_DTD)) {
                    this.fConfiguration.setFeature("http://apache.org/xml/features/validation/schema", false);
                    this.fConfiguration.setFeature("http://apache.org/xml/features/validation/schema-full-checking", false);
                    this.fConfiguration.setProperty("http://java.sun.com/xml/jaxp/properties/schemaLanguage", Constants.NS_DTD);
                    str2 = Constants.NS_DTD;
                } else {
                    return;
                }
                this.fSchemaType = str2;
            }
        } else if (str.equalsIgnoreCase(AbstractDOMParser.DOCUMENT_CLASS_NAME)) {
            this.fConfiguration.setProperty(AbstractDOMParser.DOCUMENT_CLASS_NAME, obj2);
        } else {
            String lowerCase = str.toLowerCase(Locale.ENGLISH);
            this.fConfiguration.setProperty(lowerCase, obj2);
        }
    }

    @Override // org.apache.xerces.xni.XMLDocumentHandler, org.apache.xerces.parsers.AbstractXMLDocumentParser, org.apache.xerces.parsers.AbstractDOMParser
    public void startElement(QName qName, XMLAttributes xMLAttributes, Augmentations augmentations) {
        if (!this.fNamespaceDeclarations && this.fNamespaceAware) {
            for (int length = xMLAttributes.getLength() - 1; length >= 0; length--) {
                if (XMLSymbols.PREFIX_XMLNS == xMLAttributes.getPrefix(length) || XMLSymbols.PREFIX_XMLNS == xMLAttributes.getQName(length)) {
                    xMLAttributes.removeAttributeAt(length);
                }
            }
        }
        super.startElement(qName, xMLAttributes, augmentations);
    }
}
