package org.apache.xmlbeans.impl.common;

import java.io.IOException;
import java.io.InputStream;
import java.io.OutputStream;

public abstract class PushedInputStream extends InputStream {
    public static int defaultBufferSize = 2048;
    public byte[] buf;
    public int marklimit;
    public int markpos;
    public OutputStream outputStream;
    public int readpos;
    public int writepos;

    public PushedInputStream() {
        this(defaultBufferSize);
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    /* JADX WARNING: Removed duplicated region for block: B:14:0x0038  */
    /* JADX WARNING: Removed duplicated region for block: B:19:? A[RETURN, SYNTHETIC] */
    private void shift(int i2) {
        int i3 = this.readpos;
        int i4 = this.markpos;
        if (i4 > 0) {
            if (i3 - i4 > this.marklimit) {
                this.markpos = -1;
            } else {
                i3 = i4;
            }
        }
        int i5 = this.writepos - i3;
        if (i3 > 0) {
            byte[] bArr = this.buf;
            if (bArr.length - i5 >= i2 && i5 <= i2) {
                System.arraycopy(bArr, i3, bArr, 0, i5);
                if (i3 <= 0) {
                    this.readpos -= i3;
                    int i6 = this.markpos;
                    if (i6 > 0) {
                        this.markpos = i6 - i3;
                    }
                    this.writepos -= i3;
                    return;
                }
                return;
            }
        }
        byte[] bArr2 = new byte[Math.max(this.buf.length << 1, i2 + i5)];
        System.arraycopy(this.buf, i3, bArr2, 0, i5);
        this.buf = bArr2;
        if (i3 <= 0) {
        }
    }

    @Override // java.io.InputStream
    public synchronized int available() {
        return this.writepos - this.readpos;
    }

    public abstract void fill(int i2);

    public final OutputStream getOutputStream() {
        return this.outputStream;
    }

    public synchronized void mark(int i2) {
        this.marklimit = i2;
        this.markpos = this.readpos;
    }

    public boolean markSupported() {
        return true;
    }

    @Override // java.io.InputStream
    public synchronized int read() {
        if (this.readpos >= this.writepos) {
            fill(1);
            if (this.readpos >= this.writepos) {
                return -1;
            }
        }
        byte[] bArr = this.buf;
        int i2 = this.readpos;
        this.readpos = i2 + 1;
        return bArr[i2] & 255;
    }

    @Override // java.io.InputStream
    public synchronized void reset() {
        if (this.markpos >= 0) {
            this.readpos = this.markpos;
        } else {
            throw new IOException("Resetting to invalid mark");
        }
    }

    @Override // java.io.InputStream
    public synchronized long skip(long j) {
        if (j <= 0) {
            return 0;
        }
        long j2 = (long) (this.writepos - this.readpos);
        if (j2 < j) {
            long j3 = j - j2;
            if (j3 > 2147483647L) {
                j3 = 2147483647L;
            }
            fill((int) j3);
            j2 = (long) (this.writepos - this.readpos);
            if (j2 <= 0) {
                return 0;
            }
        }
        if (j2 < j) {
            j = j2;
        }
        this.readpos = (int) (((long) this.readpos) + j);
        return j;
    }

    public PushedInputStream(int i2) {
        this.markpos = -1;
        this.outputStream = new InternalOutputStream();
        if (i2 >= 0) {
            this.buf = new byte[i2];
            return;
        }
        throw new IllegalArgumentException("Negative initial buffer size");
    }

    public class InternalOutputStream extends OutputStream {
        public InternalOutputStream() {
        }

        @Override // java.io.OutputStream
        public synchronized void write(int i2) {
            if (PushedInputStream.this.writepos + 1 > PushedInputStream.this.buf.length) {
                PushedInputStream.this.shift(1);
            }
            PushedInputStream.this.buf[PushedInputStream.this.writepos] = (byte) i2;
            PushedInputStream.this.writepos++;
        }

        @Override // java.io.OutputStream
        public synchronized void write(byte[] bArr, int i2, int i3) {
            int i4;
            if (i2 >= 0) {
                if (i2 <= bArr.length && i3 >= 0 && (i4 = i2 + i3) <= bArr.length && i4 >= 0) {
                    if (i3 != 0) {
                        if (PushedInputStream.this.writepos + i3 > PushedInputStream.this.buf.length) {
                            PushedInputStream.this.shift(i3);
                        }
                        System.arraycopy(bArr, i2, PushedInputStream.this.buf, PushedInputStream.this.writepos, i3);
                        PushedInputStream.this.writepos += i3;
                        return;
                    }
                    return;
                }
            }
            throw new IndexOutOfBoundsException();
        }
    }

    @Override // java.io.InputStream
    public synchronized int read(byte[] bArr, int i2, int i3) {
        int i4 = this.writepos - this.readpos;
        if (i4 < i3) {
            fill(i3 - i4);
            i4 = this.writepos - this.readpos;
            if (i4 <= 0) {
                return -1;
            }
        }
        if (i4 < i3) {
            i3 = i4;
        }
        System.arraycopy(this.buf, this.readpos, bArr, i2, i3);
        this.readpos += i3;
        return i3;
    }
}
