package org.apache.xmlbeans.impl.jam.internal;

import b.b.a.a.a;
import java.io.File;
import java.io.IOException;
import java.util.ArrayList;
import java.util.List;
import java.util.StringTokenizer;
import java.util.Vector;
import org.apache.poi.util.LittleEndianCP950Reader;
import org.apache.xmlbeans.impl.common.JarHelper;
import org.apache.xmlbeans.impl.jam.provider.JamLogger;

public class DirectoryScanner {
    public boolean mCaseSensitive = true;
    public Vector mDirsIncluded;
    public List mExcludeList = null;
    public String[] mExcludes;
    public Vector mFilesIncluded;
    public List mIncludeList = null;
    public String[] mIncludedFilesCache = null;
    public String[] mIncludes;
    public boolean mIsDirty = false;
    public JamLogger mLogger;
    public File mRoot;

    public DirectoryScanner(File file, JamLogger jamLogger) {
        if (jamLogger != null) {
            this.mLogger = jamLogger;
            this.mRoot = file;
            return;
        }
        throw new IllegalArgumentException("null logger");
    }

    private boolean couldHoldIncluded(String str) {
        int i2 = 0;
        while (true) {
            String[] strArr = this.mIncludes;
            if (i2 >= strArr.length) {
                return false;
            }
            if (matchPatternStart(strArr[i2], str, this.mCaseSensitive)) {
                return true;
            }
            i2++;
        }
    }

    private boolean isExcluded(String str) {
        int i2 = 0;
        while (true) {
            String[] strArr = this.mExcludes;
            if (i2 >= strArr.length) {
                return false;
            }
            if (matchPath(strArr[i2], str, this.mCaseSensitive)) {
                return true;
            }
            i2++;
        }
    }

    private boolean isIncluded(String str) {
        int i2 = 0;
        while (true) {
            String[] strArr = this.mIncludes;
            if (i2 >= strArr.length) {
                return false;
            }
            if (matchPath(strArr[i2], str, this.mCaseSensitive)) {
                return true;
            }
            i2++;
        }
    }

    /* JADX WARNING: Removed duplicated region for block: B:43:0x0070 A[LOOP:3: B:43:0x0070->B:47:0x0077, LOOP_START, PHI: r6 
      PHI: (r6v14 int) = (r6v5 int), (r6v15 int) binds: [B:42:0x006e, B:47:0x0077] A[DONT_GENERATE, DONT_INLINE]] */
    /* JADX WARNING: Removed duplicated region for block: B:49:0x007b A[LOOP:4: B:49:0x007b->B:61:0x0099, LOOP_START, PHI: r2 r4 
      PHI: (r2v2 int) = (r2v1 int), (r2v3 int) binds: [B:42:0x006e, B:61:0x0099] A[DONT_GENERATE, DONT_INLINE]
      PHI: (r4v2 int) = (r4v1 int), (r4v3 int) binds: [B:42:0x006e, B:61:0x0099] A[DONT_GENERATE, DONT_INLINE]] */
    /* JADX WARNING: Removed duplicated region for block: B:63:0x00a0 A[LOOP:5: B:63:0x00a0->B:67:0x00a7, LOOP_START, PHI: r6 
      PHI: (r6v12 int) = (r6v5 int), (r6v13 int) binds: [B:62:0x009e, B:67:0x00a7] A[DONT_GENERATE, DONT_INLINE]] */
    /* JADX WARNING: Removed duplicated region for block: B:69:0x00ab A[LOOP:6: B:69:0x00ab->B:132:0x00ab, LOOP_START, PHI: r3 r6 r7 r9 
      PHI: (r3v1 int) = (r3v0 int), (r3v2 int) binds: [B:62:0x009e, B:132:0x00ab] A[DONT_GENERATE, DONT_INLINE]
      PHI: (r6v6 int) = (r6v5 int), (r6v9 int) binds: [B:62:0x009e, B:132:0x00ab] A[DONT_GENERATE, DONT_INLINE]
      PHI: (r7v2 char) = (r7v1 char), (r7v3 char) binds: [B:62:0x009e, B:132:0x00ab] A[DONT_GENERATE, DONT_INLINE]
      PHI: (r9v2 int) = (r9v1 int), (r9v3 int) binds: [B:62:0x009e, B:132:0x00ab] A[DONT_GENERATE, DONT_INLINE]] */
    public static boolean match(String str, String str2, boolean z) {
        boolean z2;
        int i2;
        char[] charArray = str.toCharArray();
        char[] charArray2 = str2.toCharArray();
        int i3 = 1;
        int length = charArray.length - 1;
        int length2 = charArray2.length - 1;
        int i4 = 0;
        while (true) {
            if (i4 >= charArray.length) {
                z2 = false;
                break;
            } else if (charArray[i4] == '*') {
                z2 = true;
                break;
            } else {
                i4++;
            }
        }
        char c = LittleEndianCP950Reader.UNMAPPABLE;
        if (!z2) {
            if (length != length2) {
                return false;
            }
            for (int i5 = 0; i5 <= length; i5++) {
                char c2 = charArray[i5];
                if (c2 != '?') {
                    if (z && c2 != charArray2[i5]) {
                        return false;
                    }
                    if (!z && Character.toUpperCase(c2) != Character.toUpperCase(charArray2[i5])) {
                        return false;
                    }
                }
            }
            return true;
        } else if (length == 0) {
            return true;
        } else {
            int i6 = 0;
            int i7 = 0;
            while (true) {
                char c3 = charArray[i6];
                if (c3 != '*' && i7 <= length2) {
                    if (c3 != '?') {
                        if (z && c3 != charArray2[i7]) {
                            return false;
                        }
                        if (!z && Character.toUpperCase(c3) != Character.toUpperCase(charArray2[i7])) {
                            return false;
                        }
                    }
                    i6++;
                    i7++;
                } else if (i7 <= length2) {
                    while (i6 <= length) {
                        if (charArray[i6] != '*') {
                            return false;
                        }
                        i6++;
                    }
                    return true;
                } else {
                    while (true) {
                        char c4 = charArray[length];
                        if (c4 != '*' && i7 <= length2) {
                            if (c4 != '?') {
                                if (z && c4 != charArray2[length2]) {
                                    return false;
                                }
                                if (!z && Character.toUpperCase(c4) != Character.toUpperCase(charArray2[length2])) {
                                    return false;
                                }
                            }
                            length--;
                            length2--;
                        } else if (i7 <= length2) {
                            while (i6 <= length) {
                                if (charArray[i6] != '*') {
                                    return false;
                                }
                                i6++;
                            }
                            return true;
                        } else {
                            while (i6 != length && i7 <= length2) {
                                int i8 = i6 + 1;
                                int i9 = i8;
                                while (true) {
                                    if (i9 > length) {
                                        i9 = -1;
                                        break;
                                    } else if (charArray[i9] == '*') {
                                        break;
                                    } else {
                                        i9++;
                                    }
                                }
                                if (i9 == i8) {
                                    i6 = i8;
                                } else {
                                    int i10 = (i9 - i6) - i3;
                                    int i11 = (length2 - i7) + i3;
                                    int i12 = 0;
                                    while (true) {
                                        if (i12 > i11 - i10) {
                                            i2 = -1;
                                            break;
                                        }
                                        int i13 = 0;
                                        while (i13 < i10) {
                                            char c5 = charArray[i6 + i13 + 1];
                                            if (c5 == c || ((!z || c5 == charArray2[i7 + i12 + i13]) && (z || Character.toUpperCase(c5) == Character.toUpperCase(charArray2[i7 + i12 + i13])))) {
                                                i13++;
                                                c = LittleEndianCP950Reader.UNMAPPABLE;
                                            } else {
                                                i12++;
                                                c = LittleEndianCP950Reader.UNMAPPABLE;
                                            }
                                        }
                                        i2 = i7 + i12;
                                        break;
                                    }
                                    if (i2 == -1) {
                                        return false;
                                    }
                                    i7 = i2 + i10;
                                    i6 = i9;
                                    i3 = 1;
                                    c = LittleEndianCP950Reader.UNMAPPABLE;
                                }
                            }
                            while (i6 <= length) {
                                if (charArray[i6] != '*') {
                                    return false;
                                }
                                i6++;
                            }
                            return true;
                        }
                    }
                    if (i7 <= length2) {
                    }
                }
            }
            if (i7 <= length2) {
            }
        }
    }

    public static boolean matchPath(String str, String str2, boolean z) {
        int i2;
        if (str2.startsWith(File.separator) != str.startsWith(File.separator)) {
            return false;
        }
        Vector vector = tokenizePath(str);
        Vector vector2 = tokenizePath(str2);
        int i3 = 1;
        int size = vector.size() - 1;
        int size2 = vector2.size() - 1;
        int i4 = 0;
        int i5 = 0;
        while (i4 <= size && i5 <= size2) {
            String str3 = (String) vector.elementAt(i4);
            if (str3.equals("**")) {
                break;
            } else if (!match(str3, (String) vector2.elementAt(i5), z)) {
                return false;
            } else {
                i4++;
                i5++;
            }
        }
        if (i5 > size2) {
            while (i4 <= size) {
                if (!vector.elementAt(i4).equals("**")) {
                    return false;
                }
                i4++;
            }
            return true;
        } else if (i4 > size) {
            return false;
        } else {
            while (i4 <= size && i5 <= size2) {
                String str4 = (String) vector.elementAt(size);
                if (str4.equals("**")) {
                    break;
                } else if (!match(str4, (String) vector2.elementAt(size2), z)) {
                    return false;
                } else {
                    size--;
                    size2--;
                }
            }
            if (i5 > size2) {
                while (i4 <= size) {
                    if (!vector.elementAt(i4).equals("**")) {
                        return false;
                    }
                    i4++;
                }
                return true;
            }
            while (i4 != size && i5 <= size2) {
                int i6 = i4 + 1;
                int i7 = i6;
                while (true) {
                    if (i7 > size) {
                        i7 = -1;
                        break;
                    } else if (vector.elementAt(i7).equals("**")) {
                        break;
                    } else {
                        i7++;
                    }
                }
                if (i7 == i6) {
                    i4 = i6;
                } else {
                    int i8 = (i7 - i4) - i3;
                    int i9 = (size2 - i5) + i3;
                    int i10 = 0;
                    while (true) {
                        if (i10 > i9 - i8) {
                            i2 = -1;
                            break;
                        }
                        for (int i11 = 0; i11 < i8; i11++) {
                            if (!match((String) vector.elementAt(i4 + i11 + 1), (String) vector2.elementAt(i5 + i10 + i11), z)) {
                                i10++;
                            }
                        }
                        i2 = i5 + i10;
                        break;
                    }
                    if (i2 == -1) {
                        return false;
                    }
                    i5 = i2 + i8;
                    i4 = i7;
                    i3 = 1;
                }
            }
            while (i4 <= size) {
                if (!vector.elementAt(i4).equals("**")) {
                    return false;
                }
                i4++;
            }
            return true;
        }
    }

    public static boolean matchPatternStart(String str, String str2, boolean z) {
        if (str2.startsWith(File.separator) != str.startsWith(File.separator)) {
            return false;
        }
        Vector vector = tokenizePath(str);
        Vector vector2 = tokenizePath(str2);
        int size = vector.size() - 1;
        int size2 = vector2.size() - 1;
        int i2 = 0;
        int i3 = 0;
        while (i2 <= size && i3 <= size2) {
            String str3 = (String) vector.elementAt(i2);
            if (str3.equals("**")) {
                break;
            } else if (!match(str3, (String) vector2.elementAt(i3), z)) {
                return false;
            } else {
                i2++;
                i3++;
            }
        }
        if (i3 <= size2 && i2 > size) {
            return false;
        }
        return true;
    }

    private void scan() {
        if (this.mIncludes == null) {
            String[] strArr = new String[1];
            this.mIncludes = strArr;
            strArr[0] = "**";
        }
        if (this.mExcludes == null) {
            this.mExcludes = new String[0];
        }
        this.mFilesIncluded = new Vector();
        this.mDirsIncluded = new Vector();
        if (isIncluded("") && !isExcluded("")) {
            this.mDirsIncluded.addElement("");
        }
        scandir(this.mRoot, "", true);
    }

    private void scandir(File file, String str, boolean z) {
        if (this.mLogger.isVerbose(this)) {
            JamLogger jamLogger = this.mLogger;
            StringBuffer stringBuffer = new StringBuffer();
            stringBuffer.append("[DirectoryScanner] scanning dir ");
            stringBuffer.append(file);
            stringBuffer.append(" for '");
            stringBuffer.append(str);
            stringBuffer.append("'");
            jamLogger.verbose(stringBuffer.toString());
        }
        String[] list = file.list();
        if (list != null) {
            for (int i2 = 0; i2 < list.length; i2++) {
                StringBuffer a = a.a(str);
                a.append(list[i2]);
                String stringBuffer2 = a.toString();
                File file2 = new File(file, list[i2]);
                if (file2.isDirectory()) {
                    if (isIncluded(stringBuffer2) && !isExcluded(stringBuffer2)) {
                        this.mDirsIncluded.addElement(stringBuffer2);
                        if (this.mLogger.isVerbose(this)) {
                            JamLogger jamLogger2 = this.mLogger;
                            StringBuffer stringBuffer3 = new StringBuffer();
                            stringBuffer3.append("...including dir ");
                            stringBuffer3.append(stringBuffer2);
                            jamLogger2.verbose(stringBuffer3.toString());
                        }
                        StringBuffer a2 = a.a(stringBuffer2);
                        a2.append(File.separator);
                        scandir(file2, a2.toString(), z);
                    } else if (couldHoldIncluded(stringBuffer2)) {
                        StringBuffer a3 = a.a(stringBuffer2);
                        a3.append(File.separator);
                        scandir(file2, a3.toString(), z);
                    }
                } else if (file2.isFile() && isIncluded(stringBuffer2)) {
                    if (!isExcluded(stringBuffer2)) {
                        this.mFilesIncluded.addElement(stringBuffer2);
                        if (this.mLogger.isVerbose(this)) {
                            JamLogger jamLogger3 = this.mLogger;
                            StringBuffer stringBuffer4 = new StringBuffer();
                            stringBuffer4.append("...including ");
                            stringBuffer4.append(stringBuffer2);
                            stringBuffer4.append(" under '");
                            stringBuffer4.append(file);
                            jamLogger3.verbose(stringBuffer4.toString());
                        }
                    } else if (this.mLogger.isVerbose(this)) {
                        JamLogger jamLogger4 = this.mLogger;
                        StringBuffer stringBuffer5 = new StringBuffer();
                        stringBuffer5.append("...EXCLUDING ");
                        stringBuffer5.append(stringBuffer2);
                        stringBuffer5.append(" under '");
                        stringBuffer5.append(file);
                        jamLogger4.verbose(stringBuffer5.toString());
                    }
                }
            }
            return;
        }
        StringBuffer a4 = a.a("IO error scanning directory ");
        a4.append(file.getAbsolutePath());
        throw new IOException(a4.toString());
    }

    private void setExcludes(String[] strArr) {
        if (strArr == null) {
            this.mExcludes = null;
            return;
        }
        this.mExcludes = new String[strArr.length];
        for (int i2 = 0; i2 < strArr.length; i2++) {
            String replace = strArr[i2].replace(JarHelper.SEP, File.separatorChar).replace('\\', File.separatorChar);
            if (replace.endsWith(File.separator)) {
                replace = a.a(replace, "**");
            }
            this.mExcludes[i2] = replace;
        }
    }

    private void setIncludes(String[] strArr) {
        if (strArr == null) {
            this.mIncludes = null;
            return;
        }
        this.mIncludes = new String[strArr.length];
        for (int i2 = 0; i2 < strArr.length; i2++) {
            String replace = strArr[i2].replace(JarHelper.SEP, File.separatorChar).replace('\\', File.separatorChar);
            if (replace.endsWith(File.separator)) {
                replace = a.a(replace, "**");
            }
            this.mIncludes[i2] = replace;
        }
    }

    public static Vector tokenizePath(String str) {
        Vector vector = new Vector();
        StringTokenizer stringTokenizer = new StringTokenizer(str, File.separator);
        while (stringTokenizer.hasMoreTokens()) {
            vector.addElement(stringTokenizer.nextToken());
        }
        return vector;
    }

    public void exclude(String str) {
        if (this.mExcludeList == null) {
            this.mExcludeList = new ArrayList();
        }
        this.mExcludeList.add(str);
        this.mIsDirty = true;
    }

    public String[] getIncludedFiles() {
        String[] strArr;
        if (!this.mIsDirty && (strArr = this.mIncludedFilesCache) != null) {
            return strArr;
        }
        List list = this.mIncludeList;
        if (list != null) {
            String[] strArr2 = new String[list.size()];
            this.mIncludeList.toArray(strArr2);
            setIncludes(strArr2);
        } else {
            setIncludes(null);
        }
        List list2 = this.mExcludeList;
        if (list2 != null) {
            String[] strArr3 = new String[list2.size()];
            this.mExcludeList.toArray(strArr3);
            setExcludes(strArr3);
        } else {
            setExcludes(null);
        }
        scan();
        String[] strArr4 = new String[this.mFilesIncluded.size()];
        this.mIncludedFilesCache = strArr4;
        this.mFilesIncluded.copyInto(strArr4);
        return this.mIncludedFilesCache;
    }

    public File getRoot() {
        return this.mRoot;
    }

    public void include(String str) {
        if (this.mIncludeList == null) {
            this.mIncludeList = new ArrayList();
        }
        this.mIncludeList.add(str);
        this.mIsDirty = true;
    }

    public void setDirty() {
        this.mIsDirty = true;
    }
}
