package org.apache.xmlbeans.impl.jam.xml;

import b.b.a.a.a;
import java.io.InputStream;
import java.io.Reader;
import java.io.StringWriter;
import java.net.URI;
import java.net.URISyntaxException;
import java.util.ArrayList;
import org.apache.poi.javax.xml.stream.XMLInputFactory;
import org.apache.poi.javax.xml.stream.XMLStreamException;
import org.apache.poi.javax.xml.stream.XMLStreamReader;
import org.apache.poi.ss.formula.ptg.LessThanPtg;
import org.apache.xmlbeans.impl.jam.JClass;
import org.apache.xmlbeans.impl.jam.internal.CachedClassBuilder;
import org.apache.xmlbeans.impl.jam.internal.elements.ClassImpl;
import org.apache.xmlbeans.impl.jam.internal.elements.ElementContext;
import org.apache.xmlbeans.impl.jam.mutable.MAnnotatedElement;
import org.apache.xmlbeans.impl.jam.mutable.MAnnotation;
import org.apache.xmlbeans.impl.jam.mutable.MClass;
import org.apache.xmlbeans.impl.jam.mutable.MConstructor;
import org.apache.xmlbeans.impl.jam.mutable.MField;
import org.apache.xmlbeans.impl.jam.mutable.MInvokable;
import org.apache.xmlbeans.impl.jam.mutable.MMethod;
import org.apache.xmlbeans.impl.jam.mutable.MParameter;
import org.apache.xmlbeans.impl.jam.mutable.MSourcePosition;

public class JamXmlReader implements JamXmlElements {
    public CachedClassBuilder mCache;
    public ElementContext mContext;
    public XMLStreamReader mIn;

    public JamXmlReader(CachedClassBuilder cachedClassBuilder, InputStream inputStream, ElementContext elementContext) {
        this(cachedClassBuilder, XMLInputFactory.newInstance().createXMLStreamReader(inputStream), elementContext);
    }

    private boolean assertCurrentBoolean(String str) {
        assertStart(str);
        String elementText = this.mIn.getElementText();
        assertEnd(str);
        nextElement();
        return Boolean.valueOf(elementText).booleanValue();
    }

    private int assertCurrentInt(String str) {
        assertStart(str);
        String elementText = this.mIn.getElementText();
        assertEnd(str);
        nextElement();
        return Integer.valueOf(elementText).intValue();
    }

    private String assertCurrentString(String str) {
        assertStart(str);
        String elementText = this.mIn.getElementText();
        assertEnd(str);
        nextElement();
        return elementText;
    }

    private void assertEnd(String str) {
        if (!this.mIn.isEndElement() || !str.equals(getElementName())) {
            error(a.a("expected to get a </", str, ">, "));
        }
    }

    private void assertStart(String str) {
        if (!this.mIn.isStartElement() || !str.equals(getElementName())) {
            error(a.a("expected to get a <", str, ">, "));
        }
    }

    private String checkCurrentString(String str) {
        if (!str.equals(getElementName())) {
            return null;
        }
        String elementText = this.mIn.getElementText();
        assertEnd(str);
        nextElement();
        return elementText;
    }

    private void error(String str) {
        StringWriter stringWriter = new StringWriter();
        stringWriter.write(LessThanPtg.LESSTHAN);
        stringWriter.write(this.mIn.getLocalName());
        stringWriter.write("> line:");
        StringBuffer stringBuffer = new StringBuffer();
        stringBuffer.append("");
        stringBuffer.append(this.mIn.getLocation().getLineNumber());
        stringWriter.write(stringBuffer.toString());
        stringWriter.write(" col:");
        StringBuffer stringBuffer2 = new StringBuffer();
        stringBuffer2.append("");
        stringBuffer2.append(this.mIn.getLocation().getColumnNumber());
        stringWriter.write(stringBuffer2.toString());
        stringWriter.write("]");
        StringBuffer c = a.c(str, ":\n ");
        c.append(stringWriter.toString());
        throw new XMLStreamException(c.toString());
    }

    private String getElementName() {
        return this.mIn.getLocalName();
    }

    /* JADX WARNING: Removed duplicated region for block: B:2:0x0009  */
    private void nextElement() {
        while (this.mIn.next() != -1) {
            if (this.mIn.isEndElement() || this.mIn.isStartElement()) {
                return;
            }
            while (this.mIn.next() != -1) {
            }
        }
        throw new XMLStreamException("Unexpected end of file");
    }

    private void readAnnotatedElement(MAnnotatedElement mAnnotatedElement) {
        while (JamXmlElements.ANNOTATION.equals(getElementName())) {
            nextElement();
            MAnnotation addLiteralAnnotation = mAnnotatedElement.addLiteralAnnotation(assertCurrentString("name"));
            while (JamXmlElements.ANNOTATIONVALUE.equals(getElementName())) {
                nextElement();
                String assertCurrentString = assertCurrentString("name");
                JClass loadClass = this.mContext.getClassLoader().loadClass(assertCurrentString(JamXmlElements.TYPE));
                if (loadClass.isArrayType()) {
                    ArrayList arrayList = new ArrayList();
                    while ("value".equals(getElementName())) {
                        arrayList.add(assertCurrentString("value"));
                    }
                    String[] strArr = new String[arrayList.size()];
                    arrayList.toArray(strArr);
                    addLiteralAnnotation.setSimpleValue(assertCurrentString, strArr, loadClass);
                } else {
                    addLiteralAnnotation.setSimpleValue(assertCurrentString, assertCurrentString("value"), loadClass);
                }
                assertEnd(JamXmlElements.ANNOTATIONVALUE);
                nextElement();
            }
            assertEnd(JamXmlElements.ANNOTATION);
            nextElement();
        }
        if (JamXmlElements.COMMENT.equals(getElementName())) {
            mAnnotatedElement.createComment().setText(this.mIn.getElementText());
            assertEnd(JamXmlElements.COMMENT);
            nextElement();
        }
        if (JamXmlElements.SOURCEPOSITION.equals(getElementName())) {
            readSourcePosition(mAnnotatedElement);
        }
    }

    private void readClass() {
        String str;
        assertStart(JamXmlElements.CLASS);
        nextElement();
        String assertCurrentString = assertCurrentString("name");
        int lastIndexOf = assertCurrentString.lastIndexOf(46);
        if (lastIndexOf != -1) {
            str = assertCurrentString.substring(0, lastIndexOf);
            assertCurrentString = assertCurrentString.substring(lastIndexOf + 1);
        } else {
            str = "";
        }
        MClass createClassToBuild = this.mCache.createClassToBuild(str, assertCurrentString, null);
        createClassToBuild.setIsInterface(assertCurrentBoolean(JamXmlElements.ISINTERFACE));
        createClassToBuild.setModifiers(assertCurrentInt(JamXmlElements.MODIFIERS));
        String checkCurrentString = checkCurrentString(JamXmlElements.SUPERCLASS);
        if (checkCurrentString != null) {
            createClassToBuild.setSuperclass(checkCurrentString);
        }
        while (true) {
            String checkCurrentString2 = checkCurrentString(JamXmlElements.INTERFACE);
            if (checkCurrentString2 == null) {
                break;
            }
            createClassToBuild.addInterface(checkCurrentString2);
        }
        while (JamXmlElements.FIELD.equals(getElementName())) {
            readField(createClassToBuild);
        }
        while (JamXmlElements.CONSTRUCTOR.equals(getElementName())) {
            readConstructor(createClassToBuild);
        }
        while ("method".equals(getElementName())) {
            readMethod(createClassToBuild);
        }
        readAnnotatedElement(createClassToBuild);
        assertEnd(JamXmlElements.CLASS);
        ((ClassImpl) createClassToBuild).setState(6);
        nextElement();
    }

    private void readConstructor(MClass mClass) {
        assertStart(JamXmlElements.CONSTRUCTOR);
        MConstructor addNewConstructor = mClass.addNewConstructor();
        nextElement();
        readInvokableContents(addNewConstructor);
        assertEnd(JamXmlElements.CONSTRUCTOR);
        nextElement();
    }

    private void readField(MClass mClass) {
        assertStart(JamXmlElements.FIELD);
        MField addNewField = mClass.addNewField();
        nextElement();
        addNewField.setSimpleName(assertCurrentString("name"));
        addNewField.setModifiers(assertCurrentInt(JamXmlElements.MODIFIERS));
        addNewField.setType(assertCurrentString(JamXmlElements.TYPE));
        readAnnotatedElement(addNewField);
        assertEnd(JamXmlElements.FIELD);
        nextElement();
    }

    private void readInvokableContents(MInvokable mInvokable) {
        mInvokable.setModifiers(assertCurrentInt(JamXmlElements.MODIFIERS));
        while (JamXmlElements.PARAMETER.equals(getElementName())) {
            nextElement();
            MParameter addNewParameter = mInvokable.addNewParameter();
            addNewParameter.setSimpleName(assertCurrentString("name"));
            addNewParameter.setType(assertCurrentString(JamXmlElements.TYPE));
            readAnnotatedElement(addNewParameter);
            assertEnd(JamXmlElements.PARAMETER);
            nextElement();
        }
        readAnnotatedElement(mInvokable);
    }

    private void readMethod(MClass mClass) {
        assertStart("method");
        MMethod addNewMethod = mClass.addNewMethod();
        nextElement();
        addNewMethod.setSimpleName(assertCurrentString("name"));
        addNewMethod.setReturnType(assertCurrentString(JamXmlElements.RETURNTYPE));
        readInvokableContents(addNewMethod);
        assertEnd("method");
        nextElement();
    }

    private void readSourcePosition(MAnnotatedElement mAnnotatedElement) {
        assertStart(JamXmlElements.SOURCEPOSITION);
        MSourcePosition createSourcePosition = mAnnotatedElement.createSourcePosition();
        nextElement();
        if (JamXmlElements.LINE.equals(getElementName())) {
            createSourcePosition.setLine(assertCurrentInt(JamXmlElements.LINE));
        }
        if (JamXmlElements.COLUMN.equals(getElementName())) {
            createSourcePosition.setColumn(assertCurrentInt(JamXmlElements.COLUMN));
        }
        if (JamXmlElements.SOURCEURI.equals(getElementName())) {
            try {
                createSourcePosition.setSourceURI(new URI(assertCurrentString(JamXmlElements.SOURCEURI)));
            } catch (URISyntaxException e2) {
                throw new XMLStreamException(e2);
            }
        }
        assertEnd(JamXmlElements.SOURCEPOSITION);
        nextElement();
    }

    public void read() {
        nextElement();
        assertStart(JamXmlElements.JAMSERVICE);
        nextElement();
        while (JamXmlElements.CLASS.equals(getElementName())) {
            readClass();
        }
        assertEnd(JamXmlElements.JAMSERVICE);
    }

    public JamXmlReader(CachedClassBuilder cachedClassBuilder, Reader reader, ElementContext elementContext) {
        this(cachedClassBuilder, XMLInputFactory.newInstance().createXMLStreamReader(reader), elementContext);
    }

    public JamXmlReader(CachedClassBuilder cachedClassBuilder, XMLStreamReader xMLStreamReader, ElementContext elementContext) {
        if (cachedClassBuilder == null) {
            throw new IllegalArgumentException("null cache");
        } else if (xMLStreamReader == null) {
            throw new IllegalArgumentException("null cache");
        } else if (elementContext != null) {
            this.mIn = xMLStreamReader;
            this.mCache = cachedClassBuilder;
            this.mContext = elementContext;
        } else {
            throw new IllegalArgumentException("null ctx");
        }
    }
}
