package org.apache.xmlbeans.impl.piccolo.xml;

import b.b.a.a.a;
import java.io.CharConversionException;
import java.io.InputStream;
import java.io.InputStreamReader;
import java.io.Reader;
import java.util.HashMap;
import java.util.Stack;
import org.apache.poi.hmef.attribute.TNEFProperty;
import org.apache.poi.hssf.record.UnknownRecord;
import org.apache.poi.hssf.usermodel.HSSFShapeTypes;
import org.apache.poi.ss.formula.atp.YearFracCalculator;
import org.apache.poi.ss.formula.ptg.PercentPtg;
import org.apache.poi.ss.formula.ptg.StringPtg;
import org.apache.xmlbeans.impl.common.NameUtil;
import org.apache.xmlbeans.impl.piccolo.io.IllegalCharException;
import org.apache.xmlbeans.impl.piccolo.util.CharStringConverter;
import org.apache.xmlbeans.impl.piccolo.util.IndexedObject;
import org.apache.xmlbeans.impl.piccolo.util.LongStack;
import org.apache.xmlbeans.impl.piccolo.util.RecursionException;
import org.apache.xmlbeans.impl.piccolo.util.StringStack;
import org.xml.sax.ext.LexicalHandler;

public final class PiccoloLexer {
    public static final int CLOSE_TAG = 19;
    public static final int CLOSE_TAG_NS = 20;
    public static final int DTD = 21;
    public static final int DTD_ATTLIST_ELEMENT = 22;
    public static final int DTD_ATT_NAME = 23;
    public static final int DTD_ATT_TYPE = 24;
    public static final int DTD_COMMENT = 27;
    public static final int DTD_ENTITY_DECL = 25;
    public static final int DTD_IGNORE = 28;
    public static final int DTD_NMTOKENS = 26;
    public static final int DTD_PUBLIC_ID = 29;
    public static final int DTD_TAG = 30;
    public static final int DTD_TAG_QSTRING_BUFFERED = 34;
    public static final int DTD_TAG_SQSTRING_BUFFERED = 35;
    public static final int DTD_TAG_START = 31;
    public static final int DTD_TAG_VALUE_ENTITY = 32;
    public static final int DTD_TAG_VALUE_EXTERNAL_ENTITY = 33;
    public static final int DTD_TAG_VALUE_PARAM_ENTITYREF = 37;
    public static final int DTD_TAG_VALUE_STD_ENTITYREF = 36;
    public static final int ENTITYREF = 3;
    public static final char[] LETTER_RANGE_END;
    public static final char[] LETTER_RANGE_START;
    public static final char[] NON_LETTER_RANGE_END = {721, 837, 865, NameUtil.TELEIA, 1158, 1441, 1465, 1469, 1471, 1474, 1476, 1600, 1618, 1641, 1648, 1756, 1759, 1764, 1768, 1773, 1785, 2307, 2364, 2380, 2381, 2388, 2403, 2415, 2435, 2492, 2494, 2495, 2500, 2504, 2509, 2519, 2531, 2543, 2562, 2620, 2622, 2623, 2626, 2632, 2637, 2671, 2673, 2691, 2748, 2757, 2761, 2765, 2799, 2819, 2876, 2883, 2888, 2893, 2903, 2927, 2947, 3010, 3016, 3021, 3031, 3055, 3075, 3140, 3144, 3149, 3158, 3183, 3203, 3268, 3272, 3277, 3286, 3311, 3331, 3395, 3400, 3405, 3415, 3439, 3633, 3642, 3662, 3673, 3761, 3769, 3772, 3782, 3789, 3801, 3865, 3881, 3893, 3895, 3897, 3902, 3903, 3972, 3979, 3989, 3991, 4013, 4023, 4025, 8412, 8417, 12293, 12335, 12341, 12441, 12442, 12446, 12542};
    public static final char[] NON_LETTER_RANGE_START = {720, 768, 864, NameUtil.TELEIA, 1155, 1425, 1443, 1467, 1471, 1473, 1476, 1600, 1611, 1632, 1648, 1750, NameUtil.AYAH, 1760, 1767, 1770, 1776, 2305, 2364, 2366, 2381, 2385, 2402, 2406, 2433, 2492, 2494, 2495, 2496, 2503, 2507, 2519, 2530, 2534, 2562, 2620, 2622, 2623, 2624, 2631, 2635, 2662, 2672, 2689, 2748, 2750, 2759, 2763, 2790, 2817, 2876, 2878, 2887, 2891, 2902, 2918, 2946, 3006, 3014, 3018, 3031, 3047, 3073, 3134, 3142, 3146, 3157, 3174, 3202, 3262, 3270, 3274, 3285, 3302, 3330, 3390, 3398, 3402, 3415, 3430, 3633, 3636, 3654, 3664, 3761, 3764, 3771, 3782, 3784, 3792, 3864, 3872, 3893, 3895, 3897, 3902, 3903, 3953, 3974, 3984, 3991, 3993, 4017, 4025, 8400, 8417, 12293, 12330, 12337, 12441, 12442, 12445, 12540};
    public static final int PI = 4;
    public static final int PI_WS = 5;
    public static final int TAG = 6;
    public static final int TAG_NS = 8;
    public static final int TAG_QSTRING_CDATA_BUFFERED = 13;
    public static final int TAG_QSTRING_NORMALIZE = 15;
    public static final int TAG_QSTRING_NORMALIZE_BUFFERED = 17;
    public static final int TAG_SQSTRING_CDATA_BUFFERED = 14;
    public static final int TAG_SQSTRING_NORMALIZE = 16;
    public static final int TAG_SQSTRING_NORMALIZE_BUFFERED = 18;
    public static final int TAG_START = 7;
    public static final int TAG_START_NS = 9;
    public static final int TAG_VALUE = 10;
    public static final int TAG_VALUE_ENTITY = 11;
    public static final int TAG_VALUE_ENTITYREF = 12;
    public static final int XML_TAG = 1;
    public static final int YYEOF = -1;
    public static final int YYINITIAL = 0;
    public static final int YYINITIAL_DIRECT = 2;
    public static final byte[] YY_ATTRIBUTE = {0, 0, 0, 0, 0, 1, 1, 0, 1, 0, 0, 1, 0, 1, 1, 1, 1, 1, 1, 0, 0, 1, 1, 1, 1, 1, 1, 0, 1, 1, 1, 0, 1, 1, 1, 1, 0, 0, 9, 9, 9, 9, 1, 1, 9, 9, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 9, 1, 1, 1, 1, 1, 1, 1, 1, 9, 1, 1, 1, 1, 1, 1, 1, 9, 9, 1, 1, 1, 1, 1, 1, 1, 1, 9, 3, 1, 1, 1, 9, 3, 1, 1, 9, 1, 1, 9, 3, 1, 1, 1, 9, 1, 9, 1, 9, 1, 1, 1, 1, 1, 1, 9, 1, 1, 1, 1, 9, 1, 1, 1, 9, 9, 1, 1, 1, 1, 1, 1, 1, 1, 9, 1, 1, 1, 1, 1, 1, 9, 1, 1, 9, 9, 9, 9, 1, 1, 1, 1, 1, 9, 9, 1, 1, 1, 1, 9, 9, 9, 1, 1, 1, 0, 0, 9, 0, 9, 0, 0, 0, 0, 0, 0, 0, 0, 0, 9, 9, 9, 1, 1, 1, 0, 0, 0, 1, 1, 1, 9, 1, 1, 1, 0, 0, 9, 9, 0, 9, 0, 0, 0, 0, 0, 0, 0, 13, 2, 13, 2, 13, 0, 0, 0, 0, 9, 0, 0, 1, 0, 0, 0, 1, 0, 1, 0, 0, 0, 0, 0, 9, 0, 1, 1, 1, 1, 1, 1, 1, 1, 0, 0, 0, 0, 9, 1, 1, 1, 0, 0, 0, 0, 9, 0, 9, 0, 9, 9, 9, 0, 0, 0, 0, 9, 1, 1, 0, 0, 0, 1, 1, 1, 1, 9, 9, 0, 0, 0, 0, 9, 9, 9, 9, 1, 0, 0, 0, 0, 0, 9, 9, 1, 1, 1, 1, 1, 1, 1, 1, 0, 0, 0, 0, 1, 1, 0, 0, 0, 0, 9, 9, 9, 0, 0, 3, 3, 0, 0, 0, 1, 1, 9, 9, 0, 0, 0, 0, 0, 0, 0, 1, 1, 1, 1, 1, 1, 1, 0, 0, 0, 0, 3, 3, 0, 0, 0, 0, 9, 9, 13, 13, 0, 0, 0, 1, 9, 9, 0, 0, 0, 1, 9, 1, 1, 1, 1, 1, 1, 1, 0, 0, 0, 0, 13, 0, 0, 0, 0, 9, 0, 0, 0, 1, 0, 0, 9, 0, 0, 9, 1, 1, 1, 1, 1, 0, 0, 9, 0, 0, 0, 0, 0, 0, 0, 1, 9, 9, 0, 1, 0, 1, 1, 0, 0, 9, 0, 9, 0, 0, 9, 0, 9, 9, 9, 1, 9, 0, 9, 0, 9, 1, 9, 9};
    public static final int YY_BUFFERSIZE = 16384;
    public static final String[] YY_ERROR_MSG = {"Unkown internal scanner error", "Internal error: unknown state", "Error: could not match input", "Error: pushback value was too large", "Error: skip value was too large"};
    public static final int YY_ILLEGAL_STATE = 1;
    public static final int YY_NO_MATCH = 2;
    public static final int YY_PUSHBACK_2BIG = 3;
    public static final int YY_SKIP_2BIG = 4;
    public static final int YY_UNKNOWN_ERROR = 0;
    public static boolean[] asciiNameChars = null;
    public static boolean[] asciiNameCharsNS = null;
    public static boolean[] asciiNameStartChars = null;
    public static boolean[] asciiNameStartCharsNS = null;
    public static final String yy_packed0 = "\u0001'\u0001(\u0004'\u0001(\u0003'\u0001)\u0001*\u0004'\u0001()'\u0001(\b'\f+\u0001,6+\n-\u0001)\u0001*7-\u0003.\u0002/\u0002.\u0001/\u0005.\u0002/\u00010\u0001.\u0003/\u0005.\b/\u0002.\u0005/\u0001.\u0003/\u00011\u0002/\b.\u0002/\u0002.\u00012\u0001/\u00013\u0003/\u00014\u0001/\f5\u0001665\u0001.\u00017\u0004.\u00017\u0005.\u00018\u0003.\u00017).\u00017\t.\u00019\u0001.\u0002:\u0001.\u00019\u0001:\u0005.\u0003:\u00019\u0003:\u0001;\u0004.\b:\u0002.\u0005:\u0001.\u0003:\u0001.\u0002:\u0007.\u0001<\u0002:\u0001.\u00019\b:\u0003.\u0002=\u0002.\u0001=\u0004.\u0001>\u0003=\u0001.\u0003=\u0004.\u0001?\b=\u0002.\u0005=\u0001.\u0003=\u0001.\u0002=\u0007.\u0001@\u0002=\u0002.\b=\u0001.\u00019\u0001.\u0001A\u0001B\u0001.\u00019\u0001B\u0005.\u0001C\u0002B\u00019\u0003B\u0001D\u0004.\bB\u0002.\u0005B\u0001.\u0003B\u0001.\u0002B\u0007.\u0001E\u0002B\u0001.\u00019\bB\u0003.\u0001F\u0001G\u0002.\u0001G\u0004.\u0001>\u0003G\u0001.\u0003G\u0004.\u0001?\bG\u0002.\u0005G\u0001.\u0003G\u0001.\u0002G\u0007.\u0001H\u0002G\u0002.\bG\u0001.\u0001I\u0004.\u0001I\t.\u0001I(.\u0001J\u0001I\b.\u0001K\u0001L\u0004K\u0001L\u0003K\u0001.\u0001M.K\u0001L\bK\u0003.\u0002N\u0002.\u0001N\u0005.\u0002N\u0001O\u0001.\u0003N\u0005.\bN\u0002.\u0005N\u0001.\u0003N\u0001P\u0002N\b.\u0002N\u0002.\u0001Q\u0001N\u0001R\u0003N\u0001S\u0001N\u0001T\u0001U\u0004T\u0001U\u0003T\u0001.\u0001V(T\u0001W\u0005T\u0001U\bT\u0001X\u0001U\u0004X\u0001U\u0003X\u0001.\u0001V)X\u0001W\u0004X\u0001U\bX\u0001Y\u0001Z\u0004Y\u0001Z\u0003Y\u0001.\u0001[\u0004Y\u0001Z#Y\u0001\\\u0005Y\u0001Z\bY\u0001]\u0001^\u0004]\u0001^\u0003]\u0001.\u0001_\u0004]\u0001^$]\u0001\\\u0004]\u0001^\b]\u0001`\u0001a\u0004`\u0001a\u0003`\u0001.\u0001b\u0004`\u0001a#`\u0001c\u0005`\u0001a\b`\u0001d\u0001e\u0004d\u0001e\u0003d\u0001.\u0001b\u0004d\u0001e$d\u0001c\u0004d\u0001e\bd\u0001.\u0001f\u0004.\u0001f\t.\u0001f\u0003.\u0001g%.\u0001f\t.\u0001h\u0004.\u0001h\t.\u0001h\u0003.\u0001i%.\u0001h\t.\u0001j\u0004.\u0001j\u0003.\u0001k\u0005.\u0001j\u0004.\u0001l\u0001.\u0001m\".\u0001j\t.\u0001j\u0001.\u0002n\u0001.\u0001j\u0001n\u0005.\u0003n\u0001j\u0003n\u0001.\u0001o\u0003.\bn\u0002.\u0005n\u0001.\u0003n\u0001.\u0002n\b.\u0002n\u0001.\u0001j\bn\u0001.\u0001j\u0001.\u0001p\u0001q\u0001.\u0001j\u0001q\u0005.\u0003q\u0001j\u0003q\u0001r\u0001o\u0003.\bq\u0002.\u0005q\u0001.\u0003q\u0001.\u0002q\b.\u0002q\u0001.\u0001j\bq\u0001.\u0001j\u0004.\u0001j\t.\u0001j\u0004.\u0001o\u0003.\u0001s\u0001t\u0001.\u0001u\u0006.\u0001v\u0004.\u0001w\u0011.\u0001j\t.\u0001j\u0001.\u0002x\u0001.\u0001j\u0001x\u0005.\u0003x\u0001j\u0003x\u0001.\u0001y\u0003.\bx\u0002.\u0005x\u0001.\u0003x\u0001.\u0002x\b.\u0002x\u0001.\u0001j\bx\u0001.\u0001j\u0003z\u0001.\u0001j\u0003z\u0003.\u0003z\u0001j\u0003z\u0001.\u0001o\u0003.\tz\u0001.\u0005z\u0001.\u0003z\u0001.\u0002z\u0001{\u0003.\u0001|\u0003.\u0002z\u0001.\u0001j\bz!}\u0001~!}\n\u0001\f\u0001+\u0001.\u0001j\u0004.\u0001j\t.\u0001j#.\u0001\u0001\u0004.\u0001j\t.\u0001\u0001.\u0002z\u0001.\u0001\u0001z\u0004.\u0001\u0003z\u0001\u0003z\u0001r\u0001o\u0003.\u0001\u0001\u0001z\u0001\u0001z\u0001\u0001\u0001z\u0001.\u0001\u0005z\u0001\u0001\u0002z\u0001\u0002z\u0001\u0001\u0001\u0001\u0001|\u0001\u0001\u0001.\u0002z\u0001.\u0001\bz\f.\u0001\u000b.\u0001*.\u000b\u0001\t\u0001-\u0001\u0001\u0004\u0001\t\u0001)\u0001\b\u000b\u0001\t\u0001\u001e\u0001 \u000e\u000b¡\u0001\t¡\u0001\u001f¡\u0001 \r¡\u0003.\u0002¢\u0002.\u0001¢\u0005.\u0003¢\u0001.\u0003¢\u0005.\b¢\u0002.\u0005¢\u0001.\u0003¢\u0001P\u0002¢\b.\u0002¢\u0002.\b¢\u0003.\u0002£\u0002.\u0001£\u0005.\u0003£\u0001.\u0003£\u0005.\b£\u0002.\u0005£\u0001.\u0003£\u0001.\u0002£\b.\u0002£\u0002.\b£C\u0000\f¤\u0001¥B¤\u0001¥\u0007¤\u0001¦.¤\u0002\u0000\u0003§\u0002\u0000\u0003§\u0003\u0000\u0003§\u0001\u0000\u0003§\u0002\u0000\u0001¨\u0002\u0000\t§\u0001\u0000\u0005§\u0001\u0000\u0003§\u0001\u0000\u0002§\b\u0000\u0002§\u0002\u0000\b§\u0002\u0000\u0003§\u0002\u0000\u0003§\u0003\u0000\u0003§\u0001\u0000\u0003§\u0002\u0000\u0001¨\u0002\u0000\t§\u0001\u0000\u0005§\u0001\u0000\u0003§\u0001\u0000\u0002§\b\u0000\u0002§\u0002\u0000\u0005§\u0001©\u0002§\t\u0000\u0001ª\u0003\u0000\u0001«7\u0000\u0003§\u0002\u0000\u0003§\u0003\u0000\u0001§\u0001¬\u0001§\u0001\u0000\u0003§\u0002\u0000\u0001¨\u0002\u0000\t§\u0001\u0000\u0005§\u0001\u0000\u0003§\u0001\u0000\u0002§\b\u0000\u0002§\u0002\u0000\u0001§\u0001­\u0006§\u0002\u0000\u0003§\u0002\u0000\u0003§\u0003\u0000\u0003§\u0001\u0000\u0003§\u0002\u0000\u0001¨\u0002\u0000\t§\u0001\u0000\u0005§\u0001\u0000\u0003§\u0001\u0000\u0002§\b\u0000\u0002§\u0002\u0000\u0003§\u0001®\u0004§\u0002\u0000\u0003§\u0002\u0000\u0003§\u0003\u0000\u0003§\u0001\u0000\u0003§\u0002\u0000\u0001¨\u0002\u0000\t§\u0001\u0000\u0005§\u0001\u0000\u0003§\u0001\u0000\u0002§\b\u0000\u0002§\u0002\u0000\u0005§\u0001¯\u0002§\f°\u0001±B°\u0001±\u0007°\u0001².°\u0001\u0000\u00017\u0004\u0000\u00017\t\u0000\u00017)\u0000\u00017\u001c\u0000\u0001³/\u0000\u00019\u0004\u0000\u00019\t\u0000\u00019)\u0000\u00019\n\u0000\u0003:\u0002\u0000\u0003:\u0003\u0000\u0003:\u0001\u0000\u0003:\u0005\u0000\t:\u0001\u0000\u0005:\u0001\u0000\u0003:\u0001\u0000\u0002:\b\u0000\u0002:\u0002\u0000\b:\u0014\u0000\u0001´0\u0000\u0003=\u0002\u0000\u0003=\u0003\u0000\u0003=\u0001\u0000\u0003=\u0005\u0000\t=\u0001\u0000\u0005=\u0001\u0000\u0003=\u0001\u0000\u0002=\b\u0000\u0002=\u0002\u0000\b=\u0003\u0000\u0002µ\u0002\u0000\u0001µ\u0005\u0000\u0001¶\u0002µ\u0001\u0000\u0001·\u0002µ\u0005\u0000\bµ\u0002\u0000\u0005µ\u0001\u0000\u0003µ\u0001\u0000\u0002µ\b\u0000\u0002µ\u0002\u0000\bµ!\u0000\u0001¸\u0001¹\u0001\u0000\u0001º!\u0000\u0002»\u0002\u0000\u0001»\u0005\u0000\u0003»\u0001\u0000\u0003»\u0005\u0000\b»\u0002\u0000\u0005»\u0001\u0000\u0003»\u0001\u0000\u0002»\b\u0000\u0002»\u0002\u0000\b»\u0002\u0000\u0003A\u0002\u0000\u0003A\u0003\u0000\u0003A\u0001\u0000\u0003A\u0005\u0000\tA\u0001\u0000\u0005A\u0001\u0000\u0003A\u0001\u0000\u0002A\b\u0000\u0002A\u0002\u0000\bA\u0002\u0000\u0001B\u0001¼\u0001B\u0002\u0000\u0003B\u0003\u0000\u0003B\u0001\u0000\u0003B\u0005\u0000\tB\u0001\u0000\u0005B\u0001\u0000\u0003B\u0001\u0000\u0002B\b\u0000\u0002B\u0002\u0000\bB\u0002\u0000\u0001B\u0001¼\u0001B\u0002\u0000\u0003B\u0003\u0000\u0001B\u0001½\u0001B\u0001\u0000\u0003B\u0005\u0000\tB\u0001\u0000\u0005B\u0001\u0000\u0003B\u0001\u0000\u0002B\b\u0000\u0002B\u0002\u0000\bB\u0014\u0000\u0001¾0\u0000\u0003F\u0002\u0000\u0003F\u0003\u0000\u0003F\u0001\u0000\u0003F\u0005\u0000\tF\u0001\u0000\u0005F\u0001\u0000\u0003F\u0001\u0000\u0002F\b\u0000\u0002F\u0002\u0000\bF\u0002\u0000\u0001G\u0001¿\u0001G\u0002\u0000\u0003G\u0003\u0000\u0003G\u0001\u0000\u0003G\u0005\u0000\tG\u0001\u0000\u0005G\u0001\u0000\u0003G\u0001\u0000\u0002G\b\u0000\u0002G\u0002\u0000\bG\u0003\u0000\u0001À\u0001Á\u0002\u0000\u0001Á\u0005\u0000\u0003Á\u0001\u0000\u0003Á\u0005\u0000\bÁ\u0002\u0000\u0005Á\u0001\u0000\u0003Á\u0001\u0000\u0002Á\b\u0000\u0002Á\u0002\u0000\bÁ\u0001\u0000\u0001Â\u0004\u0000\u0001Â\t\u0000\u0001Â(\u0000\u0001Ã\u0001Â\t\u0000\u0001Ã\u0004\u0000\u0001Ã\t\u0000\u0001Ã#\u0000\u0001Ä\u0001Å\u0004\u0000\u0001Ã\b\u0000\u0001K\u0001\u0000\u0004K\u0001\u0000\u0003K\u0002\u0000.K\u0001\u0000\bK\u0002\u0000\u0003Æ\u0002\u0000\u0003Æ\u0003\u0000\u0003Æ\u0001\u0000\u0003Æ\u0002\u0000\u0001Ç\u0002\u0000\tÆ\u0001\u0000\u0005Æ\u0001\u0000\u0003Æ\u0001\u0000\u0002Æ\b\u0000\u0002Æ\u0002\u0000\bÆ\u0002\u0000\u0003Æ\u0002\u0000\u0003Æ\u0003\u0000\u0003Æ\u0001\u0000\u0003Æ\u0002\u0000\u0001Ç\u0002\u0000\tÆ\u0001\u0000\u0005Æ\u0001\u0000\u0003Æ\u0001\u0000\u0002Æ\b\u0000\u0002Æ\u0002\u0000\u0005Æ\u0001È\u0002Æ\t\u0000\u0001É\u0003\u0000\u0001Ê7\u0000\u0003Æ\u0002\u0000\u0003Æ\u0003\u0000\u0001Æ\u0001Ë\u0001Æ\u0001\u0000\u0003Æ\u0002\u0000\u0001Ç\u0002\u0000\tÆ\u0001\u0000\u0005Æ\u0001\u0000\u0003Æ\u0001\u0000\u0002Æ\b\u0000\u0002Æ\u0002\u0000\u0001Æ\u0001Ì\u0006Æ\u0002\u0000\u0003Æ\u0002\u0000\u0003Æ\u0003\u0000\u0003Æ\u0001\u0000\u0003Æ\u0002\u0000\u0001Ç\u0002\u0000\tÆ\u0001\u0000\u0005Æ\u0001\u0000\u0003Æ\u0001\u0000\u0002Æ\b\u0000\u0002Æ\u0002\u0000\u0003Æ\u0001Í\u0004Æ\u0002\u0000\u0003Æ\u0002\u0000\u0003Æ\u0003\u0000\u0003Æ\u0001\u0000\u0003Æ\u0002\u0000\u0001Ç\u0002\u0000\tÆ\u0001\u0000\u0005Æ\u0001\u0000\u0003Æ\u0001\u0000\u0002Æ\b\u0000\u0002Æ\u0002\u0000\u0005Æ\u0001Î\u0002Æ\u0001T\u0001\u0000\u0004T\u0001\u0000\u0003T\u0002\u0000(T\u0001\u0000\u0005T\u0001\u0000\bT\u0001\u0000\u0001U\u0004\u0000\u0001U3\u0000\u0001U\t\u0000\u0001Ï\u0004\u0000\u0001Ï\t\u0000\u0001Ï\u0003\u0000\u0001Ï!\u0000\u0001Ï\u0003\u0000\u0001Ï\b\u0000\u0001X\u0001\u0000\u0004X\u0001\u0000\u0003X\u0002\u0000)X\u0001\u0000\u0004X\u0001\u0000\bX\u0001Y\u0001\u0000\u0004Y\u0001\u0000\u0003Y\u0002\u0000\u0004Y\u0001\u0000#Y\u0001\u0000\u0005Y\u0001\u0000\bY\u0001\u0000\u0001Z\u0004\u0000\u0001Z\t\u0000\u0001Z#\u0000\u0001Ð\u0005\u0000\u0001Z\t\u0000\u0001Ñ\u0004\u0000\u0001Ñ\t\u0000\u0001Ñ\u0003\u0000\u0001Ñ!\u0000\u0001Ñ\u0003\u0000\u0001Ñ\b\u0000\u0001]\u0001\u0000\u0004]\u0001\u0000\u0003]\u0002\u0000\u0004]\u0001\u0000$]\u0001\u0000\u0004]\u0001\u0000\b]\u0001\u0000\u0001^\u0004\u0000\u0001^\t\u0000\u0001^$\u0000\u0001Ð\u0004\u0000\u0001^\b\u0000\u0001`\u0001\u0000\u0004`\u0001\u0000\u0003`\u0002\u0000\u0004`\u0001\u0000#`\u0001\u0000\u0005`\u0001\u0000\b`\u0001\u0000\u0001a\u0004\u0000\u0001a\t\u0000\u0001a#\u0000\u0001Ò\u0005\u0000\u0001a\t\u0000\u0001Ó\u0004\u0000\u0001Ó\t\u0000\u0001Ó\u0003\u0000\u0001Ó!\u0000\u0001Ó\u0003\u0000\u0001Ó\b\u0000\u0001d\u0001\u0000\u0004d\u0001\u0000\u0003d\u0002\u0000\u0004d\u0001\u0000$d\u0001\u0000\u0004d\u0001\u0000\bd\u0001\u0000\u0001e\u0004\u0000\u0001e\t\u0000\u0001e$\u0000\u0001Ò\u0004\u0000\u0001e\t\u0000\u0001Ô\u0004\u0000\u0001Ô\t\u0000\u0001Ô\u0003\u0000\u0001g%\u0000\u0001Ô\t\u0000\u0001Õ\u0004\u0000\u0001Õ\t\u0000\u0001Õ\u0003\u0000\u0001i%\u0000\u0001Õ\t\u0000\u0001j\u0004\u0000\u0001j\t\u0000\u0001j)\u0000\u0001j\u000b\u0000\u0002Ö\u0002\u0000\u0001Ö\u0005\u0000\u0003Ö\u0001\u0000\u0003Ö\u0005\u0000\bÖ\u0002\u0000\u0005Ö\u0001\u0000\u0003Ö\u0001\u0000\u0002Ö\b\u0000\u0002Ö\u0002\u0000\bÖ\u0001\u0000\u0001×\u0004\u0000\u0001×\t\u0000\u0001×\u0003\u0000\u0001Ø\u0002\u0000\u0001Ù\"\u0000\u0001×\n\u0000\u0003n\u0002\u0000\u0003n\u0003\u0000\u0003n\u0001\u0000\u0003n\u0005\u0000\tn\u0001\u0000\u0005n\u0001\u0000\u0003n\u0001\u0000\u0002n\b\u0000\u0002n\u0002\u0000\bn\u0003\u0000\u0002Ú\u0002\u0000\u0001Ú\u0005\u0000\u0003Ú\u0001\u0000\u0003Ú\u0005\u0000\bÚ\u0002\u0000\u0005Ú\u0001\u0000\u0003Ú\u0001\u0000\u0002Ú\b\u0000\u0002Ú\u0002\u0000\bÚ\u0002\u0000\u0003p\u0002\u0000\u0003p\u0003\u0000\u0003p\u0001\u0000\u0003p\u0005\u0000\tp\u0001\u0000\u0005p\u0001\u0000\u0003p\u0001\u0000\u0002p\b\u0000\u0002p\u0002\u0000\bp\u0002\u0000\u0001q\u0001Û\u0001q\u0002\u0000\u0003q\u0003\u0000\u0003q\u0001\u0000\u0003q\u0005\u0000\tq\u0001\u0000\u0005q\u0001\u0000\u0003q\u0001\u0000\u0002q\b\u0000\u0002q\u0002\u0000\bq\u001a\u0000\u0001Ü:\u0000\u0001Ý\r\u0000\u0001ÞF\u0000\u0001ßB\u0000\u0001à \u0000\u0003x\u0002\u0000\u0003x\u0003\u0000\u0003x\u0001\u0000\u0003x\u0005\u0000\tx\u0001\u0000\u0005x\u0001\u0000\u0003x\u0001\u0000\u0002x\b\u0000\u0002x\u0002\u0000\bx\u0001\u0000\u0001á\u0001\u0000\u0002Ú\u0002\u0000\u0001Ú\u0005\u0000\u0003Ú\u0001á\u0003Ú\u0005\u0000\bÚ\u0002\u0000\u0005Ú\u0001\u0000\u0003Ú\u0001\u0000\u0002Ú\b\u0000\u0002Ú\u0001\u0000\u0001á\bÚ\u0002\u0000\u0003z\u0002\u0000\u0003z\u0003\u0000\u0003z\u0001\u0000\u0003z\u0005\u0000\tz\u0001\u0000\u0005z\u0001\u0000\u0003z\u0001\u0000\u0002z\b\u0000\u0002z\u0002\u0000\bz!â\u0001ãBâ\u0001ä!â\n\u0001\u0000\f\u0001\u0000+\u0018\u0000\u0001åA\u0000\u0001Ù-\u0000\u0005æ\u0002\u0000\u0001æ\u0002\u0000\bæ\u0001\u0000\u0002æ\u0001\u0000\næ\u0001\u0000\u0010æ\u0001\u0000\u0001ç\u000eæ\u0002\u0000\u0005è\u0002\u0000\u0001è\u0002\u0000\bè\u0001\u0000\u0002è\u0001\u0000\nè\u0001\u0000\u0010è\u0002\u0000\u0001ç\rè\u0001\u0000\u0001\u0004\u0000\u0001\t\u0000\u0001\u0011\u0000\u0001\u0017\u0000\u0001\n\u0000\u0003z\u0002\u0000\u0003z\u0003\u0000\u0003z\u0001\u0000\u0001z\u0001é\u0001z\u0005\u0000\tz\u0001\u0000\u0005z\u0001\u0000\u0003z\u0001\u0000\u0002z\b\u0000\u0002z\u0002\u0000\bz\u0002\u0000\u0003z\u0002\u0000\u0003z\u0003\u0000\u0003z\u0001\u0000\u0003z\u0005\u0000\u0007z\u0001ê\u0001z\u0001\u0000\u0001z\u0001ë\u0003z\u0001\u0000\u0003z\u0001\u0000\u0002z\b\u0000\u0002z\u0002\u0000\bz\u0002\u0000\u0003z\u0002\u0000\u0003z\u0003\u0000\u0003z\u0001\u0000\u0003z\u0005\u0000\u0001z\u0001ì\u0007z\u0001\u0000\u0005z\u0001\u0000\u0003z\u0001\u0000\u0001z\u0001í\b\u0000\u0002z\u0002\u0000\bz\u0002\u0000\u0003z\u0002\u0000\u0003z\u0003\u0000\u0003z\u0001\u0000\u0003z\u0005\u0000\u0001z\u0001î\u0007z\u0001\u0000\u0005z\u0001\u0000\u0003z\u0001\u0000\u0002z\b\u0000\u0002z\u0002\u0000\bz\u0002\u0000\u0003z\u0002\u0000\u0003z\u0003\u0000\u0003z\u0001\u0000\u0003z\u0005\u0000\u0004z\u0001ï\u0004z\u0001\u0000\u0005z\u0001\u0000\u0003z\u0001\u0000\u0002z\b\u0000\u0002z\u0002\u0000\bz\u0001\u0000\u0001\u0004\u0000\u0001\t\u0000\u0001)\u0000\u0001\n\u0000\u0003z\u0002\u0000\u0003z\u0003\u0000\u0003z\u0001\u0000\u0003z\u0005\u0000\tz\u0001\u0000\u0005z\u0001\u0000\u0001z\u0001ð\u0001z\u0001\u0000\u0002z\b\u0000\u0002z\u0002\u0000\bz\u001c\u0000\u0001ñ\b\u0000\u0001ò\u0001ó\u0002\u0000\u0001ô\u0019\u0000\u000b\u0001\u0000\t\u0001\u0000\u001e\u0001õ\u000e\u000b\u0001\u0000\t\u0001\u0000\u001f\u0001õ\r\u0003\u0000\u0002ö\u0002\u0000\u0001ö\u0005\u0000\u0001÷\u0002ö\u0001\u0000\u0001ø\u0002ö\u0005\u0000\bö\u0002\u0000\u0005ö\u0001\u0000\u0003ö\u0001\u0000\u0002ö\b\u0000\u0002ö\u0002\u0000\bö\u0019\u0000\u0001ù\u0001ú\u0003\u0000\u0001û\u0002\u0000\u0001ü\u0001ý \u0000\u000b\u0001\u0000\t\u0001\u0000-\u000b\u0001\u0000\t\u0001\u0000-\u0001\u0000\u0001\u0004\u0000\u0001\t\u0000\u0001)\u0000\u0001\b\u0000\u0001\u0001\u0004\u0001\u0004\u0001\u0000\u0004\u0001\u0004\u0001\u0000$\u0001\b\u000b\u0001\u0000\t\u0001\u0000\u001e\u0001\u0000\u000e\u000b¡\u0001\u0000\t¡\u0001\u0000\u001f¡\u0001\u0000\r¡\u0002\u0000\u0003þ\u0002\u0000\u0003þ\u0003\u0000\u0003þ\u0001\u0000\u0003þ\u0002\u0000\u0001ÿ\u0002\u0000\tþ\u0001\u0000\u0005þ\u0001\u0000\u0003þ\u0001\u0000\u0002þ\b\u0000\u0002þ\u0002\u0000\bþ\u0002\u0000\u0003Ā\u0002\u0000\u0003Ā\u0003\u0000\u0003Ā\u0001\u0000\u0003Ā\u0002\u0000\u0001ā\u0002\u0000\tĀ\u0001\u0000\u0005Ā\u0001\u0000\u0003Ā\u0001\u0000\u0002Ā\b\u0000\u0002Ā\u0002\u0000\bĀ\u0002\u0000\u0003§\u0002\u0000\u0003§\u0003\u0000\u0003§\u0001\u0000\u0003§\u0002\u0000\u0001Ă\u0002\u0000\t§\u0001\u0000\u0005§\u0001\u0000\u0003§\u0001\u0000\u0002§\b\u0000\u0002§\u0002\u0000\b§\t\u0000\u0001ª\f\u0000\u0001ă5\u0000\u0001Ą\u000f\u0000\u0001Ą\u0004\u0000\u0001Ą\u0004\u0000\u0002Ą\u0001\u0000\u0001Ą\u0004\u0000\u0001Ą\u000f\u0000\u0001Ą\u0006\u0000\u0001Ą\u0002\u0000\u0003§\u0002\u0000\u0003§\u0003\u0000\u0003§\u0001\u0000\u0003§\u0002\u0000\u0001¨\u0002\u0000\t§\u0001\u0000\u0005§\u0001\u0000\u0003§\u0001\u0000\u0002§\b\u0000\u0002§\u0002\u0000\u0001§\u0001ą\u0006§\u0002\u0000\u0003§\u0002\u0000\u0003§\u0003\u0000\u0003§\u0001\u0000\u0003§\u0002\u0000\u0001¨\u0002\u0000\t§\u0001\u0000\u0005§\u0001\u0000\u0003§\u0001\u0000\u0002§\b\u0000\u0002§\u0002\u0000\u0004§\u0001Ć\u0003§\u0002\u0000\u0003§\u0002\u0000\u0003§\u0003\u0000\u0003§\u0001\u0000\u0003§\u0002\u0000\u0001¨\u0002\u0000\t§\u0001\u0000\u0005§\u0001\u0000\u0003§\u0001\u0000\u0002§\b\u0000\u0002§\u0002\u0000\u0004§\u0001ć\u0003§\u0002\u0000\u0003§\u0002\u0000\u0003§\u0003\u0000\u0003§\u0001\u0000\u0003§\u0002\u0000\u0001Ĉ\u0002\u0000\t§\u0001\u0000\u0005§\u0001\u0000\u0003§\u0001\u0000\u0002§\b\u0000\u0002§\u0002\u0000\b§\u0002\u0000\u0003µ\u0002\u0000\u0003µ\u0003\u0000\u0003µ\u0001\u0000\u0003µ\u0005\u0000\tµ\u0001\u0000\u0005µ\u0001\u0000\u0003µ\u0001\u0000\u0002µ\b\u0000\u0002µ\u0002\u0000\bµ\u0002\u0000\u0003µ\u0002\u0000\u0003µ\u0003\u0000\u0001µ\u0001ĉ\u0001µ\u0001\u0000\u0001µ\u0001Ċ\u0001µ\u0005\u0000\tµ\u0001\u0000\u0005µ\u0001\u0000\u0003µ\u0001\u0000\u0002µ\b\u0000\u0002µ\u0002\u0000\bµ\u0002\u0000\u0003µ\u0002\u0000\u0003µ\u0003\u0000\u0001µ\u0001Ċ\u0001µ\u0001\u0000\u0001µ\u0001Ċ\u0001µ\u0005\u0000\tµ\u0001\u0000\u0005µ\u0001\u0000\u0003µ\u0001\u0000\u0002µ\b\u0000\u0002µ\u0002\u0000\bµ!\u0000\u0001ċD\u0000\u0001Č?\u0000\u0001č$\u0000\u0003»\u0002\u0000\u0003»\u0003\u0000\u0003»\u0001\u0000\u0003»\u0005\u0000\t»\u0001\u0000\u0005»\u0001\u0000\u0003»\u0001\u0000\u0002»\b\u0000\u0002»\u0002\u0000\b»\u0002\u0000\u0002A\u0001Ď\u0002\u0000\u0001Ď\u0002A\u0003\u0000\u0003Ď\u0001\u0000\u0003Ď\u0005\u0000\bĎ\u0001A\u0001\u0000\u0005Ď\u0001\u0000\u0003Ď\u0001\u0000\u0002Ď\b\u0000\u0002Ď\u0002\u0000\bĎ\u0002\u0000\u0001B\u0001¼\u0001B\u0002\u0000\u0003B\u0003\u0000\u0002B\u0001ď\u0001\u0000\u0003B\u0005\u0000\tB\u0001\u0000\u0005B\u0001\u0000\u0003B\u0001\u0000\u0002B\b\u0000\u0002B\u0002\u0000\bB\u0002\u0000\u0002F\u0001Đ\u0002\u0000\u0001Đ\u0002F\u0003\u0000\u0003Đ\u0001\u0000\u0003Đ\u0005\u0000\bĐ\u0001F\u0001\u0000\u0005Đ\u0001\u0000\u0003Đ\u0001\u0000\u0002Đ\b\u0000\u0002Đ\u0002\u0000\bĐ\u0002\u0000\u0003À\u0002\u0000\u0003À\u0003\u0000\u0003À\u0001\u0000\u0003À\u0005\u0000\tÀ\u0001\u0000\u0005À\u0001\u0000\u0003À\u0001\u0000\u0002À\b\u0000\u0002À\u0002\u0000\bÀ\u0002\u0000\u0001Á\u0001đ\u0001Á\u0002\u0000\u0003Á\u0003\u0000\u0003Á\u0001\u0000\u0003Á\u0005\u0000\tÁ\u0001\u0000\u0005Á\u0001\u0000\u0003Á\u0001\u0000\u0002Á\b\u0000\u0002Á\u0002\u0000\bÁ\u0002\u0000\u0003Æ\u0002\u0000\u0003Æ\u0003\u0000\u0003Æ\u0001\u0000\u0003Æ\u0002\u0000\u0001Ē\u0002\u0000\tÆ\u0001\u0000\u0005Æ\u0001\u0000\u0003Æ\u0001\u0000\u0002Æ\b\u0000\u0002Æ\u0002\u0000\bÆ\t\u0000\u0001É\f\u0000\u0001ē5\u0000\u0001Ĕ\u000f\u0000\u0001Ĕ\u0004\u0000\u0001Ĕ\u0004\u0000\u0002Ĕ\u0001\u0000\u0001Ĕ\u0004\u0000\u0001Ĕ\u000f\u0000\u0001Ĕ\u0006\u0000\u0001Ĕ\u0002\u0000\u0003Æ\u0002\u0000\u0003Æ\u0003\u0000\u0003Æ\u0001\u0000\u0003Æ\u0002\u0000\u0001Ç\u0002\u0000\tÆ\u0001\u0000\u0005Æ\u0001\u0000\u0003Æ\u0001\u0000\u0002Æ\b\u0000\u0002Æ\u0002\u0000\u0001Æ\u0001ĕ\u0006Æ\u0002\u0000\u0003Æ\u0002\u0000\u0003Æ\u0003\u0000\u0003Æ\u0001\u0000\u0003Æ\u0002\u0000\u0001Ç\u0002\u0000\tÆ\u0001\u0000\u0005Æ\u0001\u0000\u0003Æ\u0001\u0000\u0002Æ\b\u0000\u0002Æ\u0002\u0000\u0004Æ\u0001Ė\u0003Æ\u0002\u0000\u0003Æ\u0002\u0000\u0003Æ\u0003\u0000\u0003Æ\u0001\u0000\u0003Æ\u0002\u0000\u0001Ç\u0002\u0000\tÆ\u0001\u0000\u0005Æ\u0001\u0000\u0003Æ\u0001\u0000\u0002Æ\b\u0000\u0002Æ\u0002\u0000\u0004Æ\u0001ė\u0003Æ\u0002\u0000\u0003Æ\u0002\u0000\u0003Æ\u0003\u0000\u0003Æ\u0001\u0000\u0003Æ\u0002\u0000\u0001Ę\u0002\u0000\tÆ\u0001\u0000\u0005Æ\u0001\u0000\u0003Æ\u0001\u0000\u0002Æ\b\u0000\u0002Æ\u0002\u0000\bÆ\u0002\u0000\u0003Ö\u0002\u0000\u0003Ö\u0003\u0000\u0003Ö\u0001\u0000\u0003Ö\u0002\u0000\u0001ę\u0002\u0000\tÖ\u0001\u0000\u0005Ö\u0001\u0000\u0003Ö\u0001\u0000\u0002Ö\b\u0000\u0002Ö\u0002\u0000\bÖ\u0001\u0000\u0001×\u0004\u0000\u0001×\t\u0000\u0001×\u0003\u0000\u0001Ø%\u0000\u0001×\u001c\u0000\u0001Ě0\u0000\u0003Ú\u0002\u0000\u0003Ú\u0003\u0000\u0003Ú\u0001\u0000\u0003Ú\u0002\u0000\u0001ě\u0002\u0000\tÚ\u0001\u0000\u0005Ú\u0001\u0000\u0003Ú\u0001\u0000\u0002Ú\b\u0000\u0002Ú\u0002\u0000\bÚ\u0002\u0000\u0002p\u0001Ĝ\u0002\u0000\u0001Ĝ\u0002p\u0003\u0000\u0003Ĝ\u0001\u0000\u0003Ĝ\u0005\u0000\bĜ\u0001p\u0001\u0000\u0005Ĝ\u0001\u0000\u0003Ĝ\u0001\u0000\u0002Ĝ\b\u0000\u0002Ĝ\u0002\u0000\bĜ\u001b\u0000\u0001ĝB\u0000\u0001ĞB\u0000\u0001ğL\u0000\u0001Ġ;\u0000\u0001ġ%\u0000\u0001á\u000e\u0000\u0001á)\u0000\u0001á\u001c\u0000\u0001ĢP\u0000\u0001ģ\"\u0000\u0003z\u0002\u0000\u0003z\u0003\u0000\u0003z\u0001\u0000\u0003z\u0005\u0000\tz\u0001\u0000\u0005z\u0001\u0000\u0001Ĥ\u0002z\u0001\u0000\u0002z\b\u0000\u0002z\u0002\u0000\bz\u0002\u0000\u0003z\u0002\u0000\u0003z\u0003\u0000\u0003z\u0001\u0000\u0003z\u0005\u0000\u0002z\u0001ĥ\u0006z\u0001\u0000\u0005z\u0001\u0000\u0003z\u0001\u0000\u0002z\b\u0000\u0002z\u0002\u0000\bz\u0002\u0000\u0003z\u0002\u0000\u0003z\u0003\u0000\u0003z\u0001\u0000\u0003z\u0005\u0000\u0005z\u0001Ħ\u0003z\u0001\u0000\u0005z\u0001\u0000\u0003z\u0001\u0000\u0002z\b\u0000\u0002z\u0002\u0000\bz\u0002\u0000\u0003z\u0002\u0000\u0003z\u0003\u0000\u0003z\u0001\u0000\u0003z\u0005\u0000\tz\u0001\u0000\u0001ħ\u0004z\u0001\u0000\u0003z\u0001\u0000\u0002z\b\u0000\u0002z\u0002\u0000\bz\u0002\u0000\u0003z\u0002\u0000\u0003z\u0003\u0000\u0003z\u0001\u0000\u0003z\u0005\u0000\u0001z\u0001Ĩ\u0007z\u0001\u0000\u0005z\u0001\u0000\u0003z\u0001\u0000\u0002z\b\u0000\u0002z\u0002\u0000\bz\u0002\u0000\u0003z\u0002\u0000\u0003z\u0003\u0000\u0003z\u0001\u0000\u0003z\u0005\u0000\u0004z\u0001ĩ\u0004z\u0001\u0000\u0005z\u0001\u0000\u0003z\u0001\u0000\u0002z\b\u0000\u0002z\u0002\u0000\bz\u0002\u0000\u0003z\u0002\u0000\u0003z\u0003\u0000\u0003z\u0001\u0000\u0003z\u0005\u0000\u0006z\u0001Ī\u0002z\u0001\u0000\u0005z\u0001\u0000\u0003z\u0001\u0000\u0002z\b\u0000\u0002z\u0002\u0000\bz\u0002\u0000\u0003z\u0002\u0000\u0003z\u0003\u0000\u0003z\u0001\u0000\u0003z\u0005\u0000\tz\u0001\u0000\u0005z\u0001\u0000\u0002z\u0001ī\u0001\u0000\u0002z\b\u0000\u0002z\u0002\u0000\bz\u0012\u0000\u0001ĬI\u0000\u0001ĭE\u0000\u0001ĮI\u0000\u0001į!\u0000\u0003ö\u0002\u0000\u0003ö\u0003\u0000\u0003ö\u0001\u0000\u0003ö\u0005\u0000\tö\u0001\u0000\u0005ö\u0001\u0000\u0003ö\u0001\u0000\u0002ö\b\u0000\u0002ö\u0002\u0000\bö\u0002\u0000\u0003ö\u0002\u0000\u0003ö\u0003\u0000\u0001ö\u0001İ\u0001ö\u0001\u0000\u0001ö\u0001ı\u0001ö\u0005\u0000\tö\u0001\u0000\u0005ö\u0001\u0000\u0003ö\u0001\u0000\u0002ö\b\u0000\u0002ö\u0002\u0000\bö\u0002\u0000\u0003ö\u0002\u0000\u0003ö\u0003\u0000\u0001ö\u0001ı\u0001ö\u0001\u0000\u0001ö\u0001ı\u0001ö\u0005\u0000\tö\u0001\u0000\u0005ö\u0001\u0000\u0003ö\u0001\u0000\u0002ö\b\u0000\u0002ö\u0002\u0000\bö\u0013\u0000\u0001Ĳ\u0006\u0000\u0001ĳH\u0000\u0001Ĵ=\u0000\u0001ĵH\u0000\u0001Ķ*\u0000\u0001Ą\f\u0000\u0001ķ\u0002\u0000\u0001Ą\u0004\u0000\u0001Ą\u0004\u0000\u0002Ą\u0001\u0000\u0001Ą\u0004\u0000\u0001Ą\u000f\u0000\u0001Ą\u0006\u0000\u0001Ą\u0002\u0000\u0003§\u0002\u0000\u0003§\u0003\u0000\u0003§\u0001\u0000\u0003§\u0002\u0000\u0001ĸ\u0002\u0000\t§\u0001\u0000\u0005§\u0001\u0000\u0003§\u0001\u0000\u0002§\b\u0000\u0002§\u0002\u0000\b§\u0002\u0000\u0003§\u0002\u0000\u0003§\u0003\u0000\u0003§\u0001\u0000\u0003§\u0002\u0000\u0001¨\u0002\u0000\t§\u0001\u0000\u0005§\u0001\u0000\u0003§\u0001\u0000\u0002§\b\u0000\u0001§\u0001Ĺ\u0002\u0000\b§\u0002\u0000\u0003§\u0002\u0000\u0003§\u0003\u0000\u0003§\u0001\u0000\u0003§\u0002\u0000\u0001¨\u0002\u0000\t§\u0001\u0000\u0005§\u0001\u0000\u0003§\u0001\u0000\u0002§\b\u0000\u0002§\u0002\u0000\u0005§\u0001ĺ\u0002§\u0002\u0000\u0003µ\u0002\u0000\u0003µ\u0003\u0000\u0002µ\u0001Ļ\u0001\u0000\u0002µ\u0001ļ\u0005\u0000\tµ\u0001\u0000\u0005µ\u0001\u0000\u0003µ\u0001\u0000\u0002µ\b\u0000\u0002µ\u0002\u0000\bµ\u0002\u0000\u0003µ\u0002\u0000\u0003µ\u0003\u0000\u0002µ\u0001ļ\u0001\u0000\u0002µ\u0001ļ\u0005\u0000\tµ\u0001\u0000\u0005µ\u0001\u0000\u0003µ\u0001\u0000\u0002µ\b\u0000\u0002µ\u0002\u0000\bµ!ċ\u0001Ľ!ċ$\u0000\u0001ľA\u0000\u0001Ŀ!\u0000\u0001Ď\u0001A\u0001Ď\u0002\u0000\u0003Ď\u0003\u0000\u0003Ď\u0001\u0000\u0003Ď\u0005\u0000\tĎ\u0001\u0000\u0005Ď\u0001\u0000\u0003Ď\u0001\u0000\u0002Ď\b\u0000\u0002Ď\u0002\u0000\bĎ\u0002\u0000\u0001B\u0001¼\u0001B\u0002\u0000\u0003B\u0003\u0000\u0003B\u0001\u0000\u0003B\u0005\u0000\tB\u0001\u0000\u0005B\u0001\u0000\u0003B\u0001\u0000\u0002B\b\u0000\u0001ŀ\u0001B\u0002\u0000\bB\u0002\u0000\u0001Đ\u0001F\u0001Đ\u0002\u0000\u0003Đ\u0003\u0000\u0003Đ\u0001\u0000\u0003Đ\u0005\u0000\tĐ\u0001\u0000\u0005Đ\u0001\u0000\u0003Đ\u0001\u0000\u0002Đ\b\u0000\u0002Đ\u0002\u0000\bĐ\u0002\u0000\u0002À\u0001Ł\u0002\u0000\u0001Ł\u0002À\u0003\u0000\u0003Ł\u0001\u0000\u0003Ł\u0005\u0000\bŁ\u0001À\u0001\u0000\u0005Ł\u0001\u0000\u0003Ł\u0001\u0000\u0002Ł\b\u0000\u0002Ł\u0002\u0000\bŁ\t\u0000\u0001Ĕ\f\u0000\u0001ł\u0002\u0000\u0001Ĕ\u0004\u0000\u0001Ĕ\u0004\u0000\u0002Ĕ\u0001\u0000\u0001Ĕ\u0004\u0000\u0001Ĕ\u000f\u0000\u0001Ĕ\u0006\u0000\u0001Ĕ\u0002\u0000\u0003Æ\u0002\u0000\u0003Æ\u0003\u0000\u0003Æ\u0001\u0000\u0003Æ\u0002\u0000\u0001Ń\u0002\u0000\tÆ\u0001\u0000\u0005Æ\u0001\u0000\u0003Æ\u0001\u0000\u0002Æ\b\u0000\u0002Æ\u0002\u0000\bÆ\u0002\u0000\u0003Æ\u0002\u0000\u0003Æ\u0003\u0000\u0003Æ\u0001\u0000\u0003Æ\u0002\u0000\u0001Ç\u0002\u0000\tÆ\u0001\u0000\u0005Æ\u0001\u0000\u0003Æ\u0001\u0000\u0002Æ\b\u0000\u0001Æ\u0001ń\u0002\u0000\bÆ\u0002\u0000\u0003Æ\u0002\u0000\u0003Æ\u0003\u0000\u0003Æ\u0001\u0000\u0003Æ\u0002\u0000\u0001Ç\u0002\u0000\tÆ\u0001\u0000\u0005Æ\u0001\u0000\u0003Æ\u0001\u0000\u0002Æ\b\u0000\u0002Æ\u0002\u0000\u0005Æ\u0001Ņ\u0002Æ\u0002\u0000\u0001Ĝ\u0001p\u0001Ĝ\u0002\u0000\u0003Ĝ\u0003\u0000\u0003Ĝ\u0001\u0000\u0003Ĝ\u0005\u0000\tĜ\u0001\u0000\u0005Ĝ\u0001\u0000\u0003Ĝ\u0001\u0000\u0002Ĝ\b\u0000\u0002Ĝ\u0002\u0000\bĜ\u001c\u0000\u0001ņF\u0000\u0001Ň@\u0000\u0001ň=\u0000\u0001ŉD\u0000\u0001Ŋ)\u0000\u0003z\u0002\u0000\u0003z\u0003\u0000\u0003z\u0001\u0000\u0003z\u0005\u0000\u0002z\u0001ŋ\u0006z\u0001\u0000\u0005z\u0001\u0000\u0003z\u0001\u0000\u0002z\b\u0000\u0002z\u0002\u0000\bz\u0002\u0000\u0003z\u0002\u0000\u0003z\u0003\u0000\u0003z\u0001\u0000\u0003z\u0005\u0000\u0005z\u0001Ō\u0003z\u0001\u0000\u0005z\u0001\u0000\u0003z\u0001\u0000\u0002z\b\u0000\u0002z\u0002\u0000\bz\u0002\u0000\u0003z\u0002\u0000\u0003z\u0003\u0000\u0003z\u0001\u0000\u0003z\u0005\u0000\u0002z\u0001ō\u0006z\u0001\u0000\u0005z\u0001\u0000\u0003z\u0001\u0000\u0002z\b\u0000\u0002z\u0002\u0000\bz\u0002\u0000\u0003z\u0002\u0000\u0003z\u0003\u0000\u0003z\u0001\u0000\u0002z\u0001Ŏ\u0005\u0000\tz\u0001\u0000\u0005z\u0001\u0000\u0003z\u0001\u0000\u0002z\b\u0000\u0002z\u0002\u0000\bz\u0002\u0000\u0003z\u0002\u0000\u0003z\u0003\u0000\u0003z\u0001\u0000\u0003z\u0005\u0000\u0007z\u0001ŏ\u0001z\u0001\u0000\u0005z\u0001\u0000\u0003z\u0001\u0000\u0002z\b\u0000\u0002z\u0002\u0000\bz\u0002\u0000\u0003z\u0002\u0000\u0003z\u0003\u0000\u0003z\u0001\u0000\u0003z\u0005\u0000\u0002z\u0001Ő\u0006z\u0001\u0000\u0005z\u0001\u0000\u0003z\u0001\u0000\u0002z\b\u0000\u0002z\u0002\u0000\bz\u0002\u0000\u0003z\u0002\u0000\u0003z\u0003\u0000\u0003z\u0001\u0000\u0002z\u0001ő\u0005\u0000\tz\u0001\u0000\u0005z\u0001\u0000\u0003z\u0001\u0000\u0002z\b\u0000\u0002z\u0002\u0000\bz)\u0000\u0001ŒF\u0000\u0001œ&\u0000\u0001ŔU\u0000\u0001ŕ \u0000\u0003ö\u0002\u0000\u0003ö\u0003\u0000\u0002ö\u0001Ŗ\u0001\u0000\u0002ö\u0001ŗ\u0005\u0000\tö\u0001\u0000\u0005ö\u0001\u0000\u0003ö\u0001\u0000\u0002ö\b\u0000\u0002ö\u0002\u0000\bö\u0002\u0000\u0003ö\u0002\u0000\u0003ö\u0003\u0000\u0002ö\u0001ŗ\u0001\u0000\u0002ö\u0001ŗ\u0005\u0000\tö\u0001\u0000\u0005ö\u0001\u0000\u0003ö\u0001\u0000\u0002ö\b\u0000\u0002ö\u0002\u0000\bö\u0019\u0000\u0001ŘD\u0000\u0001řB\u0000\u0001ŚB\u0000\u0001ś)\u0000\u0003§\u0002\u0000\u0003§\u0003\u0000\u0003§\u0001\u0000\u0003§\u0002\u0000\u0001Ŝ\u0002\u0000\t§\u0001\u0000\u0005§\u0001\u0000\u0003§\u0001\u0000\u0002§\b\u0000\u0002§\u0002\u0000\b§\u0002\u0000\u0003§\u0002\u0000\u0003§\u0003\u0000\u0003§\u0001\u0000\u0003§\u0002\u0000\u0001ŝ\u0002\u0000\t§\u0001\u0000\u0005§\u0001\u0000\u0003§\u0001\u0000\u0002§\b\u0000\u0002§\u0002\u0000\b§\u0001\u0000\u0001Ş\u0003µ\u0001\u0000\u0001ş\u0003µ\u0002\u0000\u0001Ş\u0003µ\u0001Ş\u0003µ\u0005\u0000\tµ\u0001\u0000\u0005µ\u0001\u0000\u0003µ\u0001\u0000\u0002µ\b\u0000\u0002µ\u0001\u0000\u0001Ş\bµ\u0001\u0000\u0001ş\u0003µ\u0001\u0000\u0001ş\u0003µ\u0002\u0000\u0001ş\u0003µ\u0001ş\u0003µ\u0005\u0000\tµ\u0001\u0000\u0005µ\u0001\u0000\u0003µ\u0001\u0000\u0002µ\b\u0000\u0002µ\u0001\u0000\u0001ş\bµ!ċ\u0001Š!ċ\u001e\u0000\u0001š?\u0000\u0001Ţ)\u0000\u0001B\u0001¼\u0001B\u0002\u0000\u0003B\u0003\u0000\u0003B\u0001\u0000\u0003B\u0005\u0000\tB\u0001\u0000\u0005B\u0001\u0000\u0003B\u0001\u0000\u0002B\b\u0000\u0001B\u0001ţ\u0002\u0000\bB\u0002\u0000\u0001Ł\u0001À\u0001Ł\u0002\u0000\u0003Ł\u0003\u0000\u0003Ł\u0001\u0000\u0003Ł\u0005\u0000\tŁ\u0001\u0000\u0005Ł\u0001\u0000\u0003Ł\u0001\u0000\u0002Ł\b\u0000\u0002Ł\u0002\u0000\bŁ\u0002\u0000\u0003Æ\u0002\u0000\u0003Æ\u0003\u0000\u0003Æ\u0001\u0000\u0003Æ\u0002\u0000\u0001Ť\u0002\u0000\tÆ\u0001\u0000\u0005Æ\u0001\u0000\u0003Æ\u0001\u0000\u0002Æ\b\u0000\u0002Æ\u0002\u0000\bÆ\u0002\u0000\u0003Æ\u0002\u0000\u0003Æ\u0003\u0000\u0003Æ\u0001\u0000\u0003Æ\u0002\u0000\u0001ť\u0002\u0000\tÆ\u0001\u0000\u0005Æ\u0001\u0000\u0003Æ\u0001\u0000\u0002Æ\b\u0000\u0002Æ\u0002\u0000\bÆ\u001b\u0000\u0001ŦN\u0000\u0001ŧ6\u0000\u0001ŨM\u0000\u0001ũ:\u0000\u0001Ū&\u0000\u0003z\u0002\u0000\u0003z\u0003\u0000\u0003z\u0001\u0000\u0003z\u0005\u0000\u0004z\u0001ū\u0004z\u0001\u0000\u0005z\u0001\u0000\u0003z\u0001\u0000\u0002z\b\u0000\u0002z\u0002\u0000\bz\u0002\u0000\u0003z\u0002\u0000\u0003z\u0003\u0000\u0003z\u0001\u0000\u0003z\u0005\u0000\u0002z\u0001Ŭ\u0006z\u0001\u0000\u0005z\u0001\u0000\u0003z\u0001\u0000\u0002z\b\u0000\u0002z\u0002\u0000\bz\u0002\u0000\u0003z\u0002\u0000\u0003z\u0003\u0000\u0003z\u0001\u0000\u0003z\u0005\u0000\u0005z\u0001ŭ\u0003z\u0001\u0000\u0005z\u0001\u0000\u0003z\u0001\u0000\u0002z\b\u0000\u0002z\u0002\u0000\bz\u0002\u0000\u0003z\u0002\u0000\u0003z\u0003\u0000\u0003z\u0001\u0000\u0003z\u0005\u0000\tz\u0001\u0000\u0005z\u0001\u0000\u0001z\u0001Ů\u0001z\u0001\u0000\u0002z\b\u0000\u0002z\u0002\u0000\bz\u0002\u0000\u0003z\u0002\u0000\u0003z\u0003\u0000\u0003z\u0001\u0000\u0003z\u0005\u0000\tz\u0001\u0000\u0002z\u0001ů\u0002z\u0001\u0000\u0003z\u0001\u0000\u0002z\b\u0000\u0002z\u0002\u0000\bz\u0002\u0000\u0003z\u0002\u0000\u0003z\u0003\u0000\u0003z\u0001\u0000\u0003z\u0005\u0000\u0001Ű\bz\u0001\u0000\u0005z\u0001\u0000\u0003z\u0001\u0000\u0002z\b\u0000\u0002z\u0002\u0000\bz\u0002\u0000\u0003z\u0002\u0000\u0003z\u0003\u0000\u0003z\u0001\u0000\u0003z\u0005\u0000\u0003z\u0001ű\u0005z\u0001\u0000\u0005z\u0001\u0000\u0003z\u0001\u0000\u0002z\b\u0000\u0002z\u0002\u0000\bz\u0013\u0000\u0001ŲY\u0000\u0001ų1\u0000\u0001ŴG\u0000\u0001ŵ%\u0000\u0001Ŷ\u0003ö\u0001\u0000\u0001ş\u0003ö\u0002\u0000\u0001Ŷ\u0003ö\u0001Ŷ\u0003ö\u0005\u0000\tö\u0001\u0000\u0005ö\u0001\u0000\u0003ö\u0001\u0000\u0002ö\b\u0000\u0002ö\u0001\u0000\u0001Ŷ\bö\u0001\u0000\u0001ş\u0003ö\u0001\u0000\u0001ş\u0003ö\u0002\u0000\u0001ş\u0003ö\u0001ş\u0003ö\u0005\u0000\tö\u0001\u0000\u0005ö\u0001\u0000\u0003ö\u0001\u0000\u0002ö\b\u0000\u0002ö\u0001\u0000\u0001ş\bö\u0012\u0000\u0001ŷL\u0000\u0001ŸD\u0000\u0001Ź7\u0000\u0001źC\u0000\u0001ŻI\u0000\u0001żD\u0000\u0001Ž&\u0000\u0001ž\u0001B\u0001ſ\u0001B\u0001\u0000\u0001ž\u0003B\u0003\u0000\u0003B\u0001ž\u0003B\u0005\u0000\tB\u0001\u0000\u0005B\u0001\u0000\u0003B\u0001\u0000\u0002B\b\u0000\u0002B\u0001ƀ\u0001ž\bB\u001c\u0000\u0001Ɓ\u0001Ƃ>\u0000\u0001ƃE\u0000\u0001ƄE\u0000\u0001ƅ%\u0000\u0003z\u0002\u0000\u0003z\u0003\u0000\u0003z\u0001\u0000\u0003z\u0005\u0000\u0003z\u0001Ɔ\u0005z\u0001\u0000\u0005z\u0001\u0000\u0003z\u0001\u0000\u0002z\b\u0000\u0002z\u0002\u0000\bz\u0002\u0000\u0003z\u0002\u0000\u0003z\u0003\u0000\u0003z\u0001\u0000\u0003z\u0005\u0000\tz\u0001\u0000\u0001z\u0001Ƈ\u0003z\u0001\u0000\u0003z\u0001\u0000\u0002z\b\u0000\u0002z\u0002\u0000\bz\u0002\u0000\u0003z\u0002\u0000\u0003z\u0003\u0000\u0003z\u0001\u0000\u0003z\u0005\u0000\u0001ƈ\bz\u0001\u0000\u0005z\u0001\u0000\u0003z\u0001\u0000\u0002z\b\u0000\u0002z\u0002\u0000\bz\u0002\u0000\u0003z\u0002\u0000\u0003z\u0003\u0000\u0003z\u0001\u0000\u0001z\u0001Ɖ\u0001z\u0005\u0000\tz\u0001\u0000\u0005z\u0001\u0000\u0003z\u0001\u0000\u0002z\b\u0000\u0002z\u0002\u0000\bz\u0002\u0000\u0003z\u0002\u0000\u0003z\u0003\u0000\u0003z\u0001\u0000\u0003z\u0005\u0000\tz\u0001\u0000\u0001Ɗ\u0004z\u0001\u0000\u0003z\u0001\u0000\u0002z\b\u0000\u0002z\u0002\u0000\bz\u001c\u0000\u0001ƋB\u0000\u0001ƌJ\u0000\u0001ƍ9\u0000\u0001Ǝ@\u0000\u0001ƏD\u0000\u0001ƐB\u0000\u0001ƑC\u0000\u0001ƒD\u0000\u0001ƓM\u0000\u0001Ɣ\u001a\u0000\u0001ž\u0004\u0000\u0001ž\t\u0000\u0001ž(\u0000\u0001ƀ\u0001ž\n\u0000\u0002A\u0001ƕ\u0002\u0000\u0001ƕ\u0002A\u0003\u0000\u0003ƕ\u0001\u0000\u0003ƕ\u0005\u0000\bƕ\u0001A\u0001\u0000\u0005ƕ\u0001\u0000\u0003ƕ\u0001\u0000\u0002ƕ\b\u0000\u0002ƕ\u0002\u0000\bƕ\u0001\u0000\u0001ƀ\u0004\u0000\u0001ƀ\t\u0000\u0001ƀ#\u0000\u0001Ɩ\u0001Ɨ\u0004\u0000\u0001ƀ!\u0000\u0001ƘC\u0000\u0001ƙH\u0000\u0001ƚ$\u0000\u0003z\u0002\u0000\u0003z\u0003\u0000\u0003z\u0001\u0000\u0003z\u0005\u0000\u0007z\u0001ƛ\u0001z\u0001\u0000\u0005z\u0001\u0000\u0003z\u0001\u0000\u0002z\b\u0000\u0002z\u0002\u0000\bz\u0002\u0000\u0003z\u0002\u0000\u0003z\u0003\u0000\u0003z\u0001\u0000\u0003z\u0005\u0000\u0001Ɯ\bz\u0001\u0000\u0005z\u0001\u0000\u0003z\u0001\u0000\u0002z\b\u0000\u0002z\u0002\u0000\bz\u0019\u0000\u0001ƝN\u0000\u0001ƞ;\u0000\u0001Ɵ>\u0000\u0001ƠE\u0000\u0001ơA\u0000\u0001ƢE\u0000\u0001ƣE\u0000\u0001Ƥ9\u0000\u0001ƥ+\u0000\u0001ƕ\u0001A\u0001ƕ\u0002\u0000\u0003ƕ\u0003\u0000\u0003ƕ\u0001\u0000\u0003ƕ\u0005\u0000\tƕ\u0001\u0000\u0005ƕ\u0001\u0000\u0003ƕ\u0001\u0000\u0002ƕ\b\u0000\u0002ƕ\u0002\u0000\bƕ\u001f\u0000\u0001ƦB\u0000\u0001Ƨ=\u0000\u0001ƨ*\u0000\u0003z\u0002\u0000\u0003z\u0003\u0000\u0003z\u0001\u0000\u0003z\u0005\u0000\u0001z\u0001Ʃ\u0007z\u0001\u0000\u0005z\u0001\u0000\u0003z\u0001\u0000\u0002z\b\u0000\u0002z\u0002\u0000\bz$\u0000\u0001ƪ7\u0000\u0001ƫD\u0000\u0001ƬG\u0000\u0001ƭ=\u0000\u0001Ʈ(\u0000\u0001Ư\u000e\u0000\u0001Ư)\u0000\u0001Ư,\u0000\u0001ư8\u0000\u0001Ʊ(\u0000";
    public static final int[] yy_rowMap = {0, 67, 134, HSSFShapeTypes.HostControl, 268, 335, 402, 469, 536, 603, 670, 737, 804, 871, 938, 1005, 1072, 1139, 1206, 1273, 1340, 1407, 1474, 1541, 1608, 1675, 1742, 1809, 1876, 1943, 2010, 2077, 2144, 2211, 2278, 2345, 2412, 2479, 2546, 2546, 2546, 2546, 2613, 2680, 2546, 2546, 2747, 2814, 2881, 2948, 3015, 3082, 3149, 3216, 3283, 3350, 3417, 3484, 2546, 3551, 3618, 3685, 3752, 3819, 3886, 3953, 4020, 2546, 4087, 4154, 4221, 4288, 4355, 4422, 4489, 2546, 2546, 4556, 4623, 4690, 4757, 4824, 4891, 4958, 5025, 2546, 5092, 5159, 5226, 5293, 2546, 5360, 5427, 5494, 2546, 5561, 5628, 2546, 5695, 5762, 5829, 5896, 2546, 5963, 2546, 6030, 2546, 6097, 6164, 6231, 6298, 6365, 6432, 2546, 6499, 6566, 6633, 6700, 2546, 6767, 6834, 6901, 2546, 2546, 6968, 7035, 7102, 7169, 7236, 7303, 7370, 7437, 2546, 7504, 7571, 7638, 7705, 7772, 7839, 2546, 7906, 7973, 2546, 2546, 2546, 2546, 8040, 8107, 8174, 8241, 8308, 2546, 2546, 8375, 8442, 8509, 8576, 2546, 2546, 2546, 8643, 8710, 8777, 2613, 2680, 2546, 2747, 2546, 8844, 8911, 8978, 9045, 9112, 9179, 9246, 3149, 3216, 2546, 2546, 2546, 9313, 9380, 9447, 9514, 9581, 9648, 9715, 9782, 9849, 2546, 9916, 9983, 10050, 4355, 4422, 2546, 2546, 4556, 2546, 10117, 10184, 10251, 10318, 10385, 10452, 10519, 2546, 5360, 2546, 5695, 2546, 5896, 5963, 10586, 10653, 2546, 10720, 10787, 10854, 10921, 10988, 11055, 11122, 11189, 11256, 6968, 7035, 11323, 11390, 7303, 2546, 7370, 11457, 11524, 11591, 11658, 11725, 11792, 11859, 11926, 11993, 12060, 12127, 12194, 2546, 12261, 12328, 12395, 12462, 12529, 12596, 12663, 2546, 8710, 2546, 8777, 2546, 2546, 2546, 12730, 12797, 12864, 12931, 2546, 12998, 13065, 13132, 13199, 13266, 13333, 13400, 13467, 13534, 2546, 2546, 13601, 13668, 13735, 13802, 2546, 2546, 2546, 2546, 13869, 13936, 14003, 14070, 14137, 14204, 2546, 2546, 14271, 14338, 14405, 14472, 14539, 6901, 14606, 14673, 14740, 14807, 14874, 14941, 15008, 15075, 15142, 15209, 15276, 15343, 2546, 2546, 2546, 15410, 15477, 15544, 15611, 15678, 15745, 15812, 15879, 15946, 2546, 2546, 16013, 16080, 16147, 16214, 16281, 16348, 16415, 16482, 16549, 16616, 16683, 16750, 16817, 16884, 16951, 17018, 17085, 17152, 17219, 17286, 17353, 17420, 17487, 17554, 2546, 2546, 2546, 2546, 17621, 17688, 17755, 17822, 2546, 2546, 17889, 17956, 18023, 18090, 2546, 6901, 18157, 6901, 18224, 18291, 18358, 18425, 18492, 18559, 18626, 18693, 2546, 18760, 18827, 18894, 18961, 2546, 19028, 19095, 19162, 19229, 19296, 19363, 2546, 19430, 19497, 2546, 19564, 19631, 6901, 6901, 6901, 19698, 19765, 2546, 19832, 19899, 19966, 20033, 20100, 20167, 20234, 20301, 2546, 2546, 20368, 20435, 20502, 20569, 6901, 20636, 20703, 2546, 20770, 2546, 20837, 20904, 2546, 20971, 2546, 2546, 2546, 6901, 2546, 21038, 2546, 21105, 2546, 20971, 2546, 2546};
    public static final char[] yycmap = yy_unpack_cmap(yycmap_packed);
    public static final String yycmap_packed = "\t\u0000\u0001\u0001\u0001:\u0002\u0000\u0001\u0006\u0012\u0000\u0001\u0010\u0001\u0018\u00014\u0001,\u0001\u0005\u0001\u0015\u0001\u000b\u00015\u0001(\u0001/\u00010\u00011\u00012\u0001!\u0001\u0002\u00016\n\t\u0001\u0003\u0001\u0016\u0001\n\u00019\u0001\u0014\u0001\f\u0001\u0005\u0001\u001e\u0001+\u0001#\u0001$\u0001\u0019\u0001&\u0001.\u0001\u0004\u0001\u001c\u0001\u0004\u0001'\u0001\u0013\u0001\u0012\u0001\u001a\u0001 \u0001)\u0001-\u0001%\u0001\u001f\u0001\u001b\u0001*\u0002\u0004\u0001\u0011\u0001\u001d\u0001\u0004\u0001\"\u0001\u0000\u0001\u0017\u0001\u0000\u0001\u0004\u0001\u0000\u0001;\u0005B\u0001A\u0004\u0004\u0001\u000f\u0001\u000e\u00017\u0001?\u0001<\u0001=\u0001\u0004\u00018\u0001@\u0001>\u0002\u0004\u0001\r\u0002\u0004\u0001\u0000\u00013:\u0000\u0001\b\b\u0000\u0017\u0007\u0001\u0000\u001f\u0007\u0001\u0000:\u0007\u0002\u0000\u000b\u0007\u0002\u0000\b\u0007\u0001\u00005\u0007\u0001\u0000D\u0007\t\u0000$\u0007\u0003\u0000\u0002\u0007\u0004\u0000\u001e\u00078\u0000Y\u0007\u0012\u0000\u0007\u0007\u000e\u0000\u0002\b.\u0000F\b\u001a\u0000\u0002\b$\u0000\u0001\u0007\u0001\b\u0003\u0007\u0001\u0000\u0001\u0007\u0001\u0000\u0014\u0007\u0001\u0000,\u0007\u0001\u0000\u0007\u0007\u0003\u0000\u0001\u0007\u0001\u0000\u0001\u0007\u0001\u0000\u0001\u0007\u0001\u0000\u0001\u0007\u0001\u0000\u0012\u0007\r\u0000\f\u0007\u0001\u0000B\u0007\u0001\u0000\f\u0007\u0001\u0000$\u0007\u0001\u0000\u0004\b\t\u00005\u0007\u0002\u0000\u0002\u0007\u0002\u0000\u0002\u0007\u0003\u0000\u001c\u0007\u0002\u0000\b\u0007\u0002\u0000\u0002\u00077\u0000&\u0007\u0002\u0000\u0001\u0007\u0007\u0000&\u0007\n\u0000\u0011\b\u0001\u0000\u0017\b\u0001\u0000\u0003\b\u0001\u0000\u0001\b\u0001\u0000\u0002\b\u0001\u0000\u0001\b\u000b\u0000\u001b\u0007\u0005\u0000\u0003\u0007.\u0000\u001a\u0007\u0005\u0000\u0001\b\n\u0007\b\b\r\u0000\n\b\u0006\u0000\u0001\bG\u0007\u0002\u0000\u0005\u0007\u0001\u0000\u000f\u0007\u0001\u0000\u0004\u0007\u0001\u0000\u0001\u0007\u000f\b\u0002\u0007\u0002\b\u0001\u0000\u0004\b\u0002\u0000\n\bȇ\u0000\u0003\b\u0001\u00005\u0007\u0002\u0000\u0001\b\u0001\u0007\u0010\b\u0003\u0000\u0004\b\u0003\u0000\n\u0007\u0002\b\u0002\u0000\n\b\u0011\u0000\u0003\b\u0001\u0000\b\u0007\u0002\u0000\u0002\u0007\u0002\u0000\u0016\u0007\u0001\u0000\u0007\u0007\u0001\u0000\u0001\u0007\u0003\u0000\u0004\u0007\u0002\u0000\u0001\b\u0001\u0000\u0007\b\u0002\u0000\u0002\b\u0002\u0000\u0003\b\t\u0000\u0001\b\u0004\u0000\u0002\u0007\u0001\u0000\u0003\u0007\u0002\b\u0002\u0000\n\b\u0002\u0007\u0010\u0000\u0001\b\u0002\u0000\u0006\u0007\u0004\u0000\u0002\u0007\u0002\u0000\u0016\u0007\u0001\u0000\u0007\u0007\u0001\u0000\u0002\u0007\u0001\u0000\u0002\u0007\u0001\u0000\u0002\u0007\u0002\u0000\u0001\b\u0001\u0000\u0005\b\u0004\u0000\u0002\b\u0002\u0000\u0003\b\u000b\u0000\u0004\u0007\u0001\u0000\u0001\u0007\u0007\u0000\n\b\u0002\b\u0003\u0007\f\u0000\u0003\b\u0001\u0000\u0007\u0007\u0001\u0000\u0001\u0007\u0001\u0000\u0003\u0007\u0001\u0000\u0016\u0007\u0001\u0000\u0007\u0007\u0001\u0000\u0002\u0007\u0001\u0000\u0005\u0007\u0002\u0000\u0001\b\u0001\u0007\b\b\u0001\u0000\u0003\b\u0001\u0000\u0003\b\u0012\u0000\u0001\u0007\u0005\u0000\n\b\u0011\u0000\u0003\b\u0001\u0000\b\u0007\u0002\u0000\u0002\u0007\u0002\u0000\u0016\u0007\u0001\u0000\u0007\u0007\u0001\u0000\u0002\u0007\u0002\u0000\u0004\u0007\u0002\u0000\u0001\b\u0001\u0007\u0006\b\u0003\u0000\u0002\b\u0002\u0000\u0003\b\b\u0000\u0002\b\u0004\u0000\u0002\u0007\u0001\u0000\u0003\u0007\u0004\u0000\n\b\u0012\u0000\u0002\b\u0001\u0000\u0006\u0007\u0003\u0000\u0003\u0007\u0001\u0000\u0004\u0007\u0003\u0000\u0002\u0007\u0001\u0000\u0001\u0007\u0001\u0000\u0002\u0007\u0003\u0000\u0002\u0007\u0003\u0000\u0003\u0007\u0003\u0000\b\u0007\u0001\u0000\u0003\u0007\u0004\u0000\u0005\b\u0003\u0000\u0003\b\u0001\u0000\u0004\b\t\u0000\u0001\b\u000f\u0000\t\b\u0011\u0000\u0003\b\u0001\u0000\b\u0007\u0001\u0000\u0003\u0007\u0001\u0000\u0017\u0007\u0001\u0000\n\u0007\u0001\u0000\u0005\u0007\u0004\u0000\u0007\b\u0001\u0000\u0003\b\u0001\u0000\u0004\b\u0007\u0000\u0002\b\t\u0000\u0002\u0007\u0004\u0000\n\b\u0012\u0000\u0002\b\u0001\u0000\b\u0007\u0001\u0000\u0003\u0007\u0001\u0000\u0017\u0007\u0001\u0000\n\u0007\u0001\u0000\u0005\u0007\u0004\u0000\u0007\b\u0001\u0000\u0003\b\u0001\u0000\u0004\b\u0007\u0000\u0002\b\u0007\u0000\u0001\u0007\u0001\u0000\u0002\u0007\u0004\u0000\n\b\u0012\u0000\u0002\b\u0001\u0000\b\u0007\u0001\u0000\u0003\u0007\u0001\u0000\u0017\u0007\u0001\u0000\u0010\u0007\u0004\u0000\u0006\b\u0002\u0000\u0003\b\u0001\u0000\u0004\b\t\u0000\u0001\b\b\u0000\u0002\u0007\u0004\u0000\n\b\u0000.\u0007\u0001\u0000\u0001\u0007\u0001\b\u0002\u0007\u0007\b\u0005\u0000\u0006\u0007\u0001\b\b\b\u0001\u0000\n\b'\u0000\u0002\u0007\u0001\u0000\u0001\u0007\u0002\u0000\u0002\u0007\u0001\u0000\u0001\u0007\u0002\u0000\u0001\u0007\u0006\u0000\u0004\u0007\u0001\u0000\u0007\u0007\u0001\u0000\u0003\u0007\u0001\u0000\u0001\u0007\u0001\u0000\u0001\u0007\u0002\u0000\u0002\u0007\u0001\u0000\u0002\u0007\u0001\u0000\u0001\u0007\u0001\b\u0002\u0007\u0006\b\u0001\u0000\u0002\b\u0001\u0007\u0002\u0000\u0005\u0007\u0001\u0000\u0001\b\u0001\u0000\u0006\b\u0002\u0000\n\b>\u0000\u0002\b\u0006\u0000\n\b\u000b\u0000\u0001\b\u0001\u0000\u0001\b\u0001\u0000\u0001\b\u0004\u0000\u0002\b\b\u0007\u0001\u0000!\u0007\u0007\u0000\u0014\b\u0001\u0000\u0006\b\u0004\u0000\u0006\b\u0001\u0000\u0001\b\u0001\u0000\u0015\b\u0003\u0000\u0007\b\u0001\u0000\u0001\bæ\u0000&\u0007\n\u0000'\u0007\t\u0000\u0001\u0007\u0001\u0000\u0002\u0007\u0001\u0000\u0003\u0007\u0001\u0000\u0001\u0007\u0001\u0000\u0002\u0007\u0001\u0000\u0005\u0007)\u0000\u0001\u0007\u0001\u0000\u0001\u0007\u0001\u0000\u0001\u0007\u000b\u0000\u0001\u0007\u0001\u0000\u0001\u0007\u0001\u0000\u0001\u0007\u0003\u0000\u0002\u0007\u0003\u0000\u0001\u0007\u0005\u0000\u0003\u0007\u0001\u0000\u0001\u0007\u0001\u0000\u0001\u0007\u0001\u0000\u0001\u0007\u0001\u0000\u0001\u0007\u0003\u0000\u0002\u0007\u0003\u0000\u0002\u0007\u0001\u0000\u0001\u0007(\u0000\u0001\u0007\t\u0000\u0001\u0007\u0002\u0000\u0001\u0007\u0002\u0000\u0002\u0007\u0007\u0000\u0002\u0007\u0001\u0000\u0001\u0007\u0001\u0000\u0007\u0007(\u0000\u0001\u0007\u0004\u0000\u0001\u0007\b\u0000\u0001\u0007ఆ\u0000\u0007\u0004\u0000Z\u0007\u0006\u0000\u0016\u0007\u0002\u0000\u0006\u0007\u0002\u0000&\u0007\u0002\u0000\u0006\u0007\u0002\u0000\b\u0007\u0001\u0000\u0001\u0007\u0001\u0000\u0001\u0007\u0001\u0000\u0001\u0007\u0001\u0000\u001f\u0007\u0002\u00005\u0007\u0001\u0000\u0007\u0007\u0001\u0000\u0001\u0007\u0003\u0000\u0003\u0007\u0001\u0000\u0007\u0007\u0003\u0000\u0004\u0007\u0002\u0000\u0006\u0007\u0004\u0000\r\u0007\u0005\u0000\u0003\u0007\u0001\u0000\u0007\u0007Ó\u0000\r\b\u0004\u0000\u0001\bD\u0000\u0001\u0007\u0003\u0000\u0002\u0007\u0002\u0000\u0001\u0007Q\u0000\u0003\u0007ຂ\u0000\u0001\b\u0001\u0000\u0001\u0007\u0019\u0000\t\u0007\u0006\b\u0001\u0000\u0005\b\u000b\u0000T\u0007\u0004\u0000\u0002\b\u0002\u0000\u0002\b\u0002\u0000Z\u0007\u0001\u0000\u0003\b\u0006\u0000(\u0007᳓\u0000冦\u0007ౚ\u0000⮤\u0007⡜\u0000";
    public static final int[] yytrans = yy_unpack();
    public AttributesHolder attribs;
    public String attributeLocalName;
    public String attributeQName;
    public String attributeURI;
    public String attributeValueType;
    public int baseState;
    public boolean bypassGERefs;
    public boolean bypassPERefs;
    public char[] cbuf;
    public int cbuflen;
    public char[] cdataBuffer;
    public int cdataLength;
    public int cdataStart;
    public Entity currentEntity;
    public String currentEntityName;
    public boolean[] defaultAttributeSpecified;
    public ElementDefinition elementDefinition;
    public String elementLocalName;
    public HashMap elementMap;
    public String elementQName;
    public String elementURI;
    public boolean endOfTag;
    public int entityBaseDepth;
    public EntityManager entityManager;
    public StringStack entityNameStack;
    public Stack entityStack;
    public LongStack entityStateStack;
    public boolean entityWasSkipped;
    public boolean inCdataSection;
    public boolean isEntityBeingParsed;
    public boolean isNamespaceDeclaration;
    public boolean isParamEntity;
    public boolean needsNormalization;
    public FastNamespaceSupport nsSupport;
    public int numAttributesDefined;
    public char[] oneCharBuffer;
    public Piccolo parser;
    public int piPrevState;
    public int prevEntityLexState;
    public int prevState;
    public boolean returnEntityEndToken;
    public CharStringConverter stringConverter;
    public String stringValue;
    public StringStack tagStack;
    public int tagStartState;
    public int tagState;
    public int tagType;
    public int tokenStartColumn;
    public int tokenStartLine;
    public boolean tokenizeInput;
    public boolean yy_atBOL;
    public boolean yy_atEOF;
    public char[] yy_buffer;
    public char[] yy_buffer_l;
    public int yy_currentPos;
    public int yy_currentPos_l;
    public int yy_endRead;
    public int yy_endRead_l;
    public boolean yy_eof_done;
    public int yy_lexical_state;
    public int yy_markedPos;
    public int yy_markedPos_l;
    public boolean yy_prev_sawCR;
    public int yy_pushbackPos;
    public Reader yy_reader;
    public int yy_savePos;
    public char[] yy_saved_buffer;
    public boolean yy_sawCR;
    public int yy_startRead;
    public int yy_startRead_l;
    public int yy_state;
    public Stack yy_streams;
    public int yychar;
    public char[] yycmap_l;
    public int yycolumn;
    public int yycolumn_next;
    public int yyline;
    public int yyline_next;

    public static final class YY_StreamInfo {
        public boolean yy_atEOF;
        public char[] yy_buffer;
        public int yy_currentPos;
        public int yy_endRead;
        public int yy_markedPos;
        public int yy_pushbackPos;
        public Reader yy_reader;
        public int yy_savePos;
        public int yy_startRead;
        public int yycolumn;
        public int yyline;

        public YY_StreamInfo(Reader reader, int i2, int i3, int i4, int i5, int i6, int i7, char[] cArr, boolean z, int i8, int i9) {
            this.yy_reader = reader;
            this.yy_endRead = i2;
            this.yy_startRead = i3;
            this.yy_savePos = i4;
            this.yy_currentPos = i5;
            this.yy_markedPos = i6;
            this.yy_pushbackPos = i7;
            this.yy_buffer = cArr;
            this.yy_atEOF = z;
            this.yyline = i8;
            this.yycolumn = i9;
        }
    }

    static {
        calcAsciiTables();
        char[] cArr = new char[HSSFShapeTypes.ActionButtonMovie];
        // fill-array-data instruction
        cArr[0] = 256;
        cArr[1] = 308;
        cArr[2] = 321;
        cArr[3] = 330;
        cArr[4] = 384;
        cArr[5] = 461;
        cArr[6] = 500;
        cArr[7] = 506;
        cArr[8] = 592;
        cArr[9] = 699;
        cArr[10] = 902;
        cArr[11] = 904;
        cArr[12] = 908;
        cArr[13] = 910;
        cArr[14] = 931;
        cArr[15] = 976;
        cArr[16] = 986;
        cArr[17] = 988;
        cArr[18] = 990;
        cArr[19] = 992;
        cArr[20] = 994;
        cArr[21] = 1025;
        cArr[22] = 1038;
        cArr[23] = 1105;
        cArr[24] = 1118;
        cArr[25] = 1168;
        cArr[26] = 1223;
        cArr[27] = 1227;
        cArr[28] = 1232;
        cArr[29] = 1262;
        cArr[30] = 1272;
        cArr[31] = 1329;
        cArr[32] = 1369;
        cArr[33] = 1377;
        cArr[34] = 1488;
        cArr[35] = 1520;
        cArr[36] = 1569;
        cArr[37] = 1601;
        cArr[38] = 1649;
        cArr[39] = 1722;
        cArr[40] = 1728;
        cArr[41] = 1744;
        cArr[42] = 1749;
        cArr[43] = 1765;
        cArr[44] = 2309;
        cArr[45] = 2365;
        cArr[46] = 2392;
        cArr[47] = 2437;
        cArr[48] = 2447;
        cArr[49] = 2451;
        cArr[50] = 2474;
        cArr[51] = 2482;
        cArr[52] = 2486;
        cArr[53] = 2524;
        cArr[54] = 2527;
        cArr[55] = 2544;
        cArr[56] = 2565;
        cArr[57] = 2575;
        cArr[58] = 2579;
        cArr[59] = 2602;
        cArr[60] = 2610;
        cArr[61] = 2613;
        cArr[62] = 2616;
        cArr[63] = 2649;
        cArr[64] = 2654;
        cArr[65] = 2674;
        cArr[66] = 2693;
        cArr[67] = 2701;
        cArr[68] = 2703;
        cArr[69] = 2707;
        cArr[70] = 2730;
        cArr[71] = 2738;
        cArr[72] = 2741;
        cArr[73] = 2749;
        cArr[74] = 2784;
        cArr[75] = 2821;
        cArr[76] = 2831;
        cArr[77] = 2835;
        cArr[78] = 2858;
        cArr[79] = 2866;
        cArr[80] = 2870;
        cArr[81] = 2877;
        cArr[82] = 2908;
        cArr[83] = 2911;
        cArr[84] = 2949;
        cArr[85] = 2958;
        cArr[86] = 2962;
        cArr[87] = 2969;
        cArr[88] = 2972;
        cArr[89] = 2974;
        cArr[90] = 2979;
        cArr[91] = 2984;
        cArr[92] = 2990;
        cArr[93] = 2999;
        cArr[94] = 3077;
        cArr[95] = 3086;
        cArr[96] = 3090;
        cArr[97] = 3114;
        cArr[98] = 3125;
        cArr[99] = 3168;
        cArr[100] = 3205;
        cArr[101] = 3214;
        cArr[102] = 3218;
        cArr[103] = 3242;
        cArr[104] = 3253;
        cArr[105] = 3294;
        cArr[106] = 3296;
        cArr[107] = 3333;
        cArr[108] = 3342;
        cArr[109] = 3346;
        cArr[110] = 3370;
        cArr[111] = 3424;
        cArr[112] = 3585;
        cArr[113] = 3632;
        cArr[114] = 3634;
        cArr[115] = 3648;
        cArr[116] = 3713;
        cArr[117] = 3716;
        cArr[118] = 3719;
        cArr[119] = 3722;
        cArr[120] = 3725;
        cArr[121] = 3732;
        cArr[122] = 3737;
        cArr[123] = 3745;
        cArr[124] = 3749;
        cArr[125] = 3751;
        cArr[126] = 3754;
        cArr[127] = 3757;
        cArr[128] = 3760;
        cArr[129] = 3762;
        cArr[130] = 3773;
        cArr[131] = 3776;
        cArr[132] = 3904;
        cArr[133] = 3913;
        cArr[134] = 4256;
        cArr[135] = 4304;
        cArr[136] = 4352;
        cArr[137] = 4354;
        cArr[138] = 4357;
        cArr[139] = 4361;
        cArr[140] = 4363;
        cArr[141] = 4366;
        cArr[142] = 4412;
        cArr[143] = 4414;
        cArr[144] = 4416;
        cArr[145] = 4428;
        cArr[146] = 4430;
        cArr[147] = 4432;
        cArr[148] = 4436;
        cArr[149] = 4441;
        cArr[150] = 4447;
        cArr[151] = 4451;
        cArr[152] = 4453;
        cArr[153] = 4455;
        cArr[154] = 4457;
        cArr[155] = 4461;
        cArr[156] = 4466;
        cArr[157] = 4469;
        cArr[158] = 4510;
        cArr[159] = 4520;
        cArr[160] = 4523;
        cArr[161] = 4526;
        cArr[162] = 4535;
        cArr[163] = 4538;
        cArr[164] = 4540;
        cArr[165] = 4587;
        cArr[166] = 4592;
        cArr[167] = 4601;
        cArr[168] = 7680;
        cArr[169] = 7840;
        cArr[170] = 7936;
        cArr[171] = 7960;
        cArr[172] = 7968;
        cArr[173] = 8008;
        cArr[174] = 8016;
        cArr[175] = 8025;
        cArr[176] = 8027;
        cArr[177] = 8029;
        cArr[178] = 8031;
        cArr[179] = 8064;
        cArr[180] = 8118;
        cArr[181] = 8126;
        cArr[182] = 8130;
        cArr[183] = 8134;
        cArr[184] = 8144;
        cArr[185] = 8150;
        cArr[186] = 8160;
        cArr[187] = 8178;
        cArr[188] = 8182;
        cArr[189] = 8486;
        cArr[190] = 8490;
        cArr[191] = 8494;
        cArr[192] = 8576;
        cArr[193] = 12295;
        cArr[194] = 12321;
        cArr[195] = 12353;
        cArr[196] = 12449;
        cArr[197] = 12549;
        cArr[198] = 19968;
        cArr[199] = 44032;
        LETTER_RANGE_START = cArr;
        char[] cArr2 = new char[HSSFShapeTypes.ActionButtonMovie];
        // fill-array-data instruction
        cArr2[0] = 305;
        cArr2[1] = 318;
        cArr2[2] = 328;
        cArr2[3] = 382;
        cArr2[4] = 451;
        cArr2[5] = 496;
        cArr2[6] = 501;
        cArr2[7] = 535;
        cArr2[8] = 680;
        cArr2[9] = 705;
        cArr2[10] = 902;
        cArr2[11] = 906;
        cArr2[12] = 908;
        cArr2[13] = 929;
        cArr2[14] = 974;
        cArr2[15] = 982;
        cArr2[16] = 986;
        cArr2[17] = 988;
        cArr2[18] = 990;
        cArr2[19] = 992;
        cArr2[20] = 1011;
        cArr2[21] = 1036;
        cArr2[22] = 1103;
        cArr2[23] = 1116;
        cArr2[24] = 1153;
        cArr2[25] = 1220;
        cArr2[26] = 1224;
        cArr2[27] = 1228;
        cArr2[28] = 1259;
        cArr2[29] = 1269;
        cArr2[30] = 1273;
        cArr2[31] = 1366;
        cArr2[32] = 1369;
        cArr2[33] = 1414;
        cArr2[34] = 1514;
        cArr2[35] = 1522;
        cArr2[36] = 1594;
        cArr2[37] = 1610;
        cArr2[38] = 1719;
        cArr2[39] = 1726;
        cArr2[40] = 1742;
        cArr2[41] = 1747;
        cArr2[42] = 1749;
        cArr2[43] = 1766;
        cArr2[44] = 2361;
        cArr2[45] = 2365;
        cArr2[46] = 2401;
        cArr2[47] = 2444;
        cArr2[48] = 2448;
        cArr2[49] = 2472;
        cArr2[50] = 2480;
        cArr2[51] = 2482;
        cArr2[52] = 2489;
        cArr2[53] = 2525;
        cArr2[54] = 2529;
        cArr2[55] = 2545;
        cArr2[56] = 2570;
        cArr2[57] = 2576;
        cArr2[58] = 2600;
        cArr2[59] = 2608;
        cArr2[60] = 2611;
        cArr2[61] = 2614;
        cArr2[62] = 2617;
        cArr2[63] = 2652;
        cArr2[64] = 2654;
        cArr2[65] = 2676;
        cArr2[66] = 2699;
        cArr2[67] = 2701;
        cArr2[68] = 2705;
        cArr2[69] = 2728;
        cArr2[70] = 2736;
        cArr2[71] = 2739;
        cArr2[72] = 2745;
        cArr2[73] = 2749;
        cArr2[74] = 2784;
        cArr2[75] = 2828;
        cArr2[76] = 2832;
        cArr2[77] = 2856;
        cArr2[78] = 2864;
        cArr2[79] = 2867;
        cArr2[80] = 2873;
        cArr2[81] = 2877;
        cArr2[82] = 2909;
        cArr2[83] = 2913;
        cArr2[84] = 2954;
        cArr2[85] = 2960;
        cArr2[86] = 2965;
        cArr2[87] = 2970;
        cArr2[88] = 2972;
        cArr2[89] = 2975;
        cArr2[90] = 2980;
        cArr2[91] = 2986;
        cArr2[92] = 2997;
        cArr2[93] = 3001;
        cArr2[94] = 3084;
        cArr2[95] = 3088;
        cArr2[96] = 3112;
        cArr2[97] = 3123;
        cArr2[98] = 3129;
        cArr2[99] = 3169;
        cArr2[100] = 3212;
        cArr2[101] = 3216;
        cArr2[102] = 3240;
        cArr2[103] = 3251;
        cArr2[104] = 3257;
        cArr2[105] = 3294;
        cArr2[106] = 3297;
        cArr2[107] = 3340;
        cArr2[108] = 3344;
        cArr2[109] = 3368;
        cArr2[110] = 3385;
        cArr2[111] = 3425;
        cArr2[112] = 3630;
        cArr2[113] = 3632;
        cArr2[114] = 3635;
        cArr2[115] = 3653;
        cArr2[116] = 3714;
        cArr2[117] = 3716;
        cArr2[118] = 3720;
        cArr2[119] = 3722;
        cArr2[120] = 3725;
        cArr2[121] = 3735;
        cArr2[122] = 3743;
        cArr2[123] = 3747;
        cArr2[124] = 3749;
        cArr2[125] = 3751;
        cArr2[126] = 3755;
        cArr2[127] = 3758;
        cArr2[128] = 3760;
        cArr2[129] = 3763;
        cArr2[130] = 3773;
        cArr2[131] = 3780;
        cArr2[132] = 3911;
        cArr2[133] = 3945;
        cArr2[134] = 4293;
        cArr2[135] = 4342;
        cArr2[136] = 4352;
        cArr2[137] = 4355;
        cArr2[138] = 4359;
        cArr2[139] = 4361;
        cArr2[140] = 4364;
        cArr2[141] = 4370;
        cArr2[142] = 4412;
        cArr2[143] = 4414;
        cArr2[144] = 4416;
        cArr2[145] = 4428;
        cArr2[146] = 4430;
        cArr2[147] = 4432;
        cArr2[148] = 4437;
        cArr2[149] = 4441;
        cArr2[150] = 4449;
        cArr2[151] = 4451;
        cArr2[152] = 4453;
        cArr2[153] = 4455;
        cArr2[154] = 4457;
        cArr2[155] = 4462;
        cArr2[156] = 4467;
        cArr2[157] = 4469;
        cArr2[158] = 4510;
        cArr2[159] = 4520;
        cArr2[160] = 4523;
        cArr2[161] = 4527;
        cArr2[162] = 4536;
        cArr2[163] = 4538;
        cArr2[164] = 4546;
        cArr2[165] = 4587;
        cArr2[166] = 4592;
        cArr2[167] = 4601;
        cArr2[168] = 7835;
        cArr2[169] = 7929;
        cArr2[170] = 7957;
        cArr2[171] = 7965;
        cArr2[172] = 8005;
        cArr2[173] = 8013;
        cArr2[174] = 8023;
        cArr2[175] = 8025;
        cArr2[176] = 8027;
        cArr2[177] = 8029;
        cArr2[178] = 8061;
        cArr2[179] = 8116;
        cArr2[180] = 8124;
        cArr2[181] = 8126;
        cArr2[182] = 8132;
        cArr2[183] = 8140;
        cArr2[184] = 8147;
        cArr2[185] = 8155;
        cArr2[186] = 8172;
        cArr2[187] = 8180;
        cArr2[188] = 8188;
        cArr2[189] = 8486;
        cArr2[190] = 8491;
        cArr2[191] = 8494;
        cArr2[192] = 8578;
        cArr2[193] = 12295;
        cArr2[194] = 12329;
        cArr2[195] = 12436;
        cArr2[196] = 12538;
        cArr2[197] = 12588;
        cArr2[198] = 40869;
        cArr2[199] = 55203;
        LETTER_RANGE_END = cArr2;
    }

    public PiccoloLexer(Piccolo piccolo) {
        this.yy_lexical_state = 0;
        char[] cArr = new char[16384];
        this.yy_buffer = cArr;
        this.yy_saved_buffer = cArr;
        this.yy_savePos = -1;
        this.yy_atBOL = true;
        this.yy_streams = new Stack();
        this.parser = null;
        this.currentEntity = null;
        this.stringConverter = new CharStringConverter(HSSFShapeTypes.ActionButtonMovie);
        this.entityManager = new EntityManager();
        this.entityStack = new Stack();
        this.attribs = new AttributesHolder();
        this.cbuf = new char[1024];
        this.oneCharBuffer = new char[1];
        this.entityStateStack = new LongStack(5);
        this.entityNameStack = new StringStack(2);
        this.tagStack = new StringStack(20);
        this.elementMap = new HashMap();
        this.elementDefinition = null;
        this.tokenStartColumn = -1;
        this.defaultAttributeSpecified = new boolean[4];
        this.nsSupport = new FastNamespaceSupport();
        this.yy_sawCR = false;
        this.yy_prev_sawCR = false;
        this.yyline_next = 0;
        this.yycolumn_next = 0;
        this.parser = piccolo;
        enableNamespaces(true);
    }

    private void addAttribute(String str, String str2, String str3, String str4, String str5) {
        if (this.needsNormalization) {
            str5 = normalizeValue(str5);
            this.needsNormalization = false;
        }
        if (this.isNamespaceDeclaration) {
            Piccolo piccolo = this.parser;
            if (piccolo.fNamespaces) {
                if (piccolo.fNamespacePrefixes) {
                    this.attribs.addAndCheckAttribute(str, str2, str3, str4, str5);
                }
                if (str == "") {
                    if (str2 == "xmlns") {
                        str2 = "";
                    }
                    this.nsSupport.declarePrefix(str2, str5);
                    this.parser.reportStartPrefixMapping(str2, str5);
                    return;
                } else if (str != "xml") {
                    this.nsSupport.declarePrefix(str2, str5);
                    this.parser.reportStartPrefixMapping(str2, str5);
                    return;
                } else {
                    return;
                }
            }
        }
        this.attribs.addAndCheckAttribute(str, str2, str3, str4, str5);
    }

    private void appendToCbuf(char c) {
        char[] cArr = this.cbuf;
        int length = cArr.length;
        int i2 = this.cbuflen;
        if (length - i2 < 1) {
            char[] cArr2 = new char[((cArr.length + 1) * 2)];
            System.arraycopy(cArr, 0, cArr2, 0, i2);
            this.cbuf = cArr2;
        }
        char[] cArr3 = this.cbuf;
        int i3 = this.cbuflen;
        this.cbuflen = i3 + 1;
        cArr3[i3] = c;
    }

    public static void calcAsciiTables() {
        asciiNameStartChars = new boolean[256];
        asciiNameStartCharsNS = new boolean[256];
        asciiNameChars = new boolean[256];
        asciiNameCharsNS = new boolean[256];
        int i2 = 0;
        while (i2 < 256) {
            boolean z = true;
            asciiNameStartChars[i2] = (i2 >= 97 && i2 <= 122) || i2 == 58 || (i2 >= 65 && i2 <= 90) || i2 == 95 || ((i2 >= 192 && i2 <= 214) || ((i2 >= 216 && i2 <= 246) || (i2 >= 248 && i2 <= 255)));
            asciiNameStartCharsNS[i2] = i2 != 58 && asciiNameStartChars[i2];
            asciiNameChars[i2] = (i2 >= 97 && i2 <= 122) || i2 == 58 || (i2 >= 65 && i2 <= 90) || i2 == 46 || i2 == 45 || i2 == 95 || i2 == 183 || ((i2 >= 48 && i2 <= 57) || ((i2 >= 192 && i2 <= 214) || ((i2 >= 216 && i2 <= 246) || (i2 >= 248 && i2 <= 255))));
            boolean[] zArr = asciiNameCharsNS;
            if (i2 == 58 || !asciiNameChars[i2]) {
                z = false;
            }
            zArr[i2] = z;
            i2++;
        }
    }

    private int cdataToken(char[] cArr, int i2, int i3) {
        return cdataToken(257, cArr, i2, i3);
    }

    private void checkEndTag(String str) {
        String pop = this.tagStack.pop();
        if (this.tagStack.size() == this.entityBaseDepth) {
            setTokenize(true);
        }
        if (pop != str) {
            throw fatalError(a.a("</", str, "> does not close tag <", pop, ">."));
        }
    }

    private void clearCbuf() {
        this.cbuflen = 0;
    }

    private void clearEntityState() {
        this.entityStateStack.clear();
        this.entityNameStack.clear();
        this.returnEntityEndToken = true;
        this.isParamEntity = false;
        this.entityBaseDepth = 0;
        this.isEntityBeingParsed = true;
        this.prevEntityLexState = 0;
        this.currentEntityName = null;
    }

    private FatalParsingException fatalError(String str) {
        return new FatalParsingException(str);
    }

    public static int findIndexFor(char[] cArr, int i2) {
        int length = cArr.length;
        int i3 = 0;
        while (i3 + 1 < length) {
            int i4 = ((length - i3) / 2) + i3;
            if (cArr[i4] > i2) {
                length = i4;
            } else {
                i3 = i4;
            }
        }
        return i3;
    }

    private int handleEntityRef(String str, int i2) {
        Entity byName = this.entityManager.getByName(str, i2);
        if (byName == null) {
            handleUnknownEntityRef(str, i2);
            return 0;
        }
        boolean z = i2 == 1;
        String a = z ? yystate() == 21 ? a.a(PercentPtg.PERCENT, str) : null : str;
        if (byName.isInternal()) {
            pushEntity(a, byName, z, true);
            setTokenize(true);
            return 295;
        } else if (str == "[dtd]" || parseExternalEntities(i2)) {
            pushEntity(a, byName, z, true);
            setTokenize(true);
            return 296;
        } else {
            this.entityWasSkipped = true;
            this.parser.reportSkippedEntity(a);
            return 0;
        }
    }

    private boolean handleLiteralEntityRef(String str, int i2) {
        Entity byName = this.entityManager.getByName(str, i2);
        boolean z = i2 == 1;
        if (byName == null) {
            if (z || (!this.currentEntity.isStandalone() && this.entityWasSkipped)) {
                return false;
            }
            throw fatalError(a.a("Reference to undefined entity: ", str));
        } else if (byName.isInternal()) {
            pushEntity((String) null, byName, z, false, this.prevState);
            yybegin(z ? 32 : 11);
            return true;
        } else if (!z) {
            throw fatalError("Referencing an external entity within an attribute value is illegal");
        } else if (parseExternalEntities(i2)) {
            yybegin(33);
            pushEntity((String) null, byName, z, false, this.prevState);
            return true;
        } else {
            this.entityWasSkipped = true;
            return false;
        }
    }

    private void handleUnknownEntityRef(String str, int i2) {
        boolean z = true;
        if (i2 != 1) {
            z = false;
        }
        String a = a.a(new StringBuffer(), z ? PercentPtg.PERCENT : "", str);
        if (this.currentEntity.isStandalone() || !this.entityWasSkipped) {
            throw fatalError(a.a("Reference to undefined entity: ", a));
        }
        this.parser.reportSkippedEntity(a);
    }

    public static boolean isASCIINameChar(int i2) {
        return asciiNameChars[i2];
    }

    public static boolean isASCIINameCharNS(int i2) {
        return asciiNameCharsNS[i2];
    }

    public static boolean isASCIINameStartChar(int i2) {
        return asciiNameStartChars[i2];
    }

    public static boolean isASCIINameStartCharNS(int i2) {
        return asciiNameStartCharsNS[i2];
    }

    public static boolean isNonASCIINameChar(int i2) {
        return isNonASCIINameStartChar(i2) || i2 <= NON_LETTER_RANGE_END[findIndexFor(NON_LETTER_RANGE_START, i2)];
    }

    public static boolean isNonASCIINameStartChar(int i2) {
        return i2 <= LETTER_RANGE_END[findIndexFor(LETTER_RANGE_START, i2)];
    }

    private boolean isTopEntity() {
        return !yymoreStreams();
    }

    /* JADX DEBUG: Failed to insert an additional move for type inference into block B:41:0x000a */
    /* JADX DEBUG: Failed to insert an additional move for type inference into block B:45:0x005b */
    /* JADX DEBUG: Failed to insert an additional move for type inference into block B:44:0x000a */
    /* JADX DEBUG: Failed to insert an additional move for type inference into block B:49:0x005b */
    /* JADX WARN: Multi-variable type inference failed */
    /* JADX WARN: Type inference failed for: r0v0, types: [char[]] */
    /* JADX WARN: Type inference failed for: r0v1, types: [char] */
    /* JADX WARN: Type inference failed for: r0v2, types: [int] */
    /* JADX WARN: Type inference failed for: r0v5 */
    /* JADX WARN: Type inference failed for: r0v7, types: [char[]] */
    /* JADX WARN: Type inference failed for: r0v8, types: [char] */
    /* JADX WARN: Type inference failed for: r0v14, types: [int] */
    /* JADX WARN: Type inference failed for: r0v22 */
    /* JADX WARN: Type inference failed for: r0v24, types: [char[]] */
    /* JADX WARN: Type inference failed for: r0v25, types: [char] */
    private void parseAttributeName() {
        char[] cArr = this.yy_buffer;
        int i2 = this.yy_markedPos;
        this.yy_markedPos = i2 + 1;
        char c = cArr[i2];
        while (true) {
            if (c != 32 && c != 9) {
                if (c != 10) {
                    break;
                }
                this.yyline_next++;
                this.yycolumn_next = 0;
            } else {
                this.yycolumn_next++;
            }
            int i3 = this.yy_endRead;
            int i4 = this.yy_markedPos;
            if (i3 - i4 > 0) {
                char[] cArr2 = this.yy_buffer;
                this.yy_markedPos = i4 + 1;
                c = cArr2[i4];
            } else {
                c = yynextChar();
            }
        }
        if (c == 47) {
            this.yy_markedPos--;
            this.attributeQName = null;
        } else if (c == 62) {
            this.yy_markedPos--;
            this.attributeQName = null;
        } else if (c > 255 ? !isNonASCIINameStartChar(c == true ? 1 : 0) : !isASCIINameStartChar(c)) {
            this.yy_markedPos--;
            this.attributeQName = "";
        } else {
            this.yycolumn_next++;
            this.yy_startRead = this.yy_markedPos - 1;
            while (true) {
                if (c <= 255) {
                    if (!isASCIINameChar(c)) {
                        break;
                    }
                } else {
                    int i5 = c == true ? 1 : 0;
                    int i6 = c == true ? 1 : 0;
                    if (!isNonASCIINameChar(i5)) {
                        break;
                    }
                }
                this.yycolumn_next++;
                int i7 = this.yy_endRead;
                int i8 = this.yy_markedPos;
                if (i7 - i8 > 0) {
                    char[] cArr3 = this.yy_buffer;
                    this.yy_markedPos = i8 + 1;
                    c = cArr3[i8];
                } else {
                    c = yynextChar();
                }
            }
            this.yy_markedPos--;
            this.attributeQName = yytext2();
        }
    }

    /* JADX DEBUG: Failed to insert an additional move for type inference into block B:55:0x0010 */
    /* JADX DEBUG: Failed to insert an additional move for type inference into block B:63:0x0069 */
    /* JADX DEBUG: Failed to insert an additional move for type inference into block B:58:0x0010 */
    /* JADX DEBUG: Failed to insert an additional move for type inference into block B:62:0x0069 */
    /* JADX WARN: Multi-variable type inference failed */
    /* JADX WARN: Type inference failed for: r2v0, types: [char[]] */
    /* JADX WARN: Type inference failed for: r2v1, types: [char] */
    /* JADX WARN: Type inference failed for: r2v2, types: [int] */
    /* JADX WARN: Type inference failed for: r2v5 */
    /* JADX WARN: Type inference failed for: r2v7, types: [char[]] */
    /* JADX WARN: Type inference failed for: r2v8, types: [char] */
    /* JADX WARN: Type inference failed for: r2v11, types: [int] */
    /* JADX WARN: Type inference failed for: r2v14 */
    /* JADX WARN: Type inference failed for: r2v16, types: [char[]] */
    /* JADX WARN: Type inference failed for: r2v17, types: [char] */
    /* JADX WARNING: Code restructure failed: missing block: B:27:0x006f, code lost:
        if (isASCIINameCharNS(r2) != false) goto L_0x0078;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:29:0x0076, code lost:
        if (isNonASCIINameChar(r2) != false) goto L_0x0078;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:31:0x007e, code lost:
        if (r2 != 58) goto L_0x00b3;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:32:0x0080, code lost:
        r8.yycolumn_next++;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:33:0x0087, code lost:
        if (r8.attributeURI != null) goto L_0x009e;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:34:0x0089, code lost:
        r1 = r8.stringConverter;
        r2 = r8.yy_buffer;
        r6 = r8.yy_startRead;
        r8.attributeURI = r1.convert(r2, r6, (r8.yy_markedPos - 1) - r6);
        r1 = r8.yy_markedPos - r8.yy_startRead;
     */
    private void parseAttributeNameNS() {
        this.attributeURI = null;
        int i2 = 0;
        this.isNamespaceDeclaration = false;
        char[] cArr = this.yy_buffer;
        int i3 = this.yy_markedPos;
        this.yy_markedPos = i3 + 1;
        char c = cArr[i3];
        while (true) {
            if (c != 32 && c != 9) {
                if (c != 10) {
                    break;
                }
                this.yyline_next++;
                this.yycolumn_next = 0;
            } else {
                this.yycolumn_next++;
            }
            int i4 = this.yy_endRead;
            int i5 = this.yy_markedPos;
            if (i4 - i5 > 0) {
                char[] cArr2 = this.yy_buffer;
                this.yy_markedPos = i5 + 1;
                c = cArr2[i5];
            } else {
                c = yynextChar();
            }
        }
        if (c == 47) {
            this.yy_markedPos--;
            this.attributeQName = null;
        } else if (c == 62) {
            this.yy_markedPos--;
            this.attributeQName = null;
        } else {
            if (c > 255 ? isNonASCIINameStartChar(c == true ? 1 : 0) : isASCIINameStartChar(c)) {
                this.yycolumn_next++;
                this.yy_startRead = this.yy_markedPos - 1;
            } else if (c == 58) {
                i2 = this.yy_markedPos - this.yy_startRead;
                this.attributeURI = "";
            } else {
                this.yy_markedPos--;
                this.attributeQName = "";
                return;
            }
            while (true) {
                if (c > 255) {
                    int i6 = c == true ? 1 : 0;
                    int i7 = c == true ? 1 : 0;
                }
                this.yycolumn_next++;
                int i8 = this.yy_endRead;
                int i9 = this.yy_markedPos;
                if (i8 - i9 > 0) {
                    char[] cArr3 = this.yy_buffer;
                    this.yy_markedPos = i9 + 1;
                    c = cArr3[i9];
                } else {
                    c = yynextChar();
                }
            }
            this.yy_markedPos--;
            if (this.attributeURI == null) {
                this.attributeURI = "";
            }
            String yytext2 = yytext2(i2, this.yy_markedPos - (this.yy_startRead + i2));
            this.attributeLocalName = yytext2;
            if (this.attributeURI == "xmlns" || yytext2 == "xmlns") {
                this.isNamespaceDeclaration = true;
            }
            this.attributeQName = yytext2();
        }
    }

    private int parseAttributes() {
        int i2;
        yybegin(this.tagState);
        this.endOfTag = false;
        int i3 = 0;
        while (!this.endOfTag) {
            if (this.yy_endRead - this.yy_markedPos <= 0) {
                return -1;
            }
            parseAttributeName();
            if (this.attributeQName == null) {
                break;
            }
            int i4 = this.yy_endRead - this.yy_markedPos;
            while (true) {
                i2 = i4 - 1;
                if (i4 <= 0) {
                    break;
                }
                char[] cArr = this.yy_buffer;
                int i5 = this.yy_markedPos;
                int i6 = i5 + 1;
                this.yy_markedPos = i6;
                char c = cArr[i5];
                if (c != '\t') {
                    if (c == '\n') {
                        this.yyline_next++;
                        this.yycolumn_next = 0;
                        i4 = i2;
                    } else if (c != ' ') {
                        if (c != '=') {
                            this.yy_markedPos = i6 - 1;
                            yybegin(10);
                            return -1;
                        }
                    }
                }
                this.yycolumn_next++;
                i4 = i2;
            }
            if (i2 < 0) {
                yybegin(10);
                return -1;
            }
            while (true) {
                i3 = yynextChar();
                if (i3 == -1) {
                    break;
                }
                if (i3 != 9) {
                    if (i3 == 10) {
                        this.yyline_next++;
                        this.yycolumn_next = 0;
                    } else if (i3 != 32) {
                        if (i3 == 34) {
                            this.yycolumn_next++;
                            parseQuotedTagValue();
                            if (yystate() != this.tagState) {
                                return -1;
                            }
                        } else if (i3 == 39) {
                            this.yycolumn_next++;
                            parseSingleQuotedTagValue();
                            if (yystate() != this.tagState) {
                                return -1;
                            }
                        } else {
                            StringBuffer a = a.a("Unexpected character encountered: '");
                            a.append((char) i3);
                            a.append("'");
                            throw fatalError(a.toString());
                        }
                    }
                }
                this.yycolumn_next++;
            }
            if (i3 == -1) {
                throw fatalError("Unexpected end of file");
            }
        }
        while (true) {
            int i7 = this.yy_endRead;
            int i8 = this.yy_markedPos;
            if (i7 - i8 <= 0) {
                return -1;
            }
            char[] cArr2 = this.yy_buffer;
            this.yy_markedPos = i8 + 1;
            char c2 = cArr2[i8];
            if (c2 != '\t') {
                if (c2 == '\n') {
                    this.yyline_next++;
                    this.yycolumn_next = 0;
                } else if (c2 != ' ') {
                    if (c2 == '/') {
                        this.yycolumn_next++;
                        if (yynextChar() == 62) {
                            this.yycolumn_next++;
                            yybegin(this.baseState);
                            processComplexElement();
                            this.parser.reportStartTag(this.elementURI, this.elementLocalName, this.stringValue);
                            this.parser.reportEndTag(this.elementURI, this.elementLocalName, this.stringValue);
                            this.attribs.clear();
                            this.tagType = 265;
                            if (this.tokenizeInput) {
                                return 265;
                            }
                            return 0;
                        }
                        throw fatalError("'/' should be followed by '>'");
                    } else if (c2 == '>') {
                        this.yycolumn_next++;
                        yybegin(this.baseState);
                        processComplexElement();
                        this.parser.reportStartTag(this.elementURI, this.elementLocalName, this.stringValue);
                        this.tagStack.push(this.stringValue);
                        this.attribs.clear();
                        this.tagType = 263;
                        if (this.tokenizeInput) {
                            return 263;
                        }
                        return 0;
                    } else {
                        StringBuffer a2 = a.a("Unexpected character: ");
                        a2.append((char) i3);
                        throw fatalError(a2.toString());
                    }
                }
            }
            this.yycolumn_next++;
        }
    }

    private int parseAttributesNS() {
        int i2;
        yybegin(this.tagState);
        this.endOfTag = false;
        int i3 = 0;
        while (!this.endOfTag) {
            if (this.yy_endRead - this.yy_markedPos <= 0) {
                return -1;
            }
            parseAttributeNameNS();
            if (this.attributeQName == null) {
                break;
            }
            int i4 = this.yy_endRead - this.yy_markedPos;
            while (true) {
                i2 = i4 - 1;
                if (i4 <= 0) {
                    break;
                }
                char[] cArr = this.yy_buffer;
                int i5 = this.yy_markedPos;
                int i6 = i5 + 1;
                this.yy_markedPos = i6;
                char c = cArr[i5];
                if (c != '\t') {
                    if (c == '\n') {
                        this.yyline_next++;
                        this.yycolumn_next = 0;
                        i4 = i2;
                    } else if (c != ' ') {
                        if (c != '=') {
                            this.yy_markedPos = i6 - 1;
                            yybegin(10);
                            return -1;
                        }
                    }
                }
                this.yycolumn_next++;
                i4 = i2;
            }
            if (i2 < 0) {
                yybegin(10);
                return -1;
            }
            while (true) {
                i3 = yynextChar();
                if (i3 == -1) {
                    break;
                }
                if (i3 != 9) {
                    if (i3 == 10) {
                        this.yyline_next++;
                        this.yycolumn_next = 0;
                    } else if (i3 != 32) {
                        if (i3 == 34) {
                            this.yycolumn_next++;
                            parseQuotedTagValue();
                            if (yystate() != this.tagState) {
                                return -1;
                            }
                        } else if (i3 == 39) {
                            this.yycolumn_next++;
                            parseSingleQuotedTagValue();
                            if (yystate() != this.tagState) {
                                return -1;
                            }
                        } else {
                            StringBuffer a = a.a("Unexpected character encountered: '");
                            a.append((char) i3);
                            a.append("'");
                            throw fatalError(a.toString());
                        }
                    }
                }
                this.yycolumn_next++;
            }
            if (i3 == -1) {
                throw fatalError("Unexpected end of file");
            }
        }
        while (true) {
            int i7 = this.yy_endRead;
            int i8 = this.yy_markedPos;
            if (i7 - i8 <= 0) {
                return -1;
            }
            char[] cArr2 = this.yy_buffer;
            this.yy_markedPos = i8 + 1;
            char c2 = cArr2[i8];
            if (c2 != '\t') {
                if (c2 == '\n') {
                    this.yyline_next++;
                    this.yycolumn_next = 0;
                } else if (c2 != ' ') {
                    if (c2 == '/') {
                        this.yycolumn_next++;
                        if (yynextChar() == 62) {
                            this.yycolumn_next++;
                            yybegin(this.baseState);
                            processComplexElement();
                            resolveNamespacePrefixes();
                            this.parser.reportStartTag(this.elementURI, this.elementLocalName, this.stringValue);
                            this.parser.reportEndTag(this.elementURI, this.elementLocalName, this.stringValue);
                            processNSContextEnd();
                            this.attribs.clear();
                            this.tagType = 265;
                            if (this.tokenizeInput) {
                                return 265;
                            }
                            return 0;
                        }
                        throw fatalError("'/' should be followed by '>'");
                    } else if (c2 == '>') {
                        this.yycolumn_next++;
                        yybegin(this.baseState);
                        processComplexElement();
                        resolveNamespacePrefixes();
                        this.parser.reportStartTag(this.elementURI, this.elementLocalName, this.stringValue);
                        this.tagStack.push(this.stringValue);
                        this.attribs.clear();
                        this.tagType = 263;
                        if (this.tokenizeInput) {
                            return 263;
                        }
                        return 0;
                    } else {
                        StringBuffer a2 = a.a("Unexpected character: ");
                        a2.append((char) i3);
                        throw fatalError(a2.toString());
                    }
                }
            }
            this.yycolumn_next++;
        }
    }

    private void parseCdata() {
        char c;
        this.cdataBuffer = this.yy_buffer;
        this.cdataStart = this.yy_startRead;
        while (true) {
            int i2 = this.yy_endRead;
            int i3 = this.yy_markedPos;
            if (i2 > i3) {
                char[] cArr = this.yy_buffer;
                this.yy_markedPos = i3 + 1;
                char c2 = cArr[i3];
                if (c2 == '\n') {
                    this.yyline_next++;
                    this.yycolumn_next = 0;
                } else if (c2 == '&') {
                    this.yycolumn_next++;
                    yybegin(3);
                    this.cdataLength = (this.yy_markedPos - 1) - this.yy_startRead;
                    return;
                } else if (c2 == '<') {
                    this.yycolumn_next++;
                    yybegin(this.tagStartState);
                    this.cdataLength = (this.yy_markedPos - 1) - this.yy_startRead;
                    this.tokenStartLine = this.yyline_next + 1;
                    this.tokenStartColumn = this.yycolumn_next + 1;
                    return;
                } else if (c2 != ']') {
                    this.yycolumn_next++;
                } else {
                    int i4 = 1;
                    while (true) {
                        int i5 = this.yy_endRead;
                        int i6 = this.yy_markedPos;
                        if (i5 - i6 >= 1) {
                            char[] cArr2 = this.yy_buffer;
                            this.yy_markedPos = i6 + 1;
                            c = cArr2[i6];
                        } else {
                            this.parser.reportCdata(this.cdataBuffer, this.cdataStart, i6 - this.yy_startRead);
                            yynextAction();
                            int yynextChar = yynextChar();
                            this.cdataBuffer = this.yy_buffer;
                            this.cdataStart = this.yy_startRead;
                            c = yynextChar;
                        }
                        if (c != 93) {
                            break;
                        }
                        i4++;
                    }
                    if (c == 62 && i4 >= 2) {
                        throw fatalError("Illegal ']]>' construct in character data");
                    } else if (c != -1) {
                        this.yy_markedPos--;
                    }
                }
            } else {
                this.cdataLength = i3 - this.yy_startRead;
                return;
            }
        }
    }

    /* JADX WARNING: Removed duplicated region for block: B:39:0x00b8  */
    /* JADX WARNING: Removed duplicated region for block: B:67:0x00da A[SYNTHETIC] */
    private void parseCdataLiteral(char c, int i2) {
        String str;
        char c2;
        int i3;
        int i4;
        int i5 = this.yy_markedPos;
        while (true) {
            int i6 = this.yy_endRead;
            int i7 = this.yy_markedPos;
            if (i6 - i7 > 0) {
                char[] cArr = this.yy_buffer;
                int i8 = i7 + 1;
                this.yy_markedPos = i8;
                char c3 = cArr[i7];
                if (c3 == '&') {
                    this.yycolumn_next++;
                    clearCbuf();
                    appendToCbuf(this.yy_buffer, i5, (this.yy_markedPos - 1) - i5);
                    this.prevState = i2;
                    yybegin(12);
                    return;
                } else if (c3 == '<') {
                    throw fatalError("Illegal '<' found in attribute value. Use '&lt;' instead.");
                } else if (c3 > '\'') {
                    this.yycolumn_next++;
                } else if (c3 == c) {
                    this.yycolumn_next++;
                    int i9 = (i8 - 1) - i5;
                    if (i9 < 4 || this.isNamespaceDeclaration) {
                        str = this.stringConverter.convert(this.yy_buffer, i5, i9);
                    } else {
                        str = new String(this.yy_buffer, i5, i9);
                    }
                    addAttribute(this.attributeURI, this.attributeLocalName, this.attributeQName, this.attributeValueType, str);
                    int i10 = this.yy_endRead;
                    int i11 = this.yy_markedPos;
                    if (i10 - i11 <= 0) {
                        c2 = yynextChar();
                    } else {
                        char[] cArr2 = this.yy_buffer;
                        this.yy_markedPos = i11 + 1;
                        c2 = cArr2[i11];
                    }
                    if (c2 != 9) {
                        if (c2 == 10) {
                            this.yyline_next++;
                            this.yycolumn_next = 0;
                            while (true) {
                                i3 = this.yy_endRead;
                                i4 = this.yy_markedPos;
                                if (i3 - i4 <= 0) {
                                    char c4 = this.yy_buffer[i4];
                                    if (c4 != '\t') {
                                        if (c4 == '\n') {
                                            this.yy_markedPos = i4 + 1;
                                            this.yyline_next++;
                                            this.yycolumn_next = 0;
                                        } else if (c4 != ' ') {
                                            return;
                                        }
                                    }
                                    this.yy_markedPos++;
                                    this.yycolumn_next++;
                                } else {
                                    return;
                                }
                            }
                        } else if (c2 != 32) {
                            if (c2 == 47 || c2 == 62) {
                                this.yy_markedPos--;
                                this.endOfTag = true;
                                return;
                            }
                            throw fatalError("Whitespace missing after attribute value");
                        }
                    }
                    this.yycolumn_next++;
                    while (true) {
                        i3 = this.yy_endRead;
                        i4 = this.yy_markedPos;
                        if (i3 - i4 <= 0) {
                        }
                    }
                } else if (c3 == '\t') {
                    this.yycolumn_next++;
                    cArr[i8 - 1] = ' ';
                } else if (c3 == '\n') {
                    this.yyline_next++;
                    this.yycolumn_next = 0;
                    cArr[i8 - 1] = ' ';
                } else {
                    this.yycolumn_next++;
                }
            } else {
                clearCbuf();
                appendToCbuf(this.yy_buffer, i5, this.yy_markedPos - i5);
                this.prevState = i2;
                yybegin(i2);
                return;
            }
        }
    }

    private void parseCdataSection() {
        char c;
        yynextAction();
        while (true) {
            int i2 = this.yy_endRead;
            int i3 = this.yy_markedPos;
            if (i2 > i3) {
                char[] cArr = this.yy_buffer;
                this.yy_markedPos = i3 + 1;
                char c2 = cArr[i3];
                if (c2 == '\n') {
                    this.yyline_next++;
                    this.yycolumn_next = 0;
                } else if (c2 != ']') {
                    this.yycolumn_next++;
                } else {
                    int i4 = 1;
                    while (true) {
                        int i5 = this.yy_endRead;
                        int i6 = this.yy_markedPos;
                        if (i5 > i6) {
                            char[] cArr2 = this.yy_buffer;
                            this.yy_markedPos = i6 + 1;
                            c = cArr2[i6];
                        } else {
                            int min = Math.min(2, i4);
                            int i7 = this.yy_markedPos - min;
                            this.yy_markedPos = i7;
                            Piccolo piccolo = this.parser;
                            char[] cArr3 = this.yy_buffer;
                            int i8 = this.yy_startRead;
                            piccolo.reportCdata(cArr3, i8, i7 - i8);
                            yynextAction();
                            this.yy_markedPos += min;
                            c = yynextChar();
                        }
                        if (c != 93) {
                            break;
                        }
                        i4++;
                    }
                    if (c == 62 && i4 >= 2) {
                        int i9 = this.yy_startRead;
                        int i10 = (this.yy_markedPos - 3) - i9;
                        if (i10 > 0) {
                            this.parser.reportCdata(this.yy_buffer, i9, i10);
                            return;
                        }
                        return;
                    } else if (c != -1) {
                        this.yy_markedPos--;
                    } else {
                        throw fatalError("Unexpected end of file in CDATA section");
                    }
                }
            } else if (yynextChar() != -1) {
                this.yy_markedPos--;
            } else {
                throw fatalError("Unexpected end of file in CDATA section");
            }
        }
    }

    private int parseCloseTag() {
        this.yy_markedPos++;
        this.yycolumn_next++;
        String parseElementName = parseElementName();
        this.stringValue = parseElementName;
        if (parseElementName == null) {
            yybegin(this.tagStartState);
            this.yy_markedPos--;
            this.yycolumn_next--;
            return -1;
        }
        while (true) {
            int i2 = this.yy_endRead;
            int i3 = this.yy_markedPos;
            if (i2 - i3 > 0) {
                char[] cArr = this.yy_buffer;
                this.yy_markedPos = i3 + 1;
                char c = cArr[i3];
                if (c != '\t') {
                    if (c == '\n') {
                        this.yyline_next++;
                        this.yycolumn_next = 0;
                    } else if (c != ' ') {
                        if (c == '>') {
                            this.yycolumn_next++;
                            checkEndTag(this.stringValue);
                            this.parser.reportEndTag(this.elementURI, this.elementLocalName, this.stringValue);
                            yybegin(this.baseState);
                            this.tagType = 264;
                            if (this.tokenizeInput) {
                                return 264;
                            }
                            return 0;
                        }
                        StringBuffer stringBuffer = new StringBuffer();
                        stringBuffer.append("Unexpected character encountered while in a closing tag: '");
                        stringBuffer.append(c);
                        stringBuffer.append("'");
                        throw fatalError(stringBuffer.toString());
                    }
                }
                this.yycolumn_next++;
            } else {
                yybegin(this.parser.fNamespaces ? 20 : 19);
                return -1;
            }
        }
    }

    private int parseCloseTagNS() {
        this.yy_markedPos++;
        this.yycolumn_next++;
        String parseElementNameNS = parseElementNameNS();
        this.stringValue = parseElementNameNS;
        if (parseElementNameNS == null) {
            yybegin(this.tagStartState);
            this.yy_markedPos--;
            this.yycolumn_next--;
            return -1;
        }
        while (true) {
            int i2 = this.yy_endRead;
            int i3 = this.yy_markedPos;
            if (i2 - i3 > 0) {
                char[] cArr = this.yy_buffer;
                this.yy_markedPos = i3 + 1;
                char c = cArr[i3];
                if (c != '\t') {
                    if (c == '\n') {
                        this.yyline_next++;
                        this.yycolumn_next = 0;
                    } else if (c != ' ') {
                        if (c == '>') {
                            this.yycolumn_next++;
                            checkEndTag(this.stringValue);
                            String uri = this.nsSupport.getURI(this.elementURI);
                            this.elementURI = uri;
                            this.parser.reportEndTag(uri, this.elementLocalName, this.stringValue);
                            processNSContextEnd();
                            yybegin(this.baseState);
                            this.tagType = 264;
                            if (this.tokenizeInput) {
                                return 264;
                            }
                            return 0;
                        }
                        StringBuffer stringBuffer = new StringBuffer();
                        stringBuffer.append("Unexpected character encountered while in a closing tag: '");
                        stringBuffer.append(c);
                        stringBuffer.append("'");
                        throw fatalError(stringBuffer.toString());
                    }
                }
                this.yycolumn_next++;
            } else {
                yybegin(this.parser.fNamespaces ? 20 : 19);
                return -1;
            }
        }
    }

    private String parseElementName() {
        char c;
        this.yy_startRead = this.yy_markedPos;
        int yynextChar = yynextChar();
        if (yynextChar > 255 ? !isNonASCIINameStartChar(yynextChar) : !isASCIINameStartChar(yynextChar)) {
            yybegin(this.tagStartState);
            this.yy_markedPos--;
            return null;
        }
        this.yycolumn_next++;
        while (true) {
            int i2 = this.yy_endRead;
            int i3 = this.yy_markedPos;
            if (i2 - i3 > 0) {
                char[] cArr = this.yy_buffer;
                this.yy_markedPos = i3 + 1;
                c = cArr[i3];
                if (c > 255) {
                    if (!isNonASCIINameChar(c)) {
                        break;
                    }
                } else if (!isASCIINameChar(c)) {
                    break;
                }
                this.yycolumn_next++;
            } else if (yynextChar() >= 0) {
                this.yy_markedPos--;
            } else {
                throw fatalError("Unexpected end of file");
            }
        }
        if (c == '>' || c == ' ' || c == '/' || c == '\n' || c == '\t') {
            this.yy_markedPos--;
            return yytext2();
        }
        this.yy_markedPos = this.yy_startRead;
        return null;
    }

    private String parseElementNameNS() {
        int i2;
        this.yy_startRead = this.yy_markedPos;
        this.elementURI = null;
        int yynextChar = yynextChar();
        if (yynextChar > 255 ? isNonASCIINameStartChar(yynextChar) : isASCIINameStartCharNS(yynextChar)) {
            this.yycolumn_next++;
            i2 = 0;
        } else if (yynextChar == 58) {
            this.yycolumn_next++;
            this.elementURI = "";
            i2 = 1;
        } else {
            yybegin(this.tagStartState);
            this.yy_markedPos--;
            return null;
        }
        while (true) {
            int i3 = this.yy_endRead;
            int i4 = this.yy_markedPos;
            if (i3 - i4 > 0) {
                char[] cArr = this.yy_buffer;
                this.yy_markedPos = i4 + 1;
                char c = cArr[i4];
                if (c > 255 ? !isNonASCIINameChar(c) : !isASCIINameCharNS(c)) {
                    if (c == '>' || c == ' ' || c == '/') {
                        break;
                    } else if (c == ':') {
                        this.yycolumn_next++;
                        if (this.elementURI == null) {
                            CharStringConverter charStringConverter = this.stringConverter;
                            char[] cArr2 = this.yy_buffer;
                            int i5 = this.yy_startRead;
                            this.elementURI = charStringConverter.convert(cArr2, i5, (this.yy_markedPos - i5) - 1);
                            i2 = this.yy_markedPos - this.yy_startRead;
                        }
                    } else if (c != '\n' && c != '\t') {
                        this.yy_markedPos = this.yy_startRead;
                        return null;
                    }
                } else {
                    this.yycolumn_next++;
                }
            } else if (yynextChar() >= 0) {
                this.yy_markedPos--;
            } else {
                throw fatalError("Unexpected end of file");
            }
        }
        int i6 = this.yy_markedPos - 1;
        this.yy_markedPos = i6;
        String yytext2 = yytext2(i2, i6 - (this.yy_startRead + i2));
        this.elementLocalName = yytext2;
        if (i2 == 0) {
            return yytext2;
        }
        return yytext2();
    }

    private void parseEncodedChar(char[] cArr, int i2, int i3, int i4) {
        int i5 = 0;
        for (int i6 = 0; i6 < i3; i6++) {
            try {
                i5 = (i5 * i4) + Character.digit(cArr[i2 + i6], i4);
            } catch (ClassCastException unused) {
                throw new CharConversionException();
            }
        }
        if (i5 >= 1114112) {
            throw new IllegalCharException("Character reference to illegal XML character");
        } else if (i5 >= 65536) {
            int i7 = i5 - 65536;
            appendToCbuf((char) ((i7 >> 10) + 55296));
            appendToCbuf((char) ((i7 & 1023) + 56320));
        } else if ((i5 >= 32 || i5 == 9 || i5 == 13 || i5 == 10) && ((i5 < 55296 || i5 >= 57344) && i5 < 65534)) {
            appendToCbuf((char) i5);
        } else {
            throw new IllegalCharException("Character reference to illegal XML character");
        }
    }

    /* JADX DEBUG: Failed to insert an additional move for type inference into block B:35:0x0019 */
    /* JADX DEBUG: Failed to insert an additional move for type inference into block B:40:0x0019 */
    /* JADX WARN: Multi-variable type inference failed */
    /* JADX WARN: Type inference failed for: r0v1, types: [char[]] */
    /* JADX WARN: Type inference failed for: r0v2, types: [char] */
    /* JADX WARN: Type inference failed for: r0v3 */
    /* JADX WARN: Type inference failed for: r0v27 */
    /* JADX WARN: Type inference failed for: r0v29, types: [char[]] */
    /* JADX WARN: Type inference failed for: r0v30, types: [char] */
    /* JADX WARNING: Unknown variable types count: 2 */
    private int parseOpenTag() {
        String parseElementName = parseElementName();
        this.stringValue = parseElementName;
        if (parseElementName == null) {
            yybegin(this.tagStartState);
            return -1;
        }
        ?? r0 = this.yy_buffer;
        int i2 = this.yy_markedPos;
        this.yy_markedPos = i2 + 1;
        char c = r0[i2];
        while (c != 62) {
            if (c == 47) {
                this.yycolumn_next++;
                if (yynextChar() == 62) {
                    this.yycolumn_next++;
                    yybegin(this.baseState);
                    processSimpleElement(this.stringValue);
                    this.parser.reportStartTag(this.elementURI, this.elementLocalName, this.stringValue);
                    this.parser.reportEndTag(this.elementURI, this.elementLocalName, this.stringValue);
                    this.attribs.clear();
                    this.tagType = 265;
                    if (this.tokenizeInput) {
                        return 265;
                    }
                    return 0;
                }
                throw fatalError("'/' should be followed by '>'");
            }
            if (c == 32 || c == 9) {
                this.yycolumn_next++;
            } else if (c == 10) {
                this.yyline_next++;
                this.yycolumn_next = 0;
            } else {
                this.yy_markedPos--;
                prepareComplexElement(this.stringValue);
                return parseAttributes();
            }
            int i3 = this.yy_endRead;
            int i4 = this.yy_markedPos;
            if (i3 - i4 > 0) {
                ?? r02 = this.yy_buffer;
                this.yy_markedPos = i4 + 1;
                c = r02[i4];
            } else {
                c = yynextChar();
            }
        }
        this.yycolumn_next++;
        yybegin(this.baseState);
        processSimpleElement(this.stringValue);
        this.parser.reportStartTag(this.elementURI, this.elementLocalName, this.stringValue);
        this.attribs.clear();
        this.tagStack.push(this.stringValue);
        this.tagType = 263;
        if (this.tokenizeInput) {
            return 263;
        }
        return 0;
    }

    /* JADX DEBUG: Failed to insert an additional move for type inference into block B:35:0x0019 */
    /* JADX DEBUG: Failed to insert an additional move for type inference into block B:40:0x0019 */
    /* JADX WARN: Multi-variable type inference failed */
    /* JADX WARN: Type inference failed for: r0v1, types: [char[]] */
    /* JADX WARN: Type inference failed for: r0v2, types: [char] */
    /* JADX WARN: Type inference failed for: r0v3 */
    /* JADX WARN: Type inference failed for: r0v32 */
    /* JADX WARN: Type inference failed for: r0v34, types: [char[]] */
    /* JADX WARN: Type inference failed for: r0v35, types: [char] */
    /* JADX WARNING: Unknown variable types count: 2 */
    private int parseOpenTagNS() {
        String parseElementNameNS = parseElementNameNS();
        this.stringValue = parseElementNameNS;
        if (parseElementNameNS == null) {
            yybegin(this.tagStartState);
            return -1;
        }
        ?? r0 = this.yy_buffer;
        int i2 = this.yy_markedPos;
        this.yy_markedPos = i2 + 1;
        char c = r0[i2];
        while (c != 62) {
            if (c == 47) {
                this.yycolumn_next++;
                if (yynextChar() == 62) {
                    this.yycolumn_next++;
                    yybegin(this.baseState);
                    this.elementURI = this.nsSupport.getURI(this.elementURI);
                    processSimpleElement(this.stringValue);
                    this.parser.reportStartTag(this.elementURI, this.elementLocalName, this.stringValue);
                    this.parser.reportEndTag(this.elementURI, this.elementLocalName, this.stringValue);
                    this.attribs.clear();
                    this.tagType = 265;
                    if (this.tokenizeInput) {
                        return 265;
                    }
                    return 0;
                }
                throw fatalError("'/' should be followed by '>'");
            }
            if (c == 32 || c == 9) {
                this.yycolumn_next++;
            } else if (c == 10) {
                this.yyline_next++;
                this.yycolumn_next = 0;
            } else {
                this.yy_markedPos--;
                prepareComplexElement(this.stringValue);
                this.nsSupport.pushContext();
                return parseAttributesNS();
            }
            int i3 = this.yy_endRead;
            int i4 = this.yy_markedPos;
            if (i3 - i4 > 0) {
                ?? r02 = this.yy_buffer;
                this.yy_markedPos = i4 + 1;
                c = r02[i4];
            } else {
                c = yynextChar();
            }
        }
        this.yycolumn_next++;
        this.nsSupport.pushContext();
        this.elementURI = this.nsSupport.getURI(this.elementURI);
        yybegin(this.baseState);
        processSimpleElement(this.stringValue);
        this.parser.reportStartTag(this.elementURI, this.elementLocalName, this.stringValue);
        this.attribs.clear();
        this.tagStack.push(this.stringValue);
        this.tagType = 263;
        if (this.tokenizeInput) {
            return 263;
        }
        return 0;
    }

    private void parseQuotedTagValue() {
        ElementDefinition elementDefinition2 = this.elementDefinition;
        if (elementDefinition2 == null) {
            parseCdataLiteral(StringPtg.FORMULA_DELIMITER, 13);
            return;
        }
        IndexedObject indexedAttribute = elementDefinition2.getIndexedAttribute(this.attributeQName);
        if (indexedAttribute == null) {
            this.attributeValueType = "CDATA";
            parseCdataLiteral(StringPtg.FORMULA_DELIMITER, 13);
            return;
        }
        this.defaultAttributeSpecified[indexedAttribute.getIndex()] = true;
        int valueType = ((AttributeDefinition) indexedAttribute.getObject()).getValueType();
        if (valueType == 3) {
            this.attributeValueType = "CDATA";
            parseCdataLiteral(StringPtg.FORMULA_DELIMITER, 13);
            return;
        }
        this.attributeValueType = AttributeDefinition.getValueTypeString(valueType);
        yybegin(15);
    }

    private void parseSingleQuotedTagValue() {
        ElementDefinition elementDefinition2 = this.elementDefinition;
        if (elementDefinition2 == null) {
            parseCdataLiteral('\'', 14);
            return;
        }
        IndexedObject indexedAttribute = elementDefinition2.getIndexedAttribute(this.attributeQName);
        if (indexedAttribute == null) {
            this.attributeValueType = "CDATA";
            parseCdataLiteral('\'', 14);
            return;
        }
        this.defaultAttributeSpecified[indexedAttribute.getIndex()] = true;
        int valueType = ((AttributeDefinition) indexedAttribute.getObject()).getValueType();
        if (valueType == 3) {
            this.attributeValueType = "CDATA";
            parseCdataLiteral('\'', 14);
            return;
        }
        this.attributeValueType = AttributeDefinition.getValueTypeString(valueType);
        yybegin(16);
    }

    private int parseTag() {
        int i2 = this.yy_endRead;
        int i3 = this.yy_markedPos;
        if (i2 - i3 > 0) {
            char c = this.yy_buffer[i3];
            if (c != '!') {
                if (c == '/') {
                    return parseCloseTag();
                }
                if (c != '?') {
                    return parseOpenTag();
                }
            }
            yybegin(this.tagStartState);
        }
        return -1;
    }

    private int parseTagNS() {
        int i2 = this.yy_endRead;
        int i3 = this.yy_markedPos;
        if (i2 - i3 > 0) {
            char c = this.yy_buffer[i3];
            if (c != '!') {
                if (c == '/') {
                    return parseCloseTagNS();
                }
                if (c != '?') {
                    return parseOpenTagNS();
                }
            }
            yybegin(this.tagStartState);
        }
        return -1;
    }

    private int parseWhitespace() {
        this.cdataBuffer = this.yy_buffer;
        this.cdataStart = this.yy_startRead;
        while (true) {
            int i2 = this.yy_endRead;
            int i3 = this.yy_markedPos;
            if (i2 - i3 > 0) {
                char[] cArr = this.yy_buffer;
                this.yy_markedPos = i3 + 1;
                char c = cArr[i3];
                if (c != '\t') {
                    if (c == '\n') {
                        this.yyline_next++;
                        this.yycolumn_next = 0;
                    } else if (c != ' ') {
                        if (c == '&') {
                            this.yycolumn_next++;
                            yybegin(3);
                            this.cdataLength = (this.yy_markedPos - 1) - this.yy_startRead;
                            return 257;
                        } else if (c != '<') {
                            this.yycolumn_next++;
                            parseCdata();
                            return 257;
                        } else {
                            this.tokenStartLine = this.yyline_next + 1;
                            int i4 = this.yycolumn_next + 1;
                            this.yycolumn_next = i4;
                            this.tokenStartColumn = i4 + 1;
                            yybegin(this.tagStartState);
                            this.cdataLength = (this.yy_markedPos - 1) - this.yy_startRead;
                            yybegin(this.tagStartState);
                            return 266;
                        }
                    }
                }
                this.yycolumn_next++;
            } else {
                this.cdataLength = i3 - this.yy_startRead;
                return 266;
            }
        }
    }

    private int parseXML() {
        int parseTag;
        if (this.parser.fNamespaces) {
            return parseXMLNS();
        }
        while (true) {
            parseCdata();
            this.parser.reportCdata(this.cdataBuffer, this.cdataStart, this.cdataLength);
            yynextAction();
            if (yystate() != this.tagStartState || (parseTag = parseTag()) == -1) {
                return 0;
            }
            if (parseTag != 0) {
                return parseTag;
            }
            yynextAction();
        }
        return 0;
    }

    private int parseXMLNS() {
        int parseTagNS;
        while (true) {
            parseCdata();
            this.parser.reportCdata(this.cdataBuffer, this.cdataStart, this.cdataLength);
            yynextAction();
            if (yystate() != this.tagStartState || (parseTagNS = parseTagNS()) == -1) {
                return 0;
            }
            if (parseTagNS != 0) {
                return parseTagNS;
            }
            yynextAction();
        }
        return 0;
    }

    private void popEntityState() {
        int i2 = this.prevEntityLexState;
        if (i2 != 0) {
            yybegin(i2);
        }
        long pop = this.entityStateStack.pop();
        boolean z = true;
        this.returnEntityEndToken = (pop & 4) == 4;
        this.isParamEntity = (pop & 2) == 2;
        if ((pop & 1) != 1) {
            z = false;
        }
        this.isEntityBeingParsed = z;
        this.entityBaseDepth = (int) ((pop >> 11) & 65535);
        this.prevEntityLexState = (int) ((pop >> 3) & 255);
        String str = this.currentEntityName;
        if (str != null) {
            this.parser.reportEndEntity(str);
        }
        this.currentEntityName = this.entityNameStack.pop();
        if (this.tagStack.size() > this.entityBaseDepth) {
            setTokenize(false);
        }
    }

    private void prepareComplexElement(String str) {
        this.isNamespaceDeclaration = false;
        ElementDefinition element = getElement(str);
        this.elementDefinition = element;
        if (element != null) {
            int attributeCount = element.getAttributeCount();
            this.numAttributesDefined = attributeCount;
            int length = this.defaultAttributeSpecified.length;
            if (length < attributeCount) {
                this.defaultAttributeSpecified = new boolean[Math.max(length * 2, attributeCount)];
            }
            for (int i2 = 0; i2 < this.numAttributesDefined; i2++) {
                this.defaultAttributeSpecified[i2] = false;
            }
            return;
        }
        this.attributeValueType = "CDATA";
    }

    private void processComplexElement() {
        AttributeDefinition attributeDefinition;
        String defaultValue;
        ElementDefinition elementDefinition2 = this.elementDefinition;
        if (elementDefinition2 != null) {
            AttributeDefinition[] attributes = elementDefinition2.getAttributes();
            for (int i2 = 0; i2 < this.numAttributesDefined; i2++) {
                if (!this.defaultAttributeSpecified[i2] && (defaultValue = (attributeDefinition = attributes[i2]).getDefaultValue()) != null) {
                    this.attribs.addAttribute(attributeDefinition.getPrefix(), attributeDefinition.getLocalName(), attributeDefinition.getQName(), attributeDefinition.getValueTypeString(), defaultValue);
                }
            }
        }
    }

    private void processNSContextEnd() {
        int contextSize = this.nsSupport.getContextSize();
        for (int i2 = 0; i2 < contextSize; i2++) {
            this.parser.reportEndPrefixMapping(this.nsSupport.getContextPrefix(i2));
        }
        this.nsSupport.popContext();
    }

    private void processSimpleElement(String str) {
        ElementDefinition element = getElement(str);
        this.elementDefinition = element;
        if (element != null) {
            AttributeDefinition[] attributes = element.getAttributes();
            int attributeCount = this.elementDefinition.getAttributeCount();
            for (int i2 = 0; i2 < attributeCount; i2++) {
                AttributeDefinition attributeDefinition = attributes[i2];
                String defaultValue = attributeDefinition.getDefaultValue();
                if (defaultValue != null) {
                    this.attribs.addAttribute(attributeDefinition.getPrefix(), attributeDefinition.getLocalName(), attributeDefinition.getQName(), attributeDefinition.getValueTypeString(), defaultValue);
                }
            }
        }
    }

    private void pushEntityState(String str, boolean z, boolean z2) {
        pushEntityState(str, z, z2, 0);
    }

    private void resolveNamespacePrefixes() {
        String uri;
        this.elementURI = this.nsSupport.getURI(this.elementURI);
        int length = this.attribs.getLength();
        for (int i2 = 0; i2 < length; i2++) {
            String uri2 = this.attribs.getURI(i2);
            if (!(uri2 == "" || (uri = this.nsSupport.getURI(uri2)) == "")) {
                this.attribs.setURI(i2, uri);
            }
        }
    }

    private void safeBacktrack() {
        char[] cArr = this.yy_buffer;
        int i2 = this.yy_markedPos - 1;
        this.yy_markedPos = i2;
        if (cArr[i2] == '\n') {
            this.yyline_next--;
        }
    }

    private int stringToken(int i2, String str) {
        this.stringValue = str;
        return i2;
    }

    private void yy_ScanError(int i2) {
        String str;
        try {
            str = YY_ERROR_MSG[i2];
        } catch (ArrayIndexOutOfBoundsException unused) {
            str = YY_ERROR_MSG[0];
        }
        throw new Error(str);
    }

    private void yy_do_eof() {
        if (!this.yy_eof_done) {
            this.yy_eof_done = true;
            yyclose();
        }
    }

    private boolean yy_refill() {
        int i2 = this.yy_savePos;
        if (i2 < 0 && (i2 = this.yy_startRead) > 0) {
            i2--;
        }
        if (i2 > 0) {
            char[] cArr = this.yy_buffer;
            System.arraycopy(cArr, i2, cArr, 0, this.yy_endRead - i2);
            this.yy_endRead -= i2;
            this.yy_currentPos -= i2;
            this.yy_markedPos -= i2;
            this.yy_pushbackPos -= i2;
            this.yy_startRead -= i2;
            if (this.yy_savePos >= 0) {
                this.yy_savePos = 0;
            }
        }
        int i3 = this.yy_markedPos;
        char[] cArr2 = this.yy_buffer;
        if (i3 >= cArr2.length || this.yy_currentPos >= cArr2.length) {
            char[] cArr3 = this.yy_buffer;
            char[] cArr4 = new char[(cArr3.length * 2)];
            System.arraycopy(cArr3, 0, cArr4, 0, cArr3.length);
            this.yy_buffer = cArr4;
            if (cArr4.length > this.yy_saved_buffer.length) {
                this.yy_saved_buffer = cArr4;
            }
        }
        int i4 = 0;
        while (i4 == 0) {
            Reader reader = this.yy_reader;
            char[] cArr5 = this.yy_buffer;
            int i5 = this.yy_endRead;
            i4 = reader.read(cArr5, i5, cArr5.length - i5);
        }
        if (i4 < 0) {
            return true;
        }
        this.yy_endRead += i4;
        return false;
    }

    public static int[] yy_unpack() {
        int[] iArr = new int[21172];
        yy_unpack(yy_packed0, 0, iArr);
        return iArr;
    }

    public static char[] yy_unpack_cmap(String str) {
        int i2;
        char[] cArr = new char[65536];
        int i3 = 0;
        int i4 = 0;
        while (i3 < 1350) {
            int i5 = i3 + 1;
            int charAt = str.charAt(i3);
            int i6 = i5 + 1;
            char charAt2 = str.charAt(i5);
            while (true) {
                i2 = i4 + 1;
                cArr[i4] = charAt2;
                charAt--;
                if (charAt <= 0) {
                    break;
                }
                i4 = i2;
            }
            i3 = i6;
            i4 = i2;
        }
        return cArr;
    }

    private void yypushback(int i2) {
        if (i2 > yylength()) {
            yy_ScanError(3);
        }
        this.yy_markedPos -= i2;
        this.yyline_next = this.yyline;
        this.yycolumn_next = this.yycolumn;
        this.yy_sawCR = this.yy_prev_sawCR;
        for (int i3 = this.yy_startRead; i3 < this.yy_markedPos; i3++) {
            yycountChar(this.yy_buffer[i3]);
        }
    }

    private String yytext2() {
        CharStringConverter charStringConverter = this.stringConverter;
        char[] cArr = this.yy_buffer;
        int i2 = this.yy_startRead;
        return charStringConverter.convert(cArr, i2, this.yy_markedPos - i2);
    }

    public void defineElement(String str, ElementDefinition elementDefinition2) {
        this.elementMap.put(str, elementDefinition2);
    }

    public void enableNamespaces(boolean z) {
        if (z) {
            this.tagState = 8;
            this.tagStartState = 9;
            return;
        }
        this.tagState = 6;
        this.tagStartState = 7;
        this.elementLocalName = "";
        this.elementURI = "";
        this.attributeLocalName = "";
        this.attributeURI = "";
    }

    public void endCdata() {
        LexicalHandler lexicalHandler = this.parser.lexHandler;
        if (lexicalHandler != null) {
            lexicalHandler.endCDATA();
            this.inCdataSection = false;
        }
    }

    public int getColumnNumber() {
        return this.yycolumn + 1;
    }

    public ElementDefinition getElement(String str) {
        return (ElementDefinition) this.elementMap.get(str);
    }

    public String getEncoding() {
        Entity entity = this.currentEntity;
        if (entity != null) {
            return entity.getDeclaredEncoding();
        }
        return null;
    }

    public int getLineNumber() {
        return this.yyline + 1;
    }

    public String getPublicID() {
        Entity entity = this.currentEntity;
        if (entity != null) {
            return entity.getPublicID();
        }
        return null;
    }

    public String getSystemID() {
        Entity entity = this.currentEntity;
        if (entity != null) {
            return entity.getSystemID();
        }
        return null;
    }

    public String getVersion() {
        Entity entity = this.currentEntity;
        if (entity != null) {
            return entity.getXMLVersion();
        }
        return null;
    }

    /* JADX WARNING: Removed duplicated region for block: B:23:0x0045  */
    /* JADX WARNING: Removed duplicated region for block: B:38:0x002b A[SYNTHETIC] */
    public String normalizeValue(String str) {
        int i2;
        if (str == null || str.length() == 0) {
            return str;
        }
        char[] charArray = str.toCharArray();
        int length = charArray.length;
        char[] cArr = new char[length];
        int i3 = 0;
        while (i3 < length && ((r8 = charArray[i3]) == '\t' || r8 == '\n' || r8 == '\r' || r8 == ' ')) {
            i3++;
        }
        int i4 = 0;
        while (i3 < length) {
            while (true) {
                i2 = i3 + 1;
                char c = charArray[i3];
                if (c != '\t' && c != '\n' && c != '\r' && c != ' ') {
                    cArr[i4] = c;
                    i3 = i2;
                    i4++;
                    if (i2 >= length) {
                        break;
                    }
                } else {
                    break;
                }
            }
            if (i3 >= length) {
                i2 = i3 + 1;
                char c2 = charArray[i3];
                if (c2 != '\t' && c2 != '\n' && c2 != '\r' && c2 != ' ') {
                    int i5 = i4 + 1;
                    cArr[i4] = ' ';
                    i4 = i5 + 1;
                    cArr[i5] = c2;
                    i3 = i2;
                }
                i3 = i2;
                if (i3 >= length) {
                }
            }
        }
        return new String(cArr, 0, i4);
    }

    public boolean parseExternalEntities(int i2) {
        if (this.currentEntity.isStandalone()) {
            return false;
        }
        if (i2 != 1) {
            return this.parser.fExternalGeneralEntities;
        }
        return this.parser.fExternalParameterEntities;
    }

    public void pushEntity(String str, Entity entity, boolean z, boolean z2) {
        pushEntity(str, entity, z, z2, 0);
    }

    public String rescanAttributeValue(String str) {
        clearCbuf();
        char[] charArray = str.toCharArray();
        yypushBuffer(charArray, 0, charArray.length);
        pushEntityState(null, false, true, yystate());
        yybegin(11);
        this.isEntityBeingParsed = false;
        if (yylex() == 294) {
            this.isEntityBeingParsed = true;
            return this.stringConverter.convert(this.cbuf, 0, this.cbuflen);
        }
        throw fatalError("Unexpected element while parsing attribute default value");
    }

    public void reset(Entity entity) {
        try {
            setTokenize(true);
            this.tagStack.clear();
            this.attribs.clear();
            this.entityStack.clear();
            clearEntityState();
            this.elementMap.clear();
            this.currentEntity = entity;
            this.entityManager.clear();
            this.elementDefinition = null;
            if (!entity.isOpen()) {
                entity.open();
            }
            if (this.parser.fNamespaces) {
                this.nsSupport.reset();
            }
            this.isNamespaceDeclaration = false;
            this.bypassGERefs = false;
            this.bypassPERefs = false;
            this.needsNormalization = false;
            this.entityWasSkipped = false;
            this.inCdataSection = false;
            this.cdataLength = 0;
            this.cdataStart = 0;
            this.cbuflen = 0;
            this.tagType = 0;
            this.piPrevState = 0;
            this.prevState = 0;
            this.endOfTag = false;
            this.tokenStartLine = 0;
            this.tokenStartColumn = 0;
            this.numAttributesDefined = 0;
            this.yy_reader = null;
            yyreset(entity.getReader());
        } catch (RecursionException unused) {
        }
    }

    public void setTokenize(boolean z) {
        this.tokenizeInput = z;
        this.baseState = z ? 0 : 2;
        int yystate = yystate();
        if (yystate == 0 || yystate == 2) {
            yybegin(this.baseState);
        }
    }

    public void startCdata() {
        LexicalHandler lexicalHandler = this.parser.lexHandler;
        if (lexicalHandler != null) {
            lexicalHandler.startCDATA();
            this.inCdataSection = true;
        }
    }

    public final void yybegin(int i2) {
        this.yy_lexical_state = i2;
    }

    public final int yybufferLeft() {
        return this.yy_endRead - this.yy_markedPos;
    }

    public final char yycharat(int i2) {
        return this.yy_buffer[this.yy_startRead + i2];
    }

    public final void yyclose() {
        this.yy_atEOF = true;
        this.yy_endRead = this.yy_startRead;
        Reader reader = this.yy_reader;
        if (reader != null) {
            reader.close();
        }
    }

    public final void yycountChar(int i2) {
        if (i2 != 10) {
            this.yycolumn_next++;
            return;
        }
        this.yyline_next++;
        this.yycolumn_next = 0;
    }

    public final int yylength() {
        return this.yy_markedPos - this.yy_startRead;
    }

    /* JADX INFO: Can't fix incorrect switch cases order, some code will duplicate */
    /* JADX WARNING: Code restructure failed: missing block: B:10:0x006b, code lost:
        r0 = 65535;
     */
    /* JADX WARNING: Removed duplicated region for block: B:105:0x0252  */
    /* JADX WARNING: Removed duplicated region for block: B:106:0x0287  */
    /* JADX WARNING: Removed duplicated region for block: B:107:0x0295  */
    /* JADX WARNING: Removed duplicated region for block: B:113:0x02d0  */
    /* JADX WARNING: Removed duplicated region for block: B:116:0x02dd  */
    /* JADX WARNING: Removed duplicated region for block: B:127:0x0326  */
    /* JADX WARNING: Removed duplicated region for block: B:131:0x033a  */
    /* JADX WARNING: Removed duplicated region for block: B:132:0x0346  */
    /* JADX WARNING: Removed duplicated region for block: B:138:0x0371  */
    /* JADX WARNING: Removed duplicated region for block: B:139:0x037d  */
    /* JADX WARNING: Removed duplicated region for block: B:140:0x03ad  */
    /* JADX WARNING: Removed duplicated region for block: B:141:0x03d5  */
    /* JADX WARNING: Removed duplicated region for block: B:142:0x03e3  */
    /* JADX WARNING: Removed duplicated region for block: B:148:0x041b  */
    /* JADX WARNING: Removed duplicated region for block: B:149:0x0429  */
    /* JADX WARNING: Removed duplicated region for block: B:14:0x0077  */
    /* JADX WARNING: Removed duplicated region for block: B:156:0x045c  */
    /* JADX WARNING: Removed duplicated region for block: B:15:0x0079  */
    /* JADX WARNING: Removed duplicated region for block: B:162:0x0486  */
    /* JADX WARNING: Removed duplicated region for block: B:171:0x04ca  */
    /* JADX WARNING: Removed duplicated region for block: B:172:0x04e8  */
    /* JADX WARNING: Removed duplicated region for block: B:173:0x04fe  */
    /* JADX WARNING: Removed duplicated region for block: B:180:0x0533  */
    /* JADX WARNING: Removed duplicated region for block: B:183:0x0559  */
    /* JADX WARNING: Removed duplicated region for block: B:184:0x0563  */
    /* JADX WARNING: Removed duplicated region for block: B:185:0x056d  */
    /* JADX WARNING: Removed duplicated region for block: B:186:0x0589  */
    /* JADX WARNING: Removed duplicated region for block: B:189:0x05b9  */
    /* JADX WARNING: Removed duplicated region for block: B:18:0x008a  */
    /* JADX WARNING: Removed duplicated region for block: B:190:0x05cb  */
    /* JADX WARNING: Removed duplicated region for block: B:191:0x05e0  */
    /* JADX WARNING: Removed duplicated region for block: B:194:0x0602  */
    /* JADX WARNING: Removed duplicated region for block: B:199:0x061b  */
    /* JADX WARNING: Removed duplicated region for block: B:202:0x0639  */
    /* JADX WARNING: Removed duplicated region for block: B:227:0x06b2  */
    /* JADX WARNING: Removed duplicated region for block: B:231:0x06c4  */
    /* JADX WARNING: Removed duplicated region for block: B:235:0x06d6  */
    /* JADX WARNING: Removed duplicated region for block: B:236:0x06e7  */
    /* JADX WARNING: Removed duplicated region for block: B:237:0x06ee  */
    /* JADX WARNING: Removed duplicated region for block: B:238:0x06f5  */
    /* JADX WARNING: Removed duplicated region for block: B:239:0x0710  */
    /* JADX WARNING: Removed duplicated region for block: B:265:0x079e  */
    /* JADX WARNING: Removed duplicated region for block: B:266:0x07aa  */
    /* JADX WARNING: Removed duplicated region for block: B:269:0x07c9  */
    /* JADX WARNING: Removed duplicated region for block: B:272:0x07e5  */
    /* JADX WARNING: Removed duplicated region for block: B:273:0x07ee  */
    /* JADX WARNING: Removed duplicated region for block: B:274:0x07f5  */
    /* JADX WARNING: Removed duplicated region for block: B:275:0x0805  */
    /* JADX WARNING: Removed duplicated region for block: B:276:0x081b  */
    /* JADX WARNING: Removed duplicated region for block: B:277:0x082b  */
    /* JADX WARNING: Removed duplicated region for block: B:278:0x0841  */
    /* JADX WARNING: Removed duplicated region for block: B:279:0x0848  */
    /* JADX WARNING: Removed duplicated region for block: B:283:0x0857  */
    /* JADX WARNING: Removed duplicated region for block: B:284:0x085e  */
    /* JADX WARNING: Removed duplicated region for block: B:285:0x0865  */
    /* JADX WARNING: Removed duplicated region for block: B:286:0x087e  */
    /* JADX WARNING: Removed duplicated region for block: B:290:0x08ab  */
    /* JADX WARNING: Removed duplicated region for block: B:291:0x08bd  */
    /* JADX WARNING: Removed duplicated region for block: B:292:0x08cb  */
    /* JADX WARNING: Removed duplicated region for block: B:296:0x08f5  */
    /* JADX WARNING: Removed duplicated region for block: B:297:0x0900  */
    /* JADX WARNING: Removed duplicated region for block: B:302:0x0931  */
    /* JADX WARNING: Removed duplicated region for block: B:303:0x0937  */
    /* JADX WARNING: Removed duplicated region for block: B:322:0x0981  */
    /* JADX WARNING: Removed duplicated region for block: B:323:0x098e  */
    /* JADX WARNING: Removed duplicated region for block: B:324:0x099b  */
    /* JADX WARNING: Removed duplicated region for block: B:325:0x09a2  */
    /* JADX WARNING: Removed duplicated region for block: B:327:0x09b1  */
    /* JADX WARNING: Removed duplicated region for block: B:328:0x09bd  */
    /* JADX WARNING: Removed duplicated region for block: B:329:0x09c9  */
    /* JADX WARNING: Removed duplicated region for block: B:32:0x00bd  */
    /* JADX WARNING: Removed duplicated region for block: B:330:0x09d5  */
    /* JADX WARNING: Removed duplicated region for block: B:331:0x09e1  */
    /* JADX WARNING: Removed duplicated region for block: B:35:0x00d0  */
    /* JADX WARNING: Removed duplicated region for block: B:397:0x00e2 A[SYNTHETIC] */
    /* JADX WARNING: Removed duplicated region for block: B:398:0x00e8 A[SYNTHETIC] */
    /* JADX WARNING: Removed duplicated region for block: B:399:0x00eb A[SYNTHETIC] */
    /* JADX WARNING: Removed duplicated region for block: B:400:0x00fb A[SYNTHETIC] */
    /* JADX WARNING: Removed duplicated region for block: B:401:0x0103 A[SYNTHETIC] */
    /* JADX WARNING: Removed duplicated region for block: B:402:0x0109 A[SYNTHETIC] */
    /* JADX WARNING: Removed duplicated region for block: B:403:0x010c A[SYNTHETIC] */
    /* JADX WARNING: Removed duplicated region for block: B:404:0x010f A[SYNTHETIC] */
    /* JADX WARNING: Removed duplicated region for block: B:405:0x0112 A[SYNTHETIC] */
    /* JADX WARNING: Removed duplicated region for block: B:406:0x0118 A[SYNTHETIC] */
    /* JADX WARNING: Removed duplicated region for block: B:407:0x0133 A[SYNTHETIC] */
    /* JADX WARNING: Removed duplicated region for block: B:408:0x013b A[SYNTHETIC] */
    /* JADX WARNING: Removed duplicated region for block: B:409:0x013e A[SYNTHETIC] */
    /* JADX WARNING: Removed duplicated region for block: B:410:0x0141 A[SYNTHETIC] */
    /* JADX WARNING: Removed duplicated region for block: B:411:0x0181 A[SYNTHETIC] */
    /* JADX WARNING: Removed duplicated region for block: B:412:0x0184 A[SYNTHETIC] */
    /* JADX WARNING: Removed duplicated region for block: B:413:0x0190 A[SYNTHETIC] */
    /* JADX WARNING: Removed duplicated region for block: B:414:0x0197 A[SYNTHETIC] */
    /* JADX WARNING: Removed duplicated region for block: B:415:0x019a A[SYNTHETIC] */
    /* JADX WARNING: Removed duplicated region for block: B:416:0x01a0 A[SYNTHETIC] */
    /* JADX WARNING: Removed duplicated region for block: B:417:0x01c8 A[SYNTHETIC] */
    /* JADX WARNING: Removed duplicated region for block: B:418:0x01cb A[SYNTHETIC] */
    /* JADX WARNING: Removed duplicated region for block: B:419:0x01ce A[SYNTHETIC] */
    /* JADX WARNING: Removed duplicated region for block: B:420:0x01d2 A[SYNTHETIC] */
    /* JADX WARNING: Removed duplicated region for block: B:421:0x01ee A[SYNTHETIC] */
    /* JADX WARNING: Removed duplicated region for block: B:422:0x02d7 A[SYNTHETIC] */
    /* JADX WARNING: Removed duplicated region for block: B:423:0x02da A[SYNTHETIC] */
    /* JADX WARNING: Removed duplicated region for block: B:424:0x02f0 A[SYNTHETIC] */
    /* JADX WARNING: Removed duplicated region for block: B:425:0x0300 A[SYNTHETIC] */
    /* JADX WARNING: Removed duplicated region for block: B:426:0x0323 A[SYNTHETIC] */
    /* JADX WARNING: Removed duplicated region for block: B:427:0x0473 A[SYNTHETIC] */
    /* JADX WARNING: Removed duplicated region for block: B:428:0x0499 A[SYNTHETIC] */
    /* JADX WARNING: Removed duplicated region for block: B:429:0x04aa A[SYNTHETIC] */
    /* JADX WARNING: Removed duplicated region for block: B:430:0x04be A[SYNTHETIC] */
    /* JADX WARNING: Removed duplicated region for block: B:431:0x04c1 A[SYNTHETIC] */
    /* JADX WARNING: Removed duplicated region for block: B:432:0x04c7 A[SYNTHETIC] */
    /* JADX WARNING: Removed duplicated region for block: B:433:0x064f A[SYNTHETIC] */
    /* JADX WARNING: Removed duplicated region for block: B:434:0x069e A[SYNTHETIC] */
    /* JADX WARNING: Removed duplicated region for block: B:435:0x0729 A[SYNTHETIC] */
    /* JADX WARNING: Removed duplicated region for block: B:436:0x072c A[SYNTHETIC] */
    /* JADX WARNING: Removed duplicated region for block: B:437:0x072f A[SYNTHETIC] */
    /* JADX WARNING: Removed duplicated region for block: B:438:0x0732 A[SYNTHETIC] */
    /* JADX WARNING: Removed duplicated region for block: B:439:0x0735 A[SYNTHETIC] */
    /* JADX WARNING: Removed duplicated region for block: B:440:0x0738 A[SYNTHETIC] */
    /* JADX WARNING: Removed duplicated region for block: B:441:0x073e A[SYNTHETIC] */
    /* JADX WARNING: Removed duplicated region for block: B:442:0x0749 A[SYNTHETIC] */
    /* JADX WARNING: Removed duplicated region for block: B:443:0x074c A[SYNTHETIC] */
    /* JADX WARNING: Removed duplicated region for block: B:444:0x074f A[SYNTHETIC] */
    /* JADX WARNING: Removed duplicated region for block: B:445:0x0755 A[SYNTHETIC] */
    /* JADX WARNING: Removed duplicated region for block: B:446:0x0760 A[SYNTHETIC] */
    /* JADX WARNING: Removed duplicated region for block: B:447:0x076e A[SYNTHETIC] */
    /* JADX WARNING: Removed duplicated region for block: B:448:0x0776 A[SYNTHETIC] */
    /* JADX WARNING: Removed duplicated region for block: B:449:0x077c A[SYNTHETIC] */
    /* JADX WARNING: Removed duplicated region for block: B:450:0x078c A[SYNTHETIC] */
    /* JADX WARNING: Removed duplicated region for block: B:451:0x090a A[SYNTHETIC] */
    /* JADX WARNING: Removed duplicated region for block: B:452:0x0969 A[SYNTHETIC] */
    /* JADX WARNING: Removed duplicated region for block: B:453:0x0975 A[SYNTHETIC] */
    /* JADX WARNING: Removed duplicated region for block: B:454:0x09ae A[SYNTHETIC] */
    /* JADX WARNING: Removed duplicated region for block: B:472:0x0b26 A[SYNTHETIC] */
    /* JADX WARNING: Removed duplicated region for block: B:563:0x00b5 A[SYNTHETIC] */
    /* JADX WARNING: Removed duplicated region for block: B:58:0x011e  */
    /* JADX WARNING: Removed duplicated region for block: B:68:0x0147  */
    /* JADX WARNING: Removed duplicated region for block: B:69:0x0158  */
    /* JADX WARNING: Removed duplicated region for block: B:70:0x0167  */
    /* JADX WARNING: Removed duplicated region for block: B:81:0x01a6  */
    /* JADX WARNING: Removed duplicated region for block: B:84:0x01c1  */
    /* JADX WARNING: Removed duplicated region for block: B:91:0x01d8  */
    /* JADX WARNING: Removed duplicated region for block: B:92:0x01e2  */
    /* JADX WARNING: Removed duplicated region for block: B:95:0x01f5  */
    /* JADX WARNING: Removed duplicated region for block: B:96:0x01fe  */
    /* JADX WARNING: Removed duplicated region for block: B:97:0x020a  */
    /* JADX WARNING: Removed duplicated region for block: B:98:0x0218  */
    /* JADX WARNING: Removed duplicated region for block: B:99:0x0224  */
    public int yylex() {
        char c;
        int i2;
        char c2;
        int i3;
        String str;
        this.yy_endRead_l = this.yy_endRead;
        this.yy_buffer_l = this.yy_buffer;
        this.yycmap_l = yycmap;
        int[] iArr = yytrans;
        int[] iArr2 = yy_rowMap;
        byte[] bArr = YY_ATTRIBUTE;
        int i4 = -1;
        this.yy_pushbackPos = -1;
        int i5 = -1;
        while (true) {
            int i6 = this.yy_markedPos;
            this.yy_markedPos_l = i6;
            int i7 = this.yyline_next;
            this.yyline = i7;
            int i8 = this.yycolumn_next;
            this.yycolumn = i8;
            this.yy_startRead = i6;
            this.yy_currentPos = i6;
            this.yy_currentPos_l = i6;
            this.yy_startRead_l = i6;
            this.yy_state = this.yy_lexical_state;
            int i9 = -1;
            boolean z = false;
            while (true) {
                int i10 = this.yy_currentPos_l;
                if (i10 < this.yy_endRead_l) {
                    char[] cArr = this.yy_buffer_l;
                    this.yy_currentPos_l = i10 + 1;
                    c = cArr[i10];
                    if (c == '\n') {
                        i8++;
                    } else {
                        i7++;
                        i8 = 0;
                    }
                    i2 = iArr[iArr2[this.yy_state] + this.yycmap_l[c]];
                    if (i2 == i4) {
                        this.yy_state = i2;
                        byte b2 = bArr[i2];
                        if ((b2 & 2) == 2) {
                            i5 = this.yy_currentPos_l;
                        }
                        if ((b2 & 1) == 1) {
                            boolean z2 = (b2 & 4) == 4;
                            int i11 = this.yy_state;
                            this.yy_markedPos_l = this.yy_currentPos_l;
                            this.yyline_next = i7;
                            this.yycolumn_next = i8;
                            z = z2;
                            i9 = i11;
                            if ((b2 & 8) == 8) {
                            }
                        }
                        i4 = -1;
                    }
                } else if (!this.yy_atEOF) {
                    this.yy_currentPos = i10;
                    this.yy_markedPos = this.yy_markedPos_l;
                    this.yy_pushbackPos = i5;
                    boolean yy_refill = yy_refill();
                    int i12 = this.yy_currentPos;
                    this.yy_currentPos_l = i12;
                    this.yy_markedPos_l = this.yy_markedPos;
                    char[] cArr2 = this.yy_buffer;
                    this.yy_buffer_l = cArr2;
                    this.yy_endRead_l = this.yy_endRead;
                    int i13 = this.yy_pushbackPos;
                    if (yy_refill) {
                        i5 = i13;
                    } else {
                        this.yy_currentPos_l = i12 + 1;
                        c = cArr2[i12];
                        i5 = i13;
                        if (c == '\n') {
                        }
                        i2 = iArr[iArr2[this.yy_state] + this.yycmap_l[c]];
                        if (i2 == i4) {
                        }
                    }
                }
                this.yy_markedPos = this.yy_markedPos_l;
                if (z) {
                    this.yy_markedPos = i5;
                }
                switch (i9) {
                    case 5:
                    case 54:
                        yybegin(4);
                        break;
                    case 6:
                    case 8:
                    case 28:
                    case 56:
                    case 126:
                    case 127:
                    case 128:
                    case 434:
                    case 435:
                    case 436:
                    case 437:
                    case 438:
                    case 439:
                    case 440:
                    case 441:
                    case UnknownRecord.CODENAME_1BA:
                    case 443:
                    case 444:
                    case 445:
                    case 446:
                    case 447:
                    case 448:
                    case 449:
                    case 450:
                    case 451:
                    case 452:
                    case 453:
                    case 454:
                    case 455:
                    case 456:
                    case 457:
                    case 458:
                    case 459:
                    case 460:
                    case 461:
                    case 462:
                    case 463:
                    case 464:
                    case 465:
                    case 466:
                    case 467:
                    case 468:
                    case 469:
                    case 470:
                    case 471:
                    case 472:
                    case 473:
                    case 474:
                    case 475:
                    case 476:
                    case 477:
                    case 478:
                    case 479:
                    case 480:
                    case 481:
                    case 482:
                    case 483:
                    case 484:
                    case 485:
                    case 486:
                    case 487:
                    case 488:
                    case 489:
                    case 490:
                    case 491:
                    case 492:
                    case 493:
                    case 494:
                    case 495:
                    case 496:
                    case 497:
                    case 498:
                    case 499:
                    case Piccolo.YYSTACKSIZE:
                    case 501:
                    case 502:
                    case 503:
                    case 504:
                    case 505:
                    case 506:
                    case 507:
                    case Piccolo.YYTABLESIZE:
                    case 509:
                    case 510:
                    case 511:
                    case 512:
                    case 513:
                    case 514:
                    case 515:
                    case 516:
                    case 517:
                    case 518:
                    case 519:
                    case 520:
                    case 521:
                    case 522:
                    case 523:
                    case 524:
                    case 525:
                    case 526:
                    case 527:
                    case 528:
                    case 529:
                    case 530:
                    case 531:
                    case 532:
                    case 533:
                    case 534:
                    case 535:
                    case 536:
                    case 537:
                    case 538:
                    case 539:
                    case 540:
                    case 541:
                    case 542:
                    case 543:
                    case 544:
                    case 545:
                    case 546:
                    case 547:
                    case 548:
                    case 549:
                    case 550:
                    case 551:
                    case 552:
                    case 553:
                    case 554:
                    case 555:
                    case 556:
                    case 557:
                    case 558:
                    case 559:
                    case 560:
                    case 561:
                    case 562:
                    case 563:
                    case 564:
                    case 565:
                    case 566:
                    case 567:
                    case 568:
                    case 569:
                    case 570:
                    case 571:
                    case 572:
                    case 573:
                    case 574:
                    case 575:
                        break;
                    case 7:
                    case 9:
                    case 10:
                    case 12:
                    case 19:
                    case 20:
                    case 27:
                    case 31:
                    case 36:
                    case 37:
                    case 163:
                    case 164:
                    case 166:
                    case 168:
                    case 169:
                    case 170:
                    case 171:
                    case 172:
                    case 173:
                    case 174:
                    case 175:
                    case 176:
                    case 183:
                    case 184:
                    case 185:
                    case HSSFShapeTypes.ActionButtonForwardNext:
                    case HSSFShapeTypes.ActionButtonBackPrevious:
                    case HSSFShapeTypes.ActionButtonReturn:
                    case HSSFShapeTypes.ActionButtonSound:
                    case HSSFShapeTypes.ActionButtonMovie:
                    case HSSFShapeTypes.HostControl:
                    case HSSFShapeTypes.TextBox:
                    case 203:
                    case 204:
                    case 205:
                    case 207:
                    case 209:
                    case 211:
                    case 212:
                    case 213:
                    case 214:
                    case 216:
                    case 217:
                    case 219:
                    case 220:
                    case 221:
                    case 223:
                    case 225:
                    case 226:
                    case 227:
                    case 228:
                    case 229:
                    case 231:
                    case 240:
                    case 241:
                    case 242:
                    case 243:
                    case 248:
                    case 249:
                    case 250:
                    case 251:
                    case 253:
                    case 255:
                    case 259:
                    case 260:
                    case 261:
                    case 262:
                    case 266:
                    case 267:
                    case 268:
                    case 275:
                    case 276:
                    case 277:
                    case 278:
                    case 284:
                    case 285:
                    case 286:
                    case 287:
                    case 288:
                    case 299:
                    case 300:
                    case 301:
                    case 302:
                    case 305:
                    case 306:
                    case 307:
                    case 308:
                    case 312:
                    case 313:
                    case 316:
                    case 317:
                    case 318:
                    case 323:
                    case 324:
                    case 325:
                    case 326:
                    case 327:
                    case 328:
                    case 329:
                    case 337:
                    case 338:
                    case 339:
                    case 340:
                    case 343:
                    case 344:
                    case 345:
                    case 346:
                    case UnknownRecord.LABELRANGES_015F:
                    case 352:
                    case 353:
                    case 357:
                    case 358:
                    case 359:
                    case 369:
                    case 370:
                    case 371:
                    case 372:
                    case 374:
                    case 375:
                    case 376:
                    case 377:
                    case 379:
                    case 380:
                    case 381:
                    case 383:
                    case 384:
                    case 386:
                    case 387:
                    case 394:
                    case 395:
                    case 397:
                    case 398:
                    case 399:
                    case 400:
                    case 401:
                    case 402:
                    case 403:
                    case 407:
                    case 409:
                    case 412:
                    case 413:
                    case 415:
                    case 417:
                    case 418:
                    case 420:
                    case 426:
                    case 428:
                    case 433:
                    default:
                        if (c2 != 65535 || this.yy_startRead != this.yy_currentPos) {
                            yy_ScanError(2);
                            break;
                        } else {
                            this.yy_atEOF = true;
                            yy_do_eof();
                            int i14 = this.yy_lexical_state;
                            if (i14 == 3) {
                                StringBuffer a = a.a("Entity is not well-formed (ending lex state: ");
                                a.append(yystate());
                                a.append(")");
                                throw fatalError(a.toString());
                            } else if (i14 == 4) {
                                StringBuffer a2 = a.a("Entity is not well-formed (ending lex state: ");
                                a2.append(yystate());
                                a2.append(")");
                                throw fatalError(a2.toString());
                            } else if (i14 == 5) {
                                StringBuffer a3 = a.a("Entity is not well-formed (ending lex state: ");
                                a3.append(yystate());
                                a3.append(")");
                                throw fatalError(a3.toString());
                            } else if (i14 == 12) {
                                StringBuffer a4 = a.a("Entity is not well-formed (ending lex state: ");
                                a4.append(yystate());
                                a4.append(")");
                                throw fatalError(a4.toString());
                            } else if (i14 == 27) {
                                StringBuffer a5 = a.a("Entity is not well-formed (ending lex state: ");
                                a5.append(yystate());
                                a5.append(")");
                                throw fatalError(a5.toString());
                            } else if (i14 == 19) {
                                StringBuffer a6 = a.a("Entity is not well-formed (ending lex state: ");
                                a6.append(yystate());
                                a6.append(")");
                                throw fatalError(a6.toString());
                            } else if (i14 != 20) {
                                switch (i14) {
                                    case 8:
                                        StringBuffer a7 = a.a("Entity is not well-formed (ending lex state: ");
                                        a7.append(yystate());
                                        a7.append(")");
                                        throw fatalError(a7.toString());
                                    case 9:
                                        StringBuffer a8 = a.a("Entity is not well-formed (ending lex state: ");
                                        a8.append(yystate());
                                        a8.append(")");
                                        throw fatalError(a8.toString());
                                    case 10:
                                        StringBuffer a9 = a.a("Entity is not well-formed (ending lex state: ");
                                        a9.append(yystate());
                                        a9.append(")");
                                        throw fatalError(a9.toString());
                                    default:
                                        switch (i14) {
                                            case 434:
                                            case 435:
                                            case 436:
                                            case 437:
                                            case 438:
                                            case 439:
                                            case 440:
                                            case 441:
                                            case UnknownRecord.CODENAME_1BA:
                                            case 443:
                                                continue;
                                            default:
                                                if (!yymoreStreams()) {
                                                    return 0;
                                                }
                                                yypopStream();
                                                if (this.isEntityBeingParsed) {
                                                    Entity entity = this.currentEntity;
                                                    if (entity != null) {
                                                        entity.close();
                                                    }
                                                    this.currentEntity = (Entity) this.entityStack.pop();
                                                }
                                                boolean z3 = this.returnEntityEndToken;
                                                boolean z4 = this.isParamEntity;
                                                popEntityState();
                                                if (z3) {
                                                    return 294;
                                                }
                                                if (z4) {
                                                    return 266;
                                                }
                                                continue;
                                        }
                                }
                            } else {
                                StringBuffer a10 = a.a("Entity is not well-formed (ending lex state: ");
                                a10.append(yystate());
                                a10.append(")");
                                throw fatalError(a10.toString());
                            }
                        }
                    case 11:
                    case 74:
                        char[] cArr3 = this.yy_buffer;
                        int i15 = this.yy_startRead;
                        appendToCbuf(cArr3, i15, this.yy_markedPos - i15);
                        break;
                    case 13:
                    case 14:
                    case 17:
                    case 18:
                    case 83:
                    case 87:
                    case 95:
                    case 99:
                        char[] cArr4 = this.yy_buffer;
                        int i16 = this.yy_startRead;
                        appendToCbuf(cArr4, i16, this.yy_markedPos - i16);
                        break;
                    case 15:
                    case 89:
                        clearCbuf();
                        this.prevState = 17;
                        yybegin(17);
                        break;
                    case 16:
                    case 93:
                        clearCbuf();
                        this.prevState = 18;
                        yybegin(18);
                        break;
                    case 21:
                    case 22:
                    case 23:
                    case 24:
                    case 25:
                    case 26:
                    case 29:
                    case 30:
                    case 105:
                    case 131:
                        return 266;
                    case 32:
                    case 150:
                        char[] cArr5 = this.yy_buffer;
                        int i17 = this.yy_startRead;
                        appendToCbuf(cArr5, i17, this.yy_markedPos - i17);
                        break;
                    case 33:
                    case 154:
                    case 155:
                        yybegin(32);
                        break;
                    case 34:
                    case 156:
                        appendToCbuf(this.yy_buffer, this.yy_startRead, yylength());
                        break;
                    case 35:
                    case 160:
                        appendToCbuf(this.yy_buffer, this.yy_startRead, yylength());
                        break;
                    case 38:
                        safeBacktrack();
                        parseCdata();
                        this.parser.reportCdata();
                        return 257;
                    case 39:
                        int parseWhitespace = parseWhitespace();
                        if (parseWhitespace == 257) {
                            this.parser.reportCdata();
                        }
                        return parseWhitespace;
                    case 40:
                        this.tokenStartLine = this.yyline_next + 1;
                        this.tokenStartColumn = this.yycolumn_next + 1;
                        yybegin(this.tagStartState);
                        if (this.parser.fNamespaces) {
                            i3 = parseTagNS();
                        } else {
                            i3 = parseTag();
                        }
                        if (i3 != -1 && this.tokenizeInput) {
                            if (this.tagType == 263) {
                                setTokenize(false);
                            }
                            return this.tagType;
                        }
                    case 41:
                        yybegin(3);
                        break;
                    case 42:
                    case 43:
                    case 45:
                    case 46:
                    case 47:
                    case 48:
                    case 49:
                    case 50:
                    case 51:
                    case 52:
                    case 53:
                    case 55:
                    case 59:
                    case 61:
                    case 62:
                    case 63:
                    case 68:
                    case 71:
                    case 72:
                    case 73:
                    case 77:
                    case 78:
                    case 79:
                    case 80:
                    case 81:
                    case 82:
                    case 86:
                    case 91:
                    case 98:
                    case 101:
                    case 103:
                    case 107:
                    case 108:
                    case 110:
                    case 114:
                    case 115:
                    case 116:
                    case 117:
                    case 120:
                    case 124:
                    case 125:
                    case 129:
                    case 130:
                    case 141:
                    case 148:
                    case 149:
                    case 161:
                    case 162:
                        StringBuffer a11 = a.a("Unexpected character encountered (lex state ");
                        a11.append(yystate());
                        a11.append("): '");
                        a11.append(yytext());
                        a11.append("'");
                        throw fatalError(a11.toString());
                    case 44:
                        safeBacktrack();
                        int parseXML = parseXML();
                        if (parseXML == 0) {
                            break;
                        } else {
                            return parseXML;
                        }
                    case 57:
                        this.attributeQName = yytext2();
                        yybegin(10);
                        break;
                    case 58:
                        yybegin(this.baseState);
                        this.tagStack.push(this.stringValue);
                        processComplexElement();
                        this.parser.reportStartTag(this.elementURI, this.elementLocalName, this.stringValue);
                        this.attribs.clear();
                        if (!this.tokenizeInput) {
                            break;
                        } else {
                            setTokenize(false);
                            return 263;
                        }
                    case 60:
                        yybegin(6);
                        String yytext2 = yytext2();
                        this.stringValue = yytext2;
                        prepareComplexElement(yytext2);
                        break;
                    case 64:
                    case 65:
                    case 66:
                    case 187:
                    case 188:
                    case 270:
                    case 319:
                    case 354:
                    case 382:
                        this.isNamespaceDeclaration = false;
                        String yytext22 = yytext2();
                        this.attributeQName = yytext22;
                        this.attributeLocalName = yytext22;
                        this.attributeURI = "";
                        yybegin(10);
                        break;
                    case 67:
                        yybegin(this.baseState);
                        processComplexElement();
                        resolveNamespacePrefixes();
                        this.parser.reportStartTag(this.elementURI, this.elementLocalName, this.stringValue);
                        this.attribs.clear();
                        this.tagStack.push(this.stringValue);
                        if (!this.tokenizeInput) {
                            break;
                        } else {
                            setTokenize(false);
                            return 263;
                        }
                    case 69:
                    case 70:
                    case 190:
                        this.nsSupport.pushContext();
                        yybegin(8);
                        this.elementURI = "";
                        String yytext23 = yytext2();
                        this.stringValue = yytext23;
                        this.elementLocalName = yytext23;
                        prepareComplexElement(yytext23);
                        break;
                    case 75:
                        appendToCbuf(' ');
                        break;
                    case 76:
                        yybegin(12);
                        break;
                    case 84:
                        for (int i18 = 0; i18 < yylength(); i18++) {
                            appendToCbuf(' ');
                        }
                        break;
                    case 85:
                        yybegin(12);
                        break;
                    case 88:
                        clearCbuf();
                        this.prevState = 17;
                        yybegin(17);
                        char[] cArr6 = this.yy_buffer;
                        int i19 = this.yy_startRead;
                        appendToCbuf(cArr6, i19, this.yy_markedPos - i19);
                        break;
                    case 90:
                        clearCbuf();
                        this.prevState = 17;
                        this.needsNormalization = true;
                        yybegin(12);
                        break;
                    case 92:
                        clearCbuf();
                        this.prevState = 18;
                        yybegin(18);
                        char[] cArr7 = this.yy_buffer;
                        int i20 = this.yy_startRead;
                        appendToCbuf(cArr7, i20, this.yy_markedPos - i20);
                        break;
                    case 94:
                        clearCbuf();
                        this.prevState = 18;
                        this.needsNormalization = true;
                        yybegin(12);
                        break;
                    case 96:
                    case 100:
                        appendToCbuf(' ');
                        break;
                    case 97:
                        this.needsNormalization = true;
                        yybegin(12);
                        break;
                    case 102:
                        yybegin(this.baseState);
                        checkEndTag(this.stringValue);
                        this.parser.reportEndTag(this.elementURI, this.elementLocalName, this.stringValue);
                        if (!this.tokenizeInput) {
                            break;
                        } else {
                            return 264;
                        }
                    case 104:
                        yybegin(this.baseState);
                        checkEndTag(this.stringValue);
                        this.parser.reportEndTag(this.elementURI, this.elementLocalName, this.stringValue);
                        processNSContextEnd();
                        if (!this.tokenizeInput) {
                            break;
                        } else {
                            return 264;
                        }
                    case 106:
                        yybegin(31);
                        this.bypassGERefs = false;
                        this.bypassPERefs = false;
                        break;
                    case 109:
                        yybegin(23);
                        this.bypassPERefs = true;
                        return stringToken(260, yytext2());
                    case 111:
                    case 112:
                    case 218:
                        yybegin(24);
                        return stringToken(299, yytext2());
                    case 113:
                        yybegin(21);
                        return TNEFProperty.PTYPE_BINARY;
                    case 118:
                        yybegin(26);
                        return 274;
                    case 119:
                        yybegin(30);
                        return stringToken(260, yytext2());
                    case 121:
                        return stringToken(260, yytext2());
                    case 122:
                        yybegin(30);
                        return 275;
                    case 123:
                        return 277;
                    case 132:
                        return 313;
                    case 133:
                    case 134:
                    case 135:
                    case 136:
                    case 137:
                    case 140:
                    case 232:
                    case UnknownRecord.BITMAP_00E9:
                    case 234:
                    case 235:
                    case 236:
                    case 237:
                    case 238:
                    case UnknownRecord.PHONETICPR_00EF:
                    case 291:
                    case 292:
                    case 293:
                    case 294:
                    case 295:
                    case 297:
                    case 298:
                    case 330:
                    case 331:
                    case 332:
                    case 333:
                    case 334:
                    case 335:
                    case 336:
                    case 363:
                    case YearFracCalculator.DAYS_PER_NORMAL_YEAR:
                    case YearFracCalculator.DAYS_PER_LEAP_YEAR:
                    case 367:
                    case 368:
                    case 389:
                    case 390:
                    case 410:
                        return stringToken(260, yytext2());
                    case 138:
                        yybegin(21);
                        return 276;
                    case 139:
                        return 274;
                    case 142:
                        return 275;
                    case 143:
                        return 311;
                    case 144:
                        return 314;
                    case 145:
                        return 312;
                    case 146:
                        this.prevState = 34;
                        clearCbuf();
                        appendToCbuf(this.yy_buffer, this.yy_startRead + 1, yylength() - 1);
                        yybegin(this.prevState);
                        break;
                    case 147:
                        this.prevState = 35;
                        clearCbuf();
                        appendToCbuf(this.yy_buffer, this.yy_startRead + 1, yylength() - 1);
                        yybegin(this.prevState);
                        break;
                    case 151:
                        yybegin(36);
                        break;
                    case 152:
                        yybegin(37);
                        break;
                    case 153:
                        char[] cArr8 = this.yy_buffer;
                        int i21 = this.yy_startRead;
                        appendToCbuf(cArr8, i21, this.yy_markedPos - i21);
                        yybegin(32);
                        break;
                    case 157:
                        if (this.bypassGERefs) {
                            appendToCbuf('&');
                            break;
                        } else {
                            yybegin(36);
                            break;
                        }
                    case 158:
                        if (this.bypassPERefs) {
                            appendToCbuf('%');
                            break;
                        } else {
                            yybegin(37);
                            break;
                        }
                    case 159:
                        yybegin(30);
                        return stringToken(261, new String(this.cbuf, 0, this.cbuflen));
                    case 165:
                        if (!this.currentEntity.isInternal()) {
                            yybegin(this.prevState);
                            if (this.currentEntity.getXMLVersion() != null) {
                                return (this.currentEntity.getDeclaredEncoding() != null && !this.currentEntity.isStandaloneDeclared()) ? 317 : 315;
                            }
                            if (!(this.currentEntity.getDeclaredEncoding() == null || this.currentEntity.isStandaloneDeclared())) {
                                return 316;
                            }
                            throw fatalError("XML declaration is not well-formed");
                        }
                        throw fatalError("XML declarations are not allowed in internal entities");
                    case 167:
                        yybegin(this.baseState);
                        int handleEntityRef = handleEntityRef(yytext2(0, yylength() - 1), 0);
                        if (handleEntityRef == 0) {
                            break;
                        } else {
                            return handleEntityRef;
                        }
                    case 177:
                        yybegin(this.piPrevState);
                        this.parser.reportPI(this.elementQName, yytext(0, yylength() - 2));
                        if (!this.tokenizeInput) {
                            break;
                        } else {
                            return 259;
                        }
                    case 178:
                        yybegin(this.piPrevState);
                        this.parser.reportPI(this.elementQName, "");
                        if (this.piPrevState != 33 && this.tokenizeInput) {
                            return 259;
                        }
                    case 179:
                        yybegin(this.baseState);
                        processComplexElement();
                        this.parser.reportStartTag("", "", this.stringValue);
                        this.parser.reportEndTag("", "", this.stringValue);
                        this.attribs.clear();
                        if (!this.tokenizeInput) {
                            break;
                        } else {
                            return 265;
                        }
                    case 180:
                    case 181:
                    case 182:
                    case 264:
                    case 265:
                    case 314:
                    case 315:
                        this.piPrevState = this.baseState;
                        this.elementQName = yytext2(1, yylength() - 1);
                        yybegin(5);
                        break;
                    case 186:
                        yybegin(19);
                        this.stringValue = yytext2(1, yylength() - 1);
                        break;
                    case 189:
                        yybegin(this.baseState);
                        processComplexElement();
                        resolveNamespacePrefixes();
                        this.parser.reportStartTag(this.elementURI, this.elementLocalName, this.stringValue);
                        this.parser.reportEndTag(this.elementURI, this.elementLocalName, this.stringValue);
                        processNSContextEnd();
                        this.attribs.clear();
                        if (!this.tokenizeInput) {
                            break;
                        } else {
                            return 265;
                        }
                    case 191:
                    case HSSFShapeTypes.ActionButtonInformation:
                    case 272:
                        yybegin(20);
                        this.elementURI = this.nsSupport.getDefaultURI();
                        String yytext24 = yytext2(1, yylength() - 1);
                        this.elementLocalName = yytext24;
                        this.stringValue = yytext24;
                        break;
                    case HSSFShapeTypes.ActionButtonEnd:
                        yybegin(this.tagState);
                        parseQuotedTagValue();
                        break;
                    case HSSFShapeTypes.ActionButtonBeginning:
                        yybegin(this.tagState);
                        parseSingleQuotedTagValue();
                        break;
                    case HSSFShapeTypes.ActionButtonDocument:
                        if (!handleLiteralEntityRef(yytext2(0, yylength() - 1), 0)) {
                            appendToCbuf('&');
                            char[] cArr9 = this.yy_buffer;
                            int i22 = this.yy_startRead;
                            appendToCbuf(cArr9, i22, this.yy_markedPos - i22);
                            yybegin(this.prevState);
                            break;
                        } else {
                            break;
                        }
                    case 206:
                        yybegin(this.tagState);
                        if (this.cbuflen < 4 || this.attributeQName == "xmlns") {
                            str = this.stringConverter.convert(this.cbuf, 0, this.cbuflen);
                        } else {
                            str = new String(this.cbuf, 0, this.cbuflen);
                        }
                        addAttribute(this.attributeURI, this.attributeLocalName, this.attributeQName, this.attributeValueType, str);
                        break;
                    case 208:
                        yybegin(this.tagState);
                        addAttribute(this.attributeURI, this.attributeLocalName, this.attributeQName, this.attributeValueType, "");
                        break;
                    case 210:
                        yybegin(this.tagState);
                        addAttribute(this.attributeURI, this.attributeLocalName, this.attributeQName, this.attributeValueType, new String(this.cbuf, 0, this.cbuflen));
                        break;
                    case 215:
                        return 281;
                    case 222:
                        yybegin(30);
                        return 286;
                    case 224:
                        return 283;
                    case 230:
                        yybegin(30);
                        return stringToken(261, yytext(1, yylength() - 2));
                    case 244:
                        return stringToken(261, yytext(1, yylength() - 2));
                    case 245:
                    case 246:
                    case 247:
                    case 303:
                    case 304:
                    case 341:
                    case 342:
                        this.piPrevState = 21;
                        yybegin(5);
                        this.elementQName = yytext2(1, yylength() - 1);
                        break;
                    case 252:
                        yybegin(30);
                        if (!isTopEntity()) {
                            return 302;
                        }
                        throw fatalError("'<![' constructs are not allowed in the internal DTD subset");
                    case 254:
                        appendToCbuf('&');
                        appendToCbuf(this.yy_buffer, this.yy_startRead, yylength());
                        yybegin(this.prevState);
                        break;
                    case 256:
                        if (!isTopEntity()) {
                            if (!handleLiteralEntityRef(yytext2(0, yylength() - 1), 1)) {
                                appendToCbuf('%');
                                char[] cArr10 = this.yy_buffer;
                                int i23 = this.yy_startRead;
                                appendToCbuf(cArr10, i23, this.yy_markedPos - i23);
                                yybegin(this.prevState);
                                break;
                            } else {
                                break;
                            }
                        } else {
                            throw fatalError("Parameter entities may not appear in the internal subset");
                        }
                    case 257:
                        yybegin(this.baseState);
                        this.parser.reportCdata('<');
                        break;
                    case TNEFProperty.PTYPE_BINARY:
                        yybegin(this.baseState);
                        try {
                            clearCbuf();
                            parseEncodedChar(this.yy_buffer, this.yy_startRead + 1, yylength() - 2, 10);
                            this.parser.reportCdata(this.cbuf, 0, this.cbuflen);
                            break;
                        } catch (IllegalCharException unused) {
                            StringBuffer a12 = a.a("Invalid character entity reference: &");
                            a12.append(yytext());
                            throw fatalError(a12.toString());
                        }
                    case 263:
                        yybegin(this.baseState);
                        this.parser.reportCdata('>');
                        break;
                    case 269:
                        this.isNamespaceDeclaration = false;
                        String yytext25 = yytext2();
                        this.attributeQName = yytext25;
                        int indexOf = yytext25.indexOf(58);
                        this.attributeURI = yytext2(0, indexOf);
                        this.attributeLocalName = yytext2(indexOf + 1, (yylength() - indexOf) - 1);
                        yybegin(10);
                        break;
                    case 271:
                        this.nsSupport.pushContext();
                        yybegin(8);
                        String yytext26 = yytext2();
                        this.stringValue = yytext26;
                        int indexOf2 = yytext26.indexOf(58);
                        this.elementURI = yytext2(0, indexOf2);
                        int i24 = indexOf2 + 1;
                        this.elementLocalName = yytext2(i24, yylength() - i24);
                        prepareComplexElement(this.stringValue);
                        break;
                    case 273:
                        appendToCbuf('<');
                        yybegin(this.prevState);
                        break;
                    case 274:
                        yybegin(this.prevState);
                        try {
                            parseEncodedChar(this.yy_buffer, this.yy_startRead + 1, yylength() - 2, 10);
                            break;
                        } catch (ClassCastException unused2) {
                            StringBuffer a13 = a.a("Invalid character entity reference: &");
                            a13.append(yytext());
                            throw fatalError(a13.toString());
                        }
                    case 279:
                        appendToCbuf('>');
                        yybegin(this.prevState);
                        break;
                    case 280:
                        int handleEntityRef2 = handleEntityRef(yytext2(1, yylength() - 2), 1);
                        if (handleEntityRef2 == 0) {
                            break;
                        } else {
                            this.returnEntityEndToken = false;
                            return handleEntityRef2;
                        }
                    case 281:
                        return 282;
                    case 282:
                        if (isTopEntity()) {
                            throw fatalError("Parameter entities may not appear in the internal subset");
                        } else if (handleEntityRef(yytext2(1, yylength() - 2), 1) == 0) {
                            return 266;
                        } else {
                            this.returnEntityEndToken = false;
                            return 266;
                        }
                    case 283:
                        yybegin(24);
                        return stringToken(298, yytext2());
                    case 289:
                        yybegin(21);
                        Piccolo piccolo = this.parser;
                        char[] cArr11 = this.yy_buffer;
                        int i25 = this.yy_startRead;
                        piccolo.reportComment(cArr11, i25, (this.yy_markedPos - 3) - i25);
                        break;
                    case 290:
                        return 303;
                    case 296:
                        return 310;
                    case 309:
                        yybegin(27);
                        break;
                    case 310:
                        yybegin(this.baseState);
                        try {
                            clearCbuf();
                            parseEncodedChar(this.yy_buffer, this.yy_startRead + 2, yylength() - 3, 16);
                            this.parser.reportCdata(this.cbuf, 0, this.cbuflen);
                            break;
                        } catch (IllegalCharException unused3) {
                            StringBuffer a14 = a.a("Invalid character entity reference: &");
                            a14.append(yytext());
                            throw fatalError(a14.toString());
                        }
                    case 311:
                        yybegin(this.baseState);
                        this.parser.reportCdata('&');
                        break;
                    case 320:
                        yybegin(20);
                        String yytext27 = yytext2(1, yylength() - 1);
                        this.stringValue = yytext27;
                        int indexOf3 = yytext27.indexOf(58) + 1;
                        this.elementURI = this.nsSupport.getURI(yytext2(1, indexOf3 - 1));
                        this.elementLocalName = yytext2(indexOf3 + 1, (yylength() - 1) - indexOf3);
                        break;
                    case 321:
                        yybegin(this.prevState);
                        try {
                            parseEncodedChar(this.yy_buffer, this.yy_startRead + 2, yylength() - 3, 16);
                            break;
                        } catch (ClassCastException unused4) {
                            StringBuffer a15 = a.a("Invalid character entity reference: &");
                            a15.append(yytext());
                            throw fatalError(a15.toString());
                        }
                    case 322:
                        appendToCbuf('&');
                        yybegin(this.prevState);
                        break;
                    case 347:
                        yybegin(this.baseState);
                        this.parser.reportCdata('\'');
                        break;
                    case 348:
                        yybegin(this.baseState);
                        this.parser.reportCdata(StringPtg.FORMULA_DELIMITER);
                        break;
                    case 349:
                        this.prevState = this.baseState;
                        yybegin(1);
                        break;
                    case 350:
                        throw fatalError("'?xml' is a reserved processing instruction target and must be in lower case.");
                    case 355:
                        appendToCbuf('\'');
                        yybegin(this.prevState);
                        break;
                    case 356:
                        appendToCbuf(StringPtg.FORMULA_DELIMITER);
                        yybegin(this.prevState);
                        break;
                    case 360:
                        yybegin(30);
                        return 287;
                    case 361:
                        yybegin(30);
                        return 257;
                    case 362:
                        return 309;
                    case 364:
                        return 300;
                    case 373:
                        this.prevState = 21;
                        yybegin(1);
                        break;
                    case 378:
                        yybegin(this.baseState);
                        Piccolo piccolo2 = this.parser;
                        char[] cArr12 = this.yy_buffer;
                        int i26 = this.yy_startRead;
                        piccolo2.reportComment(cArr12, i26 + 3, (this.yy_markedPos - i26) - 6);
                        if (!this.tokenizeInput) {
                            break;
                        } else {
                            return 301;
                        }
                    case 385:
                        yybegin(30);
                        return 289;
                    case 388:
                        yybegin(30);
                        return 288;
                    case 391:
                        return 305;
                    case 392:
                        this.bypassGERefs = true;
                        this.bypassPERefs = true;
                        return 269;
                    case 393:
                        this.bypassGERefs = true;
                        this.bypassPERefs = true;
                        yybegin(29);
                        return 270;
                    case 396:
                        return 273;
                    case 404:
                        this.attributeURI = "xmlns";
                        this.attributeLocalName = yytext2(6, yylength() - 6);
                        this.attributeQName = yytext2();
                        this.isNamespaceDeclaration = true;
                        yybegin(10);
                        break;
                    case 405:
                        this.attributeURI = "xmlns";
                        this.attributeLocalName = "";
                        this.attributeQName = "xmlns";
                        this.isNamespaceDeclaration = true;
                        parseCdataLiteral(StringPtg.FORMULA_DELIMITER, 13);
                        break;
                    case 406:
                        this.attributeURI = "xmlns";
                        this.attributeLocalName = "";
                        this.attributeQName = "xmlns";
                        this.isNamespaceDeclaration = true;
                        parseCdataLiteral('\'', 14);
                        break;
                    case 408:
                        yybegin(30);
                        return 291;
                    case 411:
                        return 304;
                    case 414:
                        return 307;
                    case 416:
                        yybegin(25);
                        return 278;
                    case 419:
                        yybegin(this.baseState);
                        startCdata();
                        parseCdataSection();
                        if (!this.tokenizeInput) {
                            endCdata();
                            break;
                        } else {
                            return 257;
                        }
                    case 421:
                        yybegin(30);
                        return 290;
                    case 422:
                        yybegin(30);
                        return 292;
                    case 423:
                        return 285;
                    case 424:
                        return 285;
                    case 425:
                        return 272;
                    case 427:
                        yybegin(30);
                        return 308;
                    case 429:
                        yybegin(22);
                        return 279;
                    case 430:
                        yybegin(30);
                        return parseExternalEntities(0) ? 267 : 268;
                    case 431:
                        return 271;
                    case 432:
                        yybegin(30);
                        return 280;
                }
                i4 = -1;
                i5 = i5;
            }
            c2 = c;
            this.yy_markedPos = this.yy_markedPos_l;
            if (z) {
            }
            switch (i9) {
            }
            i4 = -1;
            i5 = i5;
        }
    }

    public final boolean yymoreStreams() {
        return !this.yy_streams.isEmpty();
    }

    public final void yynextAction() {
        this.yyline = this.yyline_next;
        this.yycolumn = this.yycolumn_next;
        int i2 = this.yy_markedPos;
        this.yy_startRead = i2;
        this.yy_currentPos = i2;
    }

    public final int yynextBufferChar() {
        char[] cArr = this.yy_buffer;
        int i2 = this.yy_markedPos;
        this.yy_markedPos = i2 + 1;
        return cArr[i2];
    }

    public final int yynextChar() {
        int i2 = this.yy_markedPos;
        if (i2 < this.yy_endRead) {
            char[] cArr = this.yy_buffer;
            this.yy_markedPos = i2 + 1;
            return cArr[i2];
        } else if (this.yy_atEOF) {
            return -1;
        } else {
            boolean yy_refill = yy_refill();
            char[] cArr2 = this.yy_buffer;
            this.yy_buffer_l = cArr2;
            this.yy_endRead_l = this.yy_endRead;
            if (yy_refill) {
                return -1;
            }
            int i3 = this.yy_markedPos;
            this.yy_markedPos = i3 + 1;
            return cArr2[i3];
        }
    }

    public final void yypopStream() {
        Reader reader = this.yy_reader;
        if (reader != null) {
            reader.close();
        }
        YY_StreamInfo yY_StreamInfo = (YY_StreamInfo) this.yy_streams.pop();
        char[] cArr = yY_StreamInfo.yy_buffer;
        this.yy_buffer = cArr;
        this.yy_reader = yY_StreamInfo.yy_reader;
        int i2 = yY_StreamInfo.yy_endRead;
        this.yy_endRead = i2;
        this.yy_startRead = yY_StreamInfo.yy_startRead;
        this.yy_savePos = yY_StreamInfo.yy_savePos;
        this.yy_currentPos = yY_StreamInfo.yy_currentPos;
        this.yy_markedPos = yY_StreamInfo.yy_markedPos;
        this.yy_pushbackPos = yY_StreamInfo.yy_pushbackPos;
        this.yy_atEOF = yY_StreamInfo.yy_atEOF;
        int i3 = yY_StreamInfo.yyline;
        this.yyline = i3;
        int i4 = yY_StreamInfo.yycolumn;
        this.yycolumn = i4;
        this.yyline_next = i3;
        this.yycolumn_next = i4;
        this.yy_endRead_l = i2;
        this.yy_buffer_l = cArr;
        this.yycmap_l = yycmap;
    }

    public final void yypushBuffer(char[] cArr, int i2, int i3) {
        this.yy_streams.push(new YY_StreamInfo(this.yy_reader, this.yy_endRead, this.yy_startRead, this.yy_savePos, this.yy_currentPos, this.yy_markedPos, this.yy_pushbackPos, this.yy_buffer, this.yy_atEOF, this.yyline, this.yycolumn));
        this.yy_atEOF = true;
        this.yy_buffer = cArr;
        this.yy_reader = null;
        this.yy_pushbackPos = i2;
        this.yy_currentPos = i2;
        this.yy_markedPos = i2;
        this.yy_startRead = i2;
        this.yy_savePos = -1;
        int i4 = i2 + i3;
        this.yy_endRead = i4;
        this.yycolumn_next = 0;
        this.yyline_next = 0;
        this.yycolumn = 0;
        this.yyline = 0;
        this.yy_endRead_l = i4;
        this.yy_buffer_l = cArr;
    }

    public final void yypushStream(Reader reader) {
        this.yy_streams.push(new YY_StreamInfo(this.yy_reader, this.yy_endRead, this.yy_startRead, this.yy_savePos, this.yy_currentPos, this.yy_markedPos, this.yy_pushbackPos, this.yy_buffer, this.yy_atEOF, this.yyline_next, this.yycolumn_next));
        this.yy_atEOF = false;
        char[] cArr = new char[16384];
        this.yy_buffer = cArr;
        this.yy_reader = reader;
        this.yy_startRead = 0;
        this.yy_endRead = 0;
        this.yy_savePos = -1;
        this.yy_pushbackPos = 0;
        this.yy_markedPos = 0;
        this.yy_currentPos = 0;
        this.yycolumn_next = 0;
        this.yyline_next = 0;
        this.yycolumn = 0;
        this.yyline = 0;
        this.yy_endRead_l = 0;
        this.yy_buffer_l = cArr;
    }

    public final void yyreset(Reader reader) {
        yyclose();
        this.yy_buffer = this.yy_saved_buffer;
        this.yy_reader = reader;
        this.yy_atBOL = true;
        this.yy_atEOF = false;
        this.yy_startRead = 0;
        this.yy_endRead = 0;
        this.yy_savePos = -1;
        this.yy_pushbackPos = 0;
        this.yy_markedPos = 0;
        this.yy_currentPos = 0;
        this.yycolumn = 0;
        this.yychar = 0;
        this.yyline = 0;
        this.yy_lexical_state = 0;
        this.yy_state = 0;
        this.yy_sawCR = false;
        this.yycolumn_next = 0;
        this.yyline_next = 0;
        this.yy_streams.clear();
    }

    public final void yyskip(int i2) {
        int i3 = this.yy_markedPos + i2;
        this.yy_markedPos = i3;
        this.yy_markedPos_l = i3;
        if (i3 > this.yy_endRead) {
            yy_ScanError(4);
        }
    }

    public final int yystate() {
        return this.yy_lexical_state;
    }

    public final String yytext() {
        char[] cArr = this.yy_buffer;
        int i2 = this.yy_startRead;
        return new String(cArr, i2, this.yy_markedPos - i2);
    }

    private int cdataToken(int i2, char[] cArr, int i3, int i4) {
        this.cdataBuffer = cArr;
        this.cdataStart = i3;
        this.cdataLength = i4;
        return i2;
    }

    private FatalParsingException fatalError(String str, Exception exc) {
        return new FatalParsingException(str, exc);
    }

    private void pushEntityState(String str, boolean z, boolean z2, int i2) {
        int i3 = 0;
        int i4 = (this.entityBaseDepth << 11) | ((this.prevEntityLexState & 255) << 3) | (this.returnEntityEndToken ? 4 : 0);
        if (this.isParamEntity) {
            i3 = 2;
        }
        this.entityStateStack.push((long) (i4 | i3 | (this.isEntityBeingParsed ? 1 : 0)));
        this.entityBaseDepth = this.tagStack.size();
        this.entityNameStack.push(this.currentEntityName);
        this.currentEntityName = str;
        this.isParamEntity = z;
        this.returnEntityEndToken = z2;
        this.isEntityBeingParsed = true;
        this.prevEntityLexState = i2;
    }

    public static int yy_unpack(String str, int i2, int[] iArr) {
        int i3;
        int length = str.length();
        int i4 = 0;
        while (i4 < length) {
            int i5 = i4 + 1;
            int charAt = str.charAt(i4);
            int i6 = i5 + 1;
            int charAt2 = str.charAt(i5) - 1;
            while (true) {
                i3 = i2 + 1;
                iArr[i2] = charAt2;
                charAt--;
                if (charAt <= 0) {
                    break;
                }
                i2 = i3;
            }
            i4 = i6;
            i2 = i3;
        }
        return i2;
    }

    private String yytext2(int i2, int i3) {
        return this.stringConverter.convert(this.yy_buffer, this.yy_startRead + i2, i3);
    }

    public void pushEntity(String str, Entity entity, boolean z, boolean z2, int i2) {
        if (str != null) {
            try {
                this.parser.reportStartEntity(str);
            } catch (RecursionException unused) {
                StringBuffer a = a.a("Recursive reference to entity '");
                a.append(entity.getSystemID());
                a.append("'");
                throw fatalError(a.toString());
            }
        }
        entity.open();
        if (entity.isInternal()) {
            char[] charArrayValue = entity.charArrayValue();
            yypushBuffer(charArrayValue, 0, charArrayValue.length);
        } else {
            yypushStream(entity.getReader());
        }
        this.entityStack.push(this.currentEntity);
        this.currentEntity = entity;
        pushEntityState(str, z, z2, i2);
    }

    public final String yytext(int i2, int i3) {
        return new String(this.yy_buffer, this.yy_startRead + i2, i3);
    }

    private int cdataToken(char c) {
        char[] cArr = this.oneCharBuffer;
        cArr[0] = c;
        this.cdataBuffer = cArr;
        this.cdataStart = 0;
        this.cdataLength = 1;
        return 257;
    }

    private void appendToCbuf(char[] cArr, int i2, int i3) {
        if (i3 > 0) {
            char[] cArr2 = this.cbuf;
            int length = cArr2.length;
            int i4 = this.cbuflen;
            if (length - i4 < i3) {
                char[] cArr3 = new char[((cArr2.length + i3) * 2)];
                System.arraycopy(cArr2, 0, cArr3, 0, i4);
                this.cbuf = cArr3;
            }
            System.arraycopy(cArr, i2, this.cbuf, this.cbuflen, i3);
            this.cbuflen += i3;
        }
    }

    public void pushEntity(String str, String str2, String str3, boolean z, boolean z2) {
        pushEntity(str, str2, str3, z, z2, 0);
    }

    public void pushEntity(String str, String str2, String str3, boolean z, boolean z2, int i2) {
        pushEntity(str, this.entityManager.getByID(this.currentEntity, str2, str3), z, z2, i2);
    }

    public final void yyreset(char[] cArr, int i2, int i3) {
        yyclose();
        this.yy_buffer = cArr;
        this.yy_reader = null;
        this.yy_atBOL = true;
        this.yy_atEOF = true;
        this.yy_startRead = i2;
        this.yy_pushbackPos = i2;
        this.yy_markedPos = i2;
        this.yy_currentPos = i2;
        this.yy_savePos = -1;
        int i4 = i2 + i3;
        this.yy_endRead = i4;
        this.yycolumn = 0;
        this.yychar = 0;
        this.yyline = 0;
        this.yy_lexical_state = 0;
        this.yy_state = 0;
        this.yy_sawCR = false;
        this.yycolumn_next = 0;
        this.yyline_next = 0;
        this.yy_endRead_l = i4;
        this.yy_buffer_l = cArr;
        this.yy_streams.clear();
    }

    public PiccoloLexer(Reader reader) {
        this.yy_lexical_state = 0;
        char[] cArr = new char[16384];
        this.yy_buffer = cArr;
        this.yy_saved_buffer = cArr;
        this.yy_savePos = -1;
        this.yy_atBOL = true;
        this.yy_streams = new Stack();
        this.parser = null;
        this.currentEntity = null;
        this.stringConverter = new CharStringConverter(HSSFShapeTypes.ActionButtonMovie);
        this.entityManager = new EntityManager();
        this.entityStack = new Stack();
        this.attribs = new AttributesHolder();
        this.cbuf = new char[1024];
        this.oneCharBuffer = new char[1];
        this.entityStateStack = new LongStack(5);
        this.entityNameStack = new StringStack(2);
        this.tagStack = new StringStack(20);
        this.elementMap = new HashMap();
        this.elementDefinition = null;
        this.tokenStartColumn = -1;
        this.defaultAttributeSpecified = new boolean[4];
        this.nsSupport = new FastNamespaceSupport();
        this.yy_sawCR = false;
        this.yy_prev_sawCR = false;
        this.yyline_next = 0;
        this.yycolumn_next = 0;
        this.yy_reader = reader;
    }

    public PiccoloLexer(InputStream inputStream) {
        this(new InputStreamReader(inputStream));
    }
}
