package org.apache.xmlbeans.impl.util;

import b.b.a.a.a;
import java.io.File;
import java.io.FileOutputStream;
import java.io.FileReader;
import java.io.FileWriter;
import java.io.OutputStream;
import java.io.OutputStreamWriter;
import java.io.PrintStream;
import java.io.StringReader;
import java.io.StringWriter;
import java.io.Writer;
import java.nio.charset.Charset;
import java.nio.charset.CharsetEncoder;
import java.nio.charset.CodingErrorAction;
import java.util.ArrayList;
import java.util.HashSet;
import java.util.List;
import java.util.Set;
import org.apache.xmlbeans.Filer;
import org.apache.xmlbeans.impl.common.NameUtil;
import org.apache.xmlbeans.impl.tool.XMLBean;
import repackage.Repackager;

public class FilerImpl implements Filer {
    public static final Charset CHARSET;
    public File classdir;
    public boolean incrSrcGen;
    public Repackager repackager;
    public Set seenTypes;
    public List sourceFiles;
    public File srcdir;
    public boolean verbose;

    public static class IncrFileWriter extends StringWriter {
        public File _file;
        public Repackager _repackager;

        public IncrFileWriter(File file, Repackager repackager) {
            this._file = file;
            this._repackager = repackager;
        }

        /* JADX INFO: finally extract failed */
        @Override // java.io.StringWriter, java.io.Closeable, java.io.Writer, java.lang.AutoCloseable
        public void close() {
            super.close();
            Repackager repackager = this._repackager;
            String stringBuffer = (repackager != null ? repackager.repackage(getBuffer()) : getBuffer()).toString();
            ArrayList arrayList = new ArrayList();
            StringReader stringReader = new StringReader(stringBuffer);
            FileReader fileReader = new FileReader(this._file);
            try {
                Diff.readersAsText(stringReader, "<generated>", fileReader, this._file.getName(), arrayList);
                stringReader.close();
                fileReader.close();
                if (arrayList.size() > 0) {
                    Writer writerForFile = FilerImpl.writerForFile(this._file);
                    try {
                        writerForFile.write(stringBuffer);
                    } finally {
                        writerForFile.close();
                    }
                }
            } catch (Throwable th) {
                stringReader.close();
                fileReader.close();
                throw th;
            }
        }
    }

    public static class RepackagingWriter extends StringWriter {
        public File _file;
        public Repackager _repackager;

        public RepackagingWriter(File file, Repackager repackager) {
            this._file = file;
            this._repackager = repackager;
        }

        @Override // java.io.StringWriter, java.io.Closeable, java.io.Writer, java.lang.AutoCloseable
        public void close() {
            super.close();
            Writer writerForFile = FilerImpl.writerForFile(this._file);
            try {
                writerForFile.write(this._repackager.repackage(getBuffer()).toString());
            } finally {
                writerForFile.close();
            }
        }
    }

    static {
        Charset charset;
        try {
            charset = Charset.forName(System.getProperty("file.encoding"));
        } catch (Exception unused) {
            charset = null;
        }
        CHARSET = charset;
    }

    public FilerImpl(File file, File file2, Repackager repackager2, boolean z, boolean z2) {
        this.classdir = file;
        this.srcdir = file2;
        this.repackager = repackager2;
        this.verbose = z;
        List list = this.sourceFiles;
        this.sourceFiles = list == null ? new ArrayList() : list;
        this.incrSrcGen = z2;
        if (z2) {
            this.seenTypes = new HashSet();
        }
    }

    public static final Writer writerForFile(File file) {
        if (CHARSET == null) {
            return new FileWriter(file);
        }
        FileOutputStream fileOutputStream = new FileOutputStream(file);
        CharsetEncoder newEncoder = CHARSET.newEncoder();
        newEncoder.onUnmappableCharacter(CodingErrorAction.REPORT);
        return new OutputStreamWriter(fileOutputStream, newEncoder);
    }

    @Override // org.apache.xmlbeans.Filer
    public OutputStream createBinaryFile(String str) {
        if (this.verbose) {
            PrintStream printStream = System.err;
            StringBuffer stringBuffer = new StringBuffer();
            stringBuffer.append("created binary: ");
            stringBuffer.append(str);
            printStream.println(stringBuffer.toString());
        }
        File file = new File(this.classdir, str);
        file.getParentFile().mkdirs();
        return new FileOutputStream(file);
    }

    @Override // org.apache.xmlbeans.Filer
    public Writer createSourceFile(String str) {
        if (this.incrSrcGen) {
            this.seenTypes.add(str);
        }
        if (str.indexOf(36) > 0) {
            StringBuffer stringBuffer = new StringBuffer();
            stringBuffer.append(str.substring(0, str.lastIndexOf(46)));
            stringBuffer.append(".");
            stringBuffer.append(str.substring(str.indexOf(36) + 1));
            str = stringBuffer.toString();
        }
        StringBuffer stringBuffer2 = new StringBuffer();
        stringBuffer2.append(str.replace(NameUtil.PERIOD, File.separatorChar));
        stringBuffer2.append(XMLBean.JAVA);
        File file = new File(this.srcdir, stringBuffer2.toString());
        file.getParentFile().mkdirs();
        if (this.verbose) {
            PrintStream printStream = System.err;
            StringBuffer a = a.a("created source: ");
            a.append(file.getAbsolutePath());
            printStream.println(a.toString());
        }
        this.sourceFiles.add(file);
        if (!this.incrSrcGen || !file.exists()) {
            return this.repackager == null ? writerForFile(file) : new RepackagingWriter(file, this.repackager);
        }
        return new IncrFileWriter(file, this.repackager);
    }

    public Repackager getRepackager() {
        return this.repackager;
    }

    public List getSourceFiles() {
        return new ArrayList(this.sourceFiles);
    }
}
